(*******************************************************************
This file was generated automatically by the Mathematica front end.
It contains Initialization cells from a Notebook file, which
typically will have the same name as this file except ending in
".nb" instead of ".m".

This file is intended to be loaded into the Mathematica kernel using
the package loading commands Get or Needs.  Doing so is equivalent
to using the Evaluate Initialization Cells menu command in the front
end.

DO NOT EDIT THIS FILE.  This entire file is regenerated
automatically each time the parent Notebook file is saved in the
Mathematica front end.  Any changes you make to this file will be
overwritten.
***********************************************************************)



(* :Title:PrecisionPLot *)
(* :Author:Ted Ersek*)(* :Copyright 2002 by Ted Ersek, 
  Mikhail Bronshtein *)(* :
    Summary: This package implements a function called PrecisionPlot. 
          The function allows one to plot functions that require use of \
arbitrary precision arithmetic. *)
(* :Context:Graphics`PrecisionPlot` *)
(* :Keywords:Graphics, Plot, arbitrary precision, high precision *)
(* :Mathematica Version:3.0.1*)(* :Package Version:3.0,
  March 1999 *)(* :Acknowledgment: *)
(* :Warning: PrecisionPlot *)
(* :Limitations: *)
(* :Discussion: PrecisionPlot has all the options Plot has, 
  and will use the options in the same manner in every way. 
      PrecisionPlot has the HoldRest attribute instead of HoldAll as Plot \
does. This can be convenient since the following will give the desired \
result.
      PrecisionPlot[ D[f[x],x], {x,0,10} ];
    PrecisionPlot[ Table[f[x,n],{x,4}], {x,0,10} ];
  Besides that a lot of trouble would have been required to ensure the \
current implementation evaluates functions the same as the built in function \
Plot. PrecisionPlot also and uses a local environment for the dummy variable \
just like Plot. The notebook PrecisionPlot.nb contains examples *)

BeginPackage["DrawGraphics`PrecisionPlot`"]; 

PrecisionPlot::usage="PrecisionPlot[f, {x, xmin, xmax}] generates 
    a plot of f as a function of x from xmin to xmax.  
    PrecisionPlot[{f1, f2, ... }, {x, xmin, xmax}] plots several 
    functions fi.  PrecisionPlot should be used when a function needs to 
    be evaluated using arbitrary precision arithmetic.";

Begin["`Private`"]; 

Unprotect[PrecisionPlot];

SetAttributes[PrecisionPlot,HoldAll];

Options[PrecisionPlot]=Options[Plot];

SetOptions[PrecisionPlot,Compiled\[Rule]False];

PrecPlot[ expr_,{x_,xmin_,xmax_},opts___]:=
    Module[{n0,n=9,yw=1.0`3, ex1, ex2, t},
      If[ Im[expr/.x\[Rule]xmin ]=!=0,
        Plot[expr,{x,xmin,xmax},opts],
        
        (* else, Compute all that follows. *)
        (* Module initialized (n, 
              yw) to ensure the while loop below completes at least once. *)
        ex1=SetPrecision[expr ,\[Infinity]];
        (* n0 is used to get a starting precision for x values. *)
         n0=Floor[
            1/8Sum[(While[Precision[yw]<5.&&n<10000,
                        n*=2;
                        
                    yw=ex1/.x\[Rule]
                          SetPrecision[xmin+(xmax-xmin)(33.i-31)/107,n]
                    ];
                  n),{i,4}
                ]]; (* Finished computing n0.  *)
        
        (* 
          Next define ex2 to evaluate (expr) using (x) with n digits of \
precision.   
                If precision was too low double n and try again, 
          and keep doubling precision as required.  *)
        ex2:=(
            {yw,n}={1.0`3,n0};
            While[(Precision[yw]<6)&&(n<10000),
                n*=2;
                yw=ex1/.x\[Rule]SetPrecision[t,n]
              ];
            yw
            );  (* Finished computing ex2.  *)
        Plot[ex2,{t,xmin,xmax},opts]
        ]];


NonNumericQ=
    Function[{sym},
      Head[Unevaluated@sym]===Symbol&&!NumericQ[Unevaluated@sym],{HoldAll}];

PrecisionPlot[ 
    expr_,{x_?NonNumericQ,
      xmin_?(-$MaxMachineNumber\[LessEqual]#\[LessEqual]$MaxMachineNumber&),
      xmax_?(-$MaxMachineNumber\[LessEqual]#\[LessEqual]$MaxMachineNumber&)},
    opts___?OptionQ]:=
  Block[{x},
    Module[{ps,DispFunc,g,flatexpr,
        MessgWasOn=(Head[Precision::"mnprec"]=!=$Off)},
      flatexpr=Flatten@{expr};
      If[MessgWasOn,Off[Precision::"mnprec"]];
      ps=PlotStyle/.Flatten[{opts,Options[PrecisionPlot]}];
      (* Next we ensure ps is a list with sufficient depth for use with \
MapThread below. *)
      ps=Switch[ ps,   {},{{}},   {__List},ps,    _,{ps} ];
      (* Special handling of DisplayFunction is used since we may have \
DisplayFunction\[RuleDelayed]$DisplayFunction 
            
            and we should ensure $DisplayFunction doesn't evaluate.  
              The next step assigns the whole rule to DispFunc. *)
      DispFunc=
        First@Cases[
            Flatten[{opts,Options[PrecisionPlot]}],_[DisplayFunction,_],-2,
            1];
      g=MapThread[
          
          PrecPlot[ #1,{x,xmin,xmax},PlotStyle\[Rule]#2,
              DisplayFunction->Identity,opts]&,
          {flatexpr, PadRight[ps,Length[flatexpr],ps] }  
          ];
      If[MessgWasOn,On[Precision::"mnprec"]];
      Show[g,DispFunc]
      ]]

PrecisionPlot::symb=
    "PrecisionPlot was given expression `1` in the second argument and a \
non-numeric symbol was expected in this position.";
PrecisionPlot::pllm=
    "PrecisionPlot was given limiting value `1` in `2` which is not a \
machine-size real number.";
PrecisionPlot::pllm2=
    "PrecisionPlot was given limiting values `1` and `2` in `3` which are not \
machine-size real numbers.";
PrecisionPlot::lim=
    "The second argument in PrecisionPlot was `1` which doesn't have the \
required for {x,xmin,xmax}.";
PrecisionPlot::opt=
    "`1` was was used in PrecisionPlot as an argument beyond the second \
argument. PrecisionPlot only allows options beyond the second argument.";
PrecisionPlot::opts=
    "Expressions, `1`, were given beyond the second argument in \
PrecisionPlot. Only options are allowed beyond the second argument.";

PrecisionPlot[_,{x_?(!NonNumericQ[#]&),_,_},___]/;
    Message[PrecisionPlot::symb,Unevaluated@x]:="Never get here."

PrecisionPlot[ _,{x_,
        xmin_?(TrueQ[-$MaxMachineNumber\[LessEqual]#\[LessEqual]$\
MaxMachineNumber]&),
        xmax_?(!TrueQ[-$MaxMachineNumber\[LessEqual]#\[LessEqual]$\
MaxMachineNumber]&)},___]/;
    Message[PrecisionPlot::pllm,xmax,{x,xmin,xmax}]:="Never get here."

PrecisionPlot[ _,{x_,
        xmin_?(!TrueQ[-$MaxMachineNumber\[LessEqual]#\[LessEqual]$\
MaxMachineNumber]&),
        xmax_?(TrueQ[-$MaxMachineNumber\[LessEqual]#\[LessEqual]$\
MaxMachineNumber]&)},___]/;
    Message[PrecisionPlot::pllm,xmin,{x,xmin,xmax}]:="Never get here."

PrecisionPlot[ _,{_,
        xmin_?(!TrueQ[-$MaxMachineNumber\[LessEqual]#\[LessEqual]$\
MaxMachineNumber]&),
        xmax_?(!TrueQ[-$MaxMachineNumber\[LessEqual]#\[LessEqual]$\
MaxMachineNumber]&)},___]/;
    Message[PrecisionPlot::pllm2,xmin,xmax,{x,xmin,xmax}]:="Never get here."

PrecisionPlot[ _,intrval_?(Head[#]=!=List&),___]/;
    Message[PrecisionPlot::lim,intrval]:="Never get here."

PrecisionPlot[ _,_,junk__]/;
    With[{nonOptions=Cases[Flatten[{junk}],_?(!OptionQ[#]&)]},
      nonOptions=!={}&&If[Length[nonOptions]===1,
          Message[PrecisionPlot::opt,StringTake[ToString@nonOptions,{2,-2}]],
          Message[PrecisionPlot::opts,StringTake[ToString@nonOptions,{2,-2}]]
          ]
      ]:="Never get here."

Protect[PrecisionPlot];

End[];

EndPackage[];