(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10282,        283]*)
(*NotebookOutlinePosition[     11214,        316]*)
(*  CellTagsIndexPosition[     11139,        310]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["AngleArc", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AngleArc",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(center, \ {\[Theta]1, \[Theta]2}, \ radius, \ 
          label : Null, \ opts\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  "will draw a directed arc about center from angle \[Theta]1 to \[Theta]2 \
with the specified radius."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
The arc will have an arrow at the \[Theta]2 end\
\>", "MathCaption"],

Cell["\<\
If the optional argument label is not Null, the arc will be labeled near the \
center of the arc.\
\>", "MathCaption"],

Cell["\<\
The arcs will be circular only if AspectRatio \[Rule] Automatic.\
\>", "MathCaption"],

Cell["\<\
The size corresponds to the regular Plot scale.\
\>", "MathCaption"],

Cell["\<\
The options are AAArrowOptions, AAStyleOptions and AATextOptions.\
\>", "MathCaption"],

Cell[TextData[{
  "AAArrowOptions may be used to pass a List of options to prepend the \
default options passed to the Arrow routine.  The default options are ",
  Cell[BoxData[
      \({HeadScaling \[Rule] Relative, \ HeadCenter \[Rule] 1, 
        HeadLength \[Rule] 0.1}\)]]
}], "MathCaption"],

Cell[TextData[{
  "The angle label is formatted with StyleForm inside a Text statement. \
AAStyleOptions may be used to pass a List of options to prepend the default \
options passed to StyleForm. The default options are ",
  Cell[BoxData[
      \({FontSize \[Rule] 10, \ FontColor \[Rule] RGBColor[0, 0, 0]}\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "AATextOptions may be used to pass a List of options to prepend the default \
options passed to the Text statement. The default options are ",
  Cell[BoxData[
      \({Background \[Rule] Automatic}\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["AngleSquare",
    ButtonData:>{"AngleSquare"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Geometric Diagram with Angles", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
We are going to make a geometric diagram with a line at 45\[Degree] to the x \
axis going through the point -1 in the complex plane. Then we are going to \
draw the perpendicular to it from the origin. We want to mark the 45\[Degree] \
angles and the right angles. To find where the lines intersect...\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(eqn = \(-1\) + a\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\) \[Equal] 
        b\ \[ExponentialE]\^\(\[ImaginaryI]\ 3  \[Pi]/4\)\), "\
\[IndentingNewLine]", 
    \(eqnRe = \(ComplexExpand[Re[#]] &\) /@ eqn\), "\[IndentingNewLine]", 
    \(eqnIm = \(ComplexExpand[Im[#]] &\) /@ eqn\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(-1\) + a\ \[ExponentialE]\^\(\(\[ImaginaryI]\ \[Pi]\)\/4\) == 
      b\ \[ExponentialE]\^\(\(3\ \[ImaginaryI]\ \[Pi]\)\/4\)\)], "Output",
  CellLabel->"Out[2]="],

Cell[BoxData[
    \(\(-1\) + a\/\@2 == \(-\(b\/\@2\)\)\)], "Output",
  CellLabel->"Out[3]="],

Cell[BoxData[
    \(a\/\@2 == b\/\@2\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Solve[{eqnRe, eqnIm}]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({a \[Rule] 1\/\@2, b \[Rule] 1\/\@2}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["\<\
The coord function simply converts complex points to the coordinate list.\
\>", "Text"],

Cell[BoxData[{
    \(\(coord = {Re[#], Im[#]} &;\)\), "\n", 
    \(\(Draw2D[\[IndentingNewLine]{AngleSquare[
            coord[1\/\@2\ \[ExponentialE]\^\(\(3\ \[ImaginaryI]\ \
\[Pi]\)\/4\)], \(-\[Pi]\)/4, 0.05, Black, LightSteelBlue], 
          ParametricDraw[
            coord[\(-1\) + a\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)] // 
              Evaluate, {a, 0, 1.6}], \[IndentingNewLine]ParametricDraw[
            coord[b\ \[ExponentialE]\^\(\(3\ \[ImaginaryI]\ \[Pi]\)\/4\)] // 
              Evaluate, {b, 0, 
              1\/\@2}], \[IndentingNewLine]\(CirclePoint[coord[#], 3, \ 
                Black, \ Antique] &\) /@ {\(-1\), 
              0}, \[IndentingNewLine]CirclePoint[
            coord[1\/\@2\ \[ExponentialE]\^\(\(3\ \[ImaginaryI]\ \
\[Pi]\)\/4\)], 3, Black, 
            Antique], \[IndentingNewLine]Red, \[IndentingNewLine]AngleArc[
            coord[\(-1\)], \ {0, \[Pi]/4}, 
            0.2, \ \[Theta]], \[IndentingNewLine]AngleArc[
            coord[0], \ {\[Pi]/2, 3  \[Pi]/4}, 
            0.2, \ \[Theta]], \[IndentingNewLine]AngleSquare[coord[0], 0, 
            0.05, Black]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameTicks \[Rule] 
          False, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]AxesOrigin \[Rule] {0, 
            0}, \[IndentingNewLine]AxesStyle \[Rule] 
          Gray, \[IndentingNewLine]Background \[Rule] 
          Antique, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)}], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(Clear[coord, eqn, eqnRe, eqnIm]\)], "Input",
  CellLabel->"In[8]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Using Various AngleArc Options", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[9]:="],

Cell["Drawing AngleArcs with various options and embellishments.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Line[{{0, 0}, {1, 1} 
                2/3}], \[IndentingNewLine]\[IndentingNewLine]AngleArc[{0, 
              0}, {0, 45  \[Degree]}, 
            0.05], \[IndentingNewLine]AngleArc[{0, 0}, {0, 45  \[Degree]}, 
            0.1, \[Theta]], \[IndentingNewLine]\[IndentingNewLine]Red, \
\[IndentingNewLine]AngleArc[{0, 0}, {45  \[Degree], 90  \[Degree]}, 
            1/4, \[Pi]/
                2 - \[Theta]], \[IndentingNewLine]\[IndentingNewLine]Blue, \
\[IndentingNewLine]AngleArc[{0, 0}, {45  \[Degree], 90  \[Degree]}, 
            1/3, \[Pi]/
                2 - \[Theta], \[IndentingNewLine]AAArrowOptions \[Rule] \
{HeadCenter \[Rule] 1/2, 
                HeadLength \[Rule] 
                  0.2}, \[IndentingNewLine]AAStyleOptions \[Rule] {FontSize \
\[Rule] 12, FontFamily \[Rule] "\<Helvetica\>", 
                FontColor \[Rule] 
                  Gold}, \[IndentingNewLine]AATextOptions \[Rule] {Background \
\[Rule] SapGreen}], \[IndentingNewLine]\[IndentingNewLine]CinnabarGreen, \
\[IndentingNewLine]AngleArc[{0, 0}, {90  \[Degree], 45  \[Degree]}, 1/2, 
            FrameBox[
                HoldForm[\[Theta] - \[Pi]/
                      2], \[IndentingNewLine]BoxMargins \[Rule] {{1, 
                      1}, {0.7, 1}}, \[IndentingNewLine]BoxFrame \[Rule] 
                  True] // 
              DisplayForm, \[IndentingNewLine]AAArrowOptions \[Rule] \
{HeadCenter \[Rule] 1/2, 
                HeadLength \[Rule] 
                  0.2}, \[IndentingNewLine]AAStyleOptions \[Rule] {FontSize \
\[Rule] 12, FontFamily \[Rule] "\<Helvetica\>", 
                FontColor \[Rule] 
                  Gold}, \[IndentingNewLine]AATextOptions \[Rule] {Background \
\[Rule] Sepia}], \[IndentingNewLine]\[IndentingNewLine]Black, \
\[IndentingNewLine]AngleArc[{0, 0}, {0  \[Degree], 45  \[Degree]}, 1/2, 
            GridBox[{{\[Theta]}}, RowMinHeight \[Rule] 2, 
                RowAlignments \[Rule] Center, ColumnWidths \[Rule] 1] // 
              DisplayForm, \[IndentingNewLine]AAArrowOptions \[Rule] \
{HeadCenter \[Rule] 1/2, 
                HeadLength \[Rule] 
                  0.05}, \[IndentingNewLine]AAStyleOptions \[Rule] {FontSize \
\[Rule] 12, FontFamily \[Rule] "\<Helvetica\>", 
                FontColor \[Rule] 
                  Gold}, \[IndentingNewLine]AATextOptions \[Rule] {Background \
\[Rule] RoyalBlue}]}, \[IndentingNewLine]\[IndentingNewLine]AspectRatio \
\[Rule] Automatic, \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]Background \[Rule] 
          Antique, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]AxesStyle \[Rule] 
          Gray, \[IndentingNewLine]Ticks \[Rule] 
          None, \[IndentingNewLine]ImageSize \[Rule] 
          400\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[10]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{621, 733},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 55, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1834, 56, 464, 16, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 10968, 301}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 55, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1834, 56, 464, 16, 49, "Usage",
  CellTags->"Function?"],
Cell[2301, 74, 78, 2, 31, "MathCaption"],
Cell[2382, 78, 128, 3, 31, "MathCaption"],
Cell[2513, 83, 95, 2, 31, "MathCaption"],
Cell[2611, 87, 78, 2, 31, "MathCaption"],
Cell[2692, 91, 96, 2, 31, "MathCaption"],
Cell[2791, 95, 296, 6, 63, "MathCaption"],
Cell[3090, 103, 338, 7, 65, "MathCaption"],
Cell[3431, 112, 245, 6, 48, "MathCaption"],
Cell[3679, 120, 148, 6, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3852, 130, 55, 0, 40, "ExampleSection"],
Cell[3910, 132, 97, 2, 29, "Input"],
Cell[4010, 136, 325, 5, 59, "Text"],

Cell[CellGroupData[{
Cell[4360, 145, 340, 6, 70, "Input"],
Cell[4703, 153, 183, 3, 30, "Output"],
Cell[4889, 158, 92, 2, 40, "Output"],
Cell[4984, 162, 74, 2, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5095, 169, 144, 3, 30, "Input"],
Cell[5242, 174, 94, 2, 40, "Output"]
}, Open  ]],
Cell[5351, 179, 97, 2, 25, "Text"],
Cell[5451, 183, 1588, 28, 466, "Input"],
Cell[7042, 213, 88, 2, 29, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7167, 220, 56, 0, 34, "ExampleSection"],
Cell[7226, 222, 97, 2, 29, "Input"],
Cell[7326, 226, 74, 0, 25, "Text"],
Cell[7403, 228, 2851, 51, 829, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

