(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5812,        204]*)
(*NotebookOutlinePosition[      6820,        239]*)
(*  CellTagsIndexPosition[      6746,        233]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Arrow(Extensions)", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["Arrow",
          "MR"], 
        StyleBox["[",
          "MR"], 
        RowBox[{
          RowBox[{
            StyleBox["{",
              "MR"], 
            StyleBox[\(start, finish\),
              "TI"], 
            StyleBox["}",
              "TI"]}], 
          StyleBox[",",
            "TI"], 
          StyleBox[\(opts ... \),
            "TI"]}], 
        StyleBox["]",
          "MR"]}]]],
  " is the same as ",
  Cell[BoxData[
      RowBox[{
        StyleBox["Arrow",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(start, finish, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  "\n\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["Arrow",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(start, l, \[Theta], opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will draw an arrow from start at an angle \[Theta] to the x axis and of \
length l."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["These are extenstions to the regular Arrow routine.", "MathCaption"],

Cell[TextData[{
  "The regular ",
  ButtonBox["Arrow",
    ButtonData:>{"Graphics`Arrow`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  " options can be passed to the Arrow routine."
}], "MathCaption"],

Cell[TextData[{
  "The arrow extensions are part of the DrawGraphics`DrawingArrows` package. \
But this package will not be automatically loaded unless one of the ",
  StyleBox["other",
    FontSlant->"Italic"],
  " commands in the package is named. Hence you will have to explicitly load \
the DrawingArrows package if this is the only or first use of a command in \
the package."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Arrow",
    ButtonData:>{"Graphics`Arrow`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowLine",
    ButtonData:>{"ArrowLine"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowTangent",
    ButtonData:>{"ArrowTangent"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ProportionalArrow",
    ButtonData:>{"ProportionalArrow"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example  ", "ExampleSection"],

Cell["\<\
In this example we are using Arrow which is modified by DrawingArrows, but \
since we are not naming any explicit DrawingArrows routines we must \
specifically load DrawingArrows.\
\>", "Text"],

Cell[BoxData[{
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<DrawGraphics`DrawingArrows`\>"]\)}], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
The following generates a table of random point pairs based on the origin.\
\>", "Text"],

Cell[BoxData[
    \(\(pairs = 
        Table[{{0, 0}, {Random[Real, {\(-1\), 1}], 
              Random[Real, {\(-1\), 1}]}}, {10}];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell["We can now map Arrow directly onto the point pairs.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{\(Arrow[#, HeadCenter \[Rule] 1/2] &\) /@ 
            pairs}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]PlotRange \[Rule] All];\)\)], "Input",\

  CellLabel->"In[4]:="],

Cell["\<\
This draws a series of arrows from the origin based on their length and angle \
with the x axis.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Table[
            Arrow[{0, 0}, 1 + \[Theta]/4, \[Theta], 
              HeadCenter \[Rule] 1/2], {\[Theta], 0, 
              2  \[Pi] - \[Pi]/16, \[Pi]/
                16}]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(Clear[pairs]\)], "Input",
  CellLabel->"In[6]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{515, 736},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 64, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1843, 56, 1125, 47, 73, "Usage",
      CellTags->"Function?"],
    Cell[2971, 105, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6498, 222}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 64, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1843, 56, 1125, 47, 73, "Usage",
  CellTags->"Function?"],
Cell[2971, 105, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[3068, 110, 74, 0, 41, "MathCaption"],
Cell[3145, 112, 198, 6, 41, "MathCaption"],
Cell[3346, 120, 400, 8, 92, "MathCaption"],
Cell[3749, 130, 463, 18, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[4237, 152, 35, 0, 39, "ExampleSection"],
Cell[4275, 154, 203, 4, 42, "Text"],
Cell[4481, 160, 173, 3, 49, "Input"],
Cell[4657, 165, 98, 2, 25, "Text"],
Cell[4758, 169, 171, 4, 49, "Input"],
Cell[4932, 175, 67, 0, 25, "Text"],
Cell[5002, 177, 256, 5, 89, "Input"],
Cell[5261, 184, 120, 3, 25, "Text"],
Cell[5384, 189, 328, 7, 89, "Input"],
Cell[5715, 198, 69, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

