(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8246,        236]*)
(*NotebookOutlinePosition[      9328,        273]*)
(*  CellTagsIndexPosition[      9254,        267]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Arrow2D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["Arrow2D",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(origin, vector, opt ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will draw a 2D arrow specified by vector from the point specified by \
origin. Suitable only for plots with Automatic AspectRatio."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Arrow2D is a substitute for the Arrow primitive. It is suitably only for \
plots that have Automatic AspectRatio. But it is more robust and verstile \
than the regular Arrow command. It is more robust in the sense that it \
maintains its integrity better when short arrows are specified with a nonzero \
origin. It also differs from Arrow in that the origin and vector that defines \
the arrow are specified instead of the base and tip.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
The options are HeadScaling2D, HeadLength2D, HeadWidth2D, HeadCenter2D, \
HeadPosition3D, HeadColor2D and ShaftColor2D. They are roughly similar to the \
standard Arrow routine options.\
\>", "MathCaption"],

Cell["\<\
HeadScaling2D may be set to Relative (the default) or to a specific length. \
If Relative, the HeadLength2D is scaled to the arrow length, otherwise it is \
scaled to the specified length.\
\>", "MathCaption"],

Cell["\<\
HeadLength2D specifies the length of the arrowhead as a fraction of the arrow \
length if HeadScaling2D is Relative, or as a fraction of the specified length \
given in HeadScaling2D. The default is 0.15.\
\>", "MathCaption"],

Cell["\<\
HeadWidth2D specifies the width of the arrowhead as a fraction of \
HeadLength2D. The default is 0.5.\
\>", "MathCaption"],

Cell[TextData[{
  "HeadCenter2D specifies the distance from the arrowhead tip to the \
arrowhead center as a fraction of HeadLength2D. The default is 0.5. ",
  Cell[BoxData[
      \(HeadCenter2D \[Rule] 1\)]],
  " gives a triangular arrowhead. When it is less than 1 it gives a  barbed \
arrowhead."
}], "MathCaption"],

Cell["\<\
HeadPosition2D specifies the position of the arrowhead center along the arrow \
shaft. The default position is Automatic, which puts the tip at the end of \
the shaft. This allows the arrowhead to be put at any fractional position \
along the line.\
\>", "MathCaption"],

Cell["\<\
HeadColor2D specifies the color of the arrowhead. The default value is Black.\
\
\>", "MathCaption"],

Cell["\<\
ShaftColor2D specifies the color of the arrow shaft. The default value is \
Black.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ArrowLine",
    ButtonData:>{"ArrowLine"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowTangent",
    ButtonData:>{"ArrowTangent"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Arrow",
    ButtonData:>{"Graphics`Arrow`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  " ."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Arrow2D[{0, 0}, {1, 
              0}], \[IndentingNewLine]Arrow2D[{0, 0}, {1, 1}/\@2, 
            HeadCenter2D \[Rule] 1], \[IndentingNewLine]Arrow2D[{0, 0}, {0, 
              1}, HeadColor2D \[Rule] 
              GreenishUmber], \[IndentingNewLine]Arrow2D[{0, 
              0}, \(-{1, 1}\)/\@2, ShaftColor2D \[Rule] Red, 
            HeadPosition2D \[Rule] 0.5, HeadScaling2D \[Rule] 0.6, 
            HeadWidth2D \[Rule] 1]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]ImageSize \[Rule] 450];\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  "The following draws a small arrow of length ",
  Cell[BoxData[
      \(\(\(10\^\(-n\)\)\(\ \)\)\)]],
  " starting at the point ",
  Cell[BoxData[
      \({1, 0}\)]],
  ". The plot range is scaled so the picture should remain unchanged until \
precision is lost. The integrity remains good up to about ",
  Cell[BoxData[
      \(n \[Equal] 13.5\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(frame[n_] := 
        Show[Graphics[{Arrow2D[{1. , 0}, {10\^\(-n\), 0}, 
                HeadLength2D \[Rule] 0.2, HeadWidth2D \[Rule] 0.7], 
              Text[SequenceForm["\<n = \>", n], 
                Scaled[{0.1, 0.9}], {\(-1\), 
                  0}]}], \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]FrameTicks \[Rule] 
            None, \[IndentingNewLine]PlotRange \[Rule] {{1.  - 10\^\(-n\), 
                1.  + 2\/10\^n}, {\(-\(1\/10\^n\)\), 1\/10\^n}}];\)\), "\n", 
    \(\(Table[frame[n], {n, 2, 15, 0.2}];\)\), "\n", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]; 
    Pause[0.5];\), "\[IndentingNewLine]", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input",
  CellLabel->"In[3]:="],

Cell[TextData[{
  "Here is a similar arrow draw with the regular Arrow routine. The integrity \
of the arrow falls apart at about ",
  Cell[BoxData[
      \(n \[Equal] 5\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(frame[n_] := 
        Show[Graphics[{Arrow[{1. , 0}, {1.0 + 10\^\(-n\), 0}, 
                HeadScaling \[Rule] Relative, HeadLength \[Rule] 0.2, 
                HeadWidth \[Rule] 0.7, HeadCenter \[Rule] 0.5], 
              Text[SequenceForm["\<n = \>", n], 
                Scaled[{0.1, 0.9}], {\(-1\), 
                  0}]}], \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]FrameTicks \[Rule] 
            None, \[IndentingNewLine]PlotRange \[Rule] {{1.  - 10\^\(-n\), 
                1.  + 2\/10\^n}, {\(-\(1\/10\^n\)\), 1\/10\^n}}];\)\), "\n", 
    \(\(Table[frame[n], {n, 2, 15, 0.2}];\)\), "\n", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]; 
    Pause[0.5];\), "\[IndentingNewLine]", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input",
  CellLabel->"In[8]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{790, 586},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 54, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1833, 56, 441, 15, 50, "Usage",
      CellTags->"Function?"],
    Cell[2277, 73, 94, 3, 41, "MathCaption",
      CellTags->"Function?"],
    Cell[2374, 78, 492, 8, 75, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 8932, 254}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 54, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1833, 56, 441, 15, 50, "Usage",
  CellTags->"Function?"],
Cell[2277, 73, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2374, 78, 492, 8, 75, "MathCaption",
  CellTags->"Function?"],
Cell[2869, 88, 216, 4, 58, "MathCaption"],
Cell[3088, 94, 219, 4, 58, "MathCaption"],
Cell[3310, 100, 235, 4, 58, "MathCaption"],
Cell[3548, 106, 132, 3, 41, "MathCaption"],
Cell[3683, 111, 318, 7, 58, "MathCaption"],
Cell[4004, 120, 279, 5, 58, "MathCaption"],
Cell[4286, 127, 110, 3, 41, "MathCaption"],
Cell[4399, 132, 113, 3, 41, "MathCaption"],
Cell[4515, 137, 352, 14, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[4892, 155, 34, 0, 39, "ExampleSection"],
Cell[4929, 157, 97, 2, 29, "Input"],
Cell[5029, 161, 727, 12, 225, "Input"],
Cell[5759, 175, 385, 12, 42, "Text"],
Cell[6147, 189, 901, 16, 224, "Input"],
Cell[7051, 207, 192, 6, 25, "Text"],
Cell[7246, 215, 972, 17, 244, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

