(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    124076,       2283]*)
(*NotebookOutlinePosition[    125085,       2318]*)
(*  CellTagsIndexPosition[    125008,       2312]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Arrow3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["Arrow3D",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(base, tip, opt ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will draw a 3D arrow from base to tip. There will be an arrowcone at the \
tip."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
The options are HeadScaling3D, HeadLength3D, HeadWidth3D, HeadSegments3D. \
They are roughly similar to the standard Arrow routine options.\
\>", "MathCaption"],

Cell["\<\
HeadScaling3D may be set to Relative (the default) or to a specific length. \
If Relative, the HeadLength3D is scaled to the arrow length, otherwise it is \
scaled to the specified length.\
\>", "MathCaption"],

Cell["\<\
HeadLength3D specifies the length of the arrowcone as a fraction of the arrow \
length if HeadScaling3D is Relative, or as a fraction of the specified length \
given in HeadScaling3D. The default is 0.1.\
\>", "MathCaption"],

Cell["\<\
HeadWidth3D specifies the width of the arrowcone as a fraction of the \
HeadLength3D. The default is 0.5.\
\>", "MathCaption"],

Cell["\<\
HeadSegments3D specifies the number of triangular segments used to draw the \
arrowcone. The default is 10. Two segments may be used to give a flat \
arrowhead.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ArrowCurve3D",
    ButtonData:>{"ArrowCurve3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowLine3D",
    ButtonData:>{"ArrowLine3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowTangent3D",
    ButtonData:>{"ArrowTangent3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ProportionalArrow3D",
    ButtonData:>{"ProportionalArrow3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Arrow",
    ButtonData:>{"Graphics`Arrow`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  " ."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[3]:="],

Cell["Here, three arrows are drawn with Relative scaling.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{Arrow3D[{0, 0, 0}, {1, 1, 
              1}], \[IndentingNewLine]Red, 
          Arrow3D[{0, 0, 0}, {1, 0, 0}], \[IndentingNewLine]Blue, 
          Arrow3D[{0, 0, 0}, {0, 0, 
              1/4}]}, \[IndentingNewLine]PlotRange \[Rule] All];\)\)], "Input",\

  CellLabel->"In[11]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0949 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0606185 1.17489 1.95265e-016 1.17489 [
[ 0 0 0 0 ]
[ 1 1.0949 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08862 .24391 m
0 .80933 L
s
0 .80933 m
.40416 1.0949 L
s
.40416 1.0949 m
.42134 .58437 L
s
.42134 .58437 m
.08862 .24391 L
s
.66882 0 m
.92726 .41879 L
s
.92726 .41879 m
1 .95839 L
s
1 .95839 m
.70179 .59254 L
s
.70179 .59254 m
.66882 0 L
s
.08862 .24391 m
0 .80933 L
s
0 .80933 m
.70179 .59254 L
s
.70179 .59254 m
.66882 0 L
s
.66882 0 m
.08862 .24391 L
s
.42134 .58437 m
.92726 .41879 L
s
.92726 .41879 m
1 .95839 L
s
1 .95839 m
.40416 1.0949 L
s
.40416 1.0949 m
.42134 .58437 L
s
0 0 m
1 0 L
1 1.0949 L
0 1.0949 L
closepath
clip
newpath
.5 Mabswid
.792 .457 .421 r
.10219 .39379 m .10398 .38443 L .10162 .38373 L closepath p F P
0 g
s
.588 .26 .381 r
.10219 .39379 m .10631 .38414 L .10398 .38443 L closepath p F P
0 g
s
.031 0 .104 r
.10219 .39379 m .10773 .38297 L .10631 .38414 L closepath p F P
0 g
s
.941 .596 .339 r
.10219 .39379 m .10162 .38373 L .10014 .38231 L closepath p F P
0 g
s
.974 .914 .583 r
.10219 .39379 m .10769 .38136 L .10773 .38297 L closepath p F P
0 g
s
0 0 .248 r
.10219 .39379 m .10014 .38231 L .1001 .38071 L closepath p F P
0 g
s
.913 .724 .634 r
.10219 .39379 m .10622 .37994 L .10769 .38136 L closepath p F P
0 g
s
.396 .26 .577 r
.10219 .39379 m .1001 .38071 L .10152 .37953 L closepath p F P
0 g
s
.793 .585 .619 r
.10219 .39379 m .10386 .37924 L .10622 .37994 L closepath p F P
0 g
s
0 0 1 r
.10427 .37936 m
.11882 .27848 L
s
.656 .46 .606 r
.10219 .39379 m .10152 .37953 L .10386 .37924 L closepath p F P
0 g
s
.699 .445 .536 r
.97661 .94006 m .8799 .87421 L .87128 .88602 L closepath p F P
0 g
s
.631 .484 .664 r
.97661 .94006 m .89042 .86063 L .8799 .87421 L closepath p F P
0 g
s
.51 .477 .756 r
.97661 .94006 m .89895 .85031 L .89042 .86063 L closepath p F P
0 g
s
.713 .257 .169 r
.97661 .94006 m .87128 .88602 L .86781 .89163 L closepath p F P
0 g
s
.05 .297 .786 r
.97661 .94006 m .90226 .84717 L .89895 .85031 L closepath p F P
0 g
s
.185 .561 .934 r
.97661 .94006 m .86781 .89163 L .87092 .88878 L closepath p F P
0 g
s
.883 .479 .251 r
.97661 .94006 m .89899 .85256 L .90226 .84717 L closepath p F P
0 g
s
.604 .621 .842 r
.97661 .94006 m .87092 .88878 L .87951 .87841 L closepath p F P
0 g
s
.11882 .27848 m
.97569 .93934 L
s
.797 .577 .603 r
.97661 .94006 m .89028 .86452 L .89899 .85256 L closepath p F P
0 g
s
.713 .599 .728 r
.97661 .94006 m .87951 .87841 L .89028 .86452 L closepath p F P
0 g
s
.546 .47 .721 r
.66915 .05247 m .61271 .07488 L .61561 .08461 L closepath p F P
0 g
s
.593 .621 .849 r
.66915 .05247 m .60822 .06607 L .61271 .07488 L closepath p F P
0 g
s
.389 .182 .474 r
.66915 .05247 m .61561 .08461 L .61585 .0916 L closepath p F P
0 g
s
.569 .779 .977 r
.66915 .05247 m .60384 .06152 L .60822 .06607 L closepath p F P
0 g
s
.457 .841 .618 r
.66915 .05247 m .61585 .0916 L .6133 .0932 L closepath p F P
0 g
s
.106 0 0 r
.66915 .05247 m .60124 .063 L .60384 .06152 L closepath p F P
0 g
s
.754 .848 .921 r
.66915 .05247 m .6133 .0932 L .60892 .08873 L closepath p F P
0 g
s
.593 .333 .492 r
.66915 .05247 m .60144 .07001 L .60124 .063 L closepath p F P
0 g
s
.71 .678 .817 r
.66915 .05247 m .60892 .08873 L .60438 .07986 L closepath p F P
0 g
s
.667 .542 .703 r
.66915 .05247 m .60438 .07986 L .60144 .07001 L closepath p F P
0 g
s
1 0 0 r
.11882 .27848 m
.60417 .07916 L
s
0 g
.25 Mabswid
.66882 0 m
.92726 .41879 L
s
.92726 .41879 m
1 .95839 L
s
1 .95839 m
.70179 .59254 L
s
.70179 .59254 m
.66882 0 L
s
.08862 .24391 m
0 .80933 L
s
0 .80933 m
.70179 .59254 L
s
.70179 .59254 m
.66882 0 L
s
.66882 0 m
.08862 .24391 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[11]:=",
  ImageSize->{263, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004700017b000`400?l00000o`00003o[P3oool2
000005L0oooo002/0?ooo`80000000<0oooo000000000000EP3oool00:X0oooo0P0000030?ooo`80
0000EP3oool00:L0oooo0`0000050?ooo`030000003oool0000005D0oooo002U0?ooo`800000203o
ool00`000000oooo0000001E0?ooo`00XP3oool3000000X0oooo00@000000?ooo`3oool00000E03o
ool00:00oooo0P00000=0?ooo`050000003oool0oooo0?ooo`000000D`3oool009h0oooo0P00000?
0?ooo`050000003oool0oooo0?ooo`000000D`3oool009/0oooo0`00000A0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0D03oool009T0oooo0P00000D0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0C`3oool009L0oooo0P00000G0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0C`3oool009@0oooo0`00000I0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0CP3oool00980oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0CP3oool008l0oooo0`00000K0?ooo`@000001P3oool00`000000oooo0?ooo`1=
0?ooo`00S@3oool2000001P0oooo200000000`3oool000000?ooo`060?ooo`030000003oool0oooo
04`0oooo002;0?ooo`800000503oool=00000080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1<0?ooo`00R03oool300000180oooo1000000209MEO@@0000000<0ZXZc000000000000
0P0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B`3oool008H0oooo0P00
000E0?ooo`030000002GEGd0000000<000000`2ZR[<5000000D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1;0?ooo`00Q03oool2000001L0oooo0P0000050:Z:/`80000000@0]JgA
00000000000000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04X0oooo0021
0?ooo`<000006@3oool00`000000ZXZc0:Z:/`020:Z:/`80000000<0]JgA0000000000000P000007
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0B@3oool007l0oooo0P00000L0?oo
o`80o`0000<0ZXZc0000000000000P2e[M43000000T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`190?ooo`00O03oool3000001`0oooo0P3o00000`3oool00000000000020;F]d@@0
00002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04P0oooo001j0?ooo`800000
7@3oool20?l000<0oooo00D000000;F]d@00000000000<7Ij`02000000/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`170?ooo`00N03oool2000001`0oooo0`3o00060?ooo`040000
0031fN/00000000000d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`170?ooo`00
M@3oool3000001`0oooo0P3o000:0?ooo`8000003P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo04H0oooo001c0?ooo`800000703oool30?l001`0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`160?ooo`00L@3oool2000001`0oooo0P3o000O0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0A@3oool006h0oooo0`00000L0?ooo`80o`008@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo04@0oooo001/0?ooo`800000703oool30?l002<0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`140?ooo`00J@3oool3000001`0oooo
0P3o000V0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0@`3oool006L0oooo0P00
000L0?ooo`<0o`00:@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04<0oooo001U
0?ooo`800000703oool20?l002`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`12
0?ooo`00HP3oool3000001`0oooo0P3o000^0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0@@3oool00600oooo0P00000L0?ooo`<0o`00<03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0440oooo001N0?ooo`800000703oool20?l003<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`100?ooo`00F`3oool3000001/0oooo0`3o000e0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0?`3oool005T0oooo0P00000L0?ooo`80o`00>03oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03l0oooo001F0?ooo`<00000703oool20?l0
03X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`00E03oool2000001`0
oooo0`3o000l0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00580oooo
0P00000L0?ooo`80o`00?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03d0oooo
001?0?ooo`<000006`3oool30?l00440oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0l0?ooo`00C@3oool2000001`0oooo0P3o00140?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0?03oool004/0oooo0P00000L0?ooo`80o`00AP3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo03/0oooo00180?ooo`<000006`3oool30?l004P0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0k0?ooo`00AP3oool2000001`0oooo0P3o001;0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0>P3oool004<0oooo0`00000K0?ooo`<0o`00C@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03T0oooo00110?ooo`800000703oool2
0?l00500oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0i0?ooo`00?`3oool20000
01`0oooo0P3o001B0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0>03oool003`0
oooo0`00000K0?ooo`<0o`00E03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03L0
oooo000j0?ooo`800000703oool20?l005P0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0g0?ooo`00>03oool2000001/0oooo0`3o001J0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0=P3oool003D0oooo0`00000K0?ooo`80o`00G@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo03H0oooo000c0?ooo`800000703oool20?l005l0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0e0?ooo`00<03oool3000001/0oooo0`3o001Q0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0=03oool002h0oooo0P00000L0?ooo`80o`00
I03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03@0oooo000/0?ooo`8000006`3o
ool30?l006H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0c0?ooo`00:@3oool3
000001/0oooo0P3o001Y0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0<`3oool0
02L0oooo0P00000L0?ooo`80o`00J`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0380oooo000U0?ooo`8000006`3oool30?l006d0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0a0?ooo`008P3oool3000001/0oooo0P3o001`0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0<@3oool00200oooo0P00000K0?ooo`<0o`00LP3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0300oooo000M0?ooo`<000006`3oool20?l007D0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0`0?ooo`006`3oool2000001`0oooo0P3o001g0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0;`3oool001T0oooo0P00000K0?ooo`<0
o`00N@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02h0oooo000G0?ooo`800000
6`3oool20?l007`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0^0?ooo`005`3o
ool2000001P0oooo0`3o001n0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0;@3o
ool001L0oooo00<000000?ooo`0000005@3oool20?l00840oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0/0?ooo`005`3oool010000000oooo0?ooo`00000B0?ooo`80o`00P`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02`0oooo000F0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool30?l008H0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0[0?ooo`005P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0
oooo0P3o00290?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:`3oool001H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`<0o`00R`3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo02X0oooo000F0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool20?l008h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0Y0?ooo`005P3oool00`000000oooo0?ooo`060?ooo`040000003oool0o`000?l00900oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0Y0?ooo`005P3oool00`000000oooo0?ooo`06
0?ooo`80o`00TP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02P0oooo000E0?oo
o`030000003oool0oooo00L0oooo00<0003o000000000000T@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo02P0oooo000E0?ooo`030000003oool0oooo00L0oooo00@0003o0?ooo`00
00000000T03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02L0oooo000E0?ooo`03
0000003oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000002?0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool09P3oool001D0oooo00<000000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`030?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0V0?ooo`005@3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo
0P00002<0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool09@3oool001D0oooo00<0
00000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`800000R`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo02@0oooo000E0?ooo`030000003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool2000008X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0T
0?ooo`00503oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo0`0000280?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool08`3oool001@0oooo00<000000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`080?ooo`030000003oool0000008L0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0S0?ooo`00503oool00`000000oooo0?ooo`060?ooo`030000
o`3oool0oooo00X0oooo00<000000?ooo`000000QP3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo0280oooo000D0?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool02`3o
ool00`000000oooo000000250?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool08@3o
ool001@0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0<0?ooo`040000003oool0
0000000008<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0Q0?ooo`00503oool0
0`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00d0oooo00@000000?ooo`3oool00000PP3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0200oooo000C0?ooo`030000003oool0
oooo00L0oooo00<0003o0?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000840oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0P0?ooo`004`3oool00`000000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00h0oooo00@000000?ooo`3oool0oooo0P0000200?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool07`3oool001<0oooo00<000000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01h0oooo000C0?ooo`030000003oool0oooo
00H0oooo00<0003o0?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
07`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0N0?ooo`004`3oool00`000000
oooo0?ooo`060?ooo`030000o`3oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool07@3oool001<0oooo
00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo
0P00001k0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0703oool00180oooo00<0
00000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01`0oooo000B
0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0K
0?ooo`004P3oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo01H0oooo00<000000?oo
o`3oool00`3oool2000007L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0K0?oo
o`004P3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool06P3oool00180oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0I0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo01T0oooo000B0?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool06P3o
ool00`000000oooo0?ooo`040?ooo`800000L`3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo01T0oooo000B0?ooo`030000003oool0oooo00D0oooo0P00000M0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo01P0oooo000A0?ooo`030000003oool0oooo00H0oooo0`00000M0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
01P0oooo000A0?ooo`030000003oool0oooo00H0oooo0P00000O0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01L0
oooo000A0?ooo`030000003oool0oooo00H0oooo0P00000P0?ooo`030000003oool0oooo00D0oooo
0P00001^0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool05P3oool00140oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01H0oooo000A
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool05@3oool00140oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`060?ooo`800000JP3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo01@0oooo000@0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0503oool00100oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0C0?ooo`00403o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01<0oooo000@0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool01`3oool2000006H0oooo00<000000?ooo`3oool0>@3oool2
000001@0oooo000@0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo03H0oooo0`0000000`3oool000000?ooo`0C0?oo
o`00403oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0HP3oool00`000000oooo0?ooo`0c0?ooo`<00000103oool00`000000oooo0?ooo`0B0?ooo`00
403oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00P0oooo0P00001R0?ooo`030000
003oool0oooo0300oooo0`0000070?ooo`030000003oool0oooo0180oooo000?0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo02d0oooo0`00000;0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo02X0oooo0`00000>0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool02@3oool2000005h0oooo00<000000?ooo`3oool09`3oool30000
0140oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0903oool3000001@0
oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool08@3oool3000001L0oooo
00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool07P3oool3000001X0oooo00<0
00000?ooo`3oool04@3oool000h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0:
0?ooo`800000F@3oool00`000000oooo0?ooo`0K0?ooo`<000007@3oool00`000000oooo0?ooo`0A
0?ooo`003P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0H0?ooo`<000008@3oool00`000000oooo0?ooo`0@0?oo
o`003P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0E0?ooo`<00000903oool00`000000oooo0?ooo`0@0?ooo`00
3P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00/0oooo0P00001E0?ooo`030000
003oool0oooo0180oooo0`00000W0?ooo`030000003oool0oooo0100oooo000>0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo00l0oooo0`00000Z0?ooo`030000003oool0oooo0100oooo000>0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo00`0oooo0`00000]0?ooo`030000003oool0oooo0100oooo000>0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
00T0oooo0`00000`0?ooo`030000003oool0oooo0100oooo000=0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0303oool200000540oooo00<000000?ooo`3oool01@3oool3000003<0
oooo00<000000?ooo`3oool0403oool000d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool00P3oool3000003L0oooo
00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`0000000P00000j0?ooo`030000003o
ool0oooo00l0oooo000=0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03@3oool2
000004`0oooo0`00000m0?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`160?ooo`<0000000<0oooo0000
003oool0?@3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0@P3oool3000000@0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0?0?ooo`00303oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo00l0oooo0P00000o0?ooo`<000001`3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00l0oooo000<0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0i0?ooo`<000002P3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo00l0oooo000<0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0e0?ooo`<000003@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo00h0oooo000<0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0a0?ooo`<00000403oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00h0oooo000<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool2000002h0
oooo0`00000C0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03P3oool000`0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02P0oooo
0`00000F0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03P3oool000/0oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02@0oooo0`00
000I0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03P3oool000/0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`8000008@3oool3000001`0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0>0?ooo`002`3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool06`3oool3000001l0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0>0?ooo`002`3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool300000280oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0=0?ooo`002`3oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool04`3oool3000002D0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0=0?ooo`002`3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0180oooo0P00000@0?ooo`<00000:03oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000;0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0:0?ooo`<00000:`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00d0oooo000:0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`060?ooo`<00000;P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
00d0oooo000:0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool04`3oool2000000<0
oooo0`00000b0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool000X0oooo
00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0D0?ooo`<00000=@3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000:0?ooo`030000003oool0oooo05`0oooo00<0
00000?ooo`3oool0403oool3000000030?ooo`000000oooo03D0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0=0?ooo`002P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo00`0oooo0`0000050?ooo`800000=03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00`0oooo000:0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0203oool30000
00X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
00`0oooo00090?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0103oool3000000h0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00`0
oooo00090?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool00`00000B0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0<0?ooo`002@3o
ool00`000000oooo0?ooo`1R0?ooo`8000005P3oool2000002l0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0<0?ooo`002@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00`0oooo00090?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0Z0?ooo`800000@03oool00`000000oooo0?ooo`0<0?ooo`002@3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo01T0oooo0P00000W0?ooo`<000000P3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo00/0oooo00090?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0P0?ooo`@000001P3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00/0oooo00080?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`<000002P3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo00/0oooo00080?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0H0?ooo`<000003P3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo00/0oooo00080?ooo`030000003oool0oooo06<0oooo00<000000?oo
o`3oool07P3oool2000001D0oooo0`00000B0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool02`3oool000P0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00l0oooo0`00000F0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool02`3oool000P0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00X0oooo1000000J0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
2`3oool000P0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0R0?ooo`8000001`3o
ool3000001l0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0:0?ooo`001`3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo02@0oooo00@000000?ooo`3oool0oooo0`00
000R0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool02P3oool000L0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`0U0?ooo`<000009P3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo00X0oooo00070?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool08P3oool3000000030?ooo`000000000002L0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0:0?ooo`001`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01l0
oooo100000060?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0:0?ooo`001`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01`0oooo
0`00000;0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0:0?ooo`001`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01T0oooo0`00
000?0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0:0?ooo`001`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01H0oooo0`00000C
0?ooo`8000009@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00T0oooo00060?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool04`3oool3000001P0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00T0oooo00060?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool03`3oool4000001`0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00T0oooo00060?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool0303oool300000240oooo0P00000T0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool02@3oool000H0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`090?ooo`<000009P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02@3oool000H0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`060?ooo`<00000:P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool02@3oool000H0oooo00<000000?ooo`3oool0I03oool00`00
0000oooo0?ooo`020?ooo`@00000;P3oool200000280oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`090?ooo`001@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool000000080
0000=03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0203oool000D0oooo00<000000?ooo`3oool0I03oool3000003P0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00P0oooo00050?ooo`030000003o
ool0oooo0640oooo0`0000000`3oool000000?ooo`0i0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`080?ooo`001@3oool00`000000oooo0?ooo`1N
0?ooo`<00000103oool00`000000oooo0?ooo`0i0?ooo`8000008@3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00P0oooo00050?ooo`030000003oool0oooo05X0oooo100000070?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00P0oooo00050?ooo`030000003oool0oooo05L0oooo0`00000;0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00P0oooo00050?ooo`030000003oool0oooo05@0oooo0`00000>0?ooo`030000
003oool0oooo03d0oooo0P00000O0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
203oool000@0oooo00<000000?ooo`3oool0DP3oool300000140oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01`3o
ool000@0oooo00<000000?ooo`3oool0C`3oool3000001@0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01`3oool0
00@0oooo00<000000?ooo`3oool0B`3oool4000001L0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool000@0
oooo00<000000?ooo`3oool0B03oool3000001/0oooo00<000000?ooo`3oool0@P3oool2000001d0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`00103oool00`000000oooo
0?ooo`150?ooo`<000007P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`070?ooo`00103oool00`000000oooo0?oo
o`120?ooo`<000008@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`070?ooo`000`3oool00`000000oooo0?ooo`10
0?ooo`<00000903oool00`000000oooo0?ooo`160?ooo`800000703oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00L0oooo00030?ooo`030000003oool0oooo03`0oooo1000000W0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00H0oooo00030?ooo`030000003oool0oooo03T0oooo0`00000[0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo00H0oooo00030?ooo`030000003oool0oooo03H0oooo0`00000]0?ooo`030000
003oool0oooo04/0oooo0P00000J0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
1P3oool000<0oooo00<000000?ooo`3oool0<`3oool300000300oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01P3o
ool000<0oooo00<000000?ooo`3oool0;`3oool4000003<0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool0
0080oooo00<000000?ooo`3oool0;@3oool3000003L0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01P3oool00080
oooo00<000000?ooo`3oool0:P3oool3000003X0oooo00<000000?ooo`3oool0D03oool2000001T0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`000P3oool00`000000oooo
0?ooo`0W0?ooo`<00000?@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`000P3oool00`000000oooo0?oo
o`0T0?ooo`<00000@03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`000P3oool00`000000oooo0?ooo`0P
0?ooo`@00000@`3oool00`000000oooo0?ooo`1D0?ooo`8000005`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo00D0oooo00020?ooo`030000003oool0oooo01d0oooo0`0000170?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00D0oooo00020?ooo`030000003oool0oooo01X0oooo0`00001:0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00D0oooo00000`3oool000000?ooo`0I0?ooo`<00000C@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`050?ooo`0000<0oooo0000003oool05P3oool300000500oooo00<000000?ooo`3oool0F@3o
ool2000001D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`050?ooo`0000<0oooo
0000003oool04P3oool4000005<0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0103oool000030?ooo`000000oooo
00l0oooo0`00001G0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00@0oooo00000`3oool000000?ooo`0<0?ooo`<0
0000FP3oool00`000000oooo0?ooo`1M0?ooo`800000503oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00@0oooo00000`3oool000000?ooo`090?ooo`<00000G@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`040?ooo`0000<000000?ooo`3oool01P3oool300000600oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103o
ool000030000003oool0oooo0080oooo1000001S0?ooo`030000003oool0oooo0640oooo0P00000B
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool000030000003oool00000
00800000I`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`040?ooo`000P00001Z0?ooo`030000003oool0oooo06@0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0
oooo00000`3oool000000000001Y0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00030?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool0IP3oool200000140oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0
oooo06P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00<0oooo00050?ooo`800000I@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001`3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo06X0oooo0P00000?0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool00`3oool000P0oooo0P00001R0?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo
000:0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool000/0oooo0P00001N
0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0080oooo000=0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0L03oool2000000d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?oo
o`003P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0203oool2000000030?ooo`000000oooo0180oooo00<000000?ooo`3oool00P3oool000l0oooo
0P00001J0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool01P3oool2000000040>9j
@0000000oooo00000180oooo00<000000?ooo`3oool00P3oool00140oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`1d0?ooo`8000001P3oool01`000000c9>J0000003RNT0000000?oo
o`0000004@3oool00`000000oooo0?ooo`020?ooo`004P3oool2000005L0oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`020?ooo`8000000P3<TiX200000080oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`020?ooo`00503oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool00P0000040<bCVP80000000<0oooo0000003oool0
3`3oool00`000000oooo0?ooo`020?ooo`005@3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo07P0oooo0`0000000`2fVKX000000<bCVP020<bCVP050000003RNT0000000?ooo`000000
403oool00`000000oooo0?ooo`010?ooo`005P3oool2000005<0oooo00<000000?ooo`3oool0N@3o
ool01@000000]YVj0;JI^P2fVKX0000000<0c9>J00D000000>9j@0000000oooo0000000?0?ooo`03
0000003oool0oooo0040oooo000H0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
N03oool2000000@0]YVj00T000000<bCVP3<TiX0c9>J0000003RNT0000000?ooo`0000003P3oool0
0`000000oooo0?ooo`010?ooo`006@3oool200000500oooo00<000000?ooo`3oool0M`3oool20000
00H0]YVj00@000000<bCVP3<TiX0c9>J0P0000020?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1g0?oo
o`040000002JW]L00000000000D0]YVj0P0000020<bCVP8000000P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0040oooo000L0?ooo`800000C@3oool00`000000oooo0?ooo`1f0?oo
o`030000002JW]L0VYkG0080VYkG00<000000;JI^P2fVKX0102fVKX00`000000c9>J0<bCVP020000
00030?ooo`000000oooo00/0oooo00<000000?ooo`3oool00@3oool001h0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`1e0?ooo`@000000`2JW]L2000000D0]YVj00<000000<bCVP3<
TiX00P0000000`3oool000000?ooo`0:0?ooo`030000003oool0oooo0040oooo000O0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool0M`3oool4000000<0VYkG0P0000040;JI^P040000
003<TiX0c9>J00000080oooo00<000000?ooo`3oool02@3oool100000040oooo0@3oool00200oooo
0P0000190?ooo`030000003oool0oooo07T0oooo1000000309ZNe`030000002fVKX0]YVj0080]YVj
00@000000<bCVP00000000000P3oool00`000000oooo0?ooo`080?ooo`4000000@3oool10?ooo`00
8P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo07/0oooo1000000209ZNe`800000
0`2fVKX010000000c9>J0000000000020?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`40
oooo000S0?ooo`800000AP3oool00`000000oooo0?ooo`1m0?ooo`@000000P2JW]L01P000000]YVj
0;JI^P2fVKX000000<bCVP80000000<0oooo0000003oool0203oool100000040oooo0@3oool002D0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1o0?ooo`@0000000<0VYkG00000000
00000P2fVKX01P000000c9>J000000000000oooo000000P0oooo0@0000010?ooo`40oooo000V0?oo
o`800000@`3oool00`000000oooo0?ooo`210?ooo`@0000000L0VYkG0000002fVKX0]YVj0000003<
TiX000000080oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool002P0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`230?ooo`H0000000@0]YVj0000003<TiX000000P3o
ool00`000000oooo0?ooo`040?ooo`4000000@3oool10?ooo`00:@3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo08H0oooo10000000102fVKX000000000000000020?ooo`030000003o
ool0oooo00@0oooo0@0000010?ooo`00:P3oool2000003l0oooo00<000000?ooo`3oool0R03oool4
000000030;JI^P00000000000080oooo00<000000?ooo`3oool00`3oool100000040oooo000/0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool0RP3oool6000000030?ooo`000000oooo
00@0oooo0@0000010?ooo`00;@3oool2000003`0oooo00<000000?ooo`3oool0S03oool400000080
oooo00<000000?ooo`3oool00P3oool100000040oooo000_0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0SP3oool300000080oooo00D000000?ooo`3oool0oooo000000010?ooo`00
<03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0900oooo0P0000020?ooo`040000
003oool0oooo00000040oooo000a0?ooo`800000=`3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool000000040oooo000c0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0U`3o
ool100000040oooo0@00000003@0oooo0P00000d0?ooo`030000003oool0oooo09L0oooo0@000001
0?ooo`400000000f0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool20000
0000=`3oool200000340oooo00<000000?ooo`3oool0U`3oool300000000>@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo09<0oooo100000030?ooo`00>P3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo08h0oooo1@0000070?ooo`00>`3oool2000002d0oooo00<00000
0?ooo`3oool0RP3oool4000000`0oooo000m0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0Q@3oool500000100oooo000n0?ooo`800000:P3oool00`000000oooo0?ooo`210?ooo`@0
00005@3oool00400oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1l0?ooo`D00000
6@3oool00440oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1h0?ooo`@000007P3o
ool00480oooo0P00000V0?ooo`030000003oool0oooo07<0oooo1@00000R0?ooo`00A03oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo06l0oooo1000000W0?ooo`00A@3oool2000002<0
oooo00<000000?ooo`3oool0JP3oool5000002/0oooo00170?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0IP3oool400000300oooo00180?ooo`800000803oool00`000000oooo0?oo
o`1Q0?ooo`D00000=03oool004X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1M
0?ooo`@00000>@3oool004/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?oo
o`D00000?@3oool004`0oooo0P00000L0?ooo`030000003oool0oooo05@0oooo100000120?ooo`00
CP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04l0oooo1@0000160?ooo`00C`3o
ool2000001T0oooo00<000000?ooo`3oool0B`3oool4000004/0oooo001A0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0A`3oool4000004l0oooo001B0?ooo`8000005P3oool00`00
0000oooo0?ooo`120?ooo`D00000D`3oool005@0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0n0?ooo`@00000F03oool005D0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0i0?ooo`D00000G03oool005H0oooo0P00000A0?ooo`030000003oool0oooo03H0oooo1000
001Q0?ooo`00F03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0340oooo1@00001U
0?ooo`00F@3oool2000000h0oooo00<000000?ooo`3oool0;@3oool4000006X0oooo001K0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0:03oool5000006h0oooo001L0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0903oool4000007<0oooo001M0?ooo`8000002P3o
ool00`000000oooo0?ooo`0O0?ooo`D00000M`3oool005l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0K0?ooo`@00000O03oool00600oooo0P0000070?ooo`030000003oool0oooo
01H0oooo1@0000200?ooo`00HP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180
oooo100000250?ooo`00H`3oool2000000@0oooo00<000000?ooo`3oool03@3oool5000008T0oooo
001U0?ooo`050000003oool0oooo0?ooo`0000002`3oool4000008h0oooo001V0?ooo`040000003o
ool0oooo000000H0oooo1@00002B0?ooo`00I`3oool300000080oooo1000002G0?ooo`00J@3oool3
000009/0oooo0000\
\>"],
  ImageRangeCache->{{{0, 262}, {286.938, 0}} -> {0.0515908, -0.000124373, \
0.00324867, 0.00324867}}]
}, Open  ]],

Cell["\<\
Here the scaling is a fixed length so all arrowcones are the same size.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetOptions[Arrow3D, HeadScaling3D \[Rule] 1, 
        HeadLength3D \[Rule] 0.15];\)\), "\[IndentingNewLine]", 
    \(\(Draw3DItems[\[IndentingNewLine]{Arrow3D[{0, 0, 0}, {1, 1, 
              1}], \[IndentingNewLine]Red, 
          Arrow3D[{0, 0, 0}, {1, 0, 0}], \[IndentingNewLine]Blue, 
          Arrow3D[{0, 0, 0}, {0, 0, 
              1/4}]}, \[IndentingNewLine]PlotRange \[Rule] 
          All];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[Arrow3D, HeadScaling3D \[Rule] Relative, 
        HeadLength3D \[Rule] 0.2];\)\)}], "Input",
  CellLabel->"In[5]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.08638 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0570873 1.16692 3.35561e-017 1.16692 [
[ 0 0 0 0 ]
[ 1 1.08638 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08847 .24539 m
0 .80424 L
s
0 .80424 m
.40076 1.08638 L
s
.40076 1.08638 m
.41833 .58187 L
s
.41833 .58187 m
.08847 .24539 L
s
.6721 0 m
.92714 .41536 L
s
.92714 .41536 m
1 .94911 L
s
1 .94911 m
.70598 .5861 L
s
.70598 .5861 m
.6721 0 L
s
.08847 .24539 m
0 .80424 L
s
0 .80424 m
.70598 .5861 L
s
.70598 .5861 m
.6721 0 L
s
.6721 0 m
.08847 .24539 L
s
.41833 .58187 m
.92714 .41536 L
s
.92714 .41536 m
1 .94911 L
s
1 .94911 m
.40076 1.08638 L
s
.40076 1.08638 m
.41833 .58187 L
s
0 0 m
1 0 L
1 1.08638 L
0 1.08638 L
closepath
clip
newpath
.5 Mabswid
.792 .456 .42 r
.12121 .39681 m .13095 .34316 L .11752 .33909 L closepath p F P
0 g
s
.588 .261 .383 r
.12121 .39681 m .1443 .34145 L .13095 .34316 L closepath p F P
0 g
s
.13691 .2838 m
.18993 .32467 L
s
.042 0 .114 r
.12121 .39681 m .15257 .33459 L .1443 .34145 L closepath p F P
0 g
s
.942 .595 .334 r
.12121 .39681 m .11752 .33909 L .10905 .33074 L closepath p F P
0 g
s
.971 .914 .577 r
.12121 .39681 m .15257 .32513 L .15257 .33459 L closepath p F P
0 g
s
0 0 .261 r
.12121 .39681 m .10905 .33074 L .10884 .32123 L closepath p F P
0 g
s
.914 .725 .633 r
.12121 .39681 m .1442 .31665 L .15257 .32513 L closepath p F P
0 g
s
.398 .263 .578 r
.12121 .39681 m .10884 .32123 L .11706 .31423 L closepath p F P
0 g
s
.793 .585 .619 r
.12121 .39681 m .13061 .31246 L .1442 .31665 L closepath p F P
0 g
s
0 0 1 r
.13283 .31315 m
.13691 .2838 L
s
.656 .46 .607 r
.12121 .39681 m .11706 .31423 L .13061 .31246 L closepath p F P
0 g
s
.699 .445 .535 r
.97657 .93102 m .89437 .87514 L .88712 .88519 L closepath p F P
0 g
s
.631 .484 .664 r
.97657 .93102 m .90331 .86361 L .89437 .87514 L closepath p F P
0 g
s
.51 .477 .756 r
.97657 .93102 m .91062 .8549 L .90331 .86361 L closepath p F P
0 g
s
.712 .256 .167 r
.97657 .93102 m .88712 .88519 L .88431 .88998 L closepath p F P
0 g
s
.053 .299 .787 r
.97657 .93102 m .91353 .85231 L .91062 .8549 L closepath p F P
0 g
s
.187 .562 .935 r
.97657 .93102 m .88431 .88998 L .88707 .8876 L closepath p F P
0 g
s
.883 .478 .249 r
.97657 .93102 m .91085 .85694 L .91353 .85231 L closepath p F P
0 g
s
.604 .621 .842 r
.97657 .93102 m .88707 .8876 L .89442 .87885 L closepath p F P
0 g
s
.18993 .32467 m
.97567 .93033 L
s
.797 .577 .602 r
.97657 .93102 m .90354 .8671 L .91085 .85694 L closepath p F P
0 g
s
.713 .599 .728 r
.97657 .93102 m .89442 .87885 L .90354 .8671 L closepath p F P
0 g
s
.546 .47 .721 r
.67629 .06359 m .59401 .09592 L .59822 .11007 L closepath p F P
0 g
s
.592 .621 .849 r
.67629 .06359 m .58742 .08317 L .59401 .09592 L closepath p F P
0 g
s
.392 .185 .476 r
.67629 .06359 m .59822 .11007 L .59851 .12034 L closepath p F P
0 g
s
.567 .779 .978 r
.67629 .06359 m .58093 .07662 L .58742 .08317 L closepath p F P
0 g
s
.445 .832 .606 r
.67629 .06359 m .59851 .12034 L .5947 .12284 L closepath p F P
0 g
s
.115 0 0 r
.67629 .06359 m .577 .07886 L .58093 .07662 L closepath p F P
0 g
s
.754 .849 .922 r
.67629 .06359 m .5947 .12284 L .5882 .11647 L closepath p F P
0 g
s
.593 .334 .493 r
.67629 .06359 m .5772 .08917 L .577 .07886 L closepath p F P
0 g
s
.71 .678 .817 r
.67629 .06359 m .5882 .11647 L .5815 .10358 L closepath p F P
0 g
s
.667 .543 .703 r
.67629 .06359 m .5815 .10358 L .5772 .08917 L closepath p F P
0 g
s
1 0 0 r
.13691 .2838 m
.58115 .10243 L
s
0 g
.25 Mabswid
.6721 0 m
.92714 .41536 L
s
.92714 .41536 m
1 .94911 L
s
1 .94911 m
.70598 .5861 L
s
.70598 .5861 m
.6721 0 L
s
.08847 .24539 m
0 .80424 L
s
0 .80424 m
.70598 .5861 L
s
.70598 .5861 m
.6721 0 L
s
.6721 0 m
.08847 .24539 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{265.063, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004900017b000`400?l00000o`00003o/03oool2
000005L0oooo002^0?ooo`80000000<0oooo000000000000EP3oool00:/0oooo0`0000030?ooo`80
0000EP3oool00:T0oooo0P0000060?ooo`030000003oool0000005D0oooo002W0?ooo`800000203o
ool00`000000oooo0000001E0?ooo`00Y03oool3000000X0oooo00@000000?ooo`3oool00000E03o
ool00:80oooo0P00000=0?ooo`050000003oool0oooo0?ooo`000000D`3oool009l0oooo0`00000?
0?ooo`050000003oool0oooo0?ooo`000000D`3oool009d0oooo0P00000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0D03oool009/0oooo0P00000E0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0C`3oool009P0oooo0`00000G0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0C`3oool009H0oooo0P00000J0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0CP3oool009<0oooo0`00000L0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0CP3oool00940oooo0P00000O0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0C@3oool008l0oooo0P00000Q0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0C03oool008`0oooo0`00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0C03oool008X0oooo0P00000S0?ooo`@00000203oool00`000000oooo0?ooo`1;0?ooo`00Q`3o
ool3000001l0oooo2P0000080?ooo`030000003oool0oooo04/0oooo00250?ooo`8000006`3oool?
000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool0BP3oool008<0oooo0P00000G0?oo
o`H00000102GEGh300000080ZX^c100000030?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0B@3oool00800oooo0`00000E0?ooo`@000001P2GEGh400000080ZX^c1P0000040?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0B@3oool007h0oooo0P00000H0?ooo`030000
002GEGh0UeEn00<0UeEn100000040:Z;/`80000000<0]JgA0000000000000P0000050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0B03oool007/0oooo0`00000J0?ooo`030000002G
EGh0000000<000001P2ZRk<200000080]JgA00<000000<7Ik00000001`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo04L0oooo001i0?ooo`8000007@3oool2000000L0ZX^c0`000002
0;F]d@80000000<0`MW/0000003oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo04L0oooo001g0?ooo`8000007`3oool00`000000ZX^c0:Z;/`040:Z;/`800000102e[M401000
0000`MW/0000000000090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0AP3oool0
07@0oooo0`00000Q0?ooo`030000002ZRk<0ZX^c0080ZX^c0P0000040;F]d@80000000<0`MW/0000
003oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04H0oooo001b0?ooo`80
00009@3oool010000000ZX^c0000000000040;F]d@8000000P31fN`00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0A@3oool006l0oooo0`00000V0?ooo`80
o`0000<000000;F]d@2e[M400`2e[M400`000000`MW/0<7Ik002000000h0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`140?ooo`00K@3oool2000002L0oooo0P3o00020?ooo`040000
002e[M40]JgA0;F]d@8000000P31fN`00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0A03oool006/0oooo0P00000V0?ooo`<0o`00103oool010000000]JgA
0000000000030<7Ik0030000003oool0oooo00l0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`130?ooo`00J03oool3000002H0oooo0P3o00080?ooo`0400000031fN`0`MW/0<7Ik080
00004P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04<0oooo001V0?ooo`800000
9`3oool20?l000/0oooo00<000000<7Ik0000000503oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0480oooo001S0?ooo`<000009P3oool30?l000h0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo001Q0?ooo`8000009`3oool2
0?l002L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`110?ooo`00GP3oool30000
02H0oooo0`3o000Y0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0@03oool005`0
oooo0P00000W0?ooo`80o`00;03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03l0
oooo001J0?ooo`8000009P3oool30?l002h0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0o0?ooo`00E`3oool3000002H0oooo0P3o000a0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0?P3oool005D0oooo0P00000V0?ooo`<0o`00<`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo03h0oooo001B0?ooo`<000009P3oool20?l003H0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0m0?ooo`00D03oool2000002L0oooo0P3o000h0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0?03oool004h0oooo0P00000V0?ooo`<0o`00
>P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03`0oooo001;0?ooo`<000009P3o
ool20?l003d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0k0?ooo`00B@3oool2
000002H0oooo0`3o00100?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0>`3oool0
04H0oooo0`00000V0?ooo`80o`00@`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
03X0oooo00140?ooo`8000009P3oool30?l004D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0i0?ooo`00@P3oool2000002H0oooo0P3o00180?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0>@3oool003l0oooo0`00000V0?ooo`80o`00BP3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo03P0oooo000m0?ooo`8000009P3oool30?l004`0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0g0?ooo`00>P3oool3000002H0oooo0P3o001?0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0=`3oool003P0oooo0P00000V0?ooo`<0
o`00D@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03H0oooo000f0?ooo`800000
9P3oool20?l005@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0f0?ooo`00<`3o
ool3000002D0oooo0`3o001F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0=@3o
ool00340oooo0P00000V0?ooo`80o`00F@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo03@0oooo000^0?ooo`<000009@3oool30?l005/0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0d0?ooo`00;03oool2000002H0oooo0P3o001N0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0<`3oool002X0oooo0P00000V0?ooo`80o`00H03oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo03<0oooo000W0?ooo`<000009@3oool30?l00680oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0b0?ooo`009@3oool2000002H0oooo0P3o001U
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0<@3oool00280oooo0`00000U0?oo
o`<0o`00I`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0340oooo000P0?ooo`80
00009P3oool20?l006/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0`0?ooo`00
7P3oool2000002D0oooo0`3o001]0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
<03oool001/0oooo0`00000U0?ooo`80o`00L03oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo02l0oooo000I0?ooo`8000009P3oool20?l00780oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0^0?ooo`005`3oool2000002D0oooo0`3o001d0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0;P3oool001L0oooo0P00000S0?ooo`80o`00M`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo02d0oooo000G0?ooo`030000003oool0000001l0oooo
0`3o001i0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0;03oool001L0oooo00@0
00000?ooo`3oool00000703oool20?l007`0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0/0?ooo`005P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo0`3o
001n0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:`3oool001H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`80o`00P@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo02/0oooo000F0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03`3oool30?l008<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Z0?oo
o`005P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo0P3o00260?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0:@3oool001H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`090?ooo`80o`00R03oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo02T0oooo000F0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool30?l008X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0X0?ooo`005@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0P3o002=0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0:03oool001D0oooo00<000000?ooo`3oool02P3oool01000
0000oooo0?l0003o002?0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool0
01D0oooo00<000000?ooo`3oool02`3oool010000000003o00000000002>0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool09P3oool001D0oooo00<000000?ooo`3oool0303oool01000
0?l0oooo0?ooo`00002=0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool09P3oool0
01D0oooo00<000000?ooo`3oool0303oool01@000?l000000?ooo`3oool0000008d0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0U0?ooo`005@3oool00`000000oooo0?ooo`0;0?oo
o`040000o`3oool0oooo00000080oooo0P00002;0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0903oool001D0oooo00<000000?ooo`3oool02`3oool01@000?l0oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo02@0oooo000D0?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool2000008P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0S
0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`80000000<0003o0?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0S0?ooo`00503oool00`000000oooo0?ooo`070?ooo`<0000000<0YgFK0000003;
UIh00`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0Q03oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0280oooo000D0?ooo`030000003oool0oooo00D0oooo
0`0000030:MeV`040000003;UIh0biFN0<^EWP8000000`3oool00`000000oooo0?ooo`020?ooo`80
0000Q03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0240oooo000D0?ooo`030000
003oool0oooo00D0oooo00<0000006E3T`0000000`2WMI/010000000biFN0<^EWP0000020>ViXP05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool08@3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000
ID>C000000030:MeV`040000003;UIh0biFN00000080jKVR00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0P0?ooo`004`3oool00`000000oooo0?ooo`060?ooo`<000000`2WMI/01@000000
biFN0<^EWP000000jKVR00800000103oool00`000000oooo0?ooo`040?ooo`800000P03oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo0200oooo000C0?ooo`030000003oool0oooo00H0
oooo0`0000020:MeV`060000003;UIh0biFN0<^EWP000000jKVR0P0000050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo01l0oooo000C0?ooo`030000003oool0oooo00H0oooo0P000000101U@i<000000:MeV`000002
0<^EWP040000003Y^J800000000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool07P3oool001<0oooo00<00000
0?ooo`3oool01`3oool01@000000ID>C0000002WMI/000000080biFN00@000000>ViXP0000000000
203oool00`000000oooo0?ooo`050?ooo`800000O03oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo01h0oooo000C0?ooo`030000003oool0oooo00L0oooo00D0000006E3T`000000YgFK
000000020<^EWP<000002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`004`3oool00`000000oooo0?oo
o`070?ooo`<0000000D0YgFK0000003;UIh000000>ViXP02000000/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
703oool00180oooo00<000000?ooo`3oool0203oool3000000060:MeV`000000biFN0000003Y^J80
00003@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0L0?ooo`004P3oool00`000000oooo0?ooo`090?ooo`800000
00<0YgFK0000003;UIh00`00000>0?ooo`030000003oool0oooo00H0oooo0P00001g0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool06`3oool00180oooo00<000000?ooo`3oool02@3o
ool2000000030:MeV`000000biFN00800000403oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0K0?ooo`004P3oool0
0`000000oooo0?ooo`090?ooo`80000000<0YgFK0000000000000P00000A0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo01X0oooo000B0?ooo`030000003oool0oooo00T0oooo0P000000102WMI/0000000000000000C
0?ooo`030000003oool0oooo00L0oooo0P00001d0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool06@3oool00180oooo00<000000?ooo`3oool02P3oool00`000000YgFK000000020000
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool06@3oool00180oooo00<000000?ooo`3oool02P3oool4000001H0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0603oool00140oooo00<000000?ooo`3oool02`3oool4000001L0oooo
00<000000?ooo`3oool0203oool200000700oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0H0?ooo`004@3oool00`000000oooo0?ooo`0;0?ooo`<000006@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0G0?ooo`004@3oool00`000000oooo0?ooo`0<0?ooo`8000006P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0F
0?ooo`004@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool05P3oool00140oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00T0oooo0P00001[0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool05@3oool00140oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0D0?ooo`00403o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01@0oooo000@0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool02P3oool2000006L0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`0C0?ooo`00403oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
01<0oooo000@0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo03T0oooo0P00000D0?ooo`00403oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`0f0?ooo`<0000000<0oooo0000003oool04`3oool00100oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0;0?ooo`800000HP3oool00`000000oooo0?ooo`0c0?ooo`<00000103o
ool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0_0?ooo`<000001`3oool0
0`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0/0?ooo`<000002`3oool00`00
0000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0
oooo0P00001O0?ooo`030000003oool0oooo02T0oooo0`00000>0?ooo`030000003oool0oooo0140
oooo000?0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo02H0oooo0`00000A0?ooo`030000003oool0oooo0140oooo
000?0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo02<0oooo0`00000D0?ooo`030000003oool0oooo0140oooo000?
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool03@3oool2000005/0oooo00<00000
0?ooo`3oool0803oool3000001L0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool07@3oool3000001X0oooo00<000000?ooo`3oool04@3oool000h0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool06P3oool3000001d0oooo00<000000?ooo`3oool04@3oool000h0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool400000240oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0>0?ooo`800000EP3oool00`000000oooo0?ooo`0C0?ooo`<000009@3o
ool00`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0@0?ooo`<00000:03oool0
0`000000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0=0?ooo`<00000:`3oool00`00
0000oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00l0
oooo0P00001B0?ooo`030000003oool0oooo00X0oooo0`00000^0?ooo`030000003oool0oooo0100
oooo000>0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00L0oooo0`00000a0?ooo`030000003oool0oooo0100oooo
000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo00@0oooo0`00000d0?ooo`030000003oool0oooo0100oooo000=
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1=
0?ooo`040000003oool0oooo0?ooo`<00000>03oool00`000000oooo0?ooo`0?0?ooo`003@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo0100oooo0P00001=0?ooo`@00000>`3oool0
0`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0B03oool4000003d0oooo00<000000?ooo`3oool03`3oool000d0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04@0
oooo0`0000030?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03`3oool000d0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0B0?ooo`800000@@3oool3000000H0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0?0?ooo`00303oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>`3oool3000000T0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0?0?ooo`00303oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0=`3oool3000000`0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0?0?ooo`00303oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo01<0oooo0P00000d0?ooo`<000003`3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo00h0oooo000<0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0^0?ooo`<000004P3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00h0oooo000<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0Z0?ooo`<000005@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00h0oooo000<0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0V0?ooo`<00000603oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo00h0oooo000;0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0503oool2
000002<0oooo0`00000K0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03P3oool0
00/0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01d0oooo0`00000N0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03P3oool000/0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01T0
oooo0`00000Q0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03P3oool000/0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0E0?ooo`8000005P3oool3000002@0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`002`3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool4000002L0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`002`3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool3000002/0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`002`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool01`3oool3000002h0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`002P3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo01H0oooo0P0000040?ooo`<00000<@3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo00d0oooo000:0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
5`3oool4000003D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`002P3o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01@0oooo1000000g0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool03@3oool000X0oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`0@0?ooo`<00000103oool2000003D0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0<0?ooo`002P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo
00`0oooo0`0000090?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0<0?ooo`002P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00P0
oooo0`00000=0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0<0?ooo`002@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00@0oooo
0`00000A0?ooo`800000<@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00`0oooo
00090?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool00`00000F0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0<0?ooo`002@3oool0
0`000000oooo0?ooo`1R0?ooo`8000006P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool0303oool000T0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo02/0oooo0P00000o0?ooo`030000003oool0oooo
00`0oooo00090?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool06`3oool2000002P0
oooo0`0000020?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool02`3oool000T0oooo
00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo
100000060?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool02`3oool000T0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo0`00
000:0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool02`3oool000P0oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`0O0?ooo`8000006P3oool3000000h0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0;0?ooo`00203oool00`000000oooo0?ooo`1S0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0503oool300000180oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0;0?ooo`00203oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0403oool3000001H0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0;0?ooo`00203oool00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool4000001X0oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0;0?ooo`00203oool00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo02@0oooo0P0000080?ooo`<000007P3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo00X0oooo00080?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`020?ooo`<000008P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo00X0oooo00070?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool09`3oool40000
02H0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0:0?ooo`001`3oool00`000000
oooo0?ooo`1T0?ooo`030000003oool0oooo02D0oooo1@00000X0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool02P3oool000L0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`0Q0?ooo`@000001@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool02P3oool000L0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`0O0?ooo`<000002P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02P3oool000L0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0L
0?ooo`<000003P3oool2000002H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0:
0?ooo`001`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01T0oooo0`00000C0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`090?oo
o`001`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01H0oooo0`00000G0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`090?ooo`00
1P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0180oooo1000000K0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`090?ooo`001P3o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00l0oooo0`00000P0?ooo`8000009@3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00T0oooo00060?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool0303oool3000002D0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00T0oooo00060?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool02@3oool3000002T0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo00T0oooo00060?ooo`030000003oool0oooo06@0
oooo00<000000?ooo`3oool01P3oool3000002d0oooo0P00000S0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool02@3oool000H0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`020?ooo`@00000<P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0203oool000D0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0000
0002000003L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00P0oooo00050?ooo`030000003oool0oooo06@0oooo0`00000k0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`080?ooo`001@3oool00`00
0000oooo0?ooo`1Q0?ooo`<0000000<0oooo0000003oool0?03oool200000240oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`080?ooo`001@3oool00`000000oooo0?ooo`1N0?ooo`<0
0000103oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`080?ooo`001@3oool00`000000oooo0?ooo`1J0?ooo`@00000
1`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`080?ooo`001@3oool00`000000oooo0?ooo`1G0?ooo`<000002`3o
ool00`000000oooo0?ooo`0o0?ooo`800000803oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00P0oooo00050?ooo`030000003oool0oooo05@0oooo0`00000>0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00P0oooo00040?ooo`030000003oool0oooo0580oooo0`00000A0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00L0oooo00040?ooo`030000003oool0oooo04h0oooo1000000D0?ooo`030000003oool0oooo04<0
oooo0P00000N0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool000@0oooo
00<000000?ooo`3oool0B`3oool3000001P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool01`3oool000@0oooo00<0
00000?ooo`3oool0B03oool3000001/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool01`3oool000@0oooo00<00000
0?ooo`3oool0A@3oool3000001h0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01`3oool000@0oooo00<000000?oo
o`3oool0@P3oool300000240oooo00<000000?ooo`3oool0B03oool2000001`0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`070?ooo`000`3oool00`000000oooo0?ooo`0o0?ooo`@0
0000903oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`070?ooo`000`3oool00`000000oooo0?ooo`0l0?ooo`<00000
:03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`060?ooo`000`3oool00`000000oooo0?ooo`0i0?ooo`<00000:`3o
ool00`000000oooo0?ooo`1<0?ooo`8000006`3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00H0oooo00030?ooo`030000003oool0oooo03H0oooo0`00000]0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00H0oooo00030?ooo`030000003oool0oooo03<0oooo0`00000`0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00H0oooo00030?ooo`030000003oool0oooo02l0oooo1000000c0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00H0
oooo00020?ooo`030000003oool0oooo02d0oooo0`00000g0?ooo`030000003oool0oooo0580oooo
0P00000I0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00080oooo00<0
00000?ooo`3oool0:P3oool3000003X0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01P3oool00080oooo00<00000
0?ooo`3oool09`3oool3000003d0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01@3oool00080oooo00<000000?oo
o`3oool0903oool300000400oooo00<000000?ooo`3oool0EP3oool2000001P0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`050?ooo`000P3oool00`000000oooo0?ooo`0P0?ooo`@0
0000@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`050?ooo`000P3oool00`000000oooo0?ooo`0M0?ooo`<00000
A`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`050?ooo`000P3oool00`000000oooo0?ooo`0J0?ooo`<00000BP3o
ool00`000000oooo0?ooo`1J0?ooo`8000005P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00D0oooo00000`3oool000000?ooo`0I0?ooo`<00000C@3oool00`000000oooo0?ooo`1L
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`05
0?ooo`0000<0oooo0000003oool05P3oool300000500oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01@3oool00003
0?ooo`000000oooo0180oooo1000001C0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00@0oooo00000`3oool00000
0?ooo`0?0?ooo`<00000E`3oool00`000000oooo0?ooo`1O0?ooo`800000503oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00000`3oool000000?ooo`0<0?ooo`<00000FP3o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`040?ooo`0000<0oooo0000003oool02@3oool3000005d0oooo00<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0103oool000030000003oool0oooo00H0oooo0`00001P0?ooo`030000003oool0oooo
06<0oooo0P00000C0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00003
0000003oool0oooo0080oooo1000001S0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00000`000000oooo
00000002000006L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0103oool000800000JP3oool00`000000oooo0?oo
o`1W0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`030?ooo`0000<0oooo000000000000J@3oool00`000000oooo0?ooo`1X0?ooo`8000004@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00030?ooo`030000003oool0oooo
06H0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`1[0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`030?ooo`001@3oool2000006D0oooo00<000000?ooo`3oool0K03oool2000000l0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`001`3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00<0oooo00080?ooo`800000HP3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`03
0?ooo`002P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0700oooo0P00000>0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool000/0oooo0P00001N0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0080oooo000=0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
0P3oool000h0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`003`3oool2
000005X0oooo00<000000?ooo`3oool0MP3oool2000000`0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
07P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0080oooo000B0?ooo`800000E`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00H0
oooo0P0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool001@0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1j0?ooo`8000001@3oool2000000040>9j
?`000000oooo00000100oooo00<000000?ooo`3oool00@3oool001D0oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0080oooo00L000000<bCVP000000
hWXo0000003oool0000000l0oooo00<000000?ooo`3oool00@3oool001H0oooo0P00001C0?ooo`03
0000003oool0oooo07d0oooo00<000000?ooo`3oool00P0000020<bCVP8000000P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool0OP3oool3000000@0c9>J0P0000020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00@3oool001T0oooo0P00001@0?ooo`030000003oool0oooo07l0oooo00<0
00000;JI^P000000103<TiX200000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`010?ooo`006`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo07h0oooo0P000002
0;JI^P070000003<TiX0c9>J0<bCVP000000hWXo000000020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00@3oool001`0oooo0P00001=0?ooo`030000003oool0oooo07d0oooo0P00
00040;JI^P8000000P3<TiX01@000000hWXo0000003oool0000000/0oooo00<000000?ooo`3oool0
0@3oool001h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1l0?ooo`80000000<0
VYkG000000000000102fVKX00`000000c9>J0<bCVP0200000080oooo00<000000?ooo`3oool02@3o
ool100000040oooo0@3oool001l0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1k
0?ooo`<000000`2JW]L2000000<0]YVj00<000000<bCVP3<TiX00P0000020?ooo`030000003oool0
oooo00P0oooo0@0000010?ooo`40oooo000P0?ooo`800000B@3oool00`000000oooo0?ooo`1k0?oo
o`80000000<0;ho_0000000000000`2JW]L01@000000]YVj0;JI^P2fVKX000000080c9>J0P000002
0?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`40oooo000R0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0O@3oool20000000302n?k`00000000000080VYkG0P0000020;JI
^P030000003<TiX0c9>J008000000P3oool00`000000oooo0?ooo`060?ooo`4000000@3oool10?oo
o`008`3oool2000004H0oooo00<000000?ooo`3oool0O`3oool20000000302n?k`00000000000080
VYkG00<000000;JI^P2fVKX00P0000001@3<TiX000000000003oool0000000P0oooo0@0000010?oo
o`40oooo000U0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0P@3oool500000003
09ZNe`00000000000080]YVj00<000000<bCVP0000000P3oool00`000000oooo0?ooo`050?ooo`40
00000@3oool10?ooo`009P3oool2000004<0oooo00<000000?ooo`3oool0Q03oool40000000709ZN
e`00000000000;JI^P000000c9>J000000020?ooo`030000003oool0oooo00@0oooo0@0000010?oo
o`40oooo000X0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0QP3oool400000006
09ZNe`000000]YVj0000003<TiX000000P3oool00`000000oooo0?ooo`040?ooo`4000000@3oool0
02T0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`290?ooo`P000000P3oool00`00
0000oooo0?ooo`030?ooo`4000000@3oool002X0oooo0P00000o0?ooo`030000003oool0oooo08/0
oooo1`0000000`3oool000000?ooo`040?ooo`4000000@3oool002`0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`2=0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`400000
0@3oool002d0oooo0P00000l0?ooo`030000003oool0oooo0900oooo0`0000020?ooo`050000003o
ool0oooo0?ooo`0000000@3oool002l0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`2B0?ooo`8000000P3oool010000000oooo0?ooo`0000010?ooo`00<03oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`0000000@3oool00340oooo0P00000g
0?ooo`030000003oool0oooo09T0oooo0@0000010?ooo`400000000c0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0V@3oool100000040oooo0@00000003@0oooo0P00000d0?ooo`03
0000003oool0oooo09X0oooo0P00000003H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`2I0?ooo`<00000000g0?ooo`800000<@3oool00`000000oooo0?ooo`2E0?ooo`@000000`3o
ool003T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`D000001`3oool0
03X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2<0?ooo`@00000303oool003/0
oooo0P00000]0?ooo`030000003oool0oooo08P0oooo1000000@0?ooo`00?@3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo08<0oooo1@00000D0?ooo`00?P3oool2000002X0oooo00<0
00000?ooo`3oool0O`3oool4000001T0oooo00100?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0NP3oool5000001d0oooo00110?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0MP3oool400000280oooo00120?ooo`8000009P3oool00`000000oooo0?ooo`1b0?ooo`@0
00009P3oool004@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`D00000
:P3oool004D0oooo0P00000S0?ooo`030000003oool0oooo06T0oooo1000000_0?ooo`00A`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06@0oooo1@00000c0?ooo`00B03oool20000
0200oooo00<000000?ooo`3oool0H03oool4000003P0oooo001:0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0F`3oool5000003`0oooo001;0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0E`3oool400000440oooo001<0?ooo`800000703oool00`000000oooo0?oo
o`1C0?ooo`@00000A@3oool004h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1>
0?ooo`D00000B@3oool004l0oooo0P00000I0?ooo`030000003oool0oooo04X0oooo1000001>0?oo
o`00D@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1@00001B0?ooo`00
DP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000005L0oooo001D0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0?@3oool4000005/0oooo001E0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0>03oool5000005l0oooo001F0?ooo`8000004@3oool00`00
0000oooo0?ooo`0e0?ooo`@00000I03oool005P0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0`0?ooo`D00000J03oool005T0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo
1000001]0?ooo`00F`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02L0oooo1@00
001a0?ooo`00G03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo1000001f
0?ooo`00G@3oool2000000X0oooo00<000000?ooo`3oool07`3oool4000007X0oooo001O0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool5000007h0oooo001P0?ooo`800000
1`3oool00`000000oooo0?ooo`0F0?ooo`@00000P`3oool00680oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0A0?ooo`D00000Q`3oool006<0oooo0P0000040?ooo`030000003oool0
oooo00d0oooo1000002<0?ooo`00I@3oool01@000000oooo0?ooo`3oool0000000/0oooo1000002@
0?ooo`00IP3oool010000000oooo0?ooo`0000060?ooo`D00000U03oool006L0oooo0`0000020?oo
o`@00000V@3oool006T0oooo0`00002M0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 264.063}, {286.938, 0}} -> {0.0489171, -0.000110584, \
0.00324531, 0.00324531}}]
}, Open  ]],

Cell["\<\
Here is a set of random arrows from the origin with flat arrowheads.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetOptions[Arrow3D, HeadScaling3D \[Rule] 3, 
        HeadLength3D \[Rule] 0.20, 
        HeadSegments3D \[Rule] 2];\)\), "\[IndentingNewLine]", 
    \(\(Draw3DItems[\[IndentingNewLine]{Table[
            Arrow3D[{0, 0, 0}, {Random[Real, {\(-3\), 3}], 
                Random[Real, {\(-3\), 3}], 
                Random[Real, {\(-3\), 
                    3}]}], {20}]}, \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]ImageSize \[Rule] 
          400, \[IndentingNewLine]Boxed \[Rule] 
          False];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[Arrow3D, HeadScaling3D \[Rule] Relative, 
        HeadLength3D \[Rule] 0.1, HeadSegments3D \[Rule] 10];\)\)}], "Input",
  CellLabel->"In[8]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11727 
%%ImageSize: 400 446.907 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0699712 1.19537 5.51317e-017 1.19537 [
[ 0 0 0 0 ]
[ 1 1.11727 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.11727 L
0 1.11727 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.69 .723 .875 r
.46399 .88012 m .46049 .83798 L .49206 .84146 L closepath p F P
0 g
s
.69 .723 .875 r
.46399 .88012 m .49206 .84146 L .46049 .83798 L closepath p F P
0 g
s
.715 .693 .828 r
.48062 .86231 m .47779 .80831 L .51065 .81229 L closepath p F P
0 g
s
.46406 .87987 m
.47898 .83091 L
s
.715 .693 .828 r
.48062 .86231 m .51065 .81229 L .47779 .80831 L closepath p F P
0 g
s
.48557 .80925 m
.54923 .60028 L
s
.48069 .86206 m
.54923 .60028 L
s
.609 .394 .564 r
.26891 .54733 m .31822 .57225 L .3315 .54363 L closepath p F P
0 g
s
.609 .394 .564 r
.26891 .54733 m .3315 .54363 L .31822 .57225 L closepath p F P
0 g
s
.26917 .54738 m
.54923 .60028 L
s
.657 .491 .647 r
.32779 .37637 m .38372 .40855 L .35901 .43232 L closepath p F P
0 g
s
.657 .491 .647 r
.32779 .37637 m .35901 .43232 L .38372 .40855 L closepath p F P
0 g
s
.328 .37658 m
.54923 .60028 L
s
.694 .528 .658 r
.11247 .26017 m .17471 .28716 L .15242 .31281 L closepath p F P
0 g
s
.694 .528 .658 r
.11247 .26017 m .15242 .31281 L .17471 .28716 L closepath p F P
0 g
s
.644 .737 .917 r
.85302 .68155 m .78343 .67409 L .7988 .65576 L closepath p F P
0 g
s
.644 .737 .917 r
.85302 .68155 m .7988 .65576 L .78343 .67409 L closepath p F P
0 g
s
.54923 .60028 m
.85273 .68147 L
s
.58 .631 .867 r
.82498 .77845 m .75845 .74982 L .77687 .73284 L closepath p F P
0 g
s
.58 .631 .867 r
.82498 .77845 m .77687 .73284 L .75845 .74982 L closepath p F P
0 g
s
.54923 .60028 m
.82471 .77827 L
s
.683 .766 .914 r
.3751 .64526 m .44696 .63791 L .43503 .61843 L closepath p F P
0 g
s
.683 .766 .914 r
.3751 .64526 m .43503 .61843 L .44696 .63791 L closepath p F P
0 g
s
.37527 .64521 m
.54923 .60028 L
s
.594 .695 .913 r
.17037 .52192 m .2394 .54689 L .239 .52529 L closepath p F P
0 g
s
.594 .695 .913 r
.17037 .52192 m .239 .52529 L .2394 .54689 L closepath p F P
0 g
s
.11288 .2605 m
.54923 .60028 L
s
.17074 .52199 m
.54923 .60028 L
s
.9 .58 .431 r
.37878 .42359 m .42447 .48421 L .4326 .4663 L closepath p F P
0 g
s
.9 .58 .431 r
.37878 .42359 m .4326 .4663 L .42447 .48421 L closepath p F P
0 g
s
.991 .862 .608 r
.58707 .13095 m .58725 .20579 L .57478 .20505 L closepath p F P
0 g
s
.991 .862 .608 r
.58707 .13095 m .57478 .20505 L .58725 .20579 L closepath p F P
0 g
s
.67 .773 .927 r
.28379 .55659 m .36008 .55788 L .34941 .57852 L closepath p F P
0 g
s
.67 .773 .927 r
.28379 .55659 m .34941 .57852 L .36008 .55788 L closepath p F P
0 g
s
.54 .8 .993 r
.56635 .54687 m .57592 .57499 L .53948 .57265 L closepath p F P
0 g
s
.54923 .60028 m
.55139 .57341 L
s
.54 .8 .993 r
.56635 .54687 m .53948 .57265 L .57592 .57499 L closepath p F P
0 g
s
.54923 .60028 m
.56634 .54693 L
s
.37895 .42377 m
.54923 .60028 L
s
.55246 .5602 m
.58703 .13143 L
s
.28407 .55663 m
.54923 .60028 L
s
.651 .453 .603 r
.81966 .72577 m .76288 .67995 L .74525 .7108 L closepath p F P
0 g
s
.651 .453 .603 r
.81966 .72577 m .74525 .7108 L .76288 .67995 L closepath p F P
0 g
s
.621 .407 .571 r
.849 .66691 m .78502 .63536 L .77269 .66737 L closepath p F P
0 g
s
.621 .407 .571 r
.849 .66691 m .77269 .66737 L .78502 .63536 L closepath p F P
0 g
s
.54923 .60028 m
.84868 .66684 L
s
.54923 .60028 m
.81937 .72564 L
s
.672 .751 .91 r
.75924 .41826 m .69487 .45406 L .72422 .46843 L closepath p F P
0 g
s
.672 .751 .91 r
.75924 .41826 m .72422 .46843 L .69487 .45406 L closepath p F P
0 g
s
.54923 .60028 m
.75901 .41846 L
s
.971 .66 .292 r
.44834 .61852 m .47687 .63373 L .46513 .59513 L closepath p F P
0 g
s
.47455 .62611 m
.54923 .60028 L
s
.971 .66 .292 r
.44834 .61852 m .46513 .59513 L .47687 .63373 L closepath p F P
0 g
s
.44846 .6185 m
.54923 .60028 L
s
.895 .671 .592 r
.23529 .70884 m .29835 .70851 L .28574 .66992 L closepath p F P
0 g
s
.895 .671 .592 r
.23529 .70884 m .28574 .66992 L .29835 .70851 L closepath p F P
0 g
s
.23566 .70872 m
.46728 .62862 L
s
.974 .679 .396 r
.39592 .71207 m .41706 .67182 L .43156 .71087 L closepath p F P
0 g
s
.974 .679 .396 r
.39592 .71207 m .43156 .71087 L .41706 .67182 L closepath p F P
0 g
s
.929 .599 .146 r
.47009 .65565 m .49147 .66559 L .47774 .62538 L closepath p F P
0 g
s
.48513 .64702 m
.54923 .60028 L
s
.929 .599 .146 r
.47009 .65565 m .47774 .62538 L .49147 .66559 L closepath p F P
0 g
s
.47018 .65558 m
.54923 .60028 L
s
.39611 .71193 m
.47204 .65656 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[8]:=",
  ImageSize->{400, 446.875},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00jP3oool00`000000oooo0?ooo`2S0?ooo`00jP3oool00`000000oooo
0?ooo`2S0?ooo`00jP3oool00`000000oooo0?ooo`2S0?ooo`00j@3oool200000:D0oooo003Y0?oo
o`800000Y@3oool00>T0oooo0P00002U0?ooo`00j@3oool200000:D0oooo003Y0?ooo`800000Y@3o
ool00>T0oooo0P00002U0?ooo`00j03oool300000:D0oooo003X0?ooo`<00000Y@3oool00>P0oooo
0`00002U0?ooo`00j03oool300000:D0oooo003X0?ooo`<00000Y@3oool00>P0oooo0`00002U0?oo
o`00i`3oool010000000oMbK00000000002U0?ooo`00i`3oool010000000oMbK00000000002U0?oo
o`00i`3oool010000000oMbK00000000002U0?ooo`00i`3oool010000000oMbK00000000002U0?oo
o`00i`3oool2000000030?gLV`000000oooo0:@0oooo003W0?ooo`80000000<0oMbK0000003oool0
Y03oool00>H0oooo00D000000?gLV`000000oMbK0000002U0?ooo`00iP3oool01@000000oMbK0000
003mg9/000000:D0oooo003V0?ooo`050000003mg9/000000?gLV`000000Y@3oool00>H0oooo00D0
00000?gLV`000000oMbK0000002U0?ooo`00iP3oool01@000000oMbK0000003mg9/000000:D0oooo
003V0?ooo`050000003mg9/000000?gLV`000000Y@3oool00>D0oooo00H000000?gLV`3mg9/00000
0?gLV`00002U0?ooo`00i@3oool01P000000oMbK0?gLV`000000oMbK00000:D0oooo003U0?ooo`@0
000000<0oMbK0000003oool0Y03oool00>P0oooo0`00002U0?ooo`00i`3oool00`000000oooo0?oo
o`2V0?ooo`00i`3oool00`000000oooo0?ooo`2V0?ooo`00i`3oool00`000000oooo0?ooo`2V0?oo
o`00i`3oool00`000000oooo0?ooo`2V0?ooo`00i`3oool00`000000oooo0?ooo`2V0?ooo`00i`3o
ool00`000000oooo0?ooo`2V0?ooo`00i`3oool00`000000oooo0?ooo`2V0?ooo`00i`3oool00`00
0000oooo0?ooo`2V0?ooo`00i`3oool00`000000oooo0?ooo`2V0?ooo`00i`3oool00`000000oooo
0?ooo`2V0?ooo`00i`3oool00`000000oooo0?ooo`2V0?ooo`00i`3oool00`000000oooo0?ooo`2V
0?ooo`00iP3oool00`000000oooo0?ooo`2W0?ooo`00iP3oool00`000000oooo0?ooo`2W0?ooo`00
iP3oool00`000000oooo0?ooo`2W0?ooo`00iP3oool00`000000oooo0?ooo`2W0?ooo`00iP3oool0
0`000000oooo0?ooo`2W0?ooo`00iP3oool00`000000oooo0?ooo`2W0?ooo`00iP3oool00`000000
oooo0?ooo`2W0?ooo`00iP3oool00`000000oooo0?ooo`2W0?ooo`00;03oool200000;P0oooo00<0
00000?ooo`3oool0Y`3oool002d0oooo0`00002f0?ooo`030000003oool0oooo0:L0oooo000^0?oo
o`040000002aQjP0000000000;@0oooo00<000000?ooo`3oool0Y`3oool002h0oooo0`0000000`2a
QjP000000000002b0?ooo`030000003oool0oooo0:L0oooo000_0?ooo`030000002aQjP000000080
/HNX0`00002^0?ooo`030000003oool0oooo0:P0oooo000`0?ooo`030000002aQjP0000000@0/HNX
0P00002/0?ooo`030000003oool0oooo0:P0oooo000a0?ooo`040000002aQjP00000000000@0/HNX
0P00002Z0?ooo`030000003oool0oooo0:P0oooo000a0?ooo`050000002aQjP0/HNX0;67Z0000000
1@2aQjP300000:L0oooo00<000000?ooo`3oool0Z03oool00380oooo00D000000;67Z02aQjP0/HNX
000000070;67Z0800000Y@3oool00`000000oooo0?ooo`2X0?ooo`00<`3oool01@000000/HNX0;67
Z02aQjP0000000P0/HNX0P00002S0?ooo`030000003oool0oooo0:P0oooo000d0?ooo`040000002a
QjP0/HNX0;67Z0800000202aQjP200000:40oooo00<000000?ooo`3oool0Z03oool003@0oooo00<0
00000;67Z02aQjP00`2aQjP00`000000/HNX0;67Z0070;67Z0800000W`3oool00`000000oooo0?oo
o`2X0?ooo`00=@3oool00`000000/HNX0;67Z0030;67Z0030000002aQjP0/HNX00H0/HNX00<00000
0?ooo`3oool0WP3oool00`000000oooo0?ooo`2X0?ooo`00=P3oool00`000000/HNX0;67Z0030;67
Z08000001@2aQjP00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0:P0oooo000g0?ooo`03
0000002aQjP0/HNX00@0/HNX00D000000;67Z02aQjP0/HNX0000002R0?ooo`030000003oool0oooo
0:P0oooo000g0?ooo`030000002aQjP0/HNX00D0/HNX00<000000;67Z0000000X`3oool00`000000
oooo0?ooo`2X0?ooo`00>03oool00`000000/HNX0;67Z0050;67Z0030000003oool0oooo0:80oooo
00<000000?ooo`3oool0Z03oool003T0oooo00<000000;67Z02aQjP0102aQjP300000:40oooo00<0
00000?ooo`3oool0Z@3oool003X0oooo00<000000;67Z02aQjP00P2aQjP01@000000oooo0?ooo`3o
ool000000:00oooo00<000000?ooo`3oool0Z@3oool003X0oooo00D000000;67Z02aQjP0/HNX0000
00050?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0Z@3oool003/0oooo00<00000
0;67Z00000001`3oool2000009d0oooo00<000000?ooo`3oool0Z@3oool003`0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0:T0oooo00180?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool0Z@3oool004T0oooo00<000000?ooo`3oool0
V03oool00`000000oooo0?ooo`2Y0?ooo`00BP3oool2000009P0oooo00<000000?ooo`3oool0Z@3o
ool004`0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`2Y0?ooo`00C@3oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo0:T0oooo001>0?ooo`800000U03oool00`000000
oooo0?ooo`2Y0?ooo`00D03oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0:T0oooo
001A0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0ZP3oool00580oooo0P00002?
0?ooo`030000003oool0oooo0:X0oooo001D0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool0ZP3oool005D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2Z0?ooo`00
EP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0:X0oooo001G0?ooo`800000RP3o
ool00`000000oooo0?ooo`2Z0?ooo`00F@3oool00`000000oooo0?ooo`270?ooo`030000003oool0
oooo0:X0oooo001J0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0ZP3oool005/0
oooo0P0000260?ooo`030000003oool0oooo0:X0oooo001M0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0ZP3oool005h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?oo
o`2Z0?ooo`00G`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0:X0oooo001P0?oo
o`800000P03oool00`000000oooo0?ooo`2[0?ooo`00HP3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0:/0oooo001S0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
Z`3oool006@0oooo0P00001l0?ooo`030000003oool0oooo0:/0oooo001V0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0Z`3oool006L0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`2[0?ooo`00J03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05d0
oooo00<000000?ooo`3oool0Z`3oool006T0oooo0P00000H0?ooo`800000G@3oool00`000000oooo
0?ooo`2[0?ooo`00J`3oool00`000000oooo0?ooo`0E0?ooo`@00000F`3oool00`000000oooo0?oo
o`2[0?ooo`00K03oool00`000000oooo0?ooo`0E0?ooo`80000000<0Z7fU000000000000F@3oool0
0`000000oooo0?ooo`2[0?ooo`00K@3oool2000001D0oooo00<000000:QmY@0000000P2XOJD00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0:/0oooo001_0?ooo`030000003oool0oooo01<0
oooo00<000000:QmY@0000000P2XOJD2000005H0oooo00<000000?ooo`3oool0Z`3oool00700oooo
00<000000?ooo`3oool04`3oool00`000000Z7fU000000030:QmY@800000D`3oool00`000000oooo
0?ooo`2/0?ooo`00L@3oool00`000000oooo0?ooo`0B0?ooo`040000002XOJD0Z7fU000000@0Z7fU
0P00001A0?ooo`030000003oool0oooo0:`0oooo001b0?ooo`8000004`3oool010000000Z7fU0:Qm
Y@0000050:QmY@800000C`3oool00`000000oooo0?ooo`2/0?ooo`00M03oool00`000000oooo0?oo
o`0@0?ooo`050000002XOJD0Z7fU0:QmY@0000001P2XOJD00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo0:`0oooo001e0?ooo`030000003oool0oooo0100oooo00D000000:QmY@2XOJD0Z7fU
000000060:QmY@800000C03oool00`000000oooo0?ooo`2/0?ooo`00MP3oool200000100oooo00<0
00000:QmY@2XOJD00P2XOJD00`000000Z7fU0:QmY@050:QmY@800000BP3oool00`000000oooo0?oo
o`2/0?ooo`00N03oool00`000000oooo0?ooo`0>0?ooo`030000002XOJD0Z7fU0080Z7fU00<00000
0:QmY@2XOJD01P2XOJD2000004P0oooo00<000000?ooo`3oool0[03oool007T0oooo00<000000?oo
o`3oool03P3oool00`000000Z7fU0:QmY@020:QmY@030000002XOJD0Z7fU00L0Z7fU00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`2/0?ooo`00NP3oool00`000000oooo0?ooo`0=0?ooo`03
0000002XOJD0Z7fU00<0Z7fU00<000000:QmY@2XOJD01@2XOJD00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo0:`0oooo001k0?ooo`8000003P3oool00`000000Z7fU0:QmY@030:QmY@030000
002XOJD0Z7fU00<0Z7fU00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2/0?ooo`00O@3o
ool00`000000oooo0?ooo`0;0?ooo`030000002XOJD0Z7fU00@0Z7fU00D000000:QmY@2XOJD0Z7fU
0000001:0?ooo`030000003oool0oooo0:`0oooo001n0?ooo`030000003oool0oooo00/0oooo00<0
00000:QmY@2XOJD0102XOJD00`000000Z7fU0000001;0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool0G`3oool007l0oooo0P00000<0?ooo`030000002XOJD0Z7fU00<0Z7fU0P00001<
0?ooo`030000003oool0oooo04P0oooo0P00001R0?ooo`00P@3oool00`000000oooo0?ooo`090?oo
o`030000002XOJD0Z7fU0080Z7fU00H000000?ooo`3oool000000?ooo`0000180?ooo`030000003o
ool0oooo04L0oooo1000001R0?ooo`00PP3oool00`000000oooo0?ooo`090?ooo`040000002XOJD0
Z7fU000000@0oooo00<000000?ooo`000000A`3oool00`000000oooo0?ooo`150?ooo`D00000H`3o
ool008<0oooo00<000000?ooo`3oool0203oool00`000000Z7fU000000060?ooo`@00000A@3oool0
0`000000oooo0?ooo`130?ooo`80000000@0[<3X0000002/`>P00000I03oool008@0oooo0P000009
0?ooo`030000003oool0oooo00H0oooo100000140?ooo`030000003oool0oooo0480oooo00H00000
0:c0j02/`>P000000:c0j000001U0?ooo`00QP3oool00`000000oooo0?ooo`0@0?ooo`@00000@`3o
ool00`000000oooo0?ooo`100?ooo`8000000P2/`>P010000000[<3X0:c0j000001U0?ooo`00Q`3o
ool00`000000oooo0?ooo`0@0?ooo`@00000@P3oool00`000000oooo0?ooo`0n0?ooo`8000000`2/
`>P010000000[<3X0:c0j000001V0?ooo`00R03oool200000140oooo00<000000>JDKP0000000P00
00100?ooo`030000003oool0oooo03`0oooo0P0000040:c0j0040000002/`>P0[<3X000006L0oooo
002:0?ooo`030000003oool0oooo00l0oooo00D000000>JDKP000000iYA^0000000o0?ooo`030000
003oool0oooo03/0oooo00<000000:c0j02/`>P00`2/`>P01@000000[<3X0:c0j02/`>P0000006L0
oooo002;0?ooo`030000003oool0oooo00l0oooo00D000000>JDKP000000iYA^0000000n0?ooo`03
0000003oool0oooo03T0oooo0P0000040:c0j08000000`2/`>P00`000000oooo0?ooo`1V0?ooo`00
S03oool200000100oooo00D000000>JDKP000000iYA^0000000m0?ooo`030000003oool0oooo03L0
oooo0P0000050:c0j0030000002/`>P0[<3X0080[<3X00<000000?ooo`3oool0I`3oool008h0oooo
00<000000?ooo`3oool03@3oool01P000000iYA^0>JDKP000000iYA^000003`0oooo00<000000?oo
o`3oool0=@3oool2000000H0[<3X00<000000:c0j02/`>P00`2/`>P00`000000oooo0?ooo`1W0?oo
o`00S`3oool00`000000oooo0?ooo`0=0?ooo`050000003VU6h0iYA^0000003VU6h00P00000j0?oo
o`030000003oool0oooo03<0oooo0P0000070:c0j0030000002/`>P0[<3X00<0[<3X00<000000?oo
o`3oool0J03oool00900oooo00<000000?ooo`3oool03@3oool010000000iYA^0>JDKP0000020>JD
KP030000003oool0oooo03H0oooo00<000000?ooo`3oool0<`3oool00`000000[<3X0:c0j0060:c0
j0030000002/`>P0[<3X00<0[<3X00<000000?ooo`3oool0J@3oool00940oooo0P00000>0?ooo`04
0000003VU6h0iYA^00000080iYA^00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0d0?oo
o`8000001@2/`>P00`000000[<3X0:c0j0030:c0j0030000003oool0oooo06X0oooo002C0?ooo`03
0000003oool0oooo00/0oooo00D000000>JDKP3VU6h0iYA^000000020>JDKP030000003oool0oooo
03@0oooo00<000000?ooo`3oool0=P3oool2000000030:c0j0000000000000H0[<3X00<000000?oo
o`3oool0JP3oool009@0oooo00<000000?ooo`3oool02`3oool01@000000iYA^0>JDKP3VU6h00000
0080iYA^0P00000d0?ooo`030000003oool0oooo03P0oooo0P0000060:c0j0030000003oool0oooo
06/0oooo002E0?ooo`800000303oool01@000000iYA^0>JDKP3VU6h0000000<0iYA^00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo008000000`2/`>P00`00
0000oooo0?ooo`1/0?ooo`00U`3oool00`000000oooo0?ooo`0:0?ooo`050000003VU6h0iYA^0>JD
KP0000000`3VU6h00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool00`3oool2000000030:c0j0000000oooo06d0oooo002H0?ooo`030000003oool0oooo00T0
oooo00D000000>JDKP3VU6h0iYA^000000030>JDKP030000003oool0oooo0300oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06d0oooo002I0?ooo`03
0000003oool0oooo00T0oooo00L000000>JDKP3VU6h0iYA^0000003VU6h0000003<0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`1g0?ooo`00VP3oool2000000X0oooo00@000000>JD
KP3VU6h0iYA^0P00000c0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0N03oool0
09`0oooo00<000000?ooo`3oool0203oool00`000000iYA^0>JDKP02000003<0oooo00<000000?oo
o`3oool0<@3oool2000007/0oooo002M0?ooo`030000003oool0oooo00L0oooo00<000000>JDKP3V
U6h00`00000b0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0N`3oool009h0oooo
0P0000080?ooo`8000000P3oool200000340oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`1l0?ooo`00X03oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`800000
;`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo07d0oooo002Q0?ooo`030000003o
ool0oooo00X0oooo0P00000^0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0OP3o
ool00:80oooo00<000000?ooo`3oool02P3oool2000002d0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`1o0?ooo`00X`3oool2000000/0oooo0P00000/0?ooo`030000003oool0oooo
02/0oooo0P0000220?ooo`00Y@3oool00`000000oooo0?ooo`090?ooo`800000:`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo002V0?ooo`030000003oool0oooo00T0oooo
0P00000Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0P`3oool00:L0oooo0P00
000:0?ooo`800000:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo08@0oooo002Y
0?ooo`030000003oool0oooo00P0oooo0P00000X0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0Q@3oool00:X0oooo00<000000?ooo`3oool0203oool2000002L0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`260?ooo`00Z`3oool00`000000oooo0?ooo`080?ooo`80
00009P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo08L0oooo002/0?ooo`800000
2@3oool2000002D0oooo00<000000?ooo`3oool08`3oool2000008X0oooo002^0?ooo`030000003o
ool0oooo00L0oooo0P00000T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0RP3o
ool00:l0oooo00<000000?ooo`3oool01`3oool200000280oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`2;0?ooo`00/03oool2000000P0oooo0P00000Q0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0S03oool00;80oooo00<000000?ooo`3oool01P3oool200000200
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2=0?ooo`00@`3oool>00000680oooo
00<000000?ooo`3oool01P3oool2000001l0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`2>0?ooo`00A@3oool7000000D0V;7Y3`00001D0?ooo`030000003oool0oooo00H0oooo0P00
000N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0S`3oool004P0oooo0P000002
09Raj@D000003P2H/NT00`000000oooo0?ooo`1C0?ooo`8000001`3oool2000001d0oooo00<00000
0?ooo`3oool0703oool200000980oooo001:0?ooo`<00000102H/NT5000000T0V;7Y00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`050?ooo`800000703oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0980oooo001=0?ooo`<000001P2H/NT4000000D0V;7Y00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`050?ooo`8000006`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo09<0oooo001@0?ooo`<000001`2H/NT6000005T0oooo0P0000060?ooo`800000
6P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo09@0oooo001C0?ooo`<000002@2H
/NT5000005L0oooo00<000000?ooo`3oool0103oool2000001T0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`2E0?ooo`00EP3oool2000000L0V;7Y00<000000?ooo`3oool00P3oool5
000005<0oooo00<000000?ooo`3oool0103oool2000001P0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`2F0?ooo`00F03oool3000000@0V;7Y00<000000?ooo`3oool01`3oool50000
04l0oooo00<000000?ooo`3oool0103oool2000001L0oooo00<000000?ooo`3oool05@3oool20000
09T0oooo001K0?ooo`<0000000<0V;7Y0000003oool03@3oool5000000D0oooo3@00000i0?ooo`80
00001@3oool2000001D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2I0?ooo`00
GP3oool2000000/0oooo3@00000;09]TT0030000003oool0oooo03X0oooo00<000000?ooo`3oool0
0`3oool2000001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo09X0oooo001/0?ooo`L000001@2KI905000000H0VfB@00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`030?ooo`8000004`3oool010000000oooo0?ooo`3oool200000100oooo
00<000000?ooo`3oool0V`3oool006h0oooo0P00000309]TT0H00000102KI9040000000309]TT000
0000oooo03h0oooo0P0000040?ooo`8000004P3oool00`000000oooo0?ooo`020000000308[<oP00
0000oooo00d0oooo00<000000?ooo`3oool0W03oool00700oooo0P00000709]TT0D000000`2KI905
000003h0oooo00<000000?ooo`3oool00P3oool200000140oooo00L000000?ooo`000000R/cn0000
002:c?h0000000d0oooo00<000000?ooo`3oool0W@3oool00740oooo7`00000e0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool200000080R/cn00<0000008[<oP000000303o
ool00`000000oooo0?ooo`2N0?ooo`00L`3oool8000001<0ZlG]0P00000f0?ooo`8000000`3oool0
0`000000oooo0?ooo`0>0?ooo`050000002:c?h0R/cn08[<oP0000000P2:c?h00`000000oooo0?oo
o`070?ooo`800000X@3oool007H0oooo100000000`2[aNd0000000000004000000d0ZlG]00<00000
0?ooo`0000001000000c0?ooo`050000003oool0oooo0?ooo`0000003P3oool01@000000R/cn08[<
oP2:c?h0000000<0R/cn00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2Q0?ooo`00N03o
ool5000000@0ZlG]1P0000060:_5k@H000000P3oool5000002l0oooo00D000000?ooo`3oool0oooo
0000000<0?ooo`030000002:c?h0R/cn0080R/cn00<0000008[<oP2:c?h00P2:c?h00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0:80oooo001j0?ooo`80000000@0VfB@0000000000000000
1`2[aNd7000000D0oooo1P0000000`3oool0000000000003000002/0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`030000002:c?h0R/cn00<0R/cn00<0000008[<oP2:c?h00P2:c?h00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0:<0oooo001l0?ooo`80000000<0VfB@000000000000
0P0000090:_5k@030000003oool0000000D000001@3oool5000000030?ooo`000000000000800000
:03oool200000080oooo00<000000?ooo`3oool01P3oool00`000000R/cn08[<oP0308[<oP030000
002:c?h0R/cn00<0R/cn00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2T0?ooo`00OP3o
ool00`000000oooo0?ooo`020?ooo`@000001@2[aNd00`000000oooo0?ooo`050?ooo`H00000103o
ool:000002D0oooo00@000000?ooo`3oool000001P3oool8000000H0R/cn00@000000?ooo`3oool0
0000Y`3oool008L0oooo0`0000000`2[aNd000000?ooo`0=0?ooo`H000000`3oool:00000240oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0000000900000:P0oooo002:0?ooo`800000
503oool6000000<0oooo2@00000M0?ooo`80000000<0oooo0000003oool0203oool00`000000oooo
000000060?ooo`030000003oool0oooo0:P0oooo002V0?ooo`L0000000<0oooo0000000000001`00
000J0?ooo`030000003oool0000000P0oooo0P0000060?ooo`030000003oool0oooo0:T0oooo002]
0?ooo`l000005P3oool00`000000oooo000000070?ooo`8000001@3oool00`000000oooo0?ooo`2Z
0?ooo`00/`3oool>00000180oooo00<000000?ooo`0000001P3oool2000000@0oooo00<000000?oo
o`3oool0Z`3oool00;T0oooo3@00000>0?ooo`<00000103oool2000000@0oooo00<000000?ooo`3o
ool0[03oool00;l0oooo2`00000<0?ooo`8000000`3oool2000000<0oooo00<000000?ooo`3oool0
[@3oool00<H0oooo2@0000080?ooo`8000000P3oool2000000030?ooo`00000000000;00oooo002i
0?ooo`030000003oool0oooo0100oooo200000040?ooo`80000000@0oooo0000000000000000/P3o
ool00;P0oooo0P00000H0?ooo`L0000000@0oooo0000000000000000/`3oool00;L0oooo00@00000
0?RXBP3hZ4X000007@3oool600000;80oooo002g0?ooo`040000003hZ4X0n:Q:000001P0oooo3`00
002^0?ooo`00]P3oool01@000000n:Q:0?RXBP3hZ4X000000180oooo2P000000103oool000000?oo
o`0000030?ooo`T00000Z@3oool00;D0oooo00<000000?RXBP3hZ4X00`3hZ4X00`000000oooo0?oo
o`090?ooo`H0000000<0oooo000000000000100000020?ooo`8000000P3oool00`000000oooo0?oo
o`020?ooo`@000000P3oool600000:D0oooo002d0?ooo`030000003hZ4X0n:Q:00@0n:Q:00<00000
0?ooo`3oool00`3oool6000000<0oooo1`0000040?ooo`8000000`3oool00`000000oooo0?ooo`04
0?ooo`040000003oool00000000000<0oooo1`00002Q0?ooo`00]03oool00`000000n:Q:0?RXBP04
0?RXBPH000001@3oool4000000040?ooo`0000000000000000H0oooo00<000000?ooo`3oool00P3o
ool2000000L0oooo0P0000000`3oool00000000000050?ooo`P00000W03oool00;<0oooo00<00000
0?RXBP0000001P0000060?ooo`@000000P3oool3000000L0oooo0P0000050?ooo`030000003oool0
oooo00P0oooo0P0000000`3oool00000000000070?ooo`<0000000<0oooo0000000000000P00002H
0?ooo`00[03oool2000000@0oooo0`0000070?RXBP030000003oool0000000<000000`3oool30000
00T0oooo0P0000060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`0000070?oo
o`@0000000<0oooo0000000000000`00002C0?ooo`00ZP3oool200000080[/CY00<000000?ooo`3o
ool00P3oool2000000L0n:Q:0P0000040?ooo`<000002P3oool2000000P0oooo00<000000?ooo`3o
ool02`3oool2000000<0oooo0P0000090?ooo`@000000P3oool4000008l0oooo002X0?ooo`800000
102^a>T00`000000oooo0?ooo`040?ooo`8000001@3hZ4X00`000000oooo0?ooo`03000000`0oooo
0P0000080?ooo`8000003`3oool00`000000oooo0?ooo`020?ooo`8000002`3oool3000000<0oooo
1000002;0?ooo`00YP3oool2000000L0[/CY00@000000?ooo`3oool0oooo1@0000050?RXBP800000
3@3oool3000000T0oooo00<000000?ooo`3oool03`3oool2000000@0oooo0P00000<0?ooo`@00000
0`3oool5000008H0oooo002T0?ooo`8000002@2^a>T4000000D0oooo0`0000020?RXBP800000303o
ool2000000/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`8000003P3o
ool4000000@0oooo100000220?ooo`00XP3oool2000000L0[/CY100000000`2^a>T000000?ooo`04
0?ooo`<0000000L0oooo000000000000n:Q:0000003]VBD0000000T0oooo0`00000;0?ooo`800000
503oool2000000D0oooo0P00000@0?ooo`<000001@3oool5000007d0oooo002O0?ooo`<000001@2^
a>T4000000H0[/CY00<000000?ooo`0000000P0000060?ooo`80000000<0kITU0000003oool01`3o
ool2000000d0oooo0P00000F0?ooo`030000003oool0oooo00@0oooo0P00000A0?ooo`@000001P3o
ool4000007T0oooo002M0?ooo`800000102^a>T4000000T0[/CY0`00000:0?ooo`030000003]VBD0
000000H0oooo0`00000>0?ooo`030000003oool0oooo01H0oooo0P0000060?ooo`<000004P3oool4
000000H0oooo1000000N0?ooo`030000003oool0oooo05@0oooo002K0?ooo`8000000P2^a>T40000
00/0[/CY1@00000:0?ooo`040000003]VBD0kITU000000@0oooo0`00000>0?ooo`8000006P3oool2
000000L0oooo0P00000D0?ooo`<000001`3oool5000001T0oooo0`00001D0?ooo`00V@3oool60000
00D0[/CY2P00000>0?ooo`050000003]VBD0kITU0>fI9@0000000`3oool200000100oooo0P00000L
0?ooo`030000003oool0oooo00H0oooo0P00000E0?ooo`@00000203oool4000001@0oooo00@00000
09iXTP2NJ980WVRB0P00001B0?ooo`00U`3oool=000000@0oooo0`00000A0?ooo`030000003]VBD0
kITU0080kITU1000000A0?ooo`030000003oool0oooo01`0oooo0P0000080?ooo`8000005`3oool4
000000P0oooo1@00000?0?ooo`030000002NJ980WVRB00<0WVRB0P00001@0?ooo`00U@3oool50000
00/0oooo0`00000D0?ooo`030000003]VBD0kITU0080kITU0`00000A0?ooo`800000803oool00`00
0000oooo0?ooo`070?ooo`8000006@3oool3000000X0oooo1000000:0?ooo`030000002NJ980WVRB
00H0WVRB0P00001>0?ooo`00XP3oool3000001L0oooo00<000000>fI9@3]VBD00`00000C0?ooo`80
00008@3oool2000000T0oooo0P00000J0?ooo`@000002P3oool4000000H0oooo00<0000009iXTP2N
J980202NJ982000004`0oooo002O0?ooo`<000006@3oool010000000kITU0>fI9@0000030>fI9@03
0000003oool0oooo0100oooo0P00000S0?ooo`030000003oool0oooo00P0oooo0P00000L0?ooo`@0
00002P3oool5000000030?ooo`000000WVRB00/0WVRB0P00001:0?ooo`00W03oool3000001`0oooo
0`0000040>fI9@030000003oool0oooo00l0oooo0P00000U0?ooo`8000002P3oool3000001d0oooo
0`00000<0?ooo`@00000302NJ982000004P0oooo002I0?ooo`<000007`3oool2000000D0kITU00<0
00000?ooo`3oool03`3oool2000002L0oooo00<000000?ooo`3oool02P3oool2000001h0oooo1000
00080?ooo`040000002NJ980WVRB09iXTPD000002@2NJ982000004H0oooo002G0?ooo`8000008`3o
ool3000000@0kITU00<000000?ooo`3oool03P3oool2000002P0oooo0P00000<0?ooo`800000803o
ool4000000@0oooo00<0000009iXTP2NJ9801P2NJ984000000L0WVRB0P0000140?ooo`00U03oool3
000002<0oooo0P0000030?ooo`8000000P3]VBD00`000000oooo0?ooo`0>0?ooo`800000:P3oool0
0`000000oooo0?ooo`0;0?ooo`8000008P3oool4000000d0WVRB1000000509iXTP800000@P3oool0
0940oooo0`00000U0?ooo`030000003oool0oooo00D0oooo0P0000000`3]VBD000000?ooo`0=0?oo
o`800000;03oool2000000d0oooo0P00000S0?ooo`030000002NJ980WVRB00l0WVRB1@00000209iX
TP800000@03oool008h0oooo0`00000W0?ooo`030000003oool0oooo00P0oooo0P00000>0?ooo`80
0000;P3oool2000000d0oooo0P00000P0?ooo`030000002NJ980WVRB01D0WVRB1P00000n0?ooo`00
R`3oool3000002P0oooo0P00000K0?ooo`800000<03oool00`000000oooo0?ooo`0<0?ooo`800000
7P3ooolO000003d0oooo001b0?ooo`030000003oool0oooo01<0oooo0`00000Z0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`000000<@3oool2000000h0oooo0P00000Q0?ooo`030000002T
_>X0Y;cZ00@0Y;cZ100000050:BljP800000A@3oool00700oooo0`00000B0?ooo`<000007P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01/0oooo0P00000d0?ooo`030000003oool0
oooo00d0oooo0`00000N0?ooo`030000002T_>X0Y;cZ00P0Y;cZ100000030:BljP800000@`3oool0
06l0oooo00D000000>F[U`3UZiL0iJ^G0000000>0?ooo`<00000803oool2000000/0oooo0P00000N
0?ooo`800000=@3oool200000100oooo0P00000K0?ooo`D000002`2T_>X300000080Y;cZ0P000011
0?ooo`00KP3oool00`000000iJ^G0>F[U`020>F[U`030000003oool0oooo00X0oooo0P00000S0?oo
o`030000003i[FD0000000T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0000000g0?oo
o`030000003oool0oooo00l0oooo0P00000N0?ooo`T000001@2T_>X6000003l0oooo001/0?ooo`80
00001@3UZiL00`000000oooo0?ooo`070?ooo`<00000903oool010000000nJeU0?V]I@0000080?oo
o`030000003oool0oooo01h0oooo0P00000i0?ooo`8000004@3oool2000000l0oooo00<000000?oo
o`3oool04`3oool=000003d0oooo001[0?ooo`030000003UZiL0iJ^G00H0iJ^G00<000000?ooo`3o
ool00`3oool3000002L0oooo00D000000?V]I@3i[FD0nJeU000000050?ooo`8000008@3oool20000
03/0oooo00<000000?ooo`3oool0403oool2000000`0oooo00<000000:IcVP0000007P3oool50000
03/0oooo001Y0?ooo`8000002@3UZiL00`000000oooo0?ooo`03000002T0oooo00<000000?V]I@3i
[FD00P3i[FD00`000000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`00
0000?03oool200000180oooo0P00000:0?ooo`030000002VLiX0YW>J00800000G03oool006P0oooo
00<000000>F[U`3UZiL02@3UZiL3000002`0oooo00<000000?V]I@3i[FD00P3i[FD00`000000oooo
0?ooo`02000002<0oooo00<000000?ooo`000000?P3oool00`000000oooo0?ooo`0A0?ooo`800000
1`3oool00`000000YW>J0:IcVP030:IcVP030000003oool0oooo05T0oooo001W0?ooo`030000003U
ZiL0iJ^G00L0iJ^G0`0000000`3UZiL000000?ooo`0[0?ooo`030000003i[FD0nJeU00@0nJeU0P00
000U0?ooo`800000@03oool2000001<0oooo0`0000040?ooo`030000002VLiX0YW>J00@0YW>J00<0
00000?ooo`3oool0F03oool006D0oooo0P0000070>F[U`<00000103UZiL00`000000oooo0?ooo`0Y
0?ooo`030000003i[FD0nJeU00D0nJeU00<000000?ooo`3oool0903oool200000480oooo0P00000D
0?ooo`80000000<0oooo0000002VLiX01`2VLiX2000005P0oooo001T0?ooo`030000003UZiL0iJ^G
00@0iJ^G0`0000070>F[U`030000003oool0oooo02T0oooo00<000000?V]I@3i[FD00`3i[FD20000
00030?V]I@000000oooo02<0oooo00<000000?ooo`000000A03oool00`000000oooo0?ooo`0C0?oo
o`8000002P2VLiX00`000000oooo0?ooo`1E0?ooo`00HP3oool2000000D0iJ^G0P00000;0>F[U`03
0000003oool0oooo02L0oooo00<000000?V]I@3i[FD00`3i[FD01@000000nJeU0?V]I@3i[FD00000
02@0oooo00<000000?ooo`000000A@3oool2000001<0oooo00@000000:IcVP00000000002@2VLiX0
0`000000oooo0?ooo`1D0?ooo`00H@3oool00`000000iJ^G0>F[U`020>F[U`<000003@3UZiL00`00
0000oooo0?ooo`0W0?ooo`030000003i[FD0nJeU0080nJeU00<000000?V]I@3i[FD00P3i[FD00`00
0000oooo0?ooo`0R0?ooo`800000B03oool00`000000oooo0?ooo`0?0?ooo`030000002VLiX0YW>J
0080YW>J0P0000080:IcVP030000003oool0oooo05<0oooo001P0?ooo`030000003UZiL0iJ^G00<0
0000403UZiL00`000000oooo0?ooo`0V0?ooo`040000003i[FD0nJeU0?V]I@8000001P3i[FD00`00
0000oooo0?ooo`0P0?ooo`030000003oool0000004T0oooo0P00000?0?ooo`030000002VLiX0YW>J
00@0YW>J0P0000070:IcVP800000D`3oool005h0oooo1@00000D0>F[U`030000003oool0oooo02D0
oooo00@000000?V]I@3i[FD00000203i[FD00`000000oooo0?ooo`0P0?ooo`030000003oool00000
04/0oooo00<000000?ooo`3oool02`3oool00`000000YW>J0:IcVP070:IcVP8000001`2VLiX00`00
0000oooo0?ooo`1@0?ooo`00G@3ooolK000002H0oooo00@000000?V]I@3i[FD000002P3i[FD00`00
0000oooo0?ooo`0O0?ooo`030000003oool0000004`0oooo0P00000;0?ooo`030000002VLiX0YW>J
00T0YW>J0`0000050:IcVP030000003oool0oooo04l0oooo002N0?ooo`<00000103i[FD800000200
oooo00<000000?ooo`000000C`3oool00`000000oooo0?ooo`070?ooo`<000003@2VLiX2000000@0
YW>J00<000000?ooo`3oool0CP3oool009d0oooo2000000X0?ooo`030000003oool000000500oooo
0P00000:0?ooo`D000002P2VLiX2000000<0YW>J0P00001>0?ooo`00c@3oool00`000000oooo0000
001B0?ooo`8000003@3oool5000000L0YW>J0P0000030:IcVP030000003oool0oooo04/0oooo003<
0?ooo`030000003oool0000005D0oooo00<000000?ooo`3oool03`3oool5000000@0YW>J0P000002
0:IcVP030000003oool0oooo04X0oooo003<0?ooo`030000003oool0000005H0oooo0P00000D0?oo
o`D0000000@0YW>J000000000000YW>J0P00001:0?ooo`00c03oool00`000000oooo0000001H0?oo
o`030000003oool0oooo01H0oooo1@0000000`2VLiX000000?ooo`180?ooo`00c03oool00`000000
oooo0000001I0?ooo`8000006`3oool3000004P0oooo003;0?ooo`030000003oool0000005`0oooo
00<000000?ooo`3oool0H`3oool00</0oooo00<000000?ooo`000000G@3oool2000006<0oooo003;
0?ooo`030000003oool0000005l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1H
0?ooo`00bP3oool010000000oooo0?ooo`00001P0?ooo`800000103oool00`000000U:7M0000001I
0?ooo`00bP3oool00`000000oooo0000001S0?ooo`040000003oool0oooo000000<0U:7M00<00000
0?ooo`3oool0EP3oool00<X0oooo00<000000?ooo`000000I03oool2000000D0U:7M00<000000?oo
o`3oool0E@3oool00<T0oooo00@000000?ooo`3oool00000I03oool010000000U:7M000000000004
09BQg@030000003oool0oooo05@0oooo00390?ooo`040000003oool0oooo000006<0oooo00<00000
09BQg@2DXMd00P2DXMd00`000000U:7M09BQg@0209BQg@800000E03oool00<T0oooo00<000000?oo
o`000000H`3oool00`000000U:7M09BQg@0409BQg@800000102DXMd00`000000oooo0?ooo`1A0?oo
o`00b03oool010000000oooo0?ooo`00001R0?ooo`800000202DXMd00`000000U:7M09BQg@0209BQ
g@030000003oool0oooo0500oooo00380?ooo`040000003oool0oooo000006@0oooo0P00000709BQ
g@8000000`2DXMd00`000000oooo0?ooo`1?0?ooo`00b03oool00`000000oooo0000001W0?ooo`<0
00001P2DXMd01@000000U:7M09BQg@2DXMd000000500oooo00370?ooo`040000003oool0oooo0000
06X0oooo0P00000509BQg@8000000P2DXMd00`000000oooo0?ooo`1=0?ooo`00a`3oool010000000
oooo0?ooo`00001/0?ooo`<00000102DXMd010000000U:7M09BQg@00001>0?ooo`00a`3oool01000
0000oooo0?ooo`00001_0?ooo`8000000`2DXMd20000000309BQg@000000oooo04`0oooo00370?oo
o`030000003oool000000780oooo0P00000309BQg@<00000C03oool00<H0oooo00@000000?ooo`3o
ool00000M03oool300000080U:7M0`00001:0?ooo`00aP3oool010000000oooo0?ooo`00001g0?oo
o`80000000@0U:7M0000000000000000B@3oool00<H0oooo00@000000?ooo`3oool00000N@3oool5
000004P0oooo00350?ooo`040000003oool0oooo000007d0oooo0`0000170?ooo`00a@3oool01000
0000oooo0?ooo`00001o0?ooo`800000AP3oool00<D0oooo00@000000?ooo`3oool00000a`3oool0
0<@0oooo00D000000?ooo`3oool0oooo000000370?ooo`00a03oool010000000oooo0?ooo`000038
0?ooo`00a03oool010000000oooo0?ooo`0000380?ooo`00``3oool01@000000oooo0?ooo`3oool0
00000<P0oooo00330?ooo`040000003oool0oooo00000<T0oooo00330?ooo`040000003oool0oooo
00000<T0oooo00330?ooo`040000003oool0oooo00000<T0oooo00320?ooo`050000003oool0oooo
0?ooo`000000b@3oool00<80oooo00@000000?ooo`3oool00000bP3oool00<80oooo00@000000?oo
o`3oool00000bP3oool00;h0oooo100000030?ooo`030000003oool0oooo0<P0oooo002n0?ooo`03
0000002g/M<0]k7C00L00000b03oool00;h0oooo00<000000;Nad`2g/M<00`2g/M<010000000]k7C
0;Nad`2g/M<400000<@0oooo002n0?ooo`030000002g/M<0]k7C00<0]k7C00<000000;Nad`2g/M<0
0`2g/M<00`000000oooo0?ooo`330?ooo`00_P3oool00`000000]k7C0;Nad`030;Nad`030000002g
/M<0]k7C00<0]k7C00<000000?ooo`3oool0``3oool00;h0oooo00<000000;Nad`2g/M<00`2g/M<0
0`000000]k7C0;Nad`020;Nad`030000003oool0oooo0<@0oooo002n0?ooo`030000002g/M<0]k7C
0080]k7C00<000000;Nad`2g/M<00`2g/M<00`000000oooo0?ooo`340?ooo`00_P3oool00`000000
]k7C0;Nad`020;Nad`030000002g/M<0]k7C0080]k7C00<000000?ooo`3oool0a@3oool00;h0oooo
00<000000;Nad`2g/M<00P2g/M<01@000000]k7C0;Nad`2g/M<000000<P0oooo002n0?ooo`050000
002g/M<0]k7C0;Nad`000000102g/M<00`000000oooo0?ooo`360?ooo`00_P3oool01@000000]k7C
0;Nad`2g/M<0000000<0]k7C00<000000?ooo`3oool0a`3oool00;h0oooo00D000000;Nad`2g/M<0
]k7C000000030;Nad`030000003oool0oooo0<L0oooo002g0?ooo`T000000P2g/M<010000000]k7C
0;Nad`00003:0?ooo`00]`3oool00`000000/;WO0;2ig`040;2ig`80000000D0]k7C0000002g/M<0
]k7C0000003;0?ooo`00]`3oool00`000000/;WO0;2ig`030;2ig`050000002`^Ml000000;Nad`00
00000P2g/M<00`000000oooo0?ooo`390?ooo`00]`3oool00`000000/;WO0;2ig`030;2ig`070000
002`^Ml000000;Nad`000000]k7C0000003<0?ooo`00]`3oool00`000000/;WO0;2ig`030;2ig`07
0000002`^Ml000000;Nad`000000]k7C0000003<0?ooo`00^03oool00`000000/;WO0;2ig`020;2i
g`060000002`^Ml000000000002g/M<00000c@3oool00;P0oooo00D000000;2ig`2`^Ml0/;WO0000
00020;2ig`<00000cP3oool00;P0oooo00D000000;2ig`2`^Ml0/;WO000000020;2ig`<00000cP3o
ool00;P0oooo00D000000;2ig`2`^Ml0/;WO000000020;2ig`800000c`3oool00;P0oooo00@00000
0;2ig`2`^Ml000000P2`^Ml300000<l0oooo002h0?ooo`040000002`^Ml0/;WO00000080/;WO0P00
003@0?ooo`00^03oool01P000000/;WO0;2ig`000000/;WO00000=80oooo002h0?ooo`050000002`
^Ml000000;2ig`000000d`3oool00;T0oooo0P0000000`2`^Ml000000?ooo`3B0?ooo`00^@3oool3
00000=@0oooo002i0?ooo`800000e@3oool00;T0oooo0P00003E0?ooo`00^@3oool00`000000oooo
0?ooo`3D0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 399}, {445.875, 0}} -> {0.058531, -9.30164*^-05, \
0.00209667, 0.00209667}}]
}, Open  ]],

Cell[TextData[{
  "Also see the example in ",
  ButtonBox["DrawVectorField3D",
    ButtonData:>{"DrawVectorField3D"},
    ButtonStyle->"AddOnsLink"],
  " ."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{494, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 54, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1833, 56, 385, 15, 50, "Usage",
      CellTags->"Function?"],
    Cell[2221, 73, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 124762, 2301}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 54, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1833, 56, 385, 15, 50, "Usage",
  CellTags->"Function?"],
Cell[2221, 73, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2318, 78, 170, 3, 75, "MathCaption"],
Cell[2491, 83, 219, 4, 75, "MathCaption"],
Cell[2713, 89, 234, 4, 75, "MathCaption"],
Cell[2950, 95, 136, 3, 58, "MathCaption"],
Cell[3089, 100, 191, 4, 58, "MathCaption"],
Cell[3283, 106, 578, 22, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3886, 132, 34, 0, 39, "ExampleSection"],
Cell[3923, 134, 97, 2, 29, "Input"],
Cell[4023, 138, 67, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[4115, 142, 335, 7, 109, "Input"],
Cell[4453, 151, 39839, 692, 294, 4067, 245, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[44307, 846, 95, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[44427, 852, 589, 11, 189, "Input"],
Cell[45019, 865, 40616, 704, 294, 4084, 248, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[85650, 1572, 92, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[85767, 1578, 743, 14, 229, "Input"],
Cell[86513, 1594, 37352, 676, 453, 4904, 271, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[123880, 2273, 168, 6, 25, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

