(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5791,        182]*)
(*NotebookOutlinePosition[      6797,        217]*)
(*  CellTagsIndexPosition[      6723,        211]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ArrowCurve", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["ArrowCurve",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(graphics, fraction, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will put arrowheads on all the the curves in graphics."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["A curve is a Line with more than two points.", "MathCaption"],

Cell[TextData[{
  "The arrowheads are put at a distance ",
  Cell[BoxData[
      \(fraction*curvelength\)]],
  " from the beginning of each curve. The routine uses the plot point that is \
closest to the fractional distance for the point of the arrowhead. Fractional \
distances will display correctly only with AspectRatio set to Automatic."
}], "MathCaption"],

Cell["The curves must be separately drawn.", "MathCaption"],

Cell[TextData[{
  "The regular ",
  ButtonBox["Arrow",
    ButtonData:>{"Graphics`Arrow`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  " options can be passed to the Arrow routine."
}], "MathCaption"],

Cell[TextData[{
  "The meaning of ",
  Cell[BoxData[
      \(HeadScaling \[Rule] Relative\)]],
  " is taken to mean relative to the length of the curve."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Arrow",
    ButtonData:>{"Graphics`Arrow`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowLine",
    ButtonData:>{"ArrowLine"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowTangent",
    ButtonData:>{"ArrowTangent"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ProportionalArrow",
    ButtonData:>{"ProportionalArrow"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example  ", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Here, two different curved arrows are drawn.", "Text"],

Cell[BoxData[
    \(\(curve[a_, b_]\)[t_] := {a\ t, b\ t\^2}\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(Module[\[IndentingNewLine]{c}, \[IndentingNewLine]c[1] = 
          ParametricDraw[
            Evaluate[\(curve[1, 1]\)[t]], {t, 0, 1}]; \[IndentingNewLine]c[
            2] = ParametricDraw[
            Evaluate[\(curve[1, 2]\)[t]], {t, 0, 
              1}]; \[IndentingNewLine]Draw2D[\[IndentingNewLine]{c[1], Blue, 
            c[2], \[IndentingNewLine]Black, 
            ArrowCurve[c[1], 1, 
              HeadCenter \[Rule] 1/2], \[IndentingNewLine]ArrowCurve[c[2], 
              1]}, \[IndentingNewLine]PlotRange \[Rule] All]];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[TextData[{
  "Here, a number of arrowheads are placed on a curve by mapping onto a list \
of fractional lengths. The routine calculates the running curve length for \
the plot points and tries to obtain a correct fractional distance. The \
AspectRatio must be set to automatic for this to display properly. Even so, \
the arrowheads may not be quite evenly spaced because of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s adaptive picking of points. If this becomes a noticable problem, it can \
be remedied by using more PlotPoints."
}], "Text"],

Cell[BoxData[
    \(\(Module[\[IndentingNewLine]{c}, \[IndentingNewLine]c[2] = 
          ParametricDraw[
            Evaluate[\(curve[1, 2]\)[t]], {t, 0, 
              1}]; \[IndentingNewLine]Draw2D[\[IndentingNewLine]{c[
              2], \[IndentingNewLine]\(ArrowCurve[c[2], #, 
                  HeadLength \[Rule] 0.12, HeadCenter \[Rule] 1/2] &\) /@ 
              Range[0.2, 1, 0.2]}, \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]PlotRange \[Rule] 
            All]];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(Clear[curve]\)], "Input",
  CellLabel->"In[5]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{515, 736},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 57, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1836, 56, 373, 14, 50, "Usage",
      CellTags->"Function?"],
    Cell[2212, 72, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6477, 200}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 57, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1836, 56, 373, 14, 50, "Usage",
  CellTags->"Function?"],
Cell[2212, 72, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2309, 77, 67, 0, 41, "MathCaption"],
Cell[2379, 79, 361, 7, 92, "MathCaption"],
Cell[2743, 88, 59, 0, 41, "MathCaption"],
Cell[2805, 90, 198, 6, 41, "MathCaption"],
Cell[3006, 98, 172, 5, 58, "MathCaption"],
Cell[3181, 105, 463, 18, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3669, 127, 35, 0, 39, "ExampleSection"],
Cell[3707, 129, 97, 2, 29, "Input"],
Cell[3807, 133, 60, 0, 25, "Text"],
Cell[3870, 135, 97, 2, 30, "Input"],
Cell[3970, 139, 598, 11, 189, "Input"],
Cell[4571, 152, 565, 10, 93, "Text"],
Cell[5139, 164, 552, 10, 189, "Input"],
Cell[5694, 176, 69, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

