(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     51551,       1274]*)
(*NotebookOutlinePosition[     52563,       1309]*)
(*  CellTagsIndexPosition[     52487,       1303]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ArrowCurve3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["ArrowCurve3D",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(graphics, fraction, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will put arrow cones on all the the curves in graphics."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["A curve is a Line with more than two points.", "MathCaption"],

Cell[TextData[{
  "The arrowcones are put at a distance ",
  Cell[BoxData[
      \(fraction*curvelength\)]],
  " from the beginning of each curve. The routine uses the first pair of \
points that exceed or equal the fractional distance."
}], "MathCaption"],

Cell["The curves must be separately drawn.", "MathCaption"],

Cell[TextData[{
  "The regular ",
  ButtonBox["Arrow3D",
    ButtonData:>{"Arrow3D"},
    ButtonStyle->"AddOnsLink"],
  " options can be passed to the Arrow3D routine."
}], "MathCaption"],

Cell[TextData[{
  "The meaning of ",
  Cell[BoxData[
      \(HeadScaling3D \[Rule] Relative\)]],
  " is taken to mean relative to the length of the curve."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Arrow3D",
    ButtonData:>{"Arrow3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowLine3D",
    ButtonData:>{"ArrowLine3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowTangent3D",
    ButtonData:>{"ArrowTangent3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ProportionalArrow3D",
    ButtonData:>{"ProportionalArrow3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Arrow",
    ButtonData:>{"Graphics`Arrow`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  " ."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Here, two different curved arrows are drawn.", "Text"],

Cell[BoxData[
    \(\(curve[a_, b_, c_]\)[\[Theta]_] := {a\ Cos[\[Theta]], 
        b\ Sin[\[Theta]], c\ \[Theta]}\)], "Input",
  CellLabel->"In[2]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Module[\[IndentingNewLine]{c}, \[IndentingNewLine]c[1] = 
          ParametricDraw3D[
            Evaluate[\(curve[1, 1, 1]\)[\[Theta]]], {\[Theta], 
              0, \[Pi]}]; \[IndentingNewLine]c[2] = 
          ParametricDraw3D[
            Evaluate[\(curve[1, 2, 1/2]\)[\[Theta]]], {\[Theta], 
              0, \[Pi]}]; \
\[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{c[1], Blue, 
            c[2], \[IndentingNewLine]Black, 
            ArrowCurve3D[{c[1], c[2]}, 
              1]}, \[IndentingNewLine]PlotRange \[Rule] All]];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.35664 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.174338 1.38018 3.42608e-017 1.38018 [
[ 0 0 0 0 ]
[ 1 1.35664 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0851 .23144 m
0 1.07435 L
s
0 1.07435 m
.37254 1.35664 L
s
.37254 1.35664 m
.39353 .56672 L
s
.39353 .56672 m
.0851 .23144 L
s
.66402 0 m
.92421 .38577 L
s
.92421 .38577 m
1 1.20582 L
s
1 1.20582 m
.69608 .8721 L
s
.69608 .8721 m
.66402 0 L
s
.0851 .23144 m
0 1.07435 L
s
0 1.07435 m
.69608 .8721 L
s
.69608 .8721 m
.66402 0 L
s
.66402 0 m
.0851 .23144 L
s
.39353 .56672 m
.92421 .38577 L
s
.92421 .38577 m
1 1.20582 L
s
1 1.20582 m
.37254 1.35664 L
s
.37254 1.35664 m
.39353 .56672 L
s
0 0 m
1 0 L
1 1.35664 L
0 1.35664 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.65135 .66202 m
.64016 .66939 L
s
.6621 .6541 m
.65135 .66202 L
s
.64016 .66939 m
.62855 .67622 L
s
.67242 .64565 m
.6621 .6541 L
s
.62855 .67622 m
.61653 .68252 L
s
.68227 .63666 m
.67242 .64565 L
s
.61653 .68252 m
.60413 .68828 L
s
.69165 .62713 m
.68227 .63666 L
s
.60413 .68828 m
.59134 .69349 L
s
.70055 .61707 m
.69165 .62713 L
s
.59134 .69349 m
.57819 .69818 L
s
.70895 .60647 m
.70055 .61707 L
s
.57819 .69818 m
.56469 .70233 L
s
.71684 .59535 m
.70895 .60647 L
s
.56469 .70233 m
.55086 .70594 L
s
.72421 .58369 m
.71684 .59535 L
s
.55086 .70594 m
.5367 .70903 L
s
.73104 .57151 m
.72421 .58369 L
s
.5367 .70903 m
.52224 .71158 L
s
.73733 .55881 m
.73104 .57151 L
s
.52224 .71158 m
.50748 .71362 L
s
.74306 .54559 m
.73733 .55881 L
s
.50748 .71362 m
.49245 .71512 L
s
.74823 .53186 m
.74306 .54559 L
s
.49245 .71512 m
.47716 .71611 L
s
.75281 .51763 m
.74823 .53186 L
s
.47716 .71611 m
.46163 .71659 L
s
.7568 .5029 m
.75281 .51763 L
s
.46163 .71659 m
.44587 .71655 L
s
.76019 .48768 m
.7568 .5029 L
s
.44587 .71655 m
.42989 .71601 L
s
.76297 .47197 m
.76019 .48768 L
s
.42989 .71601 m
.41373 .71496 L
s
.76513 .45579 m
.76297 .47197 L
s
.41373 .71496 m
.39738 .71342 L
s
.76666 .43915 m
.76513 .45579 L
s
.76755 .42205 m
.76666 .43915 L
s
.39738 .71342 m
.38088 .71138 L
s
.76779 .40451 m
.76755 .42205 L
s
.38088 .71138 m
.36424 .70886 L
s
.76737 .38654 m
.76779 .40451 L
s
.36424 .70886 m
.34747 .70586 L
s
.7663 .36816 m
.76737 .38654 L
s
.34747 .70586 m
.33061 .70239 L
s
.76455 .34938 m
.7663 .36816 L
s
.33061 .70239 m
.31366 .69845 L
s
.76213 .33021 m
.76455 .34938 L
s
.31366 .69845 m
.29665 .69405 L
s
.75903 .31067 m
.76213 .33021 L
s
.75525 .29079 m
.75903 .31067 L
s
.29665 .69405 m
.2796 .6892 L
s
.75079 .27057 m
.75525 .29079 L
s
.2796 .6892 m
.26254 .68392 L
s
.74563 .25005 m
.75079 .27057 L
s
.26254 .68392 m
.24548 .6782 L
s
.73979 .22924 m
.74563 .25005 L
s
.24548 .6782 m
.22844 .67206 L
s
.73326 .20817 m
.73979 .22924 L
s
.72605 .18686 m
.73326 .20817 L
s
.22844 .67206 m
.21146 .66551 L
s
.71815 .16534 m
.72605 .18686 L
s
.21146 .66551 m
.19456 .65857 L
s
.70958 .14364 m
.71815 .16534 L
s
.776 .94 .934 r
.09619 .60932 m .15585 .63477 L .17215 .62302 L closepath p F P
0 g
s
.944 .89 .746 r
.09619 .60932 m .14676 .65382 L .15585 .63477 L closepath p F P
0 g
s
.989 .722 .398 r
.09619 .60932 m .1483 .67298 L .14676 .65382 L closepath p F P
0 g
s
0 0 1 r
.19456 .65857 m
.17775 .65124 L
s
.146 .677 .862 r
.09619 .60932 m .17215 .62302 L .18951 .62303 L closepath p F P
0 g
s
0 0 1 r
.70034 .12178 m
.70958 .14364 L
s
0 .04 .565 r
.09619 .60932 m .15996 .685 L .1483 .67298 L closepath p F P
0 g
s
.774 .299 .108 r
.09619 .60932 m .18951 .62303 L .20133 .63489 L closepath p F P
0 g
s
.61183 .56258 m
.60281 .57884 L
s
.62044 .54608 m
.61183 .56258 L
s
.486 .691 .959 r
.09619 .60932 m .17737 .6852 L .15996 .685 L closepath p F P
0 g
s
.60281 .57884 m
.5934 .59486 L
s
.62863 .52936 m
.62044 .54608 L
s
.5934 .59486 m
.58361 .61063 L
s
0 0 1 r
.69043 .09979 m
.70034 .12178 L
s
0 g
.6364 .51242 m
.62863 .52936 L
s
.58361 .61063 m
.57346 .62616 L
s
.64371 .49527 m
.6364 .51242 L
s
.57346 .62616 m
.56296 .64143 L
s
.65057 .47792 m
.64371 .49527 L
s
.56296 .64143 m
.55214 .65644 L
s
.65696 .46037 m
.65057 .47792 L
s
.55214 .65644 m
.541 .67119 L
s
.889 .638 .554 r
.09619 .60932 m .20133 .63489 L .20302 .65415 L closepath p F P
0 g
s
.66287 .44264 m
.65696 .46037 L
s
.66828 .42474 m
.66287 .44264 L
s
.541 .67119 m
.52955 .68567 L
s
.67319 .40668 m
.66828 .42474 L
s
.52955 .68567 m
.51783 .69988 L
s
.75 .77 .87 r
.09619 .60932 m .19386 .67341 L .17737 .6852 L closepath p F P
0 g
s
.67759 .38847 m
.67319 .40668 L
s
.51783 .69988 m
.50584 .71383 L
s
.68147 .37012 m
.67759 .38847 L
s
.851 .742 .743 r
.09619 .60932 m .20302 .65415 L .19386 .67341 L closepath p F P
0 g
s
.68482 .35164 m
.68147 .37012 L
s
0 0 1 r
.67987 .07772 m
.69043 .09979 L
s
0 g
.50584 .71383 m
.4936 .7275 L
s
.68762 .33305 m
.68482 .35164 L
s
.4936 .7275 m
.48112 .74089 L
s
.68989 .31437 m
.68762 .33305 L
s
.69161 .2956 m
.68989 .31437 L
s
.48112 .74089 m
.46843 .75401 L
s
.69277 .27676 m
.69161 .2956 L
s
.46843 .75401 m
.45554 .76686 L
s
.69337 .25788 m
.69277 .27676 L
s
0 0 1 r
.66867 .05558 m
.67987 .07772 L
s
0 g
.6934 .23895 m
.69337 .25788 L
s
.45554 .76686 m
.44246 .77943 L
s
.69288 .22001 m
.6934 .23895 L
s
.69178 .20106 m
.69288 .22001 L
s
.44246 .77943 m
.42922 .79172 L
s
.69013 .18213 m
.69178 .20106 L
s
.6879 .16323 m
.69013 .18213 L
s
.42922 .79172 m
.41584 .80375 L
s
.68511 .14438 m
.6879 .16323 L
s
0 0 1 r
.65684 .03341 m
.66867 .05558 L
s
0 g
.68177 .1256 m
.68511 .14438 L
s
.67787 .10691 m
.68177 .1256 L
s
.41584 .80375 m
.40232 .8155 L
s
.67342 .08833 m
.67787 .10691 L
s
.66842 .06987 m
.67342 .08833 L
s
.6629 .05156 m
.66842 .06987 L
s
.40232 .8155 m
.38869 .82698 L
s
.65684 .03341 m
.6629 .05156 L
s
.38869 .82698 m
.37497 .83819 L
s
.37497 .83819 m
.36117 .84914 L
s
.36117 .84914 m
.34732 .85982 L
s
.34732 .85982 m
.33343 .87025 L
s
.33343 .87025 m
.31951 .88042 L
s
.31951 .88042 m
.3056 .89033 L
s
.3056 .89033 m
.2917 .9 L
s
.2917 .9 m
.27784 .90943 L
s
.27784 .90943 m
.26403 .91862 L
s
.26403 .91862 m
.2503 .92758 L
s
.2503 .92758 m
.23666 .93631 L
s
.23666 .93631 m
.22314 .94482 L
s
.22314 .94482 m
.20974 .95312 L
s
.20974 .95312 m
.1965 .96121 L
s
.1965 .96121 m
.18344 .96911 L
s
.18344 .96911 m
.17056 .97681 L
s
.17056 .97681 m
.15789 .98433 L
s
.15789 .98433 m
.14546 .99167 L
s
.973 .663 .342 r
.0568 1.04525 m .10181 1.01957 L .09383 .99819 L closepath p F P
0 g
s
.784 .298 .064 r
.0568 1.04525 m .11944 1.03362 L .10181 1.01957 L closepath p F P
0 g
s
.915 .888 .47 r
.0568 1.04525 m .09383 .99819 L .09854 .97756 L closepath p F P
0 g
s
.211 0 0 r
.0568 1.04525 m .14008 1.03501 L .11944 1.03362 L closepath p F P
0 g
s
0 0 0 r
.0568 1.04525 m .09854 .97756 L .11422 .96552 L closepath p F P
0 g
s
.707 .979 .907 r
.0568 1.04525 m .15588 1.02311 L .14008 1.03501 L closepath p F P
0 g
s
.545 .141 .226 r
.0568 1.04525 m .11422 .96552 L .13493 .96675 L closepath p F P
0 g
s
.927 .871 .762 r
.0568 1.04525 m .16074 1.00242 L .15588 1.02311 L closepath p F P
0 g
s
.789 .463 .437 r
.0568 1.04525 m .13493 .96675 L .15274 .98085 L closepath p F P
0 g
s
.899 .678 .595 r
.0568 1.04525 m .15274 .98085 L .16074 1.00242 L closepath p F P
0 g
s
.25 Mabswid
.66402 0 m
.92421 .38577 L
s
.92421 .38577 m
1 1.20582 L
s
1 1.20582 m
.69608 .8721 L
s
.69608 .8721 m
.66402 0 L
s
.0851 .23144 m
0 1.07435 L
s
0 1.07435 m
.69608 .8721 L
s
.69608 .8721 m
.66402 0 L
s
.66402 0 m
.0851 .23144 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[3]:=",
  ImageSize->{212.25, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003D00017b000`400?l00000o`00003oR`3oool2
000004L0oooo00290?ooo`80000000<0oooo000000000000AP3oool008H0oooo0`0000030?ooo`80
0000AP3oool008@0oooo0P0000060?ooo`030000003oool0000004D0oooo00210?ooo`<00000203o
ool010000000oooo0?ooo`0000140?ooo`00O`3oool2000000/0oooo00@000000?ooo`3oool00000
A03oool007`0oooo0`00000=0?ooo`050000003oool0oooo0?ooo`000000@`3oool007X0oooo0P00
000>0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0@03oool007L0oooo0`00000@
0?ooo`03000000000?l0000000@0oooo00<000000?ooo`3oool0@03oool007D0oooo0P00000D0?oo
o`8000001@3oool00`000000oooo0?ooo`0o0?ooo`00LP3oool3000001H0oooo0P0000060?ooo`03
0000003oool0oooo03h0oooo001`0?ooo`8000006P3oool00`000000003o0?ooo`040?ooo`030000
003oool0oooo03h0oooo001]0?ooo`<00000703oool00`000000003o0?ooo`050?ooo`030000003o
ool0oooo03d0oooo001[0?ooo`8000007`3oool2000000030000o`3oool0oooo00@0oooo00<00000
0?ooo`3oool0?03oool006P0oooo0`00000R0?ooo`03000000000?l0oooo00H0oooo00<000000?oo
o`3oool0>`3oool006H0oooo0P00000U0?ooo`030000003oool0003o00H0oooo00<000000?ooo`3o
ool0>`3oool006<0oooo0`00000W0?ooo`030000003oool0003o00L0oooo00<000000?ooo`3oool0
>P3oool00640oooo0P00000Z0?ooo`80000000<0003o0?ooo`3oool01P3oool00`000000oooo0?oo
o`0i0?ooo`00GP3oool3000002`0oooo0P0000000`3oool0003o0?ooo`060?ooo`030000003oool0
oooo03T0oooo001L0?ooo`800000;`3oool2000000030?ooo`000?l0oooo00L0oooo00<000000?oo
o`3oool0>03oool005T0oooo0`00000a0?ooo`8000000P3oool00`000?l0oooo0?ooo`060?ooo`03
0000003oool0oooo03L0oooo001G0?ooo`800000=03oool01@000000oooo0000003oool0003o00P0
oooo00<000000?ooo`3oool0=`3oool005@0oooo0`00000f0?ooo`050000003oool000000?ooo`00
0?l02@3oool00`000000oooo0?ooo`0f0?ooo`00DP3oool2000003T0oooo00<000000?ooo`000000
0P3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo001?0?ooo`<00000>`3o
ool00`000000oooo000000020?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3oool0=@3o
ool004`0oooo0`00000n0?ooo`040000003oool0oooo00000080oooo00<0003o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`0d0?ooo`00BP3oool200000440oooo00@000000?ooo`3oool000000P3o
ool00`000?l0oooo0?ooo`080?ooo`030000003oool0oooo03<0oooo00170?ooo`<00000@`3oool0
10000000oooo0?ooo`0000030?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3oool0<`3o
ool004D0oooo0P0000160?ooo`040000003oool0oooo000000<0oooo00<0003o0?ooo`3oool0203o
ool00`000000oooo0?ooo`0b0?ooo`00@P3oool3000004P0oooo00@000000?ooo`3oool00000103o
ool00`000?l0oooo0?ooo`080?ooo`030000003oool0oooo0340oooo00100?ooo`800000B`3oool0
10000000oooo0?ooo`0000040?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0<@3o
ool003d0oooo0`00001=0?ooo`040000003oool0oooo000000@0oooo00<0003o0?ooo`3oool02@3o
ool00`000000oooo0?ooo`0`0?ooo`00>`3oool200000500oooo00@000000?ooo`3oool000001@3o
ool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo02l0oooo000h0?ooo`<00000DP3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<0003o0?ooo`3oool02@3oool00`000000oooo0?oo
o`0_0?ooo`00=P3oool2000005D0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000o`3o
ool0oooo00T0oooo00<000000?ooo`3oool0;P3oool003<0oooo0`00001G0?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo02d0oooo000a
0?ooo`800000FP3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0003o0?ooo`3oool02P3o
ool00`000000oooo0?ooo`0]0?ooo`00;P3oool3000005`0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3oool0;03oool002`0oooo0P00001O
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000?l0oooo0?ooo`0;0?ooo`030000003o
ool0oooo02/0oooo000Y0?ooo`<00000H@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<0
003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0[0?ooo`009`3oool2000006D0oooo00@00000
0?ooo`3oool000001`3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo02X0oooo000T
0?ooo`<00000I`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0003o0?ooo`3oool0303o
ool00`000000oooo0?ooo`0Y0?ooo`008P3oool2000006X0oooo00D000000?ooo`3oool0oooo0000
00070?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0:03oool001l0oooo0`00001/
0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000?l0oooo0?ooo`0<0?ooo`030000003o
ool0oooo02P0oooo000M0?ooo`800000K`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<0
003o0?ooo`3oool03@3oool00`000000oooo0?ooo`0W0?ooo`006P3oool300000740oooo00D00000
0?ooo`3oool0oooo000000070?ooo`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool09P3o
ool001P0oooo0P00001d0?ooo`050000003oool0oooo0?ooo`000000203oool00`000?l0oooo0?oo
o`0=0?ooo`030000003oool0oooo02H0oooo000E0?ooo`<00000MP3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`0U0?ooo`004`3oool2
000007T0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000o`3oool0oooo00h0oooo00<0
00000?ooo`3oool0903oool00140oooo0P00001k0?ooo`050000003oool0oooo0?ooo`0000002@3o
ool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo02@0oooo000A0?ooo`800000N`3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo0?oo
o`0S0?ooo`004@3oool00`000000oooo0000001j0?ooo`050000003oool0oooo0?ooo`0000002P3o
ool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo0280oooo000A0?ooo`040000003oool0
oooo000007T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000o`3oool0oooo00l0oooo
00<000000?ooo`3oool08P3oool00140oooo00D000000?ooo`3oool0oooo0000001h0?ooo`050000
003oool0oooo0?ooo`0000002P3oool00`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo0240
oooo000A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0M@3oool01@000000oooo
0?ooo`3oool0000000X0oooo00<0003o0?ooo`3oool04@3oool00`000000oooo0?ooo`0P0?ooo`00
403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07@0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`030000o`3oool0oooo0140oooo00<000000?ooo`3oool0803oool00100oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1c0?ooo`050000003oool0oooo0?ooo`00
00002`3oool00`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo01l0oooo000@0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0LP3oool01@000000oooo0?ooo`3oool0000000/0
oooo00<0003o0?ooo`3oool04P3oool00`000000oooo0?ooo`0N0?ooo`00403oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0780oooo00D000000?ooo`3oool0oooo0000000;0?ooo`03
0000o`3oool0oooo0180oooo00<000000?ooo`3oool07P3oool00100oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1a0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000?l0
oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo000@0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0L03oool01@000000oooo0?ooo`3oool0000000`0oooo00<0003o0?ooo`3o
ool04`3oool00`000000oooo0?ooo`0L0?ooo`00403oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo06l0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000o`3oool0oooo01<0
oooo00<000000?ooo`3oool0703oool00100oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1^0?ooo`050000003oool0oooo0?ooo`000000303oool00`000?l0oooo0?ooo`0D0?ooo`03
0000003oool0oooo01/0oooo000@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
K@3oool01@000000oooo0?ooo`3oool0000000`0oooo00<0003o0?ooo`3oool05@3oool00`000000
oooo0?ooo`0J0?ooo`00403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06`0oooo
00@000000?ooo`3oool000003P3oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo01X0
oooo000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0J`3oool010000000oooo
0?ooo`00000>0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool06@3oool000l0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0000000h0oooo
00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`0H0?ooo`003`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`0000003P3oool00`000?l0oooo0?oo
o`0F0?ooo`030000003oool0oooo01P0oooo000?0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0000000?0?ooo`030000o`3oool0oooo01H0oooo00<00000
0?ooo`3oool05`3oool000l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0000000l0oooo00<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?oo
o`003`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`00
00003`3oool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo01D0oooo000?0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0000000?0?ooo`030000
o`3oool0oooo01P0oooo00<000000?ooo`3oool05@3oool000l0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`1U0?ooo`800000403oool00`000?l0oooo0?ooo`0I0?ooo`030000003o
ool0oooo01@0oooo000?0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0I03oool2
00000100oooo00<0003o0?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`003`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo06<0oooo0P00000@0?ooo`030000o`3oool0oooo
01X0oooo00<000000?ooo`3oool04`3oool000l0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1R0?ooo`800000403oool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo0180
oooo000>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool04@3oool000h0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00l0oooo00<0
003o0?ooo`3oool0703oool00`000000oooo0?ooo`0A0?ooo`003P3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0M
0?ooo`030000003oool0oooo0100oooo000>0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0G`3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo01h0oooo00<000000?oo
o`3oool03`3oool000h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo0100oooo00<0003o0?ooo`3oool07@3oool00`000000oooo0?ooo`0?0?ooo`00
3P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
403oool00`000?l0oooo0?ooo`0M0?ooo`800000403oool000h0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool06P3o
ool3000000030?ooo`000000oooo00l0oooo000>0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo01L0oooo0`000004
0?ooo`030000003oool0oooo00h0oooo000>0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0F@3oool200000180oooo00<0003o0?ooo`3oool0503oool3000000L0oooo00<000000?oo
o`3oool03P3oool000h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1H0?ooo`80
00004P3oool00`000?l0oooo0?ooo`0A0?ooo`<000002P3oool00`000000oooo0?ooo`0>0?ooo`00
3@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo05L0oooo0P00000B0?ooo`030000
o`3oool0oooo00h0oooo0`00000=0?ooo`030000003oool0oooo00h0oooo000=0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0EP3oool200000180oooo00<0003o0?ooo`3oool02`3o
ool300000140oooo00<000000?ooo`3oool03@3oool000d0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool000000180oooo00<0003o0?ooo`3oool0203oool3
000001@0oooo00<000000?ooo`3oool03@3oool000d0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool000000180oooo00<0003o0?ooo`3oool01@3oool30000
01L0oooo00<000000?ooo`3oool03@3oool000d0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`1B0?ooo`030000003oool000000180oooo00<0003o0?ooo`3oool00`3oool2000001X0
oooo00<000000?ooo`3oool03@3oool000d0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`1@0?ooo`040000003oool0oooo00000140oooo00@0003o0?ooo`3oool0oooo0`00000L0?oo
o`030000003oool0oooo00d0oooo000=0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0C`3oool010000000oooo0?ooo`00000A0?ooo`040000o`0000000000000001l0oooo00<00000
0?ooo`3oool03@3oool000d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1?0?oo
o`050000003oool0oooo0?ooo`0000003P3oool2000000030000o`3oool0oooo0200oooo00<00000
0?ooo`3oool03@3oool000d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool300000080oooo00<0003o0?oo
o`3oool0803oool00`000000oooo0?ooo`0=0?ooo`003@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`<0
00001@3oool00`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo00d0oooo000=0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo0`0000080?ooo`030000o`3oool0oooo0200oooo00<000000?ooo`3oool0
3@3oool000`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`00000;0?ooo`030000o`3oool0oooo0200oooo00<0
00000?ooo`3oool03@3oool000`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo00<0oooo0`00000>0?ooo`030000o`3oool0oooo0240oooo00<00000
0?ooo`3oool0303oool000`0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`160?oo
o`040000003oool0oooo0?ooo`@00000403oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0
oooo00`0oooo000<0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0A@3oool40000
00<0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0oooo
00`0oooo000<0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0@P3oool3000000H0
oooo00<000000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo00`0
oooo000<0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool3000000030?oo
o`000000oooo00H0oooo00<000000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0R0?ooo`030000
003oool0oooo00`0oooo000<0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0>P3o
ool3000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo0280oooo00<000000?ooo`3oool0303oool000`0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0f0?ooo`<000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00d0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`0<0?ooo`00303oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0380oooo0`0000090?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo
00`0oooo000<0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0;P3oool3000000/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo02<0
oooo00<000000?ooo`3oool0303oool000/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`0Z0?ooo`<000003P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo
00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`0<0?ooo`002`3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo02H0oooo0`00000A0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0303oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo00`0oooo000;
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool08`3oool2000001<0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo02@0oooo00<00000
0?ooo`3oool02`3oool000/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0O0?oo
o`<000005@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<0003o0?oo
o`3oool0903oool00`000000oooo0?ooo`0;0?ooo`002`3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo01`0oooo0`00000G0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo000;0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool0603oool3000001X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo02D0oooo00<000000?ooo`3oool0
2`3oool000/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0D0?ooo`<000007@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0003o0?ooo`3oool09P3o
ool00`000000oooo0?ooo`0;0?ooo`002`3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0100oooo0`00000O0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0V0?ooo`030000003oool0oooo00/0oooo000;0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0303oool300000280oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000o`3oool0oooo02L0oooo00<000000?ooo`3oool02`3oool000/0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`080?ooo`<00000903oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool09`3oool00`000000
oooo0?ooo`0;0?ooo`002`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00@0oooo
0`00000W0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000?l0oooo
0?ooo`0X0?ooo`030000003oool0oooo00/0oooo000:0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool00`00000Y0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo00/0oooo000:0?ooo`030000003oool0
oooo04H0oooo0P00000/0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo00X0oooo000:0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00H0oooo00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0:0?ooo`002P3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`050?ooo`030000o`3oool0oooo02/0oooo00<000000?ooo`3oool02P3oool000X0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo00X0oooo
000:0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool0;03oool00`000000oooo0?oo
o`0:0?ooo`002P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo02`0oooo00<00000
0?ooo`3oool02P3oool000X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0]0?oo
o`030000003oool0oooo00X0oooo000:0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0:0?ooo`002P3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000
o`3oool0oooo02h0oooo00<000000?ooo`3oool02P3oool000T0oooo00<000000?ooo`3oool0203o
ool4000003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0C0?ooo`050000003o
ool0oooo0?ooo`000?l0<@3oool00`000000oooo0?ooo`0:0?ooo`002@3oool00`000000oooo0?oo
o`090?ooo`T00000=@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01<0oooo00@0
00000?ooo`3oool0003o<P3oool00`000000oooo0?ooo`0:0?ooo`002@3oool00`000000oooo0?oo
o`0:0?ooo`l00000;P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`000?l0=03oool00`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?ooo`0:
0?ooo`<0000000<0fKfn0000000000000P3SXhd3000000@0aT`K1000000Z0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0503oool00`000000003o0?ooo`0d0?ooo`030000003oool0
oooo00T0oooo00090?ooo`030000003oool0oooo00/0oooo100000000`3I_Kh00000000000030>>S
S@@000001036C1/00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool05@3oool00`000000003o0?ooo`0d0?ooo`030000003oool0oooo00T0oooo00090?ooo`03
0000003oool0oooo00`0oooo0P000000102oaMh000000=Vm_P3I_Kh3000000@0hj>=1@00000Y0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo00T0oooo00090?ooo`030000003oool0oooo00d0oooo0P0000000`2oaMh0
0000000000030=Vm_P8000001P3SXhd2000002P0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0F0?ooo`030000o`000000oooo03D0oooo00<000000?ooo`3oool02@3oool000T0oooo
00<000000?ooo`3oool03@3oool300000080_lGN00<000000=Vm_P3I_Kh00P3I_Kh2000000D0hj>=
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01H0oooo
00<0003o0?ooo`000000=P3oool00`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?oo
o`0>0?ooo`050000001l/?D000000000002oaMh00P0000040=Vm_P8000000`3SXhd00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05P3oool010000?l0oooo
0?ooo`00000f0?ooo`030000003oool0oooo00T0oooo00090?ooo`030000003oool0oooo00l0oooo
00@0000007b`m@1l/?D000000P2oaMh00`000000fKfn0=Vm_P030=Vm_P80000000<0hj>=0000003o
ool09P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01@0oooo0P000?l30?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool02@3oool000P0oooo00<000000?ooo`3oool0
4@3oool010000000O;3e07b`m@0000020;o5gP030000003I_Kh0fKfn00@0fKfn0P00000W0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool02@3oool000P0oooo00<000000?ooo`3oool0
4P3oool010000000O;3e07b`m@0000020;o5gP800000103I_Kh00`000000003o0?ooo`0V0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`040?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool02@3oool000P0oooo00<000000?ooo`3oool0
4P3oool200000080O;3e00D000000;o5gP2oaMh0_lGN000000030=Vm_P040000003oool0003o0000
obD0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo
00D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`090?ooo`00203oool00`000000
oooo0?ooo`0C0?ooo`8000000P1l/?D010000000_lGN0;o5gP2oaMh3000000@0oooo0P000?lS0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool04P3oool20000o`P0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`080?ooo`00203oool00`000000oooo0?ooo`0D0?ooo`05
0000001l/?D0O;3e07b`m@000000102oaMh00`000000oooo0?ooo`040?ooo`<0003o803oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0100oooo0P000?l:0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0203oool000P0oooo00<000000?ooo`3oool05@3oool01P000000
O;3e07b`m@1l/?D000000;o5gP8000002P3oool30000oad0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`080?ooo`00203oool00`000000oooo0?ooo`0F0?ooo`D000003`3oool40000
oaT0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0>0?ooo`<0003o3@3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo00P0oooo00080?ooo`030000003oool0oooo02h0
oooo10000?lE0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0303oool30000oa40
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`080?ooo`00203oool00`000000oooo
0?ooo`0b0?ooo`<0003o4P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo
0P000?lD0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0203oool000P0oooo00<0
00000?ooo`3oool0=@3oool40000o`h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`080?ooo`<0003o5P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00P0oooo0008
0?ooo`030000003oool0oooo03T0oooo0`000?l;0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01P3oool30000oaT0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`08
0?ooo`001`3oool00`000000oooo0?ooo`0m0?ooo`L0003o103oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00@0oooo0`000?lL0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0203oool000L0oooo00<000000?ooo`3oool0A03oool70000oaD0oooo00<0003o00000000
0?l01P000?lO0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0203oool000L0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0E0000o`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`080?ooo`001`3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo00L0oooo00070?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool01`3oool000L0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`070?oo
o`001`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00L0oooo00070?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool01`3oool000L0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`070?ooo`001`3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo00L0oooo00060?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01`3oool000H0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`070?ooo`001P3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00L0oooo00060?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool01`3oool000H0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`09
0?ooo`800000<P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00H0oooo00060?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool01P3oool000H0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`060?ooo`001P3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00H0oooo00060?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool01P3o
ool000H0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`060?ooo`001P3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo00H0oooo00050?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool01P3oool000D0oooo00<000000?ooo`3oool0B@3oool010000000oooo
0?ooo`3oool2000003`0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`060?ooo`00
1@3oool00`000000oooo0?ooo`190?ooo`040000003oool0oooo000003h0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`060?ooo`001@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0000003l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`050?ooo`001@3o
ool00`000000oooo0?ooo`190?ooo`800000@03oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo00D0oooo00050?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00D0oooo00050?ooo`030000003oool0oooo
04P0oooo0P0000110?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool01@3oool000D0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo000000110?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool01@3oool000D0oooo00<000000?ooo`3oool0A@3oool200000080oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00D0oooo
00050?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool01@3oool000@0oooo00<00000
0?ooo`3oool0@`3oool2000000D0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo00D0oooo00040?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool01@3oool000@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`050?ooo`00
103oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00D0oooo00040?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0n0?ooo`800000>@3o
ool00`000000oooo0?ooo`040?ooo`00103oool00`000000oooo0?ooo`0m0?ooo`8000002`3oool0
0`000000oooo0?ooo`0j0?ooo`@000000P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00@0oooo00040?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0g0?ooo`<000001`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
00@0oooo00040?ooo`030000003oool0oooo03X0oooo0P00000>0?ooo`030000003oool0oooo03@0
oooo0`00000;0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0103oool000@0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo
1000000?0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0103oool000@0oooo00<0
00000?ooo`3oool0=`3oool200000140oooo00<000000?ooo`3oool0;@3oool3000001@0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`040?ooo`00103oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0:@3oool4000001L0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`040?ooo`000`3oool00`000000oooo0?ooo`0e0?oo
o`800000503oool00`000000oooo0?ooo`0V0?ooo`<00000703oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo00@0oooo00030?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0R0?ooo`@00000803oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo00@0oooo00030?ooo`030000003oool0oooo0380oooo0P00000G0?ooo`030000
003oool0oooo01l0oooo0`00000U0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
103oool000<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01`0oooo0`00000Y0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0103o
ool000<0oooo00<000000?ooo`3oool0;`3oool2000001X0oooo00<000000?ooo`3oool0603oool4
000002d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`030?ooo`000`3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool05@3oool30000
0380oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`030?ooo`000`3oool00`000000
oooo0?ooo`0/0?ooo`8000007@3oool00`000000oooo0?ooo`0A0?ooo`@00000=P3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00<0oooo00030?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0>0?ooo`<00000>`3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00<0oooo00030?ooo`030000003oool0oooo02T0oooo0P00
000P0?ooo`030000003oool0oooo00/0oooo0`00000o0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool00`3oool000<0oooo00<000000?ooo`3oool09`3oool200000280oooo00<00000
0?ooo`3oool01`3oool4000004<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`03
0?ooo`000P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0103oool3000004P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`030?oo
o`000P3oool00`000000oooo0?ooo`0U0?ooo`8000009@3oool00`000000oooo0?ooo`04000004/0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`030?ooo`000P3oool00`000000oooo
0?ooo`0S0?ooo`8000009P3oool400000500oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`030?ooo`000P3oool00`000000oooo0?ooo`0C0?ooo`D000002@3oool2000002D0oooo1000
001D0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00`3oool00080oooo00<00000
0?ooo`3oool04@3oool2000000<0Rb@i00<000000<UfK`0000001`3oool00`000000oooo0?ooo`0R
0?ooo`<000000`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool00`3oool00080oooo00<000000?ooo`3oool03`3oool400000080Rb@i00@000000<Uf
K`39MVl0bGI_0P0000040?ooo`030000003oool0oooo0200oooo0`0000060?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`000P3oool00`00
0000oooo0?ooo`0>0?ooo`@000000P2;93T00`000000bGI_0<UfK`040<UfK`040000003oool00000
000001l0oooo100000090?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?ooo`0>0?ooo`<000000P2;93T00`00
0000bGI_0<UfK`030<UfK`@000007P3oool3000000d0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00020?ooo`030000003oool0oooo00d0
oooo0`00000208/T>@0300000039MVl0bGI_00<0bGI_00@000000>J]V03V[IP000006`3oool40000
0100oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0080oooo00020?ooo`030000003oool0oooo00d0oooo0`0000000`2;93T000000<UfK`040<UfK`03
0000003V[IP0iZfH0080iZfH00<000000?ooo`3oool05@3oool3000001@0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo00020?ooo`030000
003oool0oooo00`0oooo0`0000000`2;93T000000<UfK`030<UfK`800000103V[IP2000001<0oooo
1000000G0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`020?ooo`0000<0oooo0000003oool03P3oool20000000308/T>@000000bGI_00<0bGI_00<0
00000>J]V03V[IP00P3V[IP2000000030>gN``000000oooo00l0oooo0`00000K0?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`0000<0oooo
0000003oool03@3oool30000000408/T>@000000bGI_0<UfK`8000000`3V[IP2000000<0kMk300<0
00000?ooo`3oool02`3oool3000001h0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0080oooo00000`3oool000000?ooo`0=0?ooo`80000000D0Rb@i
00000039MVl0bGI_000000030>J]V0800000103]g/<00`000000oooo0?ooo`080?ooo`@000008@3o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3o
ool000030?ooo`000000oooo00`0oooo0P0000000`2;93T000000<UfK`0200000080iZfH0P000006
0>gN``030000003oool0oooo00D0oooo0`00000U0?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`0000<0oooo0000003oool0303oool30000
00040<UfK`000000iZfH0>J]V08000001`3]g/<2000000<0oooo1000000X0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`0000<0oooo0000
003oool02`3oool3000000030<UfK`000000iZfH008000001@3]g/<5000000040?ooo`0000000000
000002`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0040oooo00000`3oool000000?ooo`0;0?ooo`H000000`3]g/<:000002l0oooo00<000000?oo
o`3oool0G`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0040oooo00000`3oool0
00000?ooo`0:0?ooo`D0000000<0kMk30000000000002@00000b0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`010?ooo`0000<0oooo0000003oool0
2P3oool800000080oooo0`00000f0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`010?ooo`0000<0oooo0000003oool02@3oool3000000@0oooo1000
000i0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`010?ooo`0000<000000?ooo`3oool03@3oool3000003d0oooo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0040oooo00000`000000oooo0?ooo`090?oo
o`@00000@03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool00@3oool000030000003oool0oooo00H0oooo0`0000140?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`010?ooo`0000<000000?ooo`3oool0
0`3oool3000004L0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo0040oooo00000`000000oooo00000003000004X0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0040oooo0002000004h0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool10?ooo`0000<0oooo0000
003oool0C@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo01<0oooo0@0000010?oo
o`40oooo00020?ooo`800000C03oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0180
oooo0@0000010?ooo`40oooo00040?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
JP3oool00`000000oooo0?ooo`0A0?ooo`4000000@3oool10?ooo`001@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0403oool100000040oooo0@3o
ool000H0oooo0P0000180?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool03`3oool1
00000040oooo0@3oool000P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo00h0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool10?ooo`00
2P3oool2000004@0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0<0?ooo`400000
0@3oool10?ooo`00303oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool02`3oool100000040oooo0@3oool000d0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`40oooo000>0?oo
o`800000?`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00/0oooo0@0000010?oo
o`00403oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool02P3oool100000040oooo000A0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`090?ooo`4000000@3oool00180oooo0P00000k0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0203oool100000040oooo000D0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`070?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
00H0oooo0@0000010?ooo`005P3oool2000003L0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`050?ooo`4000000@3oool001P0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`006@3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool00`3oool100000040oooo000J
0?ooo`800000<`3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo0@000001
0?ooo`00703oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo07`0oooo00D000000?oo
o`3oool0oooo000000010?ooo`007@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
07`0oooo00<000000?ooo`3oool00P3oool1000000007P3oool2000002l0oooo00<000000?ooo`3o
ool0O@3oool010000000oooo0?ooo`3oool100000000803oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool00@0000000240oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`1o0?ooo`4000000@3oool1000000008P3oool2000002/0oooo00<0
00000?ooo`3oool0P03oool200000000903oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo07l0oooo0`00000002D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1k0?oo
o`@000000`3oool002H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1g0?ooo`@0
00001`3oool002L0oooo0P00000V0?ooo`030000003oool0oooo07<0oooo1000000;0?ooo`00:@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06l0oooo1000000?0?ooo`00:P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06/0oooo1000000C0?ooo`00:`3oool20000
0280oooo00<000000?ooo`3oool0IP3oool5000001L0oooo000]0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0HP3oool4000001`0oooo000^0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0GP3oool400000200oooo000_0?ooo`8000007P3oool00`000000oooo0?oo
o`1J0?ooo`@00000903oool00340oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1F
0?ooo`@00000:03oool00380oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1B0?oo
o`@00000;03oool003<0oooo0P00000J0?ooo`030000003oool0oooo04h0oooo1000000`0?ooo`00
=@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04T0oooo1@00000d0?ooo`00=P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000000i0?ooo`00=`3oool2
000001H0oooo00<000000?ooo`3oool0@@3oool4000003d0oooo000i0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0?P3oool400000440oooo000j0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0>P3oool4000004D0oooo000k0?ooo`8000004@3oool00`000000oooo
0?ooo`0f0?ooo`@00000B@3oool003d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0a0?ooo`D00000C@3oool003h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0]
0?ooo`@00000DP3oool003l0oooo0P00000=0?ooo`030000003oool0oooo02T0oooo1000001F0?oo
o`00@@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02D0oooo1000001J0?ooo`00
@P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0240oooo1000001N0?ooo`00@`3o
ool2000000T0oooo00<000000?ooo`3oool07@3oool400000680oooo00150?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool06@3oool4000006H0oooo00160?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0503oool5000006X0oooo00170?ooo`8000001@3oool00`000000
oooo0?ooo`0@0?ooo`@00000K`3oool004T0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0<0?ooo`@00000L`3oool004X0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`@00000
M`3oool004/0oooo0P0000000`3oool000000?ooo`050?ooo`@00000N`3oool004d0oooo0P000002
0?ooo`@00000O`3oool004h0oooo0`0000230?ooo`00\
\>"],
  ImageRangeCache->{{{0, 211.25}, {286.938, 0}} -> {0.126312, -0.000600504, \
0.00342982, 0.00342982}}]
}, Open  ]],

Cell["\<\
Here, a number of arrowcones are placed on a curve by mapping onto a list of \
fractional lengths. Since the curve is rather long, the head length must be \
reduced.\
\>", "Text"],

Cell[BoxData[
    \(\(Module[\[IndentingNewLine]{c}, \[IndentingNewLine]c[2] = 
          ParametricDraw3D[
            Evaluate[\(curve[1, 2, 1/2]\)[\[Theta]]], {\[Theta], 0, 
              4  \[Pi]}]; \
\[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{c[
              2], \[IndentingNewLine]Black, \(ArrowCurve3D[c[2], #, 
                  HeadLength3D \[Rule] 0.02] &\) /@ 
              Range[0.2, 1, 0.2]}, \[IndentingNewLine]PlotRange \[Rule] 
            All]];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(Clear[curve]\)], "Input",
  CellLabel->"In[5]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{515, 639},
WindowMargins->{{117, Automatic}, {Automatic, -55}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 59, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1838, 56, 376, 14, 50, "Usage",
      CellTags->"Function?"],
    Cell[2217, 72, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 52241, 1292}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 59, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1838, 56, 376, 14, 50, "Usage",
  CellTags->"Function?"],
Cell[2217, 72, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2314, 77, 67, 0, 41, "MathCaption"],
Cell[2384, 79, 256, 6, 75, "MathCaption"],
Cell[2643, 87, 59, 0, 41, "MathCaption"],
Cell[2705, 89, 187, 6, 41, "MathCaption"],
Cell[2895, 97, 174, 5, 58, "MathCaption"],
Cell[3072, 104, 568, 22, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3665, 130, 33, 0, 39, "ExampleSection"],
Cell[3701, 132, 97, 2, 29, "Input"],
Cell[3801, 136, 60, 0, 25, "Text"],
Cell[3864, 138, 151, 3, 29, "Input"],

Cell[CellGroupData[{
Cell[4040, 145, 597, 12, 209, "Input"],
Cell[4640, 159, 46093, 1088, 294, 7697, 609, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[50748, 1250, 189, 4, 42, "Text"],
Cell[50940, 1256, 511, 10, 189, "Input"],
Cell[51454, 1268, 69, 2, 29, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

