(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19929,        458]*)
(*NotebookOutlinePosition[     21012,        495]*)
(*  CellTagsIndexPosition[     20937,        489]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ArrowLine", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["ArrowLine",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(points, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " has the same usage as Line but will put an arrowhead at the position of \
the last point."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
ArrowLine is intended for lines with many points. For two-point lines use the \
regular Arrow routine.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell[TextData[{
  "The regular ",
  ButtonBox["Arrow",
    ButtonData:>{"Graphics`Arrow`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  " options can be passed to the Arrow routine."
}], "MathCaption"],

Cell[TextData[{
  "The meaning of ",
  Cell[BoxData[
      \(HeadScaling \[Rule] Relative\)]],
  " is taken to mean relative to the length of the curve."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Arrow",
    ButtonData:>{"Graphics`Arrow`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowCurve",
    ButtonData:>{"ArrowCurve"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowTangent",
    ButtonData:>{"ArrowTangent"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ProportionalArrow",
    ButtonData:>{"ProportionalArrow"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example  ", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Here, an ArrowLine is used to draw a broken arrow around an obstacle.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pts = {{1.01046, \(-7.00355\)}, {7.56105, \(-6.79449\)}, {7.49136, 
            7.00355}, {0.59234, 7.07324}};\)\), "\n", 
    \(\(Show[
        Graphics[\n\t{AbsolutePointSize[5], Point[{0, \(-7\)}], 
            Point[{0, 7}], \[IndentingNewLine]LightSteelBlue, 
            Rectangle[{\(-5\), \(-5\)}, {5, 5}], Black, 
            ArrowLine[pts, HeadCenter \[Rule] 1/2]}], \n\n
        AspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] {{\(-10\), 10}, {\(-10\), 10}}, 
        Background \[Rule] Linen, \n{}];\)\)}], "Input",
  CellLabel->"In[96]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.05 0.5 0.05 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.025 0 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.025 0 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 0 0 r
5 Mabswid
.5 .15 Mdot
.5 .85 Mdot
.69 .769 .871 r
.25 .25 m
.25 .75 L
.75 .75 L
.75 .25 L
F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
.55052 .14982 m
.87805 .16028 L
.87457 .85018 L
.52962 .85366 L
s
.87457 .85018 m
.52962 .85366 L
s
% Start of user PostScript
7.49136 7.00355 0.59234 7.07324 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[96]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3j
l>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40
oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`
iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3o
ool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V
803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?oo
o`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP
0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo
003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00
n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool0
0?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803j
l>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool008h0n_3V0`00002>0?[`iP40
oooo002=0?[`iPD00000303jl>H@00000740n_3V0@3oool008d0n_3V1@00000L0?[`iQl00000DP3j
l>H10?ooo`00S@3jl>H5000003/0n_3V8000000b0?[`iP40oooo002>0?[`iP<00000G03jl>H@0000
0280n_3V0@3oool00?`0n_3V00<000000?[`iP3jl>H0803jl>H10?ooo`00o03jl>H00`000000n_3V
0?[`iP0P0?[`iP40oooo003l0?[`iP030000003jl>H0n_3V0200n_3V0@3oool00?`0n_3V00<00000
0?[`iP3jl>H0803jl>H10?ooo`00o03jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo003l0?[`iP03
0000003jl>H0n_3V0200n_3V0@3oool00?`0n_3V00<000000?[`iP3jl>H0803jl>H10?ooo`00o03j
l>H00`000000n_3V0?[`iP0P0?[`iP40oooo003l0?[`iP030000003jl>H0n_3V0200n_3V0@3oool0
0?`0n_3V00<000000?[`iP3jl>H0803jl>H10?ooo`00o03jl>H00`000000n_3V0?[`iP0P0?[`iP40
oooo003l0?[`iP030000003jl>H0n_3V0200n_3V0@3oool00?`0n_3V00<000000?[`iP3jl>H0803j
l>H10?ooo`00o03jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo003l0?[`iP030000003jl>H0n_3V
0200n_3V0@3oool00?`0n_3V00<000000?[`iP3jl>H0803jl>H10?ooo`00o03jl>H00`000000n_3V
0?[`iP0P0?[`iP40oooo003l0?[`iP030000003jl>H0n_3V0200n_3V0@3oool00?`0n_3V00<00000
0?[`iP3jl>H0803jl>H10?ooo`00o03jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo003l0?[`iP03
0000003jl>H0n_3V0200n_3V0@3oool00?`0n_3V00<000000?[`iP3jl>H0803jl>H10?ooo`00o03j
l>H00`000000n_3V0?[`iP0P0?[`iP40oooo003l0?[`iP030000003jl>H0n_3V0200n_3V0@3oool0
0?`0n_3V00<000000?[`iP3jl>H0803jl>H10?ooo`00o03jl>H00`000000n_3V0?[`iP0P0?[`iP40
oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3j
l>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P
0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00
/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V
0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo0017
0?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`00
0000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40
oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3j
l>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P
0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00
/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V
0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo0017
0?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`00
0000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40
oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3j
l>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P
0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00
/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V
0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo0017
0?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`00
0000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40
oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3j
l>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P
0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00
/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V
0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo0017
0?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`00
0000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40
oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3j
l>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P
0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00
/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V
0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo0017
0?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`00
0000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40
oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3j
l>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P
0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00
/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V
0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo0017
0?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`00
0000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40
oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3j
l>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P
0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00
/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V
0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo0017
0?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`00
0000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40
oooo00170?[`iY00/<CN9@3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN9@3j
l>H00`000000n_3V0?[`iP0P0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q
0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00
/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V
0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo0017
0?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`00
0000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903j
l>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q
0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00
/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V
0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo0017
0?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`00
0000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903j
l>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q
0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00
/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V
0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo0017
0?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`00
0000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903j
l>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q
0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00
/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V
0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo0017
0?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`00
0000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903j
l>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q
0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00
/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V
0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo0017
0?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`00
0000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903j
l>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q
0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00
/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V
0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo0017
0?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`00
0000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903j
l>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q
0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00
/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V
0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo0017
0?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`00
0000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903j
l>H00`000000n_3V0?[`iP0Q0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q
0?[`iP40oooo00170?[`iY00/<CN903jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo003k0?[`iP03
0000003jl>H0n_3V0240n_3V0@3oool00?/0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00n`3j
l>H00`000000n_3V0?[`iP0Q0?[`iP40oooo003k0?[`iP030000003jl>H0n_3V0240n_3V0@3oool0
0?/0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00n`3jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo003k0?[`iP030000003jl>H0n_3V0240n_3V0@3oool00?/0n_3V00<000000?[`iP3jl>H08@3j
l>H10?ooo`00n`3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo003k0?[`iP030000003jl>H0n_3V
0240n_3V0@3oool00?/0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00n`3jl>H00`000000n_3V
0?[`iP0Q0?[`iP40oooo003k0?[`iP030000003jl>H0n_3V0240n_3V0@3oool00?/0n_3V00<00000
0?[`iP3jl>H08@3jl>H10?ooo`00n`3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo003k0?[`iP03
0000003jl>H0n_3V0240n_3V0@3oool00?/0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00n`3j
l>H00`000000n_3V0?[`iP0Q0?[`iP40oooo003k0?[`iP030000003jl>H0n_3V0240n_3V0@3oool0
0?/0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00n`3jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo003k0?[`iP030000003jl>H0n_3V0240n_3V0@3oool00?/0n_3V00<000000?[`iP3jl>H08@3j
l>H10?ooo`00n`3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo003k0?[`iP030000003jl>H0n_3V
0240n_3V0@3oool008h0n_3V0`00000C0?[`iP<00000E03jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo002=0?[`iPD000003P3jl>H5000005H0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00S@3j
l>H5000000T0n_3V2000000W0?[`iS8000008`3jl>H10?ooo`00S@3jl>H5000000H0n_3V<P00001E
0?[`iP40oooo002>0?[`iP<000002@3jl>H8000007d0n_3V0@3oool009h0n_3V1P00001k0?[`iP40
oooo002Q0?[`iPD00000N@3jl>H10?ooo`00Y@3jl>H2000007P0n_3V0@3oool00?l0n_3V803jl>H1
0?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3j
l>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40
oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`
iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3o
ool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V
803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?oo
o`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP
0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo
003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00
n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool0
0?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.0001, -10.0001, 0.0696871, \
0.0696871}}]
}, Open  ]],

Cell["This extracts the Line primitive from a ParametricPlot.", "Text"],

Cell[BoxData[
    \(\(g = ParametricDraw[{x, \@x}, {x, 0, 8}];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
This converts the Line to an ArrowLine, without and with additional \
options.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{g /. 
            Line \[Rule] ArrowLine}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Background \[Rule] 
          Linen];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{g /. 
            Line \[Rule] \((ArrowLine[#, HeadCenter \[Rule] 1/2, 
                    HeadScaling \[Rule] Relative, 
                    HeadLength \[Rule] 
                      0.1] &)\)}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Background \[Rule] 
          Linen];\)\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(Clear[pts, g]\)], "Input",
  CellLabel->"In[7]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{515, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 56, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1835, 56, 395, 15, 50, "Usage",
      CellTags->"Function?"],
    Cell[2233, 73, 158, 4, 58, "MathCaption",
      CellTags->"Function?"],
    Cell[2394, 79, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 20615, 476}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 56, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1835, 56, 395, 15, 50, "Usage",
  CellTags->"Function?"],
Cell[2233, 73, 158, 4, 58, "MathCaption",
  CellTags->"Function?"],
Cell[2394, 79, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2491, 84, 198, 6, 41, "MathCaption"],
Cell[2692, 92, 172, 5, 58, "MathCaption"],
Cell[2867, 99, 465, 18, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3357, 121, 35, 0, 39, "ExampleSection"],
Cell[3395, 123, 97, 2, 29, "Input"],
Cell[3495, 127, 93, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[3613, 133, 584, 11, 229, "Input"],
Cell[4200, 146, 14677, 275, 294, 1568, 108, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[18892, 424, 71, 0, 25, "Text"],
Cell[18966, 426, 101, 2, 32, "Input"],
Cell[19070, 430, 102, 3, 25, "Text"],
Cell[19175, 435, 248, 5, 89, "Input"],
Cell[19426, 442, 402, 8, 109, "Input"],
Cell[19831, 452, 70, 2, 29, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

