(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     76828,       1436]*)
(*NotebookOutlinePosition[     77836,       1471]*)
(*  CellTagsIndexPosition[     77760,       1465]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ArrowLine3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["ArrowLine3D",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(points, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " is a Line with an arrowcone at the end."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell[TextData[{
  "The regular ",
  ButtonBox["Arrow3D",
    ButtonData:>{"Arrow3D"},
    ButtonStyle->"AddOnsLink"],
  " options can be passed to the Arrow3D routine."
}], "MathCaption"],

Cell[TextData[{
  "The meaning of ",
  Cell[BoxData[
      \(HeadScaling3D \[Rule] Relative\)]],
  " is taken to mean relative to the length of the curve."
}], "MathCaption"],

Cell[TextData[{
  "ParametricPlot3D with one iterator does not produce a single Line but \
multiple connected two point Lines. ",
  ButtonBox["ToSingleLine",
    ButtonData:>{"ToSingleLine"},
    ButtonStyle->"AddOnsLink"],
  " will convert the output to a single Line. (The two dimensional \
ParametricPlot does produce a single Line.)"
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Arrow3D",
    ButtonData:>{"Arrow3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowCurve3D",
    ButtonData:>{"ArrowCurve3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowTangent3D",
    ButtonData:>{"ArrowTangent3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ProportionalArrow3D",
    ButtonData:>{"ProportionalArrow3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Arrow",
    ButtonData:>{"Graphics`Arrow`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  " ."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Here is a series of points along a helix. ArrowLine3D turns them into a \
curved arrow.\
\>", "Text"],

Cell[BoxData[
    \(\(pts = 
        Table[{Cos[t], Sin[t], t}, {t, 0, 2  \[Pi], 
            2  \[Pi]/50}];\)\)], "Input",
  CellLabel->"In[94]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{ArrowLine3D[pts, 
            HeadLength3D \[Rule] 0.05]}, \[IndentingNewLine]PlotRange \[Rule] 
          All];\)\)], "Input",
  CellLabel->"In[95]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.19247 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.626878 2.26954 -0.0770632 2.26954 [
[ 0 0 0 0 ]
[ 1 2.19247 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08268 .21672 m
0 1.89883 L
s
0 1.89883 m
.35736 2.19247 L
s
.35736 2.19247 m
.38043 .56365 L
s
.38043 .56365 m
.08268 .21672 L
s
.6482 0 m
.92198 .37193 L
s
.92198 .37193 m
1 2.03102 L
s
1 2.03102 m
.67668 1.71198 L
s
.67668 1.71198 m
.6482 0 L
s
.08268 .21672 m
0 1.89883 L
s
0 1.89883 m
.67668 1.71198 L
s
.67668 1.71198 m
.6482 0 L
s
.6482 0 m
.08268 .21672 L
s
.38043 .56365 m
.92198 .37193 L
s
.92198 .37193 m
1 2.03102 L
s
1 2.03102 m
.35736 2.19247 L
s
.35736 2.19247 m
.38043 .56365 L
s
0 0 m
1 0 L
1 2.19247 L
0 2.19247 L
closepath
clip
newpath
.5 Mabswid
.70619 .739 m
.67956 .78291 L
s
.72958 .69311 m
.70619 .739 L
s
.74937 .64547 m
.72958 .69311 L
s
.67956 .78291 m
.65008 .82466 L
s
.76526 .59636 m
.74937 .64547 L
s
.65008 .82466 m
.61819 .86408 L
s
.77697 .54606 m
.76526 .59636 L
s
.61819 .86408 m
.58434 .90106 L
s
.78432 .49491 m
.77697 .54606 L
s
.78715 .44325 m
.78432 .49491 L
s
.58434 .90106 m
.54902 .9355 L
s
.78539 .39145 m
.78715 .44325 L
s
.77905 .33991 m
.78539 .39145 L
s
.54902 .9355 m
.51271 .96737 L
s
.7682 .28902 m
.77905 .33991 L
s
.75298 .23918 m
.7682 .28902 L
s
.51271 .96737 m
.47594 .99664 L
s
.47594 .99664 m
.43922 1.02335 L
s
.43922 1.02335 m
.40307 1.04755 L
s
.40307 1.04755 m
.36801 1.06934 L
s
.36801 1.06934 m
.33456 1.08885 L
s
.33456 1.08885 m
.30321 1.10624 L
s
.30321 1.10624 m
.27446 1.1217 L
s
.27446 1.1217 m
.24876 1.13546 L
s
.24876 1.13546 m
.22654 1.14778 L
s
.22654 1.14778 m
.20821 1.15893 L
s
.20821 1.15893 m
.1941 1.16921 L
s
.1941 1.16921 m
.18451 1.17897 L
s
.18451 1.17897 m
.1797 1.18853 L
s
.1797 1.18853 m
.17982 1.19827 L
s
.17982 1.19827 m
.18499 1.20855 L
s
.18499 1.20855 m
.19521 1.21974 L
s
.19521 1.21974 m
.21043 1.2322 L
s
.21043 1.2322 m
.23049 1.24629 L
s
.23049 1.24629 m
.25514 1.26235 L
s
.25514 1.26235 m
.28405 1.28068 L
s
.28405 1.28068 m
.31679 1.30158 L
s
.31679 1.30158 m
.35286 1.32526 L
s
.35286 1.32526 m
.39167 1.35193 L
s
.39167 1.35193 m
.43257 1.38172 L
s
.43257 1.38172 m
.47486 1.41472 L
s
.47486 1.41472 m
.51782 1.45095 L
s
.51782 1.45095 m
.56069 1.49037 L
s
.56069 1.49037 m
.6027 1.53289 L
s
.729 .552 .653 r
.79826 1.84153 m .74333 1.69271 L .72203 1.70212 L closepath p F P
0 g
s
.584 .476 .697 r
.79826 1.84153 m .76375 1.68621 L .74333 1.69271 L closepath p F P
0 g
s
.851 .584 .533 r
.79826 1.84153 m .72203 1.70212 L .70788 1.71088 L closepath p F P
0 g
s
.6027 1.53289 m
.64311 1.57836 L
s
.265 .261 .667 r
.79826 1.84153 m .77557 1.68508 L .76375 1.68621 L closepath p F P
0 g
s
.64311 1.57836 m
.68122 1.62658 L
s
.841 .393 0 r
.79826 1.84153 m .70788 1.71088 L .7063 1.71567 L closepath p F P
0 g
s
.68122 1.62658 m
.71635 1.67731 L
s
.919 .747 .652 r
.79826 1.84153 m .76009 1.69858 L .77421 1.68979 L closepath p F P
0 g
s
.772 .673 .754 r
.79826 1.84153 m .73858 1.70809 L .76009 1.69858 L closepath p F P
0 g
s
.616 .599 .81 r
.79826 1.84153 m .718 1.71462 L .73858 1.70809 L closepath p F P
0 g
s
.261 .423 .835 r
.79826 1.84153 m .7063 1.71567 L .718 1.71462 L closepath p F P
0 g
s
.855 .619 .081 r
.79826 1.84153 m .77421 1.68979 L .77557 1.68508 L closepath p F P
0 g
s
.71635 1.67731 m
.73531 1.70912 L
s
.25 Mabswid
.6482 0 m
.92198 .37193 L
s
.92198 .37193 m
1 2.03102 L
s
1 2.03102 m
.67668 1.71198 L
s
.67668 1.71198 m
.6482 0 L
s
.08268 .21672 m
0 1.89883 L
s
0 1.89883 m
.67668 1.71198 L
s
.67668 1.71198 m
.6482 0 L
s
.6482 0 m
.08268 .21672 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[95]:=",
  ImageSize->{131.313, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002300017b000`400?l00000o`00003oD`3oool2
000002h0oooo001A0?ooo`80000000<0oooo000000000000;@3oool004h0oooo0`0000030?ooo`80
0000;@3oool004/0oooo0`0000060?ooo`030000003oool0000002`0oooo00190?ooo`8000002@3o
ool010000000oooo0?ooo`00000[0?ooo`00AP3oool3000000/0oooo00D000000?ooo`3oool0oooo
0000000Z0?ooo`00@`3oool3000000h0oooo00D000000?ooo`3oool0oooo0000000Z0?ooo`00@@3o
ool200000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0W0?ooo`00?P3oool3
000001<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`00>`3oool30000
01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`00>@3oool2000001T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`00=P3oool3000001/0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`00<`3oool3000001h0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?ooo`00<@3oool200000240oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0R0?ooo`00;P3oool3000002<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0R0?ooo`00;03oool2000002H0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0Q0?ooo`00:@3oool3000002P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0P0?ooo`009P3oool3000002/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0P0?ooo`00903oool2000002h0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0O0?ooo`008@3oool300000300oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0N0?ooo`007P3oool3000003<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0M0?ooo`00703oool2000003H0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0M0?ooo`006@3oool3000003P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0L0?ooo`005P3oool3000003/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0K
0?ooo`00503oool2000003h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0J0?oo
o`004@3oool300000400oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0J0?ooo`00
3P3oool3000004<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0I0?ooo`00303o
ool2000004H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0H0?ooo`002P3oool2
000004T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`002P3oool20000
04T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`002P3oool00`000000
oooo000000180?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool000X0oooo
00@000000?ooo`3oool00000A`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool05@3oool000X0oooo00@000000?ooo`3oool00000A`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool000X0oooo
00D000000?ooo`3oool0oooo000000160?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0D0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01<0oooo000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04P3o
ool000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`002P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo000:0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0403oool000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0?0?ooo`002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo0009
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool000T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`002@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool000T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`002@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00090?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool02@3oool000T0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`090?ooo`002@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`8000002P3oool000T0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool02`3oool3000000030?ooo`000000oooo00T0oooo00090?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00P0oooo0`0000040?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00H0oooo0P0000070?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0
oooo0`0000090?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<00000
303oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool03P3oool3000000l0oooo00<000000?ooo`3oool0203o
ool000T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00/0oooo1000000A0?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`080?ooo`<000000`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`060?ooo`8000001P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`030?ooo`<00000203oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`03000000/0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo02`0oooo0`00000>0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3oool0
00P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0X0?ooo`@00000403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0903oool3000000<0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0803oool3000000H0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool07P3oool2000000T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool06P3oool3000000/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool05P3oool3000000h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool04P3oool300000140oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
3P3oool3000001@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00L0oooo00080?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02P3o
ool3000001L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool2
000001X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00L0oooo00080?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool30000
01`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00L0oooo00080?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00`00000O0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`00
203oool00`000000oooo0?ooo`0V0?ooo`8000008P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00L0oooo00080?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo00070?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00H0oooo00070?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01P3oool0
00L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`060?ooo`001`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo00070?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00H0oooo00070?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3o
ool000L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`001`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0R0?ooo`050000003oool0oooo0?ooo`0000007`3oool00`000000oooo0?ooo`060?ooo`00
1`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0280oooo00D000000?ooo`3oool0
oooo0000000O0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool08P3oool010000000oooo0?ooo`00000P0?ooo`030000003oool0oooo00H0
oooo00070?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0000000Q0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool08P3oool200000280oooo00<000000?ooo`3oool01P3oool000L0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0R0?ooo`8000008`3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0240oooo0P00000T0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool08@3oool2000002@0oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0000002@0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000002@0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0O0?ooo`050000003oool0
oooo0?ooo`000000903oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo01l0oooo00D000000?ooo`3oool0oooo0000000T0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo01H0oooo0P00000;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0A0?ooo`800000403oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool000H0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0103oool000D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`040?ooo`00
1@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`080?ooo`8000006@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00@0oooo00050?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo00@0oooo0P00000M0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`020?ooo`8000007`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo0005
0?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0:03oool0
10000000oooo00000000000R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103o
ool000D0oooo00<000000?ooo`3oool0:03oool2000002@0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0W0?ooo`8000009P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo02D0
oooo0P0000000`3oool000000?ooo`0U0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0103oool000D0oooo00<000000?ooo`3oool08`3oool2000000<0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003o
ool0oooo0240oooo0P0000050?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0O0?ooo`8000001`3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0103oool0
00D0oooo00<000000?ooo`3oool07@3oool2000000T0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo00050?ooo`030000003oool0oooo01/0
oooo0P00000;0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`040?ooo`001@3oool00`000000oooo0?ooo`0I0?ooo`8000003@3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool000D0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0?ooo`0G
0?ooo`800000403oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`030?oo
o`00103oool00`000000oooo0?ooo`0D0?ooo`8000004`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00<0oooo00040?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool0
00@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`030?ooo`00103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00040?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`030?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`800000
4P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
0`3oool000@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`00103oool0
0`000000oooo0?ooo`0H0?ooo`8000003`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`030?ooo`00103oool00`000000oooo0?ooo`0K0?ooo`800000303oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool000@0oooo
00<000000?ooo`3oool07@3oool2000000X0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00040?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0803oool2000000L0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00040?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool000<0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`000`3oool00`000000oooo0?ooo`0U0?ooo`800000
0`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
0P3oool000<0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00000V0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool000<0oooo00<000000?ooo`3oool0:03o
ool3000002H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`000`3oool0
0`000000oooo0?ooo`0Z0?ooo`8000009@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo0080oooo00030?ooo`030000003oool0oooo02X0oooo00@000000?ooo`00000000008`3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00030?ooo`030000003oool0oooo
02X0oooo00D000000?ooo`3oool0oooo0000000R0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool00P3oool000<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?oo
o`800000803oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00030?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool000<0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`020?ooo`000`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo0080oooo00030?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool0
00<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`000`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00030?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool00P3oool000<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0<0?ooo`8000005`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo0003
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool000<0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0?0?ooo`800000503oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0080oooo00030?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool00P3oool000<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`010?ooo`000`3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0503oool2000000l0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0040oooo00020?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00@3oool00080oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`010?oo
o`000P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0040oooo00020?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo0040oooo00020?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00@3oool00080
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0R
0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`010?ooo`000P3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02<0oooo00@000000?ooo`3oool000009P3o
ool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo02<0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`010?ooo`000P3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`0000009P3oool0
0`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02D0oooo0P00000V0?ooo`030000003oool0oooo0040oooo00020?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`4000000@3oool10?ooo`00
0P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02H0oooo0P00000V0?ooo`400000
0@3oool10?ooo`000P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02H0oooo0P00
000V0?ooo`4000000@3oool10?ooo`0000<0oooo0000003oool0;03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0000002D0oooo0@0000010?ooo`40oooo00000`3oool000000?ooo`0/0?oo
o`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000903oool100000040oooo0@3oool0
00030?ooo`000000oooo02`0oooo00<000000?ooo`3oool09P3oool01@000000oooo0?ooo`3oool0
000002<0oooo0@0000010?ooo`40oooo00000`3oool000000?ooo`0/0?ooo`030000003oool0oooo
02H0oooo00D000000?ooo`3oool0oooo0000000S0?ooo`4000000@3oool10?ooo`0000<0oooo0000
003oool0;03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0803oool100000040oooo0@3oool000030?ooo`000000oooo02`0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo1000000J0?ooo`40
00000@3oool10?ooo`0000<0oooo0000003oool0;03oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`000000000009Ei/P03000001X0oooo0@0000010?ooo`40
oooo00000`3oool000000?ooo`0/0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
0`3oool30000000309Ei/P0000000000008000006P3oool100000040oooo0@3oool000030?ooo`00
0000oooo02`0oooo00<000000?ooo`3oool09@3oool2000000<0oooo0P000000203IUHP000000000
00000000aJc10000003[_jH000006P3oool100000040oooo0@3oool000030?ooo`000000oooo02`0
oooo00<000000?ooo`3oool08@3oool400000080oooo00<000000?ooo`3oool00`0000000`2MVLl0
00000<F/`@020<F/`@<000006@3oool100000040oooo0@3oool000030?ooo`000000oooo02`0oooo
00<000000?ooo`3oool07P3oool3000000L0oooo00<000000?ooo`3oool00P00000209fIc`030000
0035[<40aJc100<000006@3oool100000040oooo0@3oool000030?ooo`000000oooo02`0oooo00<0
00000?ooo`3oool06P3oool4000000/0oooo00@000000?ooo`00000000000P2MVLl00`000000aJc1
0<F/`@03000001T0oooo0@0000010?ooo`40oooo00000`3oool000000?ooo`0/0?ooo`030000003o
ool0oooo01L0oooo0`00000@0?ooo`040000003oool0000000000080WIW?00<000000<F/`@000000
0P00000I0?ooo`4000000@3oool10?ooo`0000<0oooo0000003oool0;03oool00`000000oooo0?oo
o`0C0?ooo`@00000503oool01P000000oooo000000000000WIW?00000080aJc10P00000I0?ooo`40
00000@3oool10?ooo`0000<0oooo0000003oool0;03oool00`000000oooo0?ooo`0@0?ooo`<00000
6@3oool00`000000oooo0000000209fIc`0400000035[<400000000001T0oooo0@0000010?ooo`40
oooo00000`3oool000000?ooo`0/0?ooo`030000003oool0oooo00`0oooo1000000M0?ooo`<00000
00<0WIW?00000035[<400P00000I0?ooo`4000000@3oool10?ooo`0000<0oooo0000003oool0;03o
ool00`000000oooo0?ooo`090?ooo`<000008P3oool30000000309fIc`000000000000800000603o
ool100000040oooo0@3oool000030?ooo`000000oooo02`0oooo00<000000?ooo`3oool01@3oool4
000002H0oooo0P0000000`2MVLl000000<F/`@02000001P0oooo0@0000010?ooo`40oooo00000`3o
ool000000?ooo`0/0?ooo`030000003oool0oooo0080oooo0`00000[0?ooo`80000000@0WIW?0000
0000000000006@3oool100000040oooo00000`3oool000000?ooo`0/0?ooo`D00000;`3oool50000
01T0oooo0@0000010?ooo`0000<0oooo0000003oool0:P3oool3000003@0oooo1000000I0?ooo`40
00000@3oool000030?ooo`000000oooo02H0oooo100000020?ooo`030000003oool0oooo03<0oooo
0`00000I0?ooo`4000000@3oool000030000003oool0oooo0280oooo100000060?ooo`030000003o
ool0oooo03@0oooo0`00000H0?ooo`4000000@3oool000030000003oool0oooo01l0oooo0`00000:
0?ooo`030000003oool0oooo03@0oooo0`00000H0?ooo`4000000@3oool000030000003oool0oooo
01/0oooo1000000=0?ooo`030000003oool0oooo03D0oooo0P00000H0?ooo`4000000@3oool00003
0000003oool0oooo01P0oooo0`00000A0?ooo`030000003oool0oooo03H0oooo0P00000G0?ooo`40
00000@3oool000030000003oool0oooo01@0oooo1000000D0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0503oool100000040oooo00000`000000oooo0?ooo`0A0?ooo`<00000603o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01<0oooo0@0000010?ooo`0000<00000
0?ooo`3oool03@3oool4000001/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0B
0?ooo`4000000@3oool000030000003oool0oooo00X0oooo0`00000O0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool04@3oool100000040oooo00000`000000oooo0?ooo`060?ooo`@0
00008P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0100oooo0@0000010?ooo`00
00<000000?ooo`3oool00`3oool3000002H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0?0?ooo`4000000@3oool000030000003oool0000000<00000:@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00h0oooo0@0000010?ooo`000P00000]0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool03@3oool100000040oooo00000`3oool000000?ooo`0/0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0303oool100000040oooo00020?ooo`80
0000:`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`00
103oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
2P3oool100000040oooo00050?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`090?ooo`4000000@3oool000H0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`001`3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool01`3oool10000
0040oooo00080?ooo`800000903oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00L0
oooo0@00000000X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo00H0oooo0@00000000/0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo00D0oooo0@00000000`0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00@0oooo0@00000000d0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00<0oooo0@00000000h0
oooo0P00000N0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool00P3oool100000000
403oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo04d0oooo00@000000?ooo`3oool0
oooo0@0000000140oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo00400000000B0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0C`3o
ool100000040oooo0@00000001<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1@
0?ooo`800000000D0?ooo`800000603oool00`000000oooo0?ooo`1@0?ooo`800000000F0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0C03oool400000080oooo000G0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0B03oool4000000H0oooo000H0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0A03oool4000000X0oooo000I0?ooo`8000004`3oool0
0`000000oooo0?ooo`100?ooo`@000003P3oool001/0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0l0?ooo`@000004P3oool001`0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0h0?ooo`@000005P3oool001d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0d0?ooo`@000006P3oool001h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0`0?ooo`@000007P3oool001l0oooo0P00000=0?ooo`030000003oool0oooo02`0oooo1000000R
0?ooo`008@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02P0oooo1000000V0?oo
o`008P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02@0oooo1000000Z0?ooo`00
8`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo1000000^0?ooo`00903o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo1000000b0?ooo`009@3oool2
000000L0oooo00<000000?ooo`3oool0603oool4000003H0oooo000W0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0503oool4000003X0oooo000X0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0403oool4000003h0oooo000Y0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0303oool400000480oooo000Z0?ooo`050000003oool0oooo0?ooo`000000
2P3oool4000004H0oooo000[0?ooo`80000000<0oooo0000003oool01@3oool4000004X0oooo000]
0?ooo`8000000P3oool4000004h0oooo000^0?ooo`<00000DP3oool00001\
\>"],
  ImageRangeCache->{{{0, 130.313}, {286.875, 0}} -> {0.276211, 0.0319747, \
0.00338127, 0.00338127}}]
}, Open  ]],

Cell["\<\
ParametricPlot3D does not produce a single Line, but multiple connected two \
point Lines. ToSingleLine combines them into one Line.\
\>", "Text"],

Cell[BoxData[
    \(\(curve[a_, b_, c_]\)[\[Theta]_] := {a\ Cos[\[Theta]], 
        b\ Sin[\[Theta]], c\ \[Theta]}\)], "Input",
  CellLabel->"In[4]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Module[\[IndentingNewLine]{c}, \[IndentingNewLine]c[1] = 
          ParametricDraw3D[
            Evaluate[\(curve[1, 1, 1]\)[\[Theta]]], {\[Theta], 
              0, \[Pi]}]; \[IndentingNewLine]c[2] = 
          ParametricDraw3D[
            Evaluate[\(curve[1, 2, 1/2]\)[\[Theta]]], {\[Theta], 
              0, \[Pi]}]; \
\[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{ArrowLine3D @@ 
              ToSingleLine[c[1]], \[IndentingNewLine]Blue, 
            ArrowLine3D @@ 
              ToSingleLine[c[2]]}, \[IndentingNewLine]PlotRange \[Rule] 
            All]];\)\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    RowBox[{\(ParametricPlot3D::"ppfun"\), \(\(:\)\(\ \)\), "\<\"Argument \\!\
\\(\\(\\(curve[\\(\\(1, 1, 1\\)\\)]\\)\\)[\[Theta]]\\) is not a list with \
three or four elements. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"ParametricPlot3D::ppfun\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[93]:="],

Cell[BoxData[
    RowBox[{\(ParametricPlot3D::"ppfun"\), \(\(:\)\(\ \)\), "\<\"Argument \\!\
\\(\\(\\(curve[\\(\\(1, 2, 1\\/2\\)\\)]\\)\\)[\[Theta]]\\) is not a list with \
three or four elements. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"ParametricPlot3D::ppfun\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[93]:="],

Cell[BoxData[
    RowBox[{\(Graphics3D::"gprim"\), \(\(:\)\(\ \)\), "\<\"\\!\\(ArrowLine3D[\
\[Theta]]\\) was encountered where a \\!\\(Graphics3D\\) primitive or \
directive was expected. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::gprim\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[93]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.26852e-017 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{265.313, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004900017b000`400?l00000o`00003o/03oool2
000005L0oooo002^0?ooo`80000000<0oooo000000000000EP3oool00:/0oooo0`0000030?ooo`80
0000EP3oool00:T0oooo0P0000060?ooo`030000003oool0000005D0oooo002W0?ooo`800000203o
ool00`000000oooo0000001E0?ooo`00Y03oool3000000X0oooo00@000000?ooo`3oool00000E03o
ool00:80oooo0P00000=0?ooo`050000003oool0oooo0?ooo`000000D`3oool009l0oooo0`00000?
0?ooo`050000003oool0oooo0?ooo`000000D`3oool009d0oooo0P00000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0D03oool009/0oooo0P00000E0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0C`3oool009P0oooo0`00000G0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0C`3oool009H0oooo0P00000J0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0CP3oool009<0oooo0`00000L0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0CP3oool00940oooo0P00000O0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0C@3oool008l0oooo0P00000Q0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0C03oool008`0oooo0`00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0C03oool008X0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
B`3oool008L0oooo0`00000X0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0BP3o
ool008D0oooo0P00000[0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0BP3oool0
08<0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0B@3oool00800
oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0B@3oool007h0oooo
0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0B03oool007/0oooo0`00
000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A`3oool007T0oooo0P00000g
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A`3oool007L0oooo0P00000i0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0AP3oool007@0oooo0`00000k0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0A@3oool00780oooo0P00000o0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0A@3oool006l0oooo0`0000110?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0A03oool006d0oooo0P0000140?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0A03oool006/0oooo0P0000160?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@`3oool006P0oooo0`0000180?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0@P3oool006H0oooo0P00001;0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0@P3oool006<0oooo0`00001=0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0@@3oool00640oooo0P00001@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0@03oool005h0oooo0`00001B0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0@03oool005`0oooo0P00001E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0?`3oool005X0oooo0P00001G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
?`3oool005L0oooo0`00001I0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3o
ool005D0oooo0P00001L0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?@3oool0
0580oooo0`00001N0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?@3oool00500
oooo0P00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0?03oool004h0oooo
0P00001S0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>`3oool004/0oooo0`00
001U0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>`3oool004T0oooo0P00001Y
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>P3oool004H0oooo0`00001[0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>P3oool004@0oooo0P00001^0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0>@3oool00480oooo0P00001`0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0>03oool003l0oooo0`00001b0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0>03oool003d0oooo0P00001e0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0=`3oool003X0oooo0`00001g0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0=P3oool003P0oooo0P00001j0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0=P3oool003H0oooo0P00001l0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0=@3oool003<0oooo0`00001n0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0=@3oool00340oooo0P0000210?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0=03oool002h0oooo0`0000230?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0<`3oool002`0oooo0P0000260?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0<`3oool002X0oooo0P0000280?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
<P3oool002L0oooo0`00002:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0<@3o
ool002D0oooo0P00002=0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0<@3oool0
0280oooo0`00002?0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0<03oool00200
oooo0P00002C0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0<03oool001h0oooo
0P00002E0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0;`3oool001/0oooo0`00
002G0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;P3oool001T0oooo0P00002J
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;P3oool001L0oooo0P00002L0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0;@3oool001L0oooo0P00002L0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0;03oool001L0oooo00<000000?ooo`000000
V`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02`0oooo000G0?ooo`040000003o
ool0oooo000009X0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0[0?ooo`005P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0[0?ooo`005P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo09H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Z0?ooo`005P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0Y0?ooo`005P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo09@0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0Y0?ooo`005P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0X0?ooo`005P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`005@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W
0?ooo`005@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0V0?ooo`005@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0V0?ooo`00
5@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0U0?ooo`005@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0T0?ooo`005@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0T0?ooo`005@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0S0?ooo`00503oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0R0?ooo`00503oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo08X0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0R0?ooo`00503oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0Q0?ooo`00503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0Q0?ooo`00503oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo08L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?oo
o`00503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0O0?ooo`004`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0O0?ooo`004`3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0N0?ooo`004`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo08@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`004`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0M0?ooo`004`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0880
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0L0?ooo`004`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0L0?ooo`004P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0K0?ooo`004P3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0J
0?ooo`004P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo07l0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0J0?ooo`004P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0I0?ooo`00
4P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0H0?ooo`004P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0H0?ooo`004P3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0G0?ooo`004@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
07X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0G0?ooo`004@3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0F0?ooo`004@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0E0?ooo`004@3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0E0?ooo`004@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0D0?ooo`004@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo07D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0C0?oo
o`00403oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0C0?ooo`00403oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo07<0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0B0?ooo`00403o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool0>P3oool2000001<0oooo000@0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0g0?ooo`<0000000<0oooo0000
003oool04P3oool00100oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo03@0oooo0`0000040?ooo`030000003oool0oooo0140oooo000@0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0`0?ooo`<00000
1`3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0;@3oool3000000/0oooo00<000000?ooo`3oool0403o
ool000l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo02X0oooo0`00000>0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0W0?ooo`<000004@3oool00`00
0000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool08`3oool4000001@0oooo00<000000?ooo`3oool0403oool000l0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0200oooo
0`00000H0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0J@3oool00`000000oooo0?ooo`0M0?ooo`<000006`3oool00`000000oooo0?oo
o`0@0?ooo`003P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo06P0oooo00<00000
0?ooo`3oool06P3oool3000001h0oooo00<000000?ooo`3oool0403oool000h0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01L0oooo0`00000Q0?oo
o`030000003oool0oooo0100oooo000>0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`0D0?ooo`<000009@3oool00`000000oooo0?ooo`0?0?ooo`00
3P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
4@3oool3000002P0oooo00<000000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00h0oooo0`00000[0?ooo`030000003o
ool0oooo00l0oooo000>0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`0;0?ooo`<00000;P3oool00`000000oooo0?ooo`0?0?ooo`003P3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0203oool30000
0340oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo00D0oooo0`00000d0?ooo`030000003oool0oooo00l0
oooo000=0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`020?ooo`<00000=`3oool00`000000oooo0?ooo`0?0?ooo`003@3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo05l0oooo00<000000?ooo`0000000P00000k0?ooo`030000003o
ool0oooo00h0oooo000=0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0G@3oool3
000003h0oooo00<000000?ooo`3oool03P3oool000d0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`1I0?ooo`<000000P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
00h0oooo000=0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0E@3oool4000000D0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0>0?ooo`00303oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo0540oooo0`0000090?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool03P3oool000`0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`1=0?ooo`<00000303oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00h0oooo000<
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0B@3oool3000000l0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0>0?ooo`00303oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo04D0oooo0`00000B0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool03@3oool000`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`110?ooo`<0
00005@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000<0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0?@3oool3000001P0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0=0?ooo`002`3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo03T0oooo0`00000K0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3o
ool000/0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0e0?ooo`<000007P3oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000;0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool0<@3oool300000240oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0=0?ooo`002`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo02d0
oooo0`00000T0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool000/0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0Y0?ooo`<000009`3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000;0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool09@3oool3000002X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0<0?ooo`002`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0240oooo0`00000]
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0303oool000X0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`0M0?ooo`<00000<03oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo00`0oooo000:0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0603oool4000003@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0<0?ooo`00
2P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01@0oooo0`00000h0?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool0303oool000X0oooo00<000000?ooo`3oool0G03o
ool00`000000oooo0?ooo`0@0?ooo`<00000>`3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo00`0oooo000:0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0303oool3
000003h0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0<0?ooo`002P3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo00P0oooo0`0000110?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool02`3oool000T0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`040?ooo`<00000A03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00/0
oooo00090?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool00`0000170?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool02`3oool000T0oooo00<000000?ooo`3oool0HP3o
ool2000004X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0;0?ooo`002@3oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo04P0oooo0P0000100?ooo`030000003oool0
oooo00/0oooo00090?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0A@3oool30000
0080oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0;0?ooo`002@3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo0440oooo100000060?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool02`3oool000T0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`0n0?ooo`<000002P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00/0oooo
00080?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0>`3oool3000000h0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`00203oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo03P0oooo0`00000B0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool02P3oool000P0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0e0?oo
o`<000005P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00X0oooo00080?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool0<@3oool4000001X0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0:0?ooo`00203oool00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo02h0oooo0`00000N0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
2P3oool000P0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0[0?ooo`<000008P3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00X0oooo00070?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool0:03oool3000002H0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0:0?ooo`001`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
02D0oooo0`00000Z0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool02@3oool000L0
oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0Q0?ooo`@00000;P3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo00T0oooo00070?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool07`3oool3000003<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`090?ooo`001`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01`0oooo0`00
000f0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02@3oool000L0oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`0I0?ooo`<00000>P3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo00T0oooo00070?ooo`030000003oool0oooo06<0oooo00<000000?oo
o`3oool05P3oool3000003h0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`090?oo
o`001P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0180oooo100000120?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool02@3oool000H0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`0?0?ooo`<00000A`3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo00T0oooo00060?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303o
ool3000004X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`080?ooo`001P3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00T0oooo0`00001>0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0203oool000H0oooo00<000000?ooo`3oool0I03oool00`00
0000oooo0?ooo`060?ooo`<00000DP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00P0oooo00060?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool00P3oool4000005H0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`080?ooo`001@3oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0000000800000F`3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo00P0oooo00050?ooo`030000003oool0oooo06@0oooo0`00001N0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0203oool000D0oooo00<000000?ooo`3oool0H@3oool3
000000030?ooo`000000oooo05l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`08
0?ooo`001@3oool00`000000oooo0?ooo`1N0?ooo`<00000103oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool01`3oool000D0oooo00<000000?ooo`3o
ool0FP3oool4000000L0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00L0oooo00050?ooo`030000003oool0oooo05L0oooo0`00000;0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`070?ooo`001@3o
ool00`000000oooo0?ooo`1D0?ooo`<000003P3oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool01`3oool000@0oooo00<000000?ooo`3oool0DP3oool3
00000140oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00L0oooo00040?ooo`030000003oool0oooo04h0oooo1000000D0?ooo`030000003oool0oooo
06<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`00103oool00`000000
oooo0?ooo`1;0?ooo`<00000603oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool01`3oool000@0oooo00<000000?ooo`3oool0B03oool3000001/0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00H0oooo
00040?ooo`030000003oool0oooo04D0oooo0`00000N0?ooo`030000003oool0oooo06H0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`060?ooo`00103oool00`000000oooo0?ooo`12
0?ooo`<000008@3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool01P3oool000<0oooo00<000000?ooo`3oool0?`3oool4000002@0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00H0oooo00030?ooo`03
0000003oool0oooo03`0oooo0`00000X0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`060?ooo`000`3oool00`000000oooo0?ooo`0i0?ooo`<00000
:`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
1P3oool000<0oooo00<000000?ooo`3oool0=P3oool3000002d0oooo00<000000?ooo`3oool0J`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00H0oooo00030?ooo`030000003oool0
oooo03<0oooo0`00000`0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`060?ooo`000`3oool00`000000oooo0?ooo`0_0?ooo`@00000<`3oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool00080
oooo00<000000?ooo`3oool0;@3oool3000003L0oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00020?ooo`030000003oool0oooo02X0oooo
0`00000j0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`050?ooo`000P3oool00`000000oooo0?ooo`0W0?ooo`<00000?@3oool00`000000oooo0?oo
o`1_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01@3oool00080oooo00<00000
0?ooo`3oool0903oool300000400oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00D0oooo00020?ooo`030000003oool0oooo0200oooo100000130?oo
o`030000003oool0oooo0700oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?oo
o`000P3oool00`000000oooo0?ooo`0M0?ooo`<00000A`3oool00`000000oooo0?ooo`1a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01@3oool00080oooo00<000000?ooo`3oool0
6P3oool3000004X0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00@0oooo00000`3oool000000?ooo`0I0?ooo`<00000C@3oool00`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0103oool000030?ooo`000000
oooo01H0oooo0`00001@0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`040?ooo`0000<0oooo0000003oool04P3oool4000005<0oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00@0oooo00000`3oool0
00000?ooo`0?0?ooo`<00000E`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0103oool000030?ooo`000000oooo00`0oooo0`00001J0?ooo`030000
003oool0oooo07H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`0000<0
oooo0000003oool02@3oool3000005d0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00@0oooo00000`000000oooo0?ooo`060?ooo`<00000H03oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool0
00030000003oool0oooo0080oooo1000001S0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`030?ooo`0000<000000?ooo`0000000P00001W0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`030?ooo`00
0P00001Z0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`030?ooo`0000<0oooo000000000000J@3oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool00`3oool000<0oooo00<000000?ooo`3oool0IP3oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool0
00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool00`3oool000D0oooo0P00001U0?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`001`3oool00`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`020?ooo`00203oool200000680oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0080oooo000:0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo000;0?oo
o`800000GP3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool00P3oool000d0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool00P3oool000h0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool000l0oooo0P00001J0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`020?ooo`004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`004P3oool20000
05L0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0040oooo000D0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0040oooo
000F0?ooo`800000D`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool00@3oool001P0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`29
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool001T0oooo0P00001@0?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?oo
o`006`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`010?ooo`00703oool2000004d0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`007P3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02@3oool100000040oooo0@3o
ool001l0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo00P0oooo0@0000010?ooo`40oooo000P0?ooo`800000B@3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo00L0oooo0@0000010?ooo`40oooo000R0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool10?ooo`00
8`3oool2000004H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`060?ooo`400000
0@3oool10?ooo`009@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool01@3oool100000040oooo0@3oool002H0oooo0P0000130?ooo`030000003oool0
oooo0940oooo00<000000?ooo`3oool01@3oool100000040oooo000X0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`040?ooo`4000000@3oool002T0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00<0
oooo0@0000010?ooo`00:P3oool2000003l0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`030?ooo`4000000@3oool002`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`2D0?ooo`030000003oool0oooo0080oooo0@0000010?ooo`00;@3oool2000003`0oooo00<00000
0?ooo`3oool0U@3oool01@000000oooo0?ooo`3oool000000040oooo000_0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0UP3oool010000000oooo0?ooo`0000010?ooo`00<03oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`0000000@3oool0
0340oooo0P00000g0?ooo`030000003oool0oooo09T0oooo0@0000010?ooo`400000000c0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0V@3oool100000040oooo0@00000003@0oooo
0P00000d0?ooo`030000003oool0oooo09X0oooo0P00000003H0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`2I0?ooo`<00000000g0?ooo`800000<@3oool00`000000oooo0?ooo`2E
0?ooo`@000000`3oool003T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?oo
o`D000001`3oool003X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2<0?ooo`@0
0000303oool003/0oooo0P00000]0?ooo`030000003oool0oooo08P0oooo1000000@0?ooo`00?@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo08<0oooo1@00000D0?ooo`00?P3oool2
000002X0oooo00<000000?ooo`3oool0O`3oool4000001T0oooo00100?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0NP3oool5000001d0oooo00110?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0MP3oool400000280oooo00120?ooo`8000009P3oool00`000000oooo
0?ooo`1b0?ooo`@000009P3oool004@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`1]0?ooo`D00000:P3oool004D0oooo0P00000S0?ooo`030000003oool0oooo06T0oooo1000000_
0?ooo`00A`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06@0oooo1@00000c0?oo
o`00B03oool200000200oooo00<000000?ooo`3oool0H03oool4000003P0oooo001:0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool5000003`0oooo001;0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0E`3oool400000440oooo001<0?ooo`800000703oool0
0`000000oooo0?ooo`1C0?ooo`@00000A@3oool004h0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`1>0?ooo`D00000B@3oool004l0oooo0P00000I0?ooo`030000003oool0oooo04X0
oooo1000001>0?ooo`00D@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo
1@00001B0?ooo`00DP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000005L0oooo001D
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?@3oool4000005/0oooo001E0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0>03oool5000005l0oooo001F0?ooo`80
00004@3oool00`000000oooo0?ooo`0e0?ooo`@00000I03oool005P0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0`0?ooo`D00000J03oool005T0oooo0P00000>0?ooo`030000003o
ool0oooo02`0oooo1000001]0?ooo`00F`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo02L0oooo1@00001a0?ooo`00G03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
02<0oooo1000001f0?ooo`00G@3oool2000000X0oooo00<000000?ooo`3oool07`3oool4000007X0
oooo001O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool5000007h0oooo
001P0?ooo`8000001`3oool00`000000oooo0?ooo`0F0?ooo`@00000P`3oool00680oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`D00000Q`3oool006<0oooo0P0000040?oo
o`030000003oool0oooo00d0oooo1000002<0?ooo`00I@3oool01@000000oooo0?ooo`3oool00000
00/0oooo1000002@0?ooo`00IP3oool010000000oooo0?ooo`0000060?ooo`D00000U03oool006L0
oooo0`0000020?ooo`@00000V@3oool006T0oooo0`00002M0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 264.313}, {286.938, 0}} -> {0.0486402, \
-4.72903*^-05, 0.00324458, 0.00324458}}]
}, Open  ]],

Cell[BoxData[
    \(Clear[pts, curve]\)], "Input",
  CellLabel->"In[6]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{515, 639},
WindowMargins->{{3, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 58, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1837, 56, 347, 14, 33, "Usage",
      CellTags->"Function?"],
    Cell[2187, 72, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 77514, 1454}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 58, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1837, 56, 347, 14, 33, "Usage",
  CellTags->"Function?"],
Cell[2187, 72, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2284, 77, 187, 6, 41, "MathCaption"],
Cell[2474, 85, 174, 5, 58, "MathCaption"],
Cell[2651, 92, 356, 8, 75, "MathCaption"],
Cell[3010, 102, 570, 22, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3605, 128, 33, 0, 39, "ExampleSection"],
Cell[3641, 130, 97, 2, 29, "Input"],
Cell[3741, 134, 111, 3, 25, "Text"],
Cell[3855, 139, 148, 4, 29, "Input"],

Cell[CellGroupData[{
Cell[4028, 147, 206, 4, 69, "Input"],
Cell[4237, 153, 39044, 735, 294, 3953, 297, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[43296, 891, 156, 3, 42, "Text"],
Cell[43455, 896, 151, 3, 29, "Input"],

Cell[CellGroupData[{
Cell[43631, 903, 633, 13, 209, "Input"],
Cell[44267, 918, 396, 6, 50, "Message"],
Cell[44666, 926, 400, 6, 65, "Message"],
Cell[45069, 934, 383, 6, 50, "Message"],
Cell[45455, 942, 31256, 485, 294, 1348, 111, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[76726, 1430, 74, 2, 29, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

