(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8630,        234]*)
(*NotebookOutlinePosition[      9561,        267]*)
(*  CellTagsIndexPosition[      9487,        261]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CirclePoint", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["CirclePoint",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(location, size, rimcolor, diskcolor\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  "can be used to mark missing or special points in 2D graphics."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
A circle is drawn of the specified size with the color diskcolor and outline \
rimcolor.\
\>", "MathCaption"],

Cell["The size is given in printer's points.", "MathCaption"],

Cell[CellGroupData[{

Cell["Step Function Plot", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Red, \[IndentingNewLine]Draw[
              Sign[x - 1], {x, \(-5\), 5}] /. 
            SplitLineOnDistance[0.6], \[IndentingNewLine]CirclePoint[{1, 1}, 
            4, Red, White], \[IndentingNewLine]CirclePoint[{1, \(-1\)}, 4, 
            Red, White], \[IndentingNewLine]CirclePoint[{1, 0}, 4, Red, 
            Red]}, \[IndentingNewLine]PlotRange \[Rule] {\(-1.2\), 
            1.2}, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)], "Input",
  CellLabel->"In[2]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Rational Polynomial Plot", "ExampleSection"],

Cell[BoxData[{
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<NumericalMath`NLimit`\>"]\)}], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
Here is a fairly complicated rational polynomial. It has a pole, many zeros \
and two missing points. We expand the numerator and denominator first to \
disguise the missing points. We also extract an asymptote curve.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(p[x_] = 
      Expand[\((x + 3)\) \((x - 0.5)\) \((x - 2)\) \((x - 4)\) \((3  x\^5 - 
                6.2  x\^3 + x\^2 - 1.5)\)]/
        Expand[\((x + 3)\) \((x - 4)\) \((2.5  x\^5 - 1.2  x\^4 + x\^2 + 
                5)\)]\), "\n", 
    \(p[x] // Apart\), "\[IndentingNewLine]", 
    \(asymp[x_] = Select[%, \ Denominator[#] \[Equal] 1 &]\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(\((\(\(18.`\)\(\[InvisibleSpace]\)\) - 43.5`\ x + 0.75`\ x\^2 + 
          108.65`\ x\^3 - 189.8`\ x\^4 + 13.200000000000003`\ x\^5 + 
          109.7`\ x\^6 - 31.7`\ x\^7 - 10.5`\ x\^8 + 3\ x\^9)\)/\((\(-60\) - 
          5\ x - 7\ x\^2 - x\^3 + 15.399999999999999`\ x\^4 - 28.8`\ x\^5 - 
          3.7`\ x\^6 + 2.5`\ x\^7)\)\)], "Output",
  CellLabel->"Out[5]="],

Cell[BoxData[
    \(\(-2.4435200000000004`\) - 2.4240000000000004`\ x + 
      1.2000000000000002`\ x\^2 + 
      0.6666885169059578`\/\(\(\(1.1183537494672877`\)\(\[InvisibleSpace]\)\) \
+ x\) + \(\(\(0.5601401214946715`\)\(\[InvisibleSpace]\)\) + \
0.25365844674395444`\ x\)\/\(\(\(1.5840193466035641`\)\(\[InvisibleSpace]\)\) \
- 2.0498441721733007`\ x + x\^2\) + \(\(\(1.3477513103480827`\)\(\
\[InvisibleSpace]\)\) + 4.026763436350088`\ x\)\/\(\(\(1.128990573864256`\)\(\
\[InvisibleSpace]\)\) + 0.4514904227060131`\ x + x\^2\)\)], "Output",
  CellLabel->"Out[6]="],

Cell[BoxData[
    \(\(-2.4435200000000004`\) - 2.4240000000000004`\ x + 
      1.2000000000000002`\ x\^2\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
  "The following routine\n1) Finds the numerator and denominator real roots.\n\
2) Finds their order, with negative integers used for denominator roots.\n3) \
Consolidates the roots into one list and finds their net order.\n4) \
Consolidates all poles (negative order) together, all missing points (zero \
order) together, and all zeros (positive order) together.\n5) Returns a list \
",
  Cell[BoxData[
      \({poles, \ missingpoints, \ zeros}\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(PolesAndZeros[expr_, 
        var_] := \[IndentingNewLine]Module[{nroots, droots, 
          roots}, \[IndentingNewLine]nroots = 
          Select[var /. Solve[Numerator[expr] \[Equal] 0] // N, 
            FreeQ[#, Complex] &]; \[IndentingNewLine]droots = 
          Select[var /. Solve[Denominator[expr] \[Equal] 0] // N, 
            FreeQ[#, Complex] &]; \[IndentingNewLine]nroots = \({First[#], 
                Length[#]} &\) /@ 
            Split[Sort[nroots], 
              Abs[#2 - #1] < 
                  1.0*^-8 &]; \[IndentingNewLine]droots = \({First[#], \
\(-Length[#]\)} &\) /@ 
            Split[Sort[droots], 
              Abs[#2 - #1] < 1.0*^-8 &]; \[IndentingNewLine]roots = 
          Split[Sort[Join[nroots, droots]], 
            Abs[First[#2] - First[#1]] < 
                1.0*^-8 &]; \[IndentingNewLine]roots = \({First[First[#]], 
                Last[Plus @@ #]} &\) /@ 
            roots; \[IndentingNewLine]roots = \({Switch[
                  First[#], _?Negative, \(-1\), _?Positive, 1, _, 0], 
                Last[#]} &\) /@ 
            Sort[Reverse /@ roots]; \[IndentingNewLine]roots = 
          Split[roots, 
            First[#1] \[Equal] First[#2] &]; \[IndentingNewLine]Map[Last, 
          roots, {2}]\[IndentingNewLine]]\)], "Input",
  CellLabel->"In[8]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \({poles, missing, zeros} = PolesAndZeros[p[x], x]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({{\(-1.1183537494672877`\)}, {\(-3.`\), 
        3.9999999999999996`}, {\(-1.4609884369405661`\), \
\(-0.605694999925375`\), 0.5`, 1.416761434935708`, 
        2.000000000000001`}}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell["We now draw our diagram with all the special points marked.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Blue, \[IndentingNewLine]Draw[
              p[x], {x, \(-4\), 5}] /. 
            SplitLineOnDistance[
              20], \[IndentingNewLine]\(CirclePoint[{#, 
                  NLimit[p[x], x \[Rule] #]}, 4, Black, White] &\) /@ 
            missing, \[IndentingNewLine]\(CirclePoint[{#, 0}, 4, Black, 
                LightBlue] &\) /@ 
            zeros, \[IndentingNewLine]\(CirclePoint[{#, 0}, 4, Black, 
                Apricot] &\) /@ poles, \[IndentingNewLine]Salmon, 
          AbsoluteDashing[{4, 4}], \[IndentingNewLine]Draw[
            asymp[x], {x, \(-4\), 
              5}]}, \[IndentingNewLine]AspectRatio \[Rule] 
          1, \[IndentingNewLine]PlotRange \[Rule] {Automatic, {\(-6\), 
              15}}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]AxesStyle \[Rule] 
          Gray, \[IndentingNewLine]ImageSize \[Rule] 500];\)\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(\(Clear[p, asympt, PolesAndZeros, poles, missing, zeros];\)\)], "Input",\

  CellLabel->"In[11]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{598, 686},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 58, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1837, 56, 386, 14, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 9316, 252}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 58, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1837, 56, 386, 14, 32, "Usage",
  CellTags->"Function?"],
Cell[2226, 72, 119, 3, 31, "MathCaption"],
Cell[2348, 77, 61, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2434, 81, 44, 0, 40, "ExampleSection"],
Cell[2481, 83, 97, 2, 29, "Input"],
Cell[2581, 87, 569, 9, 189, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3187, 101, 50, 0, 34, "ExampleSection"],
Cell[3240, 103, 167, 3, 49, "Input"],
Cell[3410, 108, 241, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[3676, 116, 400, 8, 91, "Input"],
Cell[4079, 126, 384, 6, 62, "Output"],
Cell[4466, 134, 570, 9, 70, "Output"],
Cell[5039, 145, 142, 3, 23, "Output"]
}, Open  ]],
Cell[5196, 151, 484, 10, 167, "Text"],
Cell[5683, 163, 1324, 26, 389, "Input"],

Cell[CellGroupData[{
Cell[7032, 193, 105, 2, 29, "Input"],
Cell[7140, 197, 238, 5, 23, "Output"]
}, Open  ]],
Cell[7393, 205, 75, 0, 25, "Text"],
Cell[7471, 207, 1009, 18, 289, "Input"],
Cell[8483, 227, 119, 3, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

