(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    106341,       3995]*)
(*NotebookOutlinePosition[    107371,       4031]*)
(*  CellTagsIndexPosition[    107294,       4025]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ComplexInequalityDraw", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          RowBox[{"ComplexInequality", 
            StyleBox["Draw",
              "MR"]}]], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(ineqs, {z, zmin, zmax}, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " extracts the graphics primitives from the corresponding \
ComplexInequalityPlot statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as ComplexInequalityPlot. Regular ComplexInequalityPlot \
options may be used. Basic Graphics3D options, such as PlotRange have no \
effect.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["InequalityDraw",
    ButtonData:>{"InequalityDraw"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["InequalityDraw3D",
    ButtonData:>{"InequalityDraw3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["InequalityGraphics",
    ButtonData:>{"InequalityGraphics"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Here we investigate the absolute value of the following function.\
\>", "Text"],

Cell[BoxData[
    \(f[z_] := 2  z + z\^2 - \((1 + 1  \[ImaginaryI])\)\)], "Input",
  CellLabel->"In[8]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Solve[f[z] \[Equal] 0]\), "\[IndentingNewLine]", 
    \(zeropts = {Re[z], Im[z]} /. % // N\)}], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({{z \[Rule] \(-1\) - \@\(2 + \[ImaginaryI]\)}, {z \[Rule] \(-1\) + \
\@\(2 + \[ImaginaryI]\)}}\)], "Output",
  CellLabel->"Out[9]="],

Cell[BoxData[
    \({{\(-2.4553466902253547`\), \(-0.34356074972251244`\)}, \
{0.4553466902253549`, 0.34356074972251244`}}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["\<\
Since the calulations are slow, we calculate the regions outside the Draw2D \
statement.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\(region[2] = 
            ComplexInequalityDraw[Abs[f[z]] \[LessEqual] 2, {z}, 
              Fills \[Rule] AquamarineMedium];\))\) // Timing\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \({0.172`\ Second, Null}\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\(region[1] = 
            ComplexInequalityDraw[Abs[f[z]] \[LessEqual] 1, {z}, 
              Fills \[Rule] LightCoral];\))\) // Timing\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({0.172`\ Second, Null}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["Now we draw the two regions and label the boundary lines.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{region[2], \[IndentingNewLine]region[
            1], \[IndentingNewLine]AbsolutePointSize[4], 
          Point /@ zeropts, \[IndentingNewLine]region[2] // 
            DrawLineLabels[
              Abs[f[#1 + #2  \[ImaginaryI]]] &, \((0.5 &)\)], \
\[IndentingNewLine]region[1] // 
            DrawLineLabels[
              Abs[f[#1 + #2  \[ImaginaryI]]] &, \((0.5 &)\)]}, \
\[IndentingNewLine]Frame \[Rule] True, \[IndentingNewLine]PlotLabel \[Rule] 
          Abs[f[z]], \[IndentingNewLine]TextStyle \[Rule] {FontSize \[Rule] 
              12, FontWeight \[Rule] "\<Bold\>"}, \
\[IndentingNewLine]ImageSize \[Rule] 
          400, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Background \[Rule] 
          Antique];\)\)], "Input",
  CellLabel->"In[13]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .48506 
%%ImageSize: 400 194.024 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.981 .922 .845 r
MFill
% Scaling calculations
0.735721 0.235721 0.24253 0.235721 [
[.02856 -0.0125 -9.5625 -15.5625 ]
[.02856 -0.0125 9.5625 0 ]
[.26428 -0.0125 -9.5625 -15.5625 ]
[.26428 -0.0125 9.5625 0 ]
[.5 -0.0125 -9.5625 -15.5625 ]
[.5 -0.0125 9.5625 0 ]
[.73572 -0.0125 -5.59375 -15.5625 ]
[.73572 -0.0125 5.59375 0 ]
[.97144 -0.0125 -5.59375 -15.5625 ]
[.97144 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00681 -19.125 -7.78125 ]
[-0.0125 .00681 0 7.78125 ]
[-0.0125 .12467 -33.5 -7.78125 ]
[-0.0125 .12467 0 7.78125 ]
[-0.0125 .24253 -11.1875 -7.78125 ]
[-0.0125 .24253 0 7.78125 ]
[-0.0125 .36039 -25.5625 -7.78125 ]
[-0.0125 .36039 0 7.78125 ]
[-0.0125 .47825 -11.1875 -7.78125 ]
[-0.0125 .47825 0 7.78125 ]
[ 0 0 -0.125 0 ]
[ 0 .48506 .125 0 ]
[ 1 0 .125 0 ]
[.5 .49756 -73 0 ]
[.5 .49756 73 15.625 ]
[ 0 0 0 0 ]
[ 1 .48506 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02856 0 m
.02856 .00625 L
s
gsave
.02856 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.26428 0 m
.26428 .00625 L
s
gsave
.26428 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.73572 0 m
.73572 .00625 L
s
gsave
.73572 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.97144 0 m
.97144 .00625 L
s
gsave
.97144 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.0757 0 m
.0757 .00375 L
s
.12285 0 m
.12285 .00375 L
s
.16999 0 m
.16999 .00375 L
s
.21713 0 m
.21713 .00375 L
s
.31142 0 m
.31142 .00375 L
s
.35857 0 m
.35857 .00375 L
s
.40571 0 m
.40571 .00375 L
s
.45286 0 m
.45286 .00375 L
s
.54714 0 m
.54714 .00375 L
s
.59429 0 m
.59429 .00375 L
s
.64143 0 m
.64143 .00375 L
s
.68858 0 m
.68858 .00375 L
s
.78287 0 m
.78287 .00375 L
s
.83001 0 m
.83001 .00375 L
s
.87715 0 m
.87715 .00375 L
s
.9243 0 m
.9243 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00681 m
.00625 .00681 L
s
gsave
-0.0125 .00681 -80.125 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .12467 m
.00625 .12467 L
s
gsave
-0.0125 .12467 -94.5 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .24253 m
.00625 .24253 L
s
gsave
-0.0125 .24253 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .36039 m
.00625 .36039 L
s
gsave
-0.0125 .36039 -86.5625 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .47825 m
.00625 .47825 L
s
gsave
-0.0125 .47825 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03038 m
.00375 .03038 L
s
0 .05395 m
.00375 .05395 L
s
0 .07753 m
.00375 .07753 L
s
0 .1011 m
.00375 .1011 L
s
0 .14824 m
.00375 .14824 L
s
0 .17181 m
.00375 .17181 L
s
0 .19539 m
.00375 .19539 L
s
0 .21896 m
.00375 .21896 L
s
0 .2661 m
.00375 .2661 L
s
0 .28967 m
.00375 .28967 L
s
0 .31325 m
.00375 .31325 L
s
0 .33682 m
.00375 .33682 L
s
0 .38396 m
.00375 .38396 L
s
0 .40754 m
.00375 .40754 L
s
0 .43111 m
.00375 .43111 L
s
0 .45468 m
.00375 .45468 L
s
.25 Mabswid
0 0 m
0 .48506 L
s
.02856 .47881 m
.02856 .48506 L
s
.26428 .47881 m
.26428 .48506 L
s
.5 .47881 m
.5 .48506 L
s
.73572 .47881 m
.73572 .48506 L
s
.97144 .47881 m
.97144 .48506 L
s
.125 Mabswid
.0757 .48131 m
.0757 .48506 L
s
.12285 .48131 m
.12285 .48506 L
s
.16999 .48131 m
.16999 .48506 L
s
.21713 .48131 m
.21713 .48506 L
s
.31142 .48131 m
.31142 .48506 L
s
.35857 .48131 m
.35857 .48506 L
s
.40571 .48131 m
.40571 .48506 L
s
.45286 .48131 m
.45286 .48506 L
s
.54714 .48131 m
.54714 .48506 L
s
.59429 .48131 m
.59429 .48506 L
s
.64143 .48131 m
.64143 .48506 L
s
.68858 .48131 m
.68858 .48506 L
s
.78287 .48131 m
.78287 .48506 L
s
.83001 .48131 m
.83001 .48506 L
s
.87715 .48131 m
.87715 .48506 L
s
.9243 .48131 m
.9243 .48506 L
s
.25 Mabswid
0 .48506 m
1 .48506 L
s
.99375 .00681 m
1 .00681 L
s
.99375 .12467 m
1 .12467 L
s
.99375 .24253 m
1 .24253 L
s
.99375 .36039 m
1 .36039 L
s
.99375 .47825 m
1 .47825 L
s
.125 Mabswid
.99625 .03038 m
1 .03038 L
s
.99625 .05395 m
1 .05395 L
s
.99625 .07753 m
1 .07753 L
s
.99625 .1011 m
1 .1011 L
s
.99625 .14824 m
1 .14824 L
s
.99625 .17181 m
1 .17181 L
s
.99625 .19539 m
1 .19539 L
s
.99625 .21896 m
1 .21896 L
s
.99625 .2661 m
1 .2661 L
s
.99625 .28967 m
1 .28967 L
s
.99625 .31325 m
1 .31325 L
s
.99625 .33682 m
1 .33682 L
s
.99625 .38396 m
1 .38396 L
s
.99625 .40754 m
1 .40754 L
s
.99625 .43111 m
1 .43111 L
s
.99625 .45468 m
1 .45468 L
s
.25 Mabswid
1 0 m
1 .48506 L
s
gsave
.5 .49756 -134 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.250 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Abs) show
%%IncludeResource: font Mathematica2Mono-Bold
%%IncludeFont: Mathematica2Mono-Bold
/Mathematica2Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
84.813 15.063 moveto
(@) show
92.000 15.063 moveto
(H) show
99.188 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
107.125 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
117.188 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
127.250 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Mathematica2Mono-Bold
%%IncludeFont: Mathematica2Mono-Bold
/Mathematica2Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
134.438 15.063 moveto
(L) show
144.500 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
154.563 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
164.938 15.063 moveto
(z) show
175.000 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
185.063 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
192.250 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2Mono-Bold
%%IncludeFont: Mathematica2Mono-Bold
/Mathematica2Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
197.813 15.063 moveto
(D) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .48506 L
0 .48506 L
closepath
clip
newpath
.5 Mabswid
.02381 .1655 m
.02426 .1539 L
.02468 .14945 L
.0256 .14242 L
.02727 .1335 L
.02922 .12561 L
.03106 .11946 L
.03871 .10036 L
.0465 .08619 L
.05496 .07397 L
.07071 .0564 L
.08589 .04364 L
.10048 .03406 L
.11601 .02612 L
.13096 .02033 L
.13856 .018 L
.14686 .01589 L
.15489 .01426 L
.16217 .01313 L
.16581 .01268 L
.16976 .01228 L
.17392 .01195 L
.17595 .01182 L
.17784 .01173 L
.17961 .01166 L
.18151 .0116 L
.18259 .01158 L
.18312 .01157 L
.18361 .01156 L
.18405 .01156 L
.18453 .01155 L
.18502 .01155 L
.18528 .01155 L
.18553 .01155 L
.18601 .01155 L
.18628 .01155 L
.18653 .01155 L
.18703 .01155 L
.18731 .01155 L
.18757 .01156 L
.18803 .01156 L
.18853 .01157 L
.18944 .01158 L
.19051 .01161 L
.19163 .01164 L
.19365 .01171 L
.19729 .0119 L
.2012 .01219 L
.20826 .01291 L
.21643 .01408 L
Mistroke
.22418 .01552 L
.23893 .01918 L
.25462 .02442 L
.26973 .03084 L
.28579 .03925 L
.30125 .04906 L
.31614 .06029 L
.33197 .07451 L
.34722 .09102 L
.36188 .11053 L
.37005 .12375 L
.37749 .13822 L
.38083 .14594 L
.38446 .15583 L
.38612 .16122 L
.38789 .16798 L
.38939 .17539 L
.38981 .17795 L
.39025 .18122 L
.39067 .18528 L
.39105 .19417 L
Mfstroke
.02381 .16564 m
.02426 .17726 L
.02468 .18172 L
.0256 .18878 L
.02727 .19775 L
.02922 .2057 L
.03106 .21191 L
.03871 .23126 L
.0465 .2457 L
.05496 .25822 L
.07071 .2764 L
.08589 .2898 L
.10048 .30006 L
.11601 .30878 L
.13096 .31542 L
.14686 .32085 L
.1548 .323 L
.16217 .32467 L
.16975 .3261 L
.1769 .32717 L
.1807 .32763 L
.18481 .32805 L
.18852 .32836 L
.19199 .32859 L
.19565 .32877 L
.19759 .32884 L
.19968 .3289 L
.20072 .32892 L
.20127 .32893 L
.20186 .32893 L
.20237 .32894 L
.20264 .32894 L
.20293 .32894 L
.2032 .32894 L
.20344 .32895 L
.20392 .32895 L
.20439 .32895 L
.20483 .32895 L
.2053 .32895 L
.20581 .32894 L
.20607 .32894 L
.20635 .32894 L
.20685 .32893 L
.2078 .32892 L
.20871 .3289 L
.20968 .32888 L
.21145 .32883 L
.21355 .32875 L
.21546 .32866 L
.21962 .32841 L
Mistroke
.22358 .3281 L
.23123 .32729 L
.23832 .32631 L
.25343 .32345 L
.26949 .31925 L
.28496 .31403 L
.29984 .30782 L
.31567 .29981 L
.33092 .29047 L
.34558 .27957 L
.36119 .26497 L
.36891 .25593 L
.37621 .24548 L
.37967 .2395 L
.38333 .23191 L
.38524 .22714 L
.38734 .22075 L
.38826 .21733 L
.38926 .21288 L
.38971 .21039 L
.39019 .20722 L
.39061 .20366 L
.39105 .19429 L
Mfstroke
.4 .804 .667 r
.02381 .1655 m
.02426 .1539 L
.02468 .14945 L
.0256 .14242 L
.02727 .1335 L
.02922 .12561 L
.03106 .11946 L
.03871 .10036 L
.0465 .08619 L
.05496 .07397 L
.07071 .0564 L
.08589 .04364 L
.10048 .03406 L
.11601 .02612 L
.13096 .02033 L
.13856 .018 L
.14686 .01589 L
.15489 .01426 L
.16217 .01313 L
.16581 .01268 L
.16976 .01228 L
.17392 .01195 L
.17595 .01182 L
.17784 .01173 L
.17961 .01166 L
.18151 .0116 L
.18259 .01158 L
.18312 .01157 L
.18361 .01156 L
.18405 .01156 L
.18453 .01155 L
.18502 .01155 L
.18528 .01155 L
.18553 .01155 L
.18601 .01155 L
.18628 .01155 L
.18653 .01155 L
.18703 .01155 L
.18731 .01155 L
.18757 .01156 L
.18803 .01156 L
.18853 .01157 L
.18944 .01158 L
.19051 .01161 L
.19163 .01164 L
.19365 .01171 L
.19729 .0119 L
.2012 .01219 L
.20826 .01291 L
.21643 .01408 L
.22418 .01552 L
.23893 .01918 L
.25462 .02442 L
.26973 .03084 L
.28579 .03925 L
.30125 .04906 L
.31614 .06029 L
.33197 .07451 L
.34722 .09102 L
.36188 .11053 L
.37005 .12375 L
.37749 .13822 L
.38083 .14594 L
.38446 .15583 L
.38612 .16122 L
.38789 .16798 L
.38939 .17539 L
.38981 .17795 L
.39025 .18122 L
.39067 .18528 L
.39105 .19417 L
.39105 .19429 L
.39061 .20366 L
.39019 .20722 L
.38971 .21039 L
.38926 .21288 L
.38826 .21733 L
.38734 .22075 L
.38524 .22714 L
.38333 .23191 L
.37967 .2395 L
.37621 .24548 L
.36891 .25593 L
.36119 .26497 L
.34558 .27957 L
.33092 .29047 L
.31567 .29981 L
.29984 .30782 L
.28496 .31403 L
.26949 .31925 L
.25343 .32345 L
.23832 .32631 L
.23123 .32729 L
.22358 .3281 L
.21962 .32841 L
.21546 .32866 L
.21355 .32875 L
.21145 .32883 L
.20968 .32888 L
.20871 .3289 L
.2078 .32892 L
.20685 .32893 L
.20635 .32894 L
.20607 .32894 L
.20581 .32894 L
.2053 .32895 L
.20483 .32895 L
.20439 .32895 L
.20392 .32895 L
.20344 .32895 L
.2032 .32894 L
.20293 .32894 L
.20264 .32894 L
.20237 .32894 L
.20186 .32893 L
.20127 .32893 L
.20072 .32892 L
.19968 .3289 L
.19759 .32884 L
.19565 .32877 L
.19199 .32859 L
.18852 .32836 L
.18481 .32805 L
.1807 .32763 L
.1769 .32717 L
.16975 .3261 L
.16217 .32467 L
.1548 .323 L
.14686 .32085 L
.13096 .31542 L
.11601 .30878 L
.10048 .30006 L
.08589 .2898 L
.07071 .2764 L
.05496 .25822 L
.0465 .2457 L
.03871 .23126 L
.03106 .21191 L
.02922 .2057 L
.02727 .19775 L
.0256 .18878 L
.02468 .18172 L
.02426 .17726 L
.02381 .16564 L
F
0 0 0 r
.02381 .1655 m
.02426 .1539 L
.02468 .14945 L
.0256 .14242 L
.02727 .1335 L
.02922 .12561 L
.03106 .11946 L
.03871 .10036 L
.0465 .08619 L
.05496 .07397 L
.07071 .0564 L
.08589 .04364 L
.10048 .03406 L
.11601 .02612 L
.13096 .02033 L
.13856 .018 L
.14686 .01589 L
.15489 .01426 L
.16217 .01313 L
.16581 .01268 L
.16976 .01228 L
.17392 .01195 L
.17595 .01182 L
.17784 .01173 L
.17961 .01166 L
.18151 .0116 L
.18259 .01158 L
.18312 .01157 L
.18361 .01156 L
.18405 .01156 L
.18453 .01155 L
.18502 .01155 L
.18528 .01155 L
.18553 .01155 L
.18601 .01155 L
.18628 .01155 L
.18653 .01155 L
.18703 .01155 L
.18731 .01155 L
.18757 .01156 L
.18803 .01156 L
.18853 .01157 L
.18944 .01158 L
.19051 .01161 L
.19163 .01164 L
.19365 .01171 L
.19729 .0119 L
.2012 .01219 L
.20826 .01291 L
.21643 .01408 L
Mistroke
.22418 .01552 L
.23893 .01918 L
.25462 .02442 L
.26973 .03084 L
.28579 .03925 L
.30125 .04906 L
.31614 .06029 L
.33197 .07451 L
.34722 .09102 L
.36188 .11053 L
.37005 .12375 L
.37749 .13822 L
.38083 .14594 L
.38446 .15583 L
.38612 .16122 L
.38789 .16798 L
.38939 .17539 L
.38981 .17795 L
.39025 .18122 L
.39067 .18528 L
.39105 .19417 L
Mfstroke
.02381 .16564 m
.02426 .17726 L
.02468 .18172 L
.0256 .18878 L
.02727 .19775 L
.02922 .2057 L
.03106 .21191 L
.03871 .23126 L
.0465 .2457 L
.05496 .25822 L
.07071 .2764 L
.08589 .2898 L
.10048 .30006 L
.11601 .30878 L
.13096 .31542 L
.14686 .32085 L
.1548 .323 L
.16217 .32467 L
.16975 .3261 L
.1769 .32717 L
.1807 .32763 L
.18481 .32805 L
.18852 .32836 L
.19199 .32859 L
.19565 .32877 L
.19759 .32884 L
.19968 .3289 L
.20072 .32892 L
.20127 .32893 L
.20186 .32893 L
.20237 .32894 L
.20264 .32894 L
.20293 .32894 L
.2032 .32894 L
.20344 .32895 L
.20392 .32895 L
.20439 .32895 L
.20483 .32895 L
.2053 .32895 L
.20581 .32894 L
.20607 .32894 L
.20635 .32894 L
.20685 .32893 L
.2078 .32892 L
.20871 .3289 L
.20968 .32888 L
.21145 .32883 L
.21355 .32875 L
.21546 .32866 L
.21962 .32841 L
Mistroke
.22358 .3281 L
.23123 .32729 L
.23832 .32631 L
.25343 .32345 L
.26949 .31925 L
.28496 .31403 L
.29984 .30782 L
.31567 .29981 L
.33092 .29047 L
.34558 .27957 L
.36119 .26497 L
.36891 .25593 L
.37621 .24548 L
.37967 .2395 L
.38333 .23191 L
.38524 .22714 L
.38734 .22075 L
.38826 .21733 L
.38926 .21288 L
.38971 .21039 L
.39019 .20722 L
.39061 .20366 L
.39105 .19429 L
Mfstroke
.60895 .29078 m
.6094 .28134 L
.60981 .27778 L
.61029 .27465 L
.61074 .2722 L
.61241 .26519 L
.61423 .25941 L
.6162 .25427 L
.62384 .23948 L
.63229 .22761 L
.64009 .21873 L
.65527 .20479 L
.66986 .19407 L
.68539 .18466 L
.70034 .17715 L
.71624 .17059 L
.73155 .1655 L
.74628 .16168 L
.7545 .15998 L
.76195 .15871 L
.76972 .15766 L
.77704 .15691 L
.7808 .15662 L
.78478 .15639 L
.78818 .15624 L
.7901 .15618 L
.79098 .15616 L
.7919 .15615 L
.79291 .15613 L
.79335 .15613 L
.79383 .15612 L
.7941 .15612 L
.79435 .15612 L
.79483 .15612 L
.79509 .15611 L
.79537 .15611 L
.79566 .15611 L
.79593 .15611 L
.79643 .15611 L
.7969 .15612 L
.79732 .15612 L
.79778 .15612 L
.79881 .15614 L
.79975 .15615 L
.80141 .15619 L
.80323 .15625 L
.80691 .15641 L
.81083 .15665 L
.81441 .15694 L
.82246 .15781 L
Mistroke
.8298 .15889 L
.83779 .16038 L
.85349 .16431 L
.8686 .16947 L
.88465 .17661 L
.90012 .18538 L
.91501 .19596 L
.93084 .21023 L
.94608 .22825 L
.95376 .23979 L
.96075 .25266 L
.96432 .26059 L
.96821 .27091 L
.97034 .27778 L
.97231 .28543 L
.97419 .29499 L
.97514 .30173 L
.9754 .30409 L
.97568 .30713 L
.97619 .31942 L
Mfstroke
.60895 .29089 m
.6094 .30056 L
.60981 .30435 L
.61074 .31042 L
.61241 .31832 L
.6162 .33118 L
.62384 .34967 L
.64009 .37742 L
.65549 .39721 L
.6703 .41276 L
.68606 .42656 L
.70123 .4377 L
.71582 .44673 L
.73136 .45473 L
.74631 .46099 L
.76221 .4662 L
.77015 .46827 L
.77752 .46988 L
.7851 .47123 L
.79225 .47221 L
.79605 .47263 L
.80016 .47298 L
.80198 .47311 L
.8039 .47323 L
.80566 .47332 L
.80733 .47339 L
.80825 .47342 L
.80925 .47345 L
.81007 .47347 L
.81099 .47349 L
.81198 .4735 L
.81252 .47351 L
.81302 .47351 L
.8135 .47351 L
.81393 .47351 L
.81441 .47351 L
.81491 .47351 L
.81535 .47351 L
.81575 .4735 L
.81622 .4735 L
.81666 .47349 L
.81744 .47348 L
.81828 .47346 L
.8202 .47341 L
.82198 .47334 L
.82571 .47314 L
.82921 .47288 L
.83305 .47251 L
.83717 .47202 L
.84534 .47076 L
Mistroke
.85309 .46918 L
.86783 .46513 L
.88353 .45914 L
.89864 .45152 L
.91469 .441 L
.93016 .42782 L
.94505 .41109 L
.95275 .40007 L
.96088 .38556 L
.96454 .37749 L
.96847 .36705 L
.97037 .36091 L
.97217 .35403 L
.97378 .34629 L
.9747 .34064 L
.9751 .33759 L
.97554 .33347 L
.97588 .32922 L
.97619 .31956 L
Mfstroke
.4 .804 .667 r
.60895 .29078 m
.6094 .28134 L
.60981 .27778 L
.61029 .27465 L
.61074 .2722 L
.61241 .26519 L
.61423 .25941 L
.6162 .25427 L
.62384 .23948 L
.63229 .22761 L
.64009 .21873 L
.65527 .20479 L
.66986 .19407 L
.68539 .18466 L
.70034 .17715 L
.71624 .17059 L
.73155 .1655 L
.74628 .16168 L
.7545 .15998 L
.76195 .15871 L
.76972 .15766 L
.77704 .15691 L
.7808 .15662 L
.78478 .15639 L
.78818 .15624 L
.7901 .15618 L
.79098 .15616 L
.7919 .15615 L
.79291 .15613 L
.79335 .15613 L
.79383 .15612 L
.7941 .15612 L
.79435 .15612 L
.79483 .15612 L
.79509 .15611 L
.79537 .15611 L
.79566 .15611 L
.79593 .15611 L
.79643 .15611 L
.7969 .15612 L
.79732 .15612 L
.79778 .15612 L
.79881 .15614 L
.79975 .15615 L
.80141 .15619 L
.80323 .15625 L
.80691 .15641 L
.81083 .15665 L
.81441 .15694 L
.82246 .15781 L
.8298 .15889 L
.83779 .16038 L
.85349 .16431 L
.8686 .16947 L
.88465 .17661 L
.90012 .18538 L
.91501 .19596 L
.93084 .21023 L
.94608 .22825 L
.95376 .23979 L
.96075 .25266 L
.96432 .26059 L
.96821 .27091 L
.97034 .27778 L
.97231 .28543 L
.97419 .29499 L
.97514 .30173 L
.9754 .30409 L
.97568 .30713 L
.97619 .31942 L
.97619 .31956 L
.97588 .32922 L
.97554 .33347 L
.9751 .33759 L
.9747 .34064 L
.97378 .34629 L
.97217 .35403 L
.97037 .36091 L
.96847 .36705 L
.96454 .37749 L
.96088 .38556 L
.95275 .40007 L
.94505 .41109 L
.93016 .42782 L
.91469 .441 L
.89864 .45152 L
.88353 .45914 L
.86783 .46513 L
.85309 .46918 L
.84534 .47076 L
.83717 .47202 L
.83305 .47251 L
.82921 .47288 L
.82571 .47314 L
.82198 .47334 L
.8202 .47341 L
.81828 .47346 L
.81744 .47348 L
.81666 .47349 L
.81622 .4735 L
.81575 .4735 L
.81535 .47351 L
.81491 .47351 L
.81441 .47351 L
.81393 .47351 L
.8135 .47351 L
.81302 .47351 L
.81252 .47351 L
.81198 .4735 L
.81099 .47349 L
.81007 .47347 L
.80925 .47345 L
.80825 .47342 L
.80733 .47339 L
.80566 .47332 L
.8039 .47323 L
.80198 .47311 L
.80016 .47298 L
.79605 .47263 L
.79225 .47221 L
.7851 .47123 L
.77752 .46988 L
.77015 .46827 L
.76221 .4662 L
.74631 .46099 L
.73136 .45473 L
.71582 .44673 L
.70123 .4377 L
.68606 .42656 L
.6703 .41276 L
.65549 .39721 L
.64009 .37742 L
.62384 .34967 L
.6162 .33118 L
.61241 .31832 L
.61074 .31042 L
.60981 .30435 L
.6094 .30056 L
.60895 .29089 L
F
0 0 0 r
.60895 .29078 m
.6094 .28134 L
.60981 .27778 L
.61029 .27465 L
.61074 .2722 L
.61241 .26519 L
.61423 .25941 L
.6162 .25427 L
.62384 .23948 L
.63229 .22761 L
.64009 .21873 L
.65527 .20479 L
.66986 .19407 L
.68539 .18466 L
.70034 .17715 L
.71624 .17059 L
.73155 .1655 L
.74628 .16168 L
.7545 .15998 L
.76195 .15871 L
.76972 .15766 L
.77704 .15691 L
.7808 .15662 L
.78478 .15639 L
.78818 .15624 L
.7901 .15618 L
.79098 .15616 L
.7919 .15615 L
.79291 .15613 L
.79335 .15613 L
.79383 .15612 L
.7941 .15612 L
.79435 .15612 L
.79483 .15612 L
.79509 .15611 L
.79537 .15611 L
.79566 .15611 L
.79593 .15611 L
.79643 .15611 L
.7969 .15612 L
.79732 .15612 L
.79778 .15612 L
.79881 .15614 L
.79975 .15615 L
.80141 .15619 L
.80323 .15625 L
.80691 .15641 L
.81083 .15665 L
.81441 .15694 L
.82246 .15781 L
Mistroke
.8298 .15889 L
.83779 .16038 L
.85349 .16431 L
.8686 .16947 L
.88465 .17661 L
.90012 .18538 L
.91501 .19596 L
.93084 .21023 L
.94608 .22825 L
.95376 .23979 L
.96075 .25266 L
.96432 .26059 L
.96821 .27091 L
.97034 .27778 L
.97231 .28543 L
.97419 .29499 L
.97514 .30173 L
.9754 .30409 L
.97568 .30713 L
.97619 .31942 L
Mfstroke
.60895 .29089 m
.6094 .30056 L
.60981 .30435 L
.61074 .31042 L
.61241 .31832 L
.6162 .33118 L
.62384 .34967 L
.64009 .37742 L
.65549 .39721 L
.6703 .41276 L
.68606 .42656 L
.70123 .4377 L
.71582 .44673 L
.73136 .45473 L
.74631 .46099 L
.76221 .4662 L
.77015 .46827 L
.77752 .46988 L
.7851 .47123 L
.79225 .47221 L
.79605 .47263 L
.80016 .47298 L
.80198 .47311 L
.8039 .47323 L
.80566 .47332 L
.80733 .47339 L
.80825 .47342 L
.80925 .47345 L
.81007 .47347 L
.81099 .47349 L
.81198 .4735 L
.81252 .47351 L
.81302 .47351 L
.8135 .47351 L
.81393 .47351 L
.81441 .47351 L
.81491 .47351 L
.81535 .47351 L
.81575 .4735 L
.81622 .4735 L
.81666 .47349 L
.81744 .47348 L
.81828 .47346 L
.8202 .47341 L
.82198 .47334 L
.82571 .47314 L
.82921 .47288 L
.83305 .47251 L
.83717 .47202 L
.84534 .47076 L
Mistroke
.85309 .46918 L
.86783 .46513 L
.88353 .45914 L
.89864 .45152 L
.91469 .441 L
.93016 .42782 L
.94505 .41109 L
.95275 .40007 L
.96088 .38556 L
.96454 .37749 L
.96847 .36705 L
.97037 .36091 L
.97217 .35403 L
.97378 .34629 L
.9747 .34064 L
.9751 .33759 L
.97554 .33347 L
.97588 .32922 L
.97619 .31956 L
Mfstroke
.08523 .16289 m
.08543 .15736 L
.08561 .15524 L
.08602 .15188 L
.08675 .14762 L
.08761 .14384 L
.08842 .14089 L
.09179 .13171 L
.09522 .12485 L
.09895 .11888 L
.10589 .11021 L
.11257 .10378 L
.11899 .09884 L
.12583 .09462 L
.13242 .09138 L
.13942 .08872 L
.14292 .08766 L
.14616 .08682 L
.1495 .08611 L
.15265 .08558 L
.15432 .08534 L
.15613 .08513 L
.15777 .08497 L
.15929 .08486 L
.16091 .08477 L
.16176 .08473 L
.16268 .0847 L
.16314 .08469 L
.16338 .08469 L
.16364 .08468 L
.16386 .08468 L
.16398 .08468 L
.16411 .08468 L
.16423 .08468 L
.16434 .08468 L
.16455 .08467 L
.16476 .08467 L
.16495 .08467 L
.16516 .08468 L
.16538 .08468 L
.16549 .08468 L
.16562 .08468 L
.16584 .08468 L
.16626 .08469 L
.16666 .0847 L
.16709 .08471 L
.16786 .08473 L
.16879 .08477 L
.16963 .08482 L
.17146 .08495 L
Mistroke
.17321 .08511 L
.17658 .08553 L
.1797 .08604 L
.18635 .08755 L
.19342 .08981 L
.20024 .09267 L
.20679 .09614 L
.21376 .10072 L
.22048 .1062 L
.22694 .11274 L
.23381 .12171 L
.23721 .12733 L
.24043 .13387 L
.24195 .1376 L
.24356 .14233 L
.2444 .14528 L
.24533 .1492 L
.24573 .15128 L
.24617 .15396 L
.24637 .15546 L
.24658 .15734 L
.24676 .15945 L
.24696 .1649 L
Mfstroke
.08523 .16296 m
.08543 .16849 L
.08561 .17061 L
.08602 .17397 L
.08675 .17825 L
.08761 .18203 L
.08842 .18499 L
.09179 .19422 L
.09522 .20113 L
.09895 .20714 L
.10589 .21591 L
.11257 .22244 L
.11899 .22748 L
.12583 .23181 L
.13242 .23516 L
.13942 .23795 L
.14616 .23997 L
.15265 .24135 L
.15599 .24185 L
.15784 .24206 L
.15955 .24223 L
.1613 .24236 L
.1622 .24241 L
.16319 .24246 L
.16405 .24249 L
.16485 .24251 L
.1653 .24252 L
.1657 .24253 L
.16593 .24253 L
.16604 .24253 L
.16617 .24253 L
.16628 .24253 L
.1664 .24253 L
.16661 .24253 L
.16682 .24253 L
.16701 .24253 L
.16722 .24253 L
.16734 .24253 L
.16745 .24253 L
.16766 .24252 L
.1679 .24252 L
.16833 .24251 L
.16872 .2425 L
.16914 .24249 L
.1699 .24247 L
.17077 .24243 L
.17158 .24238 L
.17344 .24225 L
.17521 .24209 L
.17688 .2419 L
Mistroke
.18003 .24145 L
.1834 .24083 L
.18653 .24012 L
.19318 .23818 L
.20025 .23543 L
.20706 .23202 L
.21362 .22792 L
.22059 .22248 L
.22731 .21587 L
.23376 .20764 L
.23736 .20182 L
.24064 .19522 L
.24219 .19137 L
.24389 .18629 L
.24466 .18345 L
.24548 .17982 L
.24619 .17574 L
.24638 .17431 L
.24659 .17246 L
.24678 .17014 L
.24696 .16496 L
Mfstroke
.941 .502 .502 r
.08523 .16289 m
.08543 .15736 L
.08561 .15524 L
.08602 .15188 L
.08675 .14762 L
.08761 .14384 L
.08842 .14089 L
.09179 .13171 L
.09522 .12485 L
.09895 .11888 L
.10589 .11021 L
.11257 .10378 L
.11899 .09884 L
.12583 .09462 L
.13242 .09138 L
.13942 .08872 L
.14292 .08766 L
.14616 .08682 L
.1495 .08611 L
.15265 .08558 L
.15432 .08534 L
.15613 .08513 L
.15777 .08497 L
.15929 .08486 L
.16091 .08477 L
.16176 .08473 L
.16268 .0847 L
.16314 .08469 L
.16338 .08469 L
.16364 .08468 L
.16386 .08468 L
.16398 .08468 L
.16411 .08468 L
.16423 .08468 L
.16434 .08468 L
.16455 .08467 L
.16476 .08467 L
.16495 .08467 L
.16516 .08468 L
.16538 .08468 L
.16549 .08468 L
.16562 .08468 L
.16584 .08468 L
.16626 .08469 L
.16666 .0847 L
.16709 .08471 L
.16786 .08473 L
.16879 .08477 L
.16963 .08482 L
.17146 .08495 L
.17321 .08511 L
.17658 .08553 L
.1797 .08604 L
.18635 .08755 L
.19342 .08981 L
.20024 .09267 L
.20679 .09614 L
.21376 .10072 L
.22048 .1062 L
.22694 .11274 L
.23381 .12171 L
.23721 .12733 L
.24043 .13387 L
.24195 .1376 L
.24356 .14233 L
.2444 .14528 L
.24533 .1492 L
.24573 .15128 L
.24617 .15396 L
.24637 .15546 L
.24658 .15734 L
.24676 .15945 L
.24696 .1649 L
.24696 .16496 L
.24678 .17014 L
.24659 .17246 L
.24638 .17431 L
.24619 .17574 L
.24548 .17982 L
.24466 .18345 L
.24389 .18629 L
.24219 .19137 L
.24064 .19522 L
.23736 .20182 L
.23376 .20764 L
.22731 .21587 L
.22059 .22248 L
.21362 .22792 L
.20706 .23202 L
.20025 .23543 L
.19318 .23818 L
.18653 .24012 L
.1834 .24083 L
.18003 .24145 L
.17688 .2419 L
.17521 .24209 L
.17344 .24225 L
.17158 .24238 L
.17077 .24243 L
.1699 .24247 L
.16914 .24249 L
.16872 .2425 L
.16833 .24251 L
.1679 .24252 L
.16766 .24252 L
.16745 .24253 L
.16734 .24253 L
.16722 .24253 L
.16701 .24253 L
.16682 .24253 L
.16661 .24253 L
.1664 .24253 L
.16628 .24253 L
.16617 .24253 L
.16604 .24253 L
.16593 .24253 L
.1657 .24253 L
.1653 .24252 L
.16485 .24251 L
.16405 .24249 L
.16319 .24246 L
.1622 .24241 L
.1613 .24236 L
.15955 .24223 L
.15784 .24206 L
.15599 .24185 L
.15265 .24135 L
.14616 .23997 L
.13942 .23795 L
.13242 .23516 L
.12583 .23181 L
.11899 .22748 L
.11257 .22244 L
.10589 .21591 L
.09895 .20714 L
.09522 .20113 L
.09179 .19422 L
.08842 .18499 L
.08761 .18203 L
.08675 .17825 L
.08602 .17397 L
.08561 .17061 L
.08543 .16849 L
.08523 .16296 L
F
0 0 0 r
.08523 .16289 m
.08543 .15736 L
.08561 .15524 L
.08602 .15188 L
.08675 .14762 L
.08761 .14384 L
.08842 .14089 L
.09179 .13171 L
.09522 .12485 L
.09895 .11888 L
.10589 .11021 L
.11257 .10378 L
.11899 .09884 L
.12583 .09462 L
.13242 .09138 L
.13942 .08872 L
.14292 .08766 L
.14616 .08682 L
.1495 .08611 L
.15265 .08558 L
.15432 .08534 L
.15613 .08513 L
.15777 .08497 L
.15929 .08486 L
.16091 .08477 L
.16176 .08473 L
.16268 .0847 L
.16314 .08469 L
.16338 .08469 L
.16364 .08468 L
.16386 .08468 L
.16398 .08468 L
.16411 .08468 L
.16423 .08468 L
.16434 .08468 L
.16455 .08467 L
.16476 .08467 L
.16495 .08467 L
.16516 .08468 L
.16538 .08468 L
.16549 .08468 L
.16562 .08468 L
.16584 .08468 L
.16626 .08469 L
.16666 .0847 L
.16709 .08471 L
.16786 .08473 L
.16879 .08477 L
.16963 .08482 L
.17146 .08495 L
Mistroke
.17321 .08511 L
.17658 .08553 L
.1797 .08604 L
.18635 .08755 L
.19342 .08981 L
.20024 .09267 L
.20679 .09614 L
.21376 .10072 L
.22048 .1062 L
.22694 .11274 L
.23381 .12171 L
.23721 .12733 L
.24043 .13387 L
.24195 .1376 L
.24356 .14233 L
.2444 .14528 L
.24533 .1492 L
.24573 .15128 L
.24617 .15396 L
.24637 .15546 L
.24658 .15734 L
.24676 .15945 L
.24696 .1649 L
Mfstroke
.08523 .16296 m
.08543 .16849 L
.08561 .17061 L
.08602 .17397 L
.08675 .17825 L
.08761 .18203 L
.08842 .18499 L
.09179 .19422 L
.09522 .20113 L
.09895 .20714 L
.10589 .21591 L
.11257 .22244 L
.11899 .22748 L
.12583 .23181 L
.13242 .23516 L
.13942 .23795 L
.14616 .23997 L
.15265 .24135 L
.15599 .24185 L
.15784 .24206 L
.15955 .24223 L
.1613 .24236 L
.1622 .24241 L
.16319 .24246 L
.16405 .24249 L
.16485 .24251 L
.1653 .24252 L
.1657 .24253 L
.16593 .24253 L
.16604 .24253 L
.16617 .24253 L
.16628 .24253 L
.1664 .24253 L
.16661 .24253 L
.16682 .24253 L
.16701 .24253 L
.16722 .24253 L
.16734 .24253 L
.16745 .24253 L
.16766 .24252 L
.1679 .24252 L
.16833 .24251 L
.16872 .2425 L
.16914 .24249 L
.1699 .24247 L
.17077 .24243 L
.17158 .24238 L
.17344 .24225 L
.17521 .24209 L
.17688 .2419 L
Mistroke
.18003 .24145 L
.1834 .24083 L
.18653 .24012 L
.19318 .23818 L
.20025 .23543 L
.20706 .23202 L
.21362 .22792 L
.22059 .22248 L
.22731 .21587 L
.23376 .20764 L
.23736 .20182 L
.24064 .19522 L
.24219 .19137 L
.24389 .18629 L
.24466 .18345 L
.24548 .17982 L
.24619 .17574 L
.24638 .17431 L
.24659 .17246 L
.24678 .17014 L
.24696 .16496 L
Mfstroke
.75304 .3201 m
.75324 .31463 L
.75342 .31253 L
.75383 .30922 L
.75456 .30501 L
.75542 .30128 L
.75623 .29837 L
.7596 .28931 L
.76303 .28254 L
.76676 .27667 L
.7737 .2681 L
.78038 .26175 L
.7868 .25685 L
.79364 .25265 L
.80023 .24942 L
.80723 .24674 L
.81073 .24567 L
.81397 .24482 L
.81731 .24409 L
.82046 .24354 L
.82213 .24329 L
.82394 .24306 L
.82558 .24289 L
.8271 .24277 L
.82872 .24266 L
.82957 .24262 L
.83049 .24258 L
.83095 .24257 L
.83145 .24255 L
.83192 .24254 L
.83215 .24254 L
.83236 .24254 L
.83257 .24253 L
.83275 .24253 L
.83296 .24253 L
.83307 .24253 L
.83319 .24253 L
.83341 .24253 L
.83361 .24253 L
.83383 .24253 L
.83395 .24253 L
.83407 .24253 L
.83446 .24254 L
.83468 .24254 L
.83489 .24254 L
.83576 .24257 L
.83651 .24259 L
.83732 .24262 L
.83917 .24273 L
.84086 .24287 L
Mistroke
.84409 .24322 L
.84761 .24376 L
.85096 .24441 L
.85452 .24526 L
.86159 .24747 L
.8684 .25028 L
.87496 .2537 L
.88193 .25825 L
.88864 .2637 L
.8951 .27025 L
.8987 .27465 L
.90198 .2793 L
.90515 .2846 L
.90859 .29172 L
.91015 .29571 L
.9118 .30085 L
.91322 .30666 L
.9136 .3087 L
.91402 .31134 L
.91421 .31281 L
.91441 .31467 L
.91458 .31674 L
.91477 .32211 L
Mfstroke
.75304 .32016 m
.75324 .32565 L
.75342 .32775 L
.75383 .33109 L
.75456 .33533 L
.75542 .33909 L
.75623 .34204 L
.7596 .35125 L
.76303 .35816 L
.76676 .3642 L
.7737 .37303 L
.78038 .37963 L
.7868 .38475 L
.79364 .38918 L
.80023 .39261 L
.80723 .39549 L
.81397 .3976 L
.82046 .39905 L
.8238 .39959 L
.82736 .40001 L
.82911 .40016 L
.83003 .40022 L
.831 .40028 L
.83185 .40032 L
.8323 .40033 L
.83278 .40035 L
.83322 .40036 L
.83363 .40037 L
.83404 .40038 L
.83442 .40038 L
.83462 .40038 L
.83482 .40039 L
.83502 .40039 L
.8352 .40039 L
.8354 .40039 L
.83562 .40039 L
.83573 .40038 L
.83585 .40038 L
.83606 .40038 L
.83629 .40038 L
.83653 .40038 L
.83697 .40037 L
.8378 .40035 L
.83859 .40032 L
.83943 .40028 L
.84093 .40019 L
.84253 .40006 L
.84426 .39989 L
.84737 .39948 L
.85096 .39886 L
Mistroke
.85437 .39811 L
.86087 .39625 L
.86778 .39359 L
.87443 .39029 L
.8815 .38587 L
.88832 .38051 L
.89487 .37402 L
.8982 .37006 L
.90185 .36501 L
.90509 .35966 L
.90856 .35255 L
.91023 .34829 L
.91181 .34336 L
.9125 .34077 L
.91323 .33753 L
.91361 .33551 L
.91403 .33283 L
.91421 .33141 L
.91441 .32959 L
.9146 .32729 L
.91477 .32217 L
Mfstroke
.941 .502 .502 r
.75304 .3201 m
.75324 .31463 L
.75342 .31253 L
.75383 .30922 L
.75456 .30501 L
.75542 .30128 L
.75623 .29837 L
.7596 .28931 L
.76303 .28254 L
.76676 .27667 L
.7737 .2681 L
.78038 .26175 L
.7868 .25685 L
.79364 .25265 L
.80023 .24942 L
.80723 .24674 L
.81073 .24567 L
.81397 .24482 L
.81731 .24409 L
.82046 .24354 L
.82213 .24329 L
.82394 .24306 L
.82558 .24289 L
.8271 .24277 L
.82872 .24266 L
.82957 .24262 L
.83049 .24258 L
.83095 .24257 L
.83145 .24255 L
.83192 .24254 L
.83215 .24254 L
.83236 .24254 L
.83257 .24253 L
.83275 .24253 L
.83296 .24253 L
.83307 .24253 L
.83319 .24253 L
.83341 .24253 L
.83361 .24253 L
.83383 .24253 L
.83395 .24253 L
.83407 .24253 L
.83446 .24254 L
.83468 .24254 L
.83489 .24254 L
.83576 .24257 L
.83651 .24259 L
.83732 .24262 L
.83917 .24273 L
.84086 .24287 L
.84409 .24322 L
.84761 .24376 L
.85096 .24441 L
.85452 .24526 L
.86159 .24747 L
.8684 .25028 L
.87496 .2537 L
.88193 .25825 L
.88864 .2637 L
.8951 .27025 L
.8987 .27465 L
.90198 .2793 L
.90515 .2846 L
.90859 .29172 L
.91015 .29571 L
.9118 .30085 L
.91322 .30666 L
.9136 .3087 L
.91402 .31134 L
.91421 .31281 L
.91441 .31467 L
.91458 .31674 L
.91477 .32211 L
.91477 .32217 L
.9146 .32729 L
.91441 .32959 L
.91421 .33141 L
.91403 .33283 L
.91361 .33551 L
.91323 .33753 L
.9125 .34077 L
.91181 .34336 L
.91023 .34829 L
.90856 .35255 L
.90509 .35966 L
.90185 .36501 L
.8982 .37006 L
.89487 .37402 L
.88832 .38051 L
.8815 .38587 L
.87443 .39029 L
.86778 .39359 L
.86087 .39625 L
.85437 .39811 L
.85096 .39886 L
.84737 .39948 L
.84426 .39989 L
.84253 .40006 L
.84093 .40019 L
.83943 .40028 L
.83859 .40032 L
.8378 .40035 L
.83697 .40037 L
.83653 .40038 L
.83629 .40038 L
.83606 .40038 L
.83585 .40038 L
.83573 .40038 L
.83562 .40039 L
.8354 .40039 L
.8352 .40039 L
.83502 .40039 L
.83482 .40039 L
.83462 .40038 L
.83442 .40038 L
.83404 .40038 L
.83363 .40037 L
.83322 .40036 L
.83278 .40035 L
.8323 .40033 L
.83185 .40032 L
.831 .40028 L
.83003 .40022 L
.82911 .40016 L
.82736 .40001 L
.8238 .39959 L
.82046 .39905 L
.81397 .3976 L
.80723 .39549 L
.80023 .39261 L
.79364 .38918 L
.7868 .38475 L
.78038 .37963 L
.7737 .37303 L
.76676 .3642 L
.76303 .35816 L
.7596 .35125 L
.75623 .34204 L
.75542 .33909 L
.75456 .33533 L
.75383 .33109 L
.75342 .32775 L
.75324 .32565 L
.75304 .32016 L
F
0 0 0 r
.75304 .3201 m
.75324 .31463 L
.75342 .31253 L
.75383 .30922 L
.75456 .30501 L
.75542 .30128 L
.75623 .29837 L
.7596 .28931 L
.76303 .28254 L
.76676 .27667 L
.7737 .2681 L
.78038 .26175 L
.7868 .25685 L
.79364 .25265 L
.80023 .24942 L
.80723 .24674 L
.81073 .24567 L
.81397 .24482 L
.81731 .24409 L
.82046 .24354 L
.82213 .24329 L
.82394 .24306 L
.82558 .24289 L
.8271 .24277 L
.82872 .24266 L
.82957 .24262 L
.83049 .24258 L
.83095 .24257 L
.83145 .24255 L
.83192 .24254 L
.83215 .24254 L
.83236 .24254 L
.83257 .24253 L
.83275 .24253 L
.83296 .24253 L
.83307 .24253 L
.83319 .24253 L
.83341 .24253 L
.83361 .24253 L
.83383 .24253 L
.83395 .24253 L
.83407 .24253 L
.83446 .24254 L
.83468 .24254 L
.83489 .24254 L
.83576 .24257 L
.83651 .24259 L
.83732 .24262 L
.83917 .24273 L
.84086 .24287 L
Mistroke
.84409 .24322 L
.84761 .24376 L
.85096 .24441 L
.85452 .24526 L
.86159 .24747 L
.8684 .25028 L
.87496 .2537 L
.88193 .25825 L
.88864 .2637 L
.8951 .27025 L
.8987 .27465 L
.90198 .2793 L
.90515 .2846 L
.90859 .29172 L
.91015 .29571 L
.9118 .30085 L
.91322 .30666 L
.9136 .3087 L
.91402 .31134 L
.91421 .31281 L
.91441 .31467 L
.91458 .31674 L
.91477 .32211 L
Mfstroke
.75304 .32016 m
.75324 .32565 L
.75342 .32775 L
.75383 .33109 L
.75456 .33533 L
.75542 .33909 L
.75623 .34204 L
.7596 .35125 L
.76303 .35816 L
.76676 .3642 L
.7737 .37303 L
.78038 .37963 L
.7868 .38475 L
.79364 .38918 L
.80023 .39261 L
.80723 .39549 L
.81397 .3976 L
.82046 .39905 L
.8238 .39959 L
.82736 .40001 L
.82911 .40016 L
.83003 .40022 L
.831 .40028 L
.83185 .40032 L
.8323 .40033 L
.83278 .40035 L
.83322 .40036 L
.83363 .40037 L
.83404 .40038 L
.83442 .40038 L
.83462 .40038 L
.83482 .40039 L
.83502 .40039 L
.8352 .40039 L
.8354 .40039 L
.83562 .40039 L
.83573 .40038 L
.83585 .40038 L
.83606 .40038 L
.83629 .40038 L
.83653 .40038 L
.83697 .40037 L
.8378 .40035 L
.83859 .40032 L
.83943 .40028 L
.84093 .40019 L
.84253 .40006 L
.84426 .39989 L
.84737 .39948 L
.85096 .39886 L
Mistroke
.85437 .39811 L
.86087 .39625 L
.86778 .39359 L
.87443 .39029 L
.8815 .38587 L
.88832 .38051 L
.89487 .37402 L
.8982 .37006 L
.90185 .36501 L
.90509 .35966 L
.90856 .35255 L
.91023 .34829 L
.91181 .34336 L
.9125 .34077 L
.91323 .33753 L
.91361 .33551 L
.91403 .33283 L
.91421 .33141 L
.91441 .32959 L
.9146 .32729 L
.91477 .32217 L
Mfstroke
4 Mabswid
.15694 .16155 Mdot
.84306 .32352 Mdot
gsave
.18601 .01155 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.20392 .32895 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18601 .01155 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.20392 .32895 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.79509 .15611 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.8135 .47351 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.79509 .15611 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.8135 .47351 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16455 .08467 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16682 .24253 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16455 .08467 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16682 .24253 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83307 .24253 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.8354 .40039 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83307 .24253 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.8354 .40039 -70.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{400, 194},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000`R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3kk=R@0?_/f040oooo003o0?_/f900nncH0@3oool00?l0nncHT03kk=P10?ooo`00o`3k
k=R@0?_/f040oooo003o0?_/f900nncH0@3oool004L0nncH0`0000160?_/f0D00000AP3kk=P60000
0480nncH0`0000170?_/f0H00000703kk=P10?ooo`00AP3kk=P00`000000nncH0?_/f002000004D0
nncH0P00001;0?_/f0800000@`3kk=P2000000030?_/f0000000000004P0nncH0P00000N0?_/f040
oooo000n0?_/f0D000001P3kk=P2000003d0nncH1@0000040?_/f0800000@03kk=P5000000D0nncH
0P0000130?_/f080000000<0nncH000000000000B03kk=P2000001h0nncH0@3oool004T0nncH0P00
00170?_/f0800000B@3kk=P2000004<0nncH0P0000000`3kk=P00000000000180?_/f08000007P3k
k=P10?ooo`00A`3kk=P3000004T0nncH0P0000180?_/f0800000@`3kk=P2000000030?_/f0000000
000004P0nncH0P00000N0?_/f040oooo00190?_/f0800000A@3kk=P2000000030?_/f00000000000
04P0nncH0P0000130?_/f080000000<0nncH000000000000B03kk=P2000001h0nncH0@3oool004H0
nncH00<000000?_/f03kk=P00P0000150?_/f080000000<0nncH000000000000AP3kk=P4000004<0
nncH0P0000000`3kk=P00000000000160?_/f0@000007P3kk=P10?ooo`00A`3kk=P3000004L0nncH
0`0000190?_/f0800000A03kk=P3000004T0nncH0P00000N0?_/f040oooo003o0?_/f900nncH0@3o
ool00?l0nncHT03kk=P10?ooo`00o`3kk=R@0?_/f040oooo003o0?_/f900nncH0@3oool00?l0nncH
T03kk=P10?ooo`00o`3kk=R@0?_/f040oooo000_0?_/f0H000001P3kk=So000003l000005P3kk=P1
0?ooo`00<@3kk=P2000000P0nncH00<000000?_/f03kk=P01P3kk=P00`000000nncH0?_/f00<0?_/
f0030000003kk=P0nncH00`0nncH00<000000?_/f03kk=P02`3kk=P5000000<0nncH0P0000060?_/
f0030000003kk=P0nncH00`0nncH00<000000?_/f03kk=P0303kk=P00`000000nncH0?_/f00<0?_/
f0030000003kk=P0nncH00`0nncH00<000000?_/f03kk=P0303kk=P00`000000nncH0?_/f00<0?_/
f0030000003kk=P0nncH00`0nncH00<000000?_/f03kk=P0303kk=P00`000000nncH0?_/f00<0?_/
f0030000003kk=P0nncH00/0nncH00<000000?_/f03kk=P0303kk=P00`000000nncH0?_/f00<0?_/
f0030000003kk=P0nncH00`0nncH00<000000?_/f03kk=P0303kk=P00`000000nncH0?_/f00<0?_/
f0030000003kk=P0nncH00`0nncH00<000000?_/f03kk=P01P3kk=P00`000000nncH0?_/f00D0?_/
f040oooo000W0?_/f0D000001@3kk=P2000000P0nncH0`0000060?_/f0030000003kk=P0nncH02T0
nncH0P0000060?_/f08000005@3kk=P00`000000nncH0?_/f0180?_/f0030000003kk=P0nncH04L0
nncH00<000000?_/f03kk=P0B03kk=P00`000000nncH0?_/f0040?_/f0<000005P3kk=P10?ooo`00
<@3kk=P2000000P0nncH00<000000?_/f03kk=P0<`3kk=P200000?l0nncH1P3kk=P00`000000nncH
0?_/f00D0?_/f040oooo000a0?_/f0800000203kk=P00`000000nncH0?_/f00`0?_/f1<00000m`3k
k=P00`000000nncH0?_/f00D0?_/f040oooo000a0?_/f0800000203kk=P00`000000nncH0?_/f00[
0?_/f0D000001@1VcJX2000000`0I/fZ1000003c0?_/f0030000003kk=P0nncH01@0nncH0@3oool0
02l0nncH100000080?_/f0030000003kk=P0nncH02H0nncH1@00000706K=ZP80000000<0I/fZ0000
00000000401VcJX400000>l0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00<@3kk=P2000000P0
nncH00<000000?_/f03kk=P0903kk=P2000000`0I/fZ0P0000000`1VcJX000000000000D06K=ZP80
0000k@3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH0280nncH
0P00000?06K=ZP<000005`1VcJX300000>X0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3k
k=P00`000000nncH0?_/f00P0?_/f0800000;P1VcJX200000>P0nncH00<000000?_/f03kk=P0503k
k=P10?ooo`00>`3kk=P2000001l0nncH0P00000b06K=ZP<00000i03kk=P2000001H0nncH0@3oool0
03/0nncH00<000000?_/f03kk=P07@3kk=P00`000000I/fZ06K=ZP0e06K=ZP800000h`3kk=P00`00
0000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH01/0nncH0P00000j06K=ZP80
0000h@3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH01T0nncH
0P00000n06K=ZP030000003kk=P0nncH0=h0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3k
k=P00`000000nncH0?_/f00H0?_/f0030000001VcJX0I/fZ03l0I/fZ0P00003N0?_/f0030000003k
k=P0nncH01@0nncH0@3oool003/0nncH00<000000?_/f03kk=P05`3kk=P00`000000I/fZ06K=ZP12
06K=ZP030000003kk=P0nncH0=/0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`00
0000nncH0?_/f00E0?_/f0800000AP1VcJX00`000000nncH0?_/f03J0?_/f0030000003kk=P0nncH
01@0nncH0@3oool003/0nncH0P00000E0?_/f0030000001VcJX0I/fZ04L0I/fZ00<000000?_/f03k
k=P0f03kk=P2000001H0nncH0@3oool003/0nncH00<000000?_/f03kk=P04`3kk=P00`000000I/fZ
06K=ZP1906K=ZP800000f@3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003k
k=P0nncH0180nncH00<0000006K=ZP1VcJX0C01VcJX00`000000nncH0?_/f03F0?_/f0030000003k
k=P0nncH01@0nncH0@3oool003/0nncH00<000000?_/f03kk=P04@3kk=P00`000000I/fZ06K=ZP1>
06K=ZP030000003kk=P0nncH0=D0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`00
0000nncH0?_/f00@0?_/f0030000001VcJX0I/fZ0500I/fZ00<000000?_/f03kk=P0e03kk=P00`00
0000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH00l0nncH00<0000006K=ZP1V
cJX0DP1VcJX00`000000nncH0?_/f03C0?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH
00<000000?_/f03kk=P03P3kk=P00`000000I/fZ06K=ZP1D06K=ZP030000003kk=P0nncH0=80nncH
00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f00=0?_/f0030000001V
cJX0I/fZ05H0I/fZ00<000000?_/f03kk=P0d@3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k
0?_/f08000003P3kk=P00`000000I/fZ06K=ZP0K06K=ZPH000000P1VcJX200000380I/fZ00<00000
0?_/f03kk=P0c`3kk=P2000001H0nncH0@3oool003/0nncH00<000000?_/f03kk=P0303kk=P00`00
0000I/fZ06K=ZP0N06K=ZP800000101VcJX2000003<0I/fZ00<000000?_/f03kk=P0c`3kk=P00`00
0000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH00`0nncH00<0000006K=ZP1V
cJX07@1VcJX;00000380I/fZ00<000000?_/f03kk=P0cP3kk=P00`000000nncH0?_/f00D0?_/f040
oooo000k0?_/f0030000003kk=P0nncH00/0nncH00<0000006K=ZP1VcJX06`1VcJX3000000030?20
P0000000000000P0l8200P00000a06K=ZP030000003kk=P0nncH0<d0nncH00<000000?_/f03kk=P0
503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f00;0?_/f0030000001VcJX0I/fZ01T0I/fZ0P00
00040?20P08000002P3`P805000002d0I/fZ00<000000?_/f03kk=P0c03kk=P00`000000nncH0?_/
f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH00X0nncH00<0000006K=ZP1VcJX0601VcJX2
000000H0l8200P00000?0?20P0030000001VcJX0I/fZ02/0I/fZ00<000000?_/f03kk=P0b`3kk=P0
0`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH00X0nncH00<0000006K=
ZP1VcJX05P1VcJX2000000H0l8201000000@0?20P0030000001VcJX0I/fZ02/0I/fZ00<000000?_/
f03kk=P0bP3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f08000002P3kk=P00`000000
I/fZ06K=ZP0F06K=ZP030000003`P800l82000P0l8200P00000A0?20P0800000:`1VcJX00`000000
nncH0?_/f0390?_/f08000005P3kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f0090?_/f0030000
001VcJX0I/fZ01D0I/fZ00<000000?20P03`P8007P3`P8000`000000I/fZ06K=ZP0Y06K=ZP030000
003kk=P0nncH0<T0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/
f0080?_/f0030000001VcJX0I/fZ01D0I/fZ00<000000?20P03`P800803`P8000`000000I/fZ06K=
ZP0Y06K=ZP030000003kk=P0nncH0<P0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P0
0`000000nncH0?_/f0080?_/f0030000001VcJX0I/fZ01@0I/fZ00<000000?20P03`P8008P3`P800
0`000000I/fZ06K=ZP0Y06K=ZP030000003kk=P0nncH0<L0nncH00<000000?_/f03kk=P0503kk=P1
0?ooo`00>`3kk=P00`000000nncH0?_/f0080?_/f0030000001VcJX0I/fZ01<0I/fZ00<000000?20
P03`P800903`P8000`000000I/fZ06K=ZP0X06K=ZP030000003kk=P0nncH0<L0nncH00<000000?_/
f03kk=P0503kk=P10?ooo`008P3kk=P3000000@0nncH0P0000050?_/f0<00000203kk=P00`000000
nncH0?_/f0070?_/f0030000001VcJX0I/fZ01<0I/fZ00<000000?20P03`P8009P3`P8000`000000
I/fZ06K=ZP0X06K=ZP030000003kk=P0nncH0<H0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00
8@3kk=P2000000030?_/f0000000000000<0nncH0P0000040?_/f0030000003kk=P0nncH00800000
1`3kk=P00`000000nncH0?_/f0070?_/f0030000001VcJX0I/fZ0180I/fZ00<000000?20P03`P800
9`3`P8000`000000I/fZ06K=ZP0X06K=ZP030000003kk=P0nncH0<H0nncH00<000000?_/f03kk=P0
503kk=P10?ooo`006@3kk=P5000000<0nncH0P0000000`3kk=P000000000000<0?_/f08000001`3k
k=P00`000000nncH0?_/f0060?_/f0030000001VcJX0I/fZ0180I/fZ00<000000?20P03`P800:@3`
P8000`000000I/fZ06K=ZP0X06K=ZP030000003kk=P0nncH0<D0nncH00<000000?_/f03kk=P0503k
k=P10?ooo`008@3kk=P2000000030?_/f0000000000000`0nncH0P0000070?_/f0<000001P3kk=P0
0`000000I/fZ06K=ZP0B06K=ZP030000003`P800l82002X0l82000<0000006K=ZP1VcJX0:01VcJX0
0`000000nncH0?_/f0320?_/f0<000005P3kk=P10?ooo`008@3kk=P2000000030?_/f00000000000
00T0nncH00<000000?_/f03kk=P00P0000070?_/f0030000003kk=P0nncH00H0nncH00<0000006K=
ZP1VcJX04@1VcJX00`000000l8200?20P00[0?20P0030000001VcJX0I/fZ02P0I/fZ00<000000?_/
f03kk=P0a03kk=P00`000000nncH0?_/f00D0?_/f040oooo000Q0?_/f080000000<0nncH00000000
00002@3kk=P4000000P0nncH00<000000?_/f03kk=P01P3kk=P00`000000I/fZ06K=ZP0A06K=ZP03
0000003`P800l82002`0l82000<0000006K=ZP1VcJX0:01VcJX00`000000nncH0?_/f0330?_/f003
0000003kk=P0nncH01@0nncH0@3oool00240nncH0P0000000`3kk=P00000000000090?_/f0800000
2P3kk=P00`000000nncH0?_/f0060?_/f0030000001VcJX0I/fZ0140I/fZ00<000000?20P03`P800
;03`P8000`000000I/fZ06K=ZP0X06K=ZP030000003kk=P0nncH0<<0nncH00<000000?_/f03kk=P0
503kk=P10?ooo`008P3kk=P3000000X0nncH1@0000070?_/f0030000003kk=P0nncH00D0nncH00<0
000006K=ZP1VcJX04@1VcJX00`000000l8200?20P00^0?20P0030000001VcJX0I/fZ02P0I/fZ00<0
00000?_/f03kk=P0`P3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0
nncH00D0nncH00<0000006K=ZP1VcJX04@1VcJX00`000000l8200?20P00^0?20P0030000001VcJX0
I/fZ02P0I/fZ00<000000?_/f03kk=P0`P3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/
f0030000003kk=P0nncH00D0nncH00<0000006K=ZP1VcJX04@1VcJX00`000000l8200?20P00_0?20
P0030000001VcJX0I/fZ02P0I/fZ00<000000?_/f03kk=P0`@3kk=P00`000000nncH0?_/f00D0?_/
f040oooo000k0?_/f08000001P3kk=P00`000000I/fZ06K=ZP0A06K=ZP030000003`P800l82002l0
l82000<0000006K=ZP1VcJX0:01VcJX00`000000nncH0?_/f01j0?_/f0D000000`3kk=P2000003`0
nncH0P00000F0?_/f040oooo000k0?_/f0030000003kk=P0nncH00D0nncH00<0000006K=ZP1VcJX0
401VcJX00`000000l8200?20P00`0?20P0030000001VcJX0I/fZ02T0I/fZ00<000000?_/f03kk=P0
N@3kk=P2000000H0nncH0P00000m0?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH00<0
00000?_/f03kk=P01@3kk=P00`000000I/fZ06K=ZP0@06K=ZP030000003`P800l8200300l82000<0
000006K=ZP1VcJX0:@1VcJX00`000000nncH0?_/f01j0?_/f0800000A03kk=P00`000000nncH0?_/
f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH00D0nncH00<0000006K=ZP1VcJX0401VcJX0
0`000000l8200?20P00C0?20P08000006`3`P8000`000000I/fZ06K=ZP0Y06K=ZP030000003kk=P0
nncH07@0nncH6000000d0?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH00<000000?_/
f03kk=P01@3kk=P00`000000I/fZ06K=ZP0@06K=ZP030000003`P800l8200180l8201000000J0?20
P0030000001VcJX0I/fZ02X0I/fZ00<000000?_/f03kk=P0KP3kk=P5000000P0I/fZ0P00000>06K=
ZP@00000<03kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH00D0
nncH00<0000006K=ZP1VcJX0401VcJX00`000000l8200?20P00B0?20P0@000006P3`P8000`000000
I/fZ06K=ZP0Z06K=ZP030000003kk=P0nncH06`0nncH0P00000:06K=ZP80000000<0I/fZ00000000
00004P1VcJX4000002`0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH
0?_/f0050?_/f0030000001VcJX0I/fZ0100I/fZ00<000000?20P03`P8004`3`P802000001/0l820
00<0000006K=ZP1VcJX0:P1VcJX00`000000nncH0?_/f01X0?_/f0@00000301VcJX20000000306K=
ZP000000000001H0I/fZ0P00000Z0?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH00<0
00000?_/f03kk=P01@3kk=P00`000000I/fZ06K=ZP0@06K=ZP030000003`P800l8200300l82000<0
000006K=ZP1VcJX0:P1VcJX00`000000nncH0?_/f01T0?_/f0@000004@1VcJX3000001T0I/fZ0`00
000W0?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH0P0000060?_/f0030000001VcJX0
I/fZ0100I/fZ00<000000?20P03`P800<03`P8000`000000I/fZ06K=ZP0[06K=ZP030000003kk=P0
nncH0640nncH0P00000d06K=ZP800000903kk=P2000001H0nncH0@3oool003/0nncH00<000000?_/
f03kk=P01@3kk=P00`000000I/fZ06K=ZP0@06K=ZP030000003`P800l8200300l82000<0000006K=
ZP1VcJX0:`1VcJX00`000000nncH0?_/f01O0?_/f0800000>01VcJX2000002<0nncH00<000000?_/
f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f0050?_/f0030000001VcJX0I/fZ0140
I/fZ00<000000?20P03`P800;`3`P8000`000000I/fZ06K=ZP0[06K=ZP030000003kk=P0nncH05d0
nncH0P00000l06K=ZP8000008@3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000
003kk=P0nncH00D0nncH00<0000006K=ZP1VcJX04@1VcJX00`000000l8200?20P00_0?20P0030000
001VcJX0I/fZ02/0I/fZ00<000000?_/f03kk=P0F`3kk=P200000400I/fZ0P00000O0?_/f0030000
003kk=P0nncH01@0nncH0@3oool003/0nncH00<000000?_/f03kk=P01@3kk=P00`000000I/fZ06K=
ZP0A06K=ZP030000003`P800l82002h0l82000<0000006K=ZP1VcJX0;01VcJX00`000000nncH0?_/
f01J0?_/f0030000001VcJX0I/fZ0480I/fZ00<000000?_/f03kk=P0703kk=P00`000000nncH0?_/
f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH00D0nncH00<0000006K=ZP1VcJX04@1VcJX0
0`000000l8200?20P00^0?20P0030000001VcJX0I/fZ02`0I/fZ00<000000?_/f03kk=P0F@3kk=P0
0`000000I/fZ06K=ZP1406K=ZP030000003kk=P0nncH01/0nncH00<000000?_/f03kk=P0503kk=P1
0?ooo`00>`3kk=P00`000000nncH0?_/f0050?_/f0030000001VcJX0I/fZ0180I/fZ00<000000?20
P03`P800;@3`P8000`000000I/fZ06K=ZP0/06K=ZP030000003kk=P0nncH05L0nncH0P00001806K=
ZP8000006`3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f08000001`3kk=P00`000000
I/fZ06K=ZP0A06K=ZP030000003`P800l82002`0l82000<0000006K=ZP1VcJX0;@1VcJX00`000000
nncH0?_/f01F0?_/f0030000001VcJX0I/fZ04X0I/fZ00<000000?_/f03kk=P05`3kk=P2000001H0
nncH0@3oool003/0nncH00<000000?_/f03kk=P01P3kk=P00`000000I/fZ06K=ZP0A06K=ZP030000
003`P800l82002/0l82000<0000006K=ZP1VcJX0;P1VcJX00`000000nncH0?_/f01D0?_/f0800000
CP1VcJX00`000000nncH0?_/f00G0?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH00<0
00000?_/f03kk=P01P3kk=P00`000000I/fZ06K=ZP0B06K=ZP030000003`P800l82002X0l82000<0
000006K=ZP1VcJX0;P1VcJX00`000000nncH0?_/f01B0?_/f0800000D@1VcJX00`000000nncH0?_/
f00F0?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH00<000000?_/f03kk=P01P3kk=P0
0`000000I/fZ06K=ZP0B06K=ZP030000003`P800l82002T0l82000<0000006K=ZP1VcJX0;`1VcJX0
0`000000nncH0?_/f01A0?_/f0030000001VcJX0I/fZ0580I/fZ00<000000?_/f03kk=P05@3kk=P0
0`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH00H0nncH00<0000006K=
ZP1VcJX04`1VcJX00`000000l8200?20P00X0?20P0030000001VcJX0I/fZ02l0I/fZ00<000000?_/
f03kk=P0D03kk=P00`000000I/fZ06K=ZP1D06K=ZP030000003kk=P0nncH01@0nncH00<000000?_/
f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f0070?_/f0030000001VcJX0I/fZ01<0
I/fZ00<000000?20P03`P8009P3`P8000`000000I/fZ06K=ZP0`06K=ZP030000003kk=P0nncH04h0
nncH0P00001H06K=ZP030000003kk=P0nncH01<0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00
>`3kk=P00`000000nncH0?_/f0070?_/f0030000001VcJX0I/fZ01@0I/fZ00<000000?20P03`P800
9@3`P8000`000000I/fZ06K=ZP0`06K=ZP030000003kk=P0nncH04d0nncH00<0000006K=ZP1VcJX0
F@1VcJX00`000000nncH0?_/f00B0?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH0P00
00090?_/f0030000001VcJX0I/fZ01@0I/fZ00<000000?20P03`P8008`3`P8000`000000I/fZ06K=
ZP0`06K=ZP030000003kk=P0nncH04d0nncH00<0000006K=ZP1VcJX0F`1VcJX00`000000nncH0?_/
f00@0?_/f08000005P3kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f0080?_/f0030000001VcJX0
I/fZ01D0I/fZ00<000000?20P03`P8008@3`P8000`000000I/fZ06K=ZP0a06K=ZP030000003kk=P0
nncH04`0nncH00<0000006K=ZP1VcJX0G@1VcJX00`000000nncH0?_/f00@0?_/f0030000003kk=P0
nncH01@0nncH0@3oool003/0nncH00<000000?_/f03kk=P0203kk=P00`000000I/fZ06K=ZP0F06K=
ZP030000003`P800l82001l0l82000<0000006K=ZP1VcJX0<@1VcJX00`000000nncH0?_/f01=0?_/
f0030000001VcJX0I/fZ05h0I/fZ00<000000?_/f03kk=P03`3kk=P00`000000nncH0?_/f00D0?_/
f040oooo000k0?_/f0030000003kk=P0nncH00T0nncH00<0000006K=ZP1VcJX05P1VcJX2000001d0
l8200P00000d06K=ZP030000003kk=P0nncH04`0nncH00<0000006K=ZP1VcJX0H01VcJX00`000000
nncH0?_/f00>0?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH00<000000?_/f03kk=P0
2@3kk=P00`000000I/fZ06K=ZP0H06K=ZP030000003`P800l82001T0l82000<0000006K=ZP1VcJX0
=01VcJX00`000000nncH0?_/f01;0?_/f0030000001VcJX0I/fZ0680I/fZ00<000000?_/f03kk=P0
3@3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH00X0nncH00<0
000006K=ZP1VcJX0601VcJX00`000000l8200?20P00G0?20P0030000001VcJX0I/fZ03D0I/fZ00<0
00000?_/f03kk=P0BP3kk=P00`000000I/fZ06K=ZP1S06K=ZP030000003kk=P0nncH00d0nncH00<0
00000?_/f03kk=P0503kk=P10?ooo`00<03kk=P3000000P0nncH00<000000?_/f03kk=P02P3kk=P0
0`000000I/fZ06K=ZP0I06K=ZP800000103`P80600000080l8200P0000060?20P0<00000=`1VcJX0
0`000000nncH0?_/f01;0?_/f0030000001VcJX0I/fZ03P0I/fZ1P00000206K=ZP8000008P1VcJX0
0`000000nncH0?_/f00<0?_/f0030000003kk=P0nncH01@0nncH0@3oool002l0nncH0P0000000`3k
k=P00000000000070?_/f0030000003kk=P0nncH00/0nncH00<0000006K=ZP1VcJX06P1VcJX40000
0080l8200P0000040?20P080000000<0l8200000000000000`00000i06K=ZP030000003kk=P0nncH
04/0nncH00<0000006K=ZP1VcJX0>`1VcJX2000000@0I/fZ0P00000S06K=ZP030000003kk=P0nncH
00/0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00;`3kk=P2000000030?_/f0000000000000L0
nncH0`00000;0?_/f0030000001VcJX0I/fZ01h0I/fZ2`00000m06K=ZP030000003kk=P0nncH04`0
nncH00<0000006K=ZP1VcJX0>P1VcJX;00000240I/fZ00<000000?_/f03kk=P02@3kk=P3000001H0
nncH0@3oool002l0nncH0P0000000`3kk=P00000000000070?_/f0030000003kk=P0nncH00`0nncH
00<0000006K=ZP1VcJX07`1VcJX2000004@0I/fZ00<000000?_/f03kk=P0B`3kk=P00`000000I/fZ
06K=ZP0h06K=ZP<0000000<0l820000000000000203`P80200000200I/fZ00<000000?_/f03kk=P0
2P3kk=P00`000000nncH0?_/f00D0?_/f040oooo000_0?_/f080000000<0nncH0000000000001`3k
k=P00`000000nncH0?_/f00<0?_/f0030000001VcJX0I/fZ01l0I/fZ0P00001306K=ZP030000003k
k=P0nncH04`0nncH00<0000006K=ZP1VcJX0=P1VcJX2000000@0l8200P00000:0?20P0D000006`1V
cJX00`000000nncH0?_/f00:0?_/f0030000003kk=P0nncH01@0nncH0@3oool002l0nncH0P000000
0`3kk=P00000000000070?_/f0030000003kk=P0nncH00d0nncH00<0000006K=ZP1VcJX07P1VcJX2
000004<0I/fZ00<000000?_/f03kk=P0B`3kk=P00`000000I/fZ06K=ZP0e06K=ZP8000001P3`P802
000000l0l82000<0000006K=ZP1VcJX06@1VcJX00`000000nncH0?_/f0090?_/f0030000003kk=P0
nncH01@0nncH0@3oool002l0nncH0P0000000`3kk=P00000000000070?_/f0030000003kk=P0nncH
00d0nncH00<0000006K=ZP1VcJX0701VcJX400000480I/fZ00<000000?_/f03kk=P0C03kk=P00`00
0000I/fZ06K=ZP0d06K=ZP030000003`P800l82000@0l8201000000@0?20P0030000001VcJX0I/fZ
01P0I/fZ00<000000?_/f03kk=P02@3kk=P00`000000nncH0?_/f00D0?_/f040oooo000`0?_/f0<0
0000203kk=P00`000000nncH0?_/f00>0?_/f0030000001VcJX0I/fZ01d0I/fZ0P00001106K=ZP03
0000003kk=P0nncH04`0nncH00<0000006K=ZP1VcJX0=01VcJX00`000000l8200?20P0070?20P080
00004@3`P802000001T0I/fZ00<000000?_/f03kk=P0203kk=P00`000000nncH0?_/f00D0?_/f040
oooo000k0?_/f0030000003kk=P0nncH00l0nncH00<0000006K=ZP1VcJX0G`1VcJX00`000000nncH
0?_/f01;0?_/f0030000001VcJX0I/fZ03<0I/fZ0P00000O0?20P0030000001VcJX0I/fZ01H0I/fZ
00<000000?_/f03kk=P0203kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f08000004@3k
k=P00`000000I/fZ06K=ZP1M06K=ZP030000003kk=P0nncH04`0nncH00<0000006K=ZP1VcJX0<P1V
cJX00`000000l8200?20P00P0?20P0030000001VcJX0I/fZ01D0I/fZ00<000000?_/f03kk=P01`3k
k=P2000001H0nncH0@3oool003/0nncH00<000000?_/f03kk=P0403kk=P00`000000I/fZ06K=ZP1L
06K=ZP030000003kk=P0nncH04d0nncH00<0000006K=ZP1VcJX0<@1VcJX00`000000l8200?20P00R
0?20P0030000001VcJX0I/fZ01D0I/fZ00<000000?_/f03kk=P01`3kk=P00`000000nncH0?_/f00D
0?_/f040oooo000k0?_/f0030000003kk=P0nncH0140nncH00<0000006K=ZP1VcJX0FP1VcJX00`00
0000nncH0?_/f01>0?_/f0030000001VcJX0I/fZ0300I/fZ00<000000?20P03`P800903`P8000`00
0000I/fZ06K=ZP0D06K=ZP030000003kk=P0nncH00L0nncH00<000000?_/f03kk=P0503kk=P10?oo
o`00>`3kk=P00`000000nncH0?_/f00B0?_/f0030000001VcJX0I/fZ05P0I/fZ00<000000?_/f03k
k=P0C`3kk=P00`000000I/fZ06K=ZP0_06K=ZP030000003`P800l82002H0l82000<0000006K=ZP1V
cJX04`1VcJX00`000000nncH0?_/f0070?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH
00<000000?_/f03kk=P04`3kk=P00`000000I/fZ06K=ZP1F06K=ZP030000003kk=P0nncH0500nncH
00<0000006K=ZP1VcJX0;P1VcJX00`000000l8200?20P00W0?20P0030000001VcJX0I/fZ01@0I/fZ
00<000000?_/f03kk=P01P3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003k
k=P0nncH01@0nncH00<0000006K=ZP1VcJX0E01VcJX00`000000nncH0?_/f01@0?_/f0030000001V
cJX0I/fZ02h0I/fZ00<000000?20P03`P800:@3`P8000`000000I/fZ06K=ZP0C06K=ZP030000003k
k=P0nncH00H0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f00E
0?_/f0800000DP1VcJX2000005<0nncH00<0000006K=ZP1VcJX0;P1VcJX00`000000l8200?20P00Z
0?20P0030000001VcJX0I/fZ01<0I/fZ00<000000?_/f03kk=P01@3kk=P00`000000nncH0?_/f00D
0?_/f040oooo000k0?_/f0030000003kk=P0nncH01L0nncH00<0000006K=ZP1VcJX0C@1VcJX20000
05D0nncH00<0000006K=ZP1VcJX0;@1VcJX00`000000l8200?20P00[0?20P0030000001VcJX0I/fZ
01<0I/fZ00<000000?_/f03kk=P01@3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f080
00006@3kk=P00`000000I/fZ06K=ZP1;06K=ZP030000003kk=P0nncH05D0nncH00<0000006K=ZP1V
cJX0;@1VcJX00`000000l8200?20P00/0?20P0030000001VcJX0I/fZ0180I/fZ00<000000?_/f03k
k=P0103kk=P2000001H0nncH0@3oool003/0nncH00<000000?_/f03kk=P06@3kk=P2000004T0I/fZ
0P00001H0?_/f0030000001VcJX0I/fZ02d0I/fZ00<000000?20P03`P800;03`P8000`000000I/fZ
06K=ZP0B06K=ZP030000003kk=P0nncH00D0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3k
k=P00`000000nncH0?_/f00K0?_/f0800000A@1VcJX2000005X0nncH00<0000006K=ZP1VcJX0;01V
cJX00`000000l8200?20P00^0?20P0030000001VcJX0I/fZ0140I/fZ00<000000?_/f03kk=P01@3k
k=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH01d0nncH00<00000
06K=ZP1VcJX0@@1VcJX00`000000nncH0?_/f01J0?_/f0030000001VcJX0I/fZ02`0I/fZ00<00000
0?20P03`P800;P3`P8000`000000I/fZ06K=ZP0A06K=ZP030000003kk=P0nncH00D0nncH00<00000
0?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f00N0?_/f0800000?`1VcJX20000
05d0nncH00<0000006K=ZP1VcJX0;01VcJX00`000000l8200?20P00^0?20P0030000001VcJX0I/fZ
0140I/fZ00<000000?_/f03kk=P01@3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f003
0000003kk=P0nncH0200nncH0P00000k06K=ZP800000H03kk=P00`000000I/fZ06K=ZP0Z06K=ZP03
0000003`P800l8200300l82000<0000006K=ZP1VcJX04@1VcJX00`000000nncH0?_/f0040?_/f003
0000003kk=P0nncH01@0nncH0@3oool003/0nncH00<000000?_/f03kk=P08P3kk=P2000003L0I/fZ
0P00001R0?_/f0030000001VcJX0I/fZ02X0I/fZ00<000000?20P03`P800<03`P8000`000000I/fZ
06K=ZP0A06K=ZP030000003kk=P0nncH00@0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3k
k=P2000002D0nncH0P00000c06K=ZP800000I03kk=P00`000000I/fZ06K=ZP0Z06K=ZP030000003`
P800l8200300l82000<0000006K=ZP1VcJX04@1VcJX00`000000nncH0?_/f0030?_/f08000005P3k
k=P10?ooo`00>`3kk=P00`000000nncH0?_/f00V0?_/f0<00000;@1VcJX3000006H0nncH00<00000
06K=ZP1VcJX0:P1VcJX00`000000l8200?20P00`0?20P0030000001VcJX0I/fZ0140I/fZ00<00000
0?_/f03kk=P0103kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH
02T0nncH0P00000W06K=ZP@00000J@3kk=P00`000000I/fZ06K=ZP0Z06K=ZP030000003`P800l820
01T0l8200P00000E0?20P0030000001VcJX0I/fZ0140I/fZ00<000000?_/f03kk=P0103kk=P00`00
0000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH02/0nncH1000000906K=ZPD0
00000`1VcJX2000000d0I/fZ0`00001]0?_/f0030000001VcJX0I/fZ02X0I/fZ00<000000?20P03`
P800603`P804000001@0l82000<0000006K=ZP1VcJX04@1VcJX00`000000nncH0?_/f0040?_/f003
0000003kk=P0nncH01@0nncH0@3oool003/0nncH00<000000?_/f03kk=P0;`3kk=P5000000@0I/fZ
0P00000606K=ZP8000002P1VcJX300000740nncH00<0000006K=ZP1VcJX0:@1VcJX00`000000l820
0?20P00H0?20P0@00000503`P8000`000000I/fZ06K=ZP0A06K=ZP030000003kk=P0nncH00@0nncH
00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f00d0?_/f1P00000M03k
k=P00`000000I/fZ06K=ZP0Y06K=ZP030000003`P800l82001T0l8200P00000E0?20P0030000001V
cJX0I/fZ0140I/fZ00<000000?_/f03kk=P0103kk=P00`000000nncH0?_/f00D0?_/f040oooo000k
0?_/f0030000003kk=P0nncH03X0nncH0P0000250?_/f0030000001VcJX0I/fZ02P0I/fZ00<00000
0?20P03`P800<03`P8000`000000I/fZ06K=ZP0A06K=ZP030000003kk=P0nncH00@0nncH00<00000
0?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f00k0?_/f0800000Q03kk=P00`00
0000I/fZ06K=ZP0X06K=ZP030000003`P800l8200300l82000<0000006K=ZP1VcJX04@1VcJX00`00
0000nncH0?_/f0040?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH0P00000i0?_/f080
000000<0nncH000000000000Q@3kk=P00`000000I/fZ06K=ZP0W06K=ZP030000003`P800l8200300
l82000<0000006K=ZP1VcJX0401VcJX00`000000nncH0?_/f0040?_/f08000005P3kk=P10?ooo`00
>`3kk=P00`000000nncH0?_/f00h0?_/f080000000<0nncH000000000000Q@3kk=P00`000000I/fZ
06K=ZP0X06K=ZP030000003`P800l82002l0l82000<0000006K=ZP1VcJX0401VcJX00`000000nncH
0?_/f0050?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH00<000000?_/f03kk=P0>@3k
k=P3000008H0nncH00<0000006K=ZP1VcJX0:01VcJX00`000000l8200?20P00^0?20P0030000001V
cJX0I/fZ0140I/fZ00<000000?_/f03kk=P01@3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k
0?_/f0030000003kk=P0nncH0<<0nncH00<0000006K=ZP1VcJX09`1VcJX00`000000l8200?20P00^
0?20P0030000001VcJX0I/fZ0140I/fZ00<000000?_/f03kk=P01@3kk=P00`000000nncH0?_/f00D
0?_/f040oooo000k0?_/f0030000003kk=P0nncH0<<0nncH00<0000006K=ZP1VcJX0:01VcJX00`00
0000l8200?20P00]0?20P0030000001VcJX0I/fZ0100I/fZ00<000000?_/f03kk=P01P3kk=P00`00
0000nncH0?_/f00D0?_/f040oooo000R0?_/f0<00000103kk=P2000000D0nncH0`0000080?_/f003
0000003kk=P0nncH0<@0nncH00<0000006K=ZP1VcJX09`1VcJX00`000000l8200?20P00/0?20P003
0000001VcJX0I/fZ0140I/fZ00<000000?_/f03kk=P01P3kk=P00`000000nncH0?_/f00D0?_/f040
oooo000Q0?_/f080000000<0nncH0000000000000`3kk=P2000000@0nncH00<000000?_/f03kk=P0
0P0000070?_/f0030000003kk=P0nncH0<@0nncH00<0000006K=ZP1VcJX0:01VcJX00`000000l820
0?20P00Z0?20P0030000001VcJX0I/fZ0180I/fZ00<000000?_/f03kk=P01P3kk=P00`000000nncH
0?_/f00D0?_/f040oooo000Q0?_/f080000000<0nncH000000000000303kk=P2000000L0nncH0`00
00350?_/f0030000001VcJX0I/fZ02L0I/fZ00<000000?20P03`P800:P3`P8000`000000I/fZ06K=
ZP0B06K=ZP030000003kk=P0nncH00@0nncH0`00000F0?_/f040oooo000Q0?_/f080000000<0nncH
000000000000303kk=P2000000L0nncH00<000000?_/f03kk=P0a@3kk=P00`000000I/fZ06K=ZP0W
06K=ZP030000003`P800l82002T0l82000<0000006K=ZP1VcJX04`1VcJX00`000000nncH0?_/f006
0?_/f0030000003kk=P0nncH01@0nncH0@3oool00240nncH0P0000000`3kk=P00000000000090?_/
f0030000003kk=P0nncH008000001`3kk=P00`000000nncH0?_/f0360?_/f0030000001VcJX0I/fZ
02L0I/fZ00<000000?20P03`P800:03`P8000`000000I/fZ06K=ZP0B06K=ZP030000003kk=P0nncH
00L0nncH00<000000?_/f03kk=P0503kk=P10?ooo`008@3kk=P2000000030?_/f0000000000000T0
nncH100000080?_/f0030000003kk=P0nncH0<H0nncH00<0000006K=ZP1VcJX0:01VcJX2000002L0
l82000<0000006K=ZP1VcJX04`1VcJX00`000000nncH0?_/f0070?_/f0030000003kk=P0nncH01@0
nncH0@3oool00240nncH0P0000000`3kk=P00000000000090?_/f08000002P3kk=P00`000000nncH
0?_/f0370?_/f0030000001VcJX0I/fZ02T0I/fZ00<000000?20P03`P8008`3`P8000`000000I/fZ
06K=ZP0C06K=ZP030000003kk=P0nncH00P0nncH00<000000?_/f03kk=P0503kk=P10?ooo`008P3k
k=P3000000X0nncH1@0000070?_/f0030000003kk=P0nncH0<L0nncH00<0000006K=ZP1VcJX0:P1V
cJX00`000000l8200?20P00R0?20P0030000001VcJX0I/fZ01<0I/fZ00<000000?_/f03kk=P0203k
k=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH0<P0nncH00<00000
06K=ZP1VcJX0:P1VcJX00`000000l8200?20P00P0?20P0030000001VcJX0I/fZ01@0I/fZ00<00000
0?_/f03kk=P0203kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH
0<T0nncH00<0000006K=ZP1VcJX0:P1VcJX00`000000l8200?20P00N0?20P0030000001VcJX0I/fZ
01@0I/fZ00<000000?_/f03kk=P02@3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f080
0000b`3kk=P00`000000I/fZ06K=ZP0Z06K=ZP030000003`P800l82001/0l8200P00000G06K=ZP03
0000003kk=P0nncH00P0nncH0P00000F0?_/f040oooo000k0?_/f0030000003kk=P0nncH0<X0nncH
00<0000006K=ZP1VcJX0:`1VcJX2000001T0l8200P00000H06K=ZP030000003kk=P0nncH00X0nncH
00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f03;0?_/f0030000001V
cJX0I/fZ02`0I/fZ00<000000?20P03`P8005@3`P8000`000000I/fZ06K=ZP0H06K=ZP030000003k
k=P0nncH00X0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f03<
0?_/f0030000001VcJX0I/fZ02`0I/fZ0`0000020?20P0H000000P3`P802000000H0l8200P00000J
06K=ZP030000003kk=P0nncH00/0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`00
0000nncH0?_/f03=0?_/f0030000001VcJX0I/fZ02h0I/fZ0P0000020?20P0800000103`P8020000
0080l8201000000L06K=ZP030000003kk=P0nncH00/0nncH00<000000?_/f03kk=P0503kk=P10?oo
o`00>`3kk=P00`000000nncH0?_/f03>0?_/f0030000001VcJX0I/fZ02l0I/fZ3000000O06K=ZP03
0000003kk=P0nncH00`0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH
0?_/f03?0?_/f0030000001VcJX0I/fZ0300I/fZ0P00000V06K=ZP030000003kk=P0nncH00d0nncH
00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P200000=40nncH00<0000006K=ZP1VcJX0;`1V
cJX2000002H0I/fZ00<000000?_/f03kk=P0303kk=P2000001H0nncH0@3oool003/0nncH00<00000
0?_/f03kk=P0d@3kk=P00`000000I/fZ06K=ZP0^06K=ZP8000009@1VcJX00`000000nncH0?_/f00>
0?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH00<000000?_/f03kk=P0dP3kk=P00`00
0000I/fZ06K=ZP0[06K=ZP@00000901VcJX00`000000nncH0?_/f00?0?_/f0030000003kk=P0nncH
01@0nncH0@3oool003/0nncH00<000000?_/f03kk=P0d`3kk=P00`000000I/fZ06K=ZP0/06K=ZP80
00008`1VcJX00`000000nncH0?_/f00@0?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH
00<000000?_/f03kk=P0e03kk=P200000500I/fZ00<000000?_/f03kk=P04@3kk=P00`000000nncH
0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH0=H0nncH00<0000006K=ZP1VcJX0C@1V
cJX00`000000nncH0?_/f00A0?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH00<00000
0?_/f03kk=P0e`3kk=P00`000000I/fZ06K=ZP1;06K=ZP030000003kk=P0nncH0180nncH00<00000
0?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f03H0?_/f0030000001VcJX0I/fZ
04T0I/fZ00<000000?_/f03kk=P04`3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f080
0000fP3kk=P2000004P0I/fZ00<000000?_/f03kk=P04`3kk=P2000001H0nncH0@3oool003/0nncH
00<000000?_/f03kk=P0f`3kk=P00`000000I/fZ06K=ZP1306K=ZP8000005`3kk=P00`000000nncH
0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH0=`0nncH00<0000006K=ZP1VcJX0@@1V
cJX00`000000nncH0?_/f00G0?_/f0030000003kk=P0nncH01@0nncH0@3oool003/0nncH00<00000
0?_/f03kk=P0g@3kk=P00`000000I/fZ06K=ZP0o06K=ZP030000003kk=P0nncH01P0nncH00<00000
0?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f03N0?_/f0800000?@1VcJX20000
01/0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH0?_/f03P0?_/f080
0000>@1VcJX2000001d0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00>`3kk=P00`000000nncH
0?_/f03R0?_/f0800000=P1VcJX00`000000nncH0?_/f00M0?_/f0030000003kk=P0nncH01@0nncH
0@3oool003/0nncH0P00003U0?_/f0<00000<@1VcJX2000001l0nncH0P00000F0?_/f040oooo000k
0?_/f0030000003kk=P0nncH0>L0nncH0P00000]06K=ZP8000008P3kk=P00`000000nncH0?_/f00D
0?_/f040oooo000k0?_/f0030000003kk=P0nncH0>T0nncH0`00000X06K=ZP800000903kk=P00`00
0000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH0>`0nncH0P00000T06K=ZP80
00009P3kk=P00`000000nncH0?_/f00D0?_/f040oooo000k0?_/f0030000003kk=P0nncH0>h0nncH
0P00000906K=ZPD000000`1VcJX2000000`0I/fZ0`00000X0?_/f0030000003kk=P0nncH01@0nncH
0@3oool003/0nncH00<000000?_/f03kk=P0l03kk=P5000000@0I/fZ0P00000606K=ZP8000001P1V
cJX6000002/0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00;`3kk=P6000000H0nncH00<00000
0?_/f03kk=P0m@3kk=PD00000340nncH00<000000?_/f03kk=P0503kk=P10?ooo`00<@3kk=P20000
00P0nncH00<000000?_/f03kk=P0n`3kk=P2000003d0nncH00<000000?_/f03kk=P0503kk=P10?oo
o`00<@3kk=P2000000P0nncH0`0000060?_/f0030000003kk=P0nncH04P0nncH00<000000?_/f03k
k=P0B03kk=P00`000000nncH0?_/f0170?_/f0030000003kk=P0nncH01<0nncH0P00000c0?_/f003
0000003kk=P0nncH00@0nncH0`00000F0?_/f040oooo000a0?_/f0800000203kk=P00`000000nncH
0?_/f0060?_/f0030000003kk=P0nncH00`0nncH00<000000?_/f03kk=P0303kk=P00`000000nncH
0?_/f00<0?_/f0030000003kk=P0nncH00`0nncH00<000000?_/f03kk=P0303kk=P00`000000nncH
0?_/f00<0?_/f0030000003kk=P0nncH00`0nncH00<000000?_/f03kk=P0303kk=P00`000000nncH
0?_/f00<0?_/f0030000003kk=P0nncH00`0nncH00<000000?_/f03kk=P0303kk=P00`000000nncH
0?_/f00<0?_/f0030000003kk=P0nncH00`0nncH00<000000?_/f03kk=P02`3kk=P00`000000nncH
0?_/f00<0?_/f0030000003kk=P0nncH00`0nncH00@000000?_/f03kk=P0nncH0P0000000`3kk=P0
0000000000060?_/f0030000003kk=P0nncH00`0nncH00<000000?_/f03kk=P0303kk=P00`000000
nncH0?_/f00<0?_/f0030000003kk=P0nncH00H0nncH00<000000?_/f03kk=P0503kk=P10?ooo`00
<@3kk=P2000000P0nncHo`00000o000001H0nncH0@3oool00340nncH0P00003o0?_/f5d0nncH0@3o
ool002l0nncH1000003o0?_/f5d0nncH0@3oool00340nncH0P00003o0?_/f5d0nncH0@3oool00?l0
nncHT03kk=P10?ooo`00o`3kk=R@0?_/f040oooo003o0?_/f900nncH0@3oool00:X0nncH10000006
0?_/f08000009@3kk=P2000003d0nncH1000001a0?_/f040oooo002Z0?_/f08000001`3kk=P20000
02L0nncH0P00000n0?_/f0800000L@3kk=P10?ooo`00T`3kk=P3000000030?_/f0000000000000<0
000000<0nncH0000000000000P3kk=P5000000@0nncH0P0000070?_/f08000002`3kk=P6000000d0
nncH2`0000090?_/f0030000003kk=P0nncH00D0nncH1@0000060?_/f0D000001`3kk=P00`000000
nncH0?_/f0050?_/f0D000002@3kk=P200000740nncH0@3oool009@0nncH0P000000103kk=P00000
0000003kk=P3000000040?_/f000000000000?_/f08000000P3kk=P2000000<0nncH0P0000060?_/
f08000003P3kk=P200000140nncH0P0000000`3kk=P00000000000030?_/f0800000203kk=P00`00
0000nncH0?_/f0050?_/f08000002@3kk=P200000080nncH00<000000?_/f03kk=P01@3kk=P00`00
0000nncH0?_/f0050?_/f08000000P3kk=P00`000000nncH0?_/f0070?_/f0800000L@3kk=P10?oo
o`00U03kk=P5000000030?_/f000000000000080nncH0P0000030?_/f0@000000`3kk=P2000000H0
nncH0P0000040?_/f0D000001@3kk=P2000000H0nncH1@0000060?_/f080000000<0nncH00000000
00000`3kk=P2000000H0nncH1@0000060?_/f08000002@3kk=P2000000L0nncH1@0000060?_/f080
00002`3kk=P200000740nncH0@3oool009@0nncH0P000000103kk=P000000000003kk=P200000080
nncH0P0000000`3kk=P0000000000002000000D0nncH0P0000060?_/f08000003P3kk=P200000140
nncH0P0000000`3kk=P00000000000030?_/f0800000203kk=P00`000000nncH0?_/f0070?_/f080
00002@3kk=P2000000P0nncH00<000000?_/f03kk=P01`3kk=P2000000X0nncH0P00001a0?_/f040
oooo002D0?_/f080000000@0nncH000000000000nncH0`000000103kk=P000000000003kk=P20000
0080nncH0P0000030?_/f08000001P3kk=P2000000h0nncH0P00000A0?_/f080000000<0nncH0000
000000000`3kk=P2000000P0nncH00<000000?_/f03kk=P0203kk=P2000000H0nncH00<000000?_/
f03kk=P00P0000070?_/f0030000003kk=P0nncH00D0nncH00<000000?_/f03kk=P00P0000090?_/
f0800000L@3kk=P10?ooo`00U@3kk=P00`000000nncH000000020?_/f080000000<0nncH00000000
00000`3kk=P5000000<0nncH0P0000070?_/f08000003@3kk=P2000000l0nncH1`0000020?_/f080
00004@3kk=P2000000030?_/f0000000000000H0nncH1@00000?0?_/f0D0000000<0nncH00000000
00000P0000040?_/f0800000L@3kk=P10?ooo`00U@3kk=P300000080nncH0P00000>0?_/f0800000
1`3kk=P2000000/0nncH1000000H0?_/f08000004@3kk=P2000000030?_/f000000000000240nncH
00<000000?_/f03kk=P0103kk=P200000740nncH0@3oool009<0nncH1@000000103kk=P000000000
0000000>0?_/f0@000001P3kk=P2000000`0nncH0P00000B0?_/f08000000`3kk=P2000001<0nncH
0`00000S0?_/f0040000003kk=P0nncH0?_/f0@00000L@3kk=P10?ooo`00eP3kk=P2000003l0nncH
00<000000?_/f03kk=P0M@3kk=P10?ooo`00o`3kk=PE0?_/f0040000003kk=P0nncH000007L0nncH
0@3oool00?l0nncH5P3kk=P2000007P0nncH0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {193, 0}} -> {-3.9175, -1.29004, 0.0133726, \
0.0133726}}]
}, Open  ]],

Cell[BoxData[
    \(Clear[f, region, zeropts]\)], "Input",
  CellLabel->"In[8]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{504, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 68, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1847, 56, 476, 17, 50, "Usage",
      CellTags->"Function?"],
    Cell[2326, 75, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 107048, 4014}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 68, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1847, 56, 476, 17, 50, "Usage",
  CellTags->"Function?"],
Cell[2326, 75, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2423, 80, 189, 4, 58, "MathCaption"],
Cell[2615, 86, 378, 14, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3018, 104, 33, 0, 39, "ExampleSection"],
Cell[3054, 106, 97, 2, 29, "Input"],
Cell[3154, 110, 89, 2, 25, "Text"],
Cell[3246, 114, 106, 2, 29, "Input"],

Cell[CellGroupData[{
Cell[3377, 120, 149, 3, 49, "Input"],
Cell[3529, 125, 152, 3, 30, "Output"],
Cell[3684, 130, 161, 3, 27, "Output"]
}, Open  ]],
Cell[3860, 136, 112, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[3997, 143, 203, 4, 49, "Input"],
Cell[4203, 149, 81, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4321, 156, 197, 4, 49, "Input"],
Cell[4521, 162, 81, 2, 27, "Output"]
}, Open  ]],
Cell[4617, 167, 73, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[4715, 171, 842, 16, 289, "Input"],
Cell[5560, 189, 100656, 3797, 200, 67932, 3389, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[106231, 3989, 82, 2, 29, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

