(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4924,        154]*)
(*NotebookOutlinePosition[      5931,        189]*)
(*  CellTagsIndexPosition[      5857,        183]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ContourColors", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["ContourColors",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(z, \ contourlist\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " can be used as a ColorFunction to assure that adjacent contour regions \
have distinct color shadings."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
ContourColors uses some saturation and brightness variation in addition to \
hue variation..\
\>", "MathCaption",
  CellTags->"Function?"],

Cell[TextData[{
  "First specify a list of contour values. In ContourDraw or ContourPlot \
specify a PlotRange with the z value running from the first to the last item \
on contourlist. Then use the options:\n",
  Cell[BoxData[
      \(Contours \[Rule] contourlist\)]],
  ", ",
  Cell[BoxData[
      \(ColorFunction \[Rule] Evaluate[ContourColors[#, contourlist] &]\)]]
}], "MathCaption"],

Cell["\<\
You will probably also need a PlotRange in the Show statement without the z \
range.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ContourDraw",
    ButtonData:>{"ContourDraw"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
When a number of closely spaced contour values are specified, they are \
rendered as nearly the same color.\
\>", "Text"],

Cell[BoxData[{
    \(\(contourlist = {\(-0.5\), 0, 0.25, 0.5, 0.75, 0.85, 0.9, 0.925, 0.95, 
          0.99, 1};\)\), "\[IndentingNewLine]", 
    \(\(Draw2D[\[IndentingNewLine]{ContourDraw[
            Cos[x\ y] 
              Cos[y], {x, \(-\[Pi]\)/2, \[Pi]/2}, {y, \(-\[Pi]\)/2, \[Pi]/2}, 
            PlotPoints \[Rule] 50, \[IndentingNewLine]Contours \[Rule] 
              contourlist, \[IndentingNewLine]ColorFunction \[Rule] 
              Hue]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True\[IndentingNewLine]];\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell["ContourColors differentiates the colors.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{ContourDraw[
            Cos[x\ y] 
              Cos[y], {x, \(-\[Pi]\)/2, \[Pi]/2}, {y, \(-\[Pi]\)/2, \[Pi]/2}, 
            PlotPoints \[Rule] 50, \[IndentingNewLine]Contours \[Rule] 
              contourlist, \[IndentingNewLine]ColorFunction \[Rule] 
              Evaluate[
                ContourColors[#, 
                    contourlist] &], \[IndentingNewLine]PlotRange \[Rule] \
{{\(-\[Pi]\)/2, \[Pi]/2}, {\(-\[Pi]\)/2, \[Pi]/2}, {First[contourlist], 
                  Last[contourlist]}}]}, \[IndentingNewLine]AspectRatio \
\[Rule] Automatic, \[IndentingNewLine]Frame \[Rule] 
          True\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(Clear[contourlist]\)], "Input",
  CellLabel->"In[5]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{548, 705},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 60, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1839, 56, 411, 15, 50, "Usage",
      CellTags->"Function?"],
    Cell[2253, 73, 148, 4, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5610, 172}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 60, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1839, 56, 411, 15, 50, "Usage",
  CellTags->"Function?"],
Cell[2253, 73, 148, 4, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2404, 79, 388, 9, 97, "MathCaption"],
Cell[2795, 90, 115, 3, 41, "MathCaption"],
Cell[2913, 95, 211, 8, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3149, 107, 33, 0, 39, "ExampleSection"],
Cell[3185, 109, 97, 2, 29, "Input"],
Cell[3285, 113, 131, 3, 25, "Text"],
Cell[3419, 118, 624, 11, 209, "Input"],
Cell[4046, 131, 56, 0, 25, "Text"],
Cell[4105, 133, 713, 13, 209, "Input"],
Cell[4821, 148, 75, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

