(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4215,        136]*)
(*NotebookOutlinePosition[      5221,        171]*)
(*  CellTagsIndexPosition[      5147,        165]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ContourDraw", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["ContourDraw",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(f, {x, xmin, xmax}, {y, rmin, ymax}, \ opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  "extracts the graphics primitives from the corresponding ContourPlot \
statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
ContourDraw has the same usage as ContourPlot. Regular ContourPlot options \
may be used. Basic Graphics options, such as Frame have no effect. PlotRange \
does have an effect.\
\>", "MathCaption"],

Cell[TextData[{
  "ContourPlot lines may be labeled using ",
  ButtonBox["DrawLineLabels",
    ButtonData:>{"DrawLineLabels"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell["\<\
Unique colors for each region may be obtained using ContourColors.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ContourColors",
    ButtonData:>{"ContourColors"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{ContourDraw[
            Cos[x] Cos[y], {x, \(-2\) \[Pi], 2  \[Pi]}, {y, \(-2\) \[Pi], 
              2  \[Pi]}, Contours \[Rule] Range[\(-1\), 1, 0.2], 
            PlotPoints \[Rule] 50], \[IndentingNewLine]ContourDraw[
            Cos[x] Cos[y], {x, \(-\[Pi]\), \[Pi]}, {y, \(-\[Pi]\), \[Pi]}, 
            Contours \[Rule] Range[\(-1\), 1, 0.2], PlotPoints \[Rule] 25, 
            ColorFunction \[Rule] Hue], \[IndentingNewLine]White, 
          Line[{{\(-2\) \[Pi], \(-2\) \[Pi]}, {2  \[Pi], 2  \[Pi]}}], 
          Line[{{2  \[Pi], \(-2\) \[Pi]}, {\(-2\) \[Pi], 
                2  \[Pi]}}]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
To obtain matching contours, the same Contour values were used and a \
proportional number of PlotPoints were used.\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{548, 705},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 58, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1837, 56, 418, 15, 50, "Usage",
      CellTags->"Function?"],
    Cell[2258, 73, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 4901, 154}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 58, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1837, 56, 418, 15, 50, "Usage",
  CellTags->"Function?"],
Cell[2258, 73, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2355, 78, 207, 4, 58, "MathCaption"],
Cell[2565, 84, 183, 6, 41, "MathCaption"],
Cell[2751, 92, 97, 2, 41, "MathCaption"],
Cell[2851, 96, 215, 8, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3091, 108, 33, 0, 39, "ExampleSection"],
Cell[3127, 110, 97, 2, 29, "Input"],
Cell[3227, 114, 818, 13, 209, "Input"],
Cell[4048, 129, 139, 3, 42, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

