(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8564,        243]*)
(*NotebookOutlinePosition[      9533,        277]*)
(*  CellTagsIndexPosition[      9459,        271]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CustomGridLines", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["CustomGridLines",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(inversefunction, gridspecs, gridstyle : {LightBlue}\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will generate custom grid lines."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "CustomGridLines is used in the GridLines option. For example: \n",
  Cell[BoxData[
      \(GridLines \[Rule] {CustomGridLines[ ... ], 
          CustomGridLines[ ... ]}\)]]
}], "MathCaption"],

Cell["\<\
The inversefunction is a pure function or function name which converts the \
grid values to the actual coordinate values. Hence grid lines can be matched \
to CustomTicks.\
\>", "MathCaption"],

Cell[TextData[{
  "For a linear scale, gridspecs takes the form ",
  Cell[BoxData[
      \({start, end, increment}\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "For a log scale, gridspecs takes the form ",
  Cell[BoxData[
      \({startpower, endpower, vals}\)]],
  ". vals is a list of the grid lines in one decade. The grid lines will be \
",
  Cell[BoxData[
      \(\(10\^power\) vals\)]],
  " where power ranges from the start to end value."
}], "MathCaption"],

Cell[TextData[{
  "For a data based scale, gridspecs takes the form ",
  Cell[BoxData[
      \(databased[{val1, val2,  ... }]\)]],
  ".  The grid lines will be at the specified values, which do not have to be \
evenly spaced."
}], "MathCaption"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will eliminate any grid lines which are outside the PlotRange."
}], "MathCaption"],

Cell["\<\
With CustomGridLines the default color actually is LightBlue.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["CustomTicks",
    ButtonData:>{"CustomTicks"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GridLines",
    ButtonStyle->"RefGuideLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
The following graphs a temperature versus distance curve, with a reverse \
distance scale at the top and a Fahrenheit scale on the right. The grid lines \
are matched to the Fahrenheit scale.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\n\t{Blue, 
          Draw[120  x - 20  x\^2, {x, 0, 
              1}]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.001\), 
              1.001}, {\(-0.1\), 120}}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {HoldForm[
              x], "\<\[Degree]C\>", 
            HoldForm[
              1 - x], "\<\[Degree]F\>"}, \[IndentingNewLine]FrameTicks \
\[Rule] \[IndentingNewLine]{Automatic, \[IndentingNewLine]Automatic, \
\[IndentingNewLine]CustomTicks[
              1 - # &, {1, 0, \(-0.2\), 4}], \[IndentingNewLine]CustomTicks[
              5/9 \((# - 32)\) &, {25, 250, 25, 5}, \ 
              CTNumberFunction \[Rule] \((StyleForm[#, 
                      FontColor \[Rule] 
                        Red] &)\)]}, \
\[IndentingNewLine]\[IndentingNewLine]GridLines \[Rule] {CustomGridLines[# &, \
{0, 1, 0.2}], 
            CustomGridLines[
              5/9 \((# - 32)\) &, {25, 250, 
                25}]}, \[IndentingNewLine]\[IndentingNewLine]PlotRegion \
\[Rule] {{0.02, 0.98}, {0, 
              1}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Temperature versus \
Distance\>", \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]TextStyle \[Rule] {FontSize \[Rule] 
              12}, \[IndentingNewLine]ImageSize \[Rule] {400, 
            280}];\)\)], "Input",
  CellLabel->"In[2]:=",
  GeneratedCell->False],

Cell["\<\
The following is an example of using a log scale and changing the color of \
the grid lines.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\n\t{Blue, 
          Draw[Log[x], {x, 0.1, 
              5}]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.001\), 5}, 
            All}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {x, Log[x], None, 
            x}, \[IndentingNewLine]FrameTicks \[Rule] \
\[IndentingNewLine]{Automatic, Automatic, Automatic, 
            CustomTicks[Log[#] &, {\(-2\), 1, {1, 2, 3, 4, 5, 7}, {6, 8, 9}}, 
              CTNumberFunction \[Rule] \((NumberForm[N[#], 
                      3] &)\)]}, \
\[IndentingNewLine]\[IndentingNewLine]GridLines \[Rule] {CustomGridLines[# &, \
{0, 5, 1}, {RawUmber}], 
            CustomGridLines[
              Log[#] &, {\(-1\), 
                1, {1, 2, 3, 4, 5, 6, 7, 8, 
                  9}}, {RawUmber}]}, \
\[IndentingNewLine]\[IndentingNewLine]PlotRegion \[Rule] {{0.02, 0.98}, {0, 
              1}}, \[IndentingNewLine]PlotLabel \[Rule] 
          Log[x], \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]TextStyle \[Rule] {FontSize \[Rule] 
              12}, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)], "Input",
  CellLabel->"In[3]:=",
  GeneratedCell->False],

Cell[TextData[{
  "The following illustrates a plot where the tick marks and grid lines are \
based on the actual data points.This type of display is suggested by Edward \
R.Tufte in his wonderful book ",
  StyleBox["The Visual Display of Quantitative Information",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(data = {{1, 1}, {3, 2}, {5, 3}, {8, 5}, {10, 2}};\)\), "\n", 
    \(Draw2D[\[IndentingNewLine]{AbsolutePointSize[4], 
        Point /@ data, \[IndentingNewLine]Blue, 
        Line[data]}, \[IndentingNewLine]Frame \[Rule] 
        True, \[IndentingNewLine]FrameTicks \[Rule] {CustomTicks[Identity, 
            databased[\(Transpose[
                  data]\)\[LeftDoubleBracket]1\[RightDoubleBracket]]], 
          CustomTicks[Identity, 
            databased[\(Transpose[
                    data]\)\[LeftDoubleBracket]2\[RightDoubleBracket]] // 
              Union], None, 
          None}, \[IndentingNewLine]GridLines \[Rule] {CustomGridLines[
            Identity, 
            databased[\(Transpose[
                  data]\)\[LeftDoubleBracket]1\[RightDoubleBracket]]], 
          CustomGridLines[Identity, 
            databased[\(Transpose[
                    data]\)\[LeftDoubleBracket]2\[RightDoubleBracket]] // 
              Union]}, \[IndentingNewLine]PlotRange \[Rule] {{0, 11}, {0, 
            6}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Plot with Data Based \
Grids and Ticks\>", \[IndentingNewLine]Background \[Rule] 
        Linen, \[IndentingNewLine]ImageSize \[Rule] 400]; 
    Clear[data]\)}], "Input",
  CellLabel->"In[4]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Printout",
WindowToolbars->{},
WindowSize->{616, 747},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 62, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1841, 56, 378, 14, 33, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 9288, 262}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 62, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1841, 56, 378, 14, 33, "Usage",
  CellTags->"Function?"],
Cell[2222, 72, 210, 5, 64, "MathCaption"],
Cell[2435, 79, 202, 4, 58, "MathCaption"],
Cell[2640, 85, 144, 5, 41, "MathCaption"],
Cell[2787, 92, 322, 9, 58, "MathCaption"],
Cell[3112, 103, 245, 6, 58, "MathCaption"],
Cell[3360, 111, 154, 4, 41, "MathCaption"],
Cell[3517, 117, 92, 2, 41, "MathCaption"],
Cell[3612, 121, 216, 9, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3853, 134, 34, 0, 39, "ExampleSection"],
Cell[3890, 136, 97, 2, 29, "Input"],
Cell[3990, 140, 215, 4, 42, "Text"],
Cell[4208, 146, 1417, 28, 412, "Input"],
Cell[5628, 176, 116, 3, 25, "Text"],
Cell[5747, 181, 1199, 23, 369, "Input"],
Cell[6949, 206, 309, 7, 42, "Text"],
Cell[7261, 215, 1275, 24, 289, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

