(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9389,        285]*)
(*NotebookOutlinePosition[     10286,        317]*)
(*  CellTagsIndexPosition[     10211,        311]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CustomTicks", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["CustomTicks",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(inversefunction, tickspecs, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will generate custom tick marks for axes or frames."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "CustomTicks is used in the Ticks or FrameTicks option. For example, to put \
custom ticks on the right hand frame edge: \n",
  Cell[BoxData[
      \(FrameTicks \[Rule] {Automatic, Automatic, Automatic, 
          CustomTicks[ ... ]}\)]]
}], "MathCaption"],

Cell[TextData[{
  "The inversefunction is a pure function or function name which converts the \
label values to the actual coordinate values. If the y values of a graphed \
function are transformed by ",
  Cell[BoxData[
      \(f[yvalue]\)]],
  " before plotting, then the same f can be used as the the inversefunction."
}], "MathCaption"],

Cell[TextData[{
  "For a linear scale, tickspecs takes the form ",
  Cell[BoxData[
      \({start, end, increment, subdivisions}\)]],
  ". A subdivision of n will provide n-1 unlabeled tick marks between labeled \
ticks."
}], "MathCaption"],

Cell[TextData[{
  "For a log scale, tickspecs takes the form ",
  Cell[BoxData[
      \({startpower, endpower, vals, subvals}\)]],
  ". vals and subvals are lists of the labeled and unlabeled values in one \
decade. The labeled ticks will be ",
  Cell[BoxData[
      \(\(10\^power\) vals\)]],
  " where power ranges from the start to end value."
}], "MathCaption"],

Cell[TextData[{
  "For a data based scale, tickspecs takes the form ",
  Cell[BoxData[
      \(databased[{val1, val2,  ... }]\)]],
  ". The major tick marks will be at the specified values, which do not have \
to be evenly spaced. There will be no minor tick marks."
}], "MathCaption"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will eliminate any ticks which are outside the PlotRange."
}], "MathCaption"],

Cell["\<\
The options are CTNumberFunction, CTTickSpecs, CTTickStyle, CTUnLabTickSpecs, \
CTUnLabTickStyle.\
\>", "MathCaption"],

Cell[TextData[{
  "CTNumberFunction specifies a pure function to be applied to tick values to \
give the desired formatting. The default value is Identity. Examples are:\n",
  Cell[BoxData[
      \(\(\(\(CTNumberFunction \[Rule] \((\*"\"\<\>"\)\) \*"\"\<\>" \
&\)\()\)\)\)]],
  " (for no labels), ",
  Cell[BoxData[
      \(\(\(\(\(\(CTNumberFunction \[Rule] \((\(NumberForm\)\([\)\(\(\(\(#, \
{3, 2}, NumberPadding \[Rule] \(\({\)\(\*"\"\<\>"\)\(\ \)\)\) \*"\"\<\>"\)\(,\
\)\) \*"\"\<\>" 0 \*"\"\<\>"\)\)\)\(}\)\)\(]\)\) &\)\()\)\)\)]],
  Cell[BoxData[
      \(CTNumberFunction \[Rule] \((StyleForm[#, FontSize \[Rule] 15, 
              FontColor \[Rule] Blue] &)\)\)]],
  "\n If you use CustomTicks on the bottom of a frame, and want matching but \
unlabled ticks on the top, use the same CustomTicks but with the number \
function for no labels shown as the first example above."
}], "MathCaption",
  ShowStringCharacters->True],

Cell[TextData[{
  "CTTickSpecs specifies the positive and negative tick line lengths as in \
the regular ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  ButtonBox["Ticks",
    ButtonStyle->"RefGuideLink"],
  " specification. The default value is ",
  Cell[BoxData[
      \(\((0.00625, 0)\)\)]],
  ". This is appropriate for the upper and right frame axes where CustomTicks \
is most likely to be used."
}], "MathCaption"],

Cell["\<\
CTTickStyle gives a list of style directives for the labeled tick lines. The \
default is {}.\
\>", "MathCaption"],

Cell[TextData[{
  "CTUnLabTickSpecs specifies the positive and negative minor unlabeled tick \
line lengths as in the regular ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  ButtonBox["Ticks",
    ButtonStyle->"RefGuideLink"],
  " specification. The default value is ",
  Cell[BoxData[
      \(\((0.00375, 0)\)\)]],
  ". This is appropriate for the upper and right frame axes where CustomTicks \
is most likely to be used."
}], "MathCaption"],

Cell["\<\
CTUnLabTickStyle gives a list of style directives for the minor unlabeled \
tick lines. The default is {}.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["CustomGridLines",
    ButtonData:>{"CustomGridLines"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["XTickLine",
    ButtonData:>{"XTickLine"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["YTickLine",
    ButtonData:>{"YTickLine"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["Ticks",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["FrameTicks",
    ButtonStyle->"RefGuideLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "The following scales ",
  Cell[BoxData[
      \(x\^3\)]],
  " so that it will fit on the same graph with ",
  Cell[BoxData[
      \(x\^2\)]],
  " over the domain ",
  Cell[BoxData[
      \(0 \[LessEqual] x \[LessEqual] 10\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(f1[x_] := x\^2;\)\), "\n", 
    \(\(f2[x_] := x\^3;\)\), "\n", 
    \(\(Draw2D[\[IndentingNewLine]{Draw[
            f1[x], {x, 0, 10}], \[IndentingNewLine]Blue, 
          Draw[f2[x]/10, {x, 0, 10}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameTicks \[Rule] {Automatic, Automatic, 
            Automatic, \[IndentingNewLine]CustomTicks[#/10 &, {0, 1000, 100, 
                5}, CTNumberFunction \[Rule] \((StyleForm[#, 
                      FontColor \[Rule] 
                        Blue] &)\)]}, \[IndentingNewLine]PlotLabel \[Rule] 
          SequenceForm[x\^2, "\< and \>", 
            StyleForm[x\^3, 
              FontColor \[Rule] Blue]], \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]TextStyle \[Rule] {FontSize \[Rule] 
              12}, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell["The following is an example of using a log scale.", "Text"],

Cell[BoxData[{
    \(\(f1[x_] := Sin[x];\)\), "\n", 
    \(f2[x_] := E\^x\), "\n", 
    \(\(Draw2D[\[IndentingNewLine]{Draw[
            f1[x], {x, 0, 2  \[Pi]}], \[IndentingNewLine]Blue, 
          Draw[Log[10, f2[x]], {x, 0, 
              2  \[Pi]}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {x, None, None, 
            None}, \[IndentingNewLine]FrameTicks \[Rule] {Automatic, 
            CustomTicks[Identity, \ {\(-1\), 1, 1, 5}], Automatic, 
            CustomTicks[Log[10, #] &, {0, 2, {1, 2, 5}, {3, 4, 6, 7, 8, 9}}, 
              CTNumberFunction \[Rule] \((StyleForm[#, 
                      FontColor \[Rule] 
                        Blue] &)\)]}, \[IndentingNewLine]PlotLabel \[Rule] 
          SequenceForm[f1[x], "\< and \>", 
            StyleForm[f2[x], 
              FontColor \[Rule] Blue]], \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]TextStyle \[Rule] {FontSize \[Rule] 
              12}, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)}], "Input",
  CellLabel->"In[5]:="],

Cell[TextData[{
  "For a data based example see the last example in ",
  ButtonBox["CustomGridLines",
    ButtonData:>{"CustomGridLines"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text"],

Cell[BoxData[
    \(Clear[f1, f2]\)], "Input",
  CellLabel->"In[8]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{536, 736},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 58, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1837, 56, 379, 14, 50, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 10040, 302}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 58, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1837, 56, 379, 14, 50, "Usage",
  CellTags->"Function?"],
Cell[2219, 72, 274, 6, 81, "MathCaption"],
Cell[2496, 80, 339, 7, 75, "MathCaption"],
Cell[2838, 89, 240, 6, 75, "MathCaption"],
Cell[3081, 97, 364, 9, 92, "MathCaption"],
Cell[3448, 108, 285, 6, 75, "MathCaption"],
Cell[3736, 116, 149, 4, 41, "MathCaption"],
Cell[3888, 122, 128, 3, 58, "MathCaption"],
Cell[4019, 127, 932, 18, 209, "MathCaption"],
Cell[4954, 147, 437, 13, 65, "MathCaption"],
Cell[5394, 162, 124, 3, 31, "MathCaption"],
Cell[5521, 167, 458, 13, 82, "MathCaption"],
Cell[5982, 182, 137, 3, 48, "MathCaption"],
Cell[6122, 187, 481, 20, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[6628, 211, 34, 0, 40, "ExampleSection"],
Cell[6665, 213, 97, 2, 29, "Input"],
Cell[6765, 217, 263, 11, 25, "Text"],
Cell[7031, 230, 919, 16, 293, "Input"],
Cell[7953, 248, 65, 0, 25, "Text"],
Cell[8021, 250, 1076, 19, 329, "Input"],
Cell[9100, 271, 188, 6, 25, "Text"],
Cell[9291, 279, 70, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

