(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    396577,      14312]*)
(*NotebookOutlinePosition[    397570,      14347]*)
(*  CellTagsIndexPosition[    397492,      14341]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CylindricalDraw3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          RowBox[{"Cylindrical", 
            StyleBox["Draw3D",
              "MR"]}]], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(z, {r, rmin, rmax}, {\[Phi], \[Phi]min, \[Phi]max}, 
          opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " extracts the graphics primitives from the corresponding CylindricalPlot3D \
statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as CylindricalPlot3D. Regular CylindricalPlot3D options may \
be used. Basic Graphics3D options, such as PlotRange have no effect.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Draw3D",
    ButtonData:>{"Draw3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ParametricDraw3D",
    ButtonData:>{"ParametricDraw3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SphericalDraw3D",
    ButtonData:>{"SphericalDraw3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PointParametricDraw3D",
    ButtonData:>{"PointParametricDraw3D"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["ParametricPlot3D",
    ButtonStyle->"RefGuideLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["This combines a cylindrical plot with a parametric plot.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{SurfaceColor[Carrot, Carrot, 2], 
          CylindricalDraw3D[
            2 + Cos[r\ \[Pi]/2]\ Sin[5\ \[Phi]], {r, 0, 1}, {\[Phi], 0, 
              2  \[Pi]}, 
            PlotPoints \[Rule] {15, 81}], \[IndentingNewLine]SurfaceColor[
            AquamarineMedium, AquamarineMedium, 2], 
          ParametricDraw3D[{1.01  Cos[\[Phi]], 1.01  Sin[\[Phi]], 
              z}, {\[Phi], 0, 2  \[Pi]}, {z, 0, 2}, 
            PlotPoints \[Rule] {31, 15}]}, \[IndentingNewLine]Boxed \[Rule] 
          False, \[IndentingNewLine]NeutralLighting[0.3, 0.5, 
          0.0], \[IndentingNewLine]Background \[Rule] 
          DarkSeaGreen, \[IndentingNewLine]ImageSize \[Rule] 
          300];\)\)], "Input",
  CellLabel->"In[306]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.34561 
%%ImageSize: 300 403.682 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.561 .737 .561 r
MFill
% Scaling calculations
-0.169471 1.37396 1.1872e-017 1.37396 [
[ 0 0 0 0 ]
[ 1 1.34561 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.34561 L
0 1.34561 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.432 .794 .668 r
.45209 .54484 m .50994 .54963 L .50999 .519 L p F P
0 0 0 r
s
.432 .794 .668 r
.50999 .519 m .45253 .51419 L .45209 .54484 L p F P
0 0 0 r
s
.386 .711 .608 r
.56771 .51617 m .50999 .519 L .50994 .54963 L p F P
0 0 0 r
s
.386 .711 .608 r
.50994 .54963 m .56806 .54681 L .56771 .51617 L p F P
0 0 0 r
s
.339 .627 .546 r
.62366 .50578 m .56771 .51617 L .56806 .54681 L p F P
0 0 0 r
s
.478 .878 .727 r
.39654 .53258 m .45209 .54484 L .45253 .51419 L p F P
0 0 0 r
s
.478 .878 .727 r
.45253 .51419 m .39738 .50187 L .39654 .53258 L p F P
0 0 0 r
s
.339 .627 .546 r
.56806 .54681 m .62439 .53647 L .62366 .50578 L p F P
0 0 0 r
s
.29 .541 .481 r
.67582 .4881 m .62366 .50578 L .62439 .53647 L p F P
0 0 0 r
s
.523 .961 .783 r
.34534 .51318 m .39654 .53258 L .39738 .50187 L p F P
0 0 0 r
s
.523 .961 .783 r
.39738 .50187 m .34653 .48238 L .34534 .51318 L p F P
0 0 0 r
s
.432 .794 .668 r
.45163 .57592 m .50989 .58068 L .50994 .54963 L p F P
0 0 0 r
s
.432 .794 .668 r
.50994 .54963 m .45209 .54484 L .45163 .57592 L p F P
0 0 0 r
s
.386 .711 .608 r
.56806 .54681 m .50994 .54963 L .50989 .58068 L p F P
0 0 0 r
s
.386 .711 .608 r
.50989 .58068 m .56841 .57788 L .56806 .54681 L p F P
0 0 0 r
s
.339 .627 .546 r
.62439 .53647 m .56806 .54681 L .56841 .57788 L p F P
0 0 0 r
s
.478 .878 .727 r
.3957 .56372 m .45163 .57592 L .45209 .54484 L p F P
0 0 0 r
s
.478 .878 .727 r
.45209 .54484 m .39654 .53258 L .3957 .56372 L p F P
0 0 0 r
s
.29 .541 .481 r
.62439 .53647 m .67692 .51887 L .67582 .4881 L p F P
0 0 0 r
s
.241 .455 .413 r
.7222 .46364 m .67582 .4881 L .67692 .51887 L p F P
0 0 0 r
s
.339 .627 .546 r
.56841 .57788 m .62514 .56758 L .62439 .53647 L p F P
0 0 0 r
s
.29 .541 .481 r
.67692 .51887 m .62439 .53647 L .62514 .56758 L p F P
0 0 0 r
s
.523 .961 .783 r
.34413 .54441 m .3957 .56372 L .39654 .53258 L p F P
0 0 0 r
s
.523 .961 .783 r
.39654 .53258 m .34534 .51318 L .34413 .54441 L p F P
0 0 0 r
s
.565 1 .833 r
.30044 .48719 m .34534 .51318 L .34653 .48238 L p F P
0 0 0 r
s
.565 1 .833 r
.34653 .48238 m .30196 .45627 L .30044 .48719 L p F P
0 0 0 r
s
.432 .794 .668 r
.45117 .60743 m .50983 .61217 L .50989 .58068 L p F P
0 0 0 r
s
.432 .794 .668 r
.50989 .58068 m .45163 .57592 L .45117 .60743 L p F P
0 0 0 r
s
.386 .711 .608 r
.56841 .57788 m .50989 .58068 L .50983 .61217 L p F P
0 0 0 r
s
.386 .711 .608 r
.50983 .61217 m .56876 .60938 L .56841 .57788 L p F P
0 0 0 r
s
.339 .627 .546 r
.62514 .56758 m .56841 .57788 L .56876 .60938 L p F P
0 0 0 r
s
.478 .878 .727 r
.39485 .59529 m .45117 .60743 L .45163 .57592 L p F P
0 0 0 r
s
.478 .878 .727 r
.45163 .57592 m .3957 .56372 L .39485 .59529 L p F P
0 0 0 r
s
.29 .541 .481 r
.62514 .56758 m .67804 .55008 L .67692 .51887 L p F P
0 0 0 r
s
.241 .455 .413 r
.72364 .49453 m .67692 .51887 L .67804 .55008 L p F P
0 0 0 r
s
.241 .455 .413 r
.67692 .51887 m .72364 .49453 L .7222 .46364 L p F P
0 0 0 r
s
.339 .627 .546 r
.56876 .60938 m .62589 .59914 L .62514 .56758 L p F P
0 0 0 r
s
.29 .541 .481 r
.67804 .55008 m .62514 .56758 L .62589 .59914 L p F P
0 0 0 r
s
.523 .961 .783 r
.3429 .57608 m .39485 .59529 L .3957 .56372 L p F P
0 0 0 r
s
.523 .961 .783 r
.3957 .56372 m .34413 .54441 L .3429 .57608 L p F P
0 0 0 r
s
.565 1 .833 r
.2989 .51855 m .34413 .54441 L .34534 .51318 L p F P
0 0 0 r
s
.565 1 .833 r
.34534 .51318 m .30044 .48719 L .2989 .51855 L p F P
0 0 0 r
s
.193 .367 .342 r
.76091 .43315 m .7222 .46364 L .72364 .49453 L p F P
0 0 0 r
s
.432 .794 .668 r
.4507 .63938 m .50978 .64409 L .50983 .61217 L p F P
0 0 0 r
s
.432 .794 .668 r
.50983 .61217 m .45117 .60743 L .4507 .63938 L p F P
0 0 0 r
s
.386 .711 .608 r
.56876 .60938 m .50983 .61217 L .50978 .64409 L p F P
0 0 0 r
s
.386 .711 .608 r
.50978 .64409 m .56912 .64132 L .56876 .60938 L p F P
0 0 0 r
s
.339 .627 .546 r
.62589 .59914 m .56876 .60938 L .56912 .64132 L p F P
0 0 0 r
s
.478 .878 .727 r
.39398 .62731 m .4507 .63938 L .45117 .60743 L p F P
0 0 0 r
s
.478 .878 .727 r
.45117 .60743 m .39485 .59529 L .39398 .62731 L p F P
0 0 0 r
s
.592 1 .861 r
.26374 .45541 m .30044 .48719 L .30196 .45627 L p F P
0 0 0 r
s
.592 1 .861 r
.30196 .45627 m .26554 .42436 L .26374 .45541 L p F P
0 0 0 r
s
.29 .541 .481 r
.62589 .59914 m .67917 .58172 L .67804 .55008 L p F P
0 0 0 r
s
.241 .455 .413 r
.7251 .52585 m .67804 .55008 L .67917 .58172 L p F P
0 0 0 r
s
.241 .455 .413 r
.67804 .55008 m .7251 .52585 L .72364 .49453 L p F P
0 0 0 r
s
.339 .627 .546 r
.56912 .64132 m .62666 .63114 L .62589 .59914 L p F P
0 0 0 r
s
.29 .541 .481 r
.67917 .58172 m .62589 .59914 L .62666 .63114 L p F P
0 0 0 r
s
.523 .961 .783 r
.34166 .60821 m .39398 .62731 L .39485 .59529 L p F P
0 0 0 r
s
.523 .961 .783 r
.39485 .59529 m .3429 .57608 L .34166 .60821 L p F P
0 0 0 r
s
.565 1 .833 r
.29734 .55035 m .3429 .57608 L .34413 .54441 L p F P
0 0 0 r
s
.565 1 .833 r
.34413 .54441 m .2989 .51855 L .29734 .55035 L p F P
0 0 0 r
s
.193 .367 .342 r
.76264 .46416 m .72364 .49453 L .7251 .52585 L p F P
0 0 0 r
s
.193 .367 .342 r
.72364 .49453 m .76264 .46416 L .76091 .43315 L p F P
0 0 0 r
s
.432 .794 .668 r
.45023 .67179 m .50972 .67647 L .50978 .64409 L p F P
0 0 0 r
s
.432 .794 .668 r
.50978 .64409 m .4507 .63938 L .45023 .67179 L p F P
0 0 0 r
s
.386 .711 .608 r
.56912 .64132 m .50978 .64409 L .50972 .67647 L p F P
0 0 0 r
s
.386 .711 .608 r
.50972 .67647 m .56949 .67372 L .56912 .64132 L p F P
0 0 0 r
s
.339 .627 .546 r
.62666 .63114 m .56912 .64132 L .56949 .67372 L p F P
0 0 0 r
s
.478 .878 .727 r
.3931 .65979 m .45023 .67179 L .4507 .63938 L p F P
0 0 0 r
s
.478 .878 .727 r
.4507 .63938 m .39398 .62731 L .3931 .65979 L p F P
0 0 0 r
s
.592 1 .861 r
.26192 .48692 m .2989 .51855 L .30044 .48719 L p F P
0 0 0 r
s
.592 1 .861 r
.30044 .48719 m .26374 .45541 L .26192 .48692 L p F P
0 0 0 r
s
.135 .257 .253 r
.79017 .39759 m .76091 .43315 L .76264 .46416 L p F P
0 0 0 r
s
.29 .541 .481 r
.62666 .63114 m .68032 .61382 L .67917 .58172 L p F P
0 0 0 r
s
.241 .455 .413 r
.72658 .55762 m .67917 .58172 L .68032 .61382 L p F P
0 0 0 r
s
.241 .455 .413 r
.67917 .58172 m .72658 .55762 L .7251 .52585 L p F P
0 0 0 r
s
.339 .627 .546 r
.56949 .67372 m .62743 .66359 L .62666 .63114 L p F P
0 0 0 r
s
.29 .541 .481 r
.68032 .61382 m .62666 .63114 L .62743 .66359 L p F P
0 0 0 r
s
.523 .961 .783 r
.34039 .64079 m .3931 .65979 L .39398 .62731 L p F P
0 0 0 r
s
.523 .961 .783 r
.39398 .62731 m .34166 .60821 L .34039 .64079 L p F P
0 0 0 r
s
.565 1 .833 r
.29575 .58261 m .34166 .60821 L .3429 .57608 L p F P
0 0 0 r
s
.565 1 .833 r
.3429 .57608 m .29734 .55035 L .29575 .58261 L p F P
0 0 0 r
s
.193 .367 .342 r
.76439 .49563 m .7251 .52585 L .72658 .55762 L p F P
0 0 0 r
s
.193 .367 .342 r
.7251 .52585 m .76439 .49563 L .76264 .46416 L p F P
0 0 0 r
s
.432 .794 .668 r
.44975 .70466 m .50967 .70931 L .50972 .67647 L p F P
0 0 0 r
s
.432 .794 .668 r
.50972 .67647 m .45023 .67179 L .44975 .70466 L p F P
0 0 0 r
s
.386 .711 .608 r
.56949 .67372 m .50972 .67647 L .50967 .70931 L p F P
0 0 0 r
s
.571 1 .825 r
.23698 .41889 m .26374 .45541 L .26554 .42436 L p F P
0 0 0 r
s
.571 1 .825 r
.26554 .42436 m .23899 .38768 L .23698 .41889 L p F P
0 0 0 r
s
.386 .711 .608 r
.50967 .70931 m .56986 .70658 L .56949 .67372 L p F P
0 0 0 r
s
.339 .627 .546 r
.62743 .66359 m .56949 .67372 L .56986 .70658 L p F P
0 0 0 r
s
.478 .878 .727 r
.39221 .69273 m .44975 .70466 L .45023 .67179 L p F P
0 0 0 r
s
.478 .878 .727 r
.45023 .67179 m .3931 .65979 L .39221 .69273 L p F P
0 0 0 r
s
.592 1 .861 r
.26007 .51887 m .29734 .55035 L .2989 .51855 L p F P
0 0 0 r
s
.592 1 .861 r
.2989 .51855 m .26192 .48692 L .26007 .51887 L p F P
0 0 0 r
s
.135 .257 .253 r
.79213 .42876 m .76264 .46416 L .76439 .49563 L p F P
0 0 0 r
s
.135 .257 .253 r
.76264 .46416 m .79213 .42876 L .79017 .39759 L p F P
0 0 0 r
s
.29 .541 .481 r
.62743 .66359 m .68148 .64637 L .68032 .61382 L p F P
0 0 0 r
s
.241 .455 .413 r
.72808 .58984 m .68032 .61382 L .68148 .64637 L p F P
0 0 0 r
s
.241 .455 .413 r
.68032 .61382 m .72808 .58984 L .72658 .55762 L p F P
0 0 0 r
s
.339 .627 .546 r
.56986 .70658 m .62822 .69651 L .62743 .66359 L p F P
0 0 0 r
s
.29 .541 .481 r
.68148 .64637 m .62743 .66359 L .62822 .69651 L p F P
0 0 0 r
s
.523 .961 .783 r
.33912 .67385 m .39221 .69273 L .3931 .65979 L p F P
0 0 0 r
s
.523 .961 .783 r
.3931 .65979 m .34039 .64079 L .33912 .67385 L p F P
0 0 0 r
s
.565 1 .833 r
.29415 .61534 m .34039 .64079 L .34166 .60821 L p F P
0 0 0 r
s
.565 1 .833 r
.34166 .60821 m .29575 .58261 L .29415 .61534 L p F P
0 0 0 r
s
.193 .367 .342 r
.76617 .52754 m .72658 .55762 L .72808 .58984 L p F P
0 0 0 r
s
.193 .367 .342 r
.72658 .55762 m .76617 .52754 L .76439 .49563 L p F P
0 0 0 r
s
.432 .794 .668 r
.44926 .738 m .50961 .74263 L .50967 .70931 L p F P
0 0 0 r
s
.432 .794 .668 r
.50967 .70931 m .44975 .70466 L .44926 .738 L p F P
0 0 0 r
s
.386 .711 .608 r
.56986 .70658 m .50967 .70931 L .50961 .74263 L p F P
0 0 0 r
s
.571 1 .825 r
.23494 .45056 m .26192 .48692 L .26374 .45541 L p F P
0 0 0 r
s
.571 1 .825 r
.26374 .45541 m .23698 .41889 L .23494 .45056 L p F P
0 0 0 r
s
.386 .711 .608 r
.50961 .74263 m .57023 .73991 L .56986 .70658 L p F P
0 0 0 r
s
.339 .627 .546 r
.62822 .69651 m .56986 .70658 L .57023 .73991 L p F P
0 0 0 r
s
.478 .878 .727 r
.3913 .72615 m .44926 .738 L .44975 .70466 L p F P
0 0 0 r
s
.478 .878 .727 r
.44975 .70466 m .39221 .69273 L .3913 .72615 L p F P
0 0 0 r
s
.592 1 .861 r
.2582 .5513 m .29575 .58261 L .29734 .55035 L p F P
0 0 0 r
s
.592 1 .861 r
.29734 .55035 m .26007 .51887 L .2582 .5513 L p F P
0 0 0 r
s
.059 .119 .141 r
.80843 .35823 m .79017 .39759 L .79213 .42876 L p F P
0 0 0 r
s
.135 .257 .253 r
.79412 .46038 m .76439 .49563 L .76617 .52754 L p F P
0 0 0 r
s
.135 .257 .253 r
.76439 .49563 m .79412 .46038 L .79213 .42876 L p F P
0 0 0 r
s
.29 .541 .481 r
.62822 .69651 m .68266 .67939 L .68148 .64637 L p F P
0 0 0 r
s
.241 .455 .413 r
.7296 .62253 m .68148 .64637 L .68266 .67939 L p F P
0 0 0 r
s
.241 .455 .413 r
.68148 .64637 m .7296 .62253 L .72808 .58984 L p F P
0 0 0 r
s
.339 .627 .546 r
.57023 .73991 m .62902 .72991 L .62822 .69651 L p F P
0 0 0 r
s
.29 .541 .481 r
.68266 .67939 m .62822 .69651 L .62902 .72991 L p F P
0 0 0 r
s
.442 .842 .646 r
.22166 .37894 m .23698 .41889 L .23899 .38768 L p F P
0 0 0 r
s
.442 .842 .646 r
.23899 .38768 m .22381 .34757 L .22166 .37894 L p F P
0 0 0 r
s
.523 .961 .783 r
.33782 .70739 m .3913 .72615 L .39221 .69273 L p F P
0 0 0 r
s
.523 .961 .783 r
.39221 .69273 m .33912 .67385 L .33782 .70739 L p F P
0 0 0 r
s
.565 1 .833 r
.29252 .64855 m .33912 .67385 L .34039 .64079 L p F P
0 0 0 r
s
.565 1 .833 r
.34039 .64079 m .29415 .61534 L .29252 .64855 L p F P
0 0 0 r
s
.193 .367 .342 r
.76798 .55992 m .72808 .58984 L .7296 .62253 L p F P
0 0 0 r
s
.193 .367 .342 r
.72808 .58984 m .76798 .55992 L .76617 .52754 L p F P
0 0 0 r
s
.432 .794 .668 r
.44877 .77183 m .50955 .77642 L .50961 .74263 L p F P
0 0 0 r
s
.432 .794 .668 r
.50961 .74263 m .44926 .738 L .44877 .77183 L p F P
0 0 0 r
s
.386 .711 .608 r
.57023 .73991 m .50961 .74263 L .50955 .77642 L p F P
0 0 0 r
s
.571 1 .825 r
.23287 .48268 m .26007 .51887 L .26192 .48692 L p F P
0 0 0 r
s
.571 1 .825 r
.26192 .48692 m .23494 .45056 L .23287 .48268 L p F P
0 0 0 r
s
.386 .711 .608 r
.50955 .77642 m .57062 .77372 L .57023 .73991 L p F P
0 0 0 r
s
.339 .627 .546 r
.62902 .72991 m .57023 .73991 L .57062 .77372 L p F P
0 0 0 r
s
.478 .878 .727 r
.39038 .76006 m .44877 .77183 L .44926 .738 L p F P
0 0 0 r
s
.478 .878 .727 r
.44926 .738 m .3913 .72615 L .39038 .76006 L p F P
0 0 0 r
s
.592 1 .861 r
.2563 .58419 m .29415 .61534 L .29575 .58261 L p F P
0 0 0 r
s
.592 1 .861 r
.29575 .58261 m .2582 .5513 L .2563 .58419 L p F P
0 0 0 r
s
.059 .119 .141 r
.81055 .38955 m .79213 .42876 L .79412 .46038 L p F P
0 0 0 r
s
.059 .119 .141 r
.79213 .42876 m .81055 .38955 L .80843 .35823 L p F P
0 0 0 r
s
.135 .257 .253 r
.79614 .49246 m .76617 .52754 L .76798 .55992 L p F P
0 0 0 r
s
.135 .257 .253 r
.76617 .52754 m .79614 .49246 L .79412 .46038 L p F P
0 0 0 r
s
.29 .541 .481 r
.62902 .72991 m .68386 .7129 L .68266 .67939 L p F P
0 0 0 r
s
.241 .455 .413 r
.73114 .65569 m .68266 .67939 L .68386 .7129 L p F P
0 0 0 r
s
.241 .455 .413 r
.68266 .67939 m .73114 .65569 L .7296 .62253 L p F P
0 0 0 r
s
.339 .627 .546 r
.57062 .77372 m .62983 .76379 L .62902 .72991 L p F P
0 0 0 r
s
.29 .541 .481 r
.68386 .7129 m .62902 .72991 L .62983 .76379 L p F P
0 0 0 r
s
.442 .842 .646 r
.21948 .41077 m .23494 .45056 L .23698 .41889 L p F P
0 0 0 r
s
.442 .842 .646 r
.23698 .41889 m .22166 .37894 L .21948 .41077 L p F P
0 0 0 r
s
.523 .961 .783 r
.3365 .74142 m .39038 .76006 L .3913 .72615 L p F P
0 0 0 r
s
.523 .961 .783 r
.3913 .72615 m .33782 .70739 L .3365 .74142 L p F P
0 0 0 r
s
.565 1 .833 r
.29086 .68224 m .33782 .70739 L .33912 .67385 L p F P
0 0 0 r
s
.565 1 .833 r
.33912 .67385 m .29252 .64855 L .29086 .68224 L p F P
0 0 0 r
s
.193 .367 .342 r
.76981 .59277 m .7296 .62253 L .73114 .65569 L p F P
0 0 0 r
s
.193 .367 .342 r
.7296 .62253 m .76981 .59277 L .76798 .55992 L p F P
0 0 0 r
s
.432 .794 .668 r
.44827 .80615 m .5095 .81071 L .50955 .77642 L p F P
0 0 0 r
s
.432 .794 .668 r
.50955 .77642 m .44877 .77183 L .44827 .80615 L p F P
0 0 0 r
s
.386 .711 .608 r
.57062 .77372 m .50955 .77642 L .5095 .81071 L p F P
0 0 0 r
s
.571 1 .825 r
.23077 .51528 m .2582 .5513 L .26007 .51887 L p F P
0 0 0 r
s
.571 1 .825 r
.26007 .51887 m .23287 .48268 L .23077 .51528 L p F P
0 0 0 r
s
.386 .711 .608 r
.5095 .81071 m .571 .80802 L .57062 .77372 L p F P
0 0 0 r
s
.339 .627 .546 r
.62983 .76379 m .57062 .77372 L .571 .80802 L p F P
0 0 0 r
s
.478 .878 .727 r
.38945 .79446 m .44827 .80615 L .44877 .77183 L p F P
0 0 0 r
s
.478 .878 .727 r
.44877 .77183 m .39038 .76006 L .38945 .79446 L p F P
0 0 0 r
s
.035 .07 .083 r
.81443 .31656 m .80843 .35823 L .81055 .38955 L p F P
0 0 0 r
s
.592 1 .861 r
.25437 .61758 m .29252 .64855 L .29415 .61534 L p F P
0 0 0 r
s
.592 1 .861 r
.29415 .61534 m .2563 .58419 L .25437 .61758 L p F P
0 0 0 r
s
.059 .119 .141 r
.8127 .42134 m .79412 .46038 L .79614 .49246 L p F P
0 0 0 r
s
.059 .119 .141 r
.79412 .46038 m .8127 .42134 L .81055 .38955 L p F P
0 0 0 r
s
.135 .257 .253 r
.79819 .52501 m .76798 .55992 L .76981 .59277 L p F P
0 0 0 r
s
.135 .257 .253 r
.76798 .55992 m .79819 .52501 L .79614 .49246 L p F P
0 0 0 r
s
.29 .541 .481 r
.62983 .76379 m .68508 .74689 L .68386 .7129 L p F P
0 0 0 r
s
.241 .455 .413 r
.73271 .68934 m .68386 .7129 L .68508 .74689 L p F P
0 0 0 r
s
.241 .455 .413 r
.68386 .7129 m .73271 .68934 L .73114 .65569 L p F P
0 0 0 r
s
.339 .627 .546 r
.571 .80802 m .63065 .79816 L .62983 .76379 L p F P
0 0 0 r
s
.29 .541 .481 r
.68508 .74689 m .62983 .76379 L .63065 .79816 L p F P
0 0 0 r
s
.295 .575 .424 r
.21893 .33712 m .22166 .37894 L .22381 .34757 L p F P
0 0 0 r
s
.295 .575 .424 r
.22381 .34757 m .22114 .30559 L .21893 .33712 L p F P
0 0 0 r
s
.442 .842 .646 r
.21726 .44307 m .23287 .48268 L .23494 .45056 L p F P
0 0 0 r
s
.442 .842 .646 r
.23494 .45056 m .21948 .41077 L .21726 .44307 L p F P
0 0 0 r
s
.523 .961 .783 r
.33516 .77595 m .38945 .79446 L .39038 .76006 L p F P
0 0 0 r
s
.523 .961 .783 r
.39038 .76006 m .3365 .74142 L .33516 .77595 L p F P
0 0 0 r
s
.565 1 .833 r
.28918 .71643 m .3365 .74142 L .33782 .70739 L p F P
0 0 0 r
s
.565 1 .833 r
.33782 .70739 m .29086 .68224 L .28918 .71643 L p F P
0 0 0 r
s
.193 .367 .342 r
.77166 .62611 m .73114 .65569 L .73271 .68934 L p F P
0 0 0 r
s
.193 .367 .342 r
.73114 .65569 m .77166 .62611 L .76981 .59277 L p F P
0 0 0 r
s
.432 .794 .668 r
.44776 .84097 m .50944 .84549 L .5095 .81071 L p F P
0 0 0 r
s
.432 .794 .668 r
.5095 .81071 m .44827 .80615 L .44776 .84097 L p F P
0 0 0 r
s
.386 .711 .608 r
.571 .80802 m .5095 .81071 L .50944 .84549 L p F P
0 0 0 r
s
.571 1 .825 r
.22864 .54837 m .2563 .58419 L .2582 .5513 L p F P
0 0 0 r
s
.571 1 .825 r
.2582 .5513 m .23077 .51528 L .22864 .54837 L p F P
0 0 0 r
s
.386 .711 .608 r
.50944 .84549 m .5714 .84283 L .571 .80802 L p F P
0 0 0 r
s
.339 .627 .546 r
.63065 .79816 m .571 .80802 L .5714 .84283 L p F P
0 0 0 r
s
.478 .878 .727 r
.38851 .82937 m .44776 .84097 L .44827 .80615 L p F P
0 0 0 r
s
.478 .878 .727 r
.44827 .80615 m .38945 .79446 L .38851 .82937 L p F P
0 0 0 r
s
.035 .07 .083 r
.81663 .34805 m .81055 .38955 L .8127 .42134 L p F P
0 0 0 r
s
.035 .07 .083 r
.81055 .38955 m .81663 .34805 L .81443 .31656 L p F P
0 0 0 r
s
.592 1 .861 r
.25241 .65146 m .29086 .68224 L .29252 .64855 L p F P
0 0 0 r
s
.592 1 .861 r
.29252 .64855 m .25437 .61758 L .25241 .65146 L p F P
0 0 0 r
s
.059 .119 .141 r
.81489 .4536 m .79614 .49246 L .79819 .52501 L p F P
0 0 0 r
s
.059 .119 .141 r
.79614 .49246 m .81489 .4536 L .8127 .42134 L p F P
0 0 0 r
s
.135 .257 .253 r
.80027 .55805 m .76981 .59277 L .77166 .62611 L p F P
0 0 0 r
s
.135 .257 .253 r
.76981 .59277 m .80027 .55805 L .79819 .52501 L p F P
0 0 0 r
s
.29 .541 .481 r
.63065 .79816 m .68632 .78138 L .68508 .74689 L p F P
0 0 0 r
s
.241 .455 .413 r
.7343 .72349 m .68508 .74689 L .68632 .78138 L p F P
0 0 0 r
s
.241 .455 .413 r
.68508 .74689 m .7343 .72349 L .73271 .68934 L p F P
0 0 0 r
s
.339 .627 .546 r
.5714 .84283 m .63148 .83304 L .63065 .79816 L p F P
0 0 0 r
s
.29 .541 .481 r
.68632 .78138 m .63065 .79816 L .63148 .83304 L p F P
0 0 0 r
s
.295 .575 .424 r
.2167 .36911 m .21948 .41077 L .22166 .37894 L p F P
0 0 0 r
s
.295 .575 .424 r
.22166 .37894 m .21893 .33712 L .2167 .36911 L p F P
0 0 0 r
s
.442 .842 .646 r
.21501 .47586 m .23077 .51528 L .23287 .48268 L p F P
0 0 0 r
s
.442 .842 .646 r
.23287 .48268 m .21726 .44307 L .21501 .47586 L p F P
0 0 0 r
s
.523 .961 .783 r
.33381 .811 m .38851 .82937 L .38945 .79446 L p F P
0 0 0 r
s
.523 .961 .783 r
.38945 .79446 m .33516 .77595 L .33381 .811 L p F P
0 0 0 r
s
.565 1 .833 r
.28748 .75114 m .33516 .77595 L .3365 .74142 L p F P
0 0 0 r
s
.565 1 .833 r
.3365 .74142 m .28918 .71643 L .28748 .75114 L p F P
0 0 0 r
s
.193 .367 .342 r
.77355 .65994 m .73271 .68934 L .7343 .72349 L p F P
0 0 0 r
s
.193 .367 .342 r
.73271 .68934 m .77355 .65994 L .77166 .62611 L p F P
0 0 0 r
s
.432 .794 .668 r
.44724 .87631 m .50938 .8808 L .50944 .84549 L p F P
0 0 0 r
s
.432 .794 .668 r
.50944 .84549 m .44776 .84097 L .44724 .87631 L p F P
0 0 0 r
s
.386 .711 .608 r
.5714 .84283 m .50944 .84549 L .50938 .8808 L p F P
0 0 0 r
s
.571 1 .825 r
.22647 .58195 m .25437 .61758 L .2563 .58419 L p F P
0 0 0 r
s
.571 1 .825 r
.2563 .58419 m .22864 .54837 L .22647 .58195 L p F P
0 0 0 r
s
.386 .711 .608 r
.50938 .8808 m .57179 .87815 L .5714 .84283 L p F P
0 0 0 r
s
.339 .627 .546 r
.63148 .83304 m .5714 .84283 L .57179 .87815 L p F P
0 0 0 r
s
.478 .878 .727 r
.38755 .8648 m .44724 .87631 L .44776 .84097 L p F P
0 0 0 r
s
.478 .878 .727 r
.44776 .84097 m .38851 .82937 L .38755 .8648 L p F P
0 0 0 r
s
.035 .07 .083 r
.81886 .38001 m .8127 .42134 L .81489 .4536 L p F P
0 0 0 r
s
.035 .07 .083 r
.8127 .42134 m .81886 .38001 L .81663 .34805 L p F P
0 0 0 r
s
.592 1 .861 r
.25042 .68585 m .28918 .71643 L .29086 .68224 L p F P
0 0 0 r
s
.592 1 .861 r
.29086 .68224 m .25241 .65146 L .25042 .68585 L p F P
0 0 0 r
s
.255 .486 .348 r
.80737 .27436 m .81443 .31656 L .81663 .34805 L p F P
0 0 0 r
s
.059 .119 .141 r
.81711 .48634 m .79819 .52501 L .80027 .55805 L p F P
0 0 0 r
s
.059 .119 .141 r
.79819 .52501 m .81711 .48634 L .81489 .4536 L p F P
0 0 0 r
s
.135 .257 .253 r
.80238 .59158 m .77166 .62611 L .77355 .65994 L p F P
0 0 0 r
s
.135 .257 .253 r
.77166 .62611 m .80238 .59158 L .80027 .55805 L p F P
0 0 0 r
s
.29 .541 .481 r
.63148 .83304 m .68757 .81639 L .68632 .78138 L p F P
0 0 0 r
s
.241 .455 .413 r
.73591 .75815 m .68632 .78138 L .68757 .81639 L p F P
0 0 0 r
s
.241 .455 .413 r
.68632 .78138 m .73591 .75815 L .7343 .72349 L p F P
0 0 0 r
s
.339 .627 .546 r
.57179 .87815 m .63233 .86844 L .63148 .83304 L p F P
0 0 0 r
s
.29 .541 .481 r
.68757 .81639 m .63148 .83304 L .63233 .86844 L p F P
0 0 0 r
s
.295 .575 .424 r
.21443 .4016 m .21726 .44307 L .21948 .41077 L p F P
0 0 0 r
s
.295 .575 .424 r
.21948 .41077 m .2167 .36911 L .21443 .4016 L p F P
0 0 0 r
s
.442 .842 .646 r
.21273 .50915 m .22864 .54837 L .23077 .51528 L p F P
0 0 0 r
s
.442 .842 .646 r
.23077 .51528 m .21501 .47586 L .21273 .50915 L p F P
0 0 0 r
s
.017 .035 .042 r
.22949 .29522 m .21893 .33712 L .22114 .30559 L p F P
0 0 0 r
s
.017 .035 .042 r
.22114 .30559 m .23165 .26355 L .22949 .29522 L p F P
0 0 0 r
s
.523 .961 .783 r
.33243 .84657 m .38755 .8648 L .38851 .82937 L p F P
0 0 0 r
s
.523 .961 .783 r
.38851 .82937 m .33381 .811 L .33243 .84657 L p F P
0 0 0 r
s
.565 1 .833 r
.28575 .78636 m .33381 .811 L .33516 .77595 L p F P
0 0 0 r
s
.565 1 .833 r
.33516 .77595 m .28748 .75114 L .28575 .78636 L p F P
0 0 0 r
s
.193 .367 .342 r
.77546 .69427 m .7343 .72349 L .73591 .75815 L p F P
0 0 0 r
s
.193 .367 .342 r
.7343 .72349 m .77546 .69427 L .77355 .65994 L p F P
0 0 0 r
s
.432 .794 .668 r
.44672 .91217 m .50932 .91662 L .50938 .8808 L p F P
0 0 0 r
s
.432 .794 .668 r
.50938 .8808 m .44724 .87631 L .44672 .91217 L p F P
0 0 0 r
s
.386 .711 .608 r
.57179 .87815 m .50938 .8808 L .50932 .91662 L p F P
0 0 0 r
s
.571 1 .825 r
.22428 .61604 m .25241 .65146 L .25437 .61758 L p F P
0 0 0 r
s
.571 1 .825 r
.25437 .61758 m .22647 .58195 L .22428 .61604 L p F P
0 0 0 r
s
.386 .711 .608 r
.50932 .91662 m .5722 .914 L .57179 .87815 L p F P
0 0 0 r
s
.339 .627 .546 r
.63233 .86844 m .57179 .87815 L .5722 .914 L p F P
0 0 0 r
s
.478 .878 .727 r
.38657 .90076 m .44672 .91217 L .44724 .87631 L p F P
0 0 0 r
s
.478 .878 .727 r
.44724 .87631 m .38755 .8648 L .38657 .90076 L p F P
0 0 0 r
s
.035 .07 .083 r
.82113 .41245 m .81489 .4536 L .81711 .48634 L p F P
0 0 0 r
s
.035 .07 .083 r
.81489 .4536 m .82113 .41245 L .81886 .38001 L p F P
0 0 0 r
s
.592 1 .861 r
.2484 .72076 m .28748 .75114 L .28918 .71643 L p F P
0 0 0 r
s
.592 1 .861 r
.28918 .71643 m .25042 .68585 L .2484 .72076 L p F P
0 0 0 r
s
.255 .486 .348 r
.80955 .30599 m .81663 .34805 L .81886 .38001 L p F P
0 0 0 r
s
.255 .486 .348 r
.81663 .34805 m .80955 .30599 L .80737 .27436 L p F P
0 0 0 r
s
.059 .119 .141 r
.81936 .51957 m .80027 .55805 L .80238 .59158 L p F P
0 0 0 r
s
.059 .119 .141 r
.80027 .55805 m .81936 .51957 L .81711 .48634 L p F P
0 0 0 r
s
.135 .257 .253 r
.80452 .62561 m .77355 .65994 L .77546 .69427 L p F P
0 0 0 r
s
.135 .257 .253 r
.77355 .65994 m .80452 .62561 L .80238 .59158 L p F P
0 0 0 r
s
.29 .541 .481 r
.63233 .86844 m .68884 .85192 L .68757 .81639 L p F P
0 0 0 r
s
.241 .455 .413 r
.73755 .79332 m .68757 .81639 L .68884 .85192 L p F P
0 0 0 r
s
.241 .455 .413 r
.68757 .81639 m .73755 .79332 L .73591 .75815 L p F P
0 0 0 r
s
.339 .627 .546 r
.5722 .914 m .63319 .90437 L .63233 .86844 L p F P
0 0 0 r
s
.29 .541 .481 r
.68884 .85192 m .63233 .86844 L .63319 .90437 L p F P
0 0 0 r
s
.295 .575 .424 r
.21212 .43457 m .21501 .47586 L .21726 .44307 L p F P
0 0 0 r
s
.295 .575 .424 r
.21726 .44307 m .21443 .4016 L .21212 .43457 L p F P
0 0 0 r
s
.442 .842 .646 r
.21041 .54294 m .22647 .58195 L .22864 .54837 L p F P
0 0 0 r
s
.442 .842 .646 r
.22864 .54837 m .21273 .50915 L .21041 .54294 L p F P
0 0 0 r
s
.017 .035 .042 r
.2273 .32738 m .2167 .36911 L .21893 .33712 L p F P
0 0 0 r
s
.017 .035 .042 r
.21893 .33712 m .22949 .29522 L .2273 .32738 L p F P
0 0 0 r
s
.523 .961 .783 r
.33103 .88268 m .38657 .90076 L .38755 .8648 L p F P
0 0 0 r
s
.523 .961 .783 r
.38755 .8648 m .33243 .84657 L .33103 .88268 L p F P
0 0 0 r
s
.565 1 .833 r
.28399 .82212 m .33243 .84657 L .33381 .811 L p F P
0 0 0 r
s
.565 1 .833 r
.33381 .811 m .28575 .78636 L .28399 .82212 L p F P
0 0 0 r
s
.193 .367 .342 r
.77741 .72913 m .73591 .75815 L .73755 .79332 L p F P
0 0 0 r
s
.193 .367 .342 r
.73591 .75815 m .77741 .72913 L .77546 .69427 L p F P
0 0 0 r
s
.432 .794 .668 r
.44619 .94857 m .50926 .95299 L .50932 .91662 L p F P
0 0 0 r
s
.432 .794 .668 r
.50932 .91662 m .44672 .91217 L .44619 .94857 L p F P
0 0 0 r
s
.386 .711 .608 r
.5722 .914 m .50932 .91662 L .50926 .95299 L p F P
0 0 0 r
s
.571 1 .825 r
.22204 .65065 m .25042 .68585 L .25241 .65146 L p F P
0 0 0 r
s
.571 1 .825 r
.25241 .65146 m .22428 .61604 L .22204 .65065 L p F P
0 0 0 r
s
.386 .711 .608 r
.50926 .95299 m .57261 .95039 L .5722 .914 L p F P
0 0 0 r
s
.339 .627 .546 r
.63319 .90437 m .5722 .914 L .57261 .95039 L p F P
0 0 0 r
s
.478 .878 .727 r
.38558 .93726 m .44619 .94857 L .44672 .91217 L p F P
0 0 0 r
s
.478 .878 .727 r
.44672 .91217 m .38657 .90076 L .38558 .93726 L p F P
0 0 0 r
s
.035 .07 .083 r
.82343 .44537 m .81711 .48634 L .81936 .51957 L p F P
0 0 0 r
s
.035 .07 .083 r
.81711 .48634 m .82343 .44537 L .82113 .41245 L p F P
0 0 0 r
s
.386 .722 .553 r
.787 .23353 m .80737 .27436 L .80955 .30599 L p F P
0 0 0 r
s
.592 1 .861 r
.24635 .7562 m .28575 .78636 L .28748 .75114 L p F P
0 0 0 r
s
.592 1 .861 r
.28748 .75114 m .2484 .72076 L .24635 .7562 L p F P
0 0 0 r
s
.255 .486 .348 r
.81177 .33811 m .81886 .38001 L .82113 .41245 L p F P
0 0 0 r
s
.255 .486 .348 r
.81886 .38001 m .81177 .33811 L .80955 .30599 L p F P
0 0 0 r
s
.059 .119 .141 r
.82165 .55331 m .80238 .59158 L .80452 .62561 L p F P
0 0 0 r
s
.059 .119 .141 r
.80238 .59158 m .82165 .55331 L .81936 .51957 L p F P
0 0 0 r
s
.135 .257 .253 r
.8067 .66016 m .77546 .69427 L .77741 .72913 L p F P
0 0 0 r
s
.135 .257 .253 r
.77546 .69427 m .8067 .66016 L .80452 .62561 L p F P
0 0 0 r
s
.29 .541 .481 r
.63319 .90437 m .69013 .88799 L .68884 .85192 L p F P
0 0 0 r
s
.241 .455 .413 r
.73921 .82903 m .68884 .85192 L .69013 .88799 L p F P
0 0 0 r
s
.241 .455 .413 r
.68884 .85192 m .73921 .82903 L .73755 .79332 L p F P
0 0 0 r
s
.339 .627 .546 r
.57261 .95039 m .63406 .94085 L .63319 .90437 L p F P
0 0 0 r
s
.29 .541 .481 r
.69013 .88799 m .63319 .90437 L .63406 .94085 L p F P
0 0 0 r
s
.047 .094 .112 r
.25343 .25522 m .22949 .29522 L .23165 .26355 L p F P
0 0 0 r
s
.047 .094 .112 r
.23165 .26355 m .25544 .22341 L .25343 .25522 L p F P
0 0 0 r
s
.295 .575 .424 r
.20978 .46806 m .21273 .50915 L .21501 .47586 L p F P
0 0 0 r
s
.295 .575 .424 r
.21501 .47586 m .21212 .43457 L .20978 .46806 L p F P
0 0 0 r
s
.442 .842 .646 r
.20806 .57725 m .22428 .61604 L .22647 .58195 L p F P
0 0 0 r
s
.442 .842 .646 r
.22647 .58195 m .21041 .54294 L .20806 .57725 L p F P
0 0 0 r
s
.017 .035 .042 r
.22508 .36003 m .21443 .4016 L .2167 .36911 L p F P
0 0 0 r
s
.017 .035 .042 r
.2167 .36911 m .2273 .32738 L .22508 .36003 L p F P
0 0 0 r
s
.523 .961 .783 r
.32961 .91934 m .38558 .93726 L .38657 .90076 L p F P
0 0 0 r
s
.523 .961 .783 r
.38657 .90076 m .33103 .88268 L .32961 .91934 L p F P
0 0 0 r
s
.565 1 .833 r
.28221 .85843 m .33103 .88268 L .33243 .84657 L p F P
0 0 0 r
s
.565 1 .833 r
.33243 .84657 m .28399 .82212 L .28221 .85843 L p F P
0 0 0 r
s
.193 .367 .342 r
.77938 .76451 m .73755 .79332 L .73921 .82903 L p F P
0 0 0 r
s
.193 .367 .342 r
.73755 .79332 m .77938 .76451 L .77741 .72913 L p F P
0 0 0 r
s
.432 .794 .668 r
.44565 .98553 m .50919 .9899 L .50926 .95299 L p F P
0 0 0 r
s
.432 .794 .668 r
.50926 .95299 m .44619 .94857 L .44565 .98553 L p F P
0 0 0 r
s
.386 .711 .608 r
.57261 .95039 m .50926 .95299 L .50919 .9899 L p F P
0 0 0 r
s
.571 1 .825 r
.21978 .68579 m .2484 .72076 L .25042 .68585 L p F P
0 0 0 r
s
.571 1 .825 r
.25042 .68585 m .22204 .65065 L .21978 .68579 L p F P
0 0 0 r
s
.386 .711 .608 r
.50919 .9899 m .57303 .98733 L .57261 .95039 L p F P
0 0 0 r
s
.339 .627 .546 r
.63406 .94085 m .57261 .95039 L .57303 .98733 L p F P
0 0 0 r
s
.478 .878 .727 r
.38458 .97432 m .44565 .98553 L .44619 .94857 L p F P
0 0 0 r
s
.478 .878 .727 r
.44619 .94857 m .38558 .93726 L .38458 .97432 L p F P
0 0 0 r
s
.035 .07 .083 r
.82577 .47881 m .81936 .51957 L .82165 .55331 L p F P
0 0 0 r
s
.035 .07 .083 r
.81936 .51957 m .82577 .47881 L .82343 .44537 L p F P
0 0 0 r
s
.386 .722 .553 r
.78906 .26531 m .80955 .30599 L .81177 .33811 L p F P
0 0 0 r
s
.386 .722 .553 r
.80955 .30599 m .78906 .26531 L .787 .23353 L p F P
0 0 0 r
s
.592 1 .861 r
.24427 .79218 m .28399 .82212 L .28575 .78636 L p F P
0 0 0 r
s
.592 1 .861 r
.28575 .78636 m .24635 .7562 L .24427 .79218 L p F P
0 0 0 r
s
.255 .486 .348 r
.81401 .37072 m .82113 .41245 L .82343 .44537 L p F P
0 0 0 r
s
.255 .486 .348 r
.82113 .41245 m .81401 .37072 L .81177 .33811 L p F P
0 0 0 r
s
.059 .119 .141 r
.82397 .58756 m .80452 .62561 L .8067 .66016 L p F P
0 0 0 r
s
.059 .119 .141 r
.80452 .62561 m .82397 .58756 L .82165 .55331 L p F P
0 0 0 r
s
.135 .257 .253 r
.80891 .69524 m .77741 .72913 L .77938 .76451 L p F P
0 0 0 r
s
.135 .257 .253 r
.77741 .72913 m .80891 .69524 L .8067 .66016 L p F P
0 0 0 r
s
.29 .541 .481 r
.63406 .94085 m .69144 .9246 L .69013 .88799 L p F P
0 0 0 r
s
.241 .455 .413 r
.7409 .86528 m .69013 .88799 L .69144 .9246 L p F P
0 0 0 r
s
.241 .455 .413 r
.69013 .88799 m .7409 .86528 L .73921 .82903 L p F P
0 0 0 r
s
.339 .627 .546 r
.57303 .98733 m .63495 .97787 L .63406 .94085 L p F P
0 0 0 r
s
.29 .541 .481 r
.69144 .9246 m .63406 .94085 L .63495 .97787 L p F P
0 0 0 r
s
1 .886 .202 r
.47226 .83645 m .47677 .80177 L .49193 .79311 L p F P
0 0 0 r
s
1 .886 .202 r
.49193 .79311 m .48909 .82974 L .47226 .83645 L p F P
0 0 0 r
s
1 .933 .211 r
.49477 .75815 m .49193 .79311 L .47677 .80177 L p F P
0 0 0 r
s
1 .657 .159 r
.48909 .82974 m .49193 .79311 L .50712 .80404 L p F P
0 0 0 r
s
1 .616 .15 r
.49193 .79311 m .49477 .75815 L .50827 .77066 L p F P
0 0 0 r
s
1 .616 .15 r
.50827 .77066 m .50712 .80404 L .49193 .79311 L p F P
0 0 0 r
s
1 .846 .194 r
.46773 .87239 m .47226 .83645 L .48909 .82974 L p F P
0 0 0 r
s
1 .846 .194 r
.48909 .82974 m .48623 .86775 L .46773 .87239 L p F P
0 0 0 r
s
1 .689 .165 r
.48623 .86775 m .48909 .82974 L .50597 .83893 L p F P
0 0 0 r
s
1 .657 .159 r
.50712 .80404 m .50597 .83893 L .48909 .82974 L p F P
0 0 0 r
s
1 .933 .211 r
.47677 .80177 m .48128 .76862 L .49477 .75815 L p F P
0 0 0 r
s
1 .985 .22 r
.4976 .7251 m .49477 .75815 L .48128 .76862 L p F P
0 0 0 r
s
.936 .563 .14 r
.49477 .75815 m .4976 .7251 L .50941 .73904 L p F P
0 0 0 r
s
.936 .563 .14 r
.50941 .73904 m .50827 .77066 L .49477 .75815 L p F P
0 0 0 r
s
.047 .094 .112 r
.2514 .28752 m .2273 .32738 L .22949 .29522 L p F P
0 0 0 r
s
.047 .094 .112 r
.22949 .29522 m .25343 .25522 L .2514 .28752 L p F P
0 0 0 r
s
1 .814 .188 r
.46319 .90932 m .46773 .87239 L .48623 .86775 L p F P
0 0 0 r
s
1 .814 .188 r
.48623 .86775 m .48337 .90685 L .46319 .90932 L p F P
0 0 0 r
s
1 .715 .17 r
.48337 .90685 m .48623 .86775 L .50481 .87508 L p F P
0 0 0 r
s
1 .689 .165 r
.50597 .83893 m .50481 .87508 L .48623 .86775 L p F P
0 0 0 r
s
.295 .575 .424 r
.2074 .50206 m .21041 .54294 L .21273 .50915 L p F P
0 0 0 r
s
.295 .575 .424 r
.21273 .50915 m .20978 .46806 L .2074 .50206 L p F P
0 0 0 r
s
.442 .842 .646 r
.20567 .61209 m .22204 .65065 L .22428 .61604 L p F P
0 0 0 r
s
.442 .842 .646 r
.22428 .61604 m .20806 .57725 L .20567 .61209 L p F P
0 0 0 r
s
.017 .035 .042 r
.22282 .39319 m .21212 .43457 L .21443 .4016 L p F P
0 0 0 r
s
.017 .035 .042 r
.21443 .4016 m .22508 .36003 L .22282 .39319 L p F P
0 0 0 r
s
.523 .961 .783 r
.32817 .95656 m .38458 .97432 L .38558 .93726 L p F P
0 0 0 r
s
.523 .961 .783 r
.38558 .93726 m .32961 .91934 L .32817 .95656 L p F P
0 0 0 r
s
1 .985 .22 r
.48128 .76862 m .48578 .73722 L .4976 .7251 L p F P
0 0 0 r
s
1 1 .227 r
.50042 .69419 m .4976 .7251 L .48578 .73722 L p F P
0 0 0 r
s
.819 .495 .126 r
.4976 .7251 m .50042 .69419 L .51056 .70936 L p F P
0 0 0 r
s
.819 .495 .126 r
.51056 .70936 m .50941 .73904 L .4976 .7251 L p F P
0 0 0 r
s
1 .787 .183 r
.45864 .94693 m .46319 .90932 L .48337 .90685 L p F P
0 0 0 r
s
1 .787 .183 r
.48337 .90685 m .4805 .94672 L .45864 .94693 L p F P
0 0 0 r
s
1 .737 .174 r
.4805 .94672 m .48337 .90685 L .50366 .9122 L p F P
0 0 0 r
s
1 .715 .17 r
.50481 .87508 m .50366 .9122 L .48337 .90685 L p F P
0 0 0 r
s
.565 1 .833 r
.2804 .89529 m .32961 .91934 L .33103 .88268 L p F P
0 0 0 r
s
.565 1 .833 r
.33103 .88268 m .28221 .85843 L .2804 .89529 L p F P
0 0 0 r
s
.193 .367 .342 r
.78138 .80043 m .73921 .82903 L .7409 .86528 L p F P
0 0 0 r
s
.193 .367 .342 r
.73921 .82903 m .78138 .80043 L .77938 .76451 L p F P
0 0 0 r
s
1 .619 .152 r
.50366 .9122 m .50481 .87508 L .52352 .8935 L p F P
0 0 0 r
s
.86 .52 .131 r
.50481 .87508 m .50597 .83893 L .52298 .86292 L p F P
0 0 0 r
s
.86 .52 .131 r
.52298 .86292 m .52352 .8935 L .50481 .87508 L p F P
0 0 0 r
s
.686 .417 .108 r
.50597 .83893 m .50712 .80404 L .52244 .83325 L p F P
0 0 0 r
s
.686 .417 .108 r
.52244 .83325 m .52298 .86292 L .50597 .83893 L p F P
0 0 0 r
s
1 .737 .174 r
.50366 .9122 m .5025 .95001 L .4805 .94672 L p F P
0 0 0 r
s
1 .705 .169 r
.5025 .95001 m .50366 .9122 L .52406 .92475 L p F P
0 0 0 r
s
1 .619 .152 r
.52352 .8935 m .52406 .92475 L .50366 .9122 L p F P
0 0 0 r
s
.571 1 .825 r
.21748 .72147 m .24635 .7562 L .2484 .72076 L p F P
0 0 0 r
s
.571 1 .825 r
.2484 .72076 m .21978 .68579 L .21748 .72147 L p F P
0 0 0 r
s
1 .756 .177 r
.47762 .98702 m .4805 .94672 L .5025 .95001 L p F P
0 0 0 r
s
1 .756 .177 r
.5025 .95001 m .50134 .98816 L .47762 .98702 L p F P
0 0 0 r
s
1 .775 .183 r
.50134 .98816 m .5025 .95001 L .5246 .95645 L p F P
0 0 0 r
s
1 .705 .169 r
.52406 .92475 m .5246 .95645 L .5025 .95001 L p F P
0 0 0 r
s
1 .766 .179 r
.45409 .98491 m .45864 .94693 L .4805 .94672 L p F P
0 0 0 r
s
1 .766 .179 r
.4805 .94672 m .47762 .98702 L .45409 .98491 L p F P
0 0 0 r
s
.533 .325 .086 r
.50712 .80404 m .50827 .77066 L .5219 .80468 L p F P
0 0 0 r
s
.533 .325 .086 r
.5219 .80468 m .52244 .83325 L .50712 .80404 L p F P
0 0 0 r
s
1 .775 .183 r
.5246 .95645 m .52514 .98834 L .50134 .98816 L p F P
0 0 0 r
s
1 .849 .202 r
.52514 .98834 m .5246 .95645 L .54674 .96513 L p F P
0 0 0 r
s
1 .849 .202 r
.54674 .96513 m .5489 .98754 L .52514 .98834 L p F P
0 0 0 r
s
1 1 .227 r
.48578 .73722 m .49027 .70779 L .50042 .69419 L p F P
0 0 0 r
s
1 1 .226 r
.50324 .66559 m .50042 .69419 L .49027 .70779 L p F P
0 0 0 r
s
.682 .414 .108 r
.50042 .69419 m .50324 .66559 L .5117 .68183 L p F P
0 0 0 r
s
.682 .414 .108 r
.5117 .68183 m .51056 .70936 L .50042 .69419 L p F P
0 0 0 r
s
1 .966 .23 r
.5489 .98754 m .54674 .96513 L .56885 .97464 L p F P
0 0 0 r
s
1 .966 .23 r
.56885 .97464 m .57251 .98578 L .5489 .98754 L p F P
0 0 0 r
s
.364 .224 .062 r
.50827 .77066 m .50941 .73904 L .52136 .7774 L p F P
0 0 0 r
s
.364 .224 .062 r
.52136 .7774 m .5219 .80468 L .50827 .77066 L p F P
0 0 0 r
s
1 .992 .22 r
.44926 .88816 m .4554 .858 L .47226 .83645 L p F P
0 0 0 r
s
1 .992 .22 r
.47226 .83645 m .46773 .87239 L .44926 .88816 L p F P
0 0 0 r
s
1 1 .223 r
.47677 .80177 m .47226 .83645 L .4554 .858 L p F P
0 0 0 r
s
1 .928 .21 r
.44313 .91901 m .44926 .88816 L .46773 .87239 L p F P
0 0 0 r
s
1 .928 .21 r
.46773 .87239 m .46319 .90932 L .44313 .91901 L p F P
0 0 0 r
s
1 .86 .197 r
.437 .95032 m .44313 .91901 L .46319 .90932 L p F P
0 0 0 r
s
1 .86 .197 r
.46319 .90932 m .45864 .94693 L .437 .95032 L p F P
0 0 0 r
s
1 1 .223 r
.4554 .858 m .46154 .82875 L .47677 .80177 L p F P
0 0 0 r
s
1 .977 .208 r
.48128 .76862 m .47677 .80177 L .46154 .82875 L p F P
0 0 0 r
s
1 .688 .17 r
.5246 .95645 m .52406 .92475 L .54457 .94272 L p F P
0 0 0 r
s
1 .688 .17 r
.54457 .94272 m .54674 .96513 L .5246 .95645 L p F P
0 0 0 r
s
.515 .942 .734 r
.75374 .19612 m .787 .23353 L .78906 .26531 L p F P
0 0 0 r
s
1 .798 .185 r
.43087 .98184 m .437 .95032 L .45864 .94693 L p F P
0 0 0 r
s
1 .798 .185 r
.45864 .94693 m .45409 .98491 L .43087 .98184 L p F P
0 0 0 r
s
.507 .358 .083 r
.57251 .98578 m .56885 .97464 L .5908 .98331 L p F P
0 0 0 r
s
.351 .171 .039 r
.5908 .98331 m .58566 .98344 L .58581 .98356 L p F P
0 0 0 r
s
.507 .358 .083 r
.5957 .98307 m .57251 .98578 L p .5908 .98331 L F P
0 0 0 r
s
.351 .171 .039 r
.58581 .98356 m .60595 .99944 L p .5908 .98331 L F P
0 0 0 r
s
.507 .358 .083 r
.5908 .98331 m .59586 .98305 L .5957 .98307 L p F P
0 0 0 r
s
1 .977 .208 r
.46154 .82875 m .46768 .80063 L .48128 .76862 L p F P
0 0 0 r
s
1 .807 .17 r
.48578 .73722 m .48128 .76862 L .46768 .80063 L p F P
0 0 0 r
s
.195 .123 .038 r
.50941 .73904 m .51056 .70936 L .52082 .75159 L p F P
0 0 0 r
s
.195 .123 .038 r
.52082 .75159 m .52136 .7774 L .50941 .73904 L p F P
0 0 0 r
s
1 1 .226 r
.49027 .70779 m .49477 .6805 L .50324 .66559 L p F P
0 0 0 r
s
1 .956 .203 r
.50607 .63949 m .50324 .66559 L .49477 .6805 L p F P
0 0 0 r
s
.539 .329 .087 r
.50324 .66559 m .50607 .63949 L .51285 .65659 L p F P
0 0 0 r
s
.539 .329 .087 r
.51285 .65659 m .5117 .68183 L .50324 .66559 L p F P
0 0 0 r
s
.806 .499 .129 r
.52406 .92475 m .52352 .8935 L .54239 .92046 L p F P
0 0 0 r
s
.806 .499 .129 r
.54239 .92046 m .54457 .94272 L .52406 .92475 L p F P
0 0 0 r
s
.035 .07 .083 r
.82814 .51275 m .82165 .55331 L .82397 .58756 L p F P
0 0 0 r
s
.035 .07 .083 r
.82165 .55331 m .82814 .51275 L .82577 .47881 L p F P
0 0 0 r
s
.386 .722 .553 r
.79115 .29757 m .81177 .33811 L .81401 .37072 L p F P
0 0 0 r
s
.386 .722 .553 r
.81177 .33811 m .79115 .29757 L .78906 .26531 L p F P
0 0 0 r
s
.592 1 .861 r
.24216 .82872 m .28221 .85843 L .28399 .82212 L p F P
0 0 0 r
s
.592 1 .861 r
.28399 .82212 m .24427 .79218 L .24216 .82872 L p F P
0 0 0 r
s
.255 .486 .348 r
.81629 .40383 m .82343 .44537 L .82577 .47881 L p F P
0 0 0 r
s
.255 .486 .348 r
.82343 .44537 m .81629 .40383 L .81401 .37072 L p F P
0 0 0 r
s
1 .807 .17 r
.46768 .80063 m .47383 .77381 L .48578 .73722 L p F P
0 0 0 r
s
.966 .587 .124 r
.49027 .70779 m .48578 .73722 L .47383 .77381 L p F P
0 0 0 r
s
.174 .075 .017 r
.59586 .98305 m .5908 .98331 L .61245 .98945 L p F P
0 0 0 r
s
.174 .075 .017 r
.61245 .98945 m .61882 .97938 L .59586 .98305 L p F P
0 0 0 r
s
.059 .119 .141 r
.82633 .62234 m .8067 .66016 L .80891 .69524 L p F P
0 0 0 r
s
.059 .119 .141 r
.8067 .66016 m .82633 .62234 L .82397 .58756 L p F P
0 0 0 r
s
1 .854 .198 r
.437 .95032 m .43087 .98184 L .40807 .97783 L p F P
0 0 0 r
s
.15 .092 .03 r
.51056 .70936 m .5117 .68183 L .52027 .7274 L p F P
0 0 0 r
s
.15 .092 .03 r
.52027 .7274 m .52082 .75159 L .51056 .70936 L p F P
0 0 0 r
s
.538 .334 .09 r
.52352 .8935 m .52298 .86292 L .5402 .89848 L p F P
0 0 0 r
s
.538 .334 .09 r
.5402 .89848 m .54239 .92046 L .52352 .8935 L p F P
0 0 0 r
s
.912 .588 .151 r
.54674 .96513 m .54457 .94272 L .56514 .96339 L p F P
0 0 0 r
s
.912 .588 .151 r
.56514 .96339 m .56885 .97464 L .54674 .96513 L p F P
0 0 0 r
s
.771 .467 .097 r
.49477 .6805 m .49027 .70779 L .47999 .74848 L p F P
0 0 0 r
s
.966 .587 .124 r
.47383 .77381 m .47999 .74848 L .48829 .71561 L p F P
0 0 0 r
s
.966 .587 .124 r
.48837 .7154 m .47383 .77381 L .48829 .71561 L F
.771 .467 .097 r
.47999 .74848 m .48616 .72477 L .49477 .6805 L p F P
0 0 0 r
s
.616 .375 .075 r
.49927 .65552 m .49477 .6805 L .48759 .71743 L p F P
0 0 0 r
s
.616 .375 .075 r
.48759 .71743 m .48616 .72477 L p .48752 .71762 L F P
0 0 0 r
s
.616 .375 .075 r
.49927 .65552 m .48759 .71743 L .48752 .71762 L F
.966 .587 .124 r
.48829 .71561 m .49027 .70779 L p .48837 .7154 L F P
0 0 0 r
s
1 .854 .198 r
.40807 .97783 m .41563 .95599 L .437 .95032 L p F P
0 0 0 r
s
1 .967 .219 r
.44313 .91901 m .437 .95032 L .41563 .95599 L p F P
0 0 0 r
s
.135 .257 .253 r
.81115 .73086 m .77938 .76451 L .78138 .80043 L p F P
0 0 0 r
s
.135 .257 .253 r
.77938 .76451 m .81115 .73086 L .80891 .69524 L p F P
0 0 0 r
s
1 .956 .203 r
.49477 .6805 m .49927 .65552 L .50607 .63949 L p F P
0 0 0 r
s
1 .725 .152 r
.50891 .61601 m .50607 .63949 L .49927 .65552 L p F P
0 0 0 r
s
.357 .22 .061 r
.50607 .63949 m .50891 .61601 L .51401 .63379 L p F P
0 0 0 r
s
.357 .22 .061 r
.51401 .63379 m .51285 .65659 L .50607 .63949 L p F P
0 0 0 r
s
.269 .13 .032 r
.61882 .97938 m .61245 .98945 L .63364 .99156 L p F P
0 0 0 r
s
.29 .541 .481 r
.63495 .97787 m .69277 .96177 L .69144 .9246 L p F P
0 0 0 r
s
.269 .13 .032 r
.63364 .99156 m .64129 .97476 L .61882 .97938 L p F P
0 0 0 r
s
.28 .18 .052 r
.52298 .86292 m .52244 .83325 L .538 .8769 L p F P
0 0 0 r
s
.28 .18 .052 r
.538 .8769 m .5402 .89848 L .52298 .86292 L p F P
0 0 0 r
s
.241 .455 .413 r
.74261 .90209 m .69144 .9246 L .69277 .96177 L p F P
0 0 0 r
s
.241 .455 .413 r
.69144 .9246 m .74261 .90209 L .7409 .86528 L p F P
0 0 0 r
s
.119 .219 .218 r
.29014 .21914 m .25343 .25522 L .25544 .22341 L p F P
0 0 0 r
s
.119 .219 .218 r
.25544 .22341 m .29189 .18722 L .29014 .21914 L p F P
0 0 0 r
s
1 .967 .219 r
.41563 .95599 m .42322 .93418 L .44313 .91901 L p F P
0 0 0 r
s
1 1 .233 r
.44926 .88816 m .44313 .91901 L .42322 .93418 L p F P
0 0 0 r
s
1 .943 .22 r
.41563 .95599 m .40807 .97783 L .38581 .97288 L p F P
0 0 0 r
s
.117 .072 .023 r
.5117 .68183 m .51285 .65659 L .51973 .70496 L p F P
0 0 0 r
s
.117 .072 .023 r
.51973 .70496 m .52027 .7274 L .5117 .68183 L p F P
0 0 0 r
s
1 1 .233 r
.42322 .93418 m .43085 .91253 L .44926 .88816 L p F P
0 0 0 r
s
1 1 .221 r
.4554 .858 m .44926 .88816 L .43085 .91253 L p F P
0 0 0 r
s
.168 .103 .034 r
.52244 .83325 m .5219 .80468 L .53578 .85585 L p F P
0 0 0 r
s
.168 .103 .034 r
.53578 .85585 m .538 .8769 L .52244 .83325 L p F P
0 0 0 r
s
.047 .094 .112 r
.24933 .32033 m .22508 .36003 L .2273 .32738 L p F P
0 0 0 r
s
.047 .094 .112 r
.2273 .32738 m .2514 .28752 L .24933 .32033 L p F P
0 0 0 r
s
.295 .575 .424 r
.20499 .53658 m .20806 .57725 L .21041 .54294 L p F P
0 0 0 r
s
.295 .575 .424 r
.21041 .54294 m .2074 .50206 L .20499 .53658 L p F P
0 0 0 r
s
.356 .241 .066 r
.54457 .94272 m .54239 .92046 L .5614 .95202 L p F P
0 0 0 r
s
.356 .241 .066 r
.5614 .95202 m .56514 .96339 L .54457 .94272 L p F P
0 0 0 r
s
.442 .842 .646 r
.20324 .64747 m .21978 .68579 L .22204 .65065 L p F P
0 0 0 r
s
.442 .842 .646 r
.22204 .65065 m .20567 .61209 L .20324 .64747 L p F P
0 0 0 r
s
.268 .132 .033 r
.64129 .97476 m .63364 .99156 L .65419 .98867 L p F P
0 0 0 r
s
.268 .132 .033 r
.65419 .98867 m .66315 .96922 L .64129 .97476 L p F P
0 0 0 r
s
.017 .035 .042 r
.22053 .42686 m .20978 .46806 L .21212 .43457 L p F P
0 0 0 r
s
.017 .035 .042 r
.21212 .43457 m .22282 .39319 L .22053 .42686 L p F P
0 0 0 r
s
.188 .081 .018 r
.58566 .98344 m .5908 .98331 L .56885 .97464 L p F P
0 0 0 r
s
.188 .081 .018 r
.56885 .97464 m .56514 .96339 L .58566 .98344 L p F P
0 0 0 r
s
1 1 .221 r
.43085 .91253 m .43851 .89118 L .4554 .858 L p F P
0 0 0 r
s
1 .802 .169 r
.46154 .82875 m .4554 .858 L .43851 .89118 L p F P
0 0 0 r
s
.565 1 .833 r
.27856 .93273 m .32817 .95656 L .32961 .91934 L p F P
0 0 0 r
s
.565 1 .833 r
.32961 .91934 m .2804 .89529 L .27856 .93273 L p F P
0 0 0 r
s
.193 .367 .342 r
.78341 .83691 m .7409 .86528 L .74261 .90209 L p F P
0 0 0 r
s
.193 .367 .342 r
.7409 .86528 m .78341 .83691 L .78138 .80043 L p F P
0 0 0 r
s
1 .725 .152 r
.49927 .65552 m .50379 .63297 L .50891 .61601 L p F P
0 0 0 r
s
.831 .505 .106 r
.51175 .59528 m .50891 .61601 L .50379 .63297 L p F P
0 0 0 r
s
.174 .107 .035 r
.50891 .61601 m .51175 .59528 L .51516 .61351 L p F P
0 0 0 r
s
.174 .107 .035 r
.51516 .61351 m .51401 .63379 L .50891 .61601 L p F P
0 0 0 r
s
1 .966 .23 r
.39464 .96254 m .38581 .97288 L .3642 .96702 L p F P
0 0 0 r
s
1 .943 .22 r
.38581 .97288 m .39464 .96254 L .41563 .95599 L p F P
0 0 0 r
s
.571 1 .825 r
.21515 .75771 m .24427 .79218 L .24635 .7562 L p F P
0 0 0 r
s
.571 1 .825 r
.24635 .7562 m .21748 .72147 L .21515 .75771 L p F P
0 0 0 r
s
1 1 .25 r
.42322 .93418 m .41563 .95599 L .39464 .96254 L p F P
0 0 0 r
s
.084 .051 .017 r
.51285 .65659 m .51401 .63379 L .51918 .68437 L p F P
0 0 0 r
s
.084 .051 .017 r
.51918 .68437 m .51973 .70496 L .51285 .65659 L p F P
0 0 0 r
s
.128 .078 .025 r
.5219 .80468 m .52136 .7774 L .53355 .83543 L p F P
0 0 0 r
s
.128 .078 .025 r
.53355 .83543 m .53578 .85585 L .5219 .80468 L p F P
0 0 0 r
s
.891 .545 .115 r
.46768 .80063 m .46154 .82875 L .4462 .87025 L p F P
0 0 0 r
s
1 .802 .169 r
.43851 .89118 m .4462 .87025 L .46001 .8329 L p F P
0 0 0 r
s
1 .802 .169 r
.4603 .83213 m .43851 .89118 L .46001 .8329 L F
.891 .545 .115 r
.4462 .87025 m .45393 .84987 L .46768 .80063 L p F P
0 0 0 r
s
.711 .435 .089 r
.47383 .77381 m .46768 .80063 L .45466 .84726 L p F P
0 0 0 r
s
.711 .435 .089 r
.45466 .84726 m .45393 .84987 L p .45451 .84767 L F P
0 0 0 r
s
.711 .435 .089 r
.47383 .77381 m .45466 .84726 L .45451 .84767 L F
1 .802 .169 r
.46001 .8329 m .46154 .82875 L p .4603 .83213 L F P
0 0 0 r
s
.616 .375 .075 r
.48616 .72477 m .49236 .70282 L .49927 .65552 L p F P
0 0 0 r
s
.50379 .63297 m .49927 .65552 L .49236 .70282 L p F P
s
.515 .942 .734 r
.75556 .22802 m .78906 .26531 L .79115 .29757 L p F P
0 0 0 r
s
.515 .942 .734 r
.78906 .26531 m .75556 .22802 L .75374 .19612 L p F P
0 0 0 r
s
.2 .094 .024 r
.66315 .96922 m .65419 .98867 L .67392 .98042 L p F P
0 0 0 r
s
.2 .094 .024 r
.67392 .98042 m .68428 .96278 L .66315 .96922 L p F P
0 0 0 r
s
.177 .109 .035 r
.54239 .92046 m .5402 .89848 L .55761 .94053 L p F P
0 0 0 r
s
.177 .109 .035 r
.55761 .94053 m .5614 .95202 L .54239 .92046 L p F P
0 0 0 r
s
.089 .055 .018 r
.52136 .7774 m .52082 .75159 L .53131 .81574 L p F P
0 0 0 r
s
.089 .055 .018 r
.53131 .81574 m .53355 .83543 L .52136 .7774 L p F P
0 0 0 r
s
.351 .171 .039 r
.60595 .99944 m .61245 .98945 L .5908 .98331 L p F P
0 0 0 r
s
.035 .07 .083 r
.83055 .54722 m .82397 .58756 L .82633 .62234 L p F P
0 0 0 r
s
.035 .07 .083 r
.82397 .58756 m .83055 .54722 L .82814 .51275 L p F P
0 0 0 r
s
.386 .722 .553 r
.79326 .33034 m .81401 .37072 L .81629 .40383 L p F P
0 0 0 r
s
.386 .722 .553 r
.81401 .37072 m .79326 .33034 L .79115 .29757 L p F P
0 0 0 r
s
1 .966 .23 r
.3642 .96702 m .37418 .96832 L .39464 .96254 L p F P
0 0 0 r
s
.434 .31 .077 r
.37418 .96832 m .3642 .96702 L .34335 .96026 L p F P
0 0 0 r
s
.592 1 .861 r
.24001 .86584 m .2804 .89529 L .28221 .85843 L p F P
0 0 0 r
s
.592 1 .861 r
.28221 .85843 m .24216 .82872 L .24001 .86584 L p F P
0 0 0 r
s
.255 .486 .348 r
.81861 .43745 m .82577 .47881 L .82814 .51275 L p F P
0 0 0 r
s
.255 .486 .348 r
.82577 .47881 m .81861 .43745 L .81629 .40383 L p F P
0 0 0 r
s
1 1 .25 r
.39464 .96254 m .40356 .95211 L .42322 .93418 L p F P
0 0 0 r
s
1 1 .223 r
.43085 .91253 m .42322 .93418 L .40356 .95211 L p F P
0 0 0 r
s
.059 .119 .141 r
.82872 .65765 m .80891 .69524 L .81115 .73086 L p F P
0 0 0 r
s
.059 .119 .141 r
.80891 .69524 m .82872 .65765 L .82633 .62234 L p F P
0 0 0 r
s
.831 .505 .106 r
.50379 .63297 m .50833 .61296 L .51175 .59528 L p F P
0 0 0 r
s
.635 .386 .078 r
.51462 .57736 m .51175 .59528 L .50833 .61296 L p F P
0 0 0 r
s
.128 .078 .026 r
.51175 .59528 m .51462 .57736 L .51633 .59585 L p F P
0 0 0 r
s
.128 .078 .026 r
.51633 .59585 m .51516 .61351 L .51175 .59528 L p F P
0 0 0 r
s
.054 .033 .011 r
.51401 .63379 m .51516 .61351 L .51863 .66572 L p F P
0 0 0 r
s
.054 .033 .011 r
.51863 .66572 m .51918 .68437 L .51401 .63379 L p F P
0 0 0 r
s
.49236 .70282 m .49858 .68275 L .50379 .63297 L p F P
s
.03 .018 .006 r
.50833 .61296 m .50379 .63297 L .49858 .68275 L p F P
0 0 0 r
s
.711 .435 .089 r
.45393 .84987 m .4617 .83013 L .47383 .77381 L p F P
0 0 0 r
s
.47999 .74848 m .47383 .77381 L .4617 .83013 L p F P
s
.378 .186 .039 r
.58043 .98328 m .58566 .98344 L .56514 .96339 L p F P
0 0 0 r
s
.378 .186 .039 r
.56514 .96339 m .5614 .95202 L .58043 .98328 L p F P
0 0 0 r
s
.135 .257 .253 r
.81343 .76703 m .78138 .80043 L .78341 .83691 L p F P
0 0 0 r
s
.135 .257 .253 r
.78138 .80043 m .81343 .76703 L .81115 .73086 L p F P
0 0 0 r
s
.064 .027 .006 r
.68428 .96278 m .67392 .98042 L .69269 .96716 L p F P
0 0 0 r
s
.241 .455 .413 r
.69277 .96177 m .74435 .93946 L .74261 .90209 L p F P
0 0 0 r
s
.064 .027 .006 r
.69269 .96716 m .70458 .95547 L .68428 .96278 L p F P
0 0 0 r
s
1 .911 .203 r
.40356 .95211 m .39464 .96254 L .37418 .96832 L p F P
0 0 0 r
s
.056 .034 .011 r
.52082 .75159 m .52027 .7274 L .52906 .79688 L p F P
0 0 0 r
s
.056 .034 .011 r
.52906 .79688 m .53131 .81574 L .52082 .75159 L p F P
0 0 0 r
s
.119 .219 .218 r
.28837 .25156 m .2514 .28752 L .25343 .25522 L p F P
0 0 0 r
s
.119 .219 .218 r
.25343 .25522 m .29014 .21914 L .28837 .25156 L p F P
0 0 0 r
s
.11 .067 .022 r
.5402 .89848 m .538 .8769 L .55379 .92892 L p F P
0 0 0 r
s
.11 .067 .022 r
.55379 .92892 m .55761 .94053 L .5402 .89848 L p F P
0 0 0 r
s
1 1 .223 r
.40356 .95211 m .41255 .94158 L .43085 .91253 L p F P
0 0 0 r
s
1 .633 .135 r
.43851 .89118 m .43085 .91253 L .41255 .94158 L p F P
0 0 0 r
s
.328 .153 .033 r
.3544 .97163 m .34335 .96026 L .32338 .95264 L p F P
0 0 0 r
s
.434 .31 .077 r
.34335 .96026 m .3544 .97163 L .37418 .96832 L p F P
0 0 0 r
s
.385 .197 .047 r
.61245 .98945 m .60595 .99944 L .62582 1.00837 L p F P
0 0 0 r
s
.385 .197 .047 r
.62582 1.00837 m .63364 .99156 L .61245 .98945 L p F P
0 0 0 r
s
.4617 .83013 m .46951 .81115 L .47999 .74848 L p F P
s
.011 .007 .002 r
.48616 .72477 m .47999 .74848 L .46951 .81115 L p F P
0 0 0 r
s
.047 .094 .112 r
.24723 .35364 m .22282 .39319 L .22508 .36003 L p F P
0 0 0 r
s
.047 .094 .112 r
.22508 .36003 m .24933 .32033 L .24723 .35364 L p F P
0 0 0 r
s
.295 .575 .424 r
.20254 .57166 m .20567 .61209 L .20806 .57725 L p F P
0 0 0 r
s
.295 .575 .424 r
.20806 .57725 m .20499 .53658 L .20254 .57166 L p F P
0 0 0 r
s
.533 .965 .764 r
.70875 .16412 m .75374 .19612 L .75556 .22802 L p F P
0 0 0 r
s
.442 .842 .646 r
.20077 .6834 m .21748 .72147 L .21978 .68579 L p F P
0 0 0 r
s
.442 .842 .646 r
.21978 .68579 m .20324 .64747 L .20077 .6834 L p F P
0 0 0 r
s
.017 .035 .042 r
.2182 .46106 m .2074 .50206 L .20978 .46806 L p F P
0 0 0 r
s
.017 .035 .042 r
.20978 .46806 m .22053 .42686 L .2182 .46106 L p F P
0 0 0 r
s
.027 .017 .005 r
.51516 .61351 m .51633 .59585 L .51807 .64909 L p F P
0 0 0 r
s
.027 .017 .005 r
.51807 .64909 m .51863 .66572 L .51516 .61351 L p F P
0 0 0 r
s
.193 .367 .342 r
.78548 .87395 m .74261 .90209 L .74435 .93946 L p F P
0 0 0 r
s
.193 .367 .342 r
.74261 .90209 m .78548 .87395 L .78341 .83691 L p F P
0 0 0 r
s
.03 .018 .006 r
.49858 .68275 m .50484 .66463 L .50833 .61296 L p F P
0 0 0 r
s
.056 .034 .011 r
.5129 .59557 m .50833 .61296 L .50484 .66463 L p F P
0 0 0 r
s
.635 .386 .078 r
.50833 .61296 m .5129 .59557 L .51462 .57736 L p F P
0 0 0 r
s
.076 .046 .015 r
.51462 .57736 m .51751 .56232 L .51751 .58086 L p F P
0 0 0 r
s
.076 .046 .015 r
.51751 .58086 m .51633 .59585 L .51462 .57736 L p F P
0 0 0 r
s
.011 .007 .002 r
.51751 .56232 m .51462 .57736 L .5129 .59557 L p F P
0 0 0 r
s
.489 .283 .055 r
.52678 .77892 m .52906 .79688 L .52069 .73069 L p F P
0 0 0 r
s
.489 .283 .055 r
.52678 .77892 m .52069 .73069 L .5207 .73076 L F
.52678 .77892 m .52057 .72973 L .52069 .73067 L F
.52069 .73069 m .52057 .72973 L p .5207 .73076 L F P
0 0 0 r
s
.489 .283 .055 r
.52057 .72973 m .52027 .7274 L p .52069 .73067 L F P
0 0 0 r
s
.489 .283 .055 r
.52027 .7274 m .51973 .70496 L .52678 .77892 L p F P
0 0 0 r
s
.533 .31 .06 r
.5245 .76192 m .52678 .77892 L .51973 .70496 L p F P
0 0 0 r
s
.533 .31 .06 r
.51973 .70496 m .51918 .68437 L .52433 .75951 L p F P
0 0 0 r
s
.533 .31 .06 r
.52422 .75865 m .51973 .70496 L .52433 .75951 L F
.52433 .75951 m .5245 .76192 L p .52422 .75865 L F P
0 0 0 r
s
.578 .337 .066 r
.52219 .74596 m .5245 .76192 L .51918 .68437 L p F P
0 0 0 r
s
.578 .337 .066 r
.51918 .68437 m .51863 .66572 L .52196 .74073 L p F P
0 0 0 r
s
.578 .337 .066 r
.52196 .74073 m .52219 .74596 L p .52192 .74043 L F P
0 0 0 r
s
.578 .337 .066 r
.52192 .74043 m .51918 .68437 L .52196 .74073 L F
.571 1 .825 r
.21277 .79451 m .24216 .82872 L .24427 .79218 L p F P
0 0 0 r
s
.571 1 .825 r
.24427 .79218 m .21515 .75771 L .21277 .79451 L p F P
0 0 0 r
s
.777 .513 .117 r
.71038 .94992 m .72393 .94731 L .70458 .95547 L p F P
0 0 0 r
s
.777 .513 .117 r
.70458 .95547 m .69269 .96716 L .71038 .94992 L p F P
0 0 0 r
s
.456 .254 .05 r
.54993 .91719 m .55379 .92892 L .538 .8769 L p F P
0 0 0 r
s
.456 .254 .05 r
.538 .8769 m .53578 .85585 L .54993 .91719 L p F P
0 0 0 r
s
1 .633 .135 r
.41255 .94158 m .42164 .93094 L .43851 .89118 L p F P
0 0 0 r
s
.726 .451 .094 r
.4462 .87025 m .43851 .89118 L .42164 .93094 L p F P
0 0 0 r
s
1 .707 .163 r
.59383 .63034 m .57478 .61391 L .57703 .59355 L p F P
0 0 0 r
s
1 .707 .163 r
.57703 .59355 m .59688 .60982 L .59383 .63034 L p F P
0 0 0 r
s
1 .705 .161 r
.55722 .58017 m .57703 .59355 L .57478 .61391 L p F P
0 0 0 r
s
.862 .455 .101 r
.59688 .60982 m .57703 .59355 L .57939 .60819 L p F P
0 0 0 r
s
1 .705 .161 r
.57478 .61391 m .55573 .60014 L .55722 .58017 L p F P
0 0 0 r
s
.939 .503 .113 r
.57703 .59355 m .55722 .58017 L .55878 .59631 L p F P
0 0 0 r
s
.939 .503 .113 r
.55878 .59631 m .57939 .60819 L .57703 .59355 L p F P
0 0 0 r
s
1 .698 .163 r
.61291 .64934 m .59383 .63034 L .59688 .60982 L p F P
0 0 0 r
s
1 .698 .163 r
.59688 .60982 m .61679 .62886 L .61291 .64934 L p F P
0 0 0 r
s
.712 .372 .081 r
.61679 .62886 m .59688 .60982 L .60004 .62277 L p F P
0 0 0 r
s
.862 .455 .101 r
.57939 .60819 m .60004 .62277 L .59688 .60982 L p F P
0 0 0 r
s
.011 .007 .002 r
.46951 .81115 m .47737 .793 L .48616 .72477 L p F P
0 0 0 r
s
.043 .026 .009 r
.49236 .70282 m .48616 .72477 L .47737 .793 L p F P
0 0 0 r
s
.506 .259 .055 r
.3355 .97098 m .32338 .95264 L .3044 .94418 L p F P
0 0 0 r
s
.328 .153 .033 r
.32338 .95264 m .3355 .97098 L .3544 .97163 L p F P
0 0 0 r
s
1 .693 .157 r
.53739 .56974 m .55722 .58017 L .55573 .60014 L p F P
0 0 0 r
s
1 .693 .157 r
.55573 .60014 m .53665 .58911 L .53739 .56974 L p F P
0 0 0 r
s
.995 .54 .122 r
.55722 .58017 m .53739 .56974 L .53816 .58718 L p F P
0 0 0 r
s
.995 .54 .122 r
.53816 .58718 m .55878 .59631 L .55722 .58017 L p F P
0 0 0 r
s
.515 .942 .734 r
.75742 .26041 m .79115 .29757 L .79326 .33034 L p F P
0 0 0 r
s
.515 .942 .734 r
.79115 .29757 m .75742 .26041 L .75556 .22802 L p F P
0 0 0 r
s
1 .68 .16 r
.63206 .67078 m .61291 .64934 L .61679 .62886 L p F P
0 0 0 r
s
1 .68 .16 r
.61679 .62886 m .63679 .65056 L .63206 .67078 L p F P
0 0 0 r
s
.468 .241 .05 r
.63679 .65056 m .61679 .62886 L .62076 .63994 L p F P
0 0 0 r
s
.712 .372 .081 r
.60004 .62277 m .62076 .63994 L .61679 .62886 L p F P
0 0 0 r
s
1 .911 .203 r
.37418 .96832 m .38429 .9695 L .40356 .95211 L p F P
0 0 0 r
s
.805 .517 .112 r
.41255 .94158 m .40356 .95211 L .38429 .9695 L p F P
0 0 0 r
s
.302 .152 .037 r
.63364 .99156 m .62582 1.00837 L .64502 1.00816 L p F P
0 0 0 r
s
.302 .152 .037 r
.64502 1.00816 m .65419 .98867 L .63364 .99156 L p F P
0 0 0 r
s
.505 .27 .054 r
.57513 .98269 m .58043 .98328 L .5614 .95202 L p F P
0 0 0 r
s
.505 .27 .054 r
.5614 .95202 m .55761 .94053 L .57513 .98269 L p F P
0 0 0 r
s
.07 .03 .007 r
.38429 .9695 m .37418 .96832 L .3544 .97163 L p F P
0 0 0 r
s
.181 .337 .311 r
.33824 .18895 m .29014 .21914 L .29189 .18722 L p F P
0 0 0 r
s
.181 .337 .311 r
.29189 .18722 m .33964 .15693 L .33824 .18895 L p F P
0 0 0 r
s
.569 .292 .065 r
.58566 .98344 m .58043 .98328 L .59933 1.00908 L p F P
0 0 0 r
s
.569 .292 .065 r
.59933 1.00908 m .60595 .99944 L .58566 .98344 L p F P
0 0 0 r
s
.035 .07 .083 r
.83299 .58223 m .82633 .62234 L .82872 .65765 L p F P
0 0 0 r
s
.035 .07 .083 r
.82633 .62234 m .83299 .58223 L .83055 .54722 L p F P
0 0 0 r
s
.386 .722 .553 r
.79542 .36362 m .81629 .40383 L .81861 .43745 L p F P
0 0 0 r
s
.386 .722 .553 r
.81629 .40383 m .79542 .36362 L .79326 .33034 L p F P
0 0 0 r
s
.592 1 .861 r
.23783 .90353 m .27856 .93273 L .2804 .89529 L p F P
0 0 0 r
s
.592 1 .861 r
.2804 .89529 m .24001 .86584 L .23783 .90353 L p F P
0 0 0 r
s
.255 .486 .348 r
.82096 .4716 m .82814 .51275 L .83055 .54722 L p F P
0 0 0 r
s
.255 .486 .348 r
.82814 .51275 m .82096 .4716 L .81861 .43745 L p F P
0 0 0 r
s
1 .67 .151 r
.51751 .56232 m .53739 .56974 L .53665 .58911 L p F P
0 0 0 r
s
1 .67 .151 r
.53665 .58911 m .51751 .58086 L .51751 .56232 L p F P
0 0 0 r
s
1 .576 .13 r
.53739 .56974 m .51751 .56232 L .51751 .58086 L p F P
0 0 0 r
s
1 .576 .13 r
.51751 .58086 m .53816 .58718 L .53739 .56974 L p F P
0 0 0 r
s
1 .655 .156 r
.6513 .69452 m .63206 .67078 L .63679 .65056 L p F P
0 0 0 r
s
1 .655 .156 r
.63679 .65056 m .65692 .67475 L .6513 .69452 L p F P
0 0 0 r
s
.305 .143 .031 r
.65692 .67475 m .63679 .65056 L .64158 .65958 L p F P
0 0 0 r
s
.468 .241 .05 r
.62076 .63994 m .64158 .65958 L .63679 .65056 L p F P
0 0 0 r
s
.059 .119 .141 r
.83115 .69352 m .81115 .73086 L .81343 .76703 L p F P
0 0 0 r
s
.059 .119 .141 r
.81115 .73086 m .83115 .69352 L .82872 .65765 L p F P
0 0 0 r
s
1 .697 .158 r
.60903 .69946 m .5908 .68237 L .59383 .63034 L p F P
0 0 0 r
s
1 .697 .158 r
.59383 .63034 m .61291 .64934 L .60903 .69946 L p F P
0 0 0 r
s
1 .695 .157 r
.57478 .61391 m .59383 .63034 L .5908 .68237 L p F P
0 0 0 r
s
1 .696 .159 r
.62728 .71841 m .60903 .69946 L .61291 .64934 L p F P
0 0 0 r
s
1 .696 .159 r
.61291 .64934 m .63206 .67078 L .62728 .71841 L p F P
0 0 0 r
s
.726 .451 .094 r
.42164 .93094 m .43081 .92021 L .4462 .87025 L p F P
0 0 0 r
s
.45393 .84987 m .4462 .87025 L .43081 .92021 L p F P
s
1 .695 .157 r
.5908 .68237 m .57255 .66726 L .57478 .61391 L p F P
0 0 0 r
s
1 .689 .155 r
.55573 .60014 m .57478 .61391 L .57255 .66726 L p F P
0 0 0 r
s
.515 .303 .058 r
.51751 .63452 m .51807 .64909 L .51633 .59585 L p F P
0 0 0 r
s
.515 .303 .058 r
.51633 .59585 m .51751 .58086 L .51751 .63452 L p F P
0 0 0 r
s
1 .692 .159 r
.64556 .73911 m .62728 .71841 L .63206 .67078 L p F P
0 0 0 r
s
1 .692 .159 r
.63206 .67078 m .6513 .69452 L .64556 .73911 L p F P
0 0 0 r
s
1 .966 .23 r
.72393 .94731 m .71038 .94992 L .72693 .93019 L p F P
0 0 0 r
s
1 .966 .23 r
.72693 .93019 m .74222 .93833 L .72393 .94731 L p F P
0 0 0 r
s
.522 .295 .058 r
.54603 .90534 m .54993 .91719 L .53578 .85585 L p F P
0 0 0 r
s
.522 .295 .058 r
.53578 .85585 m .53355 .83543 L .54603 .90534 L p F P
0 0 0 r
s
.056 .034 .011 r
.50484 .66463 m .51115 .64854 L .5129 .59557 L p F P
0 0 0 r
s
.076 .046 .015 r
.51751 .58086 m .5129 .59557 L .51115 .64854 L p F P
0 0 0 r
s
.011 .007 .002 r
.5129 .59557 m .51751 .58086 L .51751 .56232 L p F P
0 0 0 r
s
.88 .502 .12 r
.47411 .57337 m .49581 .56633 L .49611 .5858 L p F P
0 0 0 r
s
.962 .552 .131 r
.45236 .58339 m .47411 .57337 L .47473 .59356 L p F P
0 0 0 r
s
.88 .502 .12 r
.49611 .5858 m .47473 .59356 L .47411 .57337 L p F P
0 0 0 r
s
.659 .362 .086 r
.4734 .58936 m .49546 .5837 L .49581 .56633 L p F P
0 0 0 r
s
.659 .362 .086 r
.49581 .56633 m .47411 .57337 L .4734 .58936 L p F P
0 0 0 r
s
.811 .459 .11 r
.49581 .56633 m .51751 .56232 L .51751 .58086 L p F P
0 0 0 r
s
.811 .459 .11 r
.51751 .58086 m .49611 .5858 L .49581 .56633 L p F P
0 0 0 r
s
.738 .41 .097 r
.51751 .56232 m .49581 .56633 L .49546 .5837 L p F P
0 0 0 r
s
.043 .026 .009 r
.47737 .793 m .48527 .77578 L .49236 .70282 L p F P
0 0 0 r
s
.066 .04 .013 r
.49858 .68275 m .49236 .70282 L .48527 .77578 L p F P
0 0 0 r
s
1 .61 .144 r
.43053 .59633 m .45236 .58339 L .45333 .60408 L p F P
0 0 0 r
s
.962 .552 .131 r
.47473 .59356 m .45333 .60408 L .45236 .58339 L p F P
0 0 0 r
s
.56 .306 .073 r
.45128 .59781 m .4734 .58936 L .47411 .57337 L p F P
0 0 0 r
s
.56 .306 .073 r
.47411 .57337 m .45236 .58339 L .45128 .59781 L p F P
0 0 0 r
s
.135 .257 .253 r
.81574 .80376 m .78341 .83691 L .78548 .87395 L p F P
0 0 0 r
s
.135 .257 .253 r
.78341 .83691 m .81574 .80376 L .81343 .76703 L p F P
0 0 0 r
s
.156 .072 .018 r
.65419 .98867 m .64502 1.00816 L .66334 .99806 L p F P
0 0 0 r
s
.156 .072 .018 r
.66334 .99806 m .67392 .98042 L .65419 .98867 L p F P
0 0 0 r
s
1 .626 .151 r
.67065 .72037 m .6513 .69452 L .65692 .67475 L p F P
0 0 0 r
s
1 .626 .151 r
.65692 .67475 m .67719 .70126 L .67065 .72037 L p F P
0 0 0 r
s
.265 .174 .05 r
.67719 .70126 m .65692 .67475 L .66252 .68155 L p F P
0 0 0 r
s
.305 .143 .031 r
.64158 .65958 m .66252 .68155 L .65692 .67475 L p F P
0 0 0 r
s
.488 .284 .072 r
.53406 .57312 m .51751 .58086 L .51751 .56232 L p F P
0 0 0 r
s
.488 .284 .072 r
.51751 .56232 m .53278 .55388 L .53406 .57312 L p F P
0 0 0 r
s
.331 .186 .049 r
.53278 .55388 m .51751 .56232 L .51751 .58086 L p F P
0 0 0 r
s
.738 .41 .097 r
.49546 .5837 m .51751 .58086 L .51751 .56232 L p F P
0 0 0 r
s
1 .795 .171 r
.50694 .55174 m .51751 .56232 L .51751 .58086 L p F P
0 0 0 r
s
1 .795 .171 r
.51751 .58086 m .50539 .57077 L .50694 .55174 L p F P
0 0 0 r
s
1 .633 .135 r
.50846 .56974 m .51751 .58086 L .51751 .56232 L p F P
0 0 0 r
s
1 .633 .135 r
.51751 .56232 m .50694 .55174 L .50846 .56974 L p F P
0 0 0 r
s
1 .689 .155 r
.57255 .66726 m .55427 .65421 L .55573 .60014 L p F P
0 0 0 r
s
1 .681 .153 r
.53665 .58911 m .55573 .60014 L .55427 .65421 L p F P
0 0 0 r
s
1 .675 .158 r
.40857 .6121 m .43053 .59633 L .43187 .61732 L p F P
0 0 0 r
s
1 .61 .144 r
.45333 .60408 m .43187 .61732 L .43053 .59633 L p F P
0 0 0 r
s
.437 .237 .057 r
.42907 .60898 m .45128 .59781 L .45236 .58339 L p F P
0 0 0 r
s
.437 .237 .057 r
.45236 .58339 m .43053 .59633 L .42907 .60898 L p F P
0 0 0 r
s
1 .683 .158 r
.66389 .7614 m .64556 .73911 L .6513 .69452 L p F P
0 0 0 r
s
1 .683 .158 r
.6513 .69452 m .67065 .72037 L .66389 .7614 L p F P
0 0 0 r
s
.119 .219 .218 r
.28656 .2845 m .24933 .32033 L .2514 .28752 L p F P
0 0 0 r
s
.119 .219 .218 r
.2514 .28752 m .28837 .25156 L .28656 .2845 L p F P
0 0 0 r
s
.544 .281 .059 r
.31765 .96539 m .3044 .94418 L .28651 .93492 L p F P
0 0 0 r
s
.506 .259 .055 r
.3044 .94418 m .31765 .96539 L .3355 .97098 L p F P
0 0 0 r
s
.995 .544 .123 r
.60004 .62277 m .57939 .60819 L .58186 .65598 L p F P
0 0 0 r
s
1 .555 .126 r
.57939 .60819 m .55878 .59631 L .56042 .64665 L p F P
0 0 0 r
s
1 .555 .126 r
.56042 .64665 m .58186 .65598 L .57939 .60819 L p F P
0 0 0 r
s
.979 .532 .12 r
.62076 .63994 m .60004 .62277 L .60332 .66741 L p F P
0 0 0 r
s
.995 .544 .123 r
.58186 .65598 m .60332 .66741 L .60004 .62277 L p F P
0 0 0 r
s
1 .744 .173 r
.38644 .63056 m .40857 .6121 L .41032 .63316 L p F P
0 0 0 r
s
1 .675 .158 r
.43187 .61732 m .41032 .63316 L .40857 .6121 L p F P
0 0 0 r
s
.291 .149 .038 r
.40671 .62278 m .42907 .60898 L .43053 .59633 L p F P
0 0 0 r
s
.291 .149 .038 r
.43053 .59633 m .40857 .6121 L .40671 .62278 L p F P
0 0 0 r
s
1 .681 .153 r
.55427 .65421 m .53593 .64328 L .53665 .58911 L p F P
0 0 0 r
s
1 .566 .129 r
.55878 .59631 m .53816 .58718 L .53898 .63948 L p F P
0 0 0 r
s
1 .566 .129 r
.53898 .63948 m .56042 .64665 L .55878 .59631 L p F P
0 0 0 r
s
.805 .517 .112 r
.38429 .9695 m .39456 .97042 L .41255 .94158 L p F P
0 0 0 r
s
.42164 .93094 m .41255 .94158 L .39456 .97042 L p F P
s
.047 .094 .112 r
.2451 .38749 m .22053 .42686 L .22282 .39319 L p F P
0 0 0 r
s
.047 .094 .112 r
.22282 .39319 m .24723 .35364 L .2451 .38749 L p F P
0 0 0 r
s
1 .671 .15 r
.51751 .58086 m .53665 .58911 L .53593 .64328 L p F P
0 0 0 r
s
1 .669 .157 r
.68227 .78513 m .66389 .7614 L .67065 .72037 L p F P
0 0 0 r
s
1 .669 .157 r
.67065 .72037 m .69013 .74814 L .68227 .78513 L p F P
0 0 0 r
s
.997 .595 .146 r
.69013 .74814 m .67065 .72037 L .67719 .70126 L p F P
0 0 0 r
s
.43081 .92021 m .44007 .90937 L .45393 .84987 L p F P
s
.016 .01 .003 r
.4617 .83013 m .45393 .84987 L .44007 .90937 L p F P
0 0 0 r
s
.331 .157 .034 r
.36564 .98292 m .3544 .97163 L .3355 .97098 L p F P
0 0 0 r
s
.07 .03 .007 r
.3544 .97163 m .36564 .98292 L .38429 .9695 L p F P
0 0 0 r
s
.295 .575 .424 r
.20005 .60728 m .20324 .64747 L .20567 .61209 L p F P
0 0 0 r
s
.295 .575 .424 r
.20567 .61209 m .20254 .57166 L .20005 .60728 L p F P
0 0 0 r
s
.533 .965 .764 r
.71024 .19611 m .75556 .22802 L .75742 .26041 L p F P
0 0 0 r
s
.533 .965 .764 r
.75556 .22802 m .71024 .19611 L .70875 .16412 L p F P
0 0 0 r
s
.442 .842 .646 r
.19827 .71991 m .21515 .75771 L .21748 .72147 L p F P
0 0 0 r
s
.442 .842 .646 r
.21748 .72147 m .20077 .6834 L .19827 .71991 L p F P
0 0 0 r
s
.017 .035 .042 r
.21583 .4958 m .20499 .53658 L .2074 .50206 L p F P
0 0 0 r
s
.017 .035 .042 r
.2074 .50206 m .2182 .46106 L .21583 .4958 L p F P
0 0 0 r
s
.67392 .98042 m .66334 .99806 L .68059 .97879 L p F P
s
.68059 .97879 m .69269 .96716 L .67392 .98042 L p F P
s
.997 .595 .146 r
.67719 .70126 m .69763 .72986 L .69013 .74814 L p F P
0 0 0 r
s
.387 .258 .07 r
.69763 .72986 m .67719 .70126 L .68362 .70568 L p F P
0 0 0 r
s
.265 .174 .05 r
.66252 .68155 m .68362 .70568 L .67719 .70126 L p F P
0 0 0 r
s
.597 .328 .067 r
.55761 .94053 m .55379 .92892 L .56975 .98152 L p F P
0 0 0 r
s
.597 .328 .067 r
.56975 .98152 m .57513 .98269 L .55761 .94053 L p F P
0 0 0 r
s
.957 .516 .116 r
.64158 .65958 m .62076 .63994 L .62484 .68087 L p F P
0 0 0 r
s
.979 .532 .12 r
.60332 .66741 m .62484 .68087 L .62076 .63994 L p F P
0 0 0 r
s
1 .671 .15 r
.53593 .64328 m .51751 .63452 L .51751 .58086 L p F P
0 0 0 r
s
1 .577 .131 r
.53816 .58718 m .51751 .58086 L .51751 .63452 L p F P
0 0 0 r
s
1 .577 .131 r
.51751 .63452 m .53898 .63948 L .53816 .58718 L p F P
0 0 0 r
s
.782 .444 .107 r
.45333 .60408 m .47473 .59356 L .47531 .64793 L p F P
0 0 0 r
s
.753 .426 .103 r
.47473 .59356 m .49611 .5858 L .49639 .64013 L p F P
0 0 0 r
s
.753 .426 .103 r
.49639 .64013 m .47531 .64793 L .47473 .59356 L p F P
0 0 0 r
s
.193 .367 .342 r
.74435 .93946 m .78758 .91158 L .78548 .87395 L p F P
0 0 0 r
s
.565 .323 .063 r
.54208 .89336 m .54603 .90534 L .53355 .83543 L p F P
0 0 0 r
s
.565 .323 .063 r
.53355 .83543 m .53131 .81574 L .54208 .89336 L p F P
0 0 0 r
s
.066 .04 .013 r
.48527 .77578 m .49323 .75955 L .49858 .68275 L p F P
0 0 0 r
s
.082 .051 .016 r
.50484 .66463 m .49858 .68275 L .49323 .75955 L p F P
0 0 0 r
s
.818 .465 .112 r
.43187 .61732 m .45333 .60408 L .45425 .6579 L p F P
0 0 0 r
s
.782 .444 .107 r
.47531 .64793 m .45425 .6579 L .45333 .60408 L p F P
0 0 0 r
s
.518 .27 .062 r
.60595 .99944 m .59933 1.00908 L .61782 1.02482 L p F P
0 0 0 r
s
.518 .27 .062 r
.61782 1.02482 m .62582 1.00837 L .60595 .99944 L p F P
0 0 0 r
s
.076 .046 .015 r
.51115 .64854 m .51751 .63452 L .51751 .58086 L p F P
0 0 0 r
s
.728 .411 .099 r
.49611 .5858 m .51751 .58086 L .51751 .63452 L p F P
0 0 0 r
s
.728 .411 .099 r
.51751 .63452 m .49639 .64013 L .49611 .5858 L p F P
0 0 0 r
s
.571 1 .825 r
.21036 .8319 m .24001 .86584 L .24216 .82872 L p F P
0 0 0 r
s
.571 1 .825 r
.24216 .82872 m .21277 .79451 L .21036 .8319 L p F P
0 0 0 r
s
1 .729 .18 r
.74222 .93833 m .72693 .93019 L .7423 .90975 L p F P
0 0 0 r
s
1 .729 .18 r
.7423 .90975 m .75934 .92857 L .74222 .93833 L p F P
0 0 0 r
s
1 .744 .173 r
.41032 .63316 m .38864 .6515 L .38644 .63056 L p F P
0 0 0 r
s
1 .816 .188 r
.36413 .65158 m .38644 .63056 L .38864 .6515 L p F P
0 0 0 r
s
.136 .064 .017 r
.38419 .6391 m .40671 .62278 L .40857 .6121 L p F P
0 0 0 r
s
.136 .064 .017 r
.40857 .6121 m .38644 .63056 L .38419 .6391 L p F P
0 0 0 r
s
.862 .492 .118 r
.41032 .63316 m .43187 .61732 L .43317 .66996 L p F P
0 0 0 r
s
.818 .465 .112 r
.45425 .6579 m .43317 .66996 L .43187 .61732 L p F P
0 0 0 r
s
.926 .495 .111 r
.66252 .68155 m .64158 .65958 L .64643 .69626 L p F P
0 0 0 r
s
.957 .516 .116 r
.62484 .68087 m .64643 .69626 L .64158 .65958 L p F P
0 0 0 r
s
1 .649 .154 r
.70071 .81009 m .68227 .78513 L .69013 .74814 L p F P
0 0 0 r
s
1 .649 .154 r
.69013 .74814 m .70974 .7776 L .70071 .81009 L p F P
0 0 0 r
s
.939 .564 .14 r
.70974 .7776 m .69013 .74814 L .69763 .72986 L p F P
0 0 0 r
s
.796 .442 .104 r
.47263 .63964 m .49508 .63597 L .49546 .5837 L p F P
0 0 0 r
s
.796 .442 .104 r
.49546 .5837 m .4734 .58936 L .47263 .63964 L p F P
0 0 0 r
s
.823 .458 .108 r
.51751 .58086 m .49546 .5837 L .49508 .63597 L p F P
0 0 0 r
s
.09 .038 .009 r
.39456 .97042 m .38429 .9695 L .36564 .98292 L p F P
0 0 0 r
s
1 .98 .214 r
.69269 .96716 m .68059 .97879 L .69666 .95242 L p F P
0 0 0 r
s
1 .98 .214 r
.69666 .95242 m .71038 .94992 L .69269 .96716 L p F P
0 0 0 r
s
.331 .186 .049 r
.51751 .58086 m .53154 .57163 L .53278 .55388 L p F P
0 0 0 r
s
.498 .288 .072 r
.53538 .62737 m .51751 .63452 L .51751 .58086 L p F P
0 0 0 r
s
.498 .288 .072 r
.51751 .58086 m .53406 .57312 L .53538 .62737 L p F P
0 0 0 r
s
.314 .178 .048 r
.53154 .57163 m .51751 .58086 L .51751 .63452 L p F P
0 0 0 r
s
.823 .458 .108 r
.49508 .63597 m .51751 .63452 L .51751 .58086 L p F P
0 0 0 r
s
1 .756 .164 r
.50539 .57077 m .51751 .58086 L .51751 .63452 L p F P
0 0 0 r
s
1 .756 .164 r
.51751 .63452 m .50381 .62484 L .50539 .57077 L p F P
0 0 0 r
s
1 .644 .137 r
.51 .6228 m .51751 .63452 L .51751 .58086 L p F P
0 0 0 r
s
1 .644 .137 r
.51751 .58086 m .50846 .56974 L .51 .6228 L p F P
0 0 0 r
s
.529 .311 .079 r
.55076 .56816 m .53406 .57312 L .53278 .55388 L p F P
0 0 0 r
s
.529 .311 .079 r
.53278 .55388 m .54821 .54842 L .55076 .56816 L p F P
0 0 0 r
s
.287 .157 .042 r
.54821 .54842 m .53278 .55388 L .53154 .57163 L p F P
0 0 0 r
s
.762 .422 .1 r
.45011 .64549 m .47263 .63964 L .4734 .58936 L p F P
0 0 0 r
s
.762 .422 .1 r
.4734 .58936 m .45128 .59781 L .45011 .64549 L p F P
0 0 0 r
s
.515 .942 .734 r
.7593 .29331 m .79326 .33034 L .79542 .36362 L p F P
0 0 0 r
s
.515 .942 .734 r
.79326 .33034 m .7593 .29331 L .75742 .26041 L p F P
0 0 0 r
s
.444 .227 .047 r
.30104 .95451 m .28651 .93492 L .26983 .92489 L p F P
0 0 0 r
s
.544 .281 .059 r
.28651 .93492 m .30104 .95451 L .31765 .96539 L p F P
0 0 0 r
s
.939 .564 .14 r
.69763 .72986 m .71826 .76033 L .70974 .7776 L p F P
0 0 0 r
s
.556 .353 .095 r
.71826 .76033 m .69763 .72986 L .70489 .73175 L p F P
0 0 0 r
s
.387 .258 .07 r
.68362 .70568 m .70489 .73175 L .69763 .72986 L p F P
0 0 0 r
s
.732 .383 .084 r
.58043 .98328 m .57513 .98269 L .59257 1.0181 L p F P
0 0 0 r
s
.732 .383 .084 r
.59257 1.0181 m .59933 1.00908 L .58043 .98328 L p F P
0 0 0 r
s
1 .852 .184 r
.49625 .54411 m .50694 .55174 L .50539 .57077 L p F P
0 0 0 r
s
1 .852 .184 r
.50539 .57077 m .49315 .56342 L .49625 .54411 L p F P
0 0 0 r
s
1 .555 .119 r
.49932 .56134 m .50846 .56974 L .50694 .55174 L p F P
0 0 0 r
s
1 .555 .119 r
.50694 .55174 m .49625 .54411 L .49932 .56134 L p F P
0 0 0 r
s
.916 .524 .125 r
.38864 .6515 m .41032 .63316 L .41206 .68405 L p F P
0 0 0 r
s
.862 .492 .118 r
.43317 .66996 m .41206 .68405 L .41032 .63316 L p F P
0 0 0 r
s
.016 .01 .003 r
.44007 .90937 m .44943 .89843 L .4617 .83013 L p F P
0 0 0 r
s
.05 .031 .01 r
.46951 .81115 m .4617 .83013 L .44943 .89843 L p F P
0 0 0 r
s
.181 .337 .311 r
.33683 .22146 m .28837 .25156 L .29014 .21914 L p F P
0 0 0 r
s
.181 .337 .311 r
.29014 .21914 m .33824 .18895 L .33683 .22146 L p F P
0 0 0 r
s
.502 .907 .732 r
.65397 .13935 m .70875 .16412 L .71024 .19611 L p F P
0 0 0 r
s
.719 .397 .094 r
.42751 .65348 m .45011 .64549 L .45128 .59781 L p F P
0 0 0 r
s
.719 .397 .094 r
.45128 .59781 m .42907 .60898 L .42751 .65348 L p F P
0 0 0 r
s
1 1 .238 r
.71038 .94992 m .69666 .95242 L .71153 .922 L p F P
0 0 0 r
s
1 1 .238 r
.71153 .922 m .72693 .93019 L .71038 .94992 L p F P
0 0 0 r
s
.867 .458 .102 r
.68362 .70568 m .66252 .68155 L .66812 .71345 L p F P
0 0 0 r
s
.926 .495 .111 r
.64643 .69626 m .66812 .71345 L .66252 .68155 L p F P
0 0 0 r
s
.035 .07 .083 r
.83548 .6178 m .82872 .65765 L .83115 .69352 L p F P
0 0 0 r
s
.035 .07 .083 r
.82872 .65765 m .83548 .6178 L .83299 .58223 L p F P
0 0 0 r
s
.386 .722 .553 r
.7976 .39742 m .81861 .43745 L .82096 .4716 L p F P
0 0 0 r
s
.386 .722 .553 r
.81861 .43745 m .7976 .39742 L .79542 .36362 L p F P
0 0 0 r
s
.255 .486 .348 r
.82335 .50629 m .83055 .54722 L .83299 .58223 L p F P
0 0 0 r
s
.255 .486 .348 r
.83055 .54722 m .82335 .50629 L .82096 .4716 L p F P
0 0 0 r
s
.059 .119 .141 r
.83362 .72996 m .81343 .76703 L .81574 .80376 L p F P
0 0 0 r
s
.059 .119 .141 r
.81343 .76703 m .83362 .72996 L .83115 .69352 L p F P
0 0 0 r
s
1 .622 .15 r
.71923 .8361 m .70071 .81009 L .70974 .7776 L p F P
0 0 0 r
s
1 .622 .15 r
.70974 .7776 m .72951 .80849 L .71923 .8361 L p F P
0 0 0 r
s
.886 .535 .134 r
.72951 .80849 m .70974 .7776 L .71826 .76033 L p F P
0 0 0 r
s
1 .816 .188 r
.38864 .6515 m .3668 .67218 L .36413 .65158 L p F P
0 0 0 r
s
1 .886 .202 r
.34158 .67496 m .36413 .65158 L .3668 .67218 L p F P
0 0 0 r
s
.36147 .65779 m .38419 .6391 L .38644 .63056 L p F P
s
.38644 .63056 m .36413 .65158 L .36147 .65779 L p F P
s
1 .724 .164 r
.65668 .81986 m .63948 .80361 L .64556 .73911 L p F P
0 0 0 r
s
1 .724 .164 r
.64556 .73911 m .66389 .7614 L .65668 .81986 L p F P
0 0 0 r
s
1 .723 .163 r
.62728 .71841 m .64556 .73911 L .63948 .80361 L p F P
0 0 0 r
s
1 .723 .163 r
.63948 .80361 m .62225 .78819 L .62728 .71841 L p F P
0 0 0 r
s
1 .72 .162 r
.60903 .69946 m .62728 .71841 L .62225 .78819 L p F P
0 0 0 r
s
.617 .361 .072 r
.51863 .66572 m .51807 .64909 L .51986 .73105 L p F P
0 0 0 r
s
.617 .361 .072 r
.51986 .73105 m .52219 .74596 L .51863 .66572 L p F P
0 0 0 r
s
1 .723 .165 r
.67385 .83684 m .65668 .81986 L .66389 .7614 L p F P
0 0 0 r
s
1 .723 .165 r
.66389 .7614 m .68227 .78513 L .67385 .83684 L p F P
0 0 0 r
s
.614 .353 .07 r
.53131 .81574 m .52906 .79688 L .53809 .88126 L p F P
0 0 0 r
s
.614 .353 .07 r
.53809 .88126 m .54208 .89336 L .53131 .81574 L p F P
0 0 0 r
s
.522 .267 .057 r
.34786 .98933 m .3355 .97098 L .31765 .96539 L p F P
0 0 0 r
s
.331 .157 .034 r
.3355 .97098 m .34786 .98933 L .36564 .98292 L p F P
0 0 0 r
s
.39456 .97042 m .40497 .97091 L .42164 .93094 L p F P
s
.006 .003 .001 r
.43081 .92021 m .42164 .93094 L .40497 .97091 L p F P
0 0 0 r
s
.082 .051 .016 r
.49323 .75955 m .50125 .74435 L .50484 .66463 L p F P
0 0 0 r
s
.095 .058 .019 r
.51115 .64854 m .50484 .66463 L .50125 .74435 L p F P
0 0 0 r
s
1 .72 .162 r
.62225 .78819 m .60497 .77369 L .60903 .69946 L p F P
0 0 0 r
s
1 .716 .16 r
.5908 .68237 m .60903 .69946 L .60497 .77369 L p F P
0 0 0 r
s
1 .717 .166 r
.691 .85445 m .67385 .83684 L .68227 .78513 L p F P
0 0 0 r
s
1 .717 .166 r
.68227 .78513 m .70071 .81009 L .691 .85445 L p F P
0 0 0 r
s
1 .794 .189 r
.72693 .93019 m .71153 .922 L .72522 .89103 L p F P
0 0 0 r
s
1 .794 .189 r
.72522 .89103 m .7423 .90975 L .72693 .93019 L p F P
0 0 0 r
s
.981 .564 .134 r
.3668 .67218 m .38864 .6515 L .39087 .70004 L p F P
0 0 0 r
s
.916 .524 .125 r
.41206 .68405 m .39087 .70004 L .38864 .6515 L p F P
0 0 0 r
s
.665 .366 .087 r
.40479 .66352 m .42751 .65348 L .42907 .60898 L p F P
0 0 0 r
s
.665 .366 .087 r
.42907 .60898 m .40671 .62278 L .40479 .66352 L p F P
0 0 0 r
s
.135 .257 .253 r
.81809 .84107 m .78548 .87395 L .78758 .91158 L p F P
0 0 0 r
s
.135 .257 .253 r
.78548 .87395 m .81809 .84107 L .81574 .80376 L p F P
0 0 0 r
s
.34 .173 .042 r
.62582 1.00837 m .61782 1.02482 L .63564 1.02731 L p F P
0 0 0 r
s
.34 .173 .042 r
.63564 1.02731 m .64502 1.00816 L .62582 1.00837 L p F P
0 0 0 r
s
.237 .439 .392 r
.39559 .16638 m .33824 .18895 L .33964 .15693 L p F P
0 0 0 r
s
.237 .439 .392 r
.33964 .15693 m .39654 .1343 L .39559 .16638 L p F P
0 0 0 r
s
.664 .37 .076 r
.55379 .92892 m .54993 .91719 L .56427 .97964 L p F P
0 0 0 r
s
.664 .37 .076 r
.56427 .97964 m .56975 .98152 L .55379 .92892 L p F P
0 0 0 r
s
.946 .579 .146 r
.75934 .92857 m .7423 .90975 L .75648 .89034 L p F P
0 0 0 r
s
.946 .579 .146 r
.75648 .89034 m .7752 .91808 L .75934 .92857 L p F P
0 0 0 r
s
1 .705 .165 r
.70812 .87255 m .691 .85445 L .70071 .81009 L p F P
0 0 0 r
s
1 .705 .165 r
.70071 .81009 m .71923 .8361 L .70812 .87255 L p F P
0 0 0 r
s
1 .716 .16 r
.60497 .77369 m .58763 .76018 L .5908 .68237 L p F P
0 0 0 r
s
1 .71 .159 r
.57255 .66726 m .5908 .68237 L .58763 .76018 L p F P
0 0 0 r
s
.729 .381 .083 r
.70489 .73175 m .68362 .70568 L .68994 .73229 L p F P
0 0 0 r
s
.867 .458 .102 r
.66812 .71345 m .68994 .73229 L .68362 .70568 L p F P
0 0 0 r
s
.886 .535 .134 r
.71826 .76033 m .73907 .79239 L .72951 .80849 L p F P
0 0 0 r
s
.646 .403 .108 r
.73907 .79239 m .71826 .76033 L .72634 .75956 L p F P
0 0 0 r
s
.556 .353 .095 r
.70489 .73175 m .72634 .75956 L .71826 .76033 L p F P
0 0 0 r
s
.513 .297 .075 r
.5534 .6224 m .53538 .62737 L .53406 .57312 L p F P
0 0 0 r
s
.513 .297 .075 r
.53406 .57312 m .55076 .56816 L .5534 .6224 L p F P
0 0 0 r
s
.119 .219 .218 r
.28473 .31795 m .24723 .35364 L .24933 .32033 L p F P
0 0 0 r
s
.119 .219 .218 r
.24933 .32033 m .28656 .2845 L .28473 .31795 L p F P
0 0 0 r
s
.05 .031 .01 r
.44943 .89843 m .45887 .88738 L .46951 .81115 L p F P
0 0 0 r
s
.073 .045 .015 r
.47737 .793 m .46951 .81115 L .45887 .88738 L p F P
0 0 0 r
s
.287 .157 .042 r
.53154 .57163 m .54571 .56516 L .54821 .54842 L p F P
0 0 0 r
s
.297 .167 .045 r
.54571 .56516 m .53154 .57163 L .53029 .62443 L p F P
0 0 0 r
s
.314 .178 .048 r
.51751 .63452 m .53029 .62443 L .53154 .57163 L p F P
0 0 0 r
s
.986 .588 .144 r
.73782 .86293 m .71923 .8361 L .72951 .80849 L p F P
0 0 0 r
s
.986 .588 .144 r
.72951 .80849 m .74942 .84054 L .73782 .86293 L p F P
0 0 0 r
s
.838 .508 .129 r
.74942 .84054 m .72951 .80849 L .73907 .79239 L p F P
0 0 0 r
s
1 .683 .163 r
.72522 .89103 m .70812 .87255 L .71923 .8361 L p F P
0 0 0 r
s
1 .683 .163 r
.71923 .8361 m .73782 .86293 L .72522 .89103 L p F P
0 0 0 r
s
1 .643 .157 r
.7423 .90975 m .72522 .89103 L .73782 .86293 L p F P
0 0 0 r
s
1 .643 .157 r
.73782 .86293 m .75648 .89034 L .7423 .90975 L p F P
0 0 0 r
s
1 .776 .168 r
.49315 .56342 m .50539 .57077 L .50381 .62484 L p F P
0 0 0 r
s
.557 .331 .085 r
.56765 .56595 m .55076 .56816 L .54821 .54842 L p F P
0 0 0 r
s
.557 .331 .085 r
.54821 .54842 m .56382 .5459 L .56765 .56595 L p F P
0 0 0 r
s
.255 .134 .037 r
.56382 .5459 m .54821 .54842 L .54571 .56516 L p F P
0 0 0 r
s
1 .71 .159 r
.58763 .76018 m .57023 .74774 L .57255 .66726 L p F P
0 0 0 r
s
1 .704 .157 r
.55427 .65421 m .57255 .66726 L .57023 .74774 L p F P
0 0 0 r
s
.598 .328 .078 r
.38192 .67551 m .40479 .66352 L .40671 .62278 L p F P
0 0 0 r
s
.598 .328 .078 r
.40671 .62278 m .38419 .6391 L .38192 .67551 L p F P
0 0 0 r
s
1 .886 .202 r
.3668 .67218 m .34478 .69504 L .34158 .67496 L p F P
0 0 0 r
s
1 .95 .215 r
.31879 .70051 m .34158 .67496 L .34478 .69504 L p F P
0 0 0 r
s
.33852 .67868 m .36147 .65779 L .36413 .65158 L p F P
s
.36413 .65158 m .34158 .67496 L .33852 .67868 L p F P
s
.444 .227 .047 r
.26983 .92489 m .28578 .9387 L .30104 .95451 L p F P
0 0 0 r
s
.252 .108 .025 r
.28578 .9387 m .26983 .92489 L .25446 .91414 L p F P
0 0 0 r
s
1 .613 .145 r
.34478 .69504 m .3668 .67218 L .3696 .71784 L p F P
0 0 0 r
s
.981 .564 .134 r
.39087 .70004 m .3696 .71784 L .3668 .67218 L p F P
0 0 0 r
s
1 .616 .131 r
.50241 .61319 m .51 .6228 L .50846 .56974 L p F P
0 0 0 r
s
1 .616 .131 r
.50846 .56974 m .49932 .56134 L .50241 .61319 L p F P
0 0 0 r
s
.047 .094 .112 r
.24293 .42187 m .2182 .46106 L .22053 .42686 L p F P
0 0 0 r
s
.047 .094 .112 r
.22053 .42686 m .2451 .38749 L .24293 .42187 L p F P
0 0 0 r
s
1 .807 .187 r
.70812 .87255 m .72522 .89103 L .71153 .922 L p F P
0 0 0 r
s
.295 .575 .424 r
.19752 .64347 m .20077 .6834 L .20324 .64747 L p F P
0 0 0 r
s
.295 .575 .424 r
.20324 .64747 m .20005 .60728 L .19752 .64347 L p F P
0 0 0 r
s
.908 .548 .137 r
.75648 .89034 m .73782 .86293 L .74942 .84054 L p F P
0 0 0 r
s
.533 .965 .764 r
.71176 .22861 m .75742 .26041 L .7593 .29331 L p F P
0 0 0 r
s
.533 .965 .764 r
.75742 .26041 m .71176 .22861 L .71024 .19611 L p F P
0 0 0 r
s
.442 .842 .646 r
.19573 .75699 m .21277 .79451 L .21515 .75771 L p F P
0 0 0 r
s
.442 .842 .646 r
.21515 .75771 m .19827 .71991 L .19573 .75699 L p F P
0 0 0 r
s
.017 .035 .042 r
.21343 .53109 m .20254 .57166 L .20499 .53658 L p F P
0 0 0 r
s
.017 .035 .042 r
.20499 .53658 m .21583 .4958 L .21343 .53109 L p F P
0 0 0 r
s
.65 .376 .076 r
.52906 .79688 m .52678 .77892 L .53406 .86902 L p F P
0 0 0 r
s
.65 .376 .076 r
.53406 .86902 m .53809 .88126 L .52906 .79688 L p F P
0 0 0 r
s
.463 .239 .049 r
.72634 .75956 m .70489 .73175 L .71188 .75263 L p F P
0 0 0 r
s
.729 .381 .083 r
.68994 .73229 m .71188 .75263 L .70489 .73175 L p F P
0 0 0 r
s
.492 .254 .052 r
.33118 .98665 m .31765 .96539 L .30104 .95451 L p F P
0 0 0 r
s
.522 .267 .057 r
.31765 .96539 m .33118 .98665 L .34786 .98933 L p F P
0 0 0 r
s
1 .981 .221 r
.69601 .91374 m .71153 .922 L .69666 .95242 L p F P
0 0 0 r
s
1 .807 .187 r
.71153 .922 m .69601 .91374 L .70812 .87255 L p F P
0 0 0 r
s
.091 .04 .01 r
.64502 1.00816 m .63564 1.02731 L .65252 1.01535 L p F P
0 0 0 r
s
.091 .04 .01 r
.65252 1.01535 m .66334 .99806 L .64502 1.00816 L p F P
0 0 0 r
s
.347 .17 .039 r
.3771 .99388 m .36564 .98292 L .34786 .98933 L p F P
0 0 0 r
s
.09 .038 .009 r
.36564 .98292 m .3771 .99388 L .39456 .97042 L p F P
0 0 0 r
s
1 .909 .196 r
.48542 .5394 m .49625 .54411 L .49315 .56342 L p F P
0 0 0 r
s
1 .909 .196 r
.49315 .56342 m .48075 .55879 L .48542 .5394 L p F P
0 0 0 r
s
.894 .484 .104 r
.49004 .55565 m .49932 .56134 L .49625 .54411 L p F P
0 0 0 r
s
.894 .484 .104 r
.49625 .54411 m .48542 .5394 L .49004 .55565 L p F P
0 0 0 r
s
1 .801 .183 r
.691 .85445 m .70812 .87255 L .69601 .91374 L p F P
0 0 0 r
s
.124 .059 .015 r
.40497 .97091 m .39456 .97042 L .3771 .99388 L p F P
0 0 0 r
s
.649 .381 .076 r
.51807 .64909 m .51751 .63452 L .51751 .71724 L p F P
0 0 0 r
s
.649 .381 .076 r
.51751 .71724 m .51986 .73105 L .51807 .64909 L p F P
0 0 0 r
s
1 .704 .157 r
.57023 .74774 m .55275 .73641 L .55427 .65421 L p F P
0 0 0 r
s
1 .697 .155 r
.53593 .64328 m .55427 .65421 L .55275 .73641 L p F P
0 0 0 r
s
.571 1 .825 r
.20792 .86988 m .23783 .90353 L .24001 .86584 L p F P
0 0 0 r
s
.571 1 .825 r
.24001 .86584 m .21036 .8319 L .20792 .86988 L p F P
0 0 0 r
s
.823 .502 .128 r
.7752 .91808 m .75648 .89034 L .76948 .87345 L p F P
0 0 0 r
s
.908 .548 .137 r
.74942 .84054 m .76948 .87345 L .75648 .89034 L p F P
0 0 0 r
s
.095 .058 .019 r
.50125 .74435 m .50934 .73024 L .51115 .64854 L p F P
0 0 0 r
s
.105 .064 .021 r
.51751 .63452 m .51115 .64854 L .50934 .73024 L p F P
0 0 0 r
s
.838 .508 .129 r
.73907 .79239 m .76008 .82575 L .74942 .84054 L p F P
0 0 0 r
s
.698 .432 .114 r
.76008 .82575 m .73907 .79239 L .74799 .78884 L p F P
0 0 0 r
s
.646 .403 .108 r
.72634 .75956 m .74799 .78884 L .73907 .79239 L p F P
0 0 0 r
s
.006 .003 .001 r
.40497 .97091 m .41554 .97085 L .43081 .92021 L p F P
0 0 0 r
s
.049 .03 .01 r
.44007 .90937 m .43081 .92021 L .41554 .97085 L p F P
0 0 0 r
s
.797 .485 .124 r
.76948 .87345 m .74942 .84054 L .76008 .82575 L p F P
0 0 0 r
s
1 1 .241 r
.68276 .95466 m .69666 .95242 L .68059 .97879 L p F P
0 0 0 r
s
1 .981 .221 r
.69666 .95242 m .68276 .95466 L .69601 .91374 L p F P
0 0 0 r
s
.512 .28 .067 r
.35888 .68934 m .38192 .67551 L .38419 .6391 L p F P
0 0 0 r
s
.512 .28 .067 r
.38419 .6391 m .36147 .65779 L .35888 .68934 L p F P
0 0 0 r
s
1 .801 .183 r
.69601 .91374 m .68038 .90542 L .691 .85445 L p F P
0 0 0 r
s
1 .791 .179 r
.67385 .83684 m .691 .85445 L .68038 .90542 L p F P
0 0 0 r
s
.073 .045 .015 r
.45887 .88738 m .4684 .87622 L .47737 .793 L p F P
0 0 0 r
s
.089 .055 .018 r
.48527 .77578 m .47737 .793 L .4684 .87622 L p F P
0 0 0 r
s
.653 .341 .077 r
.59933 1.00908 m .59257 1.0181 L .60964 1.04056 L p F P
0 0 0 r
s
.653 .341 .077 r
.60964 1.04056 m .61782 1.02482 L .59933 1.00908 L p F P
0 0 0 r
s
1 .95 .215 r
.34478 .69504 m .32256 .71987 L .31879 .70051 L p F P
0 0 0 r
s
1 .673 .158 r
.32256 .71987 m .34478 .69504 L .34823 .73728 L p F P
0 0 0 r
s
1 .613 .145 r
.3696 .71784 m .34823 .73728 L .34478 .69504 L p F P
0 0 0 r
s
.794 .509 .11 r
.66334 .99806 m .65252 1.01535 L .66826 .99008 L p F P
0 0 0 r
s
.794 .509 .11 r
.66826 .99008 m .68059 .97879 L .66334 .99806 L p F P
0 0 0 r
s
.837 .445 .096 r
.57513 .98269 m .56975 .98152 L .58567 1.02622 L p F P
0 0 0 r
s
.837 .445 .096 r
.58567 1.02622 m .59257 1.0181 L .57513 .98269 L p F P
0 0 0 r
s
.135 .257 .253 r
.78758 .91158 m .82047 .87898 L .81809 .84107 L p F P
0 0 0 r
s
.823 .502 .128 r
.76948 .87345 m .78967 .90689 L .7752 .91808 L p F P
0 0 0 r
s
.515 .942 .734 r
.76121 .32673 m .79542 .36362 L .7976 .39742 L p F P
0 0 0 r
s
.515 .942 .734 r
.79542 .36362 m .76121 .32673 L .7593 .29331 L p F P
0 0 0 r
s
1 1 .241 r
.68059 .97879 m .66826 .99008 L .68276 .95466 L p F P
0 0 0 r
s
.524 .305 .077 r
.57158 .61958 m .5534 .6224 L .55076 .56816 L p F P
0 0 0 r
s
.524 .305 .077 r
.55076 .56816 m .56765 .56595 L .57158 .61958 L p F P
0 0 0 r
s
.708 .399 .082 r
.54993 .91719 m .54603 .90534 L .55872 .97692 L p F P
0 0 0 r
s
.708 .399 .082 r
.55872 .97692 m .56427 .97964 L .54993 .91719 L p F P
0 0 0 r
s
.752 .429 .104 r
.41206 .68405 m .43317 .66996 L .43457 .74851 L p F P
0 0 0 r
s
.728 .414 .1 r
.43317 .66996 m .45425 .6579 L .45523 .73893 L p F P
0 0 0 r
s
.728 .414 .1 r
.45523 .73893 m .43457 .74851 L .43317 .66996 L p F P
0 0 0 r
s
.868 .55 .12 r
.34158 .67496 m .31879 .70051 L .31532 .70158 L p F P
0 0 0 r
s
.868 .55 .12 r
.31532 .70158 m .33852 .67868 L .34158 .67496 L p F P
0 0 0 r
s
.707 .401 .098 r
.45425 .6579 m .47531 .64793 L .47592 .7305 L p F P
0 0 0 r
s
.707 .401 .098 r
.47592 .7305 m .45523 .73893 L .45425 .6579 L p F P
0 0 0 r
s
.181 .337 .311 r
.33539 .2545 m .28656 .2845 L .28837 .25156 L p F P
0 0 0 r
s
.181 .337 .311 r
.28837 .25156 m .33683 .22146 L .33539 .2545 L p F P
0 0 0 r
s
.502 .907 .732 r
.65505 .17142 m .71024 .19611 L .71176 .22861 L p F P
0 0 0 r
s
.502 .907 .732 r
.71024 .19611 m .65505 .17142 L .65397 .13935 L p F P
0 0 0 r
s
.783 .447 .108 r
.39087 .70004 m .41206 .68405 L .41395 .75919 L p F P
0 0 0 r
s
.752 .429 .104 r
.43457 .74851 m .41395 .75919 L .41206 .68405 L p F P
0 0 0 r
s
1 .697 .155 r
.55275 .73641 m .53518 .72623 L .53593 .64328 L p F P
0 0 0 r
s
1 .689 .153 r
.51751 .63452 m .53593 .64328 L .53518 .72623 L p F P
0 0 0 r
s
.455 .822 .676 r
.59205 .1233 m .65397 .13935 L .65505 .17142 L p F P
0 0 0 r
s
1 .791 .179 r
.68038 .90542 m .66464 .89704 L .67385 .83684 L p F P
0 0 0 r
s
1 .779 .175 r
.65668 .81986 m .67385 .83684 L .66464 .89704 L p F P
0 0 0 r
s
.69 .391 .095 r
.47531 .64793 m .49639 .64013 L .49668 .72326 L p F P
0 0 0 r
s
.69 .391 .095 r
.49668 .72326 m .47592 .7305 L .47531 .64793 L p F P
0 0 0 r
s
.035 .07 .083 r
.838 .65392 m .83115 .69352 L .83362 .72996 L p F P
0 0 0 r
s
.035 .07 .083 r
.83115 .69352 m .838 .65392 L .83548 .6178 L p F P
0 0 0 r
s
.386 .722 .553 r
.79982 .43175 m .82096 .4716 L .82335 .50629 L p F P
0 0 0 r
s
.386 .722 .553 r
.82096 .4716 m .79982 .43175 L .7976 .39742 L p F P
0 0 0 r
s
.165 .101 .033 r
.74799 .78884 m .72634 .75956 L .73398 .77429 L p F P
0 0 0 r
s
.463 .239 .049 r
.71188 .75263 m .73398 .77429 L .72634 .75956 L p F P
0 0 0 r
s
.97 .534 .122 r
.60332 .66741 m .58186 .65598 L .58436 .73114 L p F P
0 0 0 r
s
.982 .542 .124 r
.58186 .65598 m .56042 .64665 L .5621 .72528 L p F P
0 0 0 r
s
.982 .542 .124 r
.5621 .72528 m .58436 .73114 L .58186 .65598 L p F P
0 0 0 r
s
.255 .486 .348 r
.82578 .54153 m .83299 .58223 L .83548 .6178 L p F P
0 0 0 r
s
.255 .486 .348 r
.83299 .58223 m .82578 .54153 L .82335 .50629 L p F P
0 0 0 r
s
.255 .134 .037 r
.54571 .56516 m .56005 .56142 L .56382 .5459 L p F P
0 0 0 r
s
.283 .157 .043 r
.56005 .56142 m .54571 .56516 L .54321 .61648 L p F P
0 0 0 r
s
.297 .167 .045 r
.53029 .62443 m .54321 .61648 L .54571 .56516 L p F P
0 0 0 r
s
.956 .525 .12 r
.62484 .68087 m .60332 .66741 L .60663 .73816 L p F P
0 0 0 r
s
.97 .534 .122 r
.58436 .73114 m .60663 .73816 L .60332 .66741 L p F P
0 0 0 r
s
.821 .47 .114 r
.3696 .71784 m .39087 .70004 L .39334 .77092 L p F P
0 0 0 r
s
.783 .447 .108 r
.41395 .75919 m .39334 .77092 L .39087 .70004 L p F P
0 0 0 r
s
.059 .119 .141 r
.83613 .76697 m .81574 .80376 L .81809 .84107 L p F P
0 0 0 r
s
.059 .119 .141 r
.81574 .80376 m .83613 .76697 L .83362 .72996 L p F P
0 0 0 r
s
.993 .55 .126 r
.56042 .64665 m .53898 .63948 L .53982 .72064 L p F P
0 0 0 r
s
.993 .55 .126 r
.53982 .72064 m .5621 .72528 L .56042 .64665 L p F P
0 0 0 r
s
.371 .184 .039 r
.31584 .97412 m .30104 .95451 L .28578 .9387 L p F P
0 0 0 r
s
.492 .254 .052 r
.30104 .95451 m .31584 .97412 L .33118 .98665 L p F P
0 0 0 r
s
.595 .398 .101 r
.27196 .919 m .25446 .91414 L .2405 .90272 L p F P
0 0 0 r
s
.252 .108 .025 r
.25446 .91414 m .27196 .919 L .28578 .9387 L p F P
0 0 0 r
s
1 .923 .206 r
.68038 .90542 m .69601 .91374 L .68276 .95466 L p F P
0 0 0 r
s
.763 .467 .12 r
.78967 .90689 m .76948 .87345 L .78129 .86009 L p F P
0 0 0 r
s
.797 .485 .124 r
.76008 .82575 m .78129 .86009 L .76948 .87345 L p F P
0 0 0 r
s
.94 .513 .117 r
.64643 .69626 m .62484 .68087 L .62891 .74632 L p F P
0 0 0 r
s
.956 .525 .12 r
.60663 .73816 m .62891 .74632 L .62484 .68087 L p F P
0 0 0 r
s
1 .798 .173 r
.48075 .55879 m .49315 .56342 L .48997 .61729 L p F P
0 0 0 r
s
1 .776 .168 r
.50381 .62484 m .48997 .61729 L .49315 .56342 L p F P
0 0 0 r
s
.105 .064 .021 r
.50934 .73024 m .51751 .71724 L .51751 .63452 L p F P
0 0 0 r
s
.675 .382 .093 r
.49639 .64013 m .51751 .63452 L .51751 .71724 L p F P
0 0 0 r
s
.675 .382 .093 r
.51751 .71724 m .49668 .72326 L .49639 .64013 L p F P
0 0 0 r
s
.678 .394 .08 r
.52678 .77892 m .5245 .76192 L .52999 .85666 L p F P
0 0 0 r
s
.678 .394 .08 r
.52999 .85666 m .53406 .86902 L .52678 .77892 L p F P
0 0 0 r
s
.574 .344 .089 r
.58475 .56644 m .56765 .56595 L .56382 .5459 L p F P
0 0 0 r
s
.574 .344 .089 r
.56382 .5459 m .57964 .54629 L .58475 .56644 L p F P
0 0 0 r
s
.235 .118 .032 r
.57964 .54629 m .56382 .5459 L .56005 .56142 L p F P
0 0 0 r
s
1 .689 .153 r
.53518 .72623 m .51751 .71724 L .51751 .63452 L p F P
0 0 0 r
s
1 .558 .128 r
.53898 .63948 m .51751 .63452 L .51751 .71724 L p F P
0 0 0 r
s
1 .558 .128 r
.51751 .71724 m .53982 .72064 L .53898 .63948 L p F P
0 0 0 r
s
1 .779 .175 r
.66464 .89704 m .64878 .8886 L .65668 .81986 L p F P
0 0 0 r
s
1 .768 .172 r
.63948 .80361 m .65668 .81986 L .64878 .8886 L p F P
0 0 0 r
s
.731 .451 .118 r
.78129 .86009 m .76008 .82575 L .76984 .81931 L p F P
0 0 0 r
s
.698 .432 .114 r
.74799 .78884 m .76984 .81931 L .76008 .82575 L p F P
0 0 0 r
s
.87 .501 .121 r
.34823 .73728 m .3696 .71784 L .37273 .7836 L p F P
0 0 0 r
s
.821 .47 .114 r
.39334 .77092 m .37273 .7836 L .3696 .71784 L p F P
0 0 0 r
s
.293 .536 .468 r
.45936 .1528 m .39559 .16638 L .39654 .1343 L p F P
0 0 0 r
s
.293 .536 .468 r
.39654 .1343 m .45982 .12069 L .45936 .1528 L p F P
0 0 0 r
s
.403 .218 .053 r
.33565 .70487 m .35888 .68934 L .36147 .65779 L p F P
0 0 0 r
s
.403 .218 .053 r
.36147 .65779 m .33852 .67868 L .33565 .70487 L p F P
0 0 0 r
s
1 .592 .126 r
.49471 .60565 m .50241 .61319 L .49932 .56134 L p F P
0 0 0 r
s
1 .592 .126 r
.49932 .56134 m .49004 .55565 L .49471 .60565 L p F P
0 0 0 r
s
.237 .439 .392 r
.39462 .19897 m .33683 .22146 L .33824 .18895 L p F P
0 0 0 r
s
.237 .439 .392 r
.33824 .18895 m .39559 .16638 L .39462 .19897 L p F P
0 0 0 r
s
.919 .499 .113 r
.66812 .71345 m .64643 .69626 L .65122 .75554 L p F P
0 0 0 r
s
.94 .513 .117 r
.62891 .74632 m .65122 .75554 L .64643 .69626 L p F P
0 0 0 r
s
1 1 .225 r
.29573 .72798 m .31879 .70051 L .32256 .71987 L p F P
0 0 0 r
s
1 1 .225 r
.32256 .71987 m .30012 .74646 L .29573 .72798 L p F P
0 0 0 r
s
1 .748 .174 r
.30012 .74646 m .32256 .71987 L .32673 .75821 L p F P
0 0 0 r
s
1 .673 .158 r
.34823 .73728 m .32673 .75821 L .32256 .71987 L p F P
0 0 0 r
s
.089 .055 .018 r
.4684 .87622 m .47803 .86495 L .48527 .77578 L p F P
0 0 0 r
s
.101 .062 .02 r
.49323 .75955 m .48527 .77578 L .47803 .86495 L p F P
0 0 0 r
s
.119 .219 .218 r
.28287 .35194 m .2451 .38749 L .24723 .35364 L p F P
0 0 0 r
s
.119 .219 .218 r
.24723 .35364 m .28473 .31795 L .28287 .35194 L p F P
0 0 0 r
s
.538 .309 .077 r
.53673 .71059 m .51751 .71724 L .51751 .63452 L p F P
0 0 0 r
s
.538 .309 .077 r
.51751 .63452 m .53538 .62737 L .53673 .71059 L p F P
0 0 0 r
s
.259 .146 .041 r
.53029 .62443 m .51751 .63452 L .51751 .71724 L p F P
0 0 0 r
s
.874 .487 .114 r
.49469 .71715 m .51751 .71724 L .51751 .63452 L p F P
0 0 0 r
s
.874 .487 .114 r
.51751 .63452 m .49508 .63597 L .49469 .71715 L p F P
0 0 0 r
s
1 .741 .161 r
.50381 .62484 m .51751 .63452 L .51751 .71724 L p F P
0 0 0 r
s
1 .741 .161 r
.51751 .71724 m .50218 .7079 L .50381 .62484 L p F P
0 0 0 r
s
1 .588 .124 r
.51159 .70491 m .51751 .71724 L .51751 .63452 L p F P
0 0 0 r
s
1 .588 .124 r
.51751 .63452 m .51 .6228 L .51159 .70491 L p F P
0 0 0 r
s
.858 .476 .111 r
.47185 .71831 m .49469 .71715 L .49508 .63597 L p F P
0 0 0 r
s
.858 .476 .111 r
.49508 .63597 m .47263 .63964 L .47185 .71831 L p F P
0 0 0 r
s
.049 .03 .01 r
.41554 .97085 m .42627 .97009 L .44007 .90937 L p F P
0 0 0 r
s
.076 .046 .015 r
.44943 .89843 m .44007 .90937 L .42627 .97009 L p F P
0 0 0 r
s
.525 .268 .058 r
.36049 1.00734 m .34786 .98933 L .33118 .98665 L p F P
0 0 0 r
s
.347 .17 .039 r
.34786 .98933 m .36049 1.00734 L .3771 .99388 L p F P
0 0 0 r
s
1 .768 .172 r
.64878 .8886 m .6328 .8801 L .63948 .80361 L p F P
0 0 0 r
s
1 .758 .169 r
.62225 .78819 m .63948 .80361 L .6328 .8801 L p F P
0 0 0 r
s
.934 .54 .13 r
.32673 .75821 m .34823 .73728 L .35212 .79716 L p F P
0 0 0 r
s
.87 .501 .121 r
.37273 .7836 m .35212 .79716 L .34823 .73728 L p F P
0 0 0 r
s
.89 .479 .109 r
.68994 .73229 m .66812 .71345 L .67358 .76575 L p F P
0 0 0 r
s
.919 .499 .113 r
.65122 .75554 m .67358 .76575 L .66812 .71345 L p F P
0 0 0 r
s
.837 .464 .109 r
.44895 .72068 m .47185 .71831 L .47263 .63964 L p F P
0 0 0 r
s
.837 .464 .109 r
.47263 .63964 m .45011 .64549 L .44895 .72068 L p F P
0 0 0 r
s
.301 .201 .056 r
.30198 .95246 m .28578 .9387 L .27196 .919 L p F P
0 0 0 r
s
.371 .184 .039 r
.28578 .9387 m .30198 .95246 L .31584 .97412 L p F P
0 0 0 r
s
1 .711 .152 r
.29186 .72626 m .31532 .70158 L .31879 .70051 L p F P
0 0 0 r
s
1 .711 .152 r
.31879 .70051 m .29573 .72798 L .29186 .72626 L p F P
0 0 0 r
s
.384 .26 .07 r
.76984 .81931 m .74799 .78884 L .75622 .79705 L p F P
0 0 0 r
s
.165 .101 .033 r
.73398 .77429 m .75622 .79705 L .74799 .78884 L p F P
0 0 0 r
s
1 .962 .207 r
.47442 .53755 m .48542 .5394 L .48075 .55879 L p F P
0 0 0 r
s
.79 .421 .091 r
.48063 .55261 m .49004 .55565 L .48542 .5394 L p F P
0 0 0 r
s
.79 .421 .091 r
.48542 .5394 m .47442 .53755 L .48063 .55261 L p F P
0 0 0 r
s
.763 .467 .12 r
.78129 .86009 m .80267 .89507 L .78967 .90689 L p F P
0 0 0 r
s
.047 .094 .112 r
.24073 .4568 m .21583 .4958 L .2182 .46106 L p F P
0 0 0 r
s
.047 .094 .112 r
.2182 .46106 m .24293 .42187 L .24073 .4568 L p F P
0 0 0 r
s
.295 .575 .424 r
.19495 .68025 m .19827 .71991 L .20077 .6834 L p F P
0 0 0 r
s
.295 .575 .424 r
.20077 .6834 m .19752 .64347 L .19495 .68025 L p F P
0 0 0 r
s
.124 .059 .015 r
.3771 .99388 m .38878 1.00422 L .40497 .97091 L p F P
0 0 0 r
s
.158 .08 .022 r
.41554 .97085 m .40497 .97091 L .38878 1.00422 L p F P
0 0 0 r
s
.533 .965 .764 r
.7133 .26162 m .7593 .29331 L .76121 .32673 L p F P
0 0 0 r
s
.533 .965 .764 r
.7593 .29331 m .7133 .26162 L .71176 .22861 L p F P
0 0 0 r
s
.532 .31 .079 r
.58997 .61886 m .57158 .61958 L .56765 .56595 L p F P
0 0 0 r
s
.532 .31 .079 r
.56765 .56595 m .58475 .56644 L .58997 .61886 L p F P
0 0 0 r
s
.442 .842 .646 r
.19314 .79467 m .21036 .8319 L .21277 .79451 L p F P
0 0 0 r
s
.442 .842 .646 r
.21277 .79451 m .19573 .75699 L .19314 .79467 L p F P
0 0 0 r
s
.017 .035 .042 r
.21099 .56695 m .20005 .60728 L .20254 .57166 L p F P
0 0 0 r
s
.017 .035 .042 r
.20254 .57166 m .21343 .53109 L .21099 .56695 L p F P
0 0 0 r
s
.384 .197 .047 r
.61782 1.02482 m .60964 1.04056 L .62603 1.04571 L p F P
0 0 0 r
s
.384 .197 .047 r
.62603 1.04571 m .63564 1.02731 L .61782 1.02482 L p F P
0 0 0 r
s
.812 .449 .105 r
.42599 .72425 m .44895 .72068 L .45011 .64549 L p F P
0 0 0 r
s
.812 .449 .105 r
.45011 .64549 m .42751 .65348 L .42599 .72425 L p F P
0 0 0 r
s
1 .923 .206 r
.68276 .95466 m .66867 .9565 L .68038 .90542 L p F P
0 0 0 r
s
1 .878 .195 r
.66464 .89704 m .68038 .90542 L .66867 .9565 L p F P
0 0 0 r
s
1 1 .228 r
.66867 .9565 m .68276 .95466 L .66826 .99008 L p F P
0 0 0 r
s
.74 .42 .087 r
.54603 .90534 m .54208 .89336 L .55307 .97321 L p F P
0 0 0 r
s
.74 .42 .087 r
.55307 .97321 m .55872 .97692 L .54603 .90534 L p F P
0 0 0 r
s
1 .748 .174 r
.32673 .75821 m .3051 .78044 L .30012 .74646 L p F P
0 0 0 r
s
1 .595 .142 r
.3051 .78044 m .32673 .75821 L .33149 .81149 L p F P
0 0 0 r
s
.934 .54 .13 r
.35212 .79716 m .33149 .81149 L .32673 .75821 L p F P
0 0 0 r
s
1 .758 .169 r
.6328 .8801 m .6167 .87153 L .62225 .78819 L p F P
0 0 0 r
s
1 .748 .166 r
.60497 .77369 m .62225 .78819 L .6167 .87153 L p F P
0 0 0 r
s
.846 .45 .102 r
.71188 .75263 m .68994 .73229 L .69599 .77686 L p F P
0 0 0 r
s
.89 .479 .109 r
.67358 .76575 m .69599 .77686 L .68994 .73229 L p F P
0 0 0 r
s
.455 .822 .676 r
.65505 .17142 m .59264 .1554 L .59205 .1233 L p F P
0 0 0 r
s
.403 .729 .611 r
.52617 .11694 m .59205 .1233 L .59264 .1554 L p F P
0 0 0 r
s
.759 .467 .121 r
.80267 .89507 m .78129 .86009 L .79188 .85069 L p F P
0 0 0 r
s
.731 .451 .118 r
.76984 .81931 m .79188 .85069 L .78129 .86009 L p F P
0 0 0 r
s
.264 .133 .035 r
.31221 .72194 m .33565 .70487 L .33852 .67868 L p F P
0 0 0 r
s
.264 .133 .035 r
.33852 .67868 m .31532 .70158 L .31221 .72194 L p F P
0 0 0 r
s
1 1 .233 r
.27239 .75711 m .29573 .72798 L .30012 .74646 L p F P
0 0 0 r
s
1 1 .233 r
.30012 .74646 m .27745 .77455 L .27239 .75711 L p F P
0 0 0 r
s
1 .837 .193 r
.27745 .77455 m .30012 .74646 L .3051 .78044 L p F P
0 0 0 r
s
.701 .408 .083 r
.5245 .76192 m .52219 .74596 L .52588 .84416 L p F P
0 0 0 r
s
.701 .408 .083 r
.52588 .84416 m .52999 .85666 L .5245 .76192 L p F P
0 0 0 r
s
1 .966 .23 r
.25963 .89692 m .2405 .90272 L .22805 .89068 L p F P
0 0 0 r
s
.595 .398 .101 r
.2405 .90272 m .25963 .89692 L .27196 .919 L p F P
0 0 0 r
s
.338 .171 .041 r
.38878 1.00422 m .3771 .99388 L .36049 1.00734 L p F P
0 0 0 r
s
.78 .43 .101 r
.40294 .72896 m .42599 .72425 L .42751 .65348 L p F P
0 0 0 r
s
.78 .43 .101 r
.42751 .65348 m .40479 .66352 L .40294 .72896 L p F P
0 0 0 r
s
.841 .531 .138 r
.28966 .92376 m .27196 .919 L .25963 .89692 L p F P
0 0 0 r
s
.301 .201 .056 r
.27196 .919 m .28966 .92376 L .30198 .95246 L p F P
0 0 0 r
s
.235 .118 .032 r
.56005 .56142 m .5746 .56037 L .57964 .54629 L p F P
0 0 0 r
s
.272 .149 .041 r
.5746 .56037 m .56005 .56142 L .55628 .61064 L p F P
0 0 0 r
s
.283 .157 .043 r
.54321 .61648 m .55628 .61064 L .56005 .56142 L p F P
0 0 0 r
s
.349 .634 .541 r
.52624 .14907 m .45936 .1528 L .45982 .12069 L p F P
0 0 0 r
s
.349 .634 .541 r
.45982 .12069 m .52617 .11694 L .52624 .14907 L p F P
0 0 0 r
s
.897 .485 .104 r
.56975 .98152 m .56427 .97964 L .57862 1.03317 L p F P
0 0 0 r
s
.897 .485 .104 r
.57862 1.03317 m .58567 1.02622 L .56975 .98152 L p F P
0 0 0 r
s
.548 .315 .079 r
.55609 .70515 m .53673 .71059 L .53538 .62737 L p F P
0 0 0 r
s
.548 .315 .079 r
.53538 .62737 m .5534 .6224 L .55609 .70515 L p F P
0 0 0 r
s
.101 .062 .02 r
.47803 .86495 m .48775 .85357 L .49323 .75955 L p F P
0 0 0 r
s
.11 .068 .022 r
.50125 .74435 m .49323 .75955 L .48775 .85357 L p F P
0 0 0 r
s
1 .837 .193 r
.3051 .78044 m .28333 .80377 L .27745 .77455 L p F P
0 0 0 r
s
1 .672 .159 r
.28333 .80377 m .3051 .78044 L .31084 .8265 L p F P
0 0 0 r
s
1 .595 .142 r
.33149 .81149 m .31084 .8265 L .3051 .78044 L p F P
0 0 0 r
s
1 .748 .166 r
.6167 .87153 m .60048 .8629 L .60497 .77369 L p F P
0 0 0 r
s
1 .74 .164 r
.58763 .76018 m .60497 .77369 L .60048 .8629 L p F P
0 0 0 r
s
.515 .942 .734 r
.76315 .36069 m .7976 .39742 L .79982 .43175 L p F P
0 0 0 r
s
.515 .942 .734 r
.7976 .39742 m .76315 .36069 L .76121 .32673 L p F P
0 0 0 r
s
1 .962 .207 r
.48075 .55879 m .46817 .55683 L .47442 .53755 L p F P
0 0 0 r
s
1 .823 .178 r
.46817 .55683 m .48075 .55879 L .47597 .61187 L p F P
0 0 0 r
s
1 .798 .173 r
.48997 .61729 m .47597 .61187 L .48075 .55879 L p F P
0 0 0 r
s
.763 .4 .09 r
.73398 .77429 m .71188 .75263 L .71847 .78878 L p F P
0 0 0 r
s
.846 .45 .102 r
.69599 .77686 m .71847 .78878 L .71188 .75263 L p F P
0 0 0 r
s
.703 .442 .117 r
.79188 .85069 m .76984 .81931 L .77863 .8207 L p F P
0 0 0 r
s
.384 .26 .07 r
.75622 .79705 m .77863 .8207 L .76984 .81931 L p F P
0 0 0 r
s
1 .754 .164 r
.48997 .61729 m .50381 .62484 L .50218 .7079 L p F P
0 0 0 r
s
.448 .231 .048 r
.34502 1.00757 m .33118 .98665 L .31584 .97412 L p F P
0 0 0 r
s
.525 .268 .058 r
.33118 .98665 m .34502 1.00757 L .36049 1.00734 L p F P
0 0 0 r
s
.245 .137 .039 r
.54321 .61648 m .53029 .62443 L .529 .70627 L p F P
0 0 0 r
s
.259 .146 .041 r
.51751 .71724 m .529 .70627 L .53029 .62443 L p F P
0 0 0 r
s
.403 .729 .611 r
.59264 .1554 m .52624 .14907 L .52617 .11694 L p F P
0 0 0 r
s
.181 .337 .311 r
.33393 .28807 m .28473 .31795 L .28656 .2845 L p F P
0 0 0 r
s
.181 .337 .311 r
.28656 .2845 m .33539 .2545 L .33393 .28807 L p F P
0 0 0 r
s
.502 .907 .732 r
.65614 .20399 m .71176 .22861 L .7133 .26162 L p F P
0 0 0 r
s
.502 .907 .732 r
.71176 .22861 m .65614 .20399 L .65505 .17142 L p F P
0 0 0 r
s
.581 .352 .092 r
.60209 .56955 m .58475 .56644 L .57964 .54629 L p F P
0 0 0 r
s
.581 .352 .092 r
.57964 .54629 m .59571 .5495 L .60209 .56955 L p F P
0 0 0 r
s
.228 .111 .03 r
.59571 .5495 m .57964 .54629 L .5746 .56037 L p F P
0 0 0 r
s
1 .68 .145 r
.6557 1.00075 m .66826 .99008 L .65252 1.01535 L p F P
0 0 0 r
s
1 1 .228 r
.66826 .99008 m .6557 1.00075 L .66867 .9565 L p F P
0 0 0 r
s
.076 .046 .015 r
.42627 .97009 m .43716 .96849 L .44943 .89843 L p F P
0 0 0 r
s
.095 .058 .019 r
.45887 .88738 m .44943 .89843 L .43716 .96849 L p F P
0 0 0 r
s
.455 .822 .676 r
.59264 .1554 m .65505 .17142 L .65614 .20399 L p F P
0 0 0 r
s
.017 .007 .002 r
.63564 1.02731 m .62603 1.04571 L .64146 1.03193 L p F P
0 0 0 r
s
.017 .007 .002 r
.64146 1.03193 m .65252 1.01535 L .63564 1.02731 L p F P
0 0 0 r
s
.775 .406 .091 r
.59257 1.0181 m .58567 1.02622 L .60126 1.05522 L p F P
0 0 0 r
s
.775 .406 .091 r
.60126 1.05522 m .60964 1.04056 L .59257 1.0181 L p F P
0 0 0 r
s
.739 .406 .095 r
.37979 .73475 m .40294 .72896 L .40479 .66352 L p F P
0 0 0 r
s
.739 .406 .095 r
.40479 .66352 m .38192 .67551 L .37979 .73475 L p F P
0 0 0 r
s
.998 .568 .12 r
.5056 .6937 m .51159 .70491 L .51 .6228 L p F P
0 0 0 r
s
.998 .568 .12 r
.51 .6228 m .50241 .61319 L .5056 .6937 L p F P
0 0 0 r
s
1 .895 .19 r
.26811 .75249 m .29186 .72626 L .29573 .72798 L p F P
0 0 0 r
s
1 .895 .19 r
.29573 .72798 m .27239 .75711 L .26811 .75249 L p F P
0 0 0 r
s
.035 .07 .083 r
.84056 .69063 m .83362 .72996 L .83613 .76697 L p F P
0 0 0 r
s
.035 .07 .083 r
.83362 .72996 m .84056 .69063 L .838 .65392 L p F P
0 0 0 r
s
.386 .722 .553 r
.80208 .46664 m .82335 .50629 L .82578 .54153 L p F P
0 0 0 r
s
.386 .722 .553 r
.82335 .50629 m .80208 .46664 L .79982 .43175 L p F P
0 0 0 r
s
.255 .486 .348 r
.82824 .57733 m .83548 .6178 L .838 .65392 L p F P
0 0 0 r
s
.255 .486 .348 r
.83548 .6178 m .82824 .57733 L .82578 .54153 L p F P
0 0 0 r
s
1 .569 .122 r
.48691 .60016 m .49471 .60565 L .49004 .55565 L p F P
0 0 0 r
s
1 .569 .122 r
.49004 .55565 m .48063 .55261 L .48691 .60016 L p F P
0 0 0 r
s
1 .878 .195 r
.66867 .9565 m .65438 .9578 L .66464 .89704 L p F P
0 0 0 r
s
1 .844 .187 r
.64878 .8886 m .66464 .89704 L .65438 .9578 L p F P
0 0 0 r
s
.059 .119 .141 r
.83868 .80457 m .81809 .84107 L .82047 .87898 L p F P
0 0 0 r
s
.059 .119 .141 r
.81809 .84107 m .83868 .80457 L .83613 .76697 L p F P
0 0 0 r
s
1 .966 .23 r
.22805 .89068 m .24878 .87427 L .25963 .89692 L p F P
0 0 0 r
s
1 .782 .19 r
.27886 .89109 m .25963 .89692 L .24878 .87427 L p F P
0 0 0 r
s
.841 .531 .138 r
.25963 .89692 m .27886 .89109 L .28966 .92376 L p F P
0 0 0 r
s
1 .68 .145 r
.65252 1.01535 m .64146 1.03193 L .6557 1.00075 L p F P
0 0 0 r
s
1 .74 .164 r
.60048 .8629 m .58413 .8542 L .58763 .76018 L p F P
0 0 0 r
s
1 .732 .162 r
.57023 .74774 m .58763 .76018 L .58413 .8542 L p F P
0 0 0 r
s
1 .939 .214 r
.25455 .80387 m .27745 .77455 L .28333 .80377 L p F P
0 0 0 r
s
1 .939 .214 r
.28333 .80377 m .26143 .82798 L .25455 .80387 L p F P
0 0 0 r
s
1 .782 .184 r
.26143 .82798 m .28333 .80377 L .29018 .84204 L p F P
0 0 0 r
s
1 .672 .159 r
.31084 .8265 m .29018 .84204 L .28333 .80377 L p F P
0 0 0 r
s
.759 .467 .121 r
.79188 .85069 m .81411 .88266 L .80267 .89507 L p F P
0 0 0 r
s
.56 .288 .063 r
.75622 .79705 m .73398 .77429 L .74101 .80139 L p F P
0 0 0 r
s
.763 .4 .09 r
.71847 .78878 m .74101 .80139 L .73398 .77429 L p F P
0 0 0 r
s
.293 .536 .468 r
.4589 .18543 m .39462 .19897 L .39559 .16638 L p F P
0 0 0 r
s
.293 .536 .468 r
.39559 .16638 m .45936 .1528 L .4589 .18543 L p F P
0 0 0 r
s
.093 .044 .012 r
.28854 .74036 m .31221 .72194 L .31532 .70158 L p F P
0 0 0 r
s
.093 .044 .012 r
.31532 .70158 m .29186 .72626 L .28854 .74036 L p F P
0 0 0 r
s
1 1 .238 r
.24877 .78761 m .27239 .75711 L .27745 .77455 L p F P
0 0 0 r
s
1 1 .238 r
.27745 .77455 m .25455 .80387 L .24877 .78761 L p F P
0 0 0 r
s
.237 .439 .392 r
.39364 .23208 m .33539 .2545 L .33683 .22146 L p F P
0 0 0 r
s
.237 .439 .392 r
.33683 .22146 m .39462 .19897 L .39364 .23208 L p F P
0 0 0 r
s
.448 .231 .048 r
.31584 .97412 m .33095 .99338 L .34502 1.00757 L p F P
0 0 0 r
s
.174 .107 .035 r
.33095 .99338 m .31584 .97412 L .30198 .95246 L p F P
0 0 0 r
s
.767 .437 .091 r
.54208 .89336 m .53809 .88126 L .54734 .96841 L p F P
0 0 0 r
s
.767 .437 .091 r
.54734 .96841 m .55307 .97321 L .54208 .89336 L p F P
0 0 0 r
s
.536 .315 .08 r
.60858 .62018 m .58997 .61886 L .58475 .56644 L p F P
0 0 0 r
s
.536 .315 .08 r
.58475 .56644 m .60209 .56955 L .60858 .62018 L p F P
0 0 0 r
s
.557 .321 .08 r
.57559 .70089 m .55609 .70515 L .5534 .6224 L p F P
0 0 0 r
s
.557 .321 .08 r
.5534 .6224 m .57158 .61958 L .57559 .70089 L p F P
0 0 0 r
s
.687 .376 .089 r
.35654 .74156 m .37979 .73475 L .38192 .67551 L p F P
0 0 0 r
s
.687 .376 .089 r
.38192 .67551 m .35888 .68934 L .35654 .74156 L p F P
0 0 0 r
s
.721 .421 .087 r
.52219 .74596 m .51986 .73105 L .52171 .83152 L p F P
0 0 0 r
s
.721 .421 .087 r
.52171 .83152 m .52588 .84416 L .52219 .74596 L p F P
0 0 0 r
s
.119 .219 .218 r
.28098 .38648 m .24293 .42187 L .2451 .38749 L p F P
0 0 0 r
s
.119 .219 .218 r
.2451 .38749 m .28287 .35194 L .28098 .38648 L p F P
0 0 0 r
s
.92 .543 .133 r
.29018 .84204 m .31084 .8265 L .31761 .87935 L p F P
0 0 0 r
s
.838 .49 .12 r
.31084 .8265 m .33149 .81149 L .33713 .87343 L p F P
0 0 0 r
s
.838 .49 .12 r
.33713 .87343 m .31761 .87935 L .31084 .8265 L p F P
0 0 0 r
s
1 .782 .184 r
.29018 .84204 m .26949 .85801 L .26143 .82798 L p F P
0 0 0 r
s
1 .631 .154 r
.26949 .85801 m .29018 .84204 L .29818 .88523 L p F P
0 0 0 r
s
.92 .543 .133 r
.31761 .87935 m .29818 .88523 L .29018 .84204 L p F P
0 0 0 r
s
1 .939 .218 r
.23938 .85283 m .26143 .82798 L .26949 .85801 L p F P
0 0 0 r
s
1 .939 .218 r
.26949 .85801 m .24878 .87427 L .23938 .85283 L p F P
0 0 0 r
s
1 .782 .19 r
.24878 .87427 m .26949 .85801 L .27886 .89109 L p F P
0 0 0 r
s
1 .631 .154 r
.29818 .88523 m .27886 .89109 L .26949 .85801 L p F P
0 0 0 r
s
.784 .455 .112 r
.33149 .81149 m .35212 .79716 L .35676 .86748 L p F P
0 0 0 r
s
.784 .455 .112 r
.35676 .86748 m .33713 .87343 L .33149 .81149 L p F P
0 0 0 r
s
1 .978 .212 r
.65438 .9578 m .66867 .9565 L .6557 1.00075 L p F P
0 0 0 r
s
.833 .518 .134 r
.81411 .88266 m .79188 .85069 L .80118 .84501 L p F P
0 0 0 r
s
.703 .442 .117 r
.77863 .8207 m .80118 .84501 L .79188 .85069 L p F P
0 0 0 r
s
.692 .363 .078 r
.47105 .55215 m .48063 .55261 L .47442 .53755 L p F P
0 0 0 r
s
1 1 .214 r
.46323 .53851 m .47442 .53755 L .46817 .55683 L p F P
0 0 0 r
s
.692 .363 .078 r
.47442 .53755 m .46323 .53851 L .47105 .55215 L p F P
0 0 0 r
s
.776 .475 .123 r
.27886 .89109 m .29818 .88523 L .30755 .92828 L p F P
0 0 0 r
s
.776 .475 .123 r
.30755 .92828 m .28966 .92376 L .27886 .89109 L p F P
0 0 0 r
s
1 1 .253 r
.21721 .87807 m .23938 .85283 L .24878 .87427 L p F P
0 0 0 r
s
1 1 .253 r
.24878 .87427 m .22805 .89068 L .21721 .87807 L p F P
0 0 0 r
s
.158 .08 .022 r
.38878 1.00422 m .40068 1.01367 L .41554 .97085 L p F P
0 0 0 r
s
.177 .092 .026 r
.42627 .97009 m .41554 .97085 L .40068 1.01367 L p F P
0 0 0 r
s
.745 .43 .106 r
.35212 .79716 m .37273 .7836 L .37648 .8615 L p F P
0 0 0 r
s
.745 .43 .106 r
.37648 .8615 m .35676 .86748 L .35212 .79716 L p F P
0 0 0 r
s
.11 .068 .022 r
.48775 .85357 m .49757 .84208 L .50125 .74435 L p F P
0 0 0 r
s
.118 .072 .024 r
.50934 .73024 m .50125 .74435 L .49757 .84208 L p F P
0 0 0 r
s
.469 .297 .081 r
.31845 .96588 m .30198 .95246 L .28966 .92376 L p F P
0 0 0 r
s
.174 .107 .035 r
.30198 .95246 m .31845 .96588 L .33095 .99338 L p F P
0 0 0 r
s
.469 .297 .081 r
.28966 .92376 m .30755 .92828 L .31845 .96588 L p F P
0 0 0 r
s
.717 .412 .101 r
.37273 .7836 m .39334 .77092 L .39632 .85549 L p F P
0 0 0 r
s
.717 .412 .101 r
.39632 .85549 m .37648 .8615 L .37273 .7836 L p F P
0 0 0 r
s
1 1 .234 r
.23141 .83411 m .25455 .80387 L .26143 .82798 L p F P
0 0 0 r
s
1 1 .234 r
.26143 .82798 m .23938 .85283 L .23141 .83411 L p F P
0 0 0 r
s
1 .732 .162 r
.58413 .8542 m .56767 .84544 L .57023 .74774 L p F P
0 0 0 r
s
1 .724 .16 r
.55275 .73641 m .57023 .74774 L .56767 .84544 L p F P
0 0 0 r
s
.251 .108 .025 r
.77863 .8207 m .75622 .79705 L .76363 .81458 L p F P
0 0 0 r
s
.56 .288 .063 r
.74101 .80139 m .76363 .81458 L .75622 .79705 L p F P
0 0 0 r
s
.047 .094 .112 r
.23849 .4923 m .21343 .53109 L .21583 .4958 L p F P
0 0 0 r
s
.047 .094 .112 r
.21583 .4958 m .24073 .4568 L .23849 .4923 L p F P
0 0 0 r
s
1 .844 .187 r
.65438 .9578 m .63991 .95841 L .64878 .8886 L p F P
0 0 0 r
s
1 .818 .181 r
.6328 .8801 m .64878 .8886 L .63991 .95841 L p F P
0 0 0 r
s
.695 .398 .098 r
.39334 .77092 m .41395 .75919 L .41625 .84944 L p F P
0 0 0 r
s
.695 .398 .098 r
.41625 .84944 m .39632 .85549 L .39334 .77092 L p F P
0 0 0 r
s
.295 .575 .424 r
.19233 .71762 m .19573 .75699 L .19827 .71991 L p F P
0 0 0 r
s
.295 .575 .424 r
.19827 .71991 m .19495 .68025 L .19233 .71762 L p F P
0 0 0 r
s
1 .767 .167 r
.47597 .61187 m .48997 .61729 L .48671 .69974 L p F P
0 0 0 r
s
1 .754 .164 r
.50218 .7079 m .48671 .69974 L .48997 .61729 L p F P
0 0 0 r
s
.533 .965 .764 r
.71486 .29516 m .76121 .32673 L .76315 .36069 L p F P
0 0 0 r
s
.533 .965 .764 r
.76121 .32673 m .71486 .29516 L .7133 .26162 L p F P
0 0 0 r
s
.442 .842 .646 r
.19051 .83297 m .20792 .86988 L .21036 .8319 L p F P
0 0 0 r
s
.442 .842 .646 r
.21036 .8319 m .19314 .79467 L .19051 .83297 L p F P
0 0 0 r
s
.017 .035 .042 r
.20851 .60339 m .19752 .64347 L .20005 .60728 L p F P
0 0 0 r
s
.017 .035 .042 r
.20005 .60728 m .21099 .56695 L .20851 .60339 L p F P
0 0 0 r
s
.228 .111 .03 r
.5746 .56037 m .58937 .56192 L .59571 .5495 L p F P
0 0 0 r
s
.264 .143 .039 r
.58937 .56192 m .5746 .56037 L .56952 .60686 L p F P
0 0 0 r
s
.272 .149 .041 r
.55628 .61064 m .56952 .60686 L .5746 .56037 L p F P
0 0 0 r
s
.232 .129 .037 r
.55628 .61064 m .54321 .61648 L .54061 .69644 L p F P
0 0 0 r
s
.245 .137 .039 r
.529 .70627 m .54061 .69644 L .54321 .61648 L p F P
0 0 0 r
s
.095 .058 .019 r
.43716 .96849 m .4482 .96593 L .45887 .88738 L p F P
0 0 0 r
s
.121 .071 .023 r
.4684 .87622 m .45887 .88738 L .4482 .96593 L p F P
0 0 0 r
s
.513 .262 .058 r
.37339 1.02463 m .36049 1.00734 L .34502 1.00757 L p F P
0 0 0 r
s
.338 .171 .041 r
.36049 1.00734 m .37339 1.02463 L .38878 1.00422 L p F P
0 0 0 r
s
1 1 .215 r
.24407 .77997 m .26811 .75249 L .27239 .75711 L p F P
0 0 0 r
s
1 1 .215 r
.27239 .75711 m .24877 .78761 L .24407 .77997 L p F P
0 0 0 r
s
.677 .387 .095 r
.41395 .75919 m .43457 .74851 L .43629 .84337 L p F P
0 0 0 r
s
.677 .387 .095 r
.43629 .84337 m .41625 .84944 L .41395 .75919 L p F P
0 0 0 r
s
.618 .337 .08 r
.33315 .74928 m .35654 .74156 L .35888 .68934 L p F P
0 0 0 r
s
.618 .337 .08 r
.35888 .68934 m .33565 .70487 L .33315 .74928 L p F P
0 0 0 r
s
.455 .822 .676 r
.65614 .20399 m .59324 .18802 L .59264 .1554 L p F P
0 0 0 r
s
.403 .729 .611 r
.52624 .14907 m .59264 .1554 L .59324 .18802 L p F P
0 0 0 r
s
.93 .509 .109 r
.56427 .97964 m .55872 .97692 L .57144 1.03868 L p F P
0 0 0 r
s
.93 .509 .109 r
.57144 1.03868 m .57862 1.03317 L .56427 .97964 L p F P
0 0 0 r
s
.721 .432 .11 r
.29818 .88523 m .31761 .87935 L .32565 .93241 L p F P
0 0 0 r
s
.721 .432 .11 r
.32565 .93241 m .30755 .92828 L .29818 .88523 L p F P
0 0 0 r
s
1 1 .241 r
.22486 .81916 m .24877 .78761 L .25455 .80387 L p F P
0 0 0 r
s
1 1 .241 r
.25455 .80387 m .23141 .83411 L .22486 .81916 L p F P
0 0 0 r
s
.971 .551 .116 r
.49954 .68359 m .5056 .6937 L .50241 .61319 L p F P
0 0 0 r
s
.971 .551 .116 r
.50241 .61319 m .49471 .60565 L .49954 .68359 L p F P
0 0 0 r
s
1 1 .214 r
.46817 .55683 m .45538 .55747 L .46323 .53851 L p F P
0 0 0 r
s
1 .851 .184 r
.45538 .55747 m .46817 .55683 L .4618 .60851 L p F P
0 0 0 r
s
1 .823 .178 r
.47597 .61187 m .4618 .60851 L .46817 .55683 L p F P
0 0 0 r
s
.662 .378 .093 r
.43457 .74851 m .45523 .73893 L .45643 .83726 L p F P
0 0 0 r
s
.662 .378 .093 r
.45643 .83726 m .43629 .84337 L .43457 .74851 L p F P
0 0 0 r
s
.26465 .75994 m .28854 .74036 L .29186 .72626 L p F P
s
.29186 .72626 m .26811 .75249 L .26465 .75994 L p F P
s
.349 .634 .541 r
.52631 .18171 m .4589 .18543 L .45936 .1528 L p F P
0 0 0 r
s
.349 .634 .541 r
.45936 .1528 m .52624 .14907 L .52631 .18171 L p F P
0 0 0 r
s
1 1 .248 r
.20806 .86497 m .23141 .83411 L .23938 .85283 L p F P
0 0 0 r
s
1 1 .248 r
.23938 .85283 m .21721 .87807 L .20806 .86497 L p F P
0 0 0 r
s
.323 .167 .041 r
.40068 1.01367 m .38878 1.00422 L .37339 1.02463 L p F P
0 0 0 r
s
1 .724 .16 r
.56767 .84544 m .55107 .83661 L .55275 .73641 L p F P
0 0 0 r
s
1 .716 .158 r
.53518 .72623 m .55275 .73641 L .55107 .83661 L p F P
0 0 0 r
s
.569 .349 .093 r
.61972 .57519 m .60209 .56955 L .59571 .5495 L p F P
0 0 0 r
s
.569 .349 .093 r
.59571 .5495 m .61206 .55542 L .61972 .57519 L p F P
0 0 0 r
s
.229 .108 .028 r
.61206 .55542 m .59571 .5495 L .58937 .56192 L p F P
0 0 0 r
s
.633 .416 .108 r
.80118 .84501 m .77863 .8207 L .78632 .82822 L p F P
0 0 0 r
s
.251 .108 .025 r
.76363 .81458 m .78632 .82822 L .77863 .8207 L p F P
0 0 0 r
s
.059 .119 .141 r
.82047 .87898 m .84127 .84278 L .83868 .80457 L p F P
0 0 0 r
s
.833 .518 .134 r
.80118 .84501 m .82387 .86972 L .81411 .88266 L p F P
0 0 0 r
s
.436 .226 .053 r
.60964 1.04056 m .60126 1.05522 L .61619 1.06297 L p F P
0 0 0 r
s
.436 .226 .053 r
.61619 1.06297 m .62603 1.04571 L .60964 1.04056 L p F P
0 0 0 r
s
.564 .326 .082 r
.59526 .6978 m .57559 .70089 L .57158 .61958 L p F P
0 0 0 r
s
.564 .326 .082 r
.57158 .61958 m .58997 .61886 L .59526 .6978 L p F P
0 0 0 r
s
.515 .942 .734 r
.76512 .39519 m .79982 .43175 L .80208 .46664 L p F P
0 0 0 r
s
.515 .942 .734 r
.79982 .43175 m .76512 .39519 L .76315 .36069 L p F P
0 0 0 r
s
.649 .37 .091 r
.45523 .73893 m .47592 .7305 L .47668 .83112 L p F P
0 0 0 r
s
.649 .37 .091 r
.47668 .83112 m .45643 .83726 L .45523 .73893 L p F P
0 0 0 r
s
.79 .452 .094 r
.53809 .88126 m .53406 .86902 L .54153 .96241 L p F P
0 0 0 r
s
.79 .452 .094 r
.54153 .96241 m .54734 .96841 L .53809 .88126 L p F P
0 0 0 r
s
.403 .729 .611 r
.59324 .18802 m .52631 .18171 L .52624 .14907 L p F P
0 0 0 r
s
.181 .337 .311 r
.33245 .32217 m .28287 .35194 L .28473 .31795 L p F P
0 0 0 r
s
.181 .337 .311 r
.28473 .31795 m .33393 .28807 L .33245 .32217 L p F P
0 0 0 r
s
.502 .907 .732 r
.65725 .23708 m .7133 .26162 L .71486 .29516 L p F P
0 0 0 r
s
.502 .907 .732 r
.7133 .26162 m .65725 .23708 L .65614 .20399 L p F P
0 0 0 r
s
.741 .434 .09 r
.51986 .73105 m .51751 .71724 L .51751 .81875 L p F P
0 0 0 r
s
.741 .434 .09 r
.51751 .81875 m .52171 .83152 L .51986 .73105 L p F P
0 0 0 r
s
.993 .547 .117 r
.47897 .59665 m .48691 .60016 L .48063 .55261 L p F P
0 0 0 r
s
.993 .547 .117 r
.48063 .55261 m .47105 .55215 L .47897 .59665 L p F P
0 0 0 r
s
.118 .072 .024 r
.49757 .84208 m .50749 .83047 L .50934 .73024 L p F P
0 0 0 r
s
.128 .078 .025 r
.51751 .71724 m .50934 .73024 L .50749 .83047 L p F P
0 0 0 r
s
.455 .822 .676 r
.59324 .18802 m .65614 .20399 L .65725 .23708 L p F P
0 0 0 r
s
1 .818 .181 r
.63991 .95841 m .62524 .95821 L .6328 .8801 L p F P
0 0 0 r
s
1 .798 .176 r
.6167 .87153 m .6328 .8801 L .62524 .95821 L p F P
0 0 0 r
s
1 .879 .186 r
.64291 1.01054 m .6557 1.00075 L .64146 1.03193 L p F P
0 0 0 r
s
1 .978 .212 r
.6557 1.00075 m .64291 1.01054 L .65438 .9578 L p F P
0 0 0 r
s
.035 .07 .083 r
.84317 .72792 m .83613 .76697 L .83868 .80457 L p F P
0 0 0 r
s
.035 .07 .083 r
.83613 .76697 m .84317 .72792 L .84056 .69063 L p F P
0 0 0 r
s
.386 .722 .553 r
.80437 .50208 m .82578 .54153 L .82824 .57733 L p F P
0 0 0 r
s
.386 .722 .553 r
.82578 .54153 m .80437 .50208 L .80208 .46664 L p F P
0 0 0 r
s
.255 .486 .348 r
.83075 .61371 m .838 .65392 L .84056 .69063 L p F P
0 0 0 r
s
.255 .486 .348 r
.838 .65392 m .83075 .61371 L .82824 .57733 L p F P
0 0 0 r
s
.686 .406 .103 r
.31761 .87935 m .33713 .87343 L .34396 .93602 L p F P
0 0 0 r
s
.686 .406 .103 r
.34396 .93602 m .32565 .93241 L .31761 .87935 L p F P
0 0 0 r
s
.524 .285 .068 r
.30964 .75784 m .33315 .74928 L .33565 .70487 L p F P
0 0 0 r
s
.524 .285 .068 r
.33565 .70487 m .31221 .72194 L .30964 .75784 L p F P
0 0 0 r
s
.542 .331 .088 r
.30755 .92828 m .32565 .93241 L .3352 .9787 L p F P
0 0 0 r
s
.542 .331 .088 r
.3352 .9787 m .31845 .96588 L .30755 .92828 L p F P
0 0 0 r
s
.538 .318 .082 r
.62744 .62345 m .60858 .62018 L .60209 .56955 L p F P
0 0 0 r
s
.538 .318 .082 r
.60209 .56955 m .61972 .57519 L .62744 .62345 L p F P
0 0 0 r
s
.638 .363 .089 r
.47592 .7305 m .49668 .72326 L .49704 .82495 L p F P
0 0 0 r
s
.638 .363 .089 r
.49704 .82495 m .47668 .83112 L .47592 .7305 L p F P
0 0 0 r
s
.876 .463 .102 r
.58567 1.02622 m .57862 1.03317 L .59269 1.06842 L p F P
0 0 0 r
s
.876 .463 .102 r
.59269 1.06842 m .60126 1.05522 L .58567 1.02622 L p F P
0 0 0 r
s
1 .921 .2 r
.63991 .95841 m .65438 .9578 L .64291 1.01054 L p F P
0 0 0 r
s
.404 .205 .043 r
.35916 1.02775 m .34502 1.00757 L .33095 .99338 L p F P
0 0 0 r
s
.513 .262 .058 r
.34502 1.00757 m .35916 1.02775 L .37339 1.02463 L p F P
0 0 0 r
s
1 .716 .158 r
.55107 .83661 m .53435 .82771 L .53518 .72623 L p F P
0 0 0 r
s
1 .708 .156 r
.51751 .71724 m .53518 .72623 L .53435 .82771 L p F P
0 0 0 r
s
.293 .536 .468 r
.45842 .21858 m .39364 .23208 L .39462 .19897 L p F P
0 0 0 r
s
.293 .536 .468 r
.39462 .19897 m .4589 .18543 L .45842 .21858 L p F P
0 0 0 r
s
1 .672 .17 r
.82387 .86972 m .80118 .84501 L .80907 .84219 L p F P
0 0 0 r
s
.633 .416 .108 r
.78632 .82822 m .80907 .84219 L .80118 .84501 L p F P
0 0 0 r
s
.121 .071 .023 r
.4482 .96593 m .45939 .96229 L .4684 .87622 L p F P
0 0 0 r
s
.141 .082 .025 r
.47803 .86495 m .4684 .87622 L .45939 .96229 L p F P
0 0 0 r
s
.177 .092 .026 r
.40068 1.01367 m .41281 1.02196 L .42627 .97009 L p F P
0 0 0 r
s
.19 .1 .029 r
.43716 .96849 m .42627 .97009 L .41281 1.02196 L p F P
0 0 0 r
s
1 .783 .171 r
.4618 .60851 m .47597 .61187 L .47109 .69273 L p F P
0 0 0 r
s
1 .767 .167 r
.48671 .69974 m .47109 .69273 L .47597 .61187 L p F P
0 0 0 r
s
.237 .439 .392 r
.39264 .26572 m .33393 .28807 L .33539 .2545 L p F P
0 0 0 r
s
.237 .439 .392 r
.33539 .2545 m .39364 .23208 L .39264 .26572 L p F P
0 0 0 r
s
1 1 .228 r
.21975 .80843 m .24407 .77997 L .24877 .78761 L p F P
0 0 0 r
s
1 1 .228 r
.24877 .78761 m .22486 .81916 L .21975 .80843 L p F P
0 0 0 r
s
1 1 .24 r
.20068 .85143 m .22486 .81916 L .23141 .83411 L p F P
0 0 0 r
s
1 1 .24 r
.23141 .83411 m .20806 .86497 L .20068 .85143 L p F P
0 0 0 r
s
.219 .12 .035 r
.56952 .60686 m .55628 .61064 L .55236 .68774 L p F P
0 0 0 r
s
.232 .129 .037 r
.54061 .69644 m .55236 .68774 L .55628 .61064 L p F P
0 0 0 r
s
.912 .502 .116 r
.62891 .74632 m .60663 .73816 L .60977 .8256 L p F P
0 0 0 r
s
.928 .512 .118 r
.60663 .73816 m .58436 .73114 L .58676 .82389 L p F P
0 0 0 r
s
.928 .512 .118 r
.58676 .82389 m .60977 .8256 L .60663 .73816 L p F P
0 0 0 r
s
.893 .49 .113 r
.65122 .75554 m .62891 .74632 L .63275 .8273 L p F P
0 0 0 r
s
.912 .502 .116 r
.60977 .8256 m .63275 .8273 L .62891 .74632 L p F P
0 0 0 r
s
.62603 1.04571 m .61619 1.06297 L .63015 1.04743 L p F P
s
.63015 1.04743 m .64146 1.03193 L .62603 1.04571 L p F P
s
.941 .521 .12 r
.58436 .73114 m .5621 .72528 L .56371 .82218 L p F P
0 0 0 r
s
.941 .521 .12 r
.56371 .82218 m .58676 .82389 L .58436 .73114 L p F P
0 0 0 r
s
.119 .219 .218 r
.27906 .42158 m .24073 .4568 L .24293 .42187 L p F P
0 0 0 r
s
.119 .219 .218 r
.24293 .42187 m .28098 .38648 L .27906 .42158 L p F P
0 0 0 r
s
.868 .474 .109 r
.67358 .76575 m .65122 .75554 L .6557 .82901 L p F P
0 0 0 r
s
.893 .49 .113 r
.63275 .8273 m .6557 .82901 L .65122 .75554 L p F P
0 0 0 r
s
.128 .078 .025 r
.50749 .83047 m .51751 .81875 L .51751 .71724 L p F P
0 0 0 r
s
.627 .356 .087 r
.49668 .72326 m .51751 .71724 L .51751 .81875 L p F P
0 0 0 r
s
.627 .356 .087 r
.51751 .81875 m .49704 .82495 L .49668 .72326 L p F P
0 0 0 r
s
.244 .158 .047 r
.31845 .96588 m .3352 .9787 L .34638 1.01193 L p F P
0 0 0 r
s
.244 .158 .047 r
.34638 1.01193 m .33095 .99338 L .31845 .96588 L p F P
0 0 0 r
s
.593 .306 .066 r
.46129 .55418 m .47105 .55215 L .46323 .53851 L p F P
0 0 0 r
s
1 1 .213 r
.45182 .54215 m .46323 .53851 L .45538 .55747 L p F P
0 0 0 r
s
.593 .306 .066 r
.46323 .53851 m .45182 .54215 L .46129 .55418 L p F P
0 0 0 r
s
.663 .388 .098 r
.33713 .87343 m .35676 .86748 L .36247 .93897 L p F P
0 0 0 r
s
.663 .388 .098 r
.36247 .93897 m .34396 .93602 L .33713 .87343 L p F P
0 0 0 r
s
1 .879 .186 r
.64146 1.03193 m .63015 1.04743 L .64291 1.01054 L p F P
0 0 0 r
s
.856 .543 .118 r
.26811 .75249 m .24407 .77997 L .24051 .78045 L p F P
0 0 0 r
s
.856 .543 .118 r
.24051 .78045 m .26465 .75994 L .26811 .75249 L p F P
0 0 0 r
s
.953 .529 .122 r
.5621 .72528 m .53982 .72064 L .54062 .82046 L p F P
0 0 0 r
s
.953 .529 .122 r
.54062 .82046 m .56371 .82218 L .5621 .72528 L p F P
0 0 0 r
s
.834 .453 .104 r
.69599 .77686 m .67358 .76575 L .67862 .83071 L p F P
0 0 0 r
s
.868 .474 .109 r
.6557 .82901 m .67862 .83071 L .67358 .76575 L p F P
0 0 0 r
s
.404 .205 .043 r
.33095 .99338 m .34638 1.01193 L .35916 1.02775 L p F P
0 0 0 r
s
.229 .108 .028 r
.58937 .56192 m .6044 .56598 L .61206 .55542 L p F P
0 0 0 r
s
.257 .137 .038 r
.6044 .56598 m .58937 .56192 L .58296 .60509 L p F P
0 0 0 r
s
.264 .143 .039 r
.56952 .60686 m .58296 .60509 L .58937 .56192 L p F P
0 0 0 r
s
1 .798 .176 r
.62524 .95821 m .61037 .95706 L .6167 .87153 L p F P
0 0 0 r
s
1 .781 .172 r
.60048 .8629 m .6167 .87153 L .61037 .95706 L p F P
0 0 0 r
s
.787 .424 .097 r
.71847 .78878 m .69599 .77686 L .7015 .83241 L p F P
0 0 0 r
s
.834 .453 .104 r
.67862 .83071 m .7015 .83241 L .69599 .77686 L p F P
0 0 0 r
s
1 .708 .156 r
.53435 .82771 m .51751 .81875 L .51751 .71724 L p F P
0 0 0 r
s
.964 .536 .124 r
.53982 .72064 m .51751 .71724 L .51751 .81875 L p F P
0 0 0 r
s
.964 .536 .124 r
.51751 .81875 m .54062 .82046 L .53982 .72064 L p F P
0 0 0 r
s
.57 .331 .083 r
.6151 .69582 m .59526 .6978 L .58997 .61886 L p F P
0 0 0 r
s
.57 .331 .083 r
.58997 .61886 m .60858 .62018 L .6151 .69582 L p F P
0 0 0 r
s
.391 .209 .051 r
.28598 .76711 m .30964 .75784 L .31221 .72194 L p F P
0 0 0 r
s
.391 .209 .051 r
.31221 .72194 m .28854 .74036 L .28598 .76711 L p F P
0 0 0 r
s
.047 .094 .112 r
.23621 .52837 m .21099 .56695 L .21343 .53109 L p F P
0 0 0 r
s
.047 .094 .112 r
.21343 .53109 m .23849 .4923 L .23621 .52837 L p F P
0 0 0 r
s
.295 .575 .424 r
.18968 .7556 m .19314 .79467 L .19573 .75699 L p F P
0 0 0 r
s
.295 .575 .424 r
.19573 .75699 m .19233 .71762 L .18968 .7556 L p F P
0 0 0 r
s
.947 .535 .113 r
.49339 .67455 m .49954 .68359 L .49471 .60565 L p F P
0 0 0 r
s
.947 .535 .113 r
.49471 .60565 m .48691 .60016 L .49339 .67455 L p F P
0 0 0 r
s
.533 .965 .764 r
.71646 .32924 m .76315 .36069 L .76512 .39519 L p F P
0 0 0 r
s
.533 .965 .764 r
.76315 .36069 m .71646 .32924 L .71486 .29516 L p F P
0 0 0 r
s
.017 .035 .042 r
.20598 .64043 m .19495 .68025 L .19752 .64347 L p F P
0 0 0 r
s
.017 .035 .042 r
.19752 .64347 m .20851 .60339 L .20598 .64043 L p F P
0 0 0 r
s
1 .672 .17 r
.80907 .84219 m .8319 .85633 L .82387 .86972 L p F P
0 0 0 r
s
.946 .523 .112 r
.55872 .97692 m .55307 .97321 L .56412 1.0425 L p F P
0 0 0 r
s
.946 .523 .112 r
.56412 1.0425 m .57144 1.03868 L .55872 .97692 L p F P
0 0 0 r
s
.715 .381 .088 r
.74101 .80139 m .71847 .78878 L .72435 .8341 L p F P
0 0 0 r
s
.787 .424 .097 r
.7015 .83241 m .72435 .8341 L .71847 .78878 L p F P
0 0 0 r
s
.811 .466 .097 r
.53406 .86902 m .52999 .85666 L .53564 .95512 L p F P
0 0 0 r
s
.811 .466 .097 r
.53564 .95512 m .54153 .96241 L .53406 .86902 L p F P
0 0 0 r
s
.581 .332 .082 r
.53808 .81251 m .51751 .81875 L .51751 .71724 L p F P
0 0 0 r
s
.581 .332 .082 r
.51751 .71724 m .53673 .71059 L .53808 .81251 L p F P
0 0 0 r
s
.192 .107 .033 r
.529 .70627 m .51751 .71724 L .51751 .81875 L p F P
0 0 0 r
s
.92 .512 .119 r
.49436 .81703 m .51751 .81875 L .51751 .71724 L p F P
0 0 0 r
s
.92 .512 .119 r
.51751 .71724 m .49469 .71715 L .49436 .81703 L p F P
0 0 0 r
s
1 .726 .159 r
.50218 .7079 m .51751 .71724 L .51751 .81875 L p F P
0 0 0 r
s
1 .726 .159 r
.51751 .81875 m .50053 .80971 L .50218 .7079 L p F P
0 0 0 r
s
.879 .507 .107 r
.51325 .80583 m .51751 .81875 L .51751 .71724 L p F P
0 0 0 r
s
.879 .507 .107 r
.51751 .71724 m .51159 .70491 L .51325 .80583 L p F P
0 0 0 r
s
.908 .504 .117 r
.47117 .81531 m .49436 .81703 L .49469 .71715 L p F P
0 0 0 r
s
.908 .504 .117 r
.49469 .71715 m .47185 .71831 L .47117 .81531 L p F P
0 0 0 r
s
.455 .822 .676 r
.65725 .23708 m .59385 .22117 L .59324 .18802 L p F P
0 0 0 r
s
.403 .729 .611 r
.52631 .18171 m .59324 .18802 L .59385 .22117 L p F P
0 0 0 r
s
1 1 .213 r
.45538 .55747 m .44236 .56061 L .45182 .54215 L p F P
0 0 0 r
s
1 .883 .191 r
.44236 .56061 m .45538 .55747 L .44741 .60717 L p F P
0 0 0 r
s
1 .851 .184 r
.4618 .60851 m .44741 .60717 L .45538 .55747 L p F P
0 0 0 r
s
.646 .376 .094 r
.35676 .86748 m .37648 .8615 L .3812 .94111 L p F P
0 0 0 r
s
.646 .376 .094 r
.3812 .94111 m .36247 .93897 L .35676 .86748 L p F P
0 0 0 r
s
.588 .309 .071 r
.76363 .81458 m .74101 .80139 L .74717 .8358 L p F P
0 0 0 r
s
.715 .381 .088 r
.72435 .8341 m .74717 .8358 L .74101 .80139 L p F P
0 0 0 r
s
.556 .335 .088 r
.32565 .93241 m .34396 .93602 L .35224 .99064 L p F P
0 0 0 r
s
.556 .335 .088 r
.35224 .99064 m .3352 .9787 L .32565 .93241 L p F P
0 0 0 r
s
.893 .495 .115 r
.44795 .81358 m .47117 .81531 L .47185 .71831 L p F P
0 0 0 r
s
.893 .495 .115 r
.47185 .71831 m .44895 .72068 L .44795 .81358 L p F P
0 0 0 r
s
.349 .634 .541 r
.52638 .21487 m .45842 .21858 L .4589 .18543 L p F P
0 0 0 r
s
.349 .634 .541 r
.4589 .18543 m .52631 .18171 L .52638 .21487 L p F P
0 0 0 r
s
.525 .328 .088 r
.63766 .58322 m .61972 .57519 L .61206 .55542 L p F P
0 0 0 r
s
.525 .328 .088 r
.61206 .55542 m .62872 .56392 L .63766 .58322 L p F P
0 0 0 r
s
.234 .106 .026 r
.62872 .56392 m .61206 .55542 L .6044 .56598 L p F P
0 0 0 r
s
.488 .249 .056 r
.38659 1.04085 m .37339 1.02463 L .35916 1.02775 L p F P
0 0 0 r
s
.323 .167 .041 r
.37339 1.02463 m .38659 1.04085 L .40068 1.01367 L p F P
0 0 0 r
s
.141 .082 .025 r
.45939 .96229 m .47073 .95747 L .47803 .86495 L p F P
0 0 0 r
s
.157 .09 .028 r
.48775 .85357 m .47803 .86495 L .47073 .95747 L p F P
0 0 0 r
s
.284 .13 .029 r
.78632 .82822 m .76363 .81458 L .76995 .83749 L p F P
0 0 0 r
s
.588 .309 .071 r
.74717 .8358 m .76995 .83749 L .76363 .81458 L p F P
0 0 0 r
s
.311 .163 .041 r
.41281 1.02196 m .40068 1.01367 L .38659 1.04085 L p F P
0 0 0 r
s
.875 .484 .112 r
.4247 .81186 m .44795 .81358 L .44895 .72068 L p F P
0 0 0 r
s
.875 .484 .112 r
.44895 .72068 m .42599 .72425 L .4247 .81186 L p F P
0 0 0 r
s
.515 .942 .734 r
.76713 .43025 m .80208 .46664 L .80437 .50208 L p F P
0 0 0 r
s
.515 .942 .734 r
.80208 .46664 m .76713 .43025 L .76512 .39519 L p F P
0 0 0 r
s
1 1 .234 r
.19515 .83753 m .21975 .80843 L .22486 .81916 L p F P
0 0 0 r
s
1 1 .234 r
.22486 .81916 m .20068 .85143 L .19515 .83753 L p F P
0 0 0 r
s
1 .921 .2 r
.64291 1.01054 m .62987 1.01916 L .63991 .95841 L p F P
0 0 0 r
s
1 .878 .191 r
.62524 .95821 m .63991 .95841 L .62987 1.01916 L p F P
0 0 0 r
s
.958 .522 .112 r
.4709 .59502 m .47897 .59665 L .47105 .55215 L p F P
0 0 0 r
s
.958 .522 .112 r
.47105 .55215 m .46129 .55418 L .4709 .59502 L p F P
0 0 0 r
s
.403 .729 .611 r
.59385 .22117 m .52638 .21487 L .52631 .18171 L p F P
0 0 0 r
s
.181 .337 .311 r
.33094 .35684 m .28098 .38648 L .28287 .35194 L p F P
0 0 0 r
s
.181 .337 .311 r
.28287 .35194 m .33245 .32217 L .33094 .35684 L p F P
0 0 0 r
s
.502 .907 .732 r
.65838 .27071 m .71486 .29516 L .71646 .32924 L p F P
0 0 0 r
s
.502 .907 .732 r
.71486 .29516 m .65838 .27071 L .65725 .23708 L p F P
0 0 0 r
s
1 .781 .172 r
.61037 .95706 m .59533 .95485 L .60048 .8629 L p F P
0 0 0 r
s
1 .767 .169 r
.58413 .8542 m .60048 .8629 L .59533 .95485 L p F P
0 0 0 r
s
.538 .321 .083 r
.64658 .62856 m .62744 .62345 L .61972 .57519 L p F P
0 0 0 r
s
.538 .321 .083 r
.61972 .57519 m .63766 .58322 L .64658 .62856 L p F P
0 0 0 r
s
.203 .097 .025 r
.26218 .77699 m .28598 .76711 L .28854 .74036 L p F P
0 0 0 r
s
.203 .097 .025 r
.28854 .74036 m .26465 .75994 L .26218 .77699 L p F P
0 0 0 r
s
.532 .373 .089 r
.80907 .84219 m .78632 .82822 L .7927 .83918 L p F P
0 0 0 r
s
.284 .13 .029 r
.76995 .83749 m .7927 .83918 L .78632 .82822 L p F P
0 0 0 r
s
.455 .822 .676 r
.59385 .22117 m .65725 .23708 L .65838 .27071 L p F P
0 0 0 r
s
1 .8 .174 r
.44741 .60717 m .4618 .60851 L .45531 .68685 L p F P
0 0 0 r
s
1 .783 .171 r
.47109 .69273 m .45531 .68685 L .4618 .60851 L p F P
0 0 0 r
s
.591 .338 .083 r
.55877 .80624 m .53808 .81251 L .53673 .71059 L p F P
0 0 0 r
s
.591 .338 .083 r
.53673 .71059 m .55609 .70515 L .55877 .80624 L p F P
0 0 0 r
s
1 .864 .184 r
.21614 .80167 m .24051 .78045 L .24407 .77997 L p F P
0 0 0 r
s
1 .864 .184 r
.24407 .77997 m .21975 .80843 L .21614 .80167 L p F P
0 0 0 r
s
.633 .367 .091 r
.37648 .8615 m .39632 .85549 L .40013 .94232 L p F P
0 0 0 r
s
.633 .367 .091 r
.40013 .94232 m .3812 .94111 L .37648 .8615 L p F P
0 0 0 r
s
.035 .07 .083 r
.84582 .76583 m .83868 .80457 L .84127 .84278 L p F P
0 0 0 r
s
.035 .07 .083 r
.83868 .80457 m .84582 .76583 L .84317 .72792 L p F P
0 0 0 r
s
.386 .722 .553 r
.8067 .53811 m .82824 .57733 L .83075 .61371 L p F P
0 0 0 r
s
.386 .722 .553 r
.82824 .57733 m .8067 .53811 L .80437 .50208 L p F P
0 0 0 r
s
.854 .471 .109 r
.40141 .81013 m .4247 .81186 L .42599 .72425 L p F P
0 0 0 r
s
.854 .471 .109 r
.42599 .72425 m .40294 .72896 L .40141 .81013 L p F P
0 0 0 r
s
.255 .486 .348 r
.8333 .65068 m .84056 .69063 L .84317 .72792 L p F P
0 0 0 r
s
.255 .486 .348 r
.84056 .69063 m .8333 .65068 L .83075 .61371 L p F P
0 0 0 r
s
1 .942 .2 r
.62987 1.01916 m .64291 1.01054 L .63015 1.04743 L p F P
0 0 0 r
s
.19 .1 .029 r
.41281 1.02196 m .42517 1.02882 L .43716 .96849 L p F P
0 0 0 r
s
.199 .106 .031 r
.4482 .96593 m .43716 .96849 L .42517 1.02882 L p F P
0 0 0 r
s
.206 .112 .033 r
.58296 .60509 m .56952 .60686 L .56424 .68013 L p F P
0 0 0 r
s
.219 .12 .035 r
.55236 .68774 m .56424 .68013 L .56952 .60686 L p F P
0 0 0 r
s
.5 .259 .059 r
.60126 1.05522 m .59269 1.06842 L .60611 1.07869 L p F P
0 0 0 r
s
.5 .259 .059 r
.60611 1.07869 m .61619 1.06297 L .60126 1.05522 L p F P
0 0 0 r
s
1 .735 .161 r
.48671 .69974 m .50218 .7079 L .50053 .80971 L p F P
0 0 0 r
s
1 .966 .23 r
.8319 .85633 m .80907 .84219 L .81541 .84087 L p F P
0 0 0 r
s
.532 .373 .089 r
.7927 .83918 m .81541 .84087 L .80907 .84219 L p F P
0 0 0 r
s
.575 .335 .085 r
.63514 .6949 m .6151 .69582 L .60858 .62018 L p F P
0 0 0 r
s
.575 .335 .085 r
.60858 .62018 m .62744 .62345 L .63514 .6949 L p F P
0 0 0 r
s
.826 .454 .106 r
.37809 .80839 m .40141 .81013 L .40294 .72896 L p F P
0 0 0 r
s
.826 .454 .106 r
.40294 .72896 m .37979 .73475 L .37809 .80839 L p F P
0 0 0 r
s
.293 .536 .468 r
.45795 .25228 m .39264 .26572 L .39364 .23208 L p F P
0 0 0 r
s
.293 .536 .468 r
.39364 .23208 m .45842 .21858 L .45795 .25228 L p F P
0 0 0 r
s
.182 .102 .031 r
.54061 .69644 m .529 .70627 L .52763 .8069 L p F P
0 0 0 r
s
.192 .107 .033 r
.51751 .81875 m .52763 .8069 L .529 .70627 L p F P
0 0 0 r
s
.952 .509 .111 r
.57862 1.03317 m .57144 1.03868 L .58391 1.07982 L p F P
0 0 0 r
s
.952 .509 .111 r
.58391 1.07982 m .59269 1.06842 L .57862 1.03317 L p F P
0 0 0 r
s
.237 .439 .392 r
.39162 .29991 m .33245 .32217 L .33393 .28807 L p F P
0 0 0 r
s
.237 .439 .392 r
.33393 .28807 m .39264 .26572 L .39162 .29991 L p F P
0 0 0 r
s
.833 .479 .1 r
.52999 .85666 m .52588 .84416 L .52967 .94645 L p F P
0 0 0 r
s
.833 .479 .1 r
.52967 .94645 m .53564 .95512 L .52999 .85666 L p F P
0 0 0 r
s
.85 .49 .103 r
.50895 .79277 m .51325 .80583 L .51159 .70491 L p F P
0 0 0 r
s
.85 .49 .103 r
.51159 .70491 m .5056 .6937 L .50895 .79277 L p F P
0 0 0 r
s
.488 .249 .056 r
.35916 1.02775 m .37363 1.04679 L .38659 1.04085 L p F P
0 0 0 r
s
.354 .223 .062 r
.3352 .9787 m .35224 .99064 L .36213 1.0294 L p F P
0 0 0 r
s
.354 .223 .062 r
.36213 1.0294 m .34638 1.01193 L .3352 .9787 L p F P
0 0 0 r
s
1 .966 .23 r
.81541 .84087 m .8381 .84255 L .8319 .85633 L p F P
0 0 0 r
s
.119 .219 .218 r
.27711 .45725 m .23849 .4923 L .24073 .4568 L p F P
0 0 0 r
s
.119 .219 .218 r
.24073 .4568 m .27906 .42158 L .27711 .45725 L p F P
0 0 0 r
s
.623 .359 .089 r
.39632 .85549 m .41625 .84944 L .41926 .9425 L p F P
0 0 0 r
s
.623 .359 .089 r
.41926 .9425 m .40013 .94232 L .39632 .85549 L p F P
0 0 0 r
s
.559 .333 .086 r
.34396 .93602 m .36247 .93897 L .36956 1.00142 L p F P
0 0 0 r
s
.559 .333 .086 r
.36956 1.00142 m .35224 .99064 L .34396 .93602 L p F P
0 0 0 r
s
.318 .155 .033 r
.37363 1.04679 m .35916 1.02775 L .34638 1.01193 L p F P
0 0 0 r
s
.925 .52 .11 r
.48717 .66655 m .49339 .67455 L .48691 .60016 L p F P
0 0 0 r
s
.925 .52 .11 r
.48691 .60016 m .47897 .59665 L .48717 .66655 L p F P
0 0 0 r
s
1 .767 .169 r
.59533 .95485 m .58009 .95147 L .58413 .8542 L p F P
0 0 0 r
s
1 .755 .166 r
.56767 .84544 m .58413 .8542 L .58009 .95147 L p F P
0 0 0 r
s
.234 .106 .026 r
.6044 .56598 m .61972 .57242 L .62872 .56392 L p F P
0 0 0 r
s
.252 .131 .036 r
.61972 .57242 m .6044 .56598 L .59661 .60523 L p F P
0 0 0 r
s
.257 .137 .038 r
.58296 .60509 m .59661 .60523 L .6044 .56598 L p F P
0 0 0 r
s
.791 .433 .101 r
.35474 .80666 m .37809 .80839 L .37979 .73475 L p F P
0 0 0 r
s
.791 .433 .101 r
.37979 .73475 m .35654 .74156 L .35474 .80666 L p F P
0 0 0 r
s
.491 .249 .054 r
.45133 .55856 m .46129 .55418 L .45182 .54215 L p F P
0 0 0 r
s
1 .912 .193 r
.44018 .54835 m .45182 .54215 L .44236 .56061 L p F P
0 0 0 r
s
.491 .249 .054 r
.45182 .54215 m .44018 .54835 L .45133 .55856 L p F P
0 0 0 r
s
.6 .343 .085 r
.57956 .79994 m .55877 .80624 L .55609 .70515 L p F P
0 0 0 r
s
.6 .343 .085 r
.55609 .70515 m .57559 .70089 L .57956 .79994 L p F P
0 0 0 r
s
.957 .534 .113 r
.55307 .97321 m .54734 .96841 L .55666 1.0444 L p F P
0 0 0 r
s
.957 .534 .113 r
.55666 1.0444 m .56412 1.0425 L .55307 .97321 L p F P
0 0 0 r
s
.157 .09 .028 r
.47073 .95747 m .48223 .95138 L .48775 .85357 L p F P
0 0 0 r
s
.17 .096 .03 r
.49757 .84208 m .48775 .85357 L .48223 .95138 L p F P
0 0 0 r
s
.23823 .78735 m .26218 .77699 L .26465 .75994 L p F P
s
.26465 .75994 m .24051 .78045 L .23823 .78735 L p F P
s
.047 .094 .112 r
.2339 .56504 m .20851 .60339 L .21099 .56695 L p F P
0 0 0 r
s
.047 .094 .112 r
.21099 .56695 m .23621 .52837 L .2339 .56504 L p F P
0 0 0 r
s
.318 .155 .033 r
.34638 1.01193 m .36213 1.0294 L .37363 1.04679 L p F P
0 0 0 r
s
.295 .575 .424 r
.18698 .79421 m .19051 .83297 L .19314 .79467 L p F P
0 0 0 r
s
.295 .575 .424 r
.19314 .79467 m .18968 .7556 L .18698 .79421 L p F P
0 0 0 r
s
.533 .965 .764 r
.71807 .36388 m .76512 .39519 L .76713 .43025 L p F P
0 0 0 r
s
.533 .965 .764 r
.76512 .39519 m .71807 .36388 L .71646 .32924 L p F P
0 0 0 r
s
.017 .035 .042 r
.20342 .67807 m .19233 .71762 L .19495 .68025 L p F P
0 0 0 r
s
.017 .035 .042 r
.19495 .68025 m .20598 .64043 L .20342 .67807 L p F P
0 0 0 r
s
.61858 1.06148 m .63015 1.04743 L .61619 1.06297 L p F P
s
1 .942 .2 r
.63015 1.04743 m .61858 1.06148 L .62987 1.01916 L p F P
0 0 0 r
s
.61619 1.06297 m .60611 1.07869 L .61858 1.06148 L p F P
s
1 .878 .191 r
.62987 1.01916 m .61659 1.02636 L .62524 .95821 L p F P
0 0 0 r
s
1 .845 .184 r
.61037 .95706 m .62524 .95821 L .61659 1.02636 L p F P
0 0 0 r
s
1 1 .232 r
.19154 .82334 m .21614 .80167 L .21975 .80843 L p F P
0 0 0 r
s
1 1 .232 r
.21975 .80843 m .19515 .83753 L .19154 .82334 L p F P
0 0 0 r
s
.743 .405 .094 r
.33135 .80492 m .35474 .80666 L .35654 .74156 L p F P
0 0 0 r
s
.743 .405 .094 r
.35654 .74156 m .33315 .74928 L .33135 .80492 L p F P
0 0 0 r
s
.614 .353 .088 r
.41625 .84944 m .43629 .84337 L .43857 .94154 L p F P
0 0 0 r
s
.614 .353 .088 r
.43857 .94154 m .41926 .9425 L .41625 .84944 L p F P
0 0 0 r
s
1 .912 .193 r
.44236 .56061 m .42908 .56611 L .44018 .54835 L p F P
0 0 0 r
s
1 .92 .198 r
.42908 .56611 m .44236 .56061 L .43281 .60775 L p F P
0 0 0 r
s
1 .883 .191 r
.44741 .60717 m .43281 .60775 L .44236 .56061 L p F P
0 0 0 r
s
.455 .822 .676 r
.65838 .27071 m .59447 .25485 L .59385 .22117 L p F P
0 0 0 r
s
.403 .729 .611 r
.52638 .21487 m .59385 .22117 L .59447 .25485 L p F P
0 0 0 r
s
1 .745 .163 r
.47109 .69273 m .48671 .69974 L .48342 .80061 L p F P
0 0 0 r
s
1 .735 .161 r
.50053 .80971 m .48342 .80061 L .48671 .69974 L p F P
0 0 0 r
s
.349 .634 .541 r
.52645 .24857 m .45795 .25228 L .45842 .21858 L p F P
0 0 0 r
s
.349 .634 .541 r
.45842 .21858 m .52638 .21487 L .52645 .24857 L p F P
0 0 0 r
s
.433 .279 .076 r
.65594 .59348 m .63766 .58322 L .62872 .56392 L p F P
0 0 0 r
s
.433 .279 .076 r
.62872 .56392 m .64573 .57484 L .65594 .59348 L p F P
0 0 0 r
s
.242 .107 .025 r
.64573 .57484 m .62872 .56392 L .61972 .57242 L p F P
0 0 0 r
s
1 .822 .179 r
.43281 .60775 m .44741 .60717 L .43935 .68205 L p F P
0 0 0 r
s
1 .8 .174 r
.45531 .68685 m .43935 .68205 L .44741 .60717 L p F P
0 0 0 r
s
.199 .106 .031 r
.42517 1.02882 m .43776 1.034 L .4482 .96593 L p F P
0 0 0 r
s
.207 .111 .033 r
.45939 .96229 m .4482 .96593 L .43776 1.034 L p F P
0 0 0 r
s
.17 .096 .03 r
.55236 .68774 m .54061 .69644 L .53785 .79494 L p F P
0 0 0 r
s
.182 .102 .031 r
.52763 .8069 m .53785 .79494 L .54061 .69644 L p F P
0 0 0 r
s
.609 .349 .087 r
.60046 .7936 m .57956 .79994 L .57559 .70089 L p F P
0 0 0 r
s
.609 .349 .087 r
.57559 .70089 m .59526 .6978 L .60046 .7936 L p F P
0 0 0 r
s
1 .755 .166 r
.58009 .95147 m .56469 .94684 L .56767 .84544 L p F P
0 0 0 r
s
1 .745 .163 r
.55107 .83661 m .56767 .84544 L .56469 .94684 L p F P
0 0 0 r
s
.311 .163 .041 r
.38659 1.04085 m .40007 1.05561 L .41281 1.02196 L p F P
0 0 0 r
s
.301 .16 .041 r
.42517 1.02882 m .41281 1.02196 L .40007 1.05561 L p F P
0 0 0 r
s
.515 .942 .734 r
.76917 .46588 m .80437 .50208 L .8067 .53811 L p F P
0 0 0 r
s
.515 .942 .734 r
.80437 .50208 m .76917 .46588 L .76713 .43025 L p F P
0 0 0 r
s
.197 .106 .031 r
.59661 .60523 m .58296 .60509 L .57628 .67359 L p F P
0 0 0 r
s
.206 .112 .033 r
.56424 .68013 m .57628 .67359 L .58296 .60509 L p F P
0 0 0 r
s
.58 .34 .086 r
.65539 .69498 m .63514 .6949 L .62744 .62345 L p F P
0 0 0 r
s
.58 .34 .086 r
.62744 .62345 m .64658 .62856 L .65539 .69498 L p F P
0 0 0 r
s
.536 .322 .084 r
.66601 .63538 m .64658 .62856 L .63766 .58322 L p F P
0 0 0 r
s
.536 .322 .084 r
.63766 .58322 m .65594 .59348 L .66601 .63538 L p F P
0 0 0 r
s
.677 .366 .086 r
.30793 .80319 m .33135 .80492 L .33315 .74928 L p F P
0 0 0 r
s
.677 .366 .086 r
.33315 .74928 m .30964 .75784 L .30793 .80319 L p F P
0 0 0 r
s
.403 .729 .611 r
.59447 .25485 m .52645 .24857 L .52638 .21487 L p F P
0 0 0 r
s
.181 .337 .311 r
.32941 .39207 m .27906 .42158 L .28098 .38648 L p F P
0 0 0 r
s
.181 .337 .311 r
.28098 .38648 m .33094 .35684 L .32941 .39207 L p F P
0 0 0 r
s
.502 .907 .732 r
.65952 .30488 m .71646 .32924 L .71807 .36388 L p F P
0 0 0 r
s
.502 .907 .732 r
.71646 .32924 m .65952 .30488 L .65838 .27071 L p F P
0 0 0 r
s
.856 .494 .104 r
.52588 .84416 m .52171 .83152 L .52362 .93636 L p F P
0 0 0 r
s
.856 .494 .104 r
.52362 .93636 m .52967 .94645 L .52588 .84416 L p F P
0 0 0 r
s
.45 .23 .052 r
.40007 1.05561 m .38659 1.04085 L .37363 1.04679 L p F P
0 0 0 r
s
.913 .492 .106 r
.46268 .59518 m .4709 .59502 L .46129 .55418 L p F P
0 0 0 r
s
.913 .492 .106 r
.46129 .55418 m .45133 .55856 L .46268 .59518 L p F P
0 0 0 r
s
.957 .614 .134 r
.24051 .78045 m .21614 .80167 L .21414 .79805 L p F P
0 0 0 r
s
.957 .614 .134 r
.21414 .79805 m .23823 .78735 L .24051 .78045 L p F P
0 0 0 r
s
.606 .347 .086 r
.43629 .84337 m .45643 .83726 L .45807 .93935 L p F P
0 0 0 r
s
.606 .347 .086 r
.45807 .93935 m .43857 .94154 L .43629 .84337 L p F P
0 0 0 r
s
.561 .331 .085 r
.36247 .93897 m .3812 .94111 L .38718 1.01079 L p F P
0 0 0 r
s
.561 .331 .085 r
.38718 1.01079 m .36956 1.00142 L .36247 .93897 L p F P
0 0 0 r
s
.455 .822 .676 r
.59447 .25485 m .65838 .27071 L .65952 .30488 L p F P
0 0 0 r
s
.823 .474 .099 r
.50461 .77957 m .50895 .79277 L .5056 .6937 L p F P
0 0 0 r
s
.823 .474 .099 r
.5056 .6937 m .49954 .68359 L .50461 .77957 L p F P
0 0 0 r
s
.035 .07 .083 r
.84127 .84278 m .84851 .80435 L .84582 .76583 L p F P
0 0 0 r
s
.386 .722 .553 r
.80907 .57472 m .83075 .61371 L .8333 .65068 L p F P
0 0 0 r
s
.386 .722 .553 r
.83075 .61371 m .80907 .57472 L .8067 .53811 L p F P
0 0 0 r
s
1 1 .239 r
.81896 .84113 m .81541 .84087 L .82002 .83939 L p F P
0 0 0 r
s
.79751 .85023 m .82002 .83939 L .81541 .84087 L p F P
s
.703 .457 .098 r
.82002 .83939 m .79751 .85023 L .80047 .85786 L p F P
0 0 0 r
s
.703 .457 .098 r
.80047 .85786 m .82108 .83764 L p .82002 .83939 L F P
0 0 0 r
s
.703 .457 .098 r
.82108 .83764 m .82272 .83604 L .82002 .83939 L p F P
0 0 0 r
s
1 1 .239 r
.8381 .84255 m .81896 .84113 L p .82002 .83939 L F P
0 0 0 r
s
1 1 .239 r
.82002 .83939 m .8424 .82846 L .8381 .84255 L p F P
0 0 0 r
s
.255 .486 .348 r
.83589 .68825 m .84317 .72792 L .84582 .76583 L p F P
0 0 0 r
s
.255 .486 .348 r
.84317 .72792 m .83589 .68825 L .8333 .65068 L p F P
0 0 0 r
s
1 .934 .199 r
.61659 1.02636 m .62987 1.01916 L .61858 1.06148 L p F P
0 0 0 r
s
.17 .096 .03 r
.48223 .95138 m .49386 .94394 L .49757 .84208 L p F P
0 0 0 r
s
.182 .102 .031 r
.50749 .83047 m .49757 .84208 L .49386 .94394 L p F P
0 0 0 r
s
.81541 .84087 m .7927 .83918 L .79751 .85023 L p F P
s
.441 .269 .072 r
.35224 .99064 m .36956 1.00142 L .37821 1.04542 L p F P
0 0 0 r
s
.441 .269 .072 r
.37821 1.04542 m .36213 1.0294 L .35224 .99064 L p F P
0 0 0 r
s
.583 .313 .073 r
.28447 .80144 m .30793 .80319 L .30964 .75784 L p F P
0 0 0 r
s
.583 .313 .073 r
.30964 .75784 m .28598 .76711 L .28447 .80144 L p F P
0 0 0 r
s
.293 .536 .468 r
.45746 .28652 m .39162 .29991 L .39264 .26572 L p F P
0 0 0 r
s
.293 .536 .468 r
.39264 .26572 m .45795 .25228 L .45746 .28652 L p F P
0 0 0 r
s
.216 .099 .024 r
.7927 .83918 m .76995 .83749 L .77486 .86083 L p F P
0 0 0 r
s
.216 .099 .024 r
.77486 .86083 m .79751 .85023 L .7927 .83918 L p F P
0 0 0 r
s
.237 .439 .392 r
.39059 .33467 m .33094 .35684 L .33245 .32217 L p F P
0 0 0 r
s
.237 .439 .392 r
.33245 .32217 m .39162 .29991 L .39059 .33467 L p F P
0 0 0 r
s
.966 .542 .115 r
.54734 .96841 m .54153 .96241 L .54906 1.04415 L p F P
0 0 0 r
s
.966 .542 .115 r
.54906 1.04415 m .55666 1.0444 L .54734 .96841 L p F P
0 0 0 r
s
1 .755 .166 r
.45531 .68685 m .47109 .69273 L .46618 .79143 L p F P
0 0 0 r
s
1 .745 .163 r
.48342 .80061 m .46618 .79143 L .47109 .69273 L p F P
0 0 0 r
s
1 .542 .117 r
.57144 1.03868 m .56412 1.0425 L .57495 1.08904 L p F P
0 0 0 r
s
1 .542 .117 r
.57495 1.08904 m .58391 1.07982 L .57144 1.03868 L p F P
0 0 0 r
s
.465 .247 .059 r
.76995 .83749 m .74717 .8358 L .75207 .87106 L p F P
0 0 0 r
s
.465 .247 .059 r
.75207 .87106 m .77486 .86083 L .76995 .83749 L p F P
0 0 0 r
s
.598 .342 .085 r
.45643 .83726 m .47668 .83112 L .47773 .93586 L p F P
0 0 0 r
s
.598 .342 .085 r
.47773 .93586 m .45807 .93935 L .45643 .83726 L p F P
0 0 0 r
s
.903 .504 .107 r
.48085 .65952 m .48717 .66655 L .47897 .59665 L p F P
0 0 0 r
s
.903 .504 .107 r
.47897 .59665 m .4709 .59502 L .48085 .65952 L p F P
0 0 0 r
s
.575 .298 .067 r
.59269 1.06842 m .58391 1.07982 L .59579 1.09247 L p F P
0 0 0 r
s
.575 .298 .067 r
.59579 1.09247 m .60611 1.07869 L .59269 1.06842 L p F P
0 0 0 r
s
1 .845 .184 r
.61659 1.02636 m .60307 1.03188 L .61037 .95706 L p F P
0 0 0 r
s
1 .82 .178 r
.59533 .95485 m .61037 .95706 L .60307 1.03188 L p F P
0 0 0 r
s
.119 .219 .218 r
.27512 .49352 m .23621 .52837 L .23849 .4923 L p F P
0 0 0 r
s
.119 .219 .218 r
.23849 .4923 m .27711 .45725 L .27512 .49352 L p F P
0 0 0 r
s
1 .745 .163 r
.56469 .94684 m .54911 .94089 L .55107 .83661 L p F P
0 0 0 r
s
1 .735 .161 r
.53435 .82771 m .55107 .83661 L .54911 .94089 L p F P
0 0 0 r
s
.619 .356 .088 r
.62148 .78723 m .60046 .7936 L .59526 .6978 L p F P
0 0 0 r
s
.619 .356 .088 r
.59526 .6978 m .6151 .69582 L .62148 .78723 L p F P
0 0 0 r
s
.606 .326 .076 r
.74717 .8358 m .72435 .8341 L .72913 .88076 L p F P
0 0 0 r
s
.606 .326 .076 r
.72913 .88076 m .75207 .87106 L .74717 .8358 L p F P
0 0 0 r
s
.242 .107 .025 r
.61972 .57242 m .63534 .58108 L .64573 .57484 L p F P
0 0 0 r
s
.246 .125 .034 r
.63534 .58108 m .61972 .57242 L .6105 .60718 L p F P
0 0 0 r
s
.252 .131 .036 r
.59661 .60523 m .6105 .60718 L .61972 .57242 L p F P
0 0 0 r
s
.692 .375 .088 r
.72435 .8341 m .7015 .83241 L .70605 .88979 L p F P
0 0 0 r
s
.692 .375 .088 r
.70605 .88979 m .72913 .88076 L .72435 .8341 L p F P
0 0 0 r
s
.422 .221 .053 r
.26097 .7997 m .28447 .80144 L .28598 .76711 L p F P
0 0 0 r
s
.422 .221 .053 r
.28598 .76711 m .26218 .77699 L .26097 .7997 L p F P
0 0 0 r
s
1 1 .239 r
.1899 .80895 m .21414 .79805 L .21614 .80167 L p F P
0 0 0 r
s
1 1 .239 r
.21614 .80167 m .19154 .82334 L .1899 .80895 L p F P
0 0 0 r
s
.047 .094 .112 r
.23155 .60232 m .20598 .64043 L .20851 .60339 L p F P
0 0 0 r
s
.047 .094 .112 r
.20851 .60339 m .2339 .56504 L .23155 .60232 L p F P
0 0 0 r
s
.157 .09 .028 r
.56424 .68013 m .55236 .68774 L .54817 .78286 L p F P
0 0 0 r
s
.17 .096 .03 r
.53785 .79494 m .54817 .78286 L .55236 .68774 L p F P
0 0 0 r
s
.396 .195 .043 r
.44115 .56514 m .45133 .55856 L .44018 .54835 L p F P
0 0 0 r
s
1 .722 .154 r
.42827 .55695 m .44018 .54835 L .42908 .56611 L p F P
0 0 0 r
s
.396 .195 .043 r
.44018 .54835 m .42827 .55695 L .44115 .56514 L p F P
0 0 0 r
s
.533 .965 .764 r
.71971 .39908 m .76713 .43025 L .76917 .46588 L p F P
0 0 0 r
s
.533 .965 .764 r
.76713 .43025 m .71971 .39908 L .71807 .36388 L p F P
0 0 0 r
s
.017 .035 .042 r
.20081 .71635 m .18968 .7556 L .19233 .71762 L p F P
0 0 0 r
s
.017 .035 .042 r
.19233 .71762 m .20342 .67807 L .20081 .71635 L p F P
0 0 0 r
s
.45 .23 .052 r
.37363 1.04679 m .38843 1.06428 L .40007 1.05561 L p F P
0 0 0 r
s
.183 .112 .037 r
.38843 1.06428 m .37363 1.04679 L .36213 1.0294 L p F P
0 0 0 r
s
.753 .411 .096 r
.7015 .83241 m .67862 .83071 L .68284 .89803 L p F P
0 0 0 r
s
.753 .411 .096 r
.68284 .89803 m .70605 .88979 L .7015 .83241 L p F P
0 0 0 r
s
.562 .329 .084 r
.3812 .94111 m .40013 .94232 L .40507 1.01848 L p F P
0 0 0 r
s
.562 .329 .084 r
.40507 1.01848 m .38718 1.01079 L .3812 .94111 L p F P
0 0 0 r
s
.207 .111 .033 r
.43776 1.034 m .45057 1.03727 L .45939 .96229 L p F P
0 0 0 r
s
.216 .117 .034 r
.47073 .95747 m .45939 .96229 L .45057 1.03727 L p F P
0 0 0 r
s
.882 .509 .107 r
.52171 .83152 m .51751 .81875 L .51751 .92479 L p F P
0 0 0 r
s
.882 .509 .107 r
.51751 .92479 m .52362 .93636 L .52171 .83152 L p F P
0 0 0 r
s
.183 .112 .037 r
.36213 1.0294 m .37821 1.04542 L .38843 1.06428 L p F P
0 0 0 r
s
.182 .102 .031 r
.49386 .94394 m .50562 .93509 L .50749 .83047 L p F P
0 0 0 r
s
.589 .337 .083 r
.47668 .83112 m .49704 .82495 L .49755 .93102 L p F P
0 0 0 r
s
.589 .337 .083 r
.49755 .93102 m .47773 .93586 L .47668 .83112 L p F P
0 0 0 r
s
.798 .437 .102 r
.67862 .83071 m .6557 .82901 L .6595 .90535 L p F P
0 0 0 r
s
.798 .437 .102 r
.6595 .90535 m .68284 .89803 L .67862 .83071 L p F P
0 0 0 r
s
.455 .822 .676 r
.65952 .30488 m .5951 .28909 L .59447 .25485 L p F P
0 0 0 r
s
.403 .729 .611 r
.52645 .24857 m .59447 .25485 L .5951 .28909 L p F P
0 0 0 r
s
1 .92 .198 r
.43281 .60775 m .41796 .61014 L .42908 .56611 L p F P
0 0 0 r
s
1 .848 .185 r
.41796 .61014 m .43281 .60775 L .42319 .67827 L p F P
0 0 0 r
s
1 .822 .179 r
.43935 .68205 m .42319 .67827 L .43281 .60775 L p F P
0 0 0 r
s
.192 .107 .033 r
.51751 .81875 m .50749 .83047 L .50562 .93509 L p F P
0 0 0 r
s
.586 .345 .088 r
.67586 .69596 m .65539 .69498 L .64658 .62856 L p F P
0 0 0 r
s
.586 .345 .088 r
.64658 .62856 m .66601 .63538 L .67586 .69596 L p F P
0 0 0 r
s
1 .722 .154 r
.42908 .56611 m .41553 .57383 L .42827 .55695 L p F P
0 0 0 r
s
1 .96 .206 r
.41553 .57383 m .42908 .56611 L .41796 .61014 L p F P
0 0 0 r
s
.798 .458 .096 r
.50021 .76622 m .50461 .77957 L .49954 .68359 L p F P
0 0 0 r
s
.798 .458 .096 r
.49954 .68359 m .49339 .67455 L .50021 .76622 L p F P
0 0 0 r
s
.84 .53 .114 r
.60675 1.07371 m .61858 1.06148 L .60611 1.07869 L p F P
0 0 0 r
s
1 .934 .199 r
.61858 1.06148 m .60675 1.07371 L .61659 1.02636 L p F P
0 0 0 r
s
.831 .457 .106 r
.6557 .82901 m .63275 .8273 L .63604 .91164 L p F P
0 0 0 r
s
.831 .457 .106 r
.63604 .91164 m .6595 .90535 L .6557 .82901 L p F P
0 0 0 r
s
.349 .634 .541 r
.52652 .28283 m .45746 .28652 L .45795 .25228 L p F P
0 0 0 r
s
.349 .634 .541 r
.45795 .25228 m .52645 .24857 L .52652 .28283 L p F P
0 0 0 r
s
1 .93 .199 r
.8424 .82846 m .82002 .83939 L .82272 .83604 L p F P
0 0 0 r
s
1 .93 .199 r
.82272 .83604 m .84475 .81413 L .8424 .82846 L p F P
0 0 0 r
s
.185 .1 .029 r
.6105 .60718 m .59661 .60523 L .58848 .66805 L p F P
0 0 0 r
s
.197 .106 .031 r
.57628 .67359 m .58848 .66805 L .59661 .60523 L p F P
0 0 0 r
s
.153 .066 .015 r
.23745 .79795 m .26097 .7997 L .26218 .77699 L p F P
0 0 0 r
s
.153 .066 .015 r
.26218 .77699 m .23823 .78735 L .23745 .79795 L p F P
0 0 0 r
s
1 .735 .161 r
.54911 .94089 m .53338 .93355 L .53435 .82771 L p F P
0 0 0 r
s
1 .726 .159 r
.51751 .81875 m .53435 .82771 L .53338 .93355 L p F P
0 0 0 r
s
.857 .473 .11 r
.63275 .8273 m .60977 .8256 L .61248 .9168 L p F P
0 0 0 r
s
.857 .473 .11 r
.61248 .9168 m .63604 .91164 L .63275 .8273 L p F P
0 0 0 r
s
.84 .53 .114 r
.60611 1.07869 m .59579 1.09247 L .60675 1.07371 L p F P
0 0 0 r
s
.301 .16 .041 r
.40007 1.05561 m .41385 1.06857 L .42517 1.02882 L p F P
0 0 0 r
s
.293 .157 .042 r
.43776 1.034 m .42517 1.02882 L .41385 1.06857 L p F P
0 0 0 r
s
.629 .363 .09 r
.64261 .78082 m .62148 .78723 L .6151 .69582 L p F P
0 0 0 r
s
.629 .363 .09 r
.6151 .69582 m .63514 .6949 L .64261 .78082 L p F P
0 0 0 r
s
.321 .215 .06 r
.67458 .6058 m .65594 .59348 L .64573 .57484 L p F P
0 0 0 r
s
.321 .215 .06 r
.64573 .57484 m .66309 .58799 L .67458 .6058 L p F P
0 0 0 r
s
.259 .115 .026 r
.66309 .58799 m .64573 .57484 L .63534 .58108 L p F P
0 0 0 r
s
.515 .942 .734 r
.77124 .50209 m .8067 .53811 L .80907 .57472 L p F P
0 0 0 r
s
.515 .942 .734 r
.8067 .53811 m .77124 .50209 L .76917 .46588 L p F P
0 0 0 r
s
.525 .319 .085 r
.68577 .64374 m .66601 .63538 L .65594 .59348 L p F P
0 0 0 r
s
.525 .319 .085 r
.65594 .59348 m .67458 .6058 L .68577 .64374 L p F P
0 0 0 r
s
1 .767 .169 r
.43935 .68205 m .45531 .68685 L .44881 .78219 L p F P
0 0 0 r
s
1 .755 .166 r
.46618 .79143 m .44881 .78219 L .45531 .68685 L p F P
0 0 0 r
s
.878 .485 .113 r
.60977 .8256 m .58676 .82389 L .58882 .92075 L p F P
0 0 0 r
s
.878 .485 .113 r
.58882 .92075 m .61248 .9168 L .60977 .8256 L p F P
0 0 0 r
s
.403 .729 .611 r
.5951 .28909 m .52652 .28283 L .52645 .24857 L p F P
0 0 0 r
s
.181 .337 .311 r
.32785 .42789 m .27711 .45725 L .27906 .42158 L p F P
0 0 0 r
s
.181 .337 .311 r
.27906 .42158 m .32941 .39207 L .32785 .42789 L p F P
0 0 0 r
s
.502 .907 .732 r
.66068 .33962 m .71807 .36388 L .71971 .39908 L p F P
0 0 0 r
s
.502 .907 .732 r
.71807 .36388 m .66068 .33962 L .65952 .30488 L p F P
0 0 0 r
s
.192 .107 .033 r
.50562 .93509 m .51751 .92479 L .51751 .81875 L p F P
0 0 0 r
s
.58 .331 .082 r
.49704 .82495 m .51751 .81875 L .51751 .92479 L p F P
0 0 0 r
s
.58 .331 .082 r
.51751 .92479 m .49755 .93102 L .49704 .82495 L p F P
0 0 0 r
s
.455 .822 .676 r
.5951 .28909 m .65952 .30488 L .66068 .33962 L p F P
0 0 0 r
s
1 .905 .194 r
.60307 1.03188 m .61659 1.02636 L .60675 1.07371 L p F P
0 0 0 r
s
1 .82 .178 r
.60307 1.03188 m .58931 1.0355 L .59533 .95485 L p F P
0 0 0 r
s
1 .799 .174 r
.58009 .95147 m .59533 .95485 L .58931 1.0355 L p F P
0 0 0 r
s
.895 .496 .115 r
.58676 .82389 m .56371 .82218 L .5651 .92343 L p F P
0 0 0 r
s
.895 .496 .115 r
.5651 .92343 m .58882 .92075 L .58676 .82389 L p F P
0 0 0 r
s
.386 .722 .553 r
.81147 .61194 m .8333 .65068 L .83589 .68825 L p F P
0 0 0 r
s
.386 .722 .553 r
.8333 .65068 m .81147 .61194 L .80907 .57472 L p F P
0 0 0 r
s
.255 .486 .348 r
.83852 .72645 m .84582 .76583 L .84851 .80435 L p F P
0 0 0 r
s
.255 .486 .348 r
.84582 .76583 m .83852 .72645 L .83589 .68825 L p F P
0 0 0 r
s
.482 .29 .076 r
.36956 1.00142 m .38718 1.01079 L .39462 1.05963 L p F P
0 0 0 r
s
.482 .29 .076 r
.39462 1.05963 m .37821 1.04542 L .36956 1.00142 L p F P
0 0 0 r
s
.977 .552 .117 r
.54153 .96241 m .53564 .95512 L .54134 1.04158 L p F P
0 0 0 r
s
.977 .552 .117 r
.54134 1.04158 m .54906 1.04415 L .54153 .96241 L p F P
0 0 0 r
s
.849 .451 .098 r
.4543 .597 m .46268 .59518 L .45133 .55856 L p F P
0 0 0 r
s
.849 .451 .098 r
.45133 .55856 m .44115 .56514 L .4543 .597 L p F P
0 0 0 r
s
.406 .208 .049 r
.41385 1.06857 m .40007 1.05561 L .38843 1.06428 L p F P
0 0 0 r
s
.909 .505 .117 r
.56371 .82218 m .54062 .82046 L .54132 .92478 L p F P
0 0 0 r
s
.909 .505 .117 r
.54132 .92478 m .5651 .92343 L .56371 .82218 L p F P
0 0 0 r
s
.74 .49 .11 r
.23823 .78735 m .21414 .79805 L .21388 .7962 L p F P
0 0 0 r
s
.74 .49 .11 r
.21388 .7962 m .23745 .79795 L .23823 .78735 L p F P
0 0 0 r
s
.561 .327 .083 r
.40013 .94232 m .41926 .9425 L .42324 1.02428 L p F P
0 0 0 r
s
.561 .327 .083 r
.42324 1.02428 m .40507 1.01848 L .40013 .94232 L p F P
0 0 0 r
s
1 .726 .159 r
.53338 .93355 m .51751 .92479 L .51751 .81875 L p F P
0 0 0 r
s
.92 .512 .119 r
.54062 .82046 m .51751 .81875 L .51751 .92479 L p F P
0 0 0 r
s
.92 .512 .119 r
.51751 .92479 m .54132 .92478 L .54062 .82046 L p F P
0 0 0 r
s
.293 .536 .468 r
.45696 .32133 m .39059 .33467 L .39162 .29991 L p F P
0 0 0 r
s
.293 .536 .468 r
.39162 .29991 m .45746 .28652 L .45696 .32133 L p F P
0 0 0 r
s
.141 .082 .025 r
.57628 .67359 m .56424 .68013 L .5586 .77065 L p F P
0 0 0 r
s
.157 .09 .028 r
.54817 .78286 m .5586 .77065 L .56424 .68013 L p F P
0 0 0 r
s
.237 .439 .392 r
.38953 .37 m .32941 .39207 L .33094 .35684 L p F P
0 0 0 r
s
.237 .439 .392 r
.33094 .35684 m .39059 .33467 L .38953 .37 L p F P
0 0 0 r
s
.877 .485 .103 r
.47443 .6534 m .48085 .65952 L .4709 .59502 L p F P
0 0 0 r
s
.877 .485 .103 r
.4709 .59502 m .46268 .59518 L .47443 .6534 L p F P
0 0 0 r
s
.627 .356 .087 r
.53936 .91892 m .51751 .92479 L .51751 .81875 L p F P
0 0 0 r
s
.627 .356 .087 r
.51751 .81875 m .53808 .81251 L .53936 .91892 L p F P
0 0 0 r
s
.129 .078 .025 r
.52763 .8069 m .51751 .81875 L .51751 .92479 L p F P
0 0 0 r
s
.964 .536 .124 r
.49415 .92144 m .51751 .92479 L .51751 .81875 L p F P
0 0 0 r
s
.964 .536 .124 r
.51751 .81875 m .49436 .81703 L .49415 .92144 L p F P
0 0 0 r
s
1 .707 .156 r
.50053 .80971 m .51751 .81875 L .51751 .92479 L p F P
0 0 0 r
s
1 .707 .156 r
.51751 .92479 m .49892 .91604 L .50053 .80971 L p F P
0 0 0 r
s
.741 .434 .09 r
.51502 .91135 m .51751 .92479 L .51751 .81875 L p F P
0 0 0 r
s
.741 .434 .09 r
.51751 .81875 m .51325 .80583 L .51502 .91135 L p F P
0 0 0 r
s
1 .565 .122 r
.56412 1.0425 m .55666 1.0444 L .56579 1.09579 L p F P
0 0 0 r
s
1 .565 .122 r
.56579 1.09579 m .57495 1.08904 L .56412 1.0425 L p F P
0 0 0 r
s
.119 .219 .218 r
.2731 .53038 m .2339 .56504 L .23621 .52837 L p F P
0 0 0 r
s
.119 .219 .218 r
.23621 .52837 m .27512 .49352 L .2731 .53038 L p F P
0 0 0 r
s
.216 .117 .034 r
.45057 1.03727 m .46359 1.03841 L .47073 .95747 L p F P
0 0 0 r
s
.226 .124 .036 r
.48223 .95138 m .47073 .95747 L .46359 1.03841 L p F P
0 0 0 r
s
.953 .529 .122 r
.47076 .91673 m .49415 .92144 L .49436 .81703 L p F P
0 0 0 r
s
.953 .529 .122 r
.49436 .81703 m .47117 .81531 L .47076 .91673 L p F P
0 0 0 r
s
.642 .371 .093 r
.66386 .77438 m .64261 .78082 L .63514 .6949 L p F P
0 0 0 r
s
.642 .371 .093 r
.63514 .6949 m .65539 .69498 L .66386 .77438 L p F P
0 0 0 r
s
.055 .024 .006 r
.79751 .85023 m .77486 .86083 L .778 .87933 L p F P
0 0 0 r
s
.055 .024 .006 r
.778 .87933 m .80047 .85786 L .79751 .85023 L p F P
0 0 0 r
s
1 1 .253 r
.19029 .79445 m .21388 .7962 L .21414 .79805 L p F P
0 0 0 r
s
1 1 .253 r
.21414 .79805 m .1899 .80895 L .19029 .79445 L p F P
0 0 0 r
s
.941 .521 .12 r
.44735 .91068 m .47076 .91673 L .47117 .81531 L p F P
0 0 0 r
s
.941 .521 .12 r
.47117 .81531 m .44795 .81358 L .44735 .91068 L p F P
0 0 0 r
s
.259 .115 .026 r
.63534 .58108 m .65129 .59178 L .66309 .58799 L p F P
0 0 0 r
s
.239 .117 .031 r
.65129 .59178 m .63534 .58108 L .62463 .61081 L p F P
0 0 0 r
s
.246 .125 .034 r
.6105 .60718 m .62463 .61081 L .63534 .58108 L p F P
0 0 0 r
s
.658 .342 .076 r
.58391 1.07982 m .57495 1.08904 L .58523 1.10392 L p F P
0 0 0 r
s
.658 .342 .076 r
.58523 1.10392 m .59579 1.09247 L .58391 1.07982 L p F P
0 0 0 r
s
.771 .442 .092 r
.49576 .75272 m .50021 .76622 L .49339 .67455 L p F P
0 0 0 r
s
.771 .442 .092 r
.49339 .67455 m .48717 .66655 L .49576 .75272 L p F P
0 0 0 r
s
.047 .094 .112 r
.22916 .64022 m .20342 .67807 L .20598 .64043 L p F P
0 0 0 r
s
.047 .094 .112 r
.20598 .64043 m .23155 .60232 L .22916 .64022 L p F P
0 0 0 r
s
.592 .352 .091 r
.69656 .69775 m .67586 .69596 L .66601 .63538 L p F P
0 0 0 r
s
.592 .352 .091 r
.66601 .63538 m .68577 .64374 L .69656 .69775 L p F P
0 0 0 r
s
1 .882 .187 r
.84475 .81413 m .82272 .83604 L .82334 .82935 L p F P
0 0 0 r
s
1 .882 .187 r
.82334 .82935 m .8451 .79966 L .84475 .81413 L p F P
0 0 0 r
s
.533 .965 .764 r
.72138 .43486 m .76917 .46588 L .77124 .50209 L p F P
0 0 0 r
s
.533 .965 .764 r
.76917 .46588 m .72138 .43486 L .71971 .39908 L p F P
0 0 0 r
s
.017 .035 .042 r
.19816 .75526 m .18698 .79421 L .18968 .7556 L p F P
0 0 0 r
s
.017 .035 .042 r
.18968 .7556 m .20081 .71635 L .19816 .75526 L p F P
0 0 0 r
s
.928 .512 .118 r
.42395 .90334 m .44735 .91068 L .44795 .81358 L p F P
0 0 0 r
s
.928 .512 .118 r
.44795 .81358 m .4247 .81186 L .42395 .90334 L p F P
0 0 0 r
s
1 .781 .172 r
.42319 .67827 m .43935 .68205 L .4313 .77287 L p F P
0 0 0 r
s
1 .767 .169 r
.44881 .78219 m .4313 .77287 L .43935 .68205 L p F P
0 0 0 r
s
1 .96 .206 r
.41796 .61014 m .40284 .61421 L .41553 .57383 L p F P
0 0 0 r
s
1 .881 .192 r
.40284 .61421 m .41796 .61014 L .40683 .67546 L p F P
0 0 0 r
s
1 .848 .185 r
.42319 .67827 m .40683 .67546 L .41796 .61014 L p F P
0 0 0 r
s
.638 .363 .089 r
.56129 .91167 m .53936 .91892 L .53808 .81251 L p F P
0 0 0 r
s
.638 .363 .089 r
.53808 .81251 m .55877 .80624 L .56129 .91167 L p F P
0 0 0 r
s
.912 .502 .116 r
.40056 .89478 m .42395 .90334 L .4247 .81186 L p F P
0 0 0 r
s
.912 .502 .116 r
.4247 .81186 m .40141 .81013 L .40056 .89478 L p F P
0 0 0 r
s
.455 .822 .676 r
.66068 .33962 m .59574 .32388 L .5951 .28909 L p F P
0 0 0 r
s
.403 .729 .611 r
.52652 .28283 m .5951 .28909 L .59574 .32388 L p F P
0 0 0 r
s
1 .799 .174 r
.58931 1.0355 m .57534 1.03698 L .58009 .95147 L p F P
0 0 0 r
s
1 .781 .17 r
.56469 .94684 m .58009 .95147 L .57534 1.03698 L p F P
0 0 0 r
s
.406 .208 .049 r
.38843 1.06428 m .40356 1.07983 L .41385 1.06857 L p F P
0 0 0 r
s
.255 .167 .049 r
.37821 1.04542 m .39462 1.05963 L .40356 1.07983 L p F P
0 0 0 r
s
.255 .167 .049 r
.40356 1.07983 m .38843 1.06428 L .37821 1.04542 L p F P
0 0 0 r
s
.56 .325 .082 r
.41926 .9425 m .43857 .94154 L .44166 1.02796 L p F P
0 0 0 r
s
.56 .325 .082 r
.44166 1.02796 m .42324 1.02428 L .41926 .9425 L p F P
0 0 0 r
s
.171 .091 .026 r
.62463 .61081 m .6105 .60718 L .60085 .66344 L p F P
0 0 0 r
s
.185 .1 .029 r
.58848 .66805 m .60085 .66344 L .6105 .60718 L p F P
0 0 0 r
s
.313 .149 .033 r
.43074 .57375 m .44115 .56514 L .42827 .55695 L p F P
0 0 0 r
s
.889 .565 .123 r
.41609 .56776 m .42827 .55695 L .41553 .57383 L p F P
0 0 0 r
s
.313 .149 .033 r
.42827 .55695 m .41609 .56776 L .43074 .57375 L p F P
0 0 0 r
s
.893 .49 .113 r
.37721 .88507 m .40056 .89478 L .40141 .81013 L p F P
0 0 0 r
s
.893 .49 .113 r
.40141 .81013 m .37809 .80839 L .37721 .88507 L p F P
0 0 0 r
s
1 .715 .158 r
.48342 .80061 m .50053 .80971 L .49892 .91604 L p F P
0 0 0 r
s
.287 .146 .037 r
.77486 .86083 m .75207 .87106 L .75529 .90015 L p F P
0 0 0 r
s
.287 .146 .037 r
.75529 .90015 m .778 .87933 L .77486 .86083 L p F P
0 0 0 r
s
.349 .634 .541 r
.5266 .31765 m .45696 .32133 L .45746 .28652 L p F P
0 0 0 r
s
.349 .634 .541 r
.45746 .28652 m .52652 .28283 L .5266 .31765 L p F P
0 0 0 r
s
.293 .157 .042 r
.41385 1.06857 m .42791 1.07937 L .43776 1.034 L p F P
0 0 0 r
s
.288 .156 .042 r
.45057 1.03727 m .43776 1.034 L .42791 1.07937 L p F P
0 0 0 r
s
.868 .474 .109 r
.3539 .8743 m .37721 .88507 L .37809 .80839 L p F P
0 0 0 r
s
.868 .474 .109 r
.37809 .80839 m .35474 .80666 L .3539 .8743 L p F P
0 0 0 r
s
.889 .565 .123 r
.41553 .57383 m .40168 .58359 L .41609 .56776 L p F P
0 0 0 r
s
1 .994 .213 r
.40168 .58359 m .41553 .57383 L .40284 .61421 L p F P
0 0 0 r
s
.992 .562 .119 r
.53564 .95512 m .52967 .94645 L .5335 1.03651 L p F P
0 0 0 r
s
.992 .562 .119 r
.5335 1.03651 m .54134 1.04158 L .53564 .95512 L p F P
0 0 0 r
s
1 .683 .145 r
.59467 1.08379 m .60675 1.07371 L .59579 1.09247 L p F P
0 0 0 r
s
1 .905 .194 r
.60675 1.07371 m .59467 1.08379 L .60307 1.03188 L p F P
0 0 0 r
s
.515 .942 .734 r
.77335 .53891 m .80907 .57472 L .81147 .61194 L p F P
0 0 0 r
s
.515 .942 .734 r
.80907 .57472 m .77335 .53891 L .77124 .50209 L p F P
0 0 0 r
s
.362 .187 .045 r
.42791 1.07937 m .41385 1.06857 L .40356 1.07983 L p F P
0 0 0 r
s
.502 .299 .078 r
.38718 1.01079 m .40507 1.01848 L .41135 1.07169 L p F P
0 0 0 r
s
.502 .299 .078 r
.41135 1.07169 m .39462 1.05963 L .38718 1.01079 L p F P
0 0 0 r
s
.119 .073 .024 r
.53785 .79494 m .52763 .8069 L .52612 .91214 L p F P
0 0 0 r
s
.129 .078 .025 r
.51751 .92479 m .52612 .91214 L .52763 .8069 L p F P
0 0 0 r
s
1 .873 .188 r
.58931 1.0355 m .60307 1.03188 L .59467 1.08379 L p F P
0 0 0 r
s
.834 .453 .104 r
.33066 .8626 m .3539 .8743 L .35474 .80666 L p F P
0 0 0 r
s
.834 .453 .104 r
.35474 .80666 m .33135 .80492 L .33066 .8626 L p F P
0 0 0 r
s
.403 .729 .611 r
.59574 .32388 m .5266 .31765 L .52652 .28283 L p F P
0 0 0 r
s
.181 .337 .311 r
.32627 .4643 m .27512 .49352 L .27711 .45725 L p F P
0 0 0 r
s
.181 .337 .311 r
.27711 .45725 m .32785 .42789 L .32627 .4643 L p F P
0 0 0 r
s
.502 .907 .732 r
.66187 .37493 m .71971 .39908 L .72138 .43486 L p F P
0 0 0 r
s
.502 .907 .732 r
.71971 .39908 m .66187 .37493 L .66068 .33962 L p F P
0 0 0 r
s
.649 .37 .091 r
.58329 .90306 m .56129 .91167 L .55877 .80624 L p F P
0 0 0 r
s
.649 .37 .091 r
.55877 .80624 m .57956 .79994 L .58329 .90306 L p F P
0 0 0 r
s
.493 .305 .082 r
.70586 .65349 m .68577 .64374 L .67458 .6058 L p F P
0 0 0 r
s
.493 .305 .082 r
.67458 .6058 m .6936 .61996 L .70586 .65349 L p F P
0 0 0 r
s
.271 .179 .051 r
.6936 .61996 m .67458 .6058 L .66309 .58799 L p F P
0 0 0 r
s
.721 .421 .087 r
.51251 .8964 m .51502 .91135 L .51325 .80583 L p F P
0 0 0 r
s
.721 .421 .087 r
.51325 .80583 m .50895 .79277 L .51251 .8964 L p F P
0 0 0 r
s
.121 .071 .023 r
.58848 .66805 m .57628 .67359 L .56914 .75832 L p F P
0 0 0 r
s
.141 .082 .025 r
.5586 .77065 m .56914 .75832 L .57628 .67359 L p F P
0 0 0 r
s
.657 .382 .096 r
.68522 .76791 m .66386 .77438 L .65539 .69498 L p F P
0 0 0 r
s
.657 .382 .096 r
.65539 .69498 m .67586 .69596 L .68522 .76791 L p F P
0 0 0 r
s
.455 .822 .676 r
.59574 .32388 m .66068 .33962 L .66187 .37493 L p F P
0 0 0 r
s
.787 .424 .097 r
.30748 .85007 m .33066 .8626 L .33135 .80492 L p F P
0 0 0 r
s
.787 .424 .097 r
.33135 .80492 m .30793 .80319 L .30748 .85007 L p F P
0 0 0 r
s
.271 .179 .051 r
.66309 .58799 m .68085 .60314 L .6936 .61996 L p F P
0 0 0 r
s
.283 .128 .028 r
.68085 .60314 m .66309 .58799 L .65129 .59178 L p F P
0 0 0 r
s
.386 .722 .553 r
.81392 .64977 m .83589 .68825 L .83852 .72645 L p F P
0 0 0 r
s
.386 .722 .553 r
.83589 .68825 m .81392 .64977 L .81147 .61194 L p F P
0 0 0 r
s
.255 .486 .348 r
.84851 .80435 m .84119 .76528 L .83852 .72645 L p F P
0 0 0 r
s
1 .683 .145 r
.59579 1.09247 m .58523 1.10392 L .59467 1.08379 L p F P
0 0 0 r
s
.226 .124 .036 r
.46359 1.03841 m .47681 1.03724 L .48223 .95138 L p F P
0 0 0 r
s
.237 .132 .038 r
.49386 .94394 m .48223 .95138 L .47681 1.03724 L p F P
0 0 0 r
s
.908 .571 .123 r
.82272 .83604 m .80047 .85786 L .80133 .85899 L p F P
0 0 0 r
s
.908 .571 .123 r
.80133 .85899 m .82334 .82935 L .82272 .83604 L p F P
0 0 0 r
s
.448 .243 .059 r
.75207 .87106 m .72913 .88076 L .73235 .92006 L p F P
0 0 0 r
s
.448 .243 .059 r
.73235 .92006 m .75529 .90015 L .75207 .87106 L p F P
0 0 0 r
s
.715 .381 .088 r
.28438 .83685 m .30748 .85007 L .30793 .80319 L p F P
0 0 0 r
s
.715 .381 .088 r
.30793 .80319 m .28447 .80144 L .28438 .83685 L p F P
0 0 0 r
s
.588 .309 .071 r
.26135 .82308 m .28438 .83685 L .28447 .80144 L p F P
0 0 0 r
s
.588 .309 .071 r
.28447 .80144 m .26097 .7997 L .26135 .82308 L p F P
0 0 0 r
s
.293 .536 .468 r
.45646 .35671 m .38953 .37 L .39059 .33467 L p F P
0 0 0 r
s
.293 .536 .468 r
.39059 .33467 m .45696 .32133 L .45646 .35671 L p F P
0 0 0 r
s
.556 .322 .081 r
.43857 .94154 m .45807 .93935 L .46033 1.02935 L p F P
0 0 0 r
s
.556 .322 .081 r
.46033 1.02935 m .44166 1.02796 L .43857 .94154 L p F P
0 0 0 r
s
1 .723 .16 r
.46618 .79143 m .48342 .80061 L .48021 .90588 L p F P
0 0 0 r
s
1 .715 .158 r
.49892 .91604 m .48021 .90588 L .48342 .80061 L p F P
0 0 0 r
s
1 .798 .176 r
.40683 .67546 m .42319 .67827 L .41365 .76348 L p F P
0 0 0 r
s
1 .781 .172 r
.4313 .77287 m .41365 .76348 L .42319 .67827 L p F P
0 0 0 r
s
.76 .398 .087 r
.44575 .60032 m .4543 .597 L .44115 .56514 L p F P
0 0 0 r
s
.76 .398 .087 r
.44115 .56514 m .43074 .57375 L .44575 .60032 L p F P
0 0 0 r
s
.237 .439 .392 r
.38847 .40592 m .32785 .42789 L .32941 .39207 L p F P
0 0 0 r
s
.237 .439 .392 r
.32941 .39207 m .38953 .37 L .38847 .40592 L p F P
0 0 0 r
s
1 .581 .125 r
.55666 1.0444 m .54906 1.04415 L .55645 1.09974 L p F P
0 0 0 r
s
1 .581 .125 r
.55645 1.09974 m .56579 1.09579 L .55666 1.0444 L p F P
0 0 0 r
s
.662 .378 .093 r
.60534 .89313 m .58329 .90306 L .57956 .79994 L p F P
0 0 0 r
s
.662 .378 .093 r
.57956 .79994 m .60046 .7936 L .60534 .89313 L p F P
0 0 0 r
s
.284 .13 .029 r
.2384 .8089 m .26135 .82308 L .26097 .7997 L p F P
0 0 0 r
s
.284 .13 .029 r
.26097 .7997 m .23745 .79795 L .2384 .8089 L p F P
0 0 0 r
s
1 .938 .199 r
.8451 .79966 m .82334 .82935 L .82178 .81831 L p F P
0 0 0 r
s
1 .938 .199 r
.82178 .81831 m .8434 .78513 L .8451 .79966 L p F P
0 0 0 r
s
.842 .461 .098 r
.46791 .64811 m .47443 .6534 L .46268 .59518 L p F P
0 0 0 r
s
.842 .461 .098 r
.46268 .59518 m .4543 .597 L .46791 .64811 L p F P
0 0 0 r
s
1 .781 .17 r
.57534 1.03698 m .56115 1.03616 L .56469 .94684 L p F P
0 0 0 r
s
1 .766 .167 r
.54911 .94089 m .56469 .94684 L .56115 1.03616 L p F P
0 0 0 r
s
.743 .424 .088 r
.49127 .73907 m .49576 .75272 L .48717 .66655 L p F P
0 0 0 r
s
.743 .424 .088 r
.48717 .66655 m .48085 .65952 L .49127 .73907 L p F P
0 0 0 r
s
.119 .219 .218 r
.27105 .56787 m .23155 .60232 L .2339 .56504 L p F P
0 0 0 r
s
.119 .219 .218 r
.2339 .56504 m .2731 .53038 L .27105 .56787 L p F P
0 0 0 r
s
.532 .373 .089 r
.23745 .79795 m .21388 .7962 L .21553 .79447 L p F P
0 0 0 r
s
.532 .373 .089 r
.21553 .79447 m .2384 .8089 L .23745 .79795 L p F P
0 0 0 r
s
.561 .306 .073 r
.72913 .88076 m .70605 .88979 L .70917 .93877 L p F P
0 0 0 r
s
.561 .306 .073 r
.70917 .93877 m .73235 .92006 L .72913 .88076 L p F P
0 0 0 r
s
.6 .361 .094 r
.7175 .70026 m .69656 .69775 L .68577 .64374 L p F P
0 0 0 r
s
.6 .361 .094 r
.68577 .64374 m .70586 .65349 L .7175 .70026 L p F P
0 0 0 r
s
1 .966 .23 r
.19272 .77992 m .21553 .79447 L .21388 .7962 L p F P
0 0 0 r
s
1 .966 .23 r
.21388 .7962 m .19029 .79445 L .19272 .77992 L p F P
0 0 0 r
s
.047 .094 .112 r
.22673 .67876 m .20081 .71635 L .20342 .67807 L p F P
0 0 0 r
s
.047 .094 .112 r
.20342 .67807 m .22916 .64022 L .22673 .67876 L p F P
0 0 0 r
s
.112 .069 .022 r
.54817 .78286 m .53785 .79494 L .53483 .898 L p F P
0 0 0 r
s
.119 .073 .024 r
.52612 .91214 m .53483 .898 L .53785 .79494 L p F P
0 0 0 r
s
1 .994 .213 r
.40284 .61421 m .38744 .61982 L .40168 .58359 L p F P
0 0 0 r
s
1 .923 .201 r
.38744 .61982 m .40284 .61421 L .39025 .67353 L p F P
0 0 0 r
s
1 .881 .192 r
.40683 .67546 m .39025 .67353 L .40284 .61421 L p F P
0 0 0 r
s
.533 .965 .764 r
.72308 .47124 m .77124 .50209 L .77335 .53891 L p F P
0 0 0 r
s
.533 .965 .764 r
.77124 .50209 m .72308 .47124 L .72138 .43486 L p F P
0 0 0 r
s
1 .576 .122 r
.52967 .94645 m .52362 .93636 L .52556 1.02884 L p F P
0 0 0 r
s
1 .576 .122 r
.52556 1.02884 m .5335 1.03651 L .52967 .94645 L p F P
0 0 0 r
s
.677 .397 .1 r
.70669 .76139 m .68522 .76791 L .67586 .69596 L p F P
0 0 0 r
s
.677 .397 .1 r
.67586 .69596 m .69656 .69775 L .70669 .76139 L p F P
0 0 0 r
s
.677 .387 .095 r
.62742 .88195 m .60534 .89313 L .60046 .7936 L p F P
0 0 0 r
s
.677 .387 .095 r
.60046 .7936 m .62148 .78723 L .62742 .88195 L p F P
0 0 0 r
s
.80047 .85786 m .778 .87933 L .77904 .88823 L p F P
s
.77904 .88823 m .80133 .85899 L .80047 .85786 L p F P
s
.744 .388 .086 r
.57495 1.08904 m .56579 1.09579 L .57444 1.11268 L p F P
0 0 0 r
s
.744 .388 .086 r
.57444 1.11268 m .58523 1.10392 L .57495 1.08904 L p F P
0 0 0 r
s
.283 .128 .028 r
.65129 .59178 m .6676 .60432 L .68085 .60314 L p F P
0 0 0 r
s
.231 .108 .028 r
.6676 .60432 m .65129 .59178 L .63904 .61597 L p F P
0 0 0 r
s
.239 .117 .031 r
.62463 .61081 m .63904 .61597 L .65129 .59178 L p F P
0 0 0 r
s
.701 .408 .083 r
.50998 .87996 m .51251 .8964 L .50895 .79277 L p F P
0 0 0 r
s
.701 .408 .083 r
.50895 .79277 m .50461 .77957 L .50998 .87996 L p F P
0 0 0 r
s
.642 .351 .083 r
.70605 .88979 m .68284 .89803 L .68577 .95602 L p F P
0 0 0 r
s
.642 .351 .083 r
.68577 .95602 m .70917 .93877 L .70605 .88979 L p F P
0 0 0 r
s
.455 .822 .676 r
.66187 .37493 m .59639 .35926 L .59574 .32388 L p F P
0 0 0 r
s
.403 .729 .611 r
.5266 .31765 m .59574 .32388 L .59639 .35926 L p F P
0 0 0 r
s
.362 .187 .045 r
.40356 1.07983 m .41901 1.09305 L .42791 1.07937 L p F P
0 0 0 r
s
.359 .231 .064 r
.39462 1.05963 m .41135 1.07169 L .41901 1.09305 L p F P
0 0 0 r
s
.359 .231 .064 r
.41901 1.09305 m .40356 1.07983 L .39462 1.05963 L p F P
0 0 0 r
s
.288 .156 .042 r
.42791 1.07937 m .44225 1.08768 L .45057 1.03727 L p F P
0 0 0 r
s
.327 .169 .042 r
.44225 1.08768 m .42791 1.07937 L .41901 1.09305 L p F P
0 0 0 r
s
.511 .302 .078 r
.40507 1.01848 m .42324 1.02428 L .4284 1.08126 L p F P
0 0 0 r
s
.511 .302 .078 r
.4284 1.08126 m .41135 1.07169 L .40507 1.01848 L p F P
0 0 0 r
s
.287 .157 .042 r
.46359 1.03841 m .45057 1.03727 L .44225 1.08768 L p F P
0 0 0 r
s
.15 .079 .023 r
.63904 .61597 m .62463 .61081 L .6134 .65968 L p F P
0 0 0 r
s
.171 .091 .026 r
.60085 .66344 m .6134 .65968 L .62463 .61081 L p F P
0 0 0 r
s
1 .731 .162 r
.44881 .78219 m .46618 .79143 L .4614 .89431 L p F P
0 0 0 r
s
1 .723 .16 r
.48021 .90588 m .4614 .89431 L .46618 .79143 L p F P
0 0 0 r
s
.237 .132 .038 r
.47681 1.03724 m .49021 1.03359 L .49386 .94394 L p F P
0 0 0 r
s
.551 .318 .079 r
.45807 .93935 m .47773 .93586 L .4792 1.02831 L p F P
0 0 0 r
s
.551 .318 .079 r
.4792 1.02831 m .46033 1.02935 L .45807 .93935 L p F P
0 0 0 r
s
.248 .139 .039 r
.50562 .93509 m .49386 .94394 L .49021 1.03359 L p F P
0 0 0 r
s
.095 .058 .019 r
.60085 .66344 m .58848 .66805 L .57979 .74586 L p F P
0 0 0 r
s
.121 .071 .023 r
.56914 .75832 m .57979 .74586 L .58848 .66805 L p F P
0 0 0 r
s
1 .873 .188 r
.59467 1.08379 m .58234 1.09139 L .58931 1.0355 L p F P
0 0 0 r
s
1 .844 .182 r
.57534 1.03698 m .58931 1.0355 L .58234 1.09139 L p F P
0 0 0 r
s
.349 .634 .541 r
.52667 .35305 m .45646 .35671 L .45696 .32133 L p F P
0 0 0 r
s
.349 .634 .541 r
.45696 .32133 m .5266 .31765 L .52667 .35305 L p F P
0 0 0 r
s
.515 .942 .734 r
.77549 .57635 m .81147 .61194 L .81392 .64977 L p F P
0 0 0 r
s
.515 .942 .734 r
.81147 .61194 m .77549 .57635 L .77335 .53891 L p F P
0 0 0 r
s
1 .766 .167 r
.56115 1.03616 m .54678 1.03287 L .54911 .94089 L p F P
0 0 0 r
s
1 .753 .164 r
.53338 .93355 m .54911 .94089 L .54678 1.03287 L p F P
0 0 0 r
s
1 .876 .185 r
.58234 1.09139 m .59467 1.08379 L .58523 1.10392 L p F P
0 0 0 r
s
.695 .398 .098 r
.64952 .8696 m .62742 .88195 L .62148 .78723 L p F P
0 0 0 r
s
.695 .398 .098 r
.62148 .78723 m .64261 .78082 L .64952 .8696 L p F P
0 0 0 r
s
.704 .386 .091 r
.68284 .89803 m .6595 .90535 L .66216 .97157 L p F P
0 0 0 r
s
.704 .386 .091 r
.66216 .97157 m .68577 .95602 L .68284 .89803 L p F P
0 0 0 r
s
1 .846 .179 r
.82334 .82935 m .80133 .85899 L .7999 .85146 L p F P
0 0 0 r
s
1 .846 .179 r
.7999 .85146 m .82178 .81831 L .82334 .82935 L p F P
0 0 0 r
s
.403 .729 .611 r
.59639 .35926 m .52667 .35305 L .5266 .31765 L p F P
0 0 0 r
s
.181 .337 .311 r
.32466 .50133 m .2731 .53038 L .27512 .49352 L p F P
0 0 0 r
s
.181 .337 .311 r
.27512 .49352 m .32627 .4643 L .32466 .50133 L p F P
0 0 0 r
s
.502 .907 .732 r
.66307 .41082 m .72138 .43486 L .72308 .47124 L p F P
0 0 0 r
s
.502 .907 .732 r
.72138 .43486 m .66307 .41082 L .66187 .37493 L p F P
0 0 0 r
s
1 .818 .181 r
.39025 .67353 m .40683 .67546 L .39586 .75401 L p F P
0 0 0 r
s
1 .798 .176 r
.41365 .76348 m .39586 .75401 L .40683 .67546 L p F P
0 0 0 r
s
.247 .11 .026 r
.42008 .58417 m .43074 .57375 L .41609 .56776 L p F P
0 0 0 r
s
.719 .469 .102 r
.40361 .58055 m .41609 .56776 L .40168 .58359 L p F P
0 0 0 r
s
.247 .11 .026 r
.41609 .56776 m .40361 .58055 L .42008 .58417 L p F P
0 0 0 r
s
.455 .822 .676 r
.59639 .35926 m .66187 .37493 L .66307 .41082 L p F P
0 0 0 r
s
.719 .469 .102 r
.40168 .58359 m .38751 .59517 L .40361 .58055 L p F P
0 0 0 r
s
1 .997 .212 r
.38751 .59517 m .40168 .58359 L .38744 .61982 L p F P
0 0 0 r
s
.386 .722 .553 r
.81641 .68824 m .83852 .72645 L .84119 .76528 L p F P
0 0 0 r
s
.386 .722 .553 r
.83852 .72645 m .81641 .68824 L .81392 .64977 L p F P
0 0 0 r
s
1 1 .222 r
.8434 .78513 m .82178 .81831 L .81799 .80261 L p F P
0 0 0 r
s
1 1 .222 r
.81799 .80261 m .83963 .77063 L .8434 .78513 L p F P
0 0 0 r
s
.416 .267 .073 r
.7263 .66442 m .70586 .65349 L .6936 .61996 L p F P
0 0 0 r
s
.416 .267 .073 r
.6936 .61996 m .71303 .63572 L .7263 .66442 L p F P
0 0 0 r
s
.215 .138 .042 r
.71303 .63572 m .6936 .61996 L .68085 .60314 L p F P
0 0 0 r
s
.012 .006 .002 r
.778 .87933 m .75529 .90015 L .75646 .91668 L p F P
0 0 0 r
s
.012 .006 .002 r
.75646 .91668 m .77904 .88823 L .778 .87933 L p F P
0 0 0 r
s
.103 .063 .021 r
.5586 .77065 m .54817 .78286 L .54361 .88239 L p F P
0 0 0 r
s
.112 .069 .022 r
.53483 .898 m .54361 .88239 L .54817 .78286 L p F P
0 0 0 r
s
.71 .404 .083 r
.48672 .72526 m .49127 .73907 L .48085 .65952 L p F P
0 0 0 r
s
.71 .404 .083 r
.48085 .65952 m .47443 .6534 L .48672 .72526 L p F P
0 0 0 r
s
.248 .139 .039 r
.49021 1.03359 m .50378 1.02736 L .50562 .93509 L p F P
0 0 0 r
s
.545 .313 .078 r
.47773 .93586 m .49755 .93102 L .49827 1.0247 L p F P
0 0 0 r
s
.545 .313 .078 r
.49827 1.0247 m .4792 1.02831 L .47773 .93586 L p F P
0 0 0 r
s
1 .876 .185 r
.58523 1.10392 m .57444 1.11268 L .58234 1.09139 L p F P
0 0 0 r
s
.751 .413 .097 r
.6595 .90535 m .63604 .91164 L .63836 .98519 L p F P
0 0 0 r
s
.751 .413 .097 r
.63836 .98519 m .66216 .97157 L .6595 .90535 L p F P
0 0 0 r
s
1 .739 .164 r
.4313 .77287 m .44881 .78219 L .4425 .88139 L p F P
0 0 0 r
s
1 .731 .162 r
.4614 .89431 m .4425 .88139 L .44881 .78219 L p F P
0 0 0 r
s
1 .596 .127 r
.54906 1.04415 m .54134 1.04158 L .54693 1.10064 L p F P
0 0 0 r
s
1 .596 .127 r
.54693 1.10064 m .55645 1.09974 L .54906 1.04415 L p F P
0 0 0 r
s
.215 .138 .042 r
.68085 .60314 m .69902 .62005 L .71303 .63572 L p F P
0 0 0 r
s
.301 .137 .03 r
.69902 .62005 m .68085 .60314 L .6676 .60432 L p F P
0 0 0 r
s
.705 .417 .105 r
.72828 .75485 m .70669 .76139 L .69656 .69775 L p F P
0 0 0 r
s
.705 .417 .105 r
.69656 .69775 m .7175 .70026 L .72828 .75485 L p F P
0 0 0 r
s
.293 .536 .468 r
.45595 .39269 m .38847 .40592 L .38953 .37 L p F P
0 0 0 r
s
.293 .536 .468 r
.38953 .37 m .45646 .35671 L .45595 .39269 L p F P
0 0 0 r
s
.717 .412 .101 r
.67162 .85616 m .64952 .8696 L .64261 .78082 L p F P
0 0 0 r
s
.717 .412 .101 r
.64261 .78082 m .66386 .77438 L .67162 .85616 L p F P
0 0 0 r
s
.237 .439 .392 r
.38738 .44244 m .32627 .4643 L .32785 .42789 L p F P
0 0 0 r
s
.237 .439 .392 r
.32785 .42789 m .38847 .40592 L .38738 .44244 L p F P
0 0 0 r
s
1 .641 .163 r
.21553 .79447 m .19272 .77992 L .19724 .76546 L p F P
0 0 0 r
s
.61 .372 .098 r
.7387 .70336 m .7175 .70026 L .70586 .65349 L p F P
0 0 0 r
s
.61 .372 .098 r
.70586 .65349 m .7263 .66442 L .7387 .70336 L p F P
0 0 0 r
s
1 .592 .125 r
.52362 .93636 m .51751 .92479 L .51751 1.01846 L p F P
0 0 0 r
s
1 .592 .125 r
.51751 1.01846 m .52556 1.02884 L .52362 .93636 L p F P
0 0 0 r
s
.678 .394 .08 r
.50742 .86205 m .50998 .87996 L .50461 .77957 L p F P
0 0 0 r
s
.678 .394 .08 r
.50461 .77957 m .50021 .76622 L .50742 .86205 L p F P
0 0 0 r
s
.119 .219 .218 r
.26896 .60599 m .22916 .64022 L .23155 .60232 L p F P
0 0 0 r
s
.119 .219 .218 r
.23155 .60232 m .27105 .56787 L .26896 .60599 L p F P
0 0 0 r
s
.79 .426 .091 r
.46129 .64356 m .46791 .64811 L .4543 .597 L p F P
0 0 0 r
s
.79 .426 .091 r
.4543 .597 m .44575 .60032 L .46129 .64356 L p F P
0 0 0 r
s
.261 .147 .041 r
.51751 .92479 m .50562 .93509 L .50378 1.02736 L p F P
0 0 0 r
s
.788 .435 .102 r
.63604 .91164 m .61248 .9168 L .6144 .99668 L p F P
0 0 0 r
s
.788 .435 .102 r
.6144 .99668 m .63836 .98519 L .63604 .91164 L p F P
0 0 0 r
s
.287 .157 .042 r
.44225 1.08768 m .45686 1.09322 L .46359 1.03841 L p F P
0 0 0 r
s
.516 .303 .077 r
.42324 1.02428 m .44166 1.02796 L .44574 1.08806 L p F P
0 0 0 r
s
.516 .303 .077 r
.44574 1.08806 m .4284 1.08126 L .42324 1.02428 L p F P
0 0 0 r
s
1 .641 .163 r
.19724 .76546 m .21922 .79113 L .21553 .79447 L p F P
0 0 0 r
s
.442 .306 .079 r
.2384 .8089 m .21553 .79447 L .21922 .79113 L p F P
0 0 0 r
s
1 .753 .164 r
.54678 1.03287 m .53222 1.027 L .53338 .93355 L p F P
0 0 0 r
s
1 .741 .161 r
.51751 .92479 m .53338 .93355 L .53222 1.027 L p F P
0 0 0 r
s
.643 .333 .073 r
.43702 .60496 m .44575 .60032 L .43074 .57375 L p F P
0 0 0 r
s
.643 .333 .073 r
.43074 .57375 m .42008 .58417 L .43702 .60496 L p F P
0 0 0 r
s
.289 .16 .043 r
.47681 1.03724 m .46359 1.03841 L .45686 1.09322 L p F P
0 0 0 r
s
.047 .094 .112 r
.22426 .71795 m .19816 .75526 L .20081 .71635 L p F P
0 0 0 r
s
.047 .094 .112 r
.20081 .71635 m .22673 .67876 L .22426 .71795 L p F P
0 0 0 r
s
.076 .046 .015 r
.6134 .65968 m .60085 .66344 L .59054 .73327 L p F P
0 0 0 r
s
.095 .058 .019 r
.57979 .74586 m .59054 .73327 L .60085 .66344 L p F P
0 0 0 r
s
1 .997 .212 r
.38744 .61982 m .37175 .62678 L .38751 .59517 L p F P
0 0 0 r
s
1 .979 .214 r
.37175 .62678 m .38744 .61982 L .37344 .67238 L p F P
0 0 0 r
s
1 .923 .201 r
.39025 .67353 m .37344 .67238 L .38744 .61982 L p F P
0 0 0 r
s
.533 .965 .764 r
.72481 .50823 m .77335 .53891 L .77549 .57635 L p F P
0 0 0 r
s
.533 .965 .764 r
.77335 .53891 m .72481 .50823 L .72308 .47124 L p F P
0 0 0 r
s
.818 .452 .106 r
.61248 .9168 m .58882 .92075 L .5903 1.00587 L p F P
0 0 0 r
s
.818 .452 .106 r
.5903 1.00587 m .6144 .99668 L .61248 .9168 L p F P
0 0 0 r
s
.745 .43 .106 r
.69371 .84174 m .67162 .85616 L .66386 .77438 L p F P
0 0 0 r
s
.745 .43 .106 r
.66386 .77438 m .68522 .76791 L .69371 .84174 L p F P
0 0 0 r
s
1 .719 .152 r
.80133 .85899 m .77904 .88823 L .77774 .88419 L p F P
0 0 0 r
s
1 .719 .152 r
.77774 .88419 m .7999 .85146 L .80133 .85899 L p F P
0 0 0 r
s
.261 .147 .041 r
.50378 1.02736 m .51751 1.01846 L .51751 .92479 L p F P
0 0 0 r
s
.536 .308 .077 r
.49755 .93102 m .51751 .92479 L .51751 1.01846 L p F P
0 0 0 r
s
.536 .308 .077 r
.51751 1.01846 m .49827 1.0247 L .49755 .93102 L p F P
0 0 0 r
s
1 .844 .182 r
.58234 1.09139 m .56977 1.0962 L .57534 1.03698 L p F P
0 0 0 r
s
1 .818 .177 r
.56115 1.03616 m .57534 1.03698 L .56977 1.0962 L p F P
0 0 0 r
s
.442 .306 .079 r
.21922 .79113 m .24135 .81667 L .2384 .8089 L p F P
0 0 0 r
s
.328 .153 .033 r
.26135 .82308 m .2384 .8089 L .24135 .81667 L p F P
0 0 0 r
s
.203 .101 .027 r
.75529 .90015 m .73235 .92006 L .73358 .94396 L p F P
0 0 0 r
s
.203 .101 .027 r
.73358 .94396 m .75646 .91668 L .75529 .90015 L p F P
0 0 0 r
s
.327 .169 .042 r
.41901 1.09305 m .43478 1.10359 L .44225 1.08768 L p F P
0 0 0 r
s
.469 .29 .078 r
.41135 1.07169 m .4284 1.08126 L .43478 1.10359 L p F P
0 0 0 r
s
.469 .29 .078 r
.43478 1.10359 m .41901 1.09305 L .41135 1.07169 L p F P
0 0 0 r
s
1 .747 .166 r
.41365 .76348 m .4313 .77287 L .42352 .86717 L p F P
0 0 0 r
s
1 .739 .164 r
.4425 .88139 m .42352 .86717 L .4313 .77287 L p F P
0 0 0 r
s
.828 .437 .096 r
.56579 1.09579 m .55645 1.09974 L .56343 1.11843 L p F P
0 0 0 r
s
.828 .437 .096 r
.56343 1.11843 m .57444 1.11268 L .56579 1.09579 L p F P
0 0 0 r
s
.455 .822 .676 r
.66307 .41082 m .59705 .39523 L .59639 .35926 L p F P
0 0 0 r
s
.403 .729 .611 r
.52667 .35305 m .59639 .35926 L .59705 .39523 L p F P
0 0 0 r
s
1 .844 .187 r
.37344 .67238 m .39025 .67353 L .37794 .74447 L p F P
0 0 0 r
s
1 .818 .181 r
.39586 .75401 m .37794 .74447 L .39025 .67353 L p F P
0 0 0 r
s
1 1 .232 r
.82178 .81831 m .7999 .85146 L .79613 .83451 L p F P
0 0 0 r
s
1 1 .232 r
.79613 .83451 m .81799 .80261 L .82178 .81831 L p F P
0 0 0 r
s
.841 .466 .109 r
.58882 .92075 m .5651 .92343 L .56609 1.01262 L p F P
0 0 0 r
s
.841 .466 .109 r
.56609 1.01262 m .5903 1.00587 L .58882 .92075 L p F P
0 0 0 r
s
.231 .108 .028 r
.63904 .61597 m .65373 .62247 L .6676 .60432 L p F P
0 0 0 r
s
.117 .059 .017 r
.65373 .62247 m .63904 .61597 L .62615 .65669 L p F P
0 0 0 r
s
.15 .079 .023 r
.6134 .65968 m .62615 .65669 L .63904 .61597 L p F P
0 0 0 r
s
.328 .153 .033 r
.24135 .81667 m .26365 .84182 L .26135 .82308 L p F P
0 0 0 r
s
.64 .332 .073 r
.28438 .83685 m .26135 .82308 L .26365 .84182 L p F P
0 0 0 r
s
.093 .057 .018 r
.56914 .75832 m .5586 .77065 L .55246 .86533 L p F P
0 0 0 r
s
.103 .063 .021 r
.54361 .88239 m .55246 .86533 L .5586 .77065 L p F P
0 0 0 r
s
1 1 .245 r
.83963 .77063 m .81799 .80261 L .81199 .78266 L p F P
0 0 0 r
s
1 1 .245 r
.81199 .78266 m .83378 .75626 L .83963 .77063 L p F P
0 0 0 r
s
.349 .634 .541 r
.52675 .38905 m .45595 .39269 L .45646 .35671 L p F P
0 0 0 r
s
.349 .634 .541 r
.45646 .35671 m .52667 .35305 L .52675 .38905 L p F P
0 0 0 r
s
.301 .137 .03 r
.6676 .60432 m .68427 .61845 L .69902 .62005 L p F P
0 0 0 r
s
.215 .095 .023 r
.68427 .61845 m .6676 .60432 L .65373 .62247 L p F P
0 0 0 r
s
.86 .478 .112 r
.5651 .92343 m .54132 .92478 L .54181 1.01684 L p F P
0 0 0 r
s
.86 .478 .112 r
.54181 1.01684 m .56609 1.01262 L .5651 .92343 L p F P
0 0 0 r
s
.748 .448 .114 r
.74999 .74827 m .72828 .75485 L .7175 .70026 L p F P
0 0 0 r
s
.748 .448 .114 r
.7175 .70026 m .7387 .70336 L .74999 .74827 L p F P
0 0 0 r
s
.64 .332 .073 r
.26365 .84182 m .2861 .86627 L .28438 .83685 L p F P
0 0 0 r
s
.797 .42 .095 r
.30748 .85007 m .28438 .83685 L .2861 .86627 L p F P
0 0 0 r
s
.515 .942 .734 r
.77766 .61442 m .81392 .64977 L .81641 .68824 L p F P
0 0 0 r
s
.515 .942 .734 r
.81392 .64977 m .77766 .61442 L .77549 .57635 L p F P
0 0 0 r
s
.784 .455 .112 r
.71579 .82648 m .69371 .84174 L .68522 .76791 L p F P
0 0 0 r
s
.784 .455 .112 r
.68522 .76791 m .70669 .76139 L .71579 .82648 L p F P
0 0 0 r
s
1 .948 .201 r
.56977 1.0962 m .58234 1.09139 L .57444 1.11268 L p F P
0 0 0 r
s
1 .741 .161 r
.53222 1.027 m .51751 1.01846 L .51751 .92479 L p F P
0 0 0 r
s
.875 .487 .114 r
.54132 .92478 m .51751 .92479 L .51751 1.01846 L p F P
0 0 0 r
s
.875 .487 .114 r
.51751 1.01846 m .54181 1.01684 L .54132 .92478 L p F P
0 0 0 r
s
.403 .729 .611 r
.59705 .39523 m .52675 .38905 L .52667 .35305 L p F P
0 0 0 r
s
.181 .337 .311 r
.32302 .53898 m .27105 .56787 L .2731 .53038 L p F P
0 0 0 r
s
.181 .337 .311 r
.2731 .53038 m .32466 .50133 L .32302 .53898 L p F P
0 0 0 r
s
.502 .907 .732 r
.66429 .44732 m .72308 .47124 L .72481 .50823 L p F P
0 0 0 r
s
.502 .907 .732 r
.72308 .47124 m .66429 .44732 L .66307 .41082 L p F P
0 0 0 r
s
.675 .382 .093 r
.54048 1.013 m .51751 1.01846 L .51751 .92479 L p F P
0 0 0 r
s
.675 .382 .093 r
.51751 .92479 m .53936 .91892 L .54048 1.013 L p F P
0 0 0 r
s
.106 .065 .021 r
.52612 .91214 m .51751 .92479 L .51751 1.01846 L p F P
0 0 0 r
s
1 .558 .128 r
.49417 1.0136 m .51751 1.01846 L .51751 .92479 L p F P
0 0 0 r
s
1 .558 .128 r
.51751 .92479 m .49415 .92144 L .49417 1.0136 L p F P
0 0 0 r
s
1 .688 .153 r
.49892 .91604 m .51751 .92479 L .51751 1.01846 L p F P
0 0 0 r
s
.652 .382 .077 r
.51689 1.00463 m .51751 1.01846 L .51751 .92479 L p F P
0 0 0 r
s
.652 .382 .077 r
.51751 .92479 m .51502 .91135 L .51689 1.00463 L p F P
0 0 0 r
s
.65 .376 .076 r
.50484 .84273 m .50742 .86205 L .50021 .76622 L p F P
0 0 0 r
s
.65 .376 .076 r
.50021 .76622 m .49576 .75272 L .50484 .84273 L p F P
0 0 0 r
s
.455 .822 .676 r
.59705 .39523 m .66307 .41082 L .66429 .44732 L p F P
0 0 0 r
s
.797 .42 .095 r
.2861 .86627 m .30873 .88976 L .30748 .85007 L p F P
0 0 0 r
s
.863 .461 .104 r
.33066 .8626 m .30748 .85007 L .30873 .88976 L p F P
0 0 0 r
s
.67 .378 .077 r
.48212 .71129 m .48672 .72526 L .47443 .6534 L p F P
0 0 0 r
s
.67 .378 .077 r
.47443 .6534 m .46791 .64811 L .48212 .71129 L p F P
0 0 0 r
s
.738 .46 .121 r
.21922 .79113 m .19724 .76546 L .20384 .75116 L p F P
0 0 0 r
s
.386 .722 .553 r
.84119 .76528 m .81894 .72737 L .81641 .68824 L p F P
0 0 0 r
s
1 .611 .13 r
.54134 1.04158 m .5335 1.03651 L .53726 1.09828 L p F P
0 0 0 r
s
1 .611 .13 r
.53726 1.09828 m .54693 1.10064 L .54134 1.04158 L p F P
0 0 0 r
s
.344 .184 .046 r
.73235 .92006 m .70917 .93877 L .71042 .96972 L p F P
0 0 0 r
s
.344 .184 .046 r
.71042 .96972 m .73358 .94396 L .73235 .92006 L p F P
0 0 0 r
s
.289 .16 .043 r
.45686 1.09322 m .47171 1.09572 L .47681 1.03724 L p F P
0 0 0 r
s
.516 .302 .077 r
.44166 1.02796 m .46033 1.02935 L .46334 1.09184 L p F P
0 0 0 r
s
.516 .302 .077 r
.46334 1.09184 m .44574 1.08806 L .44166 1.02796 L p F P
0 0 0 r
s
.994 .551 .126 r
.47078 1.00612 m .49417 1.0136 L .49415 .92144 L p F P
0 0 0 r
s
.994 .551 .126 r
.49415 .92144 m .47076 .91673 L .47078 1.00612 L p F P
0 0 0 r
s
.863 .461 .104 r
.30873 .88976 m .33152 .912 L .33066 .8626 L p F P
0 0 0 r
s
.902 .486 .11 r
.3539 .8743 m .33066 .8626 L .33152 .912 L p F P
0 0 0 r
s
1 .757 .169 r
.39586 .75401 m .41365 .76348 L .40448 .85172 L p F P
0 0 0 r
s
1 .747 .166 r
.42352 .86717 m .40448 .85172 L .41365 .76348 L p F P
0 0 0 r
s
.305 .16 .041 r
.45686 1.09322 m .44225 1.08768 L .43478 1.10359 L p F P
0 0 0 r
s
.305 .204 .057 r
.7471 .67631 m .7263 .66442 L .71303 .63572 L p F P
0 0 0 r
s
.305 .204 .057 r
.71303 .63572 m .73288 .65282 L .7471 .67631 L p F P
0 0 0 r
s
.242 .105 .024 r
.73288 .65282 m .71303 .63572 L .69902 .62005 L p F P
0 0 0 r
s
.902 .486 .11 r
.33152 .912 m .35447 .93273 L .3539 .8743 L p F P
0 0 0 r
s
.927 .504 .115 r
.37721 .88507 m .3539 .8743 L .35447 .93273 L p F P
0 0 0 r
s
.984 .543 .124 r
.4474 .99608 m .47078 1.00612 L .47076 .91673 L p F P
0 0 0 r
s
.984 .543 .124 r
.47076 .91673 m .44735 .91068 L .4474 .99608 L p F P
0 0 0 r
s
.938 .59 .127 r
.77904 .88823 m .75646 .91668 L .75529 .91607 L p F P
0 0 0 r
s
.938 .59 .127 r
.75529 .91607 m .77774 .88419 L .77904 .88823 L p F P
0 0 0 r
s
.293 .536 .468 r
.45543 .42928 m .38738 .44244 L .38847 .40592 L p F P
0 0 0 r
s
.293 .536 .468 r
.38847 .40592 m .45595 .39269 L .45543 .42928 L p F P
0 0 0 r
s
.39082 .59509 m .40361 .58055 L .38751 .59517 L p F P
s
1 .906 .193 r
.37301 .60834 m .38751 .59517 L .37175 .62678 L p F P
0 0 0 r
s
.38751 .59517 m .37301 .60834 L .39082 .59509 L p F P
s
.838 .49 .12 r
.73785 .81048 m .71579 .82648 L .70669 .76139 L p F P
0 0 0 r
s
.838 .49 .12 r
.70669 .76139 m .72828 .75485 L .73785 .81048 L p F P
0 0 0 r
s
1 .948 .201 r
.57444 1.11268 m .56343 1.11843 L .56977 1.0962 L p F P
0 0 0 r
s
.602 .375 .1 r
.76014 .70692 m .7387 .70336 L .7263 .66442 L p F P
0 0 0 r
s
.602 .375 .1 r
.7263 .66442 m .7471 .67631 L .76014 .70692 L p F P
0 0 0 r
s
.689 .39 .095 r
.5635 1.00492 m .54048 1.013 L .53936 .91892 L p F P
0 0 0 r
s
.689 .39 .095 r
.53936 .91892 m .56129 .91167 L .5635 1.00492 L p F P
0 0 0 r
s
.927 .504 .115 r
.35447 .93273 m .37755 .95172 L .37721 .88507 L p F P
0 0 0 r
s
.945 .517 .118 r
.40056 .89478 m .37721 .88507 L .37755 .95172 L p F P
0 0 0 r
s
.972 .536 .122 r
.42404 .98357 m .4474 .99608 L .44735 .91068 L p F P
0 0 0 r
s
.972 .536 .122 r
.44735 .91068 m .42395 .90334 L .42404 .98357 L p F P
0 0 0 r
s
.237 .439 .392 r
.38628 .47958 m .32466 .50133 L .32627 .4643 L p F P
0 0 0 r
s
.237 .439 .392 r
.32627 .4643 m .38738 .44244 L .38628 .47958 L p F P
0 0 0 r
s
.207 .09 .021 r
.40916 .59617 m .42008 .58417 L .40361 .58055 L p F P
0 0 0 r
s
.207 .09 .021 r
.40361 .58055 m .39082 .59509 L .40916 .59617 L p F P
0 0 0 r
s
.945 .517 .118 r
.37755 .95172 m .40075 .96873 L .40056 .89478 L p F P
0 0 0 r
s
.96 .527 .12 r
.42395 .90334 m .40056 .89478 L .40075 .96873 L p F P
0 0 0 r
s
.96 .527 .12 r
.40075 .96873 m .42404 .98357 L .42395 .90334 L p F P
0 0 0 r
s
.294 .164 .044 r
.49021 1.03359 m .47681 1.03724 L .47171 1.09572 L p F P
0 0 0 r
s
1 1 .24 r
.81799 .80261 m .79613 .83451 L .79007 .80892 L p F P
0 0 0 r
s
1 1 .24 r
.79007 .80892 m .81199 .78266 L .81799 .80261 L p F P
0 0 0 r
s
1 1 .237 r
.7999 .85146 m .77774 .88419 L .77404 .86598 L p F P
0 0 0 r
s
1 1 .237 r
.77404 .86598 m .79613 .83451 L .7999 .85146 L p F P
0 0 0 r
s
1 .818 .177 r
.56977 1.0962 m .55699 1.09797 L .56115 1.03616 L p F P
0 0 0 r
s
1 .795 .172 r
.54678 1.03287 m .56115 1.03616 L .55699 1.09797 L p F P
0 0 0 r
s
.119 .219 .218 r
.26684 .64476 m .22673 .67876 L .22916 .64022 L p F P
0 0 0 r
s
.119 .219 .218 r
.22916 .64022 m .26896 .60599 L .26684 .64476 L p F P
0 0 0 r
s
.049 .03 .01 r
.62615 .65669 m .6134 .65968 L .60141 .72054 L p F P
0 0 0 r
s
.076 .046 .015 r
.59054 .73327 m .60141 .72054 L .6134 .65968 L p F P
0 0 0 r
s
.078 .048 .016 r
.57979 .74586 m .56914 .75832 L .56138 .84688 L p F P
0 0 0 r
s
.093 .057 .018 r
.55246 .86533 m .56138 .84688 L .56914 .75832 L p F P
0 0 0 r
s
.738 .46 .121 r
.20384 .75116 m .22507 .78469 L .21922 .79113 L p F P
0 0 0 r
s
.523 .336 .09 r
.24135 .81667 m .21922 .79113 L .22507 .78469 L p F P
0 0 0 r
s
1 .696 .155 r
.48021 .90588 m .49892 .91604 L .49742 1.01006 L p F P
0 0 0 r
s
1 .688 .153 r
.51751 1.01846 m .49742 1.01006 L .49892 .91604 L p F P
0 0 0 r
s
.242 .105 .024 r
.69902 .62005 m .71761 .63842 L .73288 .65282 L p F P
0 0 0 r
s
.311 .142 .031 r
.71761 .63842 m .69902 .62005 L .68427 .61845 L p F P
0 0 0 r
s
1 .979 .214 r
.37344 .67238 m .35639 .67191 L .37175 .62678 L p F P
0 0 0 r
s
1 .878 .195 r
.35639 .67191 m .37344 .67238 L .35987 .73486 L p F P
0 0 0 r
s
1 .844 .187 r
.37794 .74447 m .35987 .73486 L .37344 .67238 L p F P
0 0 0 r
s
.708 .376 .08 r
.45455 .63963 m .46129 .64356 L .44575 .60032 L p F P
0 0 0 r
s
.708 .376 .08 r
.44575 .60032 m .43702 .60496 L .45455 .63963 L p F P
0 0 0 r
s
.705 .4 .097 r
.58654 .99426 m .5635 1.00492 L .56129 .91167 L p F P
0 0 0 r
s
.705 .4 .097 r
.56129 .91167 m .58329 .90306 L .58654 .99426 L p F P
0 0 0 r
s
1 1 .257 r
.83378 .75626 m .81199 .78266 L .80387 .75958 L p F P
0 0 0 r
s
1 1 .257 r
.80387 .75958 m .82584 .74212 L .83378 .75626 L p F P
0 0 0 r
s
.305 .16 .041 r
.43478 1.10359 m .45083 1.11112 L .45686 1.09322 L p F P
0 0 0 r
s
.518 .315 .083 r
.4284 1.08126 m .44574 1.08806 L .45083 1.11112 L p F P
0 0 0 r
s
.518 .315 .083 r
.45083 1.11112 m .43478 1.10359 L .4284 1.08126 L p F P
0 0 0 r
s
.813 .497 .127 r
.77182 .74165 m .74999 .74827 L .7387 .70336 L p F P
0 0 0 r
s
.813 .497 .127 r
.7387 .70336 m .76014 .70692 L .77182 .74165 L p F P
0 0 0 r
s
.457 .25 .061 r
.70917 .93877 m .68577 .95602 L .68698 .99357 L p F P
0 0 0 r
s
.457 .25 .061 r
.68698 .99357 m .71042 .96972 L .70917 .93877 L p F P
0 0 0 r
s
.92 .543 .133 r
.75988 .79391 m .73785 .81048 L .72828 .75485 L p F P
0 0 0 r
s
.92 .543 .133 r
.72828 .75485 m .74999 .74827 L .75988 .79391 L p F P
0 0 0 r
s
.533 .965 .764 r
.72656 .54584 m .77549 .57635 L .77766 .61442 L p F P
0 0 0 r
s
.533 .965 .764 r
.77549 .57635 m .72656 .54584 L .72481 .50823 L p F P
0 0 0 r
s
1 .906 .193 r
.37175 .62678 m .35574 .6349 L .37301 .60834 L p F P
0 0 0 r
s
1 1 .229 r
.35574 .6349 m .37175 .62678 L .35639 .67191 L p F P
0 0 0 r
s
1 .767 .172 r
.37794 .74447 m .39586 .75401 L .38538 .83514 L p F P
0 0 0 r
s
1 .757 .169 r
.40448 .85172 m .38538 .83514 L .39586 .75401 L p F P
0 0 0 r
s
.097 .06 .019 r
.53483 .898 m .52612 .91214 L .52447 1.00515 L p F P
0 0 0 r
s
.106 .065 .021 r
.51751 1.01846 m .52447 1.00515 L .52612 .91214 L p F P
0 0 0 r
s
.906 .485 .105 r
.55645 1.09974 m .54693 1.10064 L .55221 1.12087 L p F P
0 0 0 r
s
.906 .485 .105 r
.55221 1.12087 m .56343 1.11843 L .55645 1.09974 L p F P
0 0 0 r
s
.623 .364 .072 r
.51627 .98803 m .51689 1.00463 L .51502 .91135 L p F P
0 0 0 r
s
.623 .364 .072 r
.51502 .91135 m .51251 .8964 L .51627 .98803 L p F P
0 0 0 r
s
.614 .353 .07 r
.50224 .82207 m .50484 .84273 L .49576 .75272 L p F P
0 0 0 r
s
.614 .353 .07 r
.49576 .75272 m .49127 .73907 L .50224 .82207 L p F P
0 0 0 r
s
.724 .412 .1 r
.60956 .98114 m .58654 .99426 L .58329 .90306 L p F P
0 0 0 r
s
.724 .412 .1 r
.58329 .90306 m .60534 .89313 L .60956 .98114 L p F P
0 0 0 r
s
.455 .822 .676 r
.66429 .44732 m .59772 .4318 L .59705 .39523 L p F P
0 0 0 r
s
.403 .729 .611 r
.52675 .38905 m .59705 .39523 L .59772 .4318 L p F P
0 0 0 r
s
.294 .164 .044 r
.47171 1.09572 m .48679 1.09497 L .49021 1.03359 L p F P
0 0 0 r
s
.513 .298 .075 r
.46033 1.02935 m .4792 1.02831 L .4812 1.09237 L p F P
0 0 0 r
s
.513 .298 .075 r
.4812 1.09237 m .46334 1.09184 L .46033 1.02935 L p F P
0 0 0 r
s
.497 .253 .056 r
.42809 .61075 m .43702 .60496 L .42008 .58417 L p F P
0 0 0 r
s
.497 .253 .056 r
.42008 .58417 m .40916 .59617 L .42809 .61075 L p F P
0 0 0 r
s
.653 .402 .107 r
.22507 .78469 m .20384 .75116 L .21252 .73712 L p F P
0 0 0 r
s
.523 .336 .09 r
.22507 .78469 m .2465 .81814 L .24135 .81667 L p F P
0 0 0 r
s
.256 .167 .049 r
.26365 .84182 m .24135 .81667 L .2465 .81814 L p F P
0 0 0 r
s
1 .703 .157 r
.4614 .89431 m .48021 .90588 L .47723 .99901 L p F P
0 0 0 r
s
1 .696 .155 r
.49742 1.01006 m .47723 .99901 L .48021 .90588 L p F P
0 0 0 r
s
.215 .095 .023 r
.65373 .62247 m .66872 .63014 L .68427 .61845 L p F P
0 0 0 r
s
.058 .026 .006 r
.66872 .63014 m .65373 .62247 L .63909 .65434 L p F P
0 0 0 r
s
.117 .059 .017 r
.62615 .65669 m .63909 .65434 L .65373 .62247 L p F P
0 0 0 r
s
.349 .634 .541 r
.52683 .42566 m .45543 .42928 L .45595 .39269 L p F P
0 0 0 r
s
.349 .634 .541 r
.45595 .39269 m .52675 .38905 L .52683 .42566 L p F P
0 0 0 r
s
1 .958 .221 r
.81199 .78266 m .79007 .80892 L .78189 .77689 L p F P
0 0 0 r
s
1 .958 .221 r
.78189 .77689 m .80387 .75958 L .81199 .78266 L p F P
0 0 0 r
s
.792 .502 .107 r
.75646 .91668 m .73358 .94396 L .73253 .94669 L p F P
0 0 0 r
s
.792 .502 .107 r
.73253 .94669 m .75529 .91607 L .75646 .91668 L p F P
0 0 0 r
s
.748 .426 .103 r
.63253 .96567 m .60956 .98114 L .60534 .89313 L p F P
0 0 0 r
s
.748 .426 .103 r
.60534 .89313 m .62742 .88195 L .63253 .96567 L p F P
0 0 0 r
s
1 .936 .2 r
.55699 1.09797 m .56977 1.0962 L .56343 1.11843 L p F P
0 0 0 r
s
1 .628 .134 r
.5335 1.03651 m .52556 1.02884 L .52745 1.09247 L p F P
0 0 0 r
s
1 .628 .134 r
.52745 1.09247 m .53726 1.09828 L .5335 1.03651 L p F P
0 0 0 r
s
1 .963 .218 r
.79613 .83451 m .77404 .86598 L .768 .83477 L p F P
0 0 0 r
s
1 .963 .218 r
.768 .83477 m .79007 .80892 L .79613 .83451 L p F P
0 0 0 r
s
1 .631 .154 r
.78189 .77689 m .75988 .79391 L .74999 .74827 L p F P
0 0 0 r
s
1 .631 .154 r
.74999 .74827 m .77182 .74165 L .78189 .77689 L p F P
0 0 0 r
s
.515 .942 .734 r
.77988 .65313 m .81641 .68824 L .81894 .72737 L p F P
0 0 0 r
s
.515 .942 .734 r
.81641 .68824 m .77988 .65313 L .77766 .61442 L p F P
0 0 0 r
s
.615 .344 .069 r
.47747 .69717 m .48212 .71129 L .46791 .64811 L p F P
0 0 0 r
s
.615 .344 .069 r
.46791 .64811 m .46129 .64356 L .47747 .69717 L p F P
0 0 0 r
s
.55 .302 .072 r
.68577 .95602 m .66216 .97157 L .66328 1.01519 L p F P
0 0 0 r
s
.55 .302 .072 r
.66328 1.01519 m .68698 .99357 L .68577 .95602 L p F P
0 0 0 r
s
.403 .729 .611 r
.59772 .4318 m .52683 .42566 L .52675 .38905 L p F P
0 0 0 r
s
.181 .337 .311 r
.32136 .57728 m .26896 .60599 L .27105 .56787 L p F P
0 0 0 r
s
.181 .337 .311 r
.27105 .56787 m .32302 .53898 L .32136 .57728 L p F P
0 0 0 r
s
.502 .907 .732 r
.66554 .48444 m .72481 .50823 L .72656 .54584 L p F P
0 0 0 r
s
.502 .907 .732 r
.72481 .50823 m .66554 .48444 L .66429 .44732 L p F P
0 0 0 r
s
.777 .444 .108 r
.65542 .94802 m .63253 .96567 L .62742 .88195 L p F P
0 0 0 r
s
.777 .444 .108 r
.62742 .88195 m .64952 .8696 L .65542 .94802 L p F P
0 0 0 r
s
1 1 .237 r
.77774 .88419 m .75529 .91607 L .75169 .89662 L p F P
0 0 0 r
s
1 1 .237 r
.75169 .89662 m .77404 .86598 L .77774 .88419 L p F P
0 0 0 r
s
.311 .142 .031 r
.68427 .61845 m .70132 .63391 L .71761 .63842 L p F P
0 0 0 r
s
.215 .092 .021 r
.70132 .63391 m .68427 .61845 L .66872 .63014 L p F P
0 0 0 r
s
.058 .035 .012 r
.59054 .73327 m .57979 .74586 L .57036 .82712 L p F P
0 0 0 r
s
.078 .048 .016 r
.56138 .84688 m .57036 .82712 L .57979 .74586 L p F P
0 0 0 r
s
.304 .171 .046 r
.50378 1.02736 m .49021 1.03359 L .48679 1.09497 L p F P
0 0 0 r
s
.455 .822 .676 r
.59772 .4318 m .66429 .44732 L .66554 .48444 L p F P
0 0 0 r
s
.295 .156 .041 r
.47171 1.09572 m .45686 1.09322 L .45083 1.11112 L p F P
0 0 0 r
s
1 .795 .172 r
.55699 1.09797 m .544 1.09648 L .54678 1.03287 L p F P
0 0 0 r
s
1 .774 .167 r
.53222 1.027 m .54678 1.03287 L .544 1.09648 L p F P
0 0 0 r
s
.814 .466 .113 r
.67821 .92839 m .65542 .94802 L .64952 .8696 L p F P
0 0 0 r
s
.814 .466 .113 r
.64952 .8696 m .67162 .85616 L .67821 .92839 L p F P
0 0 0 r
s
1 .779 .175 r
.35987 .73486 m .37794 .74447 L .36624 .81753 L p F P
0 0 0 r
s
1 .767 .172 r
.38538 .83514 m .36624 .81753 L .37794 .74447 L p F P
0 0 0 r
s
.256 .167 .049 r
.2465 .81814 m .26813 .85111 L .26365 .84182 L p F P
0 0 0 r
s
.394 .198 .041 r
.2861 .86627 m .26365 .84182 L .26813 .85111 L p F P
0 0 0 r
s
1 .709 .158 r
.4425 .88139 m .4614 .89431 L .45697 .98534 L p F P
0 0 0 r
s
1 .703 .157 r
.47723 .99901 m .45697 .98534 L .4614 .89431 L p F P
0 0 0 r
s
1 .785 .184 r
.79007 .80892 m .768 .83477 L .75988 .79391 L p F P
0 0 0 r
s
1 .785 .184 r
.75988 .79391 m .78189 .77689 L .79007 .80892 L p F P
0 0 0 r
s
.862 .495 .119 r
.70088 .90699 m .67821 .92839 L .67162 .85616 L p F P
0 0 0 r
s
.862 .495 .119 r
.67162 .85616 m .69371 .84174 L .70088 .90699 L p F P
0 0 0 r
s
.9 .566 .146 r
.79377 .735 m .77182 .74165 L .76014 .70692 L p F P
0 0 0 r
s
.9 .566 .146 r
.76014 .70692 m .78185 .71082 L .79377 .735 L p F P
0 0 0 r
s
.494 .322 .087 r
.78185 .71082 m .76014 .70692 L .7471 .67631 L p F P
0 0 0 r
s
.494 .322 .087 r
.7471 .67631 m .76826 .68894 L .78185 .71082 L p F P
0 0 0 r
s
.245 .159 .047 r
.76826 .68894 m .7471 .67631 L .73288 .65282 L p F P
0 0 0 r
s
1 .966 .23 r
.82584 .74212 m .80387 .75958 L .79377 .735 L p F P
0 0 0 r
s
1 .966 .23 r
.79377 .735 m .81584 .72831 L .82584 .74212 L p F P
0 0 0 r
s
.086 .053 .017 r
.54361 .88239 m .53483 .898 L .53151 .98908 L p F P
0 0 0 r
s
.097 .06 .019 r
.52447 1.00515 m .53151 .98908 L .53483 .898 L p F P
0 0 0 r
s
.925 .535 .128 r
.7234 .88408 m .70088 .90699 L .69371 .84174 L p F P
0 0 0 r
s
.925 .535 .128 r
.69371 .84174 m .71579 .82648 L .7234 .88408 L p F P
0 0 0 r
s
.006 .003 .001 r
.63909 .65434 m .62615 .65669 L .6124 .70769 L p F P
0 0 0 r
s
.049 .03 .01 r
.60141 .72054 m .6124 .70769 L .62615 .65669 L p F P
0 0 0 r
s
1 .782 .19 r
.80387 .75958 m .78189 .77689 L .77182 .74165 L p F P
0 0 0 r
s
1 .782 .19 r
.77182 .74165 m .79377 .735 L .80387 .75958 L p F P
0 0 0 r
s
1 .936 .2 r
.56343 1.11843 m .55221 1.12087 L .55699 1.09797 L p F P
0 0 0 r
s
.653 .402 .107 r
.21252 .73712 m .23313 .77417 L .22507 .78469 L p F P
0 0 0 r
s
.611 .379 .101 r
.2465 .81814 m .22507 .78469 L .23313 .77417 L p F P
0 0 0 r
s
1 1 .229 r
.35639 .67191 m .3391 .67201 L .35574 .6349 L p F P
0 0 0 r
s
1 .923 .206 r
.3391 .67201 m .35639 .67191 L .34165 .72516 L p F P
0 0 0 r
s
1 .878 .195 r
.35987 .73486 m .34165 .72516 L .35639 .67191 L p F P
0 0 0 r
s
1 .589 .141 r
.74578 .85991 m .7234 .88408 L .71579 .82648 L p F P
0 0 0 r
s
1 .589 .141 r
.71579 .82648 m .73785 .81048 L .74578 .85991 L p F P
0 0 0 r
s
.293 .536 .468 r
.4549 .46649 m .38628 .47958 L .38738 .44244 L p F P
0 0 0 r
s
.293 .536 .468 r
.38738 .44244 m .45543 .42928 L .4549 .46649 L p F P
0 0 0 r
s
1 .668 .158 r
.73785 .81048 m .75988 .79391 L .768 .83477 L p F P
0 0 0 r
s
1 .668 .158 r
.768 .83477 m .74578 .85991 L .73785 .81048 L p F P
0 0 0 r
s
.237 .439 .392 r
.38515 .51736 m .32302 .53898 L .32466 .50133 L p F P
0 0 0 r
s
.237 .439 .392 r
.32466 .50133 m .38628 .47958 L .38515 .51736 L p F P
0 0 0 r
s
.587 .342 .067 r
.51564 .96869 m .51627 .98803 L .51275 .90217 L p F P
0 0 0 r
s
.587 .342 .067 r
.51275 .90217 m .51261 .8988 L p .51277 .90244 L F P
0 0 0 r
s
.587 .342 .067 r
.51277 .90244 m .51564 .96869 L .51275 .90217 L F
.51267 .89991 m .51564 .96869 L .51261 .8988 L F
.51261 .8988 m .51251 .8964 L p .51267 .89991 L F P
0 0 0 r
s
.587 .342 .067 r
.51251 .8964 m .50998 .87996 L .51564 .96869 L p F P
0 0 0 r
s
.543 .315 .061 r
.51501 .94669 m .51564 .96869 L .50998 .87996 L p F P
0 0 0 r
s
.543 .315 .061 r
.50998 .87996 m .50742 .86205 L .51482 .94457 L p F P
0 0 0 r
s
.543 .315 .061 r
.50998 .87996 m .51482 .94457 L .51477 .94345 L F
.51482 .94457 m .51501 .94669 L p .51477 .94345 L F P
0 0 0 r
s
.503 .291 .056 r
.51438 .92215 m .51501 .94669 L .50742 .86205 L p F P
0 0 0 r
s
.503 .291 .056 r
.50742 .86205 m .50484 .84273 L .51391 .91827 L p F P
0 0 0 r
s
.503 .291 .056 r
.51391 .91827 m .51438 .92215 L p .51388 .91789 L F P
0 0 0 r
s
.503 .291 .056 r
.50742 .86205 m .51391 .91827 L .51388 .91789 L F
.624 .343 .082 r
.66216 .97157 m .63836 .98519 L .63935 1.03425 L p F P
0 0 0 r
s
.624 .343 .082 r
.63935 1.03425 m .66328 1.01519 L .66216 .97157 L p F P
0 0 0 r
s
.304 .171 .046 r
.48679 1.09497 m .50206 1.0908 L .50378 1.02736 L p F P
0 0 0 r
s
.506 .293 .074 r
.4792 1.02831 m .49827 1.0247 L .49926 1.08949 L p F P
0 0 0 r
s
.506 .293 .074 r
.49926 1.08949 m .4812 1.09237 L .4792 1.02831 L p F P
0 0 0 r
s
.295 .156 .041 r
.45083 1.11112 m .46716 1.11536 L .47171 1.09572 L p F P
0 0 0 r
s
.532 .319 .083 r
.44574 1.08806 m .46334 1.09184 L .46716 1.11536 L p F P
0 0 0 r
s
.532 .319 .083 r
.46716 1.11536 m .45083 1.11112 L .44574 1.08806 L p F P
0 0 0 r
s
.565 .323 .063 r
.49963 .80015 m .50224 .82207 L .49127 .73907 L p F P
0 0 0 r
s
.565 .323 .063 r
.49127 .73907 m .48672 .72526 L .49963 .80015 L p F P
0 0 0 r
s
.245 .159 .047 r
.73288 .65282 m .75315 .67096 L .76826 .68894 L p F P
0 0 0 r
s
.297 .136 .03 r
.75315 .67096 m .73288 .65282 L .71761 .63842 L p F P
0 0 0 r
s
.119 .219 .218 r
.26468 .6842 m .22426 .71795 L .22673 .67876 L p F P
0 0 0 r
s
.119 .219 .218 r
.22673 .67876 m .26684 .64476 L .26468 .6842 L p F P
0 0 0 r
s
1 .847 .194 r
.77404 .86598 m .75169 .89662 L .74578 .85991 L p F P
0 0 0 r
s
1 .847 .194 r
.74578 .85991 m .768 .83477 L .77404 .86598 L p F P
0 0 0 r
s
.73358 .94396 m .71042 .96972 L .70948 .97565 L p F P
s
.70948 .97565 m .73253 .94669 L .73358 .94396 L p F P
s
.394 .198 .041 r
.26813 .85111 m .28998 .88323 L .2861 .86627 L p F P
0 0 0 r
s
.628 .329 .07 r
.30873 .88976 m .2861 .86627 L .28998 .88323 L p F P
0 0 0 r
s
.66 .405 .106 r
.23313 .77417 m .21252 .73712 L .22326 .72345 L p F P
0 0 0 r
s
1 .714 .16 r
.42352 .86717 m .4425 .88139 L .43668 .96916 L p F P
0 0 0 r
s
1 .709 .158 r
.45697 .98534 m .43668 .96916 L .4425 .88139 L p F P
0 0 0 r
s
.3777 .61108 m .39082 .59509 L .37301 .60834 L p F P
s
1 .674 .145 r
.35817 .62282 m .37301 .60834 L .35574 .6349 L p F P
0 0 0 r
s
.37301 .60834 m .35817 .62282 L .3777 .61108 L p F P
s
.81 .529 .135 r
.81584 .72831 m .79377 .735 L .78185 .71082 L p F P
0 0 0 r
s
1 .791 .179 r
.34165 .72516 m .35987 .73486 L .34706 .79902 L p F P
0 0 0 r
s
1 .779 .175 r
.36624 .81753 m .34706 .79902 L .35987 .73486 L p F P
0 0 0 r
s
.983 .534 .115 r
.54693 1.10064 m .53726 1.09828 L .5408 1.11976 L p F P
0 0 0 r
s
.983 .534 .115 r
.5408 1.11976 m .55221 1.12087 L .54693 1.10064 L p F P
0 0 0 r
s
.533 .965 .764 r
.72835 .5841 m .77766 .61442 L .77988 .65313 L p F P
0 0 0 r
s
.533 .965 .764 r
.77766 .61442 m .72835 .5841 L .72656 .54584 L p F P
0 0 0 r
s
1 1 .23 r
.75529 .91607 m .73253 .94669 L .72909 .92606 L p F P
0 0 0 r
s
1 1 .23 r
.72909 .92606 m .75169 .89662 L .75529 .91607 L p F P
0 0 0 r
s
1 .65 .138 r
.52556 1.02884 m .51751 1.01846 L .51751 1.08309 L p F P
0 0 0 r
s
1 .65 .138 r
.51751 1.08309 m .52745 1.09247 L .52556 1.02884 L p F P
0 0 0 r
s
.684 .377 .089 r
.63836 .98519 m .6144 .99668 L .61521 1.05049 L p F P
0 0 0 r
s
.684 .377 .089 r
.61521 1.05049 m .63935 1.03425 L .63836 .98519 L p F P
0 0 0 r
s
.579 .3 .064 r
.44769 .63621 m .45455 .63963 L .43702 .60496 L p F P
0 0 0 r
s
.579 .3 .064 r
.43702 .60496 m .42809 .61075 L .44769 .63621 L p F P
0 0 0 r
s
.172 .074 .017 r
.39797 .60948 m .40916 .59617 L .39082 .59509 L p F P
0 0 0 r
s
.172 .074 .017 r
.39082 .59509 m .3777 .61108 L .39797 .60948 L p F P
0 0 0 r
s
.028 .017 .006 r
.60141 .72054 m .59054 .73327 L .5794 .80612 L p F P
0 0 0 r
s
.058 .035 .012 r
.57036 .82712 m .5794 .80612 L .59054 .73327 L p F P
0 0 0 r
s
1 .674 .145 r
.35574 .6349 m .33942 .64397 L .35817 .62282 L p F P
0 0 0 r
s
1 1 .246 r
.33942 .64397 m .35574 .6349 L .3391 .67201 L p F P
0 0 0 r
s
.318 .18 .048 r
.51751 1.01846 m .50378 1.02736 L .50206 1.0908 L p F P
0 0 0 r
s
.297 .136 .03 r
.71761 .63842 m .73663 .65796 L .75315 .67096 L p F P
0 0 0 r
s
.312 .143 .031 r
.73663 .65796 m .71761 .63842 L .70132 .63391 L p F P
0 0 0 r
s
1 .774 .167 r
.544 1.09648 m .53083 1.09156 L .53222 1.027 L p F P
0 0 0 r
s
1 .754 .163 r
.51751 1.01846 m .53222 1.027 L .53083 1.09156 L p F P
0 0 0 r
s
.455 .822 .676 r
.66554 .48444 m .5984 .469 L .59772 .4318 L p F P
0 0 0 r
s
.403 .729 .611 r
.52683 .42566 m .59772 .4318 L .5984 .469 L p F P
0 0 0 r
s
.611 .379 .101 r
.23313 .77417 m .25394 .81113 L .2465 .81814 L p F P
0 0 0 r
s
.552 .346 .093 r
.26813 .85111 m .2465 .81814 L .25394 .81113 L p F P
0 0 0 r
s
.628 .329 .07 r
.28998 .88323 m .31205 .91413 L .30873 .88976 L p F P
0 0 0 r
s
.828 .436 .096 r
.33152 .912 m .30873 .88976 L .31205 .91413 L p F P
0 0 0 r
s
1 .893 .192 r
.544 1.09648 m .55699 1.09797 L .55221 1.12087 L p F P
0 0 0 r
s
1 .718 .161 r
.40448 .85172 m .42352 .86717 L .41636 .95057 L p F P
0 0 0 r
s
1 .714 .16 r
.43668 .96916 m .41636 .95057 L .42352 .86717 L p F P
0 0 0 r
s
1 .748 .174 r
.7234 .88408 m .74578 .85991 L .75169 .89662 L p F P
0 0 0 r
s
.072 .044 .014 r
.55246 .86533 m .54361 .88239 L .5386 .97029 L p F P
0 0 0 r
s
.086 .053 .017 r
.53151 .98908 m .5386 .97029 L .54361 .88239 L p F P
0 0 0 r
s
.349 .634 .541 r
.52691 .46289 m .4549 .46649 L .45543 .42928 L p F P
0 0 0 r
s
.349 .634 .541 r
.45543 .42928 m .52683 .42566 L .52691 .46289 L p F P
0 0 0 r
s
.318 .18 .048 r
.50206 1.0908 m .51751 1.08309 L .51751 1.01846 L p F P
0 0 0 r
s
.495 .286 .072 r
.49827 1.0247 m .51751 1.01846 L .51751 1.08309 L p F P
0 0 0 r
s
.495 .286 .072 r
.51751 1.08309 m .49926 1.08949 L .49827 1.0247 L p F P
0 0 0 r
s
.541 .296 .059 r
.47276 .68288 m .47747 .69717 L .46129 .64356 L p F P
0 0 0 r
s
.541 .296 .059 r
.46129 .64356 m .45455 .63963 L .47276 .68288 L p F P
0 0 0 r
s
.297 .161 .042 r
.48679 1.09497 m .47171 1.09572 L .46716 1.11536 L p F P
0 0 0 r
s
.81 .529 .135 r
.78185 .71082 m .8038 .71492 L .81584 .72831 L p F P
0 0 0 r
s
.329 .225 .06 r
.8038 .71492 m .78185 .71082 L .76826 .68894 L p F P
0 0 0 r
s
.732 .404 .096 r
.6144 .99668 m .5903 1.00587 L .59092 1.06366 L p F P
0 0 0 r
s
.732 .404 .096 r
.59092 1.06366 m .61521 1.05049 L .6144 .99668 L p F P
0 0 0 r
s
.215 .092 .021 r
.66872 .63014 m .68401 .63875 L .70132 .63391 L p F P
0 0 0 r
s
.029 .013 .003 r
.68401 .63875 m .66872 .63014 L .65224 .65254 L p F P
0 0 0 r
s
.058 .026 .006 r
.63909 .65434 m .65224 .65254 L .66872 .63014 L p F P
0 0 0 r
s
1 .748 .174 r
.75169 .89662 m .72909 .92606 L .7234 .88408 L p F P
0 0 0 r
s
.515 .942 .734 r
.81894 .72737 m .78213 .69251 L .77988 .65313 L p F P
0 0 0 r
s
.71042 .96972 m .68698 .99357 L .68615 1.00254 L p F P
s
.68615 1.00254 m .70948 .97565 L .71042 .96972 L p F P
s
.66 .405 .106 r
.22326 .72345 m .24339 .75924 L .23313 .77417 L p F P
0 0 0 r
s
.701 .429 .112 r
.25394 .81113 m .23313 .77417 L .24339 .75924 L p F P
0 0 0 r
s
.828 .436 .096 r
.31205 .91413 m .33434 .94343 L .33152 .912 L p F P
0 0 0 r
s
.915 .486 .108 r
.35447 .93273 m .33152 .912 L .33434 .94343 L p F P
0 0 0 r
s
.403 .729 .611 r
.5984 .469 m .52691 .46289 L .52683 .42566 L p F P
0 0 0 r
s
.181 .337 .311 r
.31966 .61625 m .26684 .64476 L .26896 .60599 L p F P
0 0 0 r
s
.181 .337 .311 r
.26896 .60599 m .32136 .57728 L .31966 .61625 L p F P
0 0 0 r
s
.502 .907 .732 r
.6668 .52219 m .72656 .54584 L .72835 .5841 L p F P
0 0 0 r
s
.502 .907 .732 r
.72656 .54584 m .6668 .52219 L .66554 .48444 L p F P
0 0 0 r
s
1 .721 .163 r
.38538 .83514 m .40448 .85172 L .39607 .92974 L p F P
0 0 0 r
s
1 .718 .161 r
.41636 .95057 m .39607 .92974 L .40448 .85172 L p F P
0 0 0 r
s
1 .668 .157 r
.70088 .90699 m .7234 .88408 L .72909 .92606 L p F P
0 0 0 r
s
.522 .295 .058 r
.49699 .77709 m .49963 .80015 L .48672 .72526 L p F P
0 0 0 r
s
.522 .295 .058 r
.48672 .72526 m .48212 .71129 L .49699 .77709 L p F P
0 0 0 r
s
1 1 .246 r
.3391 .67201 m .32156 .67255 L .33942 .64397 L p F P
0 0 0 r
s
1 .981 .221 r
.32156 .67255 m .3391 .67201 L .3233 .71539 L p F P
0 0 0 r
s
1 .923 .206 r
.34165 .72516 m .3233 .71539 L .3391 .67201 L p F P
0 0 0 r
s
1 .803 .183 r
.3233 .71539 m .34165 .72516 L .32786 .77972 L p F P
0 0 0 r
s
1 .791 .179 r
.34706 .79902 m .32786 .77972 L .34165 .72516 L p F P
0 0 0 r
s
.455 .822 .676 r
.5984 .469 m .66554 .48444 L .6668 .52219 L p F P
0 0 0 r
s
.77 .427 .101 r
.5903 1.00587 m .56609 1.01262 L .5665 1.07356 L p F P
0 0 0 r
s
.77 .427 .101 r
.5665 1.07356 m .59092 1.06366 L .5903 1.00587 L p F P
0 0 0 r
s
.336 .163 .037 r
.41898 .61745 m .42809 .61075 L .40916 .59617 L p F P
0 0 0 r
s
.336 .163 .037 r
.40916 .59617 m .39797 .60948 L .41898 .61745 L p F P
0 0 0 r
s
.297 .161 .042 r
.46716 1.11536 m .48374 1.11607 L .48679 1.09497 L p F P
0 0 0 r
s
.527 .312 .081 r
.46334 1.09184 m .4812 1.09237 L .48374 1.11607 L p F P
0 0 0 r
s
.527 .312 .081 r
.48374 1.11607 m .46716 1.11536 L .46334 1.09184 L p F P
0 0 0 r
s
.65224 .65254 m .63909 .65434 L .6235 .6947 L p F P
s
.006 .003 .001 r
.6124 .70769 m .6235 .6947 L .63909 .65434 L p F P
0 0 0 r
s
.732 .448 .117 r
.24339 .75924 m .22326 .72345 L .23601 .71024 L p F P
0 0 0 r
s
1 .893 .192 r
.55221 1.12087 m .5408 1.11976 L .544 1.09648 L p F P
0 0 0 r
s
.552 .346 .093 r
.25394 .81113 m .27496 .84759 L .26813 .85111 L p F P
0 0 0 r
s
.457 .293 .08 r
.28998 .88323 m .26813 .85111 L .27496 .84759 L p F P
0 0 0 r
s
1 .977 .22 r
.73253 .94669 m .70948 .97565 L .70625 .95393 L p F P
0 0 0 r
s
1 .977 .22 r
.70625 .95393 m .72909 .92606 L .73253 .94669 L p F P
0 0 0 r
s
.329 .225 .06 r
.76826 .68894 m .78979 .70206 L .8038 .71492 L p F P
0 0 0 r
s
.249 .107 .024 r
.78979 .70206 m .76826 .68894 L .75315 .67096 L p F P
0 0 0 r
s
.801 .445 .105 r
.56609 1.01262 m .54181 1.01684 L .54202 1.08007 L p F P
0 0 0 r
s
.801 .445 .105 r
.54202 1.08007 m .5665 1.07356 L .56609 1.01262 L p F P
0 0 0 r
s
.915 .486 .108 r
.33434 .94343 m .35683 .97076 L .35447 .93273 L p F P
0 0 0 r
s
.952 .511 .114 r
.37755 .95172 m .35447 .93273 L .35683 .97076 L p F P
0 0 0 r
s
1 .668 .157 r
.72909 .92606 m .70625 .95393 L .70088 .90699 L p F P
0 0 0 r
s
1 .606 .143 r
.67821 .92839 m .70088 .90699 L .70625 .95393 L p F P
0 0 0 r
s
1 .722 .164 r
.36624 .81753 m .38538 .83514 L .37581 .90687 L p F P
0 0 0 r
s
1 .721 .163 r
.39607 .92974 m .37581 .90687 L .38538 .83514 L p F P
0 0 0 r
s
.293 .536 .468 r
.45436 .50434 m .38515 .51736 L .38628 .47958 L p F P
0 0 0 r
s
.293 .536 .468 r
.38628 .47958 m .4549 .46649 L .45436 .50434 L p F P
0 0 0 r
s
.312 .143 .031 r
.70132 .63391 m .71877 .65041 L .73663 .65796 L p F P
0 0 0 r
s
.219 .094 .021 r
.71877 .65041 m .70132 .63391 L .68401 .63875 L p F P
0 0 0 r
s
.6124 .70769 m .60141 .72054 L .5885 .784 L p F P
s
.028 .017 .006 r
.5794 .80612 m .5885 .784 L .60141 .72054 L p F P
0 0 0 r
s
1 .754 .163 r
.53083 1.09156 m .51751 1.08309 L .51751 1.01846 L p F P
0 0 0 r
s
.825 .46 .108 r
.54181 1.01684 m .51751 1.01846 L .51751 1.08309 L p F P
0 0 0 r
s
.825 .46 .108 r
.51751 1.08309 m .54202 1.08007 L .54181 1.01684 L p F P
0 0 0 r
s
.726 .41 .099 r
.54134 1.07818 m .51751 1.08309 L .51751 1.01846 L p F P
0 0 0 r
s
.726 .41 .099 r
.51751 1.01846 m .54048 1.013 L .54134 1.07818 L p F P
0 0 0 r
s
.078 .048 .016 r
.52447 1.00515 m .51751 1.01846 L .51751 1.08309 L p F P
0 0 0 r
s
1 .578 .132 r
.49448 1.07693 m .51751 1.08309 L .51751 1.01846 L p F P
0 0 0 r
s
1 .578 .132 r
.51751 1.01846 m .49417 1.0136 L .49448 1.07693 L p F P
0 0 0 r
s
1 .67 .15 r
.49742 1.01006 m .51751 1.01846 L .51751 1.08309 L p F P
0 0 0 r
s
.078 .048 .016 r
.51751 1.08309 m .52268 1.0693 L .52447 1.00515 L p F P
0 0 0 r
s
.521 .306 .059 r
.51883 1.06904 m .51751 1.08309 L .51751 1.01846 L p F P
0 0 0 r
s
.521 .306 .059 r
.51751 1.01846 m .51689 1.00463 L .51883 1.06904 L p F P
0 0 0 r
s
.237 .439 .392 r
.38401 .55579 m .32136 .57728 L .32302 .53898 L p F P
0 0 0 r
s
.237 .439 .392 r
.32302 .53898 m .38515 .51736 L .38401 .55579 L p F P
0 0 0 r
s
.053 .032 .011 r
.56138 .84688 m .55246 .86533 L .54574 .94885 L p F P
0 0 0 r
s
.072 .044 .014 r
.5386 .97029 m .54574 .94885 L .55246 .86533 L p F P
0 0 0 r
s
.952 .511 .114 r
.35683 .97076 m .3795 .99579 L .37755 .95172 L p F P
0 0 0 r
s
.974 .527 .118 r
.40075 .96873 m .37755 .95172 L .3795 .99579 L p F P
0 0 0 r
s
1 .587 .126 r
.53726 1.09828 m .52745 1.09247 L .52923 1.11491 L p F P
0 0 0 r
s
1 .587 .126 r
.52923 1.11491 m .5408 1.11976 L .53726 1.09828 L p F P
0 0 0 r
s
.092 .044 .012 r
.68698 .99357 m .66328 1.01519 L .66255 1.027 L p F P
0 0 0 r
s
.092 .044 .012 r
.66255 1.027 m .68615 1.00254 L .68698 .99357 L p F P
0 0 0 r
s
1 .606 .143 r
.70625 .95393 m .68317 .97986 L .67821 .92839 L p F P
0 0 0 r
s
.969 .556 .132 r
.65542 .94802 m .67821 .92839 L .68317 .97986 L p F P
0 0 0 r
s
.701 .429 .112 r
.24339 .75924 m .26367 .79489 L .25394 .81113 L p F P
0 0 0 r
s
.752 .458 .118 r
.27496 .84759 m .25394 .81113 L .26367 .79489 L p F P
0 0 0 r
s
1 .721 .165 r
.34706 .79902 m .36624 .81753 L .3556 .88217 L p F P
0 0 0 r
s
1 .722 .164 r
.37581 .90687 m .3556 .88217 L .36624 .81753 L p F P
0 0 0 r
s
1 .568 .129 r
.4714 1.06726 m .49448 1.07693 L .49417 1.0136 L p F P
0 0 0 r
s
1 .568 .129 r
.49417 1.0136 m .47078 1.00612 L .4714 1.06726 L p F P
0 0 0 r
s
.749 .424 .102 r
.56519 1.06976 m .54134 1.07818 L .54048 1.013 L p F P
0 0 0 r
s
.749 .424 .102 r
.54048 1.013 m .5635 1.00492 L .56519 1.06976 L p F P
0 0 0 r
s
1 .842 .181 r
.53083 1.09156 m .544 1.09648 L .5408 1.11976 L p F P
0 0 0 r
s
.974 .527 .118 r
.3795 .99579 m .40233 1.01821 L .40075 .96873 L p F P
0 0 0 r
s
.989 .539 .122 r
.42404 .98357 m .40075 .96873 L .40233 1.01821 L p F P
0 0 0 r
s
.732 .448 .117 r
.23601 .71024 m .25575 .74033 L .24339 .75924 L p F P
0 0 0 r
s
.84 .509 .129 r
.26367 .79489 m .24339 .75924 L .25575 .74033 L p F P
0 0 0 r
s
1 .981 .221 r
.3233 .71539 m .30479 .70555 L .32156 .67255 L p F P
0 0 0 r
s
1 .811 .188 r
.30479 .70555 m .3233 .71539 L .30862 .75978 L p F P
0 0 0 r
s
1 .803 .183 r
.32786 .77972 m .30862 .75978 L .3233 .71539 L p F P
0 0 0 r
s
.249 .107 .024 r
.75315 .67096 m .77385 .68983 L .78979 .70206 L p F P
0 0 0 r
s
.33 .155 .034 r
.77385 .68983 m .75315 .67096 L .73663 .65796 L p F P
0 0 0 r
s
1 .558 .127 r
.44832 1.05415 m .4714 1.06726 L .47078 1.00612 L p F P
0 0 0 r
s
1 .558 .127 r
.47078 1.00612 m .4474 .99608 L .44832 1.05415 L p F P
0 0 0 r
s
.969 .556 .132 r
.68317 .97986 m .65988 1.00353 L .65542 .94802 L p F P
0 0 0 r
s
.904 .517 .123 r
.63253 .96567 m .65542 .94802 L .65988 1.00353 L p F P
0 0 0 r
s
.989 .539 .122 r
.40233 1.01821 m .42528 1.03774 L .42404 .98357 L p F P
0 0 0 r
s
1 .549 .124 r
.4474 .99608 m .42404 .98357 L .42528 1.03774 L p F P
0 0 0 r
s
.312 .172 .045 r
.50206 1.0908 m .48679 1.09497 L .48374 1.11607 L p F P
0 0 0 r
s
1 .549 .124 r
.42528 1.03774 m .44832 1.05415 L .4474 .99608 L p F P
0 0 0 r
s
.457 .293 .08 r
.27496 .84759 m .29619 .88314 L .28998 .88323 L p F P
0 0 0 r
s
.319 .214 .06 r
.31205 .91413 m .28998 .88323 L .29619 .88314 L p F P
0 0 0 r
s
.533 .965 .764 r
.73017 .62302 m .77988 .65313 L .78213 .69251 L p F P
0 0 0 r
s
.533 .965 .764 r
.77988 .65313 m .73017 .62302 L .72835 .5841 L p F P
0 0 0 r
s
.776 .44 .106 r
.58901 1.05793 m .56519 1.06976 L .5635 1.00492 L p F P
0 0 0 r
s
.776 .44 .106 r
.5635 1.00492 m .58654 .99426 L .58901 1.05793 L p F P
0 0 0 r
s
1 .715 .165 r
.32786 .77972 m .34706 .79902 L .33546 .85589 L p F P
0 0 0 r
s
1 .721 .165 r
.3556 .88217 m .33546 .85589 L .34706 .79902 L p F P
0 0 0 r
s
1 .68 .152 r
.47723 .99901 m .49742 1.01006 L .49613 1.07519 L p F P
0 0 0 r
s
1 .67 .15 r
.51751 1.08309 m .49613 1.07519 L .49742 1.01006 L p F P
0 0 0 r
s
.904 .517 .123 r
.65988 1.00353 m .6364 1.0246 L .63253 .96567 L p F P
0 0 0 r
s
.852 .486 .116 r
.60956 .98114 m .63253 .96567 L .6364 1.0246 L p F P
0 0 0 r
s
.81 .461 .111 r
.61276 1.04282 m .58901 1.05793 L .58654 .99426 L p F P
0 0 0 r
s
.81 .461 .111 r
.58654 .99426 m .60956 .98114 L .61276 1.04282 L p F P
0 0 0 r
s
1 .904 .205 r
.70948 .97565 m .68615 1.00254 L .68317 .97986 L p F P
0 0 0 r
s
1 .904 .205 r
.68317 .97986 m .70625 .95393 L .70948 .97565 L p F P
0 0 0 r
s
.852 .486 .116 r
.6364 1.0246 m .61276 1.04282 L .60956 .98114 L p F P
0 0 0 r
s
.456 .254 .05 r
.49434 .75298 m .49699 .77709 L .48212 .71129 L p F P
0 0 0 r
s
.456 .254 .05 r
.48212 .71129 m .47747 .69717 L .49434 .75298 L p F P
0 0 0 r
s
.455 .822 .676 r
.6668 .52219 m .5991 .50684 L .5984 .469 L p F P
0 0 0 r
s
.403 .729 .611 r
.52691 .46289 m .5984 .469 L .5991 .50684 L p F P
0 0 0 r
s
.312 .172 .045 r
.48374 1.11607 m .50053 1.11305 L .50206 1.0908 L p F P
0 0 0 r
s
.509 .299 .077 r
.4812 1.09237 m .49926 1.08949 L .50053 1.11305 L p F P
0 0 0 r
s
.509 .299 .077 r
.50053 1.11305 m .48374 1.11607 L .4812 1.09237 L p F P
0 0 0 r
s
.776 .506 .111 r
.34298 .63834 m .35817 .62282 L .33942 .64397 L p F P
0 0 0 r
s
.776 .506 .111 r
.33942 .64397 m .32277 .65376 L .34298 .63834 L p F P
0 0 0 r
s
1 1 .24 r
.32277 .65376 m .33942 .64397 L .32156 .67255 L p F P
0 0 0 r
s
.882 .543 .139 r
.25575 .74033 m .23601 .71024 L .25073 .69759 L p F P
0 0 0 r
s
.459 .241 .049 r
.468 .66842 m .47276 .68288 L .45455 .63963 L p F P
0 0 0 r
s
.459 .241 .049 r
.45455 .63963 m .44769 .63621 L .468 .66842 L p F P
0 0 0 r
s
.01 .004 .001 r
.36426 .62821 m .3777 .61108 L .35817 .62282 L p F P
0 0 0 r
s
.01 .004 .001 r
.35817 .62282 m .34298 .63834 L .36426 .62821 L p F P
0 0 0 r
s
.22 .094 .021 r
.43363 .6304 m .44072 .63318 L .44055 .63306 L p F P
0 0 0 r
s
.22 .094 .021 r
.44055 .63306 m .41898 .61745 L p .43363 .6304 L F P
0 0 0 r
s
.22 .094 .021 r
.41898 .61745 m .40966 .62484 L .43363 .6304 L p F P
0 0 0 r
s
.705 .473 .11 r
.43363 .6304 m .42641 .62772 L .42659 .62769 L p F P
0 0 0 r
s
.386 .189 .04 r
.44738 .63581 m .42809 .61075 L p .44072 .63318 L F P
0 0 0 r
s
.386 .189 .04 r
.42809 .61075 m .41898 .61745 L .44072 .63318 L p F P
0 0 0 r
s
.705 .473 .11 r
.42659 .62769 m .45338 .62402 L p .43363 .6304 L F P
0 0 0 r
s
.343 .242 .061 r
.44072 .63318 m .43363 .6304 L .43396 .63051 L p F P
0 0 0 r
s
.343 .242 .061 r
.43396 .63051 m .45831 .639 L p .44072 .63318 L F P
0 0 0 r
s
.386 .189 .04 r
.44072 .63318 m .44769 .63621 L .44738 .63581 L p F P
0 0 0 r
s
.026 .016 .005 r
.57036 .82712 m .56138 .84688 L .55291 .92489 L p F P
0 0 0 r
s
.053 .032 .011 r
.54574 .94885 m .55291 .92489 L .56138 .84688 L p F P
0 0 0 r
s
1 .702 .164 r
.30862 .75978 m .32786 .77972 L .31541 .82829 L p F P
0 0 0 r
s
1 .715 .165 r
.33546 .85589 m .31541 .82829 L .32786 .77972 L p F P
0 0 0 r
s
.229 .112 .03 r
.66328 1.01519 m .63935 1.03425 L .63872 1.04868 L p F P
0 0 0 r
s
.229 .112 .03 r
.63872 1.04868 m .66255 1.027 L .66328 1.01519 L p F P
0 0 0 r
s
.349 .634 .541 r
.52699 .50076 m .45436 .50434 L .4549 .46649 L p F P
0 0 0 r
s
.349 .634 .541 r
.4549 .46649 m .52691 .46289 L .52699 .50076 L p F P
0 0 0 r
s
1 1 .24 r
.32156 .67255 m .30377 .67338 L .32277 .65376 L p F P
0 0 0 r
s
1 1 .238 r
.30377 .67338 m .32156 .67255 L .30479 .70555 L p F P
0 0 0 r
s
.84 .509 .129 r
.25575 .74033 m .27555 .77022 L .26367 .79489 L p F P
0 0 0 r
s
.942 .562 .139 r
.28412 .83004 m .26367 .79489 L .27555 .77022 L p F P
0 0 0 r
s
.752 .458 .118 r
.26367 .79489 m .28412 .83004 L .27496 .84759 L p F P
0 0 0 r
s
.652 .407 .083 r
.6235 .6947 m .6124 .70769 L .59764 .76086 L p F P
0 0 0 r
s
.5885 .784 m .59764 .76086 L .6124 .70769 L p F P
s
.813 .492 .125 r
.29619 .88314 m .27496 .84759 L .28412 .83004 L p F P
0 0 0 r
s
.062 .038 .012 r
.53151 .98908 m .52447 1.00515 L .52268 1.0693 L p F P
0 0 0 r
s
.882 .543 .139 r
.25073 .69759 m .27006 .71857 L .25575 .74033 L p F P
0 0 0 r
s
1 .627 .154 r
.27555 .77022 m .25575 .74033 L .27006 .71857 L p F P
0 0 0 r
s
1 .687 .154 r
.45697 .98534 m .47723 .99901 L .47467 1.06375 L p F P
0 0 0 r
s
1 .68 .152 r
.49613 1.07519 m .47467 1.06375 L .47723 .99901 L p F P
0 0 0 r
s
.022 .013 .004 r
.52016 1.05133 m .51883 1.06904 L .51689 1.00463 L p F P
0 0 0 r
s
.022 .013 .004 r
.51689 1.00463 m .51627 .98803 L .52016 1.05133 L p F P
0 0 0 r
s
.029 .013 .003 r
.65224 .65254 m .6656 .65115 L .68401 .63875 L p F P
0 0 0 r
s
.805 .517 .112 r
.6656 .65115 m .65224 .65254 L .63472 .68157 L p F P
0 0 0 r
s
.6235 .6947 m .63472 .68157 L .65224 .65254 L p F P
s
1 .811 .188 r
.30862 .75978 m .28935 .73935 L .30479 .70555 L p F P
0 0 0 r
s
1 .676 .161 r
.28935 .73935 m .30862 .75978 L .29544 .79964 L p F P
0 0 0 r
s
1 .702 .164 r
.31541 .82829 m .29544 .79964 L .30862 .75978 L p F P
0 0 0 r
s
1 .842 .181 r
.5408 1.11976 m .52923 1.11491 L .53083 1.09156 L p F P
0 0 0 r
s
.219 .094 .021 r
.68401 .63875 m .69961 .64807 L .71877 .65041 L p F P
0 0 0 r
s
.69961 .64807 m .68401 .63875 L .6656 .65115 L p F P
s
.142 .061 .014 r
.38651 .62381 m .39797 .60948 L .3777 .61108 L p F P
0 0 0 r
s
.142 .061 .014 r
.3777 .61108 m .36426 .62821 L .38651 .62381 L p F P
0 0 0 r
s
1 1 .238 r
.30479 .70555 m .28613 .69562 L .30377 .67338 L p F P
0 0 0 r
s
1 .798 .19 r
.28613 .69562 m .30479 .70555 L .28935 .73935 L p F P
0 0 0 r
s
.33 .155 .034 r
.73663 .65796 m .75609 .67832 L .77385 .68983 L p F P
0 0 0 r
s
.305 .139 .031 r
.75609 .67832 m .73663 .65796 L .71877 .65041 L p F P
0 0 0 r
s
.403 .729 .611 r
.5991 .50684 m .52699 .50076 L .52691 .46289 L p F P
0 0 0 r
s
.319 .214 .06 r
.29619 .88314 m .31765 .91736 L .31205 .91413 L p F P
0 0 0 r
s
.237 .153 .046 r
.33434 .94343 m .31205 .91413 L .31765 .91736 L p F P
0 0 0 r
s
.181 .337 .311 r
.31794 .65589 m .26468 .6842 L .26684 .64476 L p F P
0 0 0 r
s
.181 .337 .311 r
.26684 .64476 m .31966 .61625 L .31794 .65589 L p F P
0 0 0 r
s
.502 .907 .732 r
.66809 .5606 m .72835 .5841 L .73017 .62302 L p F P
0 0 0 r
s
.502 .907 .732 r
.72835 .5841 m .66809 .5606 L .6668 .52219 L p F P
0 0 0 r
s
.048 .029 .01 r
.51374 .89522 m .51438 .92215 L .50484 .84273 L p F P
0 0 0 r
s
.048 .029 .01 r
.50484 .84273 m .50224 .82207 L .51374 .89522 L p F P
0 0 0 r
s
.455 .822 .676 r
.5991 .50684 m .6668 .52219 L .66809 .5606 L p F P
0 0 0 r
s
1 .627 .154 r
.27006 .71857 m .28935 .73935 L .27555 .77022 L p F P
0 0 0 r
s
1 .676 .161 r
.29544 .79964 m .27555 .77022 L .28935 .73935 L p F P
0 0 0 r
s
.942 .562 .139 r
.27555 .77022 m .29544 .79964 L .28412 .83004 L p F P
0 0 0 r
s
1 .798 .19 r
.28935 .73935 m .27006 .71857 L .28613 .69562 L p F P
0 0 0 r
s
1 .648 .139 r
.52745 1.09247 m .51751 1.08309 L .51751 1.10619 L p F P
0 0 0 r
s
1 .648 .139 r
.51751 1.10619 m .52923 1.11491 L .52745 1.09247 L p F P
0 0 0 r
s
1 .824 .189 r
.65988 1.00353 m .68317 .97986 L .68615 1.00254 L p F P
0 0 0 r
s
1 .824 .189 r
.68615 1.00254 m .66255 1.027 L .65988 1.00353 L p F P
0 0 0 r
s
.366 .196 .048 r
.63935 1.03425 m .61521 1.05049 L .61469 1.06726 L p F P
0 0 0 r
s
.366 .196 .048 r
.61469 1.06726 m .63872 1.04868 L .63935 1.03425 L p F P
0 0 0 r
s
1 .692 .156 r
.43668 .96916 m .45697 .98534 L .45318 1.04885 L p F P
0 0 0 r
s
1 .687 .154 r
.47467 1.06375 m .45318 1.04885 L .45697 .98534 L p F P
0 0 0 r
s
1 .789 .169 r
.51751 1.08309 m .53083 1.09156 L .52923 1.11491 L p F P
0 0 0 r
s
1 .72 .178 r
.26733 .68561 m .28613 .69562 L .27006 .71857 L p F P
0 0 0 r
s
1 .72 .178 r
.27006 .71857 m .25073 .69759 L .26733 .68561 L p F P
0 0 0 r
s
1 .605 .146 r
.29544 .79964 m .31541 .82829 L .30474 .86429 L p F P
0 0 0 r
s
1 .605 .146 r
.30474 .86429 m .28412 .83004 L .29544 .79964 L p F P
0 0 0 r
s
.813 .492 .125 r
.28412 .83004 m .30474 .86429 L .29619 .88314 L p F P
0 0 0 r
s
.343 .193 .051 r
.51751 1.08309 m .50206 1.0908 L .50053 1.11305 L p F P
0 0 0 r
s
.5794 .80612 m .57036 .82712 L .56011 .89855 L p F P
s
.026 .016 .005 r
.55291 .92489 m .56011 .89855 L .57036 .82712 L p F P
0 0 0 r
s
.293 .536 .468 r
.45381 .54285 m .38401 .55579 L .38515 .51736 L p F P
0 0 0 r
s
.293 .536 .468 r
.38515 .51736 m .45436 .50434 L .45381 .54285 L p F P
0 0 0 r
s
.237 .439 .392 r
.38285 .5949 m .31966 .61625 L .32136 .57728 L p F P
0 0 0 r
s
.237 .439 .392 r
.32136 .57728 m .38401 .55579 L .38285 .5949 L p F P
0 0 0 r
s
.343 .193 .051 r
.50053 1.11305 m .51751 1.10619 L .51751 1.08309 L p F P
0 0 0 r
s
.478 .278 .071 r
.49926 1.08949 m .51751 1.08309 L .51751 1.10619 L p F P
0 0 0 r
s
.478 .278 .071 r
.51751 1.10619 m .50053 1.11305 L .49926 1.08949 L p F P
0 0 0 r
s
.881 .53 .133 r
.31765 .91736 m .29619 .88314 L .30474 .86429 L p F P
0 0 0 r
s
.297 .142 .03 r
.35683 .97076 m .33434 .94343 L .33933 .94984 L p F P
0 0 0 r
s
.237 .153 .046 r
.31765 .91736 m .33933 .94984 L .33434 .94343 L p F P
0 0 0 r
s
1 .694 .157 r
.41636 .95057 m .43668 .96916 L .43168 1.03062 L p F P
0 0 0 r
s
1 .692 .156 r
.45318 1.04885 m .43168 1.03062 L .43668 .96916 L p F P
0 0 0 r
s
1 .638 .151 r
.31541 .82829 m .33546 .85589 L .32553 .89727 L p F P
0 0 0 r
s
1 .638 .151 r
.32553 .89727 m .30474 .86429 L .31541 .82829 L p F P
0 0 0 r
s
.11 .067 .022 r
.49167 .72797 m .49434 .75298 L .47747 .69717 L p F P
0 0 0 r
s
.11 .067 .022 r
.47747 .69717 m .47276 .68288 L .49167 .72797 L p F P
0 0 0 r
s
.206 .089 .02 r
.40966 .62484 m .41898 .61745 L .39797 .60948 L p F P
0 0 0 r
s
.206 .089 .02 r
.39797 .60948 m .38651 .62381 L .40966 .62484 L p F P
0 0 0 r
s
.487 .266 .064 r
.61521 1.05049 m .59092 1.06366 L .59051 1.08248 L p F P
0 0 0 r
s
.487 .266 .064 r
.59051 1.08248 m .61469 1.06726 L .61521 1.05049 L p F P
0 0 0 r
s
1 .744 .173 r
.6364 1.0246 m .65988 1.00353 L .66255 1.027 L p F P
0 0 0 r
s
1 .966 .23 r
.28572 .67438 m .30377 .67338 L .28613 .69562 L p F P
0 0 0 r
s
1 .966 .23 r
.28613 .69562 m .26733 .68561 L .28572 .67438 L p F P
0 0 0 r
s
1 .662 .155 r
.33546 .85589 m .3556 .88217 L .34649 .9286 L p F P
0 0 0 r
s
1 .662 .155 r
.34649 .9286 m .32553 .89727 L .33546 .85589 L p F P
0 0 0 r
s
1 .693 .158 r
.39607 .92974 m .41636 .95057 L .41024 1.00922 L p F P
0 0 0 r
s
1 .694 .157 r
.43168 1.03062 m .41024 1.00922 L .41636 .95057 L p F P
0 0 0 r
s
.04 .025 .008 r
.5386 .97029 m .53151 .98908 L .5279 1.05185 L p F P
0 0 0 r
s
.062 .038 .012 r
.52268 1.0693 m .5279 1.05185 L .53151 .98908 L p F P
0 0 0 r
s
.652 .407 .083 r
.59764 .76086 m .60684 .73684 L .6235 .6947 L p F P
0 0 0 r
s
.902 .56 .12 r
.63472 .68157 m .6235 .6947 L .60684 .73684 L p F P
0 0 0 r
s
.305 .139 .031 r
.71877 .65041 m .73661 .66763 L .75609 .67832 L p F P
0 0 0 r
s
.196 .084 .019 r
.73661 .66763 m .71877 .65041 L .69961 .64807 L p F P
0 0 0 r
s
.079 .048 .016 r
.5131 .86607 m .51374 .89522 L .50224 .82207 L p F P
0 0 0 r
s
.079 .048 .016 r
.50224 .82207 m .49963 .80015 L .5131 .86607 L p F P
0 0 0 r
s
1 .678 .157 r
.3556 .88217 m .37581 .90687 L .36761 .95793 L p F P
0 0 0 r
s
1 .678 .157 r
.36761 .95793 m .34649 .9286 L .3556 .88217 L p F P
0 0 0 r
s
.045 .028 .009 r
.52151 1.03001 m .52016 1.05133 L .51627 .98803 L p F P
0 0 0 r
s
.045 .028 .009 r
.51627 .98803 m .51564 .96869 L .52151 1.03001 L p F P
0 0 0 r
s
1 .688 .158 r
.37581 .90687 m .39607 .92974 L .38887 .9849 L p F P
0 0 0 r
s
1 .693 .158 r
.41024 1.00922 m .38887 .9849 L .39607 .92974 L p F P
0 0 0 r
s
1 .688 .158 r
.38887 .9849 m .36761 .95793 L .37581 .90687 L p F P
0 0 0 r
s
1 .744 .173 r
.66255 1.027 m .63872 1.04868 L .6364 1.0246 L p F P
0 0 0 r
s
.881 .53 .133 r
.30474 .86429 m .32553 .89727 L .31765 .91736 L p F P
0 0 0 r
s
.533 .965 .764 r
.78213 .69251 m .73201 .66262 L .73017 .62302 L p F P
0 0 0 r
s
.297 .142 .03 r
.33933 .94984 m .36121 .98019 L .35683 .97076 L p F P
0 0 0 r
s
.448 .232 .047 r
.3795 .99579 m .35683 .97076 L .36121 .98019 L p F P
0 0 0 r
s
.998 .659 .149 r
.30579 .66401 m .32277 .65376 L .30377 .67338 L p F P
0 0 0 r
s
.998 .659 .149 r
.30377 .67338 m .28572 .67438 L .30579 .66401 L p F P
0 0 0 r
s
.591 .324 .077 r
.59092 1.06366 m .5665 1.07356 L .56621 1.09413 L p F P
0 0 0 r
s
.591 .324 .077 r
.56621 1.09413 m .59051 1.08248 L .59092 1.06366 L p F P
0 0 0 r
s
.628 .385 .078 r
.5885 .784 m .5794 .80612 L .56734 .87001 L p F P
0 0 0 r
s
.56011 .89855 m .56734 .87001 L .5794 .80612 L p F P
s
1 .669 .157 r
.61276 1.04282 m .6364 1.0246 L .63872 1.04868 L p F P
0 0 0 r
s
1 .789 .169 r
.52923 1.11491 m .51751 1.10619 L .51751 1.08309 L p F P
0 0 0 r
s
.296 .135 .03 r
.46319 .65379 m .468 .66842 L .44769 .63621 L p F P
0 0 0 r
s
.296 .135 .03 r
.44769 .63621 m .44072 .63318 L .46319 .65379 L p F P
0 0 0 r
s
.954 .57 .141 r
.33933 .94984 m .31765 .91736 L .32553 .89727 L p F P
0 0 0 r
s
.455 .822 .676 r
.66809 .5606 m .59981 .54533 L .5991 .50684 L p F P
0 0 0 r
s
.403 .729 .611 r
.52699 .50076 m .5991 .50684 L .59981 .54533 L p F P
0 0 0 r
s
.677 .373 .089 r
.5665 1.07356 m .54202 1.08007 L .54186 1.10207 L p F P
0 0 0 r
s
.677 .373 .089 r
.54186 1.10207 m .56621 1.09413 L .5665 1.07356 L p F P
0 0 0 r
s
.746 .414 .098 r
.54202 1.08007 m .51751 1.08309 L .51751 1.10619 L p F P
0 0 0 r
s
.746 .414 .098 r
.51751 1.10619 m .54186 1.10207 L .54202 1.08007 L p F P
0 0 0 r
s
.805 .455 .109 r
.54186 1.10207 m .51751 1.10619 L .51751 1.08309 L p F P
0 0 0 r
s
.805 .455 .109 r
.51751 1.08309 m .54134 1.07818 L .54186 1.10207 L p F P
0 0 0 r
s
.021 .013 .004 r
.52268 1.0693 m .51751 1.08309 L .51751 1.10619 L p F P
0 0 0 r
s
1 .579 .131 r
.49513 1.09901 m .51751 1.10619 L .51751 1.08309 L p F P
0 0 0 r
s
1 .579 .131 r
.51751 1.08309 m .49448 1.07693 L .49513 1.09901 L p F P
0 0 0 r
s
1 .668 .151 r
.49613 1.07519 m .51751 1.08309 L .51751 1.10619 L p F P
0 0 0 r
s
.021 .013 .004 r
.51751 1.10619 m .52078 1.09215 L .52268 1.0693 L p F P
0 0 0 r
s
.067 .041 .013 r
.52078 1.09215 m .51751 1.10619 L .51751 1.08309 L p F P
0 0 0 r
s
.067 .041 .013 r
.51751 1.08309 m .51883 1.06904 L .52078 1.09215 L p F P
0 0 0 r
s
.32743 .65458 m .34298 .63834 L .32277 .65376 L p F P
s
.32277 .65376 m .30579 .66401 L .32743 .65458 L p F P
s
.349 .634 .541 r
.52707 .53929 m .45381 .54285 L .45436 .50434 L p F P
0 0 0 r
s
.349 .634 .541 r
.45436 .50434 m .52699 .50076 L .52707 .53929 L p F P
0 0 0 r
s
.6656 .65115 m .67917 .65004 L .69961 .64807 L p F P
s
.805 .517 .112 r
.63472 .68157 m .64606 .6683 L .6656 .65115 L p F P
0 0 0 r
s
1 .911 .203 r
.67917 .65004 m .6656 .65115 L .64606 .6683 L p F P
0 0 0 r
s
.954 .57 .141 r
.32553 .89727 m .34649 .9286 L .33933 .94984 L p F P
0 0 0 r
s
.448 .232 .047 r
.36121 .98019 m .38327 1.00802 L .3795 .99579 L p F P
0 0 0 r
s
.647 .339 .072 r
.40233 1.01821 m .3795 .99579 L .38327 1.00802 L p F P
0 0 0 r
s
1 .669 .157 r
.63872 1.04868 m .61469 1.06726 L .61276 1.04282 L p F P
0 0 0 r
s
1 .602 .142 r
.58901 1.05793 m .61276 1.04282 L .61469 1.06726 L p F P
0 0 0 r
s
.869 .495 .118 r
.56621 1.09413 m .54186 1.10207 L .54134 1.07818 L p F P
0 0 0 r
s
.869 .495 .118 r
.54134 1.07818 m .56519 1.06976 L .56621 1.09413 L p F P
0 0 0 r
s
1 .602 .142 r
.61469 1.06726 m .59051 1.08248 L .58901 1.05793 L p F P
0 0 0 r
s
.949 .544 .129 r
.56519 1.06976 m .58901 1.05793 L .59051 1.08248 L p F P
0 0 0 r
s
.01 .006 .002 r
.54574 .94885 m .5386 .97029 L .53317 1.0308 L p F P
0 0 0 r
s
.04 .025 .008 r
.5279 1.05185 m .53317 1.0308 L .5386 .97029 L p F P
0 0 0 r
s
.116 .071 .023 r
.51245 .83492 m .5131 .86607 L .49963 .80015 L p F P
0 0 0 r
s
.116 .071 .023 r
.49963 .80015 m .49699 .77709 L .51245 .83492 L p F P
0 0 0 r
s
.403 .729 .611 r
.59981 .54533 m .52707 .53929 L .52699 .50076 L p F P
0 0 0 r
s
.502 .907 .732 r
.6694 .59967 m .73017 .62302 L .73201 .66262 L p F P
0 0 0 r
s
.502 .907 .732 r
.73017 .62302 m .6694 .59967 L .66809 .5606 L p F P
0 0 0 r
s
.949 .544 .129 r
.59051 1.08248 m .56621 1.09413 L .56519 1.06976 L p F P
0 0 0 r
s
1 .549 .124 r
.47269 1.08799 m .49513 1.09901 L .49448 1.07693 L p F P
0 0 0 r
s
1 .549 .124 r
.49448 1.07693 m .4714 1.06726 L .47269 1.08799 L p F P
0 0 0 r
s
.647 .339 .072 r
.38327 1.00802 m .40549 1.03299 L .40233 1.01821 L p F P
0 0 0 r
s
.822 .432 .095 r
.42528 1.03774 m .40233 1.01821 L .40549 1.03299 L p F P
0 0 0 r
s
.455 .822 .676 r
.59981 .54533 m .66809 .5606 L .6694 .59967 L p F P
0 0 0 r
s
.177 .109 .035 r
.48899 .70218 m .49167 .72797 L .47276 .68288 L p F P
0 0 0 r
s
.177 .109 .035 r
.47276 .68288 m .468 .66842 L .48899 .70218 L p F P
0 0 0 r
s
.073 .045 .015 r
.52286 1.00519 m .52151 1.03001 L .51564 .96869 L p F P
0 0 0 r
s
.073 .045 .015 r
.51564 .96869 m .51501 .94669 L .52286 1.00519 L p F P
0 0 0 r
s
1 .609 .148 r
.36121 .98019 m .33933 .94984 L .34649 .9286 L p F P
0 0 0 r
s
.058 .025 .006 r
.35047 .64616 m .36426 .62821 L .34298 .63834 L p F P
0 0 0 r
s
.058 .025 .006 r
.34298 .63834 m .32743 .65458 L .35047 .64616 L p F P
0 0 0 r
s
.196 .084 .019 r
.69961 .64807 m .71552 .65785 L .73661 .66763 L p F P
0 0 0 r
s
.605 .41 .1 r
.71552 .65785 m .69961 .64807 L .67917 .65004 L p F P
0 0 0 r
s
.628 .385 .078 r
.56734 .87001 m .57458 .8395 L .58778 .78687 L p F P
0 0 0 r
s
.628 .385 .078 r
.58778 .78687 m .5885 .784 L p .5879 .78643 L F P
0 0 0 r
s
.628 .385 .078 r
.56734 .87001 m .58778 .78687 L .5879 .78643 L F
.806 .491 .103 r
.59764 .76086 m .5885 .784 L .57458 .8395 L p F P
0 0 0 r
s
.806 .491 .103 r
.57458 .8395 m .58182 .80725 L .59764 .76086 L p F P
0 0 0 r
s
1 .677 .143 r
.60684 .73684 m .59764 .76086 L .58344 .80252 L p F P
0 0 0 r
s
1 .677 .143 r
.58344 .80252 m .58182 .80725 L p .5832 .80338 L F P
0 0 0 r
s
1 .677 .143 r
.5832 .80338 m .60684 .73684 L .58344 .80252 L F
1 .609 .148 r
.34649 .9286 m .36761 .95793 L .36121 .98019 L p F P
0 0 0 r
s
1 .69 .156 r
.47467 1.06375 m .49613 1.07519 L .49513 1.09901 L p F P
0 0 0 r
s
1 .668 .151 r
.51751 1.10619 m .49513 1.09901 L .49613 1.07519 L p F P
0 0 0 r
s
.902 .56 .12 r
.60684 .73684 m .61608 .71208 L .63472 .68157 L p F P
0 0 0 r
s
1 .961 .205 r
.64606 .6683 m .63472 .68157 L .61608 .71208 L p F P
0 0 0 r
s
.964 .519 .116 r
.45024 1.07321 m .47269 1.08799 L .4714 1.06726 L p F P
0 0 0 r
s
.964 .519 .116 r
.4714 1.06726 m .44832 1.05415 L .45024 1.07321 L p F P
0 0 0 r
s
.822 .432 .095 r
.40549 1.03299 m .42783 1.05481 L .42528 1.03774 L p F P
0 0 0 r
s
.913 .486 .108 r
.44832 1.05415 m .42528 1.03774 L .42783 1.05481 L p F P
0 0 0 r
s
.913 .486 .108 r
.42783 1.05481 m .45024 1.07321 L .44832 1.05415 L p F P
0 0 0 r
s
.293 .536 .468 r
.45325 .58204 m .38285 .5949 L .38401 .55579 L p F P
0 0 0 r
s
.293 .536 .468 r
.38401 .55579 m .45381 .54285 L .45325 .58204 L p F P
0 0 0 r
s
.114 .049 .011 r
.37477 .63883 m .38651 .62381 L .36426 .62821 L p F P
0 0 0 r
s
.114 .049 .011 r
.36426 .62821 m .35047 .64616 L .37477 .63883 L p F P
0 0 0 r
s
.127 .054 .012 r
.38651 .62381 m .37477 .63883 L .40014 .63267 L p F P
0 0 0 r
s
.237 .439 .392 r
.38166 .63468 m .31794 .65589 L .31966 .61625 L p F P
0 0 0 r
s
.237 .439 .392 r
.31966 .61625 m .38285 .5949 L .38166 .63468 L p F P
0 0 0 r
s
1 .645 .154 r
.36761 .95793 m .38887 .9849 L .38327 1.00802 L p F P
0 0 0 r
s
1 .645 .154 r
.38327 1.00802 m .36121 .98019 L .36761 .95793 L p F P
0 0 0 r
s
1 .702 .16 r
.45318 1.04885 m .47467 1.06375 L .47269 1.08799 L p F P
0 0 0 r
s
1 .69 .156 r
.49513 1.09901 m .47269 1.08799 L .47467 1.06375 L p F P
0 0 0 r
s
.55291 .92489 m .54574 .94885 L .53846 1.00625 L p F P
s
.01 .006 .002 r
.53317 1.0308 m .53846 1.00625 L .54574 .94885 L p F P
0 0 0 r
s
.5279 1.05185 m .52268 1.0693 L .52078 1.09215 L p F P
s
.157 .096 .031 r
.51181 .80201 m .51245 .83492 L .49699 .77709 L p F P
0 0 0 r
s
.157 .096 .031 r
.49699 .77709 m .49434 .75298 L .51181 .80201 L p F P
0 0 0 r
s
1 .673 .159 r
.38887 .9849 m .41024 1.00922 L .40549 1.03299 L p F P
0 0 0 r
s
1 .673 .159 r
.40549 1.03299 m .38327 1.00802 L .38887 .9849 L p F P
0 0 0 r
s
.52078 1.09215 m .52408 1.07412 L .5279 1.05185 L p F P
s
.114 .07 .023 r
.52408 1.07412 m .52078 1.09215 L .51883 1.06904 L p F P
0 0 0 r
s
.114 .07 .023 r
.51883 1.06904 m .52016 1.05133 L .52408 1.07412 L p F P
0 0 0 r
s
1 .704 .162 r
.43168 1.03062 m .45318 1.04885 L .45024 1.07321 L p F P
0 0 0 r
s
1 .702 .16 r
.47269 1.08799 m .45024 1.07321 L .45318 1.04885 L p F P
0 0 0 r
s
1 .694 .161 r
.41024 1.00922 m .43168 1.03062 L .42783 1.05481 L p F P
0 0 0 r
s
1 .694 .161 r
.42783 1.05481 m .40549 1.03299 L .41024 1.00922 L p F P
0 0 0 r
s
.104 .064 .021 r
.52422 .97703 m .52286 1.00519 L .51501 .94669 L p F P
0 0 0 r
s
.104 .064 .021 r
.51501 .94669 m .51438 .92215 L .52422 .97703 L p F P
0 0 0 r
s
1 .704 .162 r
.45024 1.07321 m .42783 1.05481 L .43168 1.03062 L p F P
0 0 0 r
s
.343 .242 .061 r
.45831 .639 m .46319 .65379 L .44072 .63318 L p F P
0 0 0 r
s
.605 .41 .1 r
.67917 .65004 m .69296 .64906 L .71552 .65785 L p F P
0 0 0 r
s
1 .911 .203 r
.64606 .6683 m .65751 .65489 L .67917 .65004 L p F P
0 0 0 r
s
1 .966 .23 r
.69296 .64906 m .67917 .65004 L .65751 .65489 L p F P
0 0 0 r
s
.455 .822 .676 r
.6694 .59967 m .60053 .5845 L .59981 .54533 L p F P
0 0 0 r
s
.403 .729 .611 r
.52707 .53929 m .59981 .54533 L .60053 .5845 L p F P
0 0 0 r
s
.356 .241 .066 r
.48629 .67576 m .48899 .70218 L .468 .66842 L p F P
0 0 0 r
s
.356 .241 .066 r
.468 .66842 m .46319 .65379 L .48629 .67576 L p F P
0 0 0 r
s
.127 .054 .012 r
.40014 .63267 m .40966 .62484 L .38651 .62381 L p F P
0 0 0 r
s
1 1 .253 r
.65751 .65489 m .64606 .6683 L .62536 .6867 L p F P
0 0 0 r
s
1 .961 .205 r
.61608 .71208 m .62536 .6867 L .64606 .6683 L p F P
0 0 0 r
s
.696 .423 .086 r
.56011 .89855 m .55291 .92489 L .54377 .97838 L p F P
0 0 0 r
s
.53846 1.00625 m .54377 .97838 L .55291 .92489 L p F P
s
.349 .634 .541 r
.52715 .5785 m .45325 .58204 L .45381 .54285 L p F P
0 0 0 r
s
.349 .634 .541 r
.45381 .54285 m .52707 .53929 L .52715 .5785 L p F P
0 0 0 r
s
1 .963 .205 r
.61608 .71208 m .60684 .73684 L .58908 .77351 L p F P
0 0 0 r
s
1 .677 .143 r
.58182 .80725 m .58908 .77351 L .60684 .73684 L p F P
0 0 0 r
s
.229 .147 .044 r
.51117 .7676 m .51181 .80201 L .49434 .75298 L p F P
0 0 0 r
s
.229 .147 .044 r
.49434 .75298 m .49167 .72797 L .51117 .7676 L p F P
0 0 0 r
s
.137 .084 .027 r
.52558 .94574 m .52422 .97703 L .51438 .92215 L p F P
0 0 0 r
s
.137 .084 .027 r
.51438 .92215 m .51374 .89522 L .52558 .94574 L p F P
0 0 0 r
s
.76 .462 .096 r
.53317 1.0308 m .5279 1.05185 L .52408 1.07412 L p F P
0 0 0 r
s
.403 .729 .611 r
.60053 .5845 m .52715 .5785 L .52707 .53929 L p F P
0 0 0 r
s
.502 .907 .732 r
.73201 .66262 m .67073 .63942 L .6694 .59967 L p F P
0 0 0 r
s
.159 .097 .032 r
.52741 1.05217 m .52408 1.07412 L .52016 1.05133 L p F P
0 0 0 r
s
.159 .097 .032 r
.52016 1.05133 m .52151 1.03001 L .52741 1.05217 L p F P
0 0 0 r
s
.455 .822 .676 r
.60053 .5845 m .6694 .59967 L .67073 .63942 L p F P
0 0 0 r
s
.696 .423 .086 r
.54377 .97838 m .54909 .94739 L .56011 .89855 L p F P
0 0 0 r
s
.838 .508 .107 r
.56734 .87001 m .56011 .89855 L .54909 .94739 L p F P
0 0 0 r
s
.075 .032 .007 r
.42641 .62772 m .43363 .6304 L .40966 .62484 L p F P
0 0 0 r
s
.075 .032 .007 r
.40966 .62484 m .40014 .63267 L .42641 .62772 L p F P
0 0 0 r
s
1 1 .233 r
.62536 .6867 m .61608 .71208 L .59633 .73857 L p F P
0 0 0 r
s
1 .963 .205 r
.58908 .77351 m .59633 .73857 L .61608 .71208 L p F P
0 0 0 r
s
.293 .536 .468 r
.45269 .62191 m .38166 .63468 L .38285 .5949 L p F P
0 0 0 r
s
.293 .536 .468 r
.38285 .5949 m .45325 .58204 L .45269 .62191 L p F P
0 0 0 r
s
.478 .299 .081 r
.51052 .73197 m .51117 .7676 L .49167 .72797 L p F P
0 0 0 r
s
.478 .299 .081 r
.49167 .72797 m .48899 .70218 L .51052 .73197 L p F P
0 0 0 r
s
.168 .103 .034 r
.52694 .91159 m .52558 .94574 L .51374 .89522 L p F P
0 0 0 r
s
.168 .103 .034 r
.51374 .89522 m .5131 .86607 L .52694 .91159 L p F P
0 0 0 r
s
1 .966 .23 r
.65751 .65489 m .6691 .64133 L .69296 .64906 L p F P
0 0 0 r
s
1 .963 .224 r
.6691 .64133 m .65751 .65489 L .6347 .66088 L p F P
0 0 0 r
s
1 1 .253 r
.62536 .6867 m .6347 .66088 L .65751 .65489 L p F P
0 0 0 r
s
.912 .588 .151 r
.48357 .64886 m .48629 .67576 L .46319 .65379 L p F P
0 0 0 r
s
.912 .588 .151 r
.46319 .65379 m .45831 .639 L .48357 .64886 L p F P
0 0 0 r
s
1 .688 .145 r
.57458 .8395 m .56734 .87001 L .55441 .91355 L p F P
0 0 0 r
s
.838 .508 .107 r
.54909 .94739 m .55441 .91355 L .56734 .87001 L p F P
0 0 0 r
s
.992 .605 .128 r
.53846 1.00625 m .53317 1.0308 L .52741 1.05217 L p F P
0 0 0 r
s
.76 .462 .096 r
.52408 1.07412 m .52741 1.05217 L .53317 1.0308 L p F P
0 0 0 r
s
.273 .17 .049 r
.53076 1.02641 m .52741 1.05217 L .52151 1.03001 L p F P
0 0 0 r
s
.273 .17 .049 r
.52151 1.03001 m .52286 1.00519 L .53076 1.02641 L p F P
0 0 0 r
s
1 .996 .225 r
.6347 .66088 m .62536 .6867 L .60359 .70271 L p F P
0 0 0 r
s
1 1 .233 r
.59633 .73857 m .60359 .70271 L .62536 .6867 L p F P
0 0 0 r
s
.705 .473 .11 r
.45338 .62402 m .45831 .639 L .43363 .6304 L p F P
0 0 0 r
s
.289 .179 .051 r
.5283 .87488 m .52694 .91159 L .5131 .86607 L p F P
0 0 0 r
s
.289 .179 .051 r
.5131 .86607 m .51245 .83492 L .5283 .87488 L p F P
0 0 0 r
s
1 .901 .19 r
.58182 .80725 m .57458 .8395 L .55973 .87716 L p F P
0 0 0 r
s
1 .688 .145 r
.55441 .91355 m .55973 .87716 L .57458 .8395 L p F P
0 0 0 r
s
.761 .472 .123 r
.50988 .69538 m .51052 .73197 L .48899 .70218 L p F P
0 0 0 r
s
.761 .472 .123 r
.48899 .70218 m .48629 .67576 L .50988 .69538 L p F P
0 0 0 r
s
.455 .822 .676 r
.67073 .63942 m .60126 .62436 L .60053 .5845 L p F P
0 0 0 r
s
.403 .729 .611 r
.52715 .5785 m .60053 .5845 L .60126 .62436 L p F P
0 0 0 r
s
.349 .634 .541 r
.52724 .61839 m .45269 .62191 L .45325 .58204 L p F P
0 0 0 r
s
.349 .634 .541 r
.45325 .58204 m .52715 .5785 L .52724 .61839 L p F P
0 0 0 r
s
1 .854 .18 r
.54377 .97838 m .53846 1.00625 L .53076 1.02641 L p F P
0 0 0 r
s
.992 .605 .128 r
.52741 1.05217 m .53076 1.02641 L .53846 1.00625 L p F P
0 0 0 r
s
1 1 .218 r
.58908 .77351 m .58182 .80725 L .56504 .83855 L p F P
0 0 0 r
s
1 .901 .19 r
.55973 .87716 m .56504 .83855 L .58182 .80725 L p F P
0 0 0 r
s
.466 .285 .076 r
.52966 .83594 m .5283 .87488 L .51245 .83492 L p F P
0 0 0 r
s
.466 .285 .076 r
.51245 .83492 m .51181 .80201 L .52966 .83594 L p F P
0 0 0 r
s
.466 .285 .077 r
.53411 .99704 m .53076 1.02641 L .52286 1.00519 L p F P
0 0 0 r
s
.466 .285 .077 r
.52286 1.00519 m .52422 .97703 L .53411 .99704 L p F P
0 0 0 r
s
1 .963 .224 r
.6347 .66088 m .64409 .63474 L .6691 .64133 L p F P
0 0 0 r
s
1 .871 .202 r
.64409 .63474 m .6347 .66088 L .61085 .6662 L p F P
0 0 0 r
s
1 .996 .225 r
.60359 .70271 m .61085 .6662 L .6347 .66088 L p F P
0 0 0 r
s
.403 .729 .611 r
.60126 .62436 m .52724 .61839 L .52715 .5785 L p F P
0 0 0 r
s
1 1 .222 r
.59633 .73857 m .58908 .77351 L .57033 .79808 L p F P
0 0 0 r
s
1 1 .218 r
.56504 .83855 m .57033 .79808 L .58908 .77351 L p F P
0 0 0 r
s
1 .966 .23 r
.48084 .62162 m .48357 .64886 L .45831 .639 L p F P
0 0 0 r
s
1 .966 .23 r
.45831 .639 m .45338 .62402 L .48084 .62162 L p F P
0 0 0 r
s
1 .678 .168 r
.50923 .65814 m .50988 .69538 L .48629 .67576 L p F P
0 0 0 r
s
1 .678 .168 r
.48629 .67576 m .48357 .64886 L .50923 .65814 L p F P
0 0 0 r
s
.628 .382 .1 r
.53101 .79513 m .52966 .83594 L .51181 .80201 L p F P
0 0 0 r
s
.628 .382 .1 r
.51181 .80201 m .51117 .7676 L .53101 .79513 L p F P
0 0 0 r
s
1 1 .217 r
.54909 .94739 m .54377 .97838 L .53411 .99704 L p F P
0 0 0 r
s
1 .854 .18 r
.53076 1.02641 m .53411 .99704 L .54377 .97838 L p F P
0 0 0 r
s
1 .952 .214 r
.60359 .70271 m .59633 .73857 L .57562 .75612 L p F P
0 0 0 r
s
1 1 .222 r
.57033 .79808 m .57562 .75612 L .59633 .73857 L p F P
0 0 0 r
s
.619 .377 .099 r
.53747 .96428 m .53411 .99704 L .52422 .97703 L p F P
0 0 0 r
s
.619 .377 .099 r
.52422 .97703 m .52558 .94574 L .53747 .96428 L p F P
0 0 0 r
s
1 .871 .202 r
.61085 .6662 m .61812 .62935 L .64409 .63474 L p F P
0 0 0 r
s
1 .878 .2 r
.61085 .6662 m .60359 .70271 L .58088 .71307 L p F P
0 0 0 r
s
1 .952 .214 r
.57562 .75612 m .58088 .71307 L .60359 .70271 L p F P
0 0 0 r
s
.805 .489 .124 r
.53236 .75282 m .53101 .79513 L .51117 .7676 L p F P
0 0 0 r
s
.805 .489 .124 r
.51117 .7676 m .51052 .73197 L .53236 .75282 L p F P
0 0 0 r
s
1 .807 .187 r
.61812 .62935 m .61085 .6662 L .58613 .6693 L p F P
0 0 0 r
s
1 .878 .2 r
.58088 .71307 m .58613 .6693 L .61085 .6662 L p F P
0 0 0 r
s
1 1 .227 r
.55441 .91355 m .54909 .94739 L .53747 .96428 L p F P
0 0 0 r
s
1 1 .217 r
.53411 .99704 m .53747 .96428 L .54909 .94739 L p F P
0 0 0 r
s
1 .859 .204 r
.50859 .62053 m .50923 .65814 L .48357 .64886 L p F P
0 0 0 r
s
1 .859 .204 r
.48357 .64886 m .48084 .62162 L .50859 .62053 L p F P
0 0 0 r
s
.994 .599 .148 r
.53371 .7094 m .53236 .75282 L .51052 .73197 L p F P
0 0 0 r
s
.994 .599 .148 r
.51052 .73197 m .50988 .69538 L .53371 .7094 L p F P
0 0 0 r
s
.757 .459 .118 r
.54083 .92843 m .53747 .96428 L .52558 .94574 L p F P
0 0 0 r
s
.757 .459 .118 r
.52558 .94574 m .52694 .91159 L .54083 .92843 L p F P
0 0 0 r
s
1 .807 .187 r
.58613 .6693 m .59138 .6252 L .61812 .62935 L p F P
0 0 0 r
s
1 1 .224 r
.55973 .87716 m .55441 .91355 L .54083 .92843 L p F P
0 0 0 r
s
1 1 .227 r
.53747 .96428 m .54083 .92843 L .55441 .91355 L p F P
0 0 0 r
s
1 .698 .168 r
.53506 .66526 m .53371 .7094 L .50988 .69538 L p F P
0 0 0 r
s
1 .698 .168 r
.50988 .69538 m .50923 .65814 L .53506 .66526 L p F P
0 0 0 r
s
1 .77 .179 r
.59138 .6252 m .58613 .6693 L .56078 .66911 L p F P
0 0 0 r
s
1 .77 .179 r
.56078 .66911 m .56407 .62233 L .59138 .6252 L p F P
0 0 0 r
s
.886 .534 .134 r
.54418 .88983 m .54083 .92843 L .52694 .91159 L p F P
0 0 0 r
s
.886 .534 .134 r
.52694 .91159 m .5283 .87488 L .54418 .88983 L p F P
0 0 0 r
s
1 .958 .215 r
.56504 .83855 m .55973 .87716 L .54418 .88983 L p F P
0 0 0 r
s
1 1 .224 r
.54083 .92843 m .54418 .88983 L .55973 .87716 L p F P
0 0 0 r
s
1 .795 .184 r
.58613 .6693 m .58088 .71307 L .55749 .71556 L p F P
0 0 0 r
s
1 .795 .184 r
.55749 .71556 m .56078 .66911 L .58613 .6693 L p F P
0 0 0 r
s
1 .78 .184 r
.5364 .62077 m .53506 .66526 L .50923 .65814 L p F P
0 0 0 r
s
1 .78 .184 r
.50923 .65814 m .50859 .62053 L .5364 .62077 L p F P
0 0 0 r
s
1 .907 .206 r
.57033 .79808 m .56504 .83855 L .54753 .84884 L p F P
0 0 0 r
s
1 .958 .215 r
.54418 .88983 m .54753 .84884 L .56504 .83855 L p F P
0 0 0 r
s
1 .825 .19 r
.58088 .71307 m .57562 .75612 L .55418 .76128 L p F P
0 0 0 r
s
1 .825 .19 r
.55418 .76128 m .55749 .71556 L .58088 .71307 L p F P
0 0 0 r
s
1 .758 .178 r
.56407 .62233 m .56078 .66911 L .53506 .66526 L p F P
0 0 0 r
s
1 .758 .178 r
.53506 .66526 m .5364 .62077 L .56407 .62233 L p F P
0 0 0 r
s
1 .863 .197 r
.57562 .75612 m .57033 .79808 L .55086 .80585 L p F P
0 0 0 r
s
1 .863 .197 r
.55086 .80585 m .55418 .76128 L .57562 .75612 L p F P
0 0 0 r
s
1 .907 .206 r
.54753 .84884 m .55086 .80585 L .57033 .79808 L p F P
0 0 0 r
s
.993 .595 .146 r
.54753 .84884 m .54418 .88983 L .5283 .87488 L p F P
0 0 0 r
s
.993 .595 .146 r
.5283 .87488 m .52966 .83594 L .54753 .84884 L p F P
0 0 0 r
s
1 .643 .156 r
.55086 .80585 m .54753 .84884 L .52966 .83594 L p F P
0 0 0 r
s
1 .643 .156 r
.52966 .83594 m .53101 .79513 L .55086 .80585 L p F P
0 0 0 r
s
1 .736 .173 r
.56078 .66911 m .55749 .71556 L .53371 .7094 L p F P
0 0 0 r
s
1 .736 .173 r
.53371 .7094 m .53506 .66526 L .56078 .66911 L p F P
0 0 0 r
s
1 .711 .169 r
.53236 .75282 m .53371 .7094 L .55749 .71556 L p F P
0 0 0 r
s
1 .681 .163 r
.55418 .76128 m .55086 .80585 L .53101 .79513 L p F P
0 0 0 r
s
1 .681 .163 r
.53101 .79513 m .53236 .75282 L .55418 .76128 L p F P
0 0 0 r
s
1 .711 .169 r
.55749 .71556 m .55418 .76128 L .53236 .75282 L p F P
0 0 0 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[306]:=",
  ImageSize->{300, 403.625},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001Tb000`400?l00000o`00003oo`2?_8l/
08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo
003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0
Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool0
0?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?
_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00
o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nl
S`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o
08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?
0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0
Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool009@0Skb?3P000029
08nlS`40oooo002708nlS`d000002@1IXXX00`000000IkZL06NjW00206NjW0X00000O`2?_8l10?oo
o`00PP2?_8l500000080BhUg00<0000005VRRP1IXXX04@1IXXX00`000000IkZL06NjW00<06NjW0L0
0000N02?_8l10?ooo`00OP2?_8l4000000L0BhUg00<0000005VRRP1IXXX04@1IXXX00`000000IkZL
06NjW00A06NjW0030000001ddZd0000000<00000M02?_8l10?ooo`00N@2?_8l5000000/0BhUg00<0
000005VRRP1IXXX04@1IXXX00`000000IkZL06NjW00A06NjW0030000001ddZd0M=:]00<0M=:]0`00
001a08nlS`40oooo001e08nlS`@00000401;RGL00`000000FJ::05VRRP0A05VRRP030000001W^Y`0
IkZL0140IkZL00<0000007CB[@1ddZd01P1ddZd4000006d0Skb?0@3oool007<0Skb?0P0000000`0l
L6@0000004^9M`0A04^9M`030000001IXXX0FJ::0140FJ::00<0000006NjW01W^Y`04@1W^Y`00`00
0000M=:]07CB[@0:07CB[@@00000J@2?_8l10?ooo`00L02?_8l3000000<0?71T00<0000004^9M`1;
RGL0401;RGL00`000000FJ::05VRRP0A05VRRP030000001W^Y`0IkZL0140IkZL00<0000007CB[@1d
dZd03P1ddZd3000006H0Skb?0@3oool006h0Skb?0P00000603a`I0030000001;RGL0BhUg0100BhUg
00<0000005VRRP1IXXX04@1IXXX00`000000IkZL06NjW00A06NjW0030000001ddZd0M=:]00l0M=:]
00@00000083X^`0000000000I02?_8l10?ooo`00K02?_8l2000000P0?71T00<0000004^9M`1;RGL0
401;RGL00`000000FJ::05VRRP0A05VRRP030000001W^Y`0IkZL0140IkZL00<0000007CB[@1ddZd0
3`1ddZd010000000P>Rk083X^`20j;/200000680Skb?0@3oool006T0Skb?0`00000:03a`I0030000
001;RGL0BhUg0100BhUg00<0000005VRRP1IXXX0201IXXXC000000X0IkZL00<0000007CB[@1ddZd0
3`1ddZd00`000000P>Rk083X^`03083X^`800000H02?_8l10?ooo`00I`2?_8l2000000d0?71T00<0
000004^9M`1;RGL03P1;RGL=000000T0FJ::00<0000006NjW01W^Y`01`1W^Y`<00000100M=:]00<0
0000083X^`20j;/01@20j;/3000005d0Skb?0@3oool006D0Skb?0P00000?03a`I0030000001;RGL0
BhUg00T0BhUg1@00000204^9M`030000001IXXX0FJ::0140FJ::00<0000006NjW01W^Y`04@1W^Y`0
0`000000M=:]00000003000000`0M=:]00<00000083X^`20j;/02020j;/2000005/0Skb?0@3oool0
06<0Skb?0`00000@03a`I0030000001;RGL0BhUg00D0BhUg1000000704^9M`030000001IXXX0FJ::
0140FJ::00<0000006NjW01W^Y`04@1W^Y`00`000000M=:]07CB[@0307CB[@<000002@1ddZd00`00
0000P>Rk083X^`0:083X^`800000F@2?_8l10?ooo`00HP2?_8l010000000;UI?02iFC`00000@03a`
I0030000001;RGL0BhUg00D000002`1;RGL00`000000FJ::05VRRP0A05VRRP030000001W^Y`0IkZL
0140IkZL00<0000007CB[@1ddZd01P1ddZd4000000D0M=:]00<00000083X^`20j;/03020j;/20000
05L0Skb?0@3oool00600Skb?0P00000302iFC`030000000lL6@0?71T00d0?71T1000000@04^9M`03
0000001IXXX0FJ::0140FJ::00<0000006NjW01W^Y`04@1W^Y`00`000000M=:]07CB[@0:07CB[@@0
000000<0M=:]00000020j;/03P20j;/3000005D0Skb?0@3oool005l0Skb?00<0000002iFC`0^ETl0
0`0^ETl00`000000?71T03a`I00;03a`I080000000<0?71T0000001;RGL04@1;RGL00`000000FJ::
05VRRP0A05VRRP030000001W^Y`0IkZL0140IkZL00<0000007CB[@1ddZd03P1ddZd3000000h0P>Rk
00@0000008Sg``28ml<00000E02?_8l10?ooo`00G@2?_8l2000000H0;UI?00<0000003a`I00lL6@0
200lL6@3000000<0?71T00<0000004^9M`1;RGL0401;RGL00`000000FJ::05VRRP0A05VRRP030000
001W^Y`0IkZL0140IkZL00<0000007CB[@1ddZd03`1ddZd010000000P>Rk00000000000<083X^`05
00000028ml<0R?O308Sg``000000D`2?_8l10?ooo`00F`2?_8l2000000P0;UI?00<0000003a`I00l
L6@01P0lL6@2000000H0?71T00<0000004^9M`1;RGL0401;RGL00`000000FJ::05VRRP0A05VRRP03
0000001W^Y`0IkZL0140IkZL00<0000007CB[@1ddZd03`1ddZd010000000P>Rk083X^`20j;/20000
00X0P>Rk00<0000008Sg``28ml<00P28ml<200000540Skb?0@3oool005X0Skb?00<0000002iFC`0^
ETl0200^ETl00`000000?71T03a`I00403a`I0800000200lL6@00`000000BhUg04^9M`0@04^9M`03
0000001IXXX0FJ::00P0FJ::3P00000?06NjW0030000001ddZd0M=:]00l0M=:]00<00000083X^`20
j;/00`20j;/2000000P0P>Rk00<0000008Sg``28ml<01028ml<00`000000Skb?08nlS`1>08nlS`40
oooo001H08nlS`8000002`0^ETl010000000?71T03a`I00lL6@3000000T0?71T00<0000004^9M`1;
RGL0401;RGL<000000T0FJ::00<0000006NjW01W^Y`00P1W^Y`:000000D0IkZL00<0000007CB[@1d
dZd03`1ddZd00`000000P>Rk083X^`05083X^`8000001`20j;/00`000000R?O308Sg``0408Sg``80
0000CP2?_8l10?ooo`00E`2?_8l00`000000;UI?02iFC`0;02iFC`040000000lL6@00000000000`0
?71T00<0000004^9M`1;RGL0301;RGL40000000304^9M`000000FJ::0180FJ::00<0000006NjW01W
^Y`0301W^Y`700000100M=:]00<00000083X^`20j;/01`20j;/2000000D0P>Rk00<0000008Sg``28
ml<01P28ml<00`000000Skb?08nlS`1;08nlS`40oooo001F08nlS`8000003@0^ETl2000000h0?71T
00<0000004^9M`1;RGL0201;RGL4000000D0BhUg00<0000005VRRP1IXXX04@1IXXX00`000000IkZL
06NjW00A06NjW0030000001ddZd0000000<000003@1ddZd00`000000P>Rk083X^`08083X^`800000
0`20j;/00`000000R?O308Sg``0708Sg``030000002?_8l0Skb?04X0Skb?0@3oool005D0Skb?00<0
000001hh=`0000002`0^ETl3000000l0?71T00<0000004^9M`1;RGL0101;RGL4000000T0BhUg00<0
000005VRRP1IXXX04@1IXXX00`000000IkZL06NjW00A06NjW0030000001ddZd0M=:]00<0M=:]1000
000907CB[@0300000020j;/0P>Rk00X0P>Rk0P0000000`20j;/0000008Sg``0908Sg``800000BP2?
_8l10?ooo`00E02?_8l0100000007SPg01hh=`00000902iFC`8000000P0^ETl00`000000?71T03a`
I00=03a`I0030000001;RGL0BhUg00@000003@1;RGL00`000000FJ::05VRRP0A05VRRP030000001W
^Y`0IkZL0140IkZL00<0000007CB[@1ddZd01`1ddZd4000000D0M=:]00<00000083X^`20j;/03020
j;/2000000`0R?O300<0000008nlS`2?_8l0A`2?_8l10?ooo`00D`2?_8l01@0000007SPg01hh=`0N
>3L0000000P0;UI?00<0000002iFC`0^ETl00P0^ETl00`000000?71T03a`I00<03a`I0@000004@1;
RGL00`000000FJ::05VRRP0A05VRRP030000001W^Y`0IkZL0140IkZL00<0000007CB[@1ddZd02`1d
dZd40000000307CB[@000000P>Rk00h0P>Rk0`00000:08Sg``800000B02?_8l10?ooo`00DP2?_8l0
1@0000007SPg01hh=`0N>3L0000000L0;UI?0P00000502iFC`030000000lL6@0?71T00T0?71T0`00
00000`0lL6@0000004^9M`0B04^9M`030000001IXXX0FJ::0140FJ::00<0000006NjW01W^Y`04@1W
^Y`00`000000M=:]07CB[@0?07CB[@<000003P20j;/010000000R?O308Sg``00000908Sg``030000
0023lK/0000004L0Skb?0@3oool00540Skb?00<0000001hh=`0N>3L00P0N>3L00`000000;UI?02iF
C`0302iFC`8000001P0^ETl00`000000?71T03a`I00703a`I0<00000100lL6@00`000000BhUg04^9
M`0A04^9M`030000001IXXX0FJ::0140FJ::00<0000006NjW01W^Y`04@1W^Y`00`000000M=:]07CB
[@0@07CB[@0400000020j;/00000000000`0P>Rk00@0000008Sg``28ml<0R?O30P00000708Sg``04
00000023lK/0Po6k000004H0Skb?0@3oool00500Skb?00<0000001hh=`0N>3L00`0N>3L00`000000
;UI?02iFC`0202iFC`030000000^ETl0;UI?00H0;UI?00<0000003a`I00lL6@01@0lL6@2000000L0
?71T00<0000004^9M`1;RGL04@1;RGL00`000000FJ::05VRRP0A05VRRP030000001W^Y`0IkZL0140
IkZL00<0000007CB[@1ddZd0401ddZd010000000P>Rk083X^`20j;/2000000X0P>Rk00<0000008Sg
``28ml<00`28ml<00`000000R?O308Sg``0408Sg``0500000023lK/0Po6k08?a^`000000A@2?_8l1
0?ooo`00C`2?_8l00`0000007SPg01hh=`0401hh=`030000000^ETl0;UI?008000002@0^ETl00`00
0000?71T03a`I00203a`I0<000002@0lL6@00`000000BhUg04^9M`0A04^9M`030000001IXXX0FJ::
00P0FJ::3P00000?06NjW0030000001ddZd0M=:]0100M=:]00<00000083X^`20j;/00`20j;/20000
00P0P>Rk00<0000008Sg``28ml<01028ml<00`000000R?O308Sg``0308Sg``0300000023lK/0Po6k
0080Po6k00<0000008nlS`2?_8l0@P2?_8l10?ooo`00CP2?_8l00`0000007SPg01hh=`0501hh=`<0
00002`0^ETl00`000000?71T00000002000000`0?71T00<0000004^9M`1;RGL03`1;RGL=000000T0
FJ::00<0000006NjW01W^Y`00P1W^Y`:000000D0IkZL00<0000007CB[@1ddZd0401ddZd00`000000
P>Rk083X^`05083X^`<000001@20j;/00`000000R?O308Sg``0508Sg``8000000`28ml<00`000000
Po6k08?a^`0208?a^`030000002?_8l0Skb?0480Skb?0@3oool004d0Skb?00<0000001hh=`0N>3L0
1P0N>3L00`000000;UI?02iFC`0;02iFC`8000003`0lL6@00`000000BhUg04^9M`0:04^9M`D00000
0P1;RGL00`000000FJ::05VRRP0A05VRRP030000001W^Y`0IkZL00`0IkZL1`00000A07CB[@030000
0020j;/0P>Rk00P0P>Rk0P000003083X^`0300000028ml<0R?O300L0R?O300@0000008Sg``28ml<0
00001@23lK/00`000000Skb?08nlS`1108nlS`40oooo001<08nlS`030000000N>3L07SPg00H07SPg
0P00000;02iFC`<00000400lL6@00`000000BhUg04^9M`0504^9M`D000001`1;RGL00`000000FJ::
05VRRP0A05VRRP030000001W^Y`0IkZL0140IkZL00<0000007CB[@0000000`00000=07CB[@030000
0020j;/0P>Rk00X0P>Rk0P0000000`20j;/0000008Sg``0908Sg``<000001P23lK/00`000000Skb?
08nlS`1008nlS`40oooo001;08nlS`8000001`0N>3L00`0000007SPg0000000:02iFC`040000000^
ETl0;UI?00000100?71T00<0000004^9M`1;RGL01@00000<04^9M`030000001IXXX0FJ::0140FJ::
00<0000006NjW01W^Y`04@1W^Y`00`000000M=:]07CB[@0307CB[@@000002@1ddZd00`000000P>Rk
083X^`0<083X^`8000003028ml<00`000000Po6k08?a^`0508?a^`030000002?_8l0Skb?03l0Skb?
0@3oool004/0Skb?0P00000601hh=`040000000N>3L07SPg000000P0;UI?0P00000302iFC`030000
000lL6@0?71T00d0?71T1000000A04^9M`030000001IXXX0FJ::0140FJ::00<0000006NjW01W^Y`0
4@1W^Y`00`000000M=:]07CB[@0707CB[@@000001@1ddZd00`000000P>Rk083X^`0=083X^`<00000
2P28ml<2000000L0Po6k00<0000008nlS`2?_8l0?P2?_8l10?ooo`00BP2?_8l00`00000031PL0000
000501hh=`050000000N>3L07SPg01hh=`0000001`0^ETl00`000000;UI?02iFC`0302iFC`030000
000lL6@0?71T00/0?71T0P0000000`0lL6@0000004^9M`0A04^9M`030000001IXXX0FJ::0180FJ::
00<0000006NjW01W^Y`04@1W^Y`00`000000M=:]07CB[@0;07CB[@@0000000<0M=:]00000020j;/0
3P20j;/010000000R?O308Sg``00000908Sg``0300000023lK/0000000L0Po6k00<0000008nlS`2?
_8l0?@2?_8l10?ooo`00BP2?_8l00`00000031PL0000000301hh=`800000100N>3L00`000000;UI?
02iFC`0302iFC`8000001P0^ETl00`000000?71T03a`I00803a`I0<000000`0lL6@00`000000BhUg
04^9M`0@04^9M`030000001IXXX0FJ::0180FJ::00<0000006NjW01W^Y`04@1W^Y`00`000000M=:]
07CB[@0?07CB[@<000003P20j;/01@000000R?O308Sg``28ml<0000000P0R?O300@0000008?a^`23
lK/000001P23lK/00`000000Skb?08nlS`0m08nlS`40oooo001908nlS`030000000<61`0000000<0
7SPg00<0000001hh=`0N>3L0100N>3L010000000;UI?02iFC`0^ETl2000000P0;UI?00<0000003a`
I00lL6@01P0lL6@2000000H0?71T00<0000004^9M`1;RGL0401;RGL00`000000FJ::05VRRP0B05VR
RP030000001W^Y`0IkZL0140IkZL00<0000007CB[@1ddZd0401ddZd010000000P>Rk00000000000<
083X^`0300000028ml<0R?O30080R?O30P00000608Sg``0500000023lK/0Po6k08?a^`0000001@23
lK/2000003h0Skb?0@3oool004P0Skb?00@0000000`H700<61`000000P0N>3L00`0000007SPg01hh
=`0501hh=`040000000^ETl0;UI?000000X0;UI?00<0000003a`I00lL6@0100lL6@2000000P0?71T
00<0000004^9M`1;RGL0401;RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0140IkZL
00<0000007CB[@1ddZd0401ddZd010000000P>Rk083X^`20j;/3000000T0P>Rk00<0000008Sg``28
ml<01028ml<00`000000R?O308Sg``0308Sg``0300000023lK/0Po6k0080Po6k00<0000008?a^`23
lK/00P23lK/2000003h0Skb?0@3oool004P0Skb?00H0000000`H700<61`0000001hh=`00000801hh
=`<000002`0^ETl010000000?71T03a`I00lL6@3000000X0?71T00<0000004^9M`1;RGL0401;RGL0
0`000000FJ::05VRRP0805VRRPl000003`1W^Y`00`000000M=:]07CB[@0@07CB[@0300000020j;/0
P>Rk00@0P>Rk0P000008083X^`0300000028ml<0R?O300@0R?O30P00000408Sg``0500000023lK/0
Po6k08?a^`0000001023lK/00`000000H[R=0000000m08nlS`40oooo001708nlS`040000000<61`0
31PL00`H708000002@0N>3L00`000000;UI?02iFC`0;02iFC`040000000lL6@00000000000d0?71T
00<0000004^9M`1;RGL03P1;RGL=000000X0FJ::00<0000006NjW01W^Y`00P1W^Y`:000000D0IkZL
00<0000007CB[@1ddZd0401ddZd00`000000P>Rk083X^`06083X^`8000001P20j;/00`000000R?O3
08Sg``0608Sg``0500000028ml<0R?O308Sg``0000001023lK/01`000000Po6k08?a^`23lK/00000
06:hS@000000?@2?_8l10?ooo`00A`2?_8l01@00000031PL00`H700<61`0000000T07SPg0P00000=
02iFC`8000003`0lL6@00`000000BhUg04^9M`0904^9M`D000000P1;RGL00`000000FJ::05VRRP0B
05VRRP030000001W^Y`0IkZL00`0IkZL1`00000A07CB[@0300000020j;/0P>Rk00P0P>Rk0`000003
083X^`0300000028ml<0R?O300L0R?O300@0000008Sg``28ml<000001@23lK/010000000Po6k08?a
^`00000206:hS@030000002?_8l0Skb?03X0Skb?0@3oool004H0Skb?00@0000000`H700<61`031PL
0P00000801hh=`030000000N>3L0000000/0;UI?0`00000@03a`I0030000001;RGL0BhUg00D0BhUg
1000000704^9M`030000001IXXX0FJ::0180FJ::00<0000006NjW01W^Y`04@1W^Y`00`000000M=:]
00000003000000d0M=:]00<00000083X^`20j;/02`20j;/200000003083X^`000000R?O300T0R?O3
0`00000608?a^`0300000023lK/000000080H[R=00<0000008nlS`2?_8l0>P2?_8l10?ooo`00AP2?
_8l01000000031PL00`H700<61`2000000L07SPg00@0000001hh=`0N>3L000002@0^ETl200000080
;UI?00<0000003a`I00lL6@03P0lL6@00`000000BhUg04^9M`05000000/0BhUg00<0000005VRRP1I
XXX04P1IXXX00`000000IkZL06NjW00A06NjW0030000001ddZd0M=:]00<0M=:]1000000907CB[@03
00000020j;/0P>Rk00d0P>Rk0P00000<08Sg``0300000023lK/0Po6k00D0Po6k0P00000306:hS@03
0000002?_8l0Skb?03T0Skb?0@3oool004D0Skb?00L0000000`H700<61`031PL0000000<61`00000
00H07SPg00D0000001hh=`0N>3L07SPg0000000802iFC`030000000^ETl0;UI?0080;UI?00<00000
03a`I00lL6@03@0lL6@400000100BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL06NjW00A
06NjW0030000001ddZd0M=:]00L0M=:]1000000507CB[@0300000020j;/0P>Rk00h0P>Rk0`00000:
08Sg``8000001`23lK/01@000000H[R=06:hS@1R^8d0000003/0Skb?0@3oool004D0Skb?00L00000
00`H700<61`031PL0000000<61`0000000D07SPg00D0000001hh=`0N>3L07SPg0000000702iFC`80
00001@0^ETl00`000000?71T03a`I00;03a`I080000000<0?71T0000001;RGL04@1;RGL00`000000
FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0140IkZL00<0000007CB[@1ddZd02`1ddZd400000003
07CB[@000000P>Rk00l0P>Rk00@0000008Sg``28ml<000002@28ml<00`000000Po6k0000000608?a
^`8000000`1R^8d00`000000Skb?08nlS`0h08nlS`40oooo001408nlS`8000000P0<61`010000000
31PL00`H7000000401hh=`030000000N>3L07SPg00807SPg00<0000002iFC`0^ETl00`0^ETl20000
00H0;UI?00<0000003a`I00lL6@02@0lL6@3000000<0?71T00<0000004^9M`1;RGL0401;RGL00`00
0000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0140IkZL00<0000007CB[@1ddZd03`1ddZd30000
00l0P>Rk00D0000008Sg``28ml<0R?O30000000808Sg``0400000023lK/0Po6k000000D0Po6k0P00
000306:hS@030000002?_8l0Skb?03P0Skb?0@3oool004@0Skb?0P0000000`0<61`0000000`H7002
00`H70050000000N>3L07SPg01hh=`0000001@0N>3L00`000000;UI?02iFC`0202iFC`030000000^
ETl0;UI?00H0;UI?00<0000003a`I00lL6@01`0lL6@2000000H0?71T00<0000004^9M`1;RGL0401;
RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0140IkZL00<0000007CB[@1ddZd0401d
dZd010000000P>Rk00000000000=083X^`0300000028ml<0R?O30080R?O30P00000608Sg``050000
0023lK/0Po6k08?a^`0000001023lK/00`000000H[R=0000000306:hS@030000002?_8l0Skb?03L0
Skb?0@3oool004@0Skb?0P0000000`0<61`0000000`H700200`H70040000000N>3L07SPg000000H0
7SPg00<0000002iFC`0^ETl00P00000902iFC`030000000lL6@0?71T00@0?71T0`00000803a`I003
0000001;RGL0BhUg0100BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL06NjW00A06NjW003
0000001ddZd0M=:]0100M=:]00@00000083X^`20j;/0P>Rk0`00000:083X^`0300000028ml<0R?O3
00@0R?O300<0000008Sg``28ml<00`28ml<00`000000Po6k08?a^`0208?a^`0700000023lK/0Po6k
08?a^`000000H[R=0000000306:hS@030000002?_8l0Skb?03L0Skb?0@3oool004@0Skb?00<00000
00`H70000000100<61`00`0000007SPg0000000701hh=`<000002`0^ETl010000000?71T03a`I00l
L6@3000000/0?71T00<0000004^9M`1;RGL0401;RGL00`000000FJ::05VRRP0B05VRRP030000001W
^Y`0IkZL0140IkZL00<0000007CB[@1ddZd0401ddZd00`000000P>Rk083X^`04083X^`8000002020
j;/00`000000R?O308Sg``0508Sg``8000001028ml<01@000000Po6k08?a^`23lK/0000000<0Po6k
00@0000006:hS@1R^8d000000P1R^8d00`000000Skb?08nlS`0g08nlS`40oooo001308nlS`800000
00<031PL0000000<61`00`0<61`2000000P07SPg00<0000002iFC`0^ETl02`0^ETl010000000?71T
00000000000>03a`I0030000001;RGL0BhUg0100BhUg00<0000005VRRP1IXXX0201IXXXD000000X0
IkZL00<0000007CB[@1ddZd0401ddZd00`000000P>Rk083X^`06083X^`8000001P20j;/00`000000
R?O308Sg``0708Sg``0500000028ml<0R?O308Sg``0000001023lK/01`000000Po6k08?a^`23lK/0
000006:hS@0000000P1R^8d00`000000Skb?08nlS`0g08nlS`40oooo001308nlS`<000001@0<61`0
0`0000007SPg01hh=`0601hh=`8000003@0^ETl200000100?71T00<0000004^9M`1;RGL03P1;RGL=
000000X0FJ::00<0000006NjW01W^Y`01`1W^Y`<00000140M=:]00<00000083X^`20j;/02020j;/3
000000<0P>Rk00<0000008Sg``28ml<02028ml<010000000R?O308Sg``00000508?a^`0400000023
lK/0Po6k00000080H[R=00@0000006:hS@0000000000>02?_8l10?ooo`00@`2?_8l3000000@031PL
0P00000701hh=`030000000N>3L0000000/0;UI?0`00000A03a`I0030000001;RGL0BhUg00T0BhUg
1@00000204^9M`030000001IXXX0FJ::0180FJ::00<0000006NjW01W^Y`04@1W^Y`00`000000M=:]
00000003000000h0M=:]00<00000083X^`20j;/02P20j;/200000003083X^`000000R?O300X0R?O3
0`00000608?a^`0300000023lK/000000080H[R=00@0000006:hS@0000000000>02?_8l10?ooo`00
@`2?_8l2000000D031PL0P00000601hh=`040000000N>3L07SPg000000X0;UI?00@0000002iFC`0^
ETl000004@0lL6@00`000000BhUg04^9M`0504^9M`@000001`1;RGL00`000000FJ::05VRRP0B05VR
RP030000001W^Y`0IkZL0140IkZL00<0000007CB[@1ddZd00`1ddZd4000000X0M=:]00<00000083X
^`20j;/03020j;/2000000d0R?O300<0000008?a^`23lK/01@23lK/2000000<0H[R=00<0000006:h
S@000000>02?_8l10?ooo`00@P2?_8l00`00000010P:0000000400`H70030000000<61`0000000D0
7SPg00D0000001hh=`0N>3L07SPg0000000802iFC`8000000`0^ETl00`000000?71T03a`I00?03a`
I0030000001;RGL0BhUg00D000002`1;RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL
0140IkZL00<0000007CB[@1ddZd01`1ddZd4000000H0M=:]00<00000083X^`20j;/03@20j;/30000
00/0R?O30P00000708?a^`070000001R^8d0H[R=06:hS@000000H[R=0000000h08nlS`40oooo0012
08nlS`030000000420X0000000<031PL00@0000000`H700<61`00000100N>3L00`0000007SPg01hh
=`0201hh=`030000000^ETl0;UI?00D0;UI?00<0000002iFC`0^ETl00`0^ETl00`000000?71T03a`
I00>03a`I0@00000401;RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0140IkZL00<0
000007CB[@1ddZd02`1ddZd400000080M=:]00<00000083X^`20j;/03@20j;/010000000R?O308Sg
``00000:08Sg``0300000023lK/0000000H0Po6k00<0000006:hS@1R^8d00P1R^8d2000003P0Skb?
0@3oool00480Skb?0`00000300`H70030000000<61`0000000@07SPg00<0000001hh=`0N>3L00`0N
>3L00`000000;UI?02iFC`0302iFC`8000001P0^ETl00`000000?71T03a`I00;03a`I0<0000000<0
?71T0000001;RGL04@1;RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0140IkZL00<0
000007CB[@1ddZd03`1ddZd4000000h0P>Rk00D0000008Sg``28ml<0R?O30000000908Sg``040000
0023lK/0Po6k000000D0Po6k0P00000306:hS@800000>02?_8l10?ooo`00@P2?_8l30000008031PL
00@0000000`H700<61`000000`0N>3L00`0000007SPg01hh=`0401hh=`040000000^ETl0;UI?02iF
C`800000200^ETl00`000000?71T03a`I00803a`I0<00000100lL6@00`000000BhUg04^9M`0@04^9
M`030000001IXXX0FJ::0180FJ::00<0000006NjW01W^Y`04P1W^Y`00`000000M=:]07CB[@0@07CB
[@0400000020j;/00000000000`0P>Rk00<0000008Sg``28ml<00P28ml<2000000L0R?O300D00000
08?a^`23lK/0Po6k0000000408?a^`800000101R^8d2000003L0Skb?0@3oool00480Skb?0P000002
00`H70050000000<61`031PL00`H700000000P0N>3L00`0000007SPg01hh=`0501hh=`040000000^
ETl0;UI?000000X0;UI?00<0000003a`I00lL6@01@0lL6@3000000L0?71T00<0000004^9M`1;RGL0
401;RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL00<0000007CB[@1ddZd0
401ddZd010000000P>Rk083X^`20j;/3000000T0P>Rk00<0000008Sg``28ml<01028ml<00`000000
R?O308Sg``0408Sg``0300000023lK/0Po6k0080Po6k00L0000008?a^`23lK/0Po6k0000001R^8d0
000000<0H[R=0P00000g08nlS`40oooo001208nlS`8000000P0<61`01`00000031PL00`H700<61`0
000001hh=`000000200N>3L3000000/0;UI?00<0000003a`I00lL6@00P0lL6@3000000X0?71T00<0
000004^9M`1;RGL0401;RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL00<0
000007CB[@1ddZd0401ddZd00`000000P>Rk083X^`04083X^`8000002020j;/00`000000R?O308Sg
``0408Sg``8000001028ml<00`000000Po6k08?a^`0208?a^`0700000023lK/0Po6k08?a^`000000
H[R=0000000306:hS@800000=`2?_8l10?ooo`00@P2?_8l20000000300`H7000000031PL00<031PL
0P00000901hh=`030000000^ETl0;UI?00/0;UI?00<0000003a`I00000000P00000<03a`I0030000
001;RGL0BhUg0140BhUg00<0000005VRRP1IXXX0201IXXX@000000l0IkZL00<0000007CB[@1ddZd0
401ddZd00`000000P>Rk083X^`06083X^`8000001P20j;/00`000000R?O308Sg``0608Sg``050000
0028ml<0R?O308Sg``0000001@23lK/01`000000Po6k08?a^`23lK/0000006:hS@0000000P1R^8d2
000003L0Skb?0@3oool00440Skb?1000000500`H70030000000N>3L07SPg00L07SPg0P00000=02iF
C`8000003`0lL6@00`000000BhUg04^9M`0?04^9M`d000002P1IXXX00`000000IkZL06NjW00306Nj
W0X000001@1W^Y`00`000000M=:]07CB[@0@07CB[@0300000020j;/0P>Rk00P0P>Rk0`000003083X
^`0300000028ml<0R?O300L0R?O300@0000008Sg``28ml<000001P23lK/01P000000Po6k08?a^`00
0000H[R=00000080H[R=0P00000g08nlS`40oooo001108nlS`@00000100<61`2000000P07SPg00<0
000001hh=`0000002`0^ETl300000100?71T00<0000004^9M`1;RGL02P1;RGL500000080BhUg00<0
000005VRRP1IXXX04P1IXXX00`000000IkZL06NjW00=06NjW0L000004@1ddZd00`000000P>Rk083X
^`0;083X^`80000000<0P>Rk00000028ml<02@28ml<3000000L0Po6k00<0000008?a^`0000000P1R
^8d010000000H[R=00000000000g08nlS`40oooo001108nlS`<000001@0<61`2000000L07SPg00@0
000001hh=`0N>3L000002@0^ETl200000080;UI?00<0000003a`I00lL6@03P0lL6@00`000000BhUg
04^9M`0504^9M`D000001`1;RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL
00<0000007CB[@0000000`00000=07CB[@0300000020j;/0P>Rk00d0P>Rk0P00000<08Sg``030000
0023lK/0Po6k00H0Po6k0P00000206:hS@040000001R^8d00000000003L0Skb?0@3oool00440Skb?
00<0000000@82P000000100<61`00`00000031PL0000000601hh=`050000000N>3L07SPg01hh=`00
0000200^ETl00`000000;UI?02iFC`0202iFC`030000000lL6@0?71T00h0?71T00<0000004^9M`1;
RGL01@00000<04^9M`030000001IXXX0FJ::0180FJ::00<0000006NjW01W^Y`04P1W^Y`00`000000
M=:]07CB[@0307CB[@@000002@1ddZd00`000000P>Rk083X^`0>083X^`<000002P28ml<2000000P0
Po6k00@0000006:hS@1R^8d0H[R=0`00000g08nlS`40oooo001108nlS`<00000100<61`00`000000
31PL0000000501hh=`050000000N>3L07SPg01hh=`0000001`0^ETl2000000D0;UI?00<0000003a`
I00lL6@03@0lL6@400000140BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL06NjW00B06Nj
W0030000001ddZd0M=:]00L0M=:]1000000507CB[@0300000020j;/0P>Rk00h0P>Rk00@0000008Sg
``28ml<000002@28ml<00`000000Po6k0000000708?a^`040000001R^8d0H[R=06:hS@@00000=P2?
_8l10?ooo`00@@2?_8l3000000<031PL00<0000000`H70000000100N>3L2000000@07SPg00<00000
02iFC`0^ETl00`0^ETl2000000L0;UI?00<0000003a`I00lL6@02`0lL6@20000000303a`I0000000
BhUg0180BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL06NjW00B06NjW0030000001ddZd0
M=:]00/0M=:]100000000`1ddZd00000083X^`0?083X^`0500000028ml<0R?O308Sg``0000002028
ml<010000000Po6k08?a^`00000608?a^`8000000`1R^8d3000003H0Skb?0@3oool00440Skb?0`00
000200`H70040000000<61`031PL000000<07SPg00<0000001hh=`0N>3L0100N>3L00`000000;UI?
02iFC`0202iFC`030000000^ETl0;UI?00H0;UI?00<0000003a`I00lL6@02@0lL6@3000000<0?71T
00<0000004^9M`1;RGL04@1;RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL
00<0000007CB[@1ddZd03`1ddZd3000000l0P>Rk00<0000008Sg``28ml<00P28ml<2000000H0R?O3
00D0000008?a^`23lK/0Po6k0000000508?a^`8000000`1R^8d00`000000@GaI0000000f08nlS`40
oooo001108nlS`<000000P0<61`01000000031PL00`H7000000201hh=`030000000N>3L07SPg00D0
7SPg00<0000002iFC`0^ETl00P00000902iFC`030000000lL6@0?71T00L0?71T0P00000603a`I003
0000001;RGL0BhUg0140BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL06NjW00B06NjW003
0000001ddZd0M=:]0100M=:]00@00000083X^`00000000003@20j;/00`000000R?O308Sg``0408Sg
``0300000028ml<0R?O300<0R?O300<0000008?a^`23lK/00P23lK/00`000000Po6k08?a^`0208?a
^`030000001R^8d000000080H[R=00<00000045lF@000000=P2?_8l10?ooo`00@@2?_8l01@000000
10P:0000000<61`0000000<031PL00<0000001hh=`000000200N>3L3000000/0;UI?00<0000003a`
I00lL6@0100lL6@3000000P0?71T00<0000004^9M`1;RGL04@1;RGL00`000000FJ::05VRRP0B05VR
RP030000001W^Y`0IkZL0180IkZL00<0000007CB[@1ddZd0401ddZd010000000P>Rk083X^`20j;/3
000000X0P>Rk00<0000008Sg``28ml<01@28ml<2000000@0R?O300D0000008?a^`23lK/0Po6k0000
000408?a^`030000001R^8d000000080H[R=00<00000045lF@000000=P2?_8l10?ooo`00@@2?_8l0
1@00000010P:0000000<61`0000000<031PL0P00000901hh=`030000000^ETl0;UI?00/0;UI?00@0
000003a`I00lL6@0?71T0`00000;03a`I0030000001;RGL0BhUg0140BhUg00<0000005VRRP1IXXX0
4P1IXXX00`000000IkZL06NjW00B06NjW0030000001ddZd0M=:]0100M=:]00<00000083X^`20j;/0
1020j;/2000000P0P>Rk00<0000008Sg``28ml<01`28ml<01@000000R?O308Sg``28ml<0000000@0
Po6k00D0000008?a^`23lK/0Po6k0000000206:hS@030000001R^8d0000000800000=P2?_8l10?oo
o`00@02?_8l20000000300@82P000000000000@031PL00<0000001hh=`0N>3L01`0N>3L2000000d0
;UI?00@0000003a`I000000000003P0lL6@00`000000BhUg04^9M`0A04^9M`030000001IXXX0FJ::
00P0FJ::5@00000:06NjW0030000001ddZd0M=:]0100M=:]00<00000083X^`20j;/01P20j;/20000
00H0P>Rk00<0000008Sg``28ml<02028ml<010000000R?O308Sg``00000508?a^`0400000023lK/0
Po6k00000080H[R=00<0000006:hS@0000000P00000f08nlS`40oooo001008nlS`80000000<010P:
0000000000000`0<61`2000000P07SPg00<0000001hh=`0000003@0^ETl200000100?71T00<00000
04^9M`1;RGL03`1;RGL=000000X0FJ::00<0000006NjW01W^Y`0201W^Y`<00000140M=:]00<00000
083X^`20j;/02020j;/3000000<0P>Rk00<0000008Sg``28ml<02@28ml<3000000H0Po6k00<00000
08?a^`0000000`1R^8d010000000H[R=00000000000f08nlS`40oooo001008nlS`040000000420X0
10P:000000@031PL0P00000701hh=`040000000N>3L07SPg000000/0;UI?0`00000A03a`I0030000
001;RGL0BhUg00X0BhUg1@00000204^9M`030000001IXXX0FJ::0180FJ::00<0000006NjW01W^Y`0
4P1W^Y`00`000000M=:]00000003000000d0M=:]00<00000083X^`20j;/02`20j;/200000003083X
^`000000R?O300`0R?O300<0000008?a^`23lK/01@23lK/2000000<0H[R=00@0000006:hS@000000
0000=P2?_8l10?ooo`00@02?_8l01000000010P:00@82P00000300`H70030000000<61`0000000H0
7SPg00D0000001hh=`0N>3L07SPg0000000:02iFC`040000000^ETl0;UI?00000140?71T00<00000
04^9M`1;RGL01@1;RGL5000000L0BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL06NjW00B
06NjW0030000001ddZd0M=:]00<0M=:]1000000907CB[@0300000020j;/0P>Rk00d0P>Rk0P00000=
08Sg``8000001`23lK/00`000000H[R=06:hS@0206:hS@<00000=P2?_8l10?ooo`00@02?_8l01000
000010P:00000000000300`H70030000000<61`0000000D07SPg00<0000001hh=`0N>3L00P0N>3L0
0`000000;UI?02iFC`0602iFC`8000000`0^ETl00`000000?71T03a`I00?03a`I0030000001;RGL0
BhUg00D00000301;RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL00<00000
07CB[@1ddZd01`1ddZd4000000D0M=:]00<00000083X^`20j;/03P20j;/3000000/0R?O300<00000
08?a^`0000001P23lK/2000000<0H[R=0`00000f08nlS`40oooo001008nlS`040000000420X00000
0000008031PL00@0000000`H700<61`00000100N>3L00`0000007SPg01hh=`0301hh=`030000000^
ETl0;UI?00D0;UI?00<0000002iFC`0^ETl00`0^ETl00`000000?71T03a`I00>03a`I0@000004@1;
RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL00<0000007CB[@1ddZd02`1d
dZd40000000307CB[@000000P>Rk00l0P>Rk00@0000008Sg``28ml<000002P28ml<010000000Po6k
08?a^`00000508?a^`800000101R^8d2000003H0Skb?0@3oool00400Skb?00H0000000@82P000000
000000`H7000000300`H70050000000N>3L07SPg01hh=`0000001P0N>3L00`000000;UI?02iFC`03
02iFC`8000001P0^ETl00`000000?71T03a`I00;03a`I0<0000000<0?71T0000001;RGL04P1;RGL0
0`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL00<0000007CB[@1ddZd03`1ddZd3
000000l0P>Rk00@0000008Sg``28ml<0R?O30P00000808Sg``0500000023lK/0Po6k08?a^`000000
1023lK/00`000000H[R=0000000306:hS@800000=P2?_8l10?ooo`00@02?_8l00`00000010P:0000
000200`H70050000000<61`031PL00`H700000000P0N>3L00`0000007SPg01hh=`0501hh=`040000
000^ETl0;UI?02iFC`800000200^ETl00`000000?71T03a`I00803a`I0<00000100lL6@00`000000
BhUg04^9M`0A04^9M`030000001IXXX0FJ::0180FJ::00<0000006NjW01W^Y`04P1W^Y`00`000000
M=:]07CB[@0@07CB[@0400000020j;/00000000000d0P>Rk00<0000008Sg``28ml<00`28ml<00`00
0000R?O308Sg``0508Sg``0300000023lK/0Po6k0080Po6k00L0000008?a^`23lK/0Po6k0000001R
^8d0000000<0H[R=0P00000f08nlS`40oooo001008nlS`<0000000<031PL0000000<61`00`0<61`0
0`0000007SPg0000000801hh=`040000000^ETl0;UI?000000X0;UI?00<0000003a`I00lL6@01@0l
L6@3000000L0?71T00<0000004^9M`1;RGL04@1;RGL00`000000FJ::05VRRP0B05VRRP030000001W
^Y`0IkZL0180IkZL00<0000007CB[@1ddZd0401ddZd010000000P>Rk083X^`20j;/3000000X0P>Rk
00<0000008Sg``28ml<01028ml<2000000D0R?O300<0000008?a^`23lK/00P23lK/01@000000Po6k
08?a^`23lK/000000080H[R=00<0000006:hS@1R^8d00P00000f08nlS`40oooo001008nlS`<00000
00<031PL0000000<61`00`0<61`2000000T07SPg0`00000;02iFC`030000000lL6@0?71T0080?71T
0`00000:03a`I0030000001;RGL0BhUg0140BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL
06NjW00B06NjW0030000001ddZd0M=:]0100M=:]00<00000083X^`20j;/01020j;/2000000T0P>Rk
00<0000008Sg``28ml<01@28ml<2000000<0R?O300<0000008?a^`23lK/00`23lK/01`000000Po6k
08?a^`23lK/0000006:hS@0000000P1R^8d2000003H0Skb?0@3oool00400Skb?1000000500`H7003
0000000N>3L07SPg00P07SPg00<0000002iFC`0^ETl02`0^ETl00`000000?71T00000002000000d0
?71T00<0000004^9M`1;RGL04@1;RGL00`000000FJ::05VRRP0805VRRQ0000003`1W^Y`00`000000
M=:]07CB[@0@07CB[@0300000020j;/0P>Rk00H0P>Rk0`000006083X^`0300000028ml<0R?O300L0
R?O300@0000008Sg``28ml<000001P23lK/010000000Po6k08?a^`00000206:hS@040000001R^8d0
0000000003H0Skb?0@3oool00400Skb?1000000400`H708000002@0N>3L2000000d0;UI?0P00000@
03a`I0030000001;RGL0BhUg00l0BhUg3@00000:05VRRP030000001W^Y`0IkZL00<0IkZL2P000005
06NjW0030000001ddZd0M=:]0100M=:]00<00000083X^`20j;/02@20j;/3000000<0P>Rk00<00000
08Sg``28ml<02028ml<3000000L0Po6k00<0000008?a^`0000000`1R^8d00`000000H[R=0000000f
08nlS`40oooo001008nlS`030000000420X0000000D031PL0P00000801hh=`030000000N>3L00000
00/0;UI?0`00000A03a`I0030000001;RGL0BhUg00X0BhUg1@00000204^9M`030000001IXXX0FJ::
0180FJ::00<0000006NjW01W^Y`03@1W^Y`700000180M=:]00<00000083X^`20j;/02`20j;/20000
0003083X^`000000R?O300/0R?O300<0000008?a^`23lK/01P23lK/2000000<0H[R=00<0000006:h
S@000000=P2?_8l10?ooo`00@02?_8l00`00000010P:0000000400`H70030000000<61`0000000H0
7SPg0P00000201hh=`030000000^ETl0;UI?00L0;UI?0P00000202iFC`030000000lL6@0?71T00l0
?71T00<0000004^9M`1;RGL01@1;RGL5000000L0BhUg00<0000005VRRP1IXXX04P1IXXX00`000000
IkZL06NjW00B06NjW0030000001ddZd0000000<000003P1ddZd00`000000P>Rk083X^`0=083X^`80
00003028ml<2000000P0Po6k00<0000006:hS@1R^8d00P1R^8d3000003D0Skb?0@3oool00400Skb?
0`00000300`H70040000000<61`031PL000000D07SPg00<0000001hh=`0N>3L00P0N>3L00`000000
;UI?02iFC`0602iFC`030000000^ETl0;UI?0080;UI?00<0000003a`I00lL6@03`0lL6@00`000000
BhUg04^9M`05000000`0BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL06NjW00B06NjW003
0000001ddZd0M=:]00<0M=:]1000000:07CB[@0300000020j;/0P>Rk00h0P>Rk0`00000:08Sg``03
00000023lK/0000000L0Po6k00<0000006:hS@1R^8d00P1R^8d3000003D0Skb?0@3oool00400Skb?
0`00000300`H70030000000<61`0000000D07SPg00<0000001hh=`0N>3L00P0N>3L00`000000;UI?
02iFC`0502iFC`8000001@0^ETl00`000000?71T03a`I00>03a`I0@000004@1;RGL00`000000FJ::
05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL00<0000007CB[@1ddZd01`1ddZd4000000H0M=:]
00<00000083X^`20j;/03P20j;/010000000R?O308Sg``00000908Sg``0400000023lK/0Po6k0000
00H0Po6k0P00000406:hS@800000=@2?_8l10?ooo`00@02?_8l30000008031PL00@0000000`H700<
61`00000100N>3L00`0000007SPg01hh=`0301hh=`030000000^ETl0;UI?00<0;UI?0P00000702iF
C`030000000lL6@0?71T00`0?71T0P0000000`0lL6@0000004^9M`0B04^9M`030000001IXXX0FJ::
0180FJ::00<0000006NjW01W^Y`04P1W^Y`00`000000M=:]07CB[@0;07CB[@@000000P1ddZd00`00
0000P>Rk083X^`0>083X^`0500000028ml<0R?O308Sg``0000002028ml<01@000000Po6k08?a^`23
lK/0000000D0Po6k0P00000406:hS@800000=@2?_8l10?ooo`00@02?_8l20000008031PL00D00000
00`H700<61`031PL0000000301hh=`030000000N>3L07SPg00@07SPg00<0000002iFC`0^ETl00P0^
ETl00`000000;UI?02iFC`0702iFC`030000000lL6@0?71T00T0?71T0`00000303a`I0030000001;
RGL0BhUg0140BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL06NjW00B06NjW0030000001d
dZd0M=:]00l0M=:]1000000?083X^`0300000028ml<0R?O30080R?O30P00000608Sg``0300000023
lK/0Po6k0080Po6k00<0000008?a^`23lK/00P23lK/00`000000H[R=0000000306:hS@800000=@2?
_8l10?ooo`00@02?_8l20000008031PL00H0000000`H700<61`031PL0000000N>3L2000000L07SPg
00<0000002iFC`0^ETl00P00000:02iFC`030000000lL6@0?71T00L0?71T0P00000603a`I0030000
001;RGL0BhUg0140BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL06NjW00B06NjW0030000
001ddZd0M=:]0140M=:]00@00000083X^`00000000003@20j;/00`000000R?O308Sg``0408Sg``03
00000028ml<0R?O300@0R?O300<0000008?a^`23lK/00P23lK/01`000000Po6k08?a^`23lK/00000
06:hS@0000000`1R^8d2000003D0Skb?0@3oool003l0Skb?0`0000000`0<61`0000000`H700300`H
708000002@0N>3L3000000`0;UI?00<0000003a`I00lL6@0100lL6@3000000P0?71T00<0000004^9
M`1;RGL04@1;RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL00<0000007CB
[@1ddZd04@1ddZd010000000P>Rk083X^`20j;/3000000X0P>Rk00<0000008Sg``28ml<01@28ml<2
000000@0R?O300<0000008?a^`23lK/00`23lK/01`000000Po6k08?a^`23lK/0000006:hS@000000
0P1R^8d2000003D0Skb?0@3oool003l0Skb?1000000500`H70030000000N>3L07SPg00P07SPg00<0
000002iFC`0^ETl0300^ETl010000000?71T03a`I00lL6@3000000/0?71T00<0000004^9M`1;RGL0
4@1;RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL00<0000007CB[@1ddZd0
4@1ddZd00`000000P>Rk083X^`04083X^`8000002020j;/00`000000R?O308Sg``0708Sg``050000
0028ml<0R?O308Sg``0000001P23lK/01P000000Po6k08?a^`000000H[R=00000080H[R=0P00000e
08nlS`40oooo000o08nlS`@00000100<61`2000000T07SPg0P00000>02iFC`040000000lL6@00000
000000d0?71T00<0000004^9M`1;RGL04P1;RGL00`000000FJ::05VRRP0805VRRQ0000003`1W^Y`0
0`000000M=:]07CB[@0A07CB[@0300000020j;/0P>Rk00H0P>Rk0P000006083X^`0300000028ml<0
R?O300P0R?O300@0000008Sg``28ml<000001`23lK/00`000000Po6k0000000206:hS@040000001R
^8d00000000003D0Skb?0@3oool003l0Skb?00<0000000@82P0000001@0<61`2000000P07SPg00<0
000001hh=`0000003P0^ETl2000000l0?71T00<0000004^9M`1;RGL0401;RGL=000000X0FJ::00<0
000006NjW01W^Y`00`1W^Y`:000000D0IkZL00<0000007CB[@1ddZd04@1ddZd00`000000P>Rk083X
^`08083X^`<000000`20j;/00`000000R?O308Sg``0908Sg``<000002023lK/200000080H[R=00@0
000006:hS@0000000000=@2?_8l10?ooo`00?`2?_8l00`00000010P:0000000400`H70030000000<
61`0000000L07SPg00@0000001hh=`0N>3L00000300^ETl300000100?71T00<0000004^9M`1;RGL0
2`1;RGL500000080BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL06NjW00=06NjW0L00000
4P1ddZd00`000000P>Rk083X^`0;083X^`80000000<0P>Rk00000028ml<03028ml<00`000000Po6k
08?a^`0708?a^`040000001R^8d0H[R=06:hS@@00000=02?_8l10?ooo`00?`2?_8l3000000@031PL
00<0000000`H700000001P0N>3L01@0000007SPg01hh=`0N>3L0000000X0;UI?0P00000202iFC`03
0000000lL6@0?71T00h0?71T00<0000004^9M`1;RGL01@1;RGL6000000L0BhUg00<0000005VRRP1I
XXX04P1IXXX00`000000IkZL06NjW00B06NjW0030000001ddZd0000000<000003P1ddZd00`000000
P>Rk083X^`0=083X^`8000003@28ml<2000000P0Po6k00@0000006:hS@1R^8d0H[R=1000000d08nl
S`40oooo000o08nlS`<000000`0<61`01000000031PL00`H7000000501hh=`030000000N>3L07SPg
00807SPg00<0000002iFC`0^ETl01P0^ETl2000000@0;UI?00<0000003a`I00lL6@03P0lL6@00`00
0000BhUg04^9M`05000000d0BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL06NjW00B06Nj
W0030000001ddZd0M=:]00<0M=:]1000000:07CB[@0300000020j;/0P>Rk00h0P>Rk0`00000;08Sg
``0300000023lK/0000000L0Po6k0P00000306:hS@0300000011O5T0000003@0Skb?0@3oool003l0
Skb?0`00000200`H70040000000<61`031PL000000@07SPg0P00000401hh=`030000000^ETl0;UI?
00H0;UI?00<0000002iFC`0^ETl0100^ETl00`000000?71T03a`I00=03a`I0@000004P1;RGL00`00
0000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL00<0000007CB[@1ddZd01`1ddZd40000
00H0M=:]00<00000083X^`20j;/03P20j;/010000000R?O308Sg``00000:08Sg``0400000023lK/0
Po6k000000H0Po6k0P00000306:hS@0300000011O5T0000003@0Skb?0@3oool003l0Skb?0`000002
00`H70040000000<61`031PL000000<07SPg00<0000001hh=`0N>3L0100N>3L00`000000;UI?02iF
C`0402iFC`8000001`0^ETl00`000000?71T03a`I00;03a`I080000000<0?71T0000001;RGL04`1;
RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL00<0000007CB[@1ddZd02`1d
dZd400000080M=:]00<00000083X^`20j;/03P20j;/010000000R?O308Sg``28ml<2000000P0R?O3
00D0000008?a^`23lK/0Po6k0000000508?a^`030000001R^8d000000080H[R=00<00000045lF@00
0000=02?_8l10?ooo`00?`2?_8l01@00000010P:0000000<61`0000000<031PL00@0000001hh=`0N
>3L000001`0N>3L00`000000;UI?02iFC`0202iFC`800000200^ETl00`000000?71T03a`I00903a`
I0<000000`0lL6@00`000000BhUg04^9M`0B04^9M`030000001IXXX0FJ::0180FJ::00<0000006Nj
W01W^Y`04P1W^Y`00`000000M=:]07CB[@0?07CB[@@000003`20j;/00`000000R?O308Sg``0308Sg
``0300000028ml<0R?O300D0R?O300<0000008?a^`23lK/00P23lK/00`000000Po6k08?a^`0208?a
^`030000001R^8d000000080H[R=00<00000045lF@000000=02?_8l10?ooo`00?P2?_8l200000004
00@82P00000031PL000000<031PL00<0000001hh=`000000200N>3L00`000000;UI?02iFC`020000
00X0;UI?00<0000003a`I00lL6@01`0lL6@2000000H0?71T00<0000004^9M`1;RGL04P1;RGL00`00
0000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL00<0000007CB[@1ddZd04@1ddZd01000
0000P>Rk00000000000=083X^`0300000028ml<0R?O300@0R?O30P00000508Sg``0300000023lK/0
Po6k0080Po6k00<0000008?a^`23lK/00P23lK/01@000000H[R=06:hS@000000H[R=00<00000=02?
_8l10?ooo`00?P2?_8l20000000300@82P000000000000@031PL0P00000901hh=`<00000300^ETl0
0`000000?71T03a`I00403a`I0<00000200lL6@00`000000BhUg04^9M`0B04^9M`030000001IXXX0
FJ::0180FJ::00<0000006NjW01W^Y`04P1W^Y`00`000000M=:]07CB[@0A07CB[@0400000020j;/0
P>Rk083X^`<000002`20j;/00`000000R?O308Sg``0508Sg``8000000`28ml<00`000000Po6k08?a
^`0308?a^`0500000023lK/0Po6k08?a^`0000000P1R^8d00`000000H[R=00000002000003@0Skb?
0@3oool003h0Skb?0P0000000`0420X000000000000400`H70030000000N>3L07SPg00P07SPg00<0
000002iFC`0^ETl0300^ETl010000000?71T03a`I00lL6@3000000/0?71T00<0000004^9M`1;RGL0
4P1;RGL00`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL00<0000007CB[@1ddZd0
4@1ddZd00`000000P>Rk083X^`04083X^`8000002@20j;/00`000000R?O308Sg``0708Sg``040000
0028ml<0R?O3000000H0Po6k00@0000008?a^`23lK/000000`1R^8d010000000H[R=00000000000d
08nlS`40oooo000n08nlS`040000000420X010P:000000@031PL0P00000901hh=`8000003P0^ETl0
10000000?71T00000000000>03a`I0030000001;RGL0BhUg0180BhUg00<0000005VRRP1IXXX0201I
XXX@000000l0IkZL00<0000007CB[@1ddZd04@1ddZd00`000000P>Rk083X^`06083X^`<000001P20
j;/00`000000R?O308Sg``0808Sg``<000001`23lK/00`000000Po6k0000000306:hS@040000001R
^8d00000000003@0Skb?0@3oool003h0Skb?00@0000000@82P0420X00000100<61`2000000P07SPg
00<0000001hh=`0000003P0^ETl200000100?71T00<0000004^9M`1;RGL0401;RGL=000000X0FJ::
00<0000006NjW01W^Y`00`1W^Y`:000000D0IkZL00<0000007CB[@1ddZd04@1ddZd00`000000P>Rk
083X^`09083X^`<000000`20j;/00`000000R?O308Sg``0:08Sg``0300000023lK/0Po6k00H0Po6k
0P00000406:hS@<00000=02?_8l10?ooo`00?P2?_8l01000000010P:00000000000300`H70030000
000<61`0000000L07SPg00@0000001hh=`0N>3L00000300^ETl300000140?71T00<0000004^9M`1;
RGL02`1;RGL500000080BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL06NjW00=06NjW0L0
00004P1ddZd00`000000P>Rk083X^`0<083X^`80000000<0P>Rk00000028ml<02`28ml<2000000P0
Po6k00<0000006:hS@1R^8d00P1R^8d3000003@0Skb?0@3oool003h0Skb?00@0000000@82P000000
00000P0<61`01000000031PL00`H7000000601hh=`050000000N>3L07SPg01hh=`0000002P0^ETl2
00000080;UI?00<0000003a`I00lL6@03`0lL6@00`000000BhUg04^9M`0504^9M`H000001`1;RGL0
0`000000FJ::05VRRP0B05VRRP030000001W^Y`0IkZL0180IkZL00<0000007CB[@0000000`00000>
07CB[@0300000020j;/0P>Rk00h0P>Rk0P00000<08Sg``0300000023lK/0000000L0Po6k0P000004
06:hS@800000=02?_8l10?ooo`00?P2?_8l01000000010P:00000000000200`H70040000000<61`0
31PL000000@07SPg0P00000401hh=`030000000^ETl0;UI?00L0;UI?00<0000002iFC`0^ETl00P0^
ETl00`000000?71T03a`I00?03a`I0030000001;RGL0BhUg00D000003@1;RGL00`000000FJ::05VR
RP0B05VRRP030000001W^Y`0IkZL0180IkZL00<0000007CB[@1ddZd00`1ddZd4000000X0M=:]00<0
0000083X^`20j;/03`20j;/3000000X0R?O300@0000008?a^`23lK/000001P23lK/2000000@0H[R=
0P00000d08nlS`40oooo000n08nlS`030000000420X00000008031PL00D0000000`H700<61`031PL
0000000301hh=`030000000N>3L07SPg00@07SPg00<0000002iFC`0^ETl01@0^ETl2000000D0;UI?
00<0000003a`I00lL6@03P0lL6@400000180BhUg00<0000005VRRP1IXXX04P1IXXX00`000000IkZL
06NjW00B06NjW0030000001ddZd0M=:]00L0M=:]1000000607CB[@0300000020j;/0P>Rk00l0P>Rk
00@0000008Sg``28ml<000002@28ml<01@000000Po6k08?a^`23lK/0000000D0Po6k00<0000006:h
S@0000000`1R^8d2000003@0Skb?0@3oool003h0Skb?0`00000200`H70050000000<61`031PL00`H
700000000P0N>3L00`0000007SPg01hh=`0501hh=`030000000^ETl0;UI?00<0;UI?0P00000702iF
C`030000000lL6@0?71T00`0?71T0P0000000`0lL6@0000004^9M`0C04^9M`030000001IXXX0FJ::
0180FJ::00<0000006NjW01W^Y`04P1W^Y`00`000000M=:]07CB[@0;07CB[@@000000P1ddZd00`00
0000P>Rk083X^`0?083X^`0400000028ml<0R?O308Sg``8000001`28ml<00`000000Po6k08?a^`02
08?a^`0300000023lK/0Po6k0080Po6k00@0000006:hS@1R^8d000000P1R^8d2000003@0Skb?0@3o
ool003h0Skb?0`0000000`0<61`0000000`H700300`H70030000000N>3L0000000P07SPg00<00000
02iFC`0^ETl00P0^ETl00`000000;UI?02iFC`0702iFC`030000000lL6@0?71T00T0?71T0`000003
03a`I0030000001;RGL0BhUg0140BhUg00<0000005VRRP1IXXX04`1IXXX00`000000IkZL06NjW00B
06NjW0030000001ddZd0M=:]00l0M=:]1000000@083X^`0300000028ml<0R?O300<0R?O300<00000
08Sg``28ml<01@28ml<00`000000Po6k08?a^`0208?a^`0500000023lK/0Po6k08?a^`0000000P1R
^8d00`000000H[R=06:hS@02000003@0Skb?0@3oool003h0Skb?1000000500`H708000002@0N>3L0
0`000000;UI?02iFC`02000000X0;UI?00<0000003a`I00lL6@01`0lL6@2000000H0?71T00<00000
04^9M`1;RGL04@1;RGL00`000000FJ::05VRRP0C05VRRP030000001W^Y`0IkZL0180IkZL00<00000
07CB[@1ddZd04@1ddZd010000000P>Rk00000000000>083X^`0300000028ml<0R?O300@0R?O30P00
000508Sg``0300000023lK/0Po6k00<0Po6k00D0000008?a^`23lK/0Po6k0000000206:hS@040000
001R^8d00000000003@0Skb?0@3oool003h0Skb?1000000500`H70030000000N>3L07SPg00P07SPg
0`00000<02iFC`030000000lL6@0?71T00@0?71T0`00000803a`I0030000001;RGL0BhUg0140BhUg
00<0000005VRRP1IXXX04`1IXXX00`000000IkZL06NjW00C06NjW0030000001ddZd0M=:]0100M=:]
00@00000083X^`20j;/0P>Rk0`00000;083X^`0300000028ml<0R?O300H0R?O30P00000308Sg``03
00000023lK/0Po6k00@0Po6k00@0000008?a^`23lK/000000P1R^8d010000000H[R=06:hS@00000d
08nlS`40oooo000n08nlS`030000000420X0000000D031PL0P00000:01hh=`030000000^ETl0;UI?
00`0;UI?00@0000003a`I00lL6@0?71T0`00000;03a`I0030000001;RGL0BhUg0140BhUg00<00000
05VRRP1IXXX04`1IXXX00`000000IkZL06NjW00C06NjW0030000001ddZd0M=:]0100M=:]00<00000
083X^`20j;/01020j;/2000000T0P>Rk00<0000008Sg``28ml<02028ml<010000000R?O308Sg``00
000708?a^`0300000023lK/0000000<0H[R=00<0000006:hS@000000=02?_8l10?ooo`00?P2?_8l0
0`00000010P:0000000500`H708000002@0N>3L2000000h0;UI?00@0000003a`I000000000003P0l
L6@00`000000BhUg04^9M`0A04^9M`030000001IXXX0FJ::01<0FJ::00<0000006NjW01W^Y`04`1W
^Y`00`000000M=:]07CB[@0@07CB[@0300000020j;/0P>Rk00H0P>Rk0`000006083X^`0300000028
ml<0R?O300T0R?O30`00000808?a^`800000101R^8d3000003<0Skb?0@3oool003h0Skb?0`000004
00`H70030000000<61`0000000P07SPg00<0000001hh=`0000003P0^ETl200000100?71T00<00000
04^9M`1;RGL04@1;RGL00`000000FJ::05VRRP0905VRRQ000000401W^Y`00`000000M=:]07CB[@0@
07CB[@0300000020j;/0P>Rk00T0P>Rk0`000003083X^`0300000028ml<0R?O300/0R?O300<00000
08?a^`23lK/01`23lK/00`000000H[R=06:hS@0206:hS@<00000<`2?_8l10?ooo`00?P2?_8l30000
00<031PL00@0000000`H700<61`000001P0N>3L2000000807SPg00<0000002iFC`0^ETl02P0^ETl3
00000140?71T00<0000004^9M`1;RGL03`1;RGL>000000X0FJ::00<0000006NjW01W^Y`00`1W^Y`;
000000D0IkZL00<0000007CB[@1ddZd04@1ddZd00`000000P>Rk083X^`0;083X^`80000000<0P>Rk
00000028ml<03028ml<2000000P0Po6k00<0000006:hS@1R^8d00`1R^8d2000003<0Skb?0@3oool0
03h0Skb?0`00000300`H70040000000<61`031PL000000D07SPg00<0000001hh=`0N>3L00P0N>3L0
0`000000;UI?02iFC`0802iFC`8000000P0^ETl00`000000?71T03a`I00?03a`I0030000001;RGL0
BhUg00X0BhUg1@00000204^9M`030000001IXXX0FJ::01<0FJ::00<0000006NjW01W^Y`03P1W^Y`8
00000140M=:]00<00000083X^`20j;/03@20j;/2000000d0R?O300<0000008?a^`0000001`23lK/2
000000@0H[R=0P00000c08nlS`40oooo000n08nlS`<000000P0<61`01000000031PL00`H70000005
01hh=`030000000N>3L07SPg00<07SPg00<0000002iFC`0^ETl01P0^ETl2000000@0;UI?00<00000
03a`I00lL6@03`0lL6@00`000000BhUg04^9M`0504^9M`D000001`1;RGL00`000000FJ::05VRRP0C
05VRRP030000001W^Y`0IkZL01<0IkZL00<0000007CB[@1ddZd01@00000<07CB[@0300000020j;/0
P>Rk00h0P>Rk0`00000;08Sg``0400000023lK/0Po6k000000H0Po6k0P00000406:hS@800000<`2?
_8l10?ooo`00?P2?_8l20000008031PL00D0000000`H700<61`031PL0000000401hh=`030000000N
>3L07SPg00<07SPg00<0000002iFC`0^ETl01P0^ETl00`000000;UI?02iFC`0402iFC`030000000l
L6@0?71T00l0?71T00<0000004^9M`1;RGL01@00000<04^9M`030000001IXXX0FJ::01<0FJ::00<0
000006NjW01W^Y`04`1W^Y`00`000000M=:]07CB[@0507CB[@D000001`1ddZd00`000000P>Rk083X
^`0>083X^`0300000028ml<0R?O3008000002@28ml<01@000000Po6k08?a^`23lK/0000000D0Po6k
00<0000006:hS@0000000`1R^8d2000003<0Skb?0@3oool003d0Skb?0`00000200`H70050000000<
61`031PL00`H700000000`0N>3L00`0000007SPg01hh=`0401hh=`030000000^ETl0;UI?00@0;UI?
0P00000702iFC`030000000lL6@0?71T00h0?71T1000000A04^9M`030000001IXXX0FJ::01<0FJ::
00<0000006NjW01W^Y`04`1W^Y`00`000000M=:]07CB[@0:07CB[@D000000P1ddZd00`000000P>Rk
083X^`0>083X^`0300000028ml<0R?O30080R?O300<0000008Sg``28ml<01P28ml<00`000000Po6k
08?a^`0208?a^`0300000023lK/0Po6k0080Po6k00<0000006:hS@0000000`1R^8d2000003<0Skb?
0@3oool003d0Skb?0`0000000`0<61`0000000`H700300`H70040000000N>3L00000000000L07SPg
00<0000002iFC`0^ETl00P0^ETl2000000P0;UI?00<0000003a`I00lL6@0300lL6@30000000303a`
I0000000BhUg0180BhUg00<0000005VRRP1IXXX04`1IXXX00`000000IkZL06NjW00C06NjW0030000
001ddZd0M=:]00l0M=:]1000000?083X^`0300000028ml<0R?O300<0R?O30P00000708Sg``030000
0023lK/0Po6k0080Po6k00<0000008?a^`23lK/00P23lK/00`000000H[R=0000000206:hS@800000
<`2?_8l10?ooo`00?@2?_8l4000000D031PL0P00000901hh=`030000000^ETl0;UI?008000002P0^
ETl00`000000?71T03a`I00903a`I0<00000100lL6@00`000000BhUg04^9M`0A04^9M`030000001I
XXX0FJ::01<0FJ::00<0000006NjW01W^Y`04`1W^Y`00`000000M=:]07CB[@0A07CB[@0400000020
j;/00000000000d0P>Rk00<0000008Sg``28ml<01@28ml<2000000D0R?O300<0000008?a^`23lK/0
0`23lK/01`000000Po6k08?a^`23lK/0000006:hS@0000000P1R^8d2000003<0Skb?0@3oool003d0
Skb?00@0000000@82P00000000001@0<61`00`0000007SPg01hh=`0801hh=`<00000300^ETl00`00
0000?71T03a`I00503a`I0@000001`0lL6@00`000000BhUg04^9M`0A04^9M`030000001IXXX0FJ::
01<0FJ::00<0000006NjW01W^Y`04`1W^Y`00`000000M=:]07CB[@0A07CB[@0400000020j;/0P>Rk
083X^`<000002`20j;/00`000000R?O308Sg``0608Sg``0300000028ml<0R?O30080R?O300<00000
08?a^`23lK/01023lK/010000000Po6k08?a^`00000206:hS@040000001R^8d00000000003<0Skb?
0@3oool003d0Skb?00<0000000@82P0000001@0<61`2000000X07SPg00<0000002iFC`0^ETl0300^
ETl00`000000?71T03a`I00203a`I0<000002`0lL6@00`000000BhUg04^9M`0A04^9M`030000001I
XXX0FJ::01<0FJ::00<0000006NjW01W^Y`04`1W^Y`00`000000M=:]07CB[@0A07CB[@0300000020
j;/0P>Rk00@0P>Rk0P000009083X^`0300000028ml<0R?O300L0R?O30P00000208Sg``0300000023
lK/0Po6k00D0Po6k00<0000008?a^`0000000P1R^8d01@000000H[R=00000011O5T000000380Skb?
0@3oool003d0Skb?00<0000000@82P0000001@0<61`2000000T07SPg0P00000>02iFC`030000000l
L6@00000008000003P0lL6@00`000000BhUg04^9M`0A04^9M`030000001IXXX0FJ::01<0FJ::00<0
000006NjW01W^Y`04`1W^Y`00`000000M=:]07CB[@0A07CB[@0300000020j;/0P>Rk00H0P>Rk0`00
0006083X^`0300000028ml<0R?O300T0R?O30`00000808?a^`8000000`1R^8d200000003045lF@00
0000Skb?0340Skb?0@3oool003d0Skb?0`00000400`H70030000000<61`0000000P07SPg00<00000
01hh=`0000003P0^ETl200000100?71T00<0000004^9M`1;RGL04P1;RGL00`000000FJ::05VRRP09
05VRRQ000000401W^Y`00`000000M=:]07CB[@0A07CB[@0300000020j;/0P>Rk00T0P>Rk0`000003
083X^`0300000028ml<0R?O300/0R?O300<0000008?a^`23lK/01`23lK/010000000H[R=06:hS@1R
^8d200000003045lF@000000Skb?0340Skb?0@3oool003d0Skb?0`00000400`H70030000000<61`0
000000H07SPg0P00000201hh=`030000000^ETl0;UI?00X0;UI?0`00000A03a`I0030000001;RGL0
BhUg0100BhUg3P00000:05VRRP030000001W^Y`0IkZL00<0IkZL2`00000506NjW0030000001ddZd0
M=:]0140M=:]00<00000083X^`20j;/03020j;/200000003083X^`000000R?O300`0R?O30P000008
08?a^`030000001R^8d0H[R=0080H[R=00<00000045lF@000000<P2?_8l10?ooo`00?@2?_8l30000
00<031PL00@0000000`H700<61`000001@0N>3L00`0000007SPg01hh=`0201hh=`030000000^ETl0
;UI?00P0;UI?0P00000202iFC`030000000lL6@0?71T00l0?71T00<0000004^9M`1;RGL02`1;RGL5
00000080BhUg00<0000005VRRP1IXXX04`1IXXX00`000000IkZL06NjW00>06NjW0L000004P1ddZd0
0`000000P>Rk083X^`0>083X^`8000003@28ml<00`000000Po6k0000000708?a^`8000000`1R^8d0
0`000000@GaI0000000b08nlS`40oooo000m08nlS`<000000P0<61`01000000031PL00`H70000005
01hh=`030000000N>3L07SPg00<07SPg00<0000002iFC`0^ETl01`0^ETl00`000000;UI?02iFC`02
02iFC`030000000lL6@0?71T00l0?71T00<0000004^9M`1;RGL01@1;RGL6000000L0BhUg00<00000
05VRRP1IXXX04`1IXXX00`000000IkZL06NjW00C06NjW0030000001ddZd0000000<000003P1ddZd0
0`000000P>Rk083X^`0?083X^`<000002`28ml<010000000Po6k08?a^`00000608?a^`8000000`1R
^8d00`000000@GaI0000000b08nlS`40oooo000m08nlS`030000000420X00000008031PL00@00000
00`H700<61`00000100N>3L00`0000007SPg01hh=`0401hh=`030000000^ETl0;UI?00D0;UI?0P00
000502iFC`030000000lL6@0?71T00l0?71T00<0000004^9M`1;RGL01@00000=04^9M`030000001I
XXX0FJ::01<0FJ::00<0000006NjW01W^Y`04`1W^Y`00`000000M=:]07CB[@0307CB[@@000002P1d
dZd00`000000P>Rk083X^`0?083X^`0400000028ml<0R?O3000000X0R?O300D0000008?a^`23lK/0
Po6k0000000508?a^`030000001R^8d000000080H[R=0`00000b08nlS`40oooo000l08nlS`800000
00@010P:0000000<61`000000`0<61`01@0000007SPg01hh=`0N>3L0000000L07SPg00<0000002iF
C`0^ETl00`0^ETl2000000L0;UI?00<0000003a`I00lL6@03P0lL6@400000180BhUg00<0000005VR
RP1IXXX04`1IXXX00`000000IkZL06NjW00C06NjW0030000001ddZd0M=:]00L0M=:]1000000607CB
[@0300000020j;/0P>Rk00l0P>Rk00@0000008Sg``28ml<0R?O30P00000808Sg``0300000023lK/0
Po6k0080Po6k00<0000008?a^`23lK/00P23lK/00`000000H[R=0000000206:hS@<00000<P2?_8l1
0?ooo`00?02?_8l20000000400@82P00000031PL000000<031PL00@0000001hh=`0000000000200N
>3L00`000000;UI?02iFC`0202iFC`030000000^ETl0;UI?00L0;UI?00<0000003a`I00lL6@0300l
L6@20000000303a`I0000000BhUg01<0BhUg00<0000005VRRP1IXXX04`1IXXX00`000000IkZL06Nj
W00C06NjW0030000001ddZd0M=:]00/0M=:]1000000207CB[@0300000020j;/0P>Rk00l0P>Rk00<0
000008Sg``28ml<00`28ml<00`000000R?O308Sg``0508Sg``0300000023lK/0Po6k0080Po6k00<0
000008?a^`23lK/00P23lK/01@000000H[R=06:hS@000000H[R=0080000000<0@GaI08nlS`2?_8l0
<02?_8l10?ooo`00?02?_8l20000000300@82P000000000000@031PL0P00000:01hh=`030000000^
ETl0;UI?008000002P0^ETl00`000000?71T03a`I00903a`I0<000000`0lL6@00`000000BhUg04^9
M`0B04^9M`030000001IXXX0FJ::01<0FJ::00<0000006NjW01W^Y`04`1W^Y`00`000000M=:]07CB
[@0?07CB[@@000004020j;/00`000000R?O308Sg``0408Sg``8000001@28ml<00`000000Po6k08?a
^`0308?a^`0500000023lK/0Po6k08?a^`0000000P1R^8d01@000000H[R=06:hS@000000@GaI0380
Skb?0@3oool003`0Skb?00<0000000@82P0420X00P00000400`H70030000000N>3L07SPg00T07SPg
0`00000<02iFC`030000000lL6@0?71T00L0?71T0P00000603a`I0030000001;RGL0BhUg0180BhUg
00<0000005VRRP1IXXX04`1IXXX00`000000IkZL06NjW00C06NjW0030000001ddZd0M=:]0140M=:]
00@00000083X^`00000000003P20j;/00`000000R?O308Sg``0608Sg``8000000`28ml<00`000000
Po6k08?a^`0408?a^`0400000023lK/0Po6k000000<0H[R=00@0000006:hS@0000000000<P2?_8l1
0?ooo`00?02?_8l01000000010P:00@82P00000400`H708000002`0N>3L00`000000;UI?02iFC`0<
02iFC`030000000lL6@0?71T00@0?71T0`00000803a`I0030000001;RGL0BhUg0180BhUg00<00000
05VRRP1IXXX04`1IXXX00`000000IkZL06NjW00C06NjW0030000001ddZd0M=:]0140M=:]00@00000
083X^`20j;/0P>Rk0`00000;083X^`0300000028ml<0R?O300P0R?O300@0000008Sg``28ml<00000
1`23lK/00`000000Po6k0000000306:hS@030000001R^8d0000000800000<@2?_8l10?ooo`00?02?
_8l01000000010P:00@82P00000400`H708000002P0N>3L2000000h0;UI?00@0000003a`I00lL6@0
?71T0`00000;03a`I0030000001;RGL0BhUg0180BhUg00<0000005VRRP1IXXX04`1IXXX00`000000
IkZL06NjW00C06NjW0030000001ddZd0M=:]0140M=:]00<00000083X^`20j;/01020j;/2000000T0
P>Rk00<0000008Sg``28ml<02@28ml<3000000P0Po6k0P00000406:hS@@00000<@2?_8l10?ooo`00
?02?_8l01000000010P:00000000000300`H70030000000<61`0000000T07SPg00<0000001hh=`00
00003P0^ETl010000000?71T00000000000>03a`I0030000001;RGL0BhUg0180BhUg00<0000005VR
RP1IXXX04`1IXXX00`000000IkZL06NjW00C06NjW0030000001ddZd0M=:]0140M=:]00<00000083X
^`20j;/01P20j;/3000000H0P>Rk00<0000008Sg``28ml<02`28ml<00`000000Po6k08?a^`0708?a
^`030000001R^8d0H[R=0080H[R=1000000a08nlS`40oooo000l08nlS`040000000420X000000000
008031PL00@0000000`H700<61`000001`0N>3L2000000807SPg00<0000002iFC`0^ETl0300^ETl2
00000100?71T00<0000004^9M`1;RGL04P1;RGL00`000000FJ::05VRRP0905VRRQ000000401W^Y`0
0`000000M=:]07CB[@0A07CB[@0300000020j;/0P>Rk00T0P>Rk0`000003083X^`0300000028ml<0
R?O300/0R?O30P00000808?a^`800000101R^8d00`000000@GaI0000000a08nlS`40oooo000l08nl
S`040000000420X000000000008031PL00@0000000`H700<61`000001P0N>3L00`0000007SPg01hh
=`0201hh=`030000000^ETl0;UI?00X0;UI?0`00000A03a`I0030000001;RGL0BhUg0100BhUg3P00
000:05VRRP030000001W^Y`0IkZL00<0IkZL2`00000506NjW0030000001ddZd0M=:]0180M=:]00<0
0000083X^`20j;/02`20j;/200000003083X^`000000R?O300`0R?O300<0000008?a^`0000001`23
lK/2000000@0H[R=00<00000045lF@000000<@2?_8l10?ooo`00?02?_8l30000008031PL00D00000
00`H700<61`031PL0000000501hh=`030000000N>3L07SPg00<07SPg00<0000002iFC`0^ETl0200^
ETl200000080;UI?00<0000003a`I00lL6@03`0lL6@00`000000BhUg04^9M`0;04^9M`D000000P1;
RGL00`000000FJ::05VRRP0C05VRRP030000001W^Y`0IkZL00h0IkZL2000000B07CB[@0300000020
j;/0P>Rk00d0P>Rk0P00000=08Sg``0400000023lK/0Po6k000000H0Po6k00<0000006:hS@000000
0`1R^8d00`000000@GaI0000000a08nlS`40oooo000l08nlS`<000000P0<61`01@00000031PL00`H
700<61`0000000@07SPg00<0000001hh=`0N>3L00`0N>3L00`000000;UI?02iFC`0702iFC`800000
100^ETl00`000000?71T03a`I00?03a`I0030000001;RGL0BhUg00D0BhUg1P00000704^9M`030000
001IXXX0FJ::01<0FJ::00<0000006NjW01W^Y`04`1W^Y`00`000000M=:]07CB[@05000000d0M=:]
00<00000083X^`20j;/03P20j;/3000000/0R?O300D0000008?a^`23lK/0Po6k0000000508?a^`03
0000001R^8d0000000<0H[R=00<00000045lF@000000<@2?_8l10?ooo`00>`2?_8l01P00000010P:
00000000000031PL000000@031PL00D0000001hh=`0N>3L07SPg0000000601hh=`030000000^ETl0
;UI?00D0;UI?0P00000602iFC`030000000lL6@0?71T00l0?71T00<0000004^9M`1;RGL01@00000=
04^9M`030000001IXXX0FJ::01<0FJ::00<0000006NjW01W^Y`04`1W^Y`00`000000M=:]07CB[@05
07CB[@H000001`1ddZd00`000000P>Rk083X^`0>083X^`0300000028ml<0R?O3008000002@28ml<0
0`000000Po6k08?a^`0208?a^`0300000023lK/0Po6k0080Po6k00@0000006:hS@1R^8d000000P1R
^8d300000340Skb?0@3oool003/0Skb?0P0000000`0420X000000000000500`H70040000000N>3L0
0000000000L07SPg00<0000002iFC`0^ETl00`0^ETl2000000P0;UI?00<0000003a`I00lL6@03P0l
L6@400000180BhUg00<0000005VRRP1IXXX04`1IXXX00`000000IkZL06NjW00C06NjW0030000001d
dZd0M=:]00/0M=:]1@00000207CB[@0300000020j;/0P>Rk00h0P>Rk00<0000008Sg``28ml<00P28
ml<00`000000R?O308Sg``0608Sg``0300000023lK/0Po6k00<0Po6k00<0000008?a^`23lK/00P23
lK/00`000000H[R=0000000206:hS@<00000<@2?_8l10?ooo`00>`2?_8l20000000300@82P000000
000000D031PL0P00000901hh=`040000000^ETl0;UI?02iFC`8000002@0^ETl00`000000?71T03a`
I00<03a`I0<0000000<0?71T0000001;RGL04`1;RGL00`000000FJ::05VRRP0C05VRRP030000001W
^Y`0IkZL01<0IkZL00<0000007CB[@1ddZd0401ddZd4000000l0P>Rk00<0000008Sg``28ml<00`28
ml<2000000L0R?O300<0000008?a^`23lK/00`23lK/01@000000Po6k08?a^`23lK/000000080H[R=
00<0000006:hS@1R^8d00P00000a08nlS`40oooo000k08nlS`80000000<010P:0000000<61`01@0<
61`00`0000007SPg01hh=`0801hh=`040000000^ETl00000000000/0;UI?00<0000003a`I00lL6@0
2@0lL6@3000000@0?71T00<0000004^9M`1;RGL04P1;RGL00`000000FJ::05VRRP0C05VRRP030000
001W^Y`0IkZL01<0IkZL00<0000007CB[@1ddZd04P1ddZd010000000P>Rk00000000000=083X^`03
00000028ml<0R?O300D0R?O30P00000508Sg``0300000023lK/0Po6k00@0Po6k00@0000008?a^`23
lK/000000`1R^8d010000000H[R=00000000000a08nlS`40oooo000k08nlS`040000000420X010P:
000000D031PL0P00000:01hh=`8000003@0^ETl00`000000?71T03a`I00503a`I0@000001`0lL6@0
0`000000BhUg04^9M`0B04^9M`030000001IXXX0FJ::01<0FJ::00<0000006NjW01W^Y`04`1W^Y`0
0`000000M=:]07CB[@0B07CB[@0400000020j;/0P>Rk083X^`<000002`20j;/00`000000R?O308Sg
``0608Sg``0300000028ml<0R?O30080R?O300<0000008?a^`23lK/01@23lK/00`000000Po6k0000
000306:hS@040000001R^8d0000000000340Skb?0@3oool003/0Skb?00@0000000@82P0000000000
1@0<61`2000000T07SPg0P00000>02iFC`030000000lL6@0?71T0080?71T0`00000;03a`I0030000
001;RGL0BhUg0180BhUg00<0000005VRRP1IXXX04`1IXXX00`000000IkZL06NjW00C06NjW0030000
001ddZd0M=:]0180M=:]00<00000083X^`20j;/01020j;/2000000T0P>Rk00<0000008Sg``28ml<0
1`28ml<200000080R?O300<0000008?a^`23lK/01P23lK/2000000@0H[R=0`00000a08nlS`40oooo
000k08nlS`040000000420X00000000000@031PL00<0000000`H70000000200N>3L00`0000007SPg
0000000>02iFC`030000000lL6@00000008000003P0lL6@00`000000BhUg04^9M`0B04^9M`030000
001IXXX0FJ::01<0FJ::00<0000006NjW01W^Y`04`1W^Y`00`000000M=:]07CB[@0B07CB[@030000
0020j;/0P>Rk00H0P>Rk0`000006083X^`0300000028ml<0R?O300T0R?O30`00000908?a^`030000
001R^8d0H[R=0080H[R=0`00000a08nlS`40oooo000k08nlS`040000000420X00000000000<031PL
00@0000000`H700<61`000001P0N>3L2000000807SPg00<0000002iFC`0^ETl0300^ETl200000140
?71T00<0000004^9M`1;RGL04P1;RGL00`000000FJ::05VRRP0C05VRRP030000001W^Y`0IkZL01<0
IkZL00<0000007CB[@1ddZd04P1ddZd00`000000P>Rk083X^`09083X^`<000000`20j;/00`000000
R?O308Sg``0;08Sg``0300000023lK/0Po6k00L0Po6k0P00000406:hS@800000<@2?_8l10?ooo`00
>`2?_8l01000000010P:00000000000300`H70040000000<61`031PL000000D07SPg00<0000001hh
=`0N>3L00P0N>3L00`000000;UI?02iFC`0:02iFC`<000004P0lL6@00`000000BhUg04^9M`0B04^9
M`030000001IXXX0FJ::00T0FJ::4000000@06NjW0030000001ddZd0M=:]0180M=:]00<00000083X
^`20j;/03020j;/200000003083X^`000000R?O300`0R?O30P00000808?a^`800000101R^8d20000
0340Skb?0@3oool003/0Skb?0`00000300`H70040000000<61`031PL000000D07SPg00<0000001hh
=`0N>3L00`0N>3L00`000000;UI?02iFC`0802iFC`8000000P0^ETl00`000000?71T03a`I00@03a`
I0030000001;RGL0BhUg0100BhUg:@00000506NjW0030000001ddZd0M=:]0180M=:]00<00000083X
^`20j;/03P20j;/2000000d0R?O300<0000008?a^`0000001`23lK/00`000000H[R=0000000306:h
S@800000<@2?_8l10?ooo`00>`2?_8l30000008031PL00D0000000`H700<61`031PL0000000401hh
=`030000000N>3L07SPg00<07SPg00<0000002iFC`0^ETl01`0^ETl2000000@0;UI?00<0000003a`
I00lL6@0400lL6@00`000000BhUg04^9M`0;04^9M``000000`3omcX00`000000om/d0?oK=0060?oK
=0030000003oabl0olL_00D0olL_00<000000?o2;@3o`Rd01@3o`Rd010000000olD]0?o5;@3oaBd:
00000180M=:]00<00000083X^`20j;/03`20j;/3000000/0R?O300@0000008?a^`23lK/000001P23
lK/00`000000H[R=0000000306:hS@800000<@2?_8l10?ooo`00>`2?_8l30000008031PL00D00000
00`H700<61`031PL0000000301hh=`030000000N>3L07SPg00@07SPg00<0000002iFC`0^ETl01P0^
ETl00`000000;UI?02iFC`0402iFC`030000000lL6@0?71T0100?71T00<0000004^9M`1;RGL01@1;
RGL:000000<0]7TL00<000000?og>P3omcX01@3omcX00`000000om/d0?oK=0060?oK=0030000003o
abl0olL_00D0olL_00<000000?o2;@3o`Rd01@3o`Rd00`000000olD]0?o5;@050?o5;@040000003o
cRl0olh_0?o>;`L000003@1ddZd00`000000P>Rk083X^`0?083X^`0300000028ml<0R?O300800000
2@28ml<01@000000Po6k08?a^`23lK/0000000D0Po6k00@0000006:hS@1R^8d000000P1R^8d20000
0340Skb?0@3oool003/0Skb?0`0000000`0<61`0000000`H700300`H70040000000N>3L000000000
00L07SPg00<0000002iFC`0^ETl0100^ETl2000000L0;UI?00<0000003a`I00lL6@0400lL6@00`00
0000BhUg04^9M`07000000@0omT_0`0000050;Ai70030000003omcX0ooLj00@0ooLj00<000000?oK
=03ofc@01P3ofc@00`000000olL_0?o7;`050?o7;`030000003o`Rd0ol8]00D0ol8]00<000000?o5
;@3oaBd01@3oaBd00`000000olh_0?o>;`050?o>;`030000003ogS<0000000H000001`1ddZd00`00
0000P>Rk083X^`0?083X^`0300000028ml<0R?O30080R?O300<0000008Sg``28ml<01P28ml<00`00
0000Po6k08?a^`0208?a^`8000001023lK/00`000000H[R=0000000206:hS@800000<@2?_8l10?oo
o`00>`2?_8l01000000010P:00000000000500`H708000002@0N>3L00`000000;UI?02iFC`0202iF
C`8000002@0^ETl00`000000?71T03a`I00?03a`I0D0000000<0on`c0000003ohC400P3ohC400`00
0000omT_0?oI;`020?oI;`030000003odRd0om8]00@0000000<0]7TL0000003omcX01@3omcX00`00
0000om/d0?oK=0060?oK=0030000003oabl0olL_00D0olL_00<000000?o2;@3o`Rd01@3o`Rd00`00
0000olD]0?o5;@050?o5;@030000003ocRl0olh_00D0olh_00<000000?oN<`3ogS<00`3ogS<80000
0080M=:]00<00000083X^`20j;/03`20j;/00`000000R?O308Sg``0308Sg``8000001`28ml<00`00
0000Po6k08?a^`0308?a^`0500000023lK/0Po6k08?a^`0000000P1R^8d010000000H[R=06:hS@00
000a08nlS`40oooo000k08nlS`040000000420X00000000000D031PL00<0000001hh=`0N>3L0200N
>3L00`000000;UI?02iFC`02000000/0;UI?00<0000003a`I00lL6@0300lL6@4000000@0on`c00<0
00000?oQ<@3ohC400P3ohC400`000000omT_0?oI;`020?oI;`040000003odRd0om8]0?oB;@800000
00<0Ecd?0000000000000P0000050?og>P030000003ofc@0om/d00D0om/d00<000000?o7;`3oabl0
1@3oabl00`000000ol8]0?o2;@050?o2;@030000003oaBd0olD]00D0olD]00<000000?o>;`3ocRl0
103ocRl00`000000omhc0?oN<`060?oN<`030000003omST0000000L000004020j;/00`000000R?O3
08Sg``0508Sg``8000001@28ml<00`000000Po6k08?a^`0408?a^`0400000023lK/0Po6k000000<0
H[R=00@0000006:hS@0000000000<02?_8l10?ooo`00>`2?_8l00`00000010P:0000000500`H7080
00002P0N>3L3000000d0;UI?00<0000003a`I00lL6@02@0lL6@400000080ooXf00<000000?o/<`3o
k3<00P3ok3<01@000000on4a0?oQ<@3ohC40000000D0omT_00L000000?oB;@3odRd0om8]0000003o
c2`000000080Ecd?00@000000>VF9P00000000000`3omcX00`000000om/d0?oK=0050?oK=0030000
003oabl0olL_00D0olL_00<000000?o2;@3o`Rd01@3o`Rd00`000000olD]0?o5;@050?o5;@030000
003ocRl0olh_00@0olh_00<000000?oN<`3ogS<01@3ogS<00`000000ooHi0?of>@040?of>@H00000
3P20j;/00`000000R?O308Sg``0708Sg``0300000028ml<0R?O30080R?O300<0000008?a^`23lK/0
1@23lK/00`000000Po6k0000000306:hS@040000001R^8d0000000000300Skb?0@3oool003/0Skb?
00<0000000@82P0000001@0<61`2000000X07SPg00<0000002iFC`0^ETl03@0^ETl00`000000?71T
03a`I00503a`I0@000000P3oocX01@000000ooXf0?oj=P3onSH0000000@0on`c00D000000?oQ<@3o
hC40on4a000000040?oI;`030000003odRd0om8]0080om8]00H000000?o<;03oc2`0000005Lm3`00
00030>VF9P80000000<0ooLj0000003ofc@01P3ofc@00`000000olL_0?o7;`040?o7;`030000003o
`Rd0ol8]00D0ol8]00<000000?o5;@3oaBd01P3oaBd00`000000olh_0?o>;`040?o>;`030000003o
gS<0omhc00D0omhc00<000000?of>@3omST01@3omST00`000000ooLj0?og>P05000000/0P>Rk00<0
000008Sg``28ml<02028ml<200000080R?O300<0000008?a^`23lK/01P23lK/2000000@0H[R=0`00
000`08nlS`40oooo000k08nlS`<00000100<61`00`00000031PL0000000901hh=`8000003`0^ETl0
0`000000?71T03a`I00203a`I0<0000000<0ooln0000003oocX00P3oocX00`000000ooXf0?oj=P02
0?oj=P030000003ok3<0on`c0080on`c00D000000?oQ<@3ohC40on4a000000040?oI;`030000003o
dRd0om8]0080om8]00<000000?o<;03oc2`00P0000000`1G?@l000000>VF9P030>VF9P<000001P3o
fc@00`000000olL_0?o7;`040?o7;`030000003o`Rd0ol8]00D0ol8]00<000000?o5;@3oaBd01@3o
aBd00`000000olh_0?o>;`050?o>;`030000003ogS<0omhc00@0omhc00<000000?of>@3omST01@3o
mST00`000000ooLj0?og>P050?og>P<000002@20j;/00`000000R?O308Sg``0:08Sg``<000002@23
lK/00`000000H[R=06:hS@0206:hS@<00000<02?_8l10?ooo`00>`2?_8l3000000<031PL00@00000
00`H700<61`00000200N>3L00`0000007SPg0000000?02iFC`030000000lL6@0000000<000000`3o
och01@000000oolj0?oo>P3oocX0000000<0ooXf00<000000?o/<`3ok3<00P3ok3<00`000000on4a
0?oQ<@020?oQ<@030000003ofBl0omT_0080omT_00<000000?oB;@3odRd00P3odRd010000000ol`/
0?o<;03oc2`3000000D0jIHV00@000000?n]:`0000000000103ofc@00`000000olL_0?o7;`040?o7
;`030000003o`Rd0ol8]00D0ol8]00<000000?o5;@3oaBd01@3oaBd00`000000olh_0?o>;`050?o>
;`030000003ogS<0omhc00@0omhc00<000000?of>@3omST0103omST00`000000ooLj0?og>P020?og
>P@0UeXG00<0000009YX6@0000000`000006083X^`0300000028ml<0R?O300`0R?O300<0000008?a
^`23lK/01`23lK/00`000000H[R=06:hS@0306:hS@800000<02?_8l10?ooo`00>`2?_8l3000000<0
31PL00@0000000`H700<61`000001P0N>3L2000000807SPg00<0000002iFC`0^ETl03@0^ETl50000
00<0ooln00<000000?oo>P3oocX00P3oocX01@000000ooXf0?oj=P3onSH0000000@0on`c00<00000
0?oQ<@3ohC400P3ohC400`000000omT_0?oI;`020?oI;`030000003odRd0om8]0080om8]00<00000
0?o<;03oc2`00P3oc2`2000000D0jIHV00@000000?n]:`3o[B/0ojd[0`0000000`3ofc@000000?o7
;`050?o7;`030000003o`Rd0ol8]00D0ol8]00<000000?o5;@3oaBd01@3oaBd00`000000olh_0?o>
;`050?o>;`030000003ogS<0omhc00@0omhc00<000000?of>@3omST00P3omST300000080onTc00<0
000009MJ5`2GFQL00`2GFQL010000000VE`H09UL602IG1P5000000<0P>Rk00<0000008Sg``28ml<0
3028ml<2000000P0Po6k0P00000406:hS@800000<02?_8l10?ooo`00>`2?_8l30000008031PL00@0
000000`H700<61`000001P0N>3L00`0000007SPg01hh=`0201hh=`030000000^ETl0;UI?00/0;UI?
100000000`3oocd000000?oo?P030?oo?P050000003oocX0oolj0?oo>P000000103onSH00`000000
on`c0?o/<`020?o/<`030000003ohC40on4a0080on4a00<000000?oI;`3ofBl00P3ofBl00`000000
om8]0?oB;@020?oB;@030000003oc2`0ol`/0080ol`/0`0000040>VF9P030000003o[B/0ojd[00@0
ojd[0`0000050?o7;`030000003o`Rd0ol8]00D0ol8]00<000000?o5;@3oaBd01@3oaBd00`000000
olh_0?o>;`040?o>;`030000003ogS<0omhc00@0omhc00<000000?of>@000000100000020?oY<`80
UUPF00<0000009MJ5`2GFQL00`2GFQL00`000000VE`H09UL600209UL60H0000000<0P>Rk00000028
ml<03@28ml<00`000000Po6k0000000708?a^`800000101R^8d200000300Skb?0@3oool003X0Skb?
0`00000200`H70050000000<61`031PL00`H700000001@0N>3L00`0000007SPg01hh=`0301hh=`03
0000000^ETl0;UI?00T0;UI?100000030?oo?@050000003ooch0ooln0?oo?P000000103oocX00`00
0000ooXf0?oj=P020?oj=P030000003ok3<0on`c0080on`c00<000000?oQ<@3ohC400P3ohC400`00
0000omT_0?oI;`020?oI;`030000003odRd0om8]0080om8]00<000000?o<;03oc2`00P3oc2`20000
000305/m40000000jIHV0080jIHV00<000000?n]:`3o[B/01@3o[B/00`000000ok8[000000030000
00030?o7;`000000ol8]00H0ol8]00<000000?o5;@3oaBd01@3oaBd00`000000olh_0?o>;`040?o>
;`040000003ogS<0omhc0?oN<`D000000`3ood000`000000onTc0?oY<`0309IH5P030000002GFQL0
UeXG00<0UeXG00<0000009UL602IG1P00`2IG1P00`000000W5lI09aO6@04000000h0R?O300@00000
08?a^`23lK/000001P23lK/00`000000H[R=0000000306:hS@800000<02?_8l10?ooo`00>P2?_8l3
0000008031PL00D0000000`H700<61`031PL0000000401hh=`030000000N>3L07SPg00@07SPg00<0
000002iFC`0^ETl01`0^ETl4000000@0oolm00<000000?oo?P3ooch00P3ooch00`000000oolj0?oo
>P020?oo>P050000003onSH0ooXf0?oj=P000000103ok3<00`000000on4a0?oQ<@020?oQ<@030000
003ofBl0omT_00<0omT_00D000000?oB;@3odRd0om8]000000050?o<;0<0000000<0Fcd@00000000
00000P3YURH00`000000ojd[0?n]:`040?n]:`030000003o/R/0ok8[00<0ok8[1@0000040?o2;@03
0000003oaBd0olD]00D0olD]00@000000?o>;`3ocRl0olh_1`0000030?on>@030000003ood00oom0
0080oom000<0000009IH5P2FF1H00`2FF1H00`000000UeXG09MJ5`0309MJ5`030000002IG1P0VE`H
00<0VE`H00<0000009aO6@2LGaT00P2LGaT4000000`0R?O300D0000008?a^`23lK/0Po6k00000005
08?a^`030000001R^8d0000000<0H[R=0P00000`08nlS`40oooo000j08nlS`<0000000<031PL0000
000<61`00`0<61`01@0000007SPg01hh=`0N>3L0000000L07SPg00<0000002iFC`0^ETl01P0^ETl4
000000D0oolm00D000000?oo?P3ooch0ooln000000040?oo>P030000003onSH0ooXf0080ooXf00<0
00000?o/<`3ok3<00P3ok3<00`000000on4a0?oQ<@020?oQ<@030000003ofBl0omT_0080omT_00<0
00000?oB;@3odRd00P3odRd00`000000ol`/0?o<;0020?o<;0040000003ob2/0olP[000000<0Fcd@
00<000000>VF9P0000001P3o[B/00`000000ok8[0?nb:`040?nb:`040000003o_2`0ok`/0?nl;100
00000`3oh3<00`000000oohi0?on>@030?on>@030000003ood00oom00080oom00P00000609IH5P03
0000002GFQL0UeXG0080UeXG00<0000009UL602IG1P00`2IG1P00`000000W5lI09aO6@0209aO6@H0
00002P28ml<00`000000Po6k08?a^`0208?a^`0300000023lK/0Po6k0080Po6k00@0000006:hS@1R
^8d000000P1R^8d200000300Skb?0@3oool003X0Skb?1000000500`H70040000000N>3L000000000
00P07SPg00<0000002iFC`0^ETl0100^ETlQ00000080on4a00<000000?oI;`3ofBl00P3ofBl00`00
0000om8]0?oB;@020?oB;@030000003oc2`0ol`/0080ol`/00<000000?o8:`3ob2/00P00000305/m
408000001P3o[B/00`000000ok8[0?nb:`040?nb:`030000003o_2`0ok`/00D0ok`/00<000000?o;
;`3obbl01@3obbl00`000000on0c0?oP<`040?oP<`030000003ooST0oohi00<0oohi00<000000?oo
@03ood000P0000000`2DEaH0000009IH5P0509IH5P030000002GFQL0UeXG00<0UeXG00<0000009UL
602IG1P00P2IG1P00`000000W5lI09aO6@0309aO6@030000002JGaT0000000<000002@28ml<00`00
0000Po6k08?a^`0308?a^`0300000023lK/0Po6k0080Po6k00<0000006:hS@0000000P1R^8d20000
0300Skb?0@3oool003X0Skb?00@0000000@82P00000000001@0<61`2000000X07SPg00<0000002iF
C`0^ETl00P0^ETl4000000030?og>P000000ooll00@0ooll00<000000?ok>03oncP00`3oncP00`00
0000on`d0?o/=0020?o/=0030000003oh340on0a0080on0a00<000000?oH;`3of2l00P3of2l00`00
0000om4^0?oA;P0500000080omT_00<000000?oB;@3odRd00P3odRd00`000000ol`/0?o<;0020?o<
;0050000003ob2/0olP[0?o8:`000000101K?A000`000000ojd[0?n]:`040?n]:`030000003o/R/0
ok8[00@0ok8[00<000000?nl;03o_2`01@3o_2`00`000000ol/_0?o;;`050?o;;`030000003oh3<0
on0c00<0on0c00<000000?on>@3ooST00`3ooST01@000000oom00?oo@0000000ooHd0080U5LF00<0
000009IH5P2FF1H0102FF1H00`000000UeXG09MJ5`0309MJ5`030000002IG1P0VE`H0080VE`H00<0
000009aO6@2LGaT00`2LGaT010000000VUlI09YO6@2JGaT4000000L0R?O300<0000008?a^`23lK/0
1023lK/01@000000Po6k08?a^`23lK/000000080H[R=00<0000006:hS@0000000P00000_08nlS`40
oooo000j08nlS`030000000420X0000000H031PL00<0000001hh=`0N>3L02@0N>3L00`000000;UI?
02iFC`03000000@0ooLj00<000000?oo?03ooc`00`3ooc`00`000000oo/h0?ok>0020?ok>0030000
003ok3@0on`d0080on`d00<000000?oP<@3oh3400`3oh3400`000000omP_0?oH;`020?oH;`030000
003odBh0om4^0080om4^00<000000?o<;@3oc2d01@0000020?oB;@030000003oc2`0ol`/0080ol`/
00@000000?o8:`3ob2/0olP[0P00000305/m408000001@3o[B/00`000000ok8[0?nb:`040?nb:`03
0000003o_2`0ok`/00D0ok`/00<000000?o;;`3obbl01@3obbl00`000000on0c0?oP<`030?oP<`03
0000003ooST0oohi00<0oohi00@000000?oo@0000000ooHd0`2DEaH00`000000UUPF09IH5P0409IH
5P030000002GFQL0UeXG00<0UeXG00<0000009UL602IG1P00`2IG1P00`000000W5lI09aO6@0209aO
6@030000002JGaT0VUlI0080VUlI1@00000508Sg``0300000023lK/0Po6k00D0Po6k00@0000008?a
^`23lK/000000P1R^8d01@000000H[R=00000011O5T0000002l0Skb?0@3oool003X0Skb?00<00000
00@82P0000001@0<61`2000000/07SPg100000050?og>P030000003ooc`0ooll00<0ooll00<00000
0?ok>03oncP00`3oncP00`000000on`d0?o/=0020?o/=0030000003oh340on0a0080on0a00<00000
0?oH;`3of2l00`3of2l00`000000om4^0?oA;P020?oA;P030000003oc2d0ol`]0080ol`]00<00000
0?o7;03oab`01@0000020?o<;0040000003ob2/0olP[0?o8:`<000000P1K?A000`000000`WPO0000
00040?n]:`030000003o/R/0ok8[00@0ok8[00<000000?nl;03o_2`01@3o_2`00`000000ol/_0?o;
;`040?o;;`030000003oh3<0on0c00@0on0c00<000000?on>@3ooST00P3ooST00`000000oom00000
00020?of=0@0U5LF00<0000009IH5P2FF1H00`2FF1H00`000000UeXG09MJ5`0309MJ5`030000002I
G1P0VE`H00<0VE`H00<0000009aO6@2LGaT00P2LGaT00`000000VUlI09YO6@0309YO6@030000001n
DQH00000008000001028ml<00`000000Po6k08?a^`0608?a^`0300000023lK/0000000<0H[R=0P00
00000`11O5T0000008nlS`0^08nlS`40oooo000j08nlS`<000001@0<61`2000000/07SPg0P000006
0?og>P030000003ooc`0ooll00@0ooll00<000000?ok>03oncP00P3oncP00`000000on`d0?o/=003
0?o/=0030000003oh340on0a0080on0a00<000000?oH;`3of2l00P3of2l00`000000om4^0?oA;P03
0?oA;P030000003oc2d0ol`]0080ol`]00<000000?o7;03oab`00P3oab`00`000000ol@[0?o4:`03
000000<0olP[0`00000205/m400300000032N1l0`WPO008000000P3o[B/00`000000ok8[0?nb:`04
0?nb:`030000003o_2`0ok`/00D0ok`/00<000000?o;;`3obbl0103obbl00`000000on0c0?oP<`04
0?oP<`030000003ooST0oohi0080oohi00@000000?of=03omS@0ooHd1@2DEaH00`000000UUPF09IH
5P0309IH5P030000002GFQL0UeXG00<0UeXG00<0000009UL602IG1P00`2IG1P00`000000W5lI09aO
6@0309aO6@030000002JGaT0VUlI0080VUlI00<0000007iB5P1nDQH01000000208Sg``0300000023
lK/0Po6k00L0Po6k0P00000306:hS@80000000<0@GaI0000002?_8l0;P2?_8l10?ooo`00>P2?_8l3
000000@031PL00<0000000`H700000002P0N>3L010000000okP]0000000000040?og>P030000003o
oc`0ooll00@0ooll00<000000?ok>03oncP00`3oncP00`000000on`d0?o/=0030?o/=0030000003o
h340on0a0080on0a00<000000?oH;`3of2l00P3of2l00`000000om4^0?oA;P020?oA;P030000003o
c2d0ol`]00<0ol`]00<000000?o7;03oab`00P3oab`00`000000ol@[0?o4:`020?o4:`<0000000<0
olP[0000000000000P0000000`1K?A0000000<9h7`030<9h7`030000003o[B/0000000H0ok8[00<0
00000?nl;03o_2`01@3o_2`00`000000ol/_0?o;;`040?o;;`030000003oh3<0on0c00@0on0c00@0
00000?on>@3ooST0oohi0P0000020?of=0030000002DEaH0U5LF00<0U5LF00<0000009IH5P2FF1H0
102FF1H00`000000UeXG09MJ5`0209MJ5`030000002IG1P0VE`H00<0VE`H00<0000009aO6@2LGaT0
0`2LGaT00`000000VUlI09YO6@0309YO6@060000001nDQH0OU8F07iB5P000000?a/60`00000:08?a
^`030000001R^8d0H[R=0080H[R=00<00000045lF@000000;`2?_8l10?ooo`00>P2?_8l3000000<0
31PL00@0000000`H700<61`00000200N>3L2000000@0okP]0P0000020?og>P030000003ooc`0ooll
00@0ooll00<000000?ok>03oncP00`3oncP00`000000on`d0?o/=0020?o/=0030000003oh340on0a
00<0on0a00<000000?oH;`3of2l00P3of2l00`000000om4^0?oA;P020?oA;P030000003oc2d0ol`]
00<0ol`]00<000000?o7;03oab`00P3oab`00`000000ol@[0?o4:`020?o4:`030000003o`BX0ol4Z
00@0000000@0;A/80000001K?A0000001032N1l2000000H0ok8[00<000000?nl;03o_2`0103o_2`0
0`000000ol/_0?o;;`050?o;;`030000003oh3<0on0c00@0on0c00<000000?on>@3ooST00P000003
0?of=0030000002DEaH0U5LF00<0U5LF00<0000009IH5P2FF1H0102FF1H00`000000UeXG09MJ5`03
09MJ5`030000002IG1P0VE`H00<0VE`H00<0000009aO6@2LGaT00P2LGaT00`000000VUlI09YO6@03
09YO6@030000001nDQH0OU8F0080OU8F1000000:08?a^`8000000`1R^8d00`000000@GaI0000000_
08nlS`40oooo000j08nlS`<000000`0<61`01000000031PL00`H7000000701hh=`030000003o^2d0
okP]00H0okP]0P0000060?oo?0030000003oncP0oo/h00<0oo/h00<000000?o/=03ok3@00`3ok3@0
0`000000on0a0?oP<@030?oP<@030000003of2l0omP_0080omP_00<000000?oA;P3odBh00P3odBh0
0`000000ol`]0?o<;@020?o<;@030000003oab`0olL/00<0olL/00<000000?o4:`3oa2/00P3oa2/0
1P000000ol4Z0?o1:P3o`BX000000?nn:@80000000<0;A/80000000000001@32N1l00`000000ok8[
0?nb:`040?nb:`030000003o_2`0ok`/00@0ok`/00<000000?o;;`3obbl01@3obbl00`000000on0c
0?oP<`030?oP<`060000003ooST000000000003ooc/000000P3omS@A000000<0UeXG00<0000009UL
602IG1P00`2IG1P00`000000W5lI09aO6@0209aO6@030000002JGaT0VUlI00@0VUlI00H0000007iB
5P1nDQH0OU8F0000001D>@l3000000T0Po6k0P00000306:hS@0300000011O5T0000002l0Skb?0@3o
ool003T0Skb?0P0000001@0420X0000000`H700<61`0000000<031PL00<0000001hh=`0N>3L0100N
>3L00`000000okP]0?nh;@070?nh;@040000003oc3000000000000@0ooll00<000000?ok>03oncP0
0`3oncP00`000000on`d0?o/=0030?o/=0030000003oh340on0a0080on0a00<000000?oH;`3of2l0
0`3of2l00`000000om4^0?oA;P020?oA;P030000003oc2d0ol`]0080ol`]00<000000?o7;03oab`0
0P3oab`00`000000ol@[0?o4:`030?o4:`060000003o`BX0ol4Z0?o1:P000000okhY0P0000000`0]
6`P00000000000050<9h7`<00000103o/R/00`000000ok`/0?nl;0040?nl;0030000003obbl0ol/_
00D0ol/_00<000000?oP<`3oh3<00`3oh3<2000000<0oolk00D000000?of=02QG1L0XE`G00000005
0:AN5`030000002XHAP0Z64H00@0Z64H00<000000:eU6@2]IAT03000000309aO6@030000002JGaT0
VUlI00<0VUlI00<0000007iB5P1nDQH00P1nDQH00`000000E3T?05@i3`02000000P0Po6k00<00000
06:hS@0000000P1R^8d3000002l0Skb?0@3oool003T0Skb?0P0000001@0420X0000000`H700<61`0
000000<031PL00<0000001hh=`0N>3L00`0N>3L00`000000hH/S000000080?nh;@040000003oc300
ol``0?o<<080000000<0ooll0000003oncP01@3oncP00`000000on`d0?o/=0030?o/=0030000003o
h340on0a0080on0a00<000000?oH;`3of2l00`3of2l00`000000om4^0?oA;P020?oA;P030000003o
c2d0ol`]0080ol`]00<000000?o7;03oab`00P3oab`00`000000ol@[0?o4:`030?o4:`050000003o
`BX0ol4Z0?o1:P0000000P3o_RT0100L4@D0000002dK200000050<9h7`030000003nVBD0oYTU0080
00000P3o/R/00`000000ok`/0?nl;0040?nl;0030000003obbl0ol/_00@0ol/_00<000000?oP<`3o
h3<00`3oh3<2000000@0oolk00D000000?of=02QG1L0XE`G000000050:AN5`030000002XHAP0Z64H
00@0Z64H00<000000:eU6@2]IAT00`2]IAT00`000000]6XJ0;AZ6P030;AZ6P030000002oLQd0_g8M
00L000000`2JGaT01@000000OU8F07iB5P1nDQH0000000@0E3T?00<0000008?a^`23lK/01@23lK/0
0`000000H[R=0000000206:hS@<00000;`2?_8l10?ooo`00>@2?_8l20000000400@82P00000031PL
000000@031PL00@0000001hh=`0N>3L07SPg0P0000030>6;8`030000003o^2d0okP]00@0okP]00<0
00000?o<<03oc300103oc302000000D0oo/h00<000000?o/=03ok3@00`3ok3@00`000000on0a0?oP
<@030?oP<@030000003of2l0omP_00<0omP_00<000000?oA;P3odBh00P3odBh00`000000ol`]0?o<
;@020?o<;@030000003oab`0olL/0080olL/00<000000?o4:`3oa2/00`3oa2/01@000000ol4Z0?o1
:P3o`BX000000080okhY0P0000000`0]6`P00000000000040<9h7`030000003nVBD0oYTU0080oYTU
0`0000060?nl;0030000003obbl0ol/_00@0ol/_00@000000?oP<`3oh3<0on0c0P0000000`3olcH0
00000?oo>`020?oo>`030000003omS@0XE`G0080XE`G00<000000:AN5`2TGQL00`2TGQL00`000000
Z64H0:QQ60040:QQ60030000002]IAT0[FDI00<0[FDI00<000000;AZ6P2dJQX00`2dJQX00`000000
_g8M0;mb7@030;mb7@040000003@Ob00d7lP0=1o80D000000`1nDQH00`000000E3T?05@i3`0205@i
3`0300000023lK/0Po6k00@0Po6k00D0000006:hS@1R^8d0000006:hS@0200000003045lF@2?_8l0
Skb?02d0Skb?0@3oool003T0Skb?0P0000000`0420X000000000000500`H70040000000N>3L07SPg
000000H0hH/S00<000000?nh;@3o^2d00P3o^2d00`000000ol``0?o<<0050?o<<0040000003occ00
0000000000<0oo/h00<000000?o/=03ok3@00`3ok3@00`000000on0a0?oP<@030?oP<@030000003o
f2l0omP_0080omP_00<000000?oA;P3odBh00`3odBh00`000000ol`]0?o<;@020?o<;@030000003o
ab`0olL/0080olL/00<000000?o4:`3oa2/00`3oa2/01@000000ol4Z0?o1:P3o`BX000000080okhY
0P0000000`0]6`P00000000000040<9h7`030000003nVBD0oYTU00@0oYTU0P0000050?nl;0030000
003obbl0ol/_00@0ol/_00@000000?oP<`00000000000`3olcH010000000oolk0?oo>`3ooc/20000
00<0XE`G00<000000:AN5`2TGQL00`2TGQL00`000000Z64H0:QQ60040:QQ60030000002]IAT0[FDI
00<0[FDI00<000000;AZ6P2dJQX0102dJQX00`000000_g8M0;mb7@030;mb7@030000003@Ob00d7lP
00<0d7lP00<000000>J@9@0000000`00000505@i3`0300000023lK/0Po6k00<0Po6k00@0000006:h
S@1R^8d000000P1R^8d00`000000@GaI08nlS`0^08nlS`40oooo000i08nlS`030000000420X010P:
008000001@0<61`01@0000007SPg0000002kLQd0000000H0hH/S00@000000?nh;@3o^2d00000203o
c30010000000oll`0?o?<03occ03000000H0on`d00<000000?oP<@3oh3400P3oh3400`000000omP_
0?oH;`030?oH;`030000003odBh0om4^00<0om4^00<000000?o<;@3oc2d00P3oc2d00`000000olL/
0?o7;0020?o7;0030000003oa2/0ol@[0080ol@[00<000000?o1:P3o`BX00P3o`BX01@000000okhY
0?nn:@00000071450080000000<0NT`D00000032N1l00P32N1l00`000000oYTU0?jI9@040?jI9@03
0000003o]R/0000000<0000000<0ok`/0000003obbl00P3obbl5000000@0oo<f00<000000?oo>`3o
oc/00P3ooc/00`000000XE`G0:5L5`030:5L5`030000002TGQL0Y5hG00<0Y5hG00<000000:QQ602X
HAP00`2XHAP00`000000[FDI0:eU6@040:eU6@030000002dJQX0]6XJ00<0]6XJ00<000000;mb7@2o
LQd00`2oLQd00`000000d7lP0=1o80040=1o80040000003VT2D0iY0U0>J@9@D000000P1D>@l00`00
0000Po6k08?a^`0208?a^`060000001R^8d0H[R=06:hS@000000H[R=0`00000^08nlS`40oooo000i
08nlS`040000000420X010P:000000H031PL0P0000020;]b7@030000003QRb<0hH/S00D0hH/S00<0
00000?nh;@0000001`3oc3000`000000oll`0?o?<0040?o?<0030000003ok3@0on`d00@0on`d00<0
00000?oP<@3oh3400P3oh3400`000000omP_0?oH;`030?oH;`030000003odBh0om4^0080om4^00<0
00000?o<;@3oc2d00`3oc2d00`000000olL/0?o7;0020?o7;0030000003oa2/0ol@[0080ol@[00<0
00000?o1:P3o`BX00P3o`BX010000000okhY0?nn:@3o_RT300000080NT`D00@000000<9h7`32N1l0
00001P3nVBD00`000000okH[0?nf:`030?nf:`D000000`3odc000`000000oo<f0?oc=P030?oc=P04
0000003ooc/0oolk0?oo>`8000001@2QG1L00`000000Y5hG0:AN5`030:AN5`030000002XHAP0Z64H
00@0Z64H00<000000:eU6@2]IAT00`2]IAT00`000000]6XJ0;AZ6P030;AZ6P030000002oLQd0_g8M
00<0_g8M00<000000=1o803@Ob00103@Ob000`000000iY0U0>J@9@030>J@9@030000003?Qb80chLR
00@000000`23lK/01P000000H[R=06:hS@1R^8d0000006:hS@<00000;P2?_8l10?ooo`00>@2?_8l0
1000000010P:00@82P00000600`H70030000002kLQd0^g8M0080^g8M00<000000>6;8`3QRb<01@3Q
Rb<00`000000ol``0?o<<0060?o<<0030000003occ00oll`00@0oll`0`0000030?o/=0030000003o
h340on0a00<0on0a00<000000?oH;`3of2l00`3of2l00`000000om4^0?oA;P020?oA;P030000003o
c2d0ol`]00<0ol`]00<000000?o7;03oab`00P3oab`00`000000ol@[0?o4:`020?o4:`030000003o
`BX0ol4Z0080ol4Z00H000000?nn:@3o_RT0okhY0000000L4@D20000000507Y<50000000`WPO0<9h
7`0000001P3nVBD00`000000okH[0?nf:`040?nf:`030000003odc00om<`00@0om<`00<000000?oc
=P3olcH00`3olcH01P000000oolk0?oo>`000000ooHd000000D0XE`G00<000000:AN5`2TGQL00`2T
GQL00`000000Z64H0:QQ60040:QQ60030000002]IAT0[FDI00<0[FDI00<000000;AZ6P2dJQX00`2d
JQX00`000000_g8M0;mb7@030;mb7@030000003@Ob00d7lP00@0d7lP00<000000>J@9@3VT2D00`3V
T2D00`000000chLR0<n78P040<n78P0400000023lK/0Po6k000000@0H[R=1000000^08nlS`40oooo
000i08nlS`040000000420X00000000000D031PL00<000000;]b7@2kLQd0102kLQd00`000000hH/S
0>6;8`030>6;8`030000003oX2L0000000H0ol``00<000000?o?<03occ00103occ0010000000old^
0?o=;P3ocBh2000000030?o/=0000000on0a00@0on0a00<000000?oH;`3of2l00`3of2l00`000000
om4^0?oA;P020?oA;P030000003oc2d0ol`]0080ol`]00<000000?o7;03oab`00`3oab`00`000000
ol@[0?o4:`020?o4:`030000003o`BX0ol4Z0080ol4Z00H000000?nn:@3o_RT0okhY0000000L4@D2
00000080NT`D00<000000<9h7`0000001P3nVBD00`000000okH[0?nf:`040?nf:`030000003odc00
om<`00@0om<`00<000000?oc=P3olcH00`3olcH00`000000oolk0?oo>`03000000D0XE`G00<00000
0:AN5`2TGQL00`2TGQL00`000000Z64H0:QQ60040:QQ60030000002]IAT0[FDI00<0[FDI00<00000
0;AZ6P2dJQX00`2dJQX00`000000_g8M0;mb7@040;mb7@030000003@Ob00d7lP00<0d7lP00<00000
0>J@9@3VT2D0103VT2D00`000000chLR0<n78P030<n78P80000000<0Po6k0000001R^8d00`1R^8d4
000002h0Skb?0@3oool003T0Skb?00@0000000@82P0000000000100<61`00`000000Z6LK00000005
0;]b7@030000003QRb<0hH/S00<0hH/S00@000000?nP9`3oX2L000001@3oc3000`000000oll`0?o?
<0040?o?<0030000003ocBh0old^00<0old^0P0000050?oP<@030000003of2l0omP_00<0omP_00<0
00000?oA;P3odBh00P3odBh00`000000ol`]0?o<;@020?o<;@030000003oab`0olL/00<0olL/00<0
00000?o4:`3oa2/00P3oa2/00`000000ol4Z0?o1:P020?o1:P030000003o_RT0okhY0080okhY00<0
000001`A1@0000000`1jC1@2000000H0oYTU00<000000?nf:`3o]R/0103o]R/00`000000om<`0?oC
<0040?oC<0030000003olcH0oo<f00<0oo<f00H000000?oo>`000000ooHd09iK5P0000050:5L5`03
0000002TGQL0Y5hG00<0Y5hG00<000000:QQ602XHAP0102XHAP00`000000[FDI0:eU6@030:eU6@03
0000002dJQX0]6XJ00<0]6XJ00<000000;mb7@2oLQd0102oLQd00`000000d7lP0=1o80040=1o8003
0000003VT2D0iY0U00<0iY0U00<000000<n78P3?Qb80103?Qb83000000D0H[R=00<00000045lF@00
0000;P2?_8l10?ooo`00>@2?_8l01000000010P:00000000000300`H70040000002XIa/0Z6LK0000
00H0^g8M00D000000>6;8`3QRb<0hH/S000000040?nP9`050000003oc300ol``0?o<<00000001`3o
cc000`000000old^0?o=;P040?o=;P<000000P3oh3400`000000omP_0?oH;`040?oH;`030000003o
dBh0om4^0080om4^00<000000?o<;@3oc2d00P3oc2d00`000000olL/0?o7;0020?o7;0030000003o
a2/0ol@[00<0ol@[00<000000?o1:P3o`BX00P3o`BX00`000000okhY0?nn:@020?nn:@030000000L
4@D0000000<0NT`D0P0000060?jI9@030000003o]R/0okH[00@0okH[00<000000?oC<03odc00103o
dc000`000000oo<f0?oc=P030?oc=P80000000@0ooHd0000002NFaH000001@2QG1L00`000000Y5hG
0:AN5`030:AN5`030000002XHAP0Z64H00@0Z64H00<000000:eU6@2]IAT00`2]IAT00`000000]6XJ
0;AZ6P040;AZ6P030000002oLQd0_g8M00<0_g8M00<000000=1o803@Ob00103@Ob000`000000iY0U
0>J@9@040>J@9@030000003?Qb80chLR00<0chLR0`00000506:hS@0300000011O5T0000002h0Skb?
0@3oool003T0Skb?0P0000000`0420X0000000`H700200`H70050000002XIa/0Z6LK0:QW6`000000
1P2kLQd00`000000hH/S000000060?nP9`040000003oc300ol``000000H0oll`00<000000?o=;P3o
cBh0103ocBh010000000olX]0?o:;@3obRd3000000H0omP_00<000000?oA;P3odBh00P3odBh00`00
0000ol`]0?o<;@020?o<;@030000003oab`0olL/0080olL/00<000000?o4:`3oa2/00`3oa2/00`00
0000ol4Z0?o1:P020?o1:P030000003o_RT0okhY0080okhY00<0000001`A1@000000101jC1@00`00
0000oYTU0?jI9@040?jI9@030000003o]R/0okH[00@0okH[00<000000?oC<03odc00103odc000`00
0000oo<f0?oc=P020?oc=P8000000P3omS@209iK5P030000002QG1L0XE`G00<0XE`G00<000000:AN
5`2TGQL00`2TGQL00`000000Z64H0:QQ60040:QQ60030000002]IAT0[FDI00@0[FDI00<000000;AZ
6P2dJQX00`2dJQX00`000000_g8M0;mb7@040;mb7@030000003@Ob00d7lP00<0d7lP00<000000>J@
9@3VT2D0103VT2D00`000000chLR0<n78P0300000080ooLj0P00000406:hS@0300000011O5T00000
02h0Skb?0@3oool003T0Skb?0`00000300`H70030000002XIa/0Z6LK0080Z6LK00<000000;]b7@2k
LQd0102kLQd00`000000hH/S000000070?nP9`8000001`3occ000`000000old^0?o=;P040?o=;P03
0000003obRd0olX]00<0olX]00<000000?oH;`3of2l00`3of2l00`000000om4^0?oA;P030?oA;P03
0000003oc2d0ol`]0080ol`]00<000000?o7;03oab`00P3oab`00`000000ol@[0?o4:`030?o4:`03
0000003o`BX0ol4Z0080ol4Z00<000000?nn:@3o_RT00P3o_RT4000000<0NT`D0P0000050?jI9@03
0000003o]R/0okH[00@0okH[00<000000?oC<03odc000`3odc000`000000oo<f0?oc=P030?oc=P80
000000D0ooHd0000002NFaH0WU/F000000050:5L5`030000002TGQL0Y5hG00<0Y5hG00<000000:QQ
602XHAP0102XHAP00`000000[FDI0:eU6@040:eU6@030000002dJQX0]6XJ00<0]6XJ00<000000;mb
7@2oLQd0102oLQd00`000000d7lP0=1o80030=1o80030000003VT2D0iY0U00@0iY0U0`0000050?og
>P800000101R^8d00`000000@GaI0000000^08nlS`40oooo000h08nlS`040000000420X000000000
008031PL00<000000:MV6`000000102XIa/00`000000^g8M0;]b7@040;]b7@030000003oX2L0oj0W
00L0oj0W00<000000?o?<03occ001@3occ000`000000old^0?o=;P040?o=;P030000003obRd0olX]
00<0olX]0`0000030?oH;`030000003odBh0om4^00<0om4^00<000000?o<;@3oc2d00P3oc2d00`00
0000olL/0?o7;0020?o7;0030000003oa2/0ol@[00<0ol@[00<000000?o1:P3o`BX00P3o`BX00`00
0000okhY0?nn:@020?nn:@@000000`1jC1@00`000000cWdO000000040?jI9@030000003o]R/0okH[
00<0okH[00<000000?oC<03odc00103odc000`000000oo<f0?oc=P030?oc=P040000003omS@0ooHd
00000080WU/F00<000000:5L5`2QG1L0102QG1L00`000000Y5hG0:AN5`030:AN5`030000002XHAP0
Z64H00<0Z64H00<000000:eU6@2]IAT0102]IAT00`000000]6XJ0;AZ6P030;AZ6P030000002oLQd0
_g8M00@0_g8M00<000000=1o803@Ob00103@Ob000`000000iY0U00000003000000030?o8<0000000
ooLj00H0ooLj0P00000306:hS@<00000;P2?_8l10?ooo`00>02?_8l20000000700@82P00000031PL
00`H70000000YfHK000000040:QW6`030000002kLQd0^g8M00<0^g8M00<000000=N28@000000203o
X2L2000000H0oll`00<000000?o=;P3ocBh0103ocBh00`000000olX]0?o:;@030?o:;@030000003o
ab`0olL/0080000000<0omP_0000003odBh00`3odBh00`000000ol`]0?o<;@030?o<;@030000003o
ab`0olL/0080olL/00<000000?o4:`3oa2/00`3oa2/01@000000ol4Z0?o1:P3o`BX0000000D0okhY
0`0000001@0j9@/0000007Y<501jC1@000000080cWdO0P0000020?jI9@030000003o]R/0okH[00<0
okH[00<000000?oC<03odc00103odc000`000000oo<f0?oc=P020?oc=P80000000<0ooHd0000002N
FaH00P2NFaH00`000000XE`G0:5L5`040:5L5`030000002TGQL0Y5hG00<0Y5hG00<000000:QQ602X
HAP00`2XHAP00`000000[FDI0:eU6@040:eU6@030000002dJQX0]6XJ00<0]6XJ00<000000;mb7@2o
LQd0102oLQd00`000000d7lP0=1o80030=1o80<000001P3ob3000`000000ooLj0?og>P050?og>P80
00000P1R^8d3000002h0Skb?0@3oool003P0Skb?0P000000100420X0000000`H700000030:MV6`03
0000002XIa/0Z6LK0080Z6LK00<000000;]b7@2kLQd00P2kLQd00`000000eh8Q000000070?nP9`04
0000003o[BT0ojdY000000@0oll`00<000000?o=;P3ocBh0103ocBh00`000000olX]0?o:;@030?o:
;@030000003oab`0olL/00<0olL/0`0000030?oA;P030000003oc2d0ol`]00<0ol`]00<000000?o7
;03oab`00P3oab`00`000000ol@[0?o4:`030?o4:`050000003o`BX0ol4Z0?o1:P0000001@3o_RT3
0000000503XU2`000000NT`D07Y<50000000103>OAl00`000000oYTU000000050?nf:`030000003o
dc00om<`00@0om<`00T000000?oc=P3olcH0oo<f0000003oocP000000?of=00000000`2NFaH00`00
0000XE`G0:5L5`040:5L5`030000002TGQL0Y5hG00<0Y5hG00<000000:QQ602XHAP00`2XHAP00`00
0000[FDI0:eU6@040:eU6@030000002dJQX0]6XJ00<0]6XJ00<000000;mb7@2oLQd01@2oLQd00`00
0000d7lP00000002000000030?nQ9`000000olP`00H0olP`00<000000?og>P3omcX0103omcX00`00
0000oom10000000206:hS@<00000;P2?_8l10?ooo`00>02?_8l20000000400@82P00000000000000
00<0YfHK00<000000:QW6`2XIa/00P2XIa/01@000000^g8M0;]b7@2kLQd0000000<0eh8Q00<00000
0?nP9`3oX2L0103oX2L01@000000ojdY0?n]:@3o[BT0000000<0oll`00<000000?o=;P3ocBh0103o
cBh00`000000olX]0?o:;@030?o:;@030000003oab`0olL/00@0olL/00H000000?o4;00000000000
0?oA;P0000040?o<;@030000003oab`0olL/00<0olL/00<000000?o4:`3oa2/00`3oa2/01@000000
ol4Z0?o1:P3o`BX0000000@0okhY00H000000?nl:@000000000003XU2`00000207Y<50030000003>
OAl0cWdO00<0cWdO0P0000050?nf:`030000003odc00om<`00@0om<`00H000000?oc=P0000000000
0?oo>00000020?of=0@0WU/F00<000000:5L5`2QG1L0102QG1L00`000000Y5hG0:AN5`030:AN5`03
0000002XHAP0Z64H00<0Z64H00<000000:eU6@2]IAT0102]IAT00`000000]6XJ0;AZ6P040;AZ6P03
0000002oLQd0_g8M00<0_g8M0`0000050?nQ9`030000003ob300olP`00D0olP`00<000000?og>P3o
mcX00P3omcX00`000000oom10?oo@@0200000080H[R=0P00000^08nlS`40oooo000h08nlS`030000
000420X010P:008000001@2WIQ/00`000000Z6LK0:QW6`020:QW6`030000002kLQd0000000D0eh8Q
00<000000?nP9`3oX2L00P3oX2L00`000000ojdY0?n]:@030?n]:@040000003occ00oll`000000H0
old^00<000000?o:;@3obRd00`3obRd00`000000olL/0?o7;0040?o7;0040000003oa2`0ol@/0?o4
;0800000103oc2d00`000000olL/0?o7;0030?o7;0030000003oa2/0ol@[00<0ol@[00D000000?o1
:P3o`BX0ol4Z000000040?nn:@040000003o_2T0000000000080>RD;00<0000007Y<500000001P3>
OAl00`000000okH[0?nf:`030?nf:`030000003odc00om<`00@0om<`0P0000030?oo>0030000003o
mS@0000000@0WU/F00<000000:5L5`2QG1L0102QG1L00`000000Y5hG0:AN5`030:AN5`030000002X
HAP0Z64H00@0Z64H00<000000:eU6@2]IAT0102]IAT00`000000]6XJ0;AZ6P030;AZ6P030000002o
LQd0000000<0000000<0jh/R0000003oXBL01@3oXBL00`000000olP`0?o8<0050?o8<0030000003o
mcX0ooLj00800000103ood400`000000H[R=06:hS@02000002h0Skb?0@3oool003P0Skb?00H00000
00@82P0420X000000;ae7P0000040:MV6`030000002XIa/0Z6LK0080Z6LK00<000000;]b7@000000
1@3GPR400`000000oj0W0?nP9`020?nP9`030000003o[BT0ojdY00@0ojdY0P0000070?o=;P030000
003obRd0olX]00<0olX]00<000000?o7;03oab`00`3oab`00`000000ol@/0?o4;0030?o4;0<00000
0P3oc2d00`000000olL/0?o7;0030?o7;0030000003oa2/0ol@[00<0ol@[00D000000?o1:P3o`BX0
ol4Z000000040?nn:@040000003o_2T0ok`Y00000080>RD;00<0000007Y<500000001P3>OAl30000
00<0okH[00<000000?oC<03odc000`3odc02000000@0oolh00<000000?of=0000000102NFaH00`00
0000XE`G0:5L5`040:5L5`030000002TGQL0Y5hG00<0Y5hG00<000000:QQ602XHAP0102XHAP00`00
0000[FDI0:eU6@040:eU6@030000002dJQX0]6XJ0080]6XJ0`0000050>^;8P030000003oXBL0oj4W
00@0oj4W00<000000?o8<03ob3001P3ob302000000L0oom100@0000006:hS@0000000000;P2?_8l1
0?ooo`00>02?_8l01P00000010P:00@82P000000_7DN000000D0YfHK00<000000:QW6`2XIa/00P2X
Ia/00`000000eh8Q0=N28@050=N28@040000003oX2L0oj0W000000P0ojdY00<000000?o=;P3ocBh0
103ocBh00`000000olX]0?o:;@040?o:;@030000003oab`0olL/00<0olL/00<000000?o4;03oa2`0
0`3oa2`00`000000ol4[0?o1:`03000000@0olL/00<000000?o4:`3oa2/00`3oa2/00`000000ol4Z
0?o1:P020?o1:P030000003o_RT0okhY0080okhY00<000000?nl:@3o_2T00P00000203XU2`800000
1P3>OAl00`000000ojhY0?n^:@02000000030?nf:`000000om<`00@0000000<0om`b0000003oocP0
0`3oocP2000000D0WU/F00<000000:5L5`2QG1L0102QG1L00`000000Y5hG0:AN5`030:AN5`030000
002XHAP0Z64H00@0Z64H00<000000:eU6@2]IAT0102]IAT00`000000]6XJ00000002000000030=Im
7P000000jh/R00H0jh/R00<000000?nQ9`3oXBL00`3oXBL00`000000olP`0?o8<0060?o8<0030000
003ood40oom100D0oom11@00000^08nlS`40oooo000h08nlS`030000000420X0000000<0_7DN00<0
00000:MV6`2WIQ/00P2WIQ/01`000000Z6LK0:QW6`2XIa/000000;=]700000001`3GPR400`000000
oj0W000000080?n]:@8000001@3ocBh00`000000olX]0?o:;@030?o:;@030000003oab`0olL/00@0
olL/00<000000?o4;03oa2`00`3oa2`00`000000ol4[0?o1:`020?o1:`030000003oab`0olL/0080
olL/00<000000?o4:`3oa2/00`3oa2/00`000000ol4Z0?o1:P020?o1:P030000003o_RT0okhY0080
okhY00<000000?nl:@3o_2T00P00000203XU2`8000001P3>OAl00`000000ojhY0?n^:@020?n^:@<0
00001@3og3800`000000oolh0?oo>0020?oo>08000001@2NFaH00`000000XE`G0:5L5`040:5L5`03
0000002TGQL0Y5hG00<0Y5hG00<000000:QQ602XHAP0102XHAP00`000000[FDI0:eU6@030:eU6@<0
0000103FOAh00`000000jh/R0>^;8P050>^;8P030000003oXBL0oj4W00@0oj4W00<000000?o8<03o
b3000`3ob303000000H0oom100<000000?oo?P3ooch00`00000^08nlS`40oooo000h08nlS`030000
000420X0000000@0_7DN00<000000:MV6`2WIQ/00P2WIQ/00`000000Z6LK000000020;=]70030000
003GPR40eh8Q00D0eh8Q0P0000080?n]:@040000003o/bT0ok<Y000000@0old^00<000000?o:;@3o
bRd00`3obRd00`000000olL/0?o7;0040?o7;0030000003oa2`0ol@/00<0ol@/00<000000?o1:`3o
`B/00P3o`B/300000080olL/00<000000?o4:`3oa2/00`3oa2/00`000000ol4Z0?o1:P020?o1:P03
0000003o_RT0okhY0080okhY00<000000?nl:@3o_2T00`00000203XU2`030000003>OAl0cWdO00@0
cWdO00<000000?n^:@3o[RT00`3o[RT00`000000om`b0?oL<P040?oL<P040000003oocP0oolh0?oo
>0<000001P2NFaH00`000000XE`G0:5L5`040:5L5`030000002TGQL0Y5hG00<0Y5hG00<000000:QQ
602XHAP00`2XHAP00`000000[FDI00000003000000030<Qd70000000eWdN00D0eWdN00<000000>^;
8P3[Rb80103[Rb800`000000oj4W0?nQ9`040?nQ9`030000003ob300olP`0080olP`00D000000?oe
>03omCP0ooDh000000040?oo@@040000003ooch0ooln0?oo?P<00000;P2?_8l10?ooo`00>02?_8l0
1000000010P:0000000000030;ae7P030000002WIQ/0YfHK0080YfHK00<000000:QW6`0000000`2c
KA`00`000000eh8Q0=N28@050=N28@030000003o[BT0ojdY00H0ojdY00D000000?nc:@3o/bT0ok<Y
000000030?o=;P030000003obRd0olX]00<0olX]00<000000?o7;03oab`0103oab`00`000000ol@/
0?o4;0020?o4;0030000003o`B/0ol4[00<0ol4[00<000000?no:P3o_bX00`0000050?o4:`030000
003o`BX0ol4Z0080ol4Z00<000000?nn:@3o_RT00P3o_RT00`000000ok`Y0?nl:@0300000080>RD;
00<000000<im7`3>OAl0103>OAl00`000000ojhY0?n^:@030?n^:@030000003og380om`b00<0om`b
00<000000?oo>03oocP00P3oocP00`000000ojdT0000000609iK5P030000002QG1L0XE`G00@0XE`G
00<000000:AN5`2TGQL00`2TGQL00`000000Z64H0:QQ60020:QQ60<000001@38M1`00`000000eWdN
0=Im7P040=Im7P030000003[Rb80jh/R00@0jh/R00<000000?nQ9`3oXBL0103oXBL01@000000olP`
0?o8<03ob300000000@0ooDh00D000000?oo@@3ood40oom1000000050?oo?P800000;P2?_8l10?oo
o`00>02?_8l200000080oj@Y00D000000;ae7P2lMAh0_7DN000000040:MV6`030000002cKA`0/fdL
0080/fdL00<000000=N28@3GPR40103GPR400`000000lHlS000000070?n]:@030000003o/bT0ok<Y
0080ok<Y00<000000?o=;P0000001P3obRd00`000000olL/0?o7;0030?o7;0030000003oa2`0ol@/
00<0ol@/00<000000?o1:`3o`B/00`3o`B/00`000000oklZ0?no:P020?no:P030000003oa2/0ol@[
00<0ol@[00<000000?o1:P3o`BX00P3o`BX00`000000okhY0?nn:@020?nn:@040000003o_2T0ok`Y
0?nl:@8000000P0j9@/2000000D0cWdO00<000000?n^:@3o[RT00`3o[RT00`000000om`b0?oL<P03
0?oL<P030000003oocP0oolh0080oolh0P0000000`2KFAH0000009iK5P0409iK5P030000002QG1L0
XE`G00@0XE`G00<000000:AN5`2TGQL00`2TGQL00`000000Z64H00000002000000030;i^6`000000
b7@L00D0b7@L00<000000=Im7P3FOAh0103FOAh00`000000jh/R0>^;8P050>^;8P030000003oXBL0
oj4W00@0oj4W0`0000050?oe>0050000003ood40oom10?oo@@000000103ooch3000002h0Skb?0@3o
ool003L0Skb?00<0000000@82P0000000`3oY2T01@000000_7DN0;ae7P2lMAh000000080YfHK0P00
00050;=]70030000003GPR40eh8Q00<0eh8Q00<000000?6?8`0000001P3o[BT00`000000ok<Y0?nc
:@040?nc:@8000001@3obRd00`000000olL/0?o7;0040?o7;0030000003oa2`0ol@/00<0ol@/00<0
00000?o1:`3o`B/00`3o`B/00`000000oklZ0?no:P020?no:P<000000`3oa2/00`000000ol4Z0?o1
:P020?o1:P030000003o_RT0okhY0080okhY00P000000?nl:@3o_2T0ok`Y0000000X60L0000003XU
2`800000103>OAl00`000000ojhY0?n^:@040?n^:@030000003og380om`b00<0om`b00@000000?oo
>03oocP0oolh0`0000000`2KFAH0000009iK5P0409iK5P030000002QG1L0XE`G00@0XE`G00@00000
0:AN5`2TGQL0Y5hG100000040;i^6`0300000038M1`0b7@L00D0b7@L00<000000=Im7P3FOAh00`3F
OAh00`000000jh/R0>^;8P050>^;8P030000003oXBL0oj4W00@0oj4W00<000000?oe>03omCP01@3o
mCP010000000oom10?oo@@0000050?oo?P<00000;P2?_8l10?ooo`00=`2?_8l3000000<0oj@Y00<0
00000;ae7P2lMAh00P2lMAh01@000000YfHK0000002LHAT0000000@0/fdL00<000000=N28@3GPR40
0P3GPR401@000000lHlS0?6?8`3aSb<0000000D0ojdY00<000000?nc:@3o/bT01@3o/bT00`000000
olX]0?o:;@030?o:;@030000003oab`0olL/00@0olL/00<000000?o4;03oa2`00`3oa2`00`000000
ol4[0?o1:`020?o1:`030000003o_bX0oklZ00<0oklZ00<000000?nm:@3o_BT00P0000000`3oa2/0
00000?o1:P030?o1:P030000003o_RT0okhY0080okhY00/000000?nl:@3o_2T0ok`Y0000000X60L0
000003XU2`000000X64I000000030<im7`030000003o[RT0ojhY00@0ojhY00<000000?oL<P3og380
0`3og3801P000000oolh0?oo>0000000oolg0?n]9080VeTF00<0000009iK5P2NFaH00`2NFaH00`00
0000XE`G0:5L5`030:5L5`D000000P2gJAT00`000000_VhK0;i^6`030;i^6`0300000038M1`0b7@L
00D0b7@L00<000000=Im7P3FOAh00`3FOAh00`000000jh/R0>^;8P050>^;8P030000003oXBL0oj4W
00<0oj4W0P0000080?oe>08000001@3ooch010000000oolh0?oo>000000^08nlS`40oooo000g08nl
S`D000000P3oY2T010000000_7DN0;ae7P2lMAh200000080W64I00<000000;=]702cKA`00`2cKA`0
1@000000eh8Q0=N28@3GPR40000000@0lHlS00<000000?n]:@3o[BT00P3o[BT00`000000ok<Y0?nc
:@050?nc:@800000103obRd00`000000olL/0?o7;0040?o7;0030000003oa2`0ol@/00<0ol@/00<0
00000?o1:`3o`B/00P3o`B/00`000000oklZ0?no:P030?no:P030000003o_BT0okdY0080okdY0P00
00040?o1:P030000003o_RT0okhY0080okhY00@000000?nl:@3o_2T0ok`Y0P0000000`0X60L00000
000000020:1Q6@040000003>OAl0cWdO000000H0ojhY00<000000?oL<P3og3800`3og3800`000000
oolh0?oo>00300000080VeTF00<0000009iK5P2NFaH00`2NFaH00`000000XE`G0000000300000003
0;5U6@000000]fTI00@0]fTI00<000000;i^6`2nKQ/0102nKQ/00`000000b7@L0<Qd70040<Qd7003
0000003FOAh0eWdN00<0eWdN00<000000>^;8P3[Rb801@3[Rb800`000000oj4W0?nQ9`020?nQ9`04
0000003ob2l0olP_000000L0ooDh00<000000?oo?P3ooch00`3ooch01@000000oolh0?oo>03oocP0
000002h0Skb?0@3oool003L0Skb?0`0000020?og>P040000003oY2T0oj@Y000000<0_7DN00D00000
09aQ6@2LHAT0W64I000000040;=]70040000003GPR40eh8Q000000D0lHlS00D000000?n]:@3o[BT0
ojdY000000070?nc:@040000003o]bX0okLZ000000<0olX]00<000000?o7;03oab`0103oab`00`00
0000ol@/0?o4;0030?o4;0030000003o`B/0ol4[0080ol4[00<000000?no:P3o_bX00`3o_bX00`00
0000okdY0?nm:@030?nm:@<000000P3o`BX00`000000okhY0?nn:@020?nn:@040000003o_2T0ok`Y
0?nl:@80000000<0:1P70000000000000`2PHAT00`000000cWdO000000050?n^:@030000003og380
om`b00@0om`b00@000000?oo>0000000oolg0P00000209]I5P030000002NFaH0WU/F0080WU/F0`00
00050;5U6@030000002gJAT0]fTI00<0]fTI00<000000;i^6`2nKQ/0102nKQ/00`000000b7@L0<Qd
70040<Qd70030000003FOAh0eWdN00@0eWdN00<000000>^;8P3[Rb801@3[Rb8010000000oj4W0000
000000030?o8;`030000003omCP0ooDh00@0ooDh0P0000040?oo?P030000003oocP0oolh0080oolh
00<0000008nlS`2?_8l0;02?_8l10?ooo`00=`2?_8l2000000@0ooLj00P000000?nT:@3oY2T00000
0;ae7P000000QEHG00000080W64I00<000000;=]702cKA`00`2cKA`00`000000eh8Q000000060?6?
8`040000003o[BT0ojdY000000L0ok<Y00@000000?ng:P3o]bX000000`3obRd00`000000olL/0?o7
;0040?o7;0030000003oa2`0ol@/00<0ol@/00<000000?o1:`3o`B/00P3o`B/00`000000oklZ0?no
:P030?no:P030000003o_BT0okdY00<0okdY00<000000?nk:@3o^bT00`0000040?nn:@040000003o
_2T0ok`Y0?nl:@80000000@0:1P70000000j9@/000000P2PHAT00`000000cWdO000000050?n^:@03
0000003og380om`b00<0om`b00@000000?oo>0000000oolg0P00000309]I5P030000002NFaH00000
0080000000<0[F<H0000002aIAT01@2aIAT00`000000]fTI0;MY6@030;MY6@030000002nKQ/0_VhK
00@0_VhK00<000000<Qd7038M1`01038M1`00`000000eWdN0=Im7P040=Im7P030000003[Rb80jh/R
00D0jh/R0P0000050?o8;`030000003omCP0ooDh00<0ooDh00@000000?oo?@3oocd000000`3ooch0
10000000oolh0?oo>03oocP3000002d0Skb?0@3oool003L0Skb?0P0000050?og>P80000000D0oj@Y
00000025EQL0QEHG0000000309aQ6@030000002cKA`0/fdL0080/fdL0P0000080?6?8`030000003o
[BT0000000L0ok<Y00L000000?ng:P3o]bX0okLZ0000003obRd0000000H0olL/00<000000?o4;03o
a2`0103oa2`00`000000ol4[0?o1:`020?o1:`030000003o_bX0oklZ00<0oklZ00<000000?nm:@3o
_BT00`3o_BT00`000000ok/Y0?nk:@020?nk:@8000000`3o_RT00`000000ok`Y0?nl:@020?nl:@03
0000000X60L0:1P7008000000`2PHAT2000000D0ojhY00<000000?oL<P3og3800`3og38200000080
oolg0P00000209]I5P<00000102]HaP00`000000/FDI0;5U6@040;5U6@030000002gJAT0]fTI00<0
]fTI00<000000;i^6`2nKQ/0102nKQ/00`000000b7@L0<Qd70040<Qd70030000003FOAh0eWdN00@0
eWdN00<000000>^;8P3[Rb801@3[Rb800`000000olP_0?o8;`040?o8;`030000003omCP0ooDh00<0
ooDh00@000000?oo?@3oocd000000P3ooch00`000000oolh0?oo>0020?oo>0<00000;@2?_8l10?oo
o`00=`2?_8l:00000005075>50000000QEHG08EF5`0000000P2LHAT00`000000/fdL0;=]70030;=]
70030000003aSb<0lHlS00H0lHlS0P0000080?nc:@030000003o]bX0okLZ0080okLZ0P0000060?o7
;0030000003oa2`0ol@/00<0ol@/00<000000?o1:`3o`B/00`3o`B/00`000000oklZ0?no:P020?no
:P030000003o_BT0okdY00@0okdY00<000000?nk:@3o^bT00P3o^bT01P000000okTX000000000000
okhY000000@0ok`Y0P0000000`0X60L00000000000040:1Q6@030000003o[RT0ojhY00<0ojhY00<0
00000?oL<P3og3800`3og38200000080oolg100000000`2YH1L000000:eS60040:eS60030000002a
IAT0/FDI00@0/FDI00<000000;MY6@2gJAT00`2gJAT00`000000_VhK0;i^6`040;i^6`0300000038
M1`0b7@L00D0b7@L00<000000=Im7P3FOAh00`3FOAh00`000000jh/R0>^;8P030>^;8P<000001`3o
b2l01@000000ooDh0?oe>03omCP0000000<0oolm00<000000?oo?P000000103oocP010000000oo0b
00000000000]08nlS`40oooo000g08nlS`8000001P3ood050000000308EF5`000000W64I0080W64I
00L000000;=]702cKA`0/fdL00000030MAh0000000P0lHlS00<000000?nc:@3o/bT01@3o/bT00`00
0000okLZ0?ng:P040?ng:P030000003oab`0olL/00@0olL/00<000000?o4;03oa2`00`3oa2`00`00
0000ol4[0?o1:`030?o1:`030000003o_bX0oklZ0080oklZ00<000000?nm:@3o_BT0103o_BT00`00
0000ok/Y0?nk:@020?nk:@040000003o^BP0okTX0?ni:0800000103o_2T200000080:1P700<00000
0:1Q6@2PHAT00P2PHAT3000000<0ojhY00<000000?oL<P3og3800P3og382000000<0oolg00<00000
0:UP5`2YH1L00P2YH1L00`000000[F<H0:eS60030:eS60030000002aIAT0/FDI00@0/FDI00<00000
0;MY6@2gJAT0102gJAT00`000000_VhK0;i^6`030;i^6`0300000038M1`0b7@L00D0b7@L00<00000
0=Im7P3FOAh00`3FOAh00`000000jh/R0>^;8P020>^;8P040000003oZbP0oj/X000000L0olP_00@0
00000?oe>03omCP000001@3oocd2000000<0oolh00<000000?o`<P3ol3800P00000]08nlS`40oooo
000g08nlS`800000103ood02000000040?oo?@000000omd_0?oM;`80000000D0QEHG0000002LHAT0
W64I000000030;=]700300000030MAh0000000P0lHlS0P0000060?nc:@030000003o]bX0okLZ00@0
okLZ0P0000050?o7;0030000003oa2`0ol@/00<0ol@/00<000000?o1:`3o`B/00`3o`B/00`000000
oklZ0?no:P020?no:P030000003o_BT0okdY00@0okdY00<000000?nk:@3o^bT00P3o^bT00`000000
okTX0?ni:0020?ni:0<000000P3o_2T200000080:1P700<000000:1Q6@2PHAT00P2PHAT00`000000
oj@W0?nT9`02000000030?n^:@000000om`b00<0000000@0onPd0000003oocL0oolg0P0000040:UP
5`030000002]HaP0[F<H00<0[F<H00<000000;5U6@2aIAT01@2aIAT00`000000]fTI0;MY6@030;MY
6@030000002nKQ/0_VhK00<0_VhK00<000000<Qd7038M1`01@38M1`00`000000eWdN0=Im7P040=Im
7P040000003[Rb80jh/R000000<0oj/X00<000000?o8;`3ob2l01@3ob2l00`000000ooDh00000006
0?oo?@050000003oocP0oolh0?oo>00000000P3ol383000002d0Skb?0@3oool003L0Skb?0P000000
103ood0000000000000000020?oo?@80000000L0omd_0000003oocX0oolj00000025EQL000000080
W64I00<000000;=]700000000`30MAh00`000000lHlS0?6?8`040?6?8`030000003oVRD0000000H0
ok<Y00<000000?ng:P3o]bX0103o]bX00`000000okPZ000000040?o7;0030000003oa2`0ol@/00<0
ol@/00<000000?o1:`3o`B/00`3o`B/00`000000oklZ0?no:P020?no:P030000003o_BT0okdY00@0
okdY00<000000?nk:@3o^bT00P3o^bT00`000000okTX0?ni:0020?ni:0030000003o]bP0okLX00@0
00000P0X60L00`000000X64I0:1Q6@020:1Q6@030000003oY2L0oj@W0080oj@W0`0000040?oX=005
0000003oocL0oolg0000003>OAX0102YH1L00`000000[F<H0:eS60030:eS60030000002aIAT0/FDI
00D0/FDI00<000000;MY6@2gJAT00`2gJAT00`000000_VhK0;i^6`030;i^6`0300000038M1`0b7@L
00D0b7@L00<000000=Im7P3FOAh0103FOAh3000000D0oj/X00<000000?o8;`3ob2l01@3ob2l20000
00D0oolm0P0000030?oo>0030000003ol380oo0b00<00000;@2?_8l10?ooo`00=`2?_8l3000000@0
oolm00@000000?oo>`3ooc/000000`3oocX300000080W64I00<000000;=]700000000`30MAh00`00
0000lHlS0?6?8`040?6?8`040000003oVRD0oiXU000000D0ok<Y00<000000?ng:P3o]bX00`3o]bX0
10000000okPZ0?nh:P3o^2X2000000030?o7;0000000ol@/00D0ol@/00<000000?o1:`3o`B/00P3o
`B/00`000000oklZ0?no:P030?no:P030000003o_BT0okdY00<0okdY00<000000?nk:@3o^bT00`3o
^bT00`000000okTX0?ni:0020?ni:0030000003o]bP0okLX0080okLX0`0000000`0X60L000000000
00030:1Q6@030000003oY2L0oj@W00<0oj@W00<000000?oX=03oj3@00P3oj3@00`000000oolg0?oo
=`02000000D0ZF0G00<000000:eS602]HaP00`2]HaP00`000000/FDI0;5U6@050;5U6@030000002g
JAT0]fTI00<0]fTI00<000000;i^6`2nKQ/0102nKQ/00`000000b7@L0<Qd70040<Qd70030000003F
OAh0eWdN00@0eWdN00<000000?n[:03oZbP01@3oZbP00`000000olP_0?o8;`050?o8;`030000003o
ocd0oolm00@0oolm0P0000020?oo>0050000003ol380oo0b0000003ohBl00P00000]08nlS`40oooo
000g08nlS`8000000`3oocd200000080oolk00<000000?oo>`0000000P3oocX010000000oolm0000
0000000209aQ6@0300000030MAh0`7DN00<0`7DN00<000000?6?8`3aSb<00P3aSb<00`000000oiXU
0?nJ9@020?nJ9@050000003o/bT0ok<Y0?nc:@0000001P3o]bX00`000000okPZ0?nh:P030?nh:P80
00001P3oa2`00`000000ol4[0?o1:`020?o1:`030000003o_bX0oklZ00<0oklZ00<000000?nm:@3o
_BT00`3o_BT00`000000ok/Y0?nk:@030?nk:@030000003o^BP0okTX0080okTX00<000000?ng:03o
]bP00P3o]bP30000000302PH1`000000000000<0X64I00<000000?nT9`3oY2L00`3oY2L00`000000
onPd0?oX=0020?oX=0030000003oocL0oolg008000001@2YH1L00`000000[F<H0:eS60040:eS6003
0000002aIAT0/FDI00@0/FDI00<000000;MY6@2gJAT00`2gJAT00`000000_VhK0;i^6`040;i^6`03
00000038M1`0b7@L00@0b7@L00<000000=Im7P3FOAh00`3FOAh2000000L0oj/X00<000000?o8;`3o
b2l0103ob2l2000000D0oolm00<000000?oo>`3ooc/00P0000020?o`<P030000003ohBl0on4_0080
0000;@2?_8l10?ooo`00>02?_8l010000000oolm0?oo?@0000030?oo>`060000003ooc/0oolk0000
003oocX000000`3oocd01@000000W64I0000002=F1L0000000D0`7DN00D000000?6?8`3aSb<0lHlS
000000040?nJ9@050000003o/bT0ok<Y0?nc:@0000001P3o]bX00`000000okPZ0?nh:P040?nh:P03
0000003oa2`0ol@/00@0ol@/00<000000?o1:`3o`B/00P3o`B/00`000000oklZ0?no:P030?no:P03
0000003o_BT0okdY00<0okdY00<000000?nk:@3o^bT00`3o^bT00`000000okTX0?ni:0020?ni:003
0000003o]bP0okLX0080okLX0`000000100X60L0000007M84`0000020:1Q6@030000003oY2L0oj@W
00<0oj@W00<000000?oX=03oj3@00P3oj3@01@000000oolg0000003oiS00cWdJ00D0ZF0G00<00000
0:eS602]HaP0102]HaP00`000000/FDI0;5U6@040;5U6@030000002gJAT0]fTI00<0]fTI00<00000
0;i^6`2nKQ/0102nKQ/00`000000b7@L0<Qd70050<Qd70070000003FOAh0eWdN0=Im7P000000oiHT
000000070?n[:0030000003ob2l0olP_00<0olP_00<000000?of=`0000001@3oocd00`000000oolk
0?oo>`0200000080oo0b00@000000?oQ;`0000000000;P2?_8l10?ooo`00>02?_8l3000000<0oolk
00<000000?oo>`3ooc/00P3ooc/00`000000oolm0?oo?@020?oo?@8000000P2=F1L00`000000`7DN
0<1e7P030<1e7P040000003aSb<0lHlS000000H0oiXU00@000000?nc:@3o/bT000001P3o]bX00`00
0000okPZ0?nh:P040?nh:P8000001@3oa2`00`000000ol4[0?o1:`020?o1:`030000003o_bX0oklZ
00<0oklZ00<000000?nm:@3o_BT00`3o_BT00`000000ok/Y0?nk:@020?nk:@030000003o^BP0okTX
00<0okTX00<000000?ng:03o]bP00P3o]bP20000000501dB1@000000000007M84`0000000P2PHAT0
0`000000oj@W0?nT9`030?nT9`030000003oj3@0onPd0080onPd00<000000?oo=`0000000P000005
0:UP5`030000002]HaP0[F<H00@0[F<H00<000000;5U6@2aIAT0102aIAT00`000000]fTI0;MY6@03
0;MY6@030000002nKQ/0_VhK00@0_VhK00<000000<Qd7038M1`01@38M1`010000000eWdN00000000
00020?nF90030000003oZbP0oj/X00D0oj/X00<000000?o8;`3ob2l00P3ob2l01@000000ooHg0?of
=`3omSL0000000<0oolm00D000000?oo>`3ooc/0oolk000000020?o`<P050000003ohBl000000?o^
<P000000;P2?_8l10?ooo`00>02?_8l2000000<0oolk00<000000?oo>`3ooc/00P3ooc/2000000<0
oolm00@000000?oo>`00000000000P2=F1L00`000000`7DN0<1e7P030<1e7P030000003aSb<00000
00L0oiXU00<000000?nc:@0000001P3o]bX00`000000okPZ0?nh:P040?nh:P030000003o^2T00000
00<0ol@/00<000000?o1:`3o`B/00`3o`B/00`000000oklZ0?no:P030?no:P030000003o_BT0okdY
00<0okdY00<000000?nk:@3o^bT00P3o^bT00`000000okTX0?ni:0030?ni:0030000003o]bP0okLX
0080okLX0P0000000`0M4PD000000000000207M84`030000002PHAT0000000D0oj@W00<000000?oX
=03oj3@00P3oj3@2000000030?oV<0000000000000D0ZF0G00<000000:eS602]HaP0102]HaP00`00
0000/FDI0;5U6@040;5U6@030000002gJAT0]fTI00<0]fTI00<000000;i^6`2nKQ/0102nKQ/00`00
0000b7@L0<Qd70050<Qd708000001@3oUR@00`000000oj/X0?n[:0040?n[:0050000003ob2l0olP_
0?o8;`000000103omSL010000000oolm0?oo?@0000030?oo>`80000000D0oo0b0000003ohBl00000
0?o^<P02000002h0Skb?0@3oool003P0Skb?0P0000030?oo>`030000003ooc/0oolk0080oolk00<0
00000?oo?@0000000P3oocd00`000000oolk0?oo>`0200000080SEPG00<000000<1e7P30MAh00P30
MAh2000000P0oiXU0P0000070?ng:P030000003o^2X0okPZ00@0okPZ00@000000?nh:@3o^2T00000
0P3oa2`00`000000ol4[0?o1:`030?o1:`030000003o_bX0oklZ00<0oklZ00<000000?nm:@3o_BT0
0`3o_BT00`000000ok/Y0?nk:@020?nk:@030000003o^BP0okTX00<0okTX00<000000?ng:03o]bP0
0P3o]bP500000080MdPC00<000000:1Q6@0000001@3oY2L00`000000onPd0?oX=0020?oX=0800000
00<0onH`0000000000001@2YH1L00`000000[F<H0:eS60040:eS60030000002aIAT0/FDI00@0/FDI
00<000000;MY6@2gJAT00`2gJAT00`000000_VhK0;i^6`040;i^6`0300000038M1`0b7@L00D0b7@L
00<000000?nF903oUR@0103oUR@00`000000oj/X0?n[:0050?n[:0040000003ob2l0olP_000000@0
ooHg00@000000?oo?@3oocd000000`3ooc/00`000000omP]0000000200000080onhb0P00000^08nl
S`40oooo000h08nlS`8000000P3ooc/00`000000oolk0?oo>`020?oo>`060000003oocd0oolm0000
003oocd00000103ooc/010000000SEPG08eH5`0000050<1e7P030000003oVRD0oiXU00L0oiXU00<0
00000?ng:P3o]bX0103o]bX00`000000okPZ0?nh:P040?nh:P030000003o^2T0okPY0080okPY00<0
00000?o4;00000001@3o`B/00`000000oklZ0?no:P030?no:P030000003o_BT0okdY00<0okdY00<0
00000?nk:@3o^bT00P3o^bT00`000000okTX0?ni:0030?ni:0030000003o]bP0okLX0080okLX1@00
000307M84`800000103oY2L00`000000onPd0?oX=0020?oX=0040000003oocL0onH`0?oV<0800000
1@2YH1L00`000000[F<H0:eS60040:eS60030000002aIAT0/FDI00@0/FDI00<000000;MY6@2gJAT0
0`2gJAT00`000000_VhK0;i^6`040;i^6`0300000038M1`0b7@L00<0b7@L0`0000060?nF90030000
003oZbP0oj/X00D0oj/X00<000000?o8;`0000001@3omSL00`000000oolm000000030?oo>`030000
003of2d0omP]008000000`3okS82000002h0Skb?0@3oool003P0Skb?00@00000077GY@0000000000
103ooc/00`000000oolm0?oo?@020?oo?@030000003ooc/0oolk00@0oolk00@0000008eH5`2=F1L0
00001030MAh2000000P0oiXU0P0000050?ng:P030000003o^2X0okPZ00@0okPZ00<000000?nh:@3o
^2T00`3o^2T2000000D0ol4[00<000000?no:P3o_bX00`3o_bX00`000000okdY0?nm:@030?nm:@03
0000003o^bT0ok/Y0080ok/Y00<000000?ni:03o^BP00`3o^BP00`000000okLX0?ng:0020?ng:0<0
000000<07A850000001gB1<00P1gB1<2000000@0oj@W00<000000?oX=03oj3@00P3oj3@200000004
0?oV<0000000YUhG000000D0ZF0G00<000000:eS602]HaP0102]HaP00`000000/FDI0;5U6@040;5U
6@030000002gJAT0]fTI00<0]fTI00<000000;i^6`2nKQ/01@2nKQ/01@000000b7@L0<Qd7038M1`0
00000080k8PP00<000000?nF903oUR@0103oUR@00`000000oj/X0?n[:0050?n[:08000001`3omSL2
000000<0oolk00@000000?oH;@00000000000P3okS84000002h0Skb?0@3oool003T0Skb?0P000004
0?oo>`030000003oocd0oolm0080oolm0P0000060?oo>`8000000P2=F1L01P000000`7DN0<1e7P00
0000d7dO000000L0oiXU00<000000?nS9P0000001@3o]bX00`000000okPZ0?nh:P040?nh:P030000
003o^2T0okPY00@0okPY00<000000?o1:`3o`B/00`3o`B/00`000000oklZ0?no:P030?no:P030000
003o_BT0okdY00<0okdY00<000000?nk:@3o^bT00P3o^bT00`000000okTX0?ni:0030?ni:0030000
003o]bP0okLX0080okLX0`0000000`0M4PD0000007M84`0307M84`030000003oY2L0oj@W0080oj@W
00<000000?oX=03oj3@00P3oj3@01P000000onH`0?oV<0000000YUhG000000D0ZF0G00<000000:eS
602]HaP0102]HaP00`000000/FDI0;5U6@040;5U6@030000002gJAT0]fTI00<0]fTI00<000000;i^
6`2nKQ/01@2nKQ/010000000b7@L0<Qd700000030>b880030000003oUR@0oiHT00@0oiHT00<00000
0?n[:03oZbP01@3oZbP00`000000ooHg0?of=`060?of=`060000003ooc/0oolk0?oo>`000000omP]
0P000000103okS8000000000003oocd2000002l0Skb?0@3oool003T0Skb?0P0000040?oo>`030000
003oocd0oolm0080oolm00<000000?oo?`000000103ooc/010000000oo0g00000000000208eH5`03
00000030MAh000000080d7dO00<000000?nJ9@3oVRD0103oVRD010000000oj<V0?nS9P0000040?ng
:P030000003o^2X0okPZ00@0okPZ00<000000?nh:@3o^2T0103o^2T2000000<0ol4[00<000000?no
:P3o_bX0103o_bX00`000000okdY0?nm:@030?nm:@030000003o^bT0ok/Y0080ok/Y00<000000?ni
:03o^BP00`3o^BP00`000000okLX0?ng:0020?ng:0<0000000<07A850000001gB1<00`1gB1<20000
00<0oj@W00<000000?oX=03oj3@00P3oj3@01P000000onH`0?oV<0000000YUhG000000D0ZF0G00<0
00000:eS602]HaP0102]HaP00`000000/FDI0;5U6@040;5U6@030000002gJAT0]fTI00@0]fTI00<0
00000;i^6`2nKQ/0102nKQ/3000000@0k8PP00<000000?nF903oUR@0103oUR@00`000000oj/X0?n[
:0040?n[:08000001`3omSL200000080oolk00<000000?oH;@3of2d00`0000030?oo?@800000;`2?
_8l10?ooo`00>P2?_8l200000080oolk00<000000?oo?@3oocd00P3oocd010000000oolo0?oo?`00
00030?oo>`050000003ol3L0oo0g0?o`=`0000000P2=F1L2000000@0d7dO00<000000?nJ9@3oVRD0
0`3oVRD01@000000oj<V0?nS9P3oXbH0000000<0okLZ00<000000?nh:P3o^2X0103o^2X00`000000
okPY0?nh:@040?nh:@030000003o^2T000000080ol4[00<000000?no:P3o_bX00`3o_bX00`000000
okdY0?nm:@040?nm:@030000003o^bT0ok/Y0080ok/Y00<000000?ni:03o^BP00`3o^BP00`000000
okLX0?ng:0020?ng:0H000000`1gB1<01P000000oYPU000000000000oj@W00000080onPd0`000002
0?oV<0030000002VGQL0000000D0ZF0G00<000000:eS602]HaP0102]HaP00`000000/FDI0;5U6@04
0;5U6@030000002gJAT0]fTI00@0]fTI00<000000;i^6`2nKQ/0102nKQ/00`000000k8PP0>b88005
0>b880030000003oUR@0oiHT00<0oiHT00<000000?n[:03oZbP00`3oZbP00`000000omPa00000006
0?of=`030000003ooc`000000080oolk00<000000?oH;@0000002000000_08nlS`40oooo000j08nl
S`80000000<0oolk0000003oocd00`3oocd01@000000oolo0?oo?`3oocl000000080oolk00<00000
0?o`=`3ol3L00`3ol3L010000000SEPG08eH5`0000040=1m7`030000003oVRD0oiXU0080oiXU00<0
00000?nS9P3oXbH00`3oXbH010000000okLZ0?ng:P0000060?nh:P030000003o^2T0okPY00@0okPY
00H000000?nh:@3o^2T000000?o1:`0000050?no:P030000003o_BT0okdY00@0okdY00<000000?nk
:@3o^bT00P3o^bT00`000000okTX0?ni:0030?ni:0030000003o]bP0okLX0080okLX1P00000307M8
4`040000003nV2D0oYPU0?jH9@@000000P3omCL01P000000onH`000000000000YUhG000000H0ZF0G
00<000000:eS602]HaP00`2]HaP00`000000/FDI0;5U6@040;5U6@030000002gJAT0]fTI00@0]fTI
00<000000;i^6`2nKQ/00P2nKQ/3000000L0k8PP00<000000?nF903oUR@00`3oUR@00`000000oj/X
0?n[:0020?n[:0050000003of340omPa0?oH<@0000001@3omSL00`000000ooll0?oo?00200000003
0?oH;@000000000000D0ooLj0P00000`08nlS`40oooo000k08nlS`<000000`3oocd00`000000oolo
0?oo?`030?oo?`8000001P3ol3L30000000307A;50000000d7dO00<0d7dO00D000000?nJ9@3oVRD0
oiXU000000050?nS9P030000003o]bX0000000H0okPZ00<000000?nh:@3o^2T0103o^2T00`000000
okPY0?nh:@020?nh:@8000001@3o_bX00`000000okdY0?nm:@040?nm:@030000003o^bT0ok/Y0080
ok/Y00<000000?ni:03o^BP00`3o^BP00`000000okLX0?ng:0020?ng:0H000000`1gB1<00`000000
oYPU0?jH9@020?jH9@030000003omCL0ooDg0080ooDg00<000000?oV<00000000P2VGQL00`000000
ZF0G0:UP5`040:UP5`030000002]HaP0[F<H00<0[F<H00<000000;5U6@2aIAT01@2aIAT00`000000
]fTI0;MY6@030;MY6@030000002nKQ/0_VhK008000000P3LOQh00`000000k8PP0>b880050>b88003
0000003oUR@0oiHT00@0oiHT00@000000?n[:03oZbP00000103of3400`000000ooHg0?of=`020?of
=`040000003ooc`0ooll0?oo?0@0000000<0oj`[0000000000000`3omcX200000300Skb?0@3oool0
03/0Skb?0P0000040?oo?@030000003oocl0oolo00<0oolo00<000000?o`=`3ol3L01P3ol3L20000
000307A;50000000d7dO00@0d7dO00@000000?nJ9@3oVRD000001P3oXbH2000000H0okPZ00<00000
0?nh:@3o^2T0103o^2T00`000000okPY0?nh:@030?nh:@030000003o_bX0oklZ00<0oklZ00<00000
0?nm:@3o_BT0103o_BT00`000000ok/Y0?nk:@020?nk:@030000003o^BP0okTX0080okTX00<00000
0?ng:03o]bP00`3o]bP50000000504T]3@000000MdPC07M84`000000103nV2D00`000000ooDg0?oe
=`020?oe=`030000003oiS00000000<0YUhG00<000000:UP5`2YH1L00`2YH1L00`000000[F<H0:eS
60030:eS60030000002aIAT0/FDI00D0/FDI00<000000;MY6@2gJAT00`2gJAT3000000@0g7hN00<0
00000>b8803/R2001@3/R2000`000000oiHT0?nF90040?nF90030000003oZbP0000000D0omPa00D0
00000?of=`3omSL0ooHg000000040?oo?0030000003of2d0000000@0oj`[00@000000?og>P000000
0000<@2?_8l10?ooo`00?02?_8l01@000000oolm0?oo?@3oocd0000000D0oolo0P0000080?o`=`80
00000P1dBa@00`000000d7dO0=1m7`030=1m7`030000003oVRD0000000L0oj<V00<000000?nh:P3o
^2X0103o^2X00`000000okPY0?nh:@040?nh:@030000003o^2T0okPY00<0okPY0`0000030?no:P03
0000003o_BT0okdY00@0okdY00<000000?nk:@3o^bT00P3o^bT00`000000okTX0?ni:0020?ni:003
0000003o]bP0okLX00<0okLX1@0000001019;@d0000007M84`0000050?jH9@030000003omCL0ooDg
0080ooDg0`0000030:IN5`030000002YH1L0ZF0G00<0ZF0G00<000000:eS602]HaP00`2]HaP00`00
0000/FDI0;5U6@050;5U6@030000002gJAT0]fTI00<0]fTI00<000000=an7P3LOQh0103LOQh00`00
0000k8PP0>b880050>b880030000003oUR@0oiHT00@0oiHT0P0000060?oH<@040000003omSL0ooHg
000000@0ooll0`0000000`3EQ28000000?n/:`040?n/:`800000<@2?_8l10?ooo`00?02?_8l20000
00030?oo?@000000oolo00@0oolo00@000000?oo@03ood0000001`3ol3L01@000000oj4W0000001d
Ba@0000000D0d7dO0P0000080?nS9P8000001@3o^2X00`000000okPY0?nh:@040?nh:@030000003o
^2T0okPY00<0okPY00@000000?ng:@3o]bT000000P3o_bX00`000000okdY0?nm:@030?nm:@030000
003o^bT0ok/Y00<0ok/Y00<000000?ni:03o^BP00P3o^BP00`000000okLX0?ng:0030?ng:0090000
003o]2L0000001@<10000000BBd=0000001gB1<0000000D0oYPU00H000000?oe=`3omCL0ooDg0000
003oiS02000000<0YUhG00<000000:UP5`2YH1L00`2YH1L00`000000[F<H0:eS60040:eS60030000
002aIAT0/FDI00@0/FDI00@000000;MY6@2gJAT0]fTI0`0000070=an7P030000003/R200k8PP00@0
k8PP00<000000?nF903oUR@0103oUR@00`000000omPa0?oH<@060?oH<@030000003omSL0000000<0
ooll00<000000?nh9P0000000`3EQ28010000000oj`[0?n/:`3o[2/200000380Skb?0@3oool003d0
Skb?00<000000?oo?@000000103oocl01@000000oom00?oo@03ood00000000D0oo0g0`0000001@3o
XBL0000007A;501dBa@0000000D0d7dO00<000000?nS9P3oXbH01@3oXbH00`000000ojTW00000005
0?nh:P030000003o^2T0okPY00@0okPY00<000000?nh:@3o^2T00`3o^2T010000000okLY0?ng:@3o
]bT3000000D0okdY00<000000?nk:@3o^bT00`3o^bT00`000000okTX0?ni:0020?ni:0030000003o
]bP0okLX00<0okLX00<000000?nd9`0000000P00000204T]3@8000001@3nV2D01`000000ooDg0?oe
=`3omCL000000?oV<03o/2D0102VGQL00`000000ZF0G0:UP5`030:UP5`030000002]HaP0[F<H00@0
[F<H00<000000;5U6@2aIAT0102aIAT010000000]fTI0;MY6@0000020=1g70030000003LOQh0g7hN
00D0g7hN00<000000>b8803/R200103/R2000`000000oiHT0?nF90030?nF90800000203of3420000
00@0ooll0`0000040=F48P030000003o[2/0oj`[00800000<P2?_8l10?ooo`00?@2?_8l2000000@0
oolo00<000000?oo@03ood000`3ood001@000000oo0g0?o`=`3ol3L0000000<0olP`00D000000?nQ
9`000000M4/D000000040=1m7`030000003QQb80000000H0oj<V00@000000?nY9`3oZBL00000103o
^2X00`000000okPY0?nh:@040?nh:@030000003o^2T0okPY00<0okPY00<000000?ng:@3o]bT00`3o
]bT00`000000okdY0?nm:@030?nm:@030000003o^bT0ok/Y00<0ok/Y00<000000?ni:03o^BP00P3o
^BP00`000000okLX0?ng:0030?ng:0030000003o]2L00000008000000P19;@d2000000D0oYPU00@0
00000?oe=`3omCL0ooDg0`0000040:IN5`030000002YH1L0ZF0G00<0ZF0G00<000000:eS602]HaP0
102]HaP00`000000/FDI0;5U6@040;5U6@<000000`3@Ma`00`000000g7hN0=an7P050=an7P030000
003/R200k8PP00@0k8PP00<000000?nF903oUR@00P3oUR@00`000000okl/000000080?oH<@030000
003ooc`0ooll0080ooll0P0000000`32Mah000000=F48P040=F48P<00000<`2?_8l10?ooo`00?P2?
_8l00`000000oolo0?oo?`020?oo?`030000003ood00oom000<0oom000@000000?o`=`0000000000
103ob3001P000000oj4W0?nQ9`000000M4/D000000<0d7dO00<000000>678P0000001P3oXbH01@00
0000ojTW0?nY9`3oZBL0000000<0okPZ00<000000?nh:@3o^2T0103o^2T00`000000okPY0?nh:@03
0?nh:@030000003o]bT0okLY00<0okLY0P0000040?nm:@030000003o^bT0ok/Y0080ok/Y00<00000
0?ni:03o^BP00`3o^BP00`000000okLX0?ng:0030?ng:0030000003o]2L00000008000000P19;@d2
000000@0oYPU00<000000?oe=`3omCL00P3omCL3000000@0YUhG00<000000:UP5`2YH1L00`2YH1L0
0`000000[F<H0:eS60040:eS60030000002aIAT0/FDI00@0/FDI00<000000=1g703@Ma`00`3@Ma`0
0`000000g7hN0=an7P050=an7P030000003/R200k8PP00D0k8PP00@000000?nF903oUR@000000`3o
_b`00`000000omPa0?oH<@040?oH<@8000000`3ooc`00`000000okPV000000020<9g7P030000003E
Q280eH@R00<0eH@R0P00000c08nlS`40oooo000o08nlS`040000003oocl0oolo000000L0oom000<0
00000?o8<03ob300103ob3001P000000oj4W0?nQ9`000000M4/D00000080d7dO00D000000>678P3Q
Qb80hHLR000000050?nS9P030000003oZBL0ojTW0080ojTW00<000000?nh:P0000001P3o^2T00`00
0000okPY0?nh:@030?nh:@030000003o]bT0okLY00@0okLY00<000000?nf:00000000`3o_BT00`00
0000ok/Y0?nk:@020?nk:@030000003o^BP0okTX00<0okTX00<000000?ng:03o]bP00`3o]bP00`00
0000ok@W0000000300000080BBd=00<000000?jH9@3nV2D00P3nV2D00`000000ooDg0?oe=`020?oe
=`030000003o/2D0000000@0YUhG00<000000:UP5`2YH1L00`2YH1L00`000000[F<H0:eS60040:eS
60030000002aIAT0/FDI0080/FDI0`0000050=1g70030000003LOQh0g7hN00D0g7hN00<000000>b8
803/R2001@3/R20010000000oiHT0?nF900000030?no;0030000003of340omPa00<0omPa00<00000
0?oo?00000000P3ooc`00`000000okPV000000040<9g7P040000003EQ280eH@R0=F48P800000=02?
_8l10?ooo`00?`2?_8l00`000000oolo000000070?oo@08000001`3ob30020000000oj4W0?nQ9`00
0000M4/D0000003@OAl000000`3QQb800`000000oj<V0?nS9P020?nS9P030000003oZBL0ojTW00<0
ojTW00<000000?nh:P0000001P3o^2T00`000000okPY0?nh:@030?nh:@030000003o]bT0okLY00@0
okLY00<000000?nf:03o]RP00P0000000`3o_BT000000?nk:@030?nk:@030000003o^BP0okTX00<0
okTX00<000000?ng:03o]bP00`3o]bP00`000000ok@W0000000300000080BBd=00<000000?jH9@3n
V2D00P3nV2D00`000000ooDg0?oe=`020?oe=`<00000102VGQL00`000000ZF0G0:UP5`030:UP5`03
0000002]HaP0[F<H00@0[F<H00<000000;5U6@2aIAT00P0000020<Ia6`030000003@Ma`0d7LL00@0
d7LL00<000000=an7P3LOQh0103LOQh00`000000k8PP0>b880050>b880030000003oUR@0000000@0
okl/00<000000?oH<@3of3400`3of3401@000000ooll0?oo?0000000ooll00<000001@32Mah00`00
0000eH@R00000002000003@0Skb?0@3oool00400Skb?00<000000?oo@03ood001@3ood0010000000
ooLj0?og>P0000060?o8<0050000003oXBL0oj4W0000001dBa@00P0000050>678P050000003oXbH0
oj<V0?nS9P0000001P3oZBL2000000H0okPY00<000000?nh:@3o^2T00`3o^2T00`000000okLY0?ng
:@040?ng:@030000003o]RP0okHX0080okHX0P0000040?nk:@030000003o^BP0okTX00<0okTX00<0
00000?ng:03o]bP00`3o]bP00`000000ok@W0000000300000080BBd=0P0000030?jH9@040000003o
mCL0ooDg0?oe=`<000001@2VGQL00`000000ZF0G0:UP5`030:UP5`030000002]HaP0[F<H00@0[F<H
0`0000040<Ia6`030000003@Ma`0d7LL00@0d7LL00<000000=an7P3LOQh0103LOQh00`000000k8PP
0>b880050>b8808000001@3o_b`00`000000omPa0?oH<@020?oH<@040000003ooc`0ooll0?oo?0<0
000000<0`gLN00000032Mah01032Mah010000000eH@R00000000000e08nlS`40oooo001108nlS`03
0000003ood00oom00080oom00P0000030?og>P030000003ob300olP`00@0olP`00@000000?nQ9`3o
XBL0oj4W0`0000060>678P040000003oXbH0oj<V000000L0ojTW00<000000?nh:@3o^2T0103o^2T0
0`000000okPY0?nh:@030?nh:@030000003o]bT0okLY00@0okLY00<000000?nf:03o]RP00`3o]RP0
0`000000ok/Y0?nk:@020?nk:@030000003o^BP0okTX00<0okTX00<000000?ng:03o]bP00`3o]bP0
0`000000ok@W0000000300000080BBd=00L000000>:88P00000000000?jH9@000000ooDg00800000
00<0ooli0000000000001@2VGQL00`000000ZF0G0:UP5`030:UP5`030000002]HaP0[F<H00<0[F<H
0P0000060<Ia6`030000003@Ma`0d7LL00@0d7LL00<000000=an7P3LOQh0103LOQh00`000000k8PP
0>b880050>b880030000003o_b`0okl/00@0okl/00D000000?oH<@3of340omPa000000040?oo?003
0000003o^2H000000080`gLN00<000000<9g7P32Mah00`32Mah2000003H0Skb?0@3oool00480Skb?
0P0000000`3ood0000000?og>P050?og>P030000003ob300olP`00@0olP`00L000000?nQ9`3oXBL0
oj4W0000001A=Pl0000000D0hHLR00@000000?nS9P3oXbH000001`3oZBL2000000D0okPY00<00000
0?nh:@3o^2T00`3o^2T00`000000okLY0?ng:@040?ng:@030000003o]RP0okHX00<0okHX0`000002
0?nk:@030000003o^BP0okTX00<0okTX00<000000?ng:03o]bP00`3o]bP00`000000ok@W0?nd9`02
0000000402/J20000000BBd=000000<0hXPR0`0000020?oo>@030000003o/2D0000000D0YUhG00<0
00000:UP5`2YH1L00`2YH1L010000000[F<H0:eS602]HaP2000000030;m]6P000000aW4K00D0aW4K
00<000000=1g703@Ma`0103@Ma`00`000000g7hN0=an7P040=an7P030000003/R200k8PP00@0k8PP
0P0000060?no;0040000003of340omPa000000@0ooll0`0000030<=g7P0300000032Mah0`WLN0080
`WLN0P00000g08nlS`40oooo001308nlS`8000001`3omcX00`000000olP`0?o8<0030?o8<0D00000
00<0aWTO0000000000001P3QQb82000000P0ojTW00<000000?n]:0000000103o^2T00`000000okPY
0?nh:@030?nh:@030000003o]bT0okLY00<0okLY00<000000?nf:03o]RP0103o]RP00`000000okDX
0?ne:003000000D0okTX00<000000?ng:03o]bP00`3o]bP00`000000ok@W0?nd9`020000000402/J
20000000BBd=000000@0hXPR00@000000?oo>@3oocT0ooli0`0000050:IN5`030000002YH1L0ZF0G
00<0ZF0G00@000000:eS6000000000000`2oKAX00`000000aW4K0<Ia6`040<Ia6`030000003@Ma`0
d7LL00@0d7LL00<000000=an7P3LOQh0103LOQh00`000000k8PP0>b880030>b880030000003oZbP0
000000L0okl/00<000000?oH<@000000103ooc`3000000@0`gLN00<000000<9g7P32Mah00P00000h
08nlS`40oooo001408nlS`8000001`3omcX00`000000olP`00000002000000030=N78`000000aWTO
00<0aWTO00<00000054f3`0000001@3QQb82000000L0ojTW00D000000?n]:03o[BP0ojdX00000003
0?nh:@030000003o^2T0okPY00<0okPY00<000000?ng:@3o]bT00`3o]bT00`000000okHX0?nf:004
0?nf:0030000003o]BP0okDX0080okDX00<000000?ni:03o^BP00`3o^BP00`000000okLX0?ng:003
0?ng:0030000003o]2L0ok@W0080000000@0:aX800000019;@d00000103RR28010000000ooli0?oo
>@3oocT2000000H0YUhG00<000000:UP5`2YH1L00`2YH1L2000000D0_fdJ00<000000<Ia6`36LA/0
1036LA/00`000000d7LL0=1g70040=1g70030000003LOQh0g7hN00D0g7hN00D000000>b8803/R200
k8PP000000020?n[:0030000003o_b`0okl/00D0okl/0P0000040?oo?0050000003`Ub00dX0P0=:0
800000000`33Mah010000000`WLN00000000000i08nlS`40oooo001508nlS`030000003omcX0ooLj
00@0ooLj0`0000050=N78`0300000036NAl0aWTO0080aWTO0P0000060>678P030000003oZBL0ojTW
00D0ojTW00D000000?n]:03o[BP0ojdX000000020?nh:@030000003o^2T0okPY00@0okPY00<00000
0?ng:@3o]bT00`3o]bT00`000000okHX0?nf:0040?nf:0030000003o]BP0okDX0080okDX0`000003
0?ni:0030000003o]bP0okLX00<0okLX00<000000?nd9`3o]2L00P00000202/J20800000103RR280
10000000ooli0?oo>@3oocT2000000H0YUhG00@000000:UP5`2YH1L0ZF0G0`0000060;m]6P030000
0036LA/0aW4K00@0aW4K00<000000=1g703@Ma`0103@Ma`00`000000g7hN0=an7P050=an7P040000
003/R200k8PP000000<0oj/X00<000000?no;03o_b`01@3o_b`00`000000ooll0?oo?0020?oo?003
0000003`Ub00dX0P0080dX0P00<000000<=g7P33Mah00P33Mah2000003X0Skb?0@3oool004H0Skb?
00<000000?og>P3omcX00`00000209QU6@030000003GQb<0ehLS00<0ehLS00<000000<Ii7`36NAl0
0`36NAl2000000@0hHLR00<000000?BA900000001P3oZBL00`000000ojdX0?n]:0020?n]:0030000
003o^2T0000000H0okPY00<000000?ng:@3o]bT00`3o]bT00`000000okHX0?nf:0040?nf:0030000
003o]BP0okDX0080okDX00@000000?nc:03o/bP000000P3o^BP00`000000okLX0?ng:0030?ng:003
0000003o]2L0ok@W008000000P0[6PP2000000@0hXPR00H000000?oo>@3oocT0ooli0000003FPQ/6
0:IN5`040000002YH1L0000000000080^FTI00<000000;m]6P2oKAX0102oKAX00`000000aW4K0<Ia
6`040<Ia6`030000003@Ma`0d7LL00@0d7LL00<000000=an7P3LOQh01@3LOQh00`000000k8PP0000
00040?n[:0030000003o_b`0okl/00@0okl/0P0000030?oo?0030000003`Ub00000000@0dX0P00<0
00000<=g7P33Mah00P00000k08nlS`40oooo001708nlS`8000001@2HIAT00`000000ehLS0=N78`03
0=N78`0300000036NAl0aWTO00<0aWTO0`0000030>678P030000003dTB@0000000H0ojTW00<00000
0?n]:03o[BP00`3o[BP2000000H0okPY00<000000?ng:@3o]bT00`3o]bT00`000000okHX0?nf:004
0?nf:0030000003o]BP0okDX0080okDX00@000000?nc:03o/bP0ok<X0`0000050?ng:0030000003o
]2L0ok@W00<0000000<0:aX8000000000000103RR28010000000ooli0?oo>@3oocT2000000D0YUhG
0`0000040;UY6@030000002oKAX0_fdJ00@0_fdJ00<000000<Ia6`36LA/01036LA/00`000000d7LL
0=1g70040=1g70030000003LOQh0g7hN00D0g7hN0P0000050?n[:0030000003o_b`0okl/00<0okl/
00<000000?oo>P0000000`3ooc`2000000D0dX0P00@000000<=g7P0000000000?02?_8l10?ooo`00
B02?_8l00`000000V6DI09QU6@0409QU6@030000003GQb<0ehLS0080ehLS00<000000<Ii7`36NAl0
0`36NAl300000080hHLR00D000000?BA903dTB@0m94T000000040?nY9`030000003o[BP0ojdX00D0
ojdX00<000000?nh:@3o^2T0103o^2T00`000000okLY0?ng:@030?ng:@030000003o]RP0okHX00<0
okHX00<000000?ne:03o]BP00`3o]BP00`000000ok<X0?nc:0030?nc:0030000003o]bP0okLX00<0
okLX00<000000?nd9`3o]2L00`0000000`0[6PP00000000000040>:88P030000003oocT0ooli00<0
00000`2VGQL2000000030;AV60000000^FTI00@0^FTI00<000000;m]6P2oKAX01@2oKAX00`000000
aW4K0<Ia6`030<Ia6`030000003@Ma`0d7LL00@0d7LL00<000000=an7P3LOQh01@3LOQh00`000000
oj/X0?n[:0050?n[:0030000003o_b`0okl/0080okl/00<000000?oo>P0000000P3ooc`3000000H0
dX0P0P00000m08nlS`40oooo001908nlS`800000102HIAT00`000000ehLS0=N78`030=N78`030000
0036NAl0aWTO0080aWTO00H000000;Q^7000000000000>678P0000030?BA90030000003oZBL0ojTW
0080ojTW00<000000?n]:03o[BP01@3o[BP2000000D0okPY00<000000?ng:@3o]bT00`3o]bT00`00
0000okHX0?nf:0030?nf:0030000003o]BP0okDX00<0okDX00<000000?nc:03o/bP00`3o/bP30000
00<0okLX00<000000?nd9`3o]2L00`00000202/J20050000003RR280hXPR0>:88P0000000`3oocT0
10000000eX8K0000002VGQL2000000<0]6HH00<000000;UY6@2iJAT00`2iJAT00`000000_fdJ0;m]
6P050;m]6P0300000036LA/0aW4K00@0aW4K00<000000=1g703@Ma`00`3@Ma`00`000000g7hN0=an
7P040=an7P8000001`3oZbP01@000000okl/0?no;03o_b`0000000<0oolj0`0000000`3bU2D00000
0=:080040=:080800000?P2?_8l10?ooo`00B`2?_8l2000000<0V6DI00<000000=N78`3GQb<00P3G
Qb<00`000000aWTO0<Ii7`020<Ii7`030000002hKQ`0^6hL008000001@3dTB@01@000000ojTW0?nY
9`3oZBL0000000L0ojdX00<000000?n`:00000000`3o^2T00`000000okLY0?ng:@040?ng:@030000
003o]RP0okHX00<0okHX00<000000?ne:03o]BP00`3o]BP00`000000ok<X0?nc:0030?nc:0030000
003o/RL0ok8W0080000000@0okLX0000003o]2L0ok@W0`00000202/J20050000003RR280hXPR0>:8
8P0000000`3oocT010000000eX8K0000000000050;AV60030000002iJAT0^FTI00<0^FTI00<00000
0;m]6P2oKAX01@2oKAX00`000000aW4K0<Ia6`040<Ia6`030000003@Ma`0d7LL00@0d7LL00<00000
0=an7P3LOQh00P3LOQh00`000000oi/T000000070?n[:0040000003o_b`0okl/000000@0oolj0`00
00020?:D9@030000003BP200dX0P00<00000?`2?_8l10?ooo`00C02?_8l30000000309QU6@000000
ehLS00<0ehLS00<000000<Ii7`36NAl00P36NAl01@000000^6hL0;Q^702hKQ`0000000H0m94T00@0
00000?nY9`3oZBL000001P3o[BP01@000000ok0X0?n`:03o/2P000000080okPY00<000000?ng:@3o
]bT0103o]bT00`000000okHX0?nf:0030?nf:0030000003o]BP0okDX00<0okDX00<000000?nc:03o
/bP00`3o/bP00`000000ok8W0?nb9`020?nb9`8000000P3o]2L20000000302<E1P000000:aX80080
00000P3RR2800`000000ooli0?oo>@04000000H0]6HH00<000000;UY6@2iJAT0102iJAT00`000000
_fdJ0;m]6P040;m]6P0300000036LA/0aW4K00@0aW4K00<000000=1g703@Ma`0103@Ma`01@000000
g7hN0=an7P3LOQh000000080oi/T00<000000?n[:03oZbP01@3oZbP00`000000okl/000000050?oo
>P8000000`3bU2D00`000000dX0P0000000200000400Skb?0@3oool004d0Skb?0P0000000`106`H0
00000000000200000080ehLS00<000000<Ii7`36NAl00P36NAl00`000000^6hL0;Q^7002000000D0
m94T00@000000?nY9`3oZBL000001P3o[BP01@000000ok0X0?n`:03o/2P000000080okPY00<00000
0?ng:@3o]bT0103o]bT00`000000okHX0?nf:0030?nf:0030000003o]BP0okDX00<0okDX00<00000
0?nc:03o/bP00`3o/bP00`000000ok8W0?nb9`030?nb9`D0000000/08aD60000000[6PP000000<5e
7P000000hXPR0000003oocT000000?oo>P03000000H0]6HH00<000000;UY6@2iJAT0102iJAT00`00
0000_fdJ0;m]6P040;m]6P0300000036LA/0aW4K00@0aW4K00<000000=1g703@Ma`0103@Ma`01000
0000g7hN0=an7P0000040?nK90030000003oZbP0oj/X00@0oj/X00<000000?no;0000000103oocX0
0`000000bX0K0?:D9@040?:D9@800000@P2?_8l10?ooo`00C`2?_8l00`000000@1/6040K1P0204dc
3P@000000`36NAl01@000000^6hL0;Q^702hKQ`0000000H0m94T0P0000070?n]:0030000003o/2P0
ok0X0080ok0X00<000000?nh:@0000001P3o]bT00`000000okHX0?nf:0030?nf:0030000003o]BP0
okDX00<0okDX00<000000?nc:03o/bP00`3o/bP00`000000ok8W0?nb9`030?nb9`030000003o/2L0
ok0W0080000000h08aD60000000[6PP000000<5e7P000000hXPR0000003oocT000000?oo>P000000
/6<H000000H0]6HH00<000000;UY6@2iJAT0102iJAT00`000000_fdJ0;m]6P040;m]6P0300000036
LA/0aW4K00@0aW4K00<000000=1g703@Ma`0103@Ma`00`000000g7hN000000050?nK90030000003o
ZbP0oj/X00@0oj/X0P0000050?oo>P800000103bU2D00`000000Skb?08nlS`1208nlS`40oooo001@
08nlS`03000000106`H0000000<0CC<>00H0000007Q<5000000000000<Ii7`0000040;Q^70030000
003dTB@0m94T00<0m94T0P0000070?n]:0030000003o/2P0ok0X00<0ok0X0P0000060?ng:@030000
003o]RP0okHX00<0okHX00<000000?ne:03o]BP00`3o]BP00`000000ok<X0?nc:0030?nc:0030000
003o/RL0ok8W00<0ok8W00T000000?n`9`3o/2L0ok0W0000000S5@H0000002/J200000000P31MAh3
00000080oolj00<000000;1S600000001P2dIQP00`000000^FTI0;UY6@040;UY6@030000002oKAX0
_fdJ00@0_fdJ00<000000<Ia6`36LA/01036LA/00`000000d7LL0=1g70040=1g708000001P3oVb@0
0`000000oj/X0?n[:0040?n[:0030000003oocX0oolj00<0oolj00D000000?nj;P3o^Rh000000?:D
9@02000004D0Skb?0@3oool00540Skb?00<00000040K1P0000000`1=<`h00`000000N4`D07Q<5004
00000080^6hL0P0000050?BA90030000003o[BP0ojdX00D0ojdX00<000000?n`:03o/2P0103o/2P0
0`000000okLY0?ng:@030?ng:@030000003o]RP0okHX00@0okHX00<000000?ne:03o]BP00`3o]BP0
0`000000ok<X0?nc:0030?nc:0030000003o/RL0ok8W00<0ok8W00D000000?n`9`3o/2L0ok0W0000
000202<E1P8000000`31MAh01`000000oolj0?oo>P000000eX8K0;1S600000001P2dIQP00`000000
^FTI0;UY6@040;UY6@030000002oKAX0_fdJ00@0_fdJ00<000000<Ia6`36LA/01036LA/00`000000
d7LL0=1g70040=1g70030000003oVb@0oi/T00D0oi/T00<000000?n[:03oZbP00`3oZbP2000000@0
oolj00<000000?nj;P3o^Rh00P3o^Rh00`000000Skb?08nlS`1508nlS`40oooo001B08nlS`030000
00106`H000000080CC<>00D0000007Q<501hC1@0N4`D0000000208YD5P@000001@3dTB@2000000D0
ojdX00<000000?n`:03o/2P01@3o/2P2000000@0okLY00<000000?nf:03o]RP0103o]RP00`000000
okDX0?ne:0030?ne:0030000003o/bP0ok<X00<0ok<X00<000000?nb9`3o/RL00`3o/RL010000000
ok0W0?n`9`3o/2L20000000302<E1P000000000000<0`GDN00<000000?oo>P3oocX00P0000000`2`
HaP000000;AV60050;AV60030000002iJAT0^FTI00@0^FTI00<000000;m]6P2oKAX0102oKAX00`00
0000aW4K0<Ia6`040<Ia6`030000003@Ma`0d7LL0080d7LL0`0000070?nK90030000003oZbP0oj/X
0080oj/X00@000000?oj>03onSP000000`3oocX00`000000okX^0?nj;P02000004P0Skb?0@3oool0
05@0Skb?00D0000004dc3P1=<`h0CC<>0000000307Q<50030000002:E1H0RU@F0080RU@F0P000003
0?BA90030000003oVbD0000000D0ojdX00<000000?n`:03o/2P01@3o/2P00`000000ok4X00000003
0?ng:@030000003o]RP0okHX00@0okHX00<000000?ne:03o]BP00`3o]BP00`000000ok<X0?nc:003
0?nc:0030000003o/RL0ok8W00<0ok8W00@000000?n`9`3o/2L0ok0W0P0000000`0S5@H000000000
00030<5e7P030000003oocX0oolj0080000000<0/6<H0000002dIQP01@2dIQP00`000000^FTI0;UY
6@040;UY6@030000002oKAX0_fdJ00@0_fdJ00<000000<Ia6`36LA/01036LA/01@000000d7LL0=1g
703@Ma`000000080n8hQ00<000000?nK903oVb@01@3oVb@00`000000oj/X0?n[:0020?n[:0040000
003onSP0ooXh00000080oolj00@000000?nj;P0000000000BP2?_8l10?ooo`00E@2?_8l010000000
CC<>04dc3P00000307Q<50030000002:E1H0RU@F0080RU@F0`0000020?BA90040000003oVbD0oi/U
000000@0ojdX00<000000?n`:03o/2P01@3o/2P010000000ok4X0?na:00000020?ng:@030000003o
]RP0okHX00@0okHX00<000000?ne:03o]BP00P3o]BP00`000000ok<X0?nc:0040?nc:0030000003o
/RL0ok8W00<0ok8W00@000000?n`9`3o/2L0ok0W0P0000000`0S5@H00000000000030<5e7P040000
003oocX0oolj00000080/6<H00<000000;AV602dIQP0102dIQP00`000000^FTI0;UY6@040;UY6@03
0000002oKAX0_fdJ00@0_fdJ00<000000<Ia6`36LA/01036LA/010000000d7LL0=1g700000030?R>
8@030000003oVb@0oi/T00D0oi/T00D000000?n[:03oZbP0oj/X000000030?oj>0030000003oocX0
000000800000C02?_8l10?ooo`00EP2?_8l010000000CC<>04dc3P00000207Q<50030000002:E1H0
RU@F00<0RU@F0`0000000`3dTB@000000?nK9@020?nK9@050000003o[BP0ojdX0?n]:00000001`3o
/2P01`000000ok4X0?na:03o/BP000000?ng:@0000001P3o]RP00`000000okDX0?ne:0020?ne:003
0000003o/bP0ok<X00@0ok<X00<000000?nb9`3o/RL00`3o/RL010000000ok0W0?n`9`3o/2L20000
00808aD600D000000<5e7P31MAh0`GDN000000020?oo>P040000002`HaP0/6<H000000H0]6HH00<0
00000;UY6@2iJAT0102iJAT00`000000_fdJ0;m]6P040;m]6P0300000036LA/0aW4K00@0aW4K0`00
00050?R>8@030000003oVb@0oi/T00D0oi/T00<000000?n[:00000001@3onSP2000004h0Skb?0@3o
ool005L0Skb?0`00000307Q<50030000002:E1H0RU@F0080RU@F00@0000008iE5P00000000001@3o
VbD010000000ojdX0?n]:00000060?n`:0030000003o/BP0ok4X00<0ok4X0P0000060?nf:0030000
003o]BP0okDX0080okDX00<000000?nc:03o/bP0103o/bP00`000000ok8W0?nb9`030?nb9`040000
003o/2L0ok0W0?n`9`8000000P0S5@H010000000`GDN0<5e7P0000030?oo>P040000002`HaP0/6<H
000000H0]6HH00<000000;UY6@2iJAT0102iJAT00`000000_fdJ0;m]6P050;m]6P0300000036LA/0
aW4K00<0aW4K00<000000?R>8@3hSR401@3hSR400`000000oi/T0?nK90050?nK908000001P3onSP0
0`000000Skb?08nlS`1=08nlS`40oooo001H08nlS`0305h_2@00000000000080N4`D00<0000008YD
5P2:E1H00P2:E1H010000000SUDF08iE5P0000050?nK9@030000003o[BP0000000L0ok0X00<00000
0?na:03o/BP0103o/BP00`000000okHX0?nf:0030?nf:0030000003o]BP0okDX00<0okDX00<00000
0?nc:03o/bP0103o/bP00`000000ok8W0?nb9`030?nb9`040000003o/2L0ok0W0?n`9`8000000P0S
5@H2000000040<5e7P000000oolj0?oo>P8000000P2`HaP00`000000]6HH0;AV60050;AV60030000
002iJAT0^FTI00<0^FTI00<000000;m]6P2oKAX01@2oKAX00`000000aW4K0<Ia6`020<Ia6`800000
1`3hSR400`000000oi/T0?nK90050?nK908000001@3onSP00`000000Skb?08nlS`1>08nlS`40oooo
001I08nlS`0305h_2@000000N4`D0080N4`D00D0000008YD5P2:E1H0RU@F0000000308iE5P030000
003oVbD0oi/U00<0oi/U0P0000070?n`:0030000003o/BP0ok4X00@0ok4X0P0000040?nf:0030000
003o]BP0okDX00<0okDX00<000000?nc:03o/bP00`3o/bP00`000000ok8W0?nb9`040?nb9`080000
003o/2L0ok0W0?n`9`0000006Q050000000S5@H2000000060<5e7P000000oolj0000003oocL00000
0P2`HaP00`000000]6HH0;AV60050;AV60030000002iJAT0^FTI00<0^FTI00<000000;m]6P2oKAX0
1@2oKAX01`000000aW4K0<Ia6`36LA/000000>N47`0000001`3hSR400`000000oi/T0?nK90050?nK
90030000003onSP0ooXh00<0ooXh00<0000008nlS`2?_8l0C`2?_8l10?ooo`00FP2?_8l01@1N;`T0
000007Q<501hC1@0000000<0RU@F00@0000008iE5P2>EAH0SUDF0P0000050?nK9@030000003o/2P0
ok0X00D0ok0X00<000000?na:03o/BP0103o/BP00`000000ok4X000000030?nf:0030000003o]BP0
okDX00<0okDX00<000000?nc:03o/bP00`3o/bP00`000000ok8W0?nb9`040?nb9`0:0000003o/2L0
ok0W0?n`9`0000006Q050000000S5@H0000009iP6@80000000<0oolj0000000000000`2`HaP00`00
0000]6HH0;AV60050;AV60030000002iJAT0^FTI00<0^FTI00<000000;m]6P2oKAX01@2oKAX01000
0000aW4K0<Ia6`0000020>N47`030000003hSR40n8hQ00D0n8hQ00<000000?nK903oVb@0103oVb@2
000000D0ooXh00<0000008nlS`2?_8l0C`2?_8l10?ooo`00F`2?_8l4000000@0RU@F00D0000008iE
5P2>EAH0SUDF000000050?nK9@8000001P3o/2P00`000000ok4X0?na:0040?na:0040000003o/BP0
ok4X00000080okHX00<000000?ne:03o]BP00`3o]BP00`000000ok<X0?nc:0030?nc:0030000003o
/RL0ok8W00@0ok8W00<000000?n`9`3o/2L00P3o/2L20000000302<E1P000000WV0I00<0000000<0
oolg0000002`HaP00`2`HaP00`000000]6HH0;AV60040;AV60030000002iJAT0^FTI00@0^FTI00<0
00000;m]6P2oKAX0102oKAX00`000000aW4K000000030>N47`030000003hSR40n8hQ00D0n8hQ00<0
00000?nK903oVb@00`3oVb@00`000000onLd000000040?oj>0030000002?_8l0Skb?0500Skb?0@3o
ool005`0Skb?0P0/6`P2000000<0RU@F00@0000008iE5P2>EAH0SUDF0P0000040?nK9@030000003o
YBL0000000D0ok0X00<000000?na:03o/BP0103o/BP01`000000ok4X0?na:03o/BP000000?nf:000
00001@3o]BP00`000000ok<X0?nc:0030?nc:0030000003o/RL0ok8W00<0ok8W00<000000?n`9`3o
/2L00`3o/2L3000000<0WV0I00@000000?oo=`3oocL00000102`HaP00`000000]6HH0;AV60040;AV
60030000002iJAT0^FTI00@0^FTI00<000000;m]6P2oKAX0102oKAX2000000D0ih@O00<000000?R>
8@3hSR40103hSR400`000000oi/T0?nK90020?nK90040000003oic@0onLd000000<0ooXh00<00000
08nlS`2?_8l0D@2?_8l10?ooo`00G@2?_8l202`K20050000002:E1H0RU@F08YD5P000000102>EAH2
000000<0oi/U00<000000?nU9`0000001@3o/2P00`000000ok4X0?na:0030?na:0030000003o/BP0
ok4X00<0ok4X0P0000050?ne:0030000003o/bP0ok<X00<0ok<X00<000000?nb9`3o/RL00`3o/RL0
0`000000ok0W0?n`9`030?n`9`<000000`2NH1T010000000oolg0?oo=`0000040;1S60030000002d
IQP0]6HH00@0]6HH00<000000;UY6@2iJAT0102iJAT00`000000_fdJ0;m]6P040;m]6P030000003W
Q1l0ih@O00@0ih@O00<000000?R>8@3hSR40103hSR401@000000oi/T0?nK903oVb@0000000@0onLd
00<000000?oj>0000000E02?_8l10?ooo`00G@2?_8l010000000;1/800000000000208YD5P030000
002>EAH0SUDF0080SUDF00D0000008mE5P000000oi/U000000030?nU9`030000003o/2P0ok0X0080
ok0X00<000000?na:03o/BP00`3o/BP00`000000ok4X0?na:0040?na:0030000003o]BP0okDX00<0
okDX00<000000?nc:03o/bP00`3o/bP00`000000ok8W0?nb9`030?nb9`030000003o/2L0ok0W00<0
ok0W00<0000001X@1@0000000`2NH1T010000000oolg0?oo=`0000040;1S60030000002dIQP0]6HH
00@0]6HH00<000000;UY6@2iJAT0102iJAT00`000000_fdJ0;m]6P020;m]6P<000001P3WQ1l00`00
0000n8hQ0?R>8@050?R>8@040000003oVb@0oi/T000000@0onLd00<000000?oj>0000000E02?_8l1
0?ooo`00GP2?_8l202`K20<0000000<0RU@F0000002>EAH00P2>EAH01@000000SeDF0000003oVbD0
000000@0ojDW00@000000?n`:03o/2P000001P3o/BP00`000000ok4X0?na:0040?na:0800000103o
]BP00`000000ok<X0?nc:0030?nc:0030000003o/RL0ok8W00<0ok8W00<000000?n`9`3o/2L00`3o
/2L00`0000006Q050000000309iP6@030000003oocL0000000D0/6<H00<000000;AV602dIQP0102d
IQP00`000000^FTI0;UY6@040;UY6@030000002oKAX0_fdJ008000000P3JO1d00`000000ih@O0>N4
7`040>N47`030000003hSR40n8hQ00D0n8hQ00<000000?nK900000001@3oic@2000005D0Skb?0@3o
ool005l0Skb?00@0;1/80000000n:0`0?RP<0P00000308iE5P030000002?EAH0SeDF008000001@3o
YBL00`000000ok0X000000060?na:0030000003o/BP0ok4X00@0ok4X00<000000?na9`0000000`3o
]BP00`000000ok<X0?nc:0030?nc:0030000003o/RL0ok8W00<0ok8W00<000000?n`9`3o/2L00`3o
/2L00`0000006Q050000000309iP6@030000003oocL0000000D0/6<H00<000000;AV602dIQP0102d
IQP00`000000^FTI0;UY6@040;UY6@<00000103JO1d00`000000ih@O0>N47`040>N47`030000003h
SR40n8hQ00D0n8hQ0P0000060?oW=0030000002?_8l0Skb?05@0Skb?0@3oool005l0Skb?0P000003
03hX30050000002>EAH0SUDF08iE5P0000000`2?EAH00`000000ojDW0?nU9`030?nU9`030000003o
/2P0000000H0ok4X00<000000?na:03o/BP0103o/BP00`000000ok4W0?na9`02000000030?ne:000
0000ok<X00@0ok<X00<000000?nb9`3o/RL00`3o/RL00`000000ok0W0?n`9`030?n`9`<000000P2N
H1T010000000oolg0?oo=`0000050;1S60030000002dIQP0]6HH00@0]6HH00<000000;UY6@2iJAT0
102iJAT00`000000fW`M0=Yl7@040=Yl7@030000003WQ1l0ih@O00@0ih@O00<000000?R>8@3hSR40
1@3hSR400`000000onLd0?oW=0040?oW=0030000002?_8l0Skb?05D0Skb?0@3oool00600Skb?00@0
;1/80000000n:0`0?RP<0`00000208iE5P050000002?EAH0SeDF08mE5P0000001@3oYBL2000000H0
ok4X00<000000?na:03o/BP0103o/BP00`000000ok4W0?na9`020?na9`8000001@3o/bP00`000000
ok8W0?nb9`030?nb9`030000003o/2L0ok0W00<0ok0W100000000`2NH1T000000?oo=`02000000D0
/6<H00<000000;AV602dIQP0102dIQP00`000000^FTI0;UY6@020;UY6@<000001P3JO1d00`000000
ih@O0>N47`040>N47`030000003hSR40n8hQ00@0n8hQ0P0000050?oW=0030000002?_8l0Skb?05H0
Skb?0@3oool00640Skb?00H0000003hX300n:0`0?RP<0000001J>@l3000000<0SeDF00<000000?nU
9`3oYBL0103oYBL00`000000ok4X0?na:0040?na:0030000003o/BP0ok4X00@0ok4X00<000000?na
9`3o/BL00`3o/BL00`000000ok<X0?nc:0030?nc:0030000003o/RL0ok8W00<0ok8W00<000000?n`
9`3o/2L00`3o/2L40000000309iP6@000000oolg008000001@2`HaP00`000000]6HH0;AV60040;AV
60030000002iJAT0^FTI008000000P3?MQ`00`000000fW`M0=Yl7@040=Yl7@030000003WQ1l0ih@O
00@0ih@O00<000000?R>8@3hSR400`3hSR400`000000om8`000000040?oW=0030000002?_8l0Skb?
05L0Skb?0@3oool00640Skb?0P00000203hX30050000001J>@l0FST?05Xi3`000000102?EAH00`00
0000ojDW0?nU9`030?nU9`8000001@3o/BP00`000000ok4X0?na:0040?na:0030000003o/BL0ok4W
00<0ok4W0`0000030?nc:0030000003o/RL0ok8W00<0ok8W00<000000?n`9`3o/2L00`3o/2L30000
000607M84`00000000000000003ofRh000001@2`HaP00`000000]6HH0;AV60040;AV60<00000103?
MQ`00`000000fW`M0=Yl7@040=Yl7@030000003WQ1l0ih@O00D0ih@O00D000000?R>8@3hSR40n8hQ
000000020?oB<0050000003oic@0onLd0?oW=0000000FP2?_8l10?ooo`00HP2?_8l010000000?RP<
03hX3000000305Xi3`<000000P2?EAH2000000<0ojDW00@000000?n/:03o[2P00000103o/BP00`00
0000ok4X0?na:0040?na:0030000003o/BL0ok4W00<0ok4W00@000000?n_9`3o[bL000000P3o/bP0
0`000000ok8W0?nb9`030?nb9`030000003o/2L0ok0W00<0ok0W0`0000000`1gB1<0000000000002
000000H0/6<H00<000000;AV602dIQP00`2dIQP2000000H0cgHL00<000000=Yl7@3JO1d0103JO1d0
0`000000ih@O0>N47`050>N47`040000003hSR40n8hQ000000@0om8`00@000000?oW=03oic@00000
FP2?_8l10?ooo`00H`2?_8l00`000000?RP<0000000305Xi3`030000001`A180L4@B00<0000000D0
Se@E0000003oYBL0ojDW000000030?n/:0040000003o/BP0ok4X000000L0ok4X00<000000?na9`3o
/BL00`3o/BL010000000ojlW0?n_9`3o[bL3000000D0ok8W00<000000?n`9`3o/2L00`3o/2L30000
0080MdPC00<000000?oJ;P0000001P2`HaP010000000]6HH0;AV602dIQP2000000030<I`6`000000
cgHL00D0cgHL00<000000=Yl7@3JO1d01@3JO1d00`000000ih@O0>N47`040>N47`030000003hSR40
000000D0om8`00<000000?oW=0000000F`2?_8l10?ooo`00I02?_8l00`000000?RP<0000000305Xi
3`070000001`A180L4@B07144P000000Se@E000000020?nU9`050000003o[2P0oj`X0?n/:0000000
0P3o/BP00`000000ok4X0?na:0040?na:0030000003o/BL0ok4W00@0ok4W00<000000?n_9`3o[bL0
0`3o[bL00`000000ok8W0?nb9`030?nb9`030000003o/2L0ok0W00<0ok0W00<00000018;0`000000
0P1gB1<00`000000omX^000000060;1S60040000002dIQP00000000000<0aW0K00<000000<mf703?
MQ`0103?MQ`00`000000fW`M0=Yl7@050=Yl7@030000003WQ1l0ih@O00@0ih@O0P0000060?oB<080
0000G02?_8l10?ooo`00I02?_8l00`000000?RP<0000000305Xi3`040000001`A180L4@B07144PD0
00001@3o[2P00`000000ok4X000000060?na:0030000003o/BL0ok4W00@0ok4W00<000000?n_9`3o
[bL00`3o[bL3000000<0ok8W00<000000?n`9`3o/2L00`3o/2L300000080MdPC00<000000?oJ;P00
00001@2`HaP3000000D0aW0K00<000000<mf703?MQ`0103?MQ`00`000000fW`M0=Yl7@050=Yl7@03
0000003WQ1l0ih@O00@0ih@O00<000000?oB<03odS001@3odS000`000000Skb?08nlS`1K08nlS`40
oooo001U08nlS`8000000`1J>@l01@000000L4@B07144P1`A18000000080NdXC0P0000060?n/:080
00001P3o/BP00`000000ok4W0?na9`040?na9`030000003o[bL0ojlW00<0ojlW00<000000?n^9P3o
[RH00P0000000`3o/RL000000?n`9`040?n`9`<000000P1gB1<00`000000omX^000000030;1S6080
000000<0_f`J00000036L1/01@36L1/00`000000cgHL0<mf70040<mf70030000003JO1d0fW`M00D0
fW`M00<000000>N47`3WQ1l00`3WQ1l2000000H0om8`00<0000008nlS`2?_8l0G02?_8l10?ooo`00
IP2?_8l200000080FST?00<0000007144P1`A1800P1`A1801@000000NdXC07]:4`1kBQ<0000000H0
oj`X00<000000?na:03o/BP0103o/BP00`000000ok4W0?na9`040?na9`030000003o[bL0ojlW00<0
ojlW00<000000?n^9P3o[RH00P3o[RH2000000D0ok0W0`00000207M84`<0000000<0/6<H00000000
00000`2oK1X00`000000aW0K0<I`6`040<I`6`030000003?MQ`0cgHL00@0cgHL00<000000=Yl7@3J
O1d01@3JO1d00`000000ih@O0>N47`020>N47`030000003o_R`0000000D0om8`00<0000008nlS`2?
_8l0G@2?_8l10?ooo`00I`2?_8l01@000000FST?05Xi3`1J>@l0000000<0L4@B00@0000007]:4`1k
BQ<0NdXC0P0000050?n/:08000001@3o/BP00`000000ok4W0?na9`040?na9`030000003o[bL0ojlW
00<0ojlW00<000000?n^9P3o[RH00`3o[RH3000000<0ok0W1@000000103ofRh00000000000000005
0;m/6P0300000036L1/0aW0K00@0aW0K00<000000<mf703?MQ`01@3?MQ`00`000000fW`M0=Yl7@04
0=Yl7@030000003WQ1l0ih@O008000000P3o_R`00`000000om8`0?oB<0020?oB<0030000002?_8l0
Skb?05h0Skb?0@3oool006P0Skb?00@0000005Xi3`1J>@l000000`1`A1801`000000NdXC07]:4`1k
BQ<00000081<4`000000103o[2P00`000000ok4Y000000040?na:0030000003o/BL0ok4W00@0ok4W
00<000000?n_9`3o[bL00`3o[bL00`000000ojhV0?n^9P030?n^9P030000003oZbH0oj/V00800000
00<0ok0W000000000000100000000`3mVR0000000;m/6P050;m/6P0300000036L1/0aW0K00@0aW0K
00<000000<mf703?MQ`01@3?MQ`00`000000fW`M0=Yl7@040=Yl7@030000003WQ1l0000000D0okh/
00@000000?oB<03odS000000H@2?_8l10?ooo`00J@2?_8l00`000000FST?0000000307144P070000
001kBQ<0NdXC07]:4`000000P4`C000000040?n/:0030000003o/BT0ok4Y008000000P3o/BP00`00
0000ok4W0?na9`030?na9`030000003o[bL0ojlW00@0ojlW00<000000?n^9P3o[RH00`3o[RH00`00
0000oj/V0?n[9P020?n[9P<0000000<0AB/<0000000000000`0000060;m/6P0300000036L1/0aW0K
00@0aW0K00<000000<mf703?MQ`01@3?MQ`00`000000fW`M0=Yl7@040=Yl7@8000001P3o_R`00`00
0000om8`0000001R08nlS`40oooo001Z08nlS`8000000`1`A1800`000000NdXC07]:4`0207]:4`03
00000020C1<000000080oj`X00<000000?na:@3o/BT00`3o/BT00`000000ok4X000000050?na9`03
0000003o[bL0ojlW00@0ojlW00<000000?n^9P3o[RH00`3o[RH00`000000oj/V0?n[9P030?n[9P80
00000P15:``010000000oIXP0000000000060;m/6P0300000036L1/0aW0K00@0aW0K00<000000<mf
703?MQ`01@3?MQ`00`000000fW`M0=Yl7@040=Yl7@030000003o_R`0okh/00D0okh/0P00001S08nl
S`40oooo001[08nlS`8000000`1`A1801@000000NdXC07]:4`1kBQ<000000080P4`C00<000000?n/
:00000001P3o/BT2000000D0ok4W00<000000?n_9`3o[bL0103o[bL00`000000ojhV0?n^9P030?n^
9P030000003oZbH0oj/V00<0oj/V0P00000204D[30040000003mVR00^FPI000000H0_f`J00<00000
0<I`6`36L1/01@36L1/00`000000cgHL0<mf70040<mf70030000003JO1d0fW`M00<0fW`M0P000007
0?nn;0030000002?_8l0Skb?0680Skb?0@3oool006/0Skb?00<0DBL80000001`A1800P1`A1801@00
0000NdXC07]:4`1kBQ<0000000<0P4`C0P0000070?na:@030000003o/BL0ok4W00<0ok4W00<00000
0?n_9`3o[bL0103o[bL00`000000ojhV0?n^9P030?n^9P030000003oZbH0oj/V00<0oj/V0P000002
04D[3080000000<0^FPI0000002oK1X01@2oK1X00`000000aW0K0<I`6`050<I`6`030000003?MQ`0
cgHL00@0cgHL00<000000=Yl7@3JO1d00P3JO1d00`000000oj/X000000060?nn;0030000002?_8l0
Skb?06<0Skb?0@3oool006`0Skb?00D0DBL80000001`A180L4@B0000000307]:4`0300000020C1<0
P4`C0080P4`C00<000000?na:@3o/BT01@3o/BT2000000@0ok4W00<000000?n_9`3o[bL00`3o[bL0
0`000000ojhV0?n^9P040?n^9P030000003oZbH0oj/V00<0oj/V0P00000204D[3080000000<0^FPI
0000002oK1X01@2oK1X00`000000aW0K0<I`6`050<I`6`030000003?MQ`0cgHL00@0cgHL00<00000
0=Yl7@3JO1d00P0000020?n[:0030000003o_R`0okh/00<0okh/00<0000008nlS`2?_8l0I02?_8l1
0?ooo`00K@2?_8l20000000307144P000000NdXC0080NdXC00<00000081<4`20C1<00P20C1<20000
00D0ok4Y00@000000?nd:@3o]2T000000`3o/BL00`000000ojlW0?n_9`030?n_9`030000003o[RH0
ojhV00@0ojhV00<000000?n[9P3oZbH00`3oZbH30000000504D[30000000^FPI0;UX6@0000001P2o
K1X00`000000aW0K0<I`6`050<I`6`030000003?MQ`0cgHL00@0cgHL00<000000=Yl7@000000103o
ZbP00`000000okh/0?nn;0020?nn;0030000002?_8l0Skb?06D0Skb?0@3oool006h0Skb?0P000000
1@1`A180000007]:4`1kBQ<0000000@0P4`C00<00000089=4`000000103o/BT01@000000ok@Y0?nd
:@3o]2T000000080ok4W00<000000?n_9`3o[bL00`3o[bL00`000000ojhV0?n^9P040?n^9P030000
003oZbH0oj/V00<0oj/V10000000103mVR00^FPI0;UX6@0000060;m/6P0300000036L1/0aW0K00D0
aW0K00<000000<mf703?MQ`0103?MQ`2000000D0oj/X00<000000?nn;03o_R`00P00001X08nlS`40
oooo001^08nlS`040000000^70T0000000000080NdXC00<00000081<4`20C1<00P20C1<010000000
PTdC089=4`0000030?na:@030000003o]2T0ok@Y0080ok@Y00<000000?na9`0000001@3o[bL00`00
0000ojhV0?n^9P040?n^9P030000003oZbH0oj/V00<0oj/V1@0000020;UX6@030000002oK1X0_f`J
00@0_f`J00<000000<I`6`36L1/01@36L1/00`000000cgHL0<mf70040<mf70030000003oZbP0oj/X
00@0oj/X00<000000?nn;0000000JP2?_8l10?ooo`00K`2?_8l00`000000;Q`90000000207]:4`03
00000020C1<0P4`C00<0P4`C00@00000089=4`22CA<000000P3o/BT00`000000ok@Y0?nd:@030?nd
:@8000001@3o[bL00`000000ojhV0?n^9P040?n^9P030000003oZbH0oj/V00<0oj/V1@0000020;UX
6@030000002oK1X0_f`J00@0_f`J00<000000<I`6`36L1/01@36L1/00`000000cgHL0<mf70020<mf
70<000001P3oZbP2000006/0Skb?0@3oool00700Skb?00<0000002hL2@0000000P1kBQ<00`000000
P4`C081<4`02081<4`0400000022CA<0PTdC089=4`8000001`3o]2T00`000000ojlW0?n_9`030?n_
9`030000003o[RH0ojhV00@0ojhV00<000000?n[9P3oZbH00`3oZbH20000000302PH20000000^FPI
0080^FPI00<000000;m/6P2oK1X0102oK1X00`000000aW0K0<I`6`050<I`6`030000003?MQ`0cgHL
008000000P3oVR@00`000000oj/X0?n[:0040?n[:0030000002?_8l0Skb?06X0Skb?0@3oool00740
Skb?0`0000000`1kBQ<00000081<4`03081<4`0300000022CA<0PTdC0080PTdC00<000000?nd:@3o
]2T01@3o]2T3000000<0ojlW00<000000?n^9P3o[RH0103o[RH00`000000oj/V0?n[9P030?n[9P80
000000<0:1P80000002iJ1T00P2iJ1T00`000000_f`J0;m/6P040;m/6P0300000036L1/0aW0K00D0
aW0K0`0000040?nJ90030000003oZbP0oj/X0080oj/X0P00001]08nlS`40oooo001b08nlS`@00000
1020C1<00`000000PTdC089=4`02089=4`8000001P3o]2T010000000ok<X0?nc:00000020?n_9`03
0000003o[RH0ojhV00@0ojhV00<000000?n[9P3oZbH00`3oZbH20000000302PH20000000^FPI0080
^FPI00<000000;m/6P2oK1X0102oK1X00`000000aW0K0<I`6`050<I`6`030000003oVR@0oiXT00@0
oiXT00D000000?n[:03oZbP0oj/X0000001_08nlS`40oooo001c08nlS`0300000011:P`0000000@0
P4`C00<00000089=4`22CA<00P22CA<00`000000Q4dC000000050?nd:@040000003o/bP0ok<X0?nc
:0<000001P3o[RH00`000000oj/V0?n[9P030?n[9P80000000<0:1P80000002iJ1T00P2iJ1T00`00
0000_f`J0;m/6P040;m/6P0300000036L1/0aW0K00<0aW0K0`0000060?nJ90040000003oZbP0oj/X
00000700Skb?0@3oool007@0Skb?10000002081<4`0300000022CA<0PTdC0080PTdC00<0000008A=
4`24CA<00P0000020?nd:@030000003o/bP0ok<X00@0ok<X0P0000050?n^9P030000003oZbH0oj/V
00<0oj/V0`0000040;UX6@030000002oK1X0_f`J00@0_f`J00@000000<I`6`36L1/0aW0K0P000002
0?:;8@030000003oVR@0oiXT00@0oiXT0`00001a08nlS`40oooo001e08nlS`80000000@0Fc/@0000
0000000000001@22CA<01`000000Q4dC08A=4`24CA<000000?nd:@0000001P3o/bP010000000ok0W
0000000000030?n^9P030000003oZbH0oj/V00<0oj/V0`0000040;UX6@030000002oK1X0_f`J00@0
_f`J00@000000<I`6`0000000000103bRb400`000000oiXT0?nJ90040?nJ90030000002?_8l0Skb?
0740Skb?0@3oool007H0Skb?00D0000005/k401K>a00Fc/@00000005089=4`0300000024CA<0Q4dC
0080Q4dC0P0000060?nc:0040000003o/2L0ok0W0?n`9`80000000<0ojhV0000003oZbH0103oZbH3
000000@0^FPI00<000000;m/6P2oK1X00`2oK1X3000000H0lX/Q00<000000?nJ903oVR@00P3oVR@3
000007<0Skb?0@3oool007H0Skb?0P00000205/k40<000000`22CA<00`000000Q4dC08A=4`0208A=
4`8000001P3o/bP00`000000ok0W0?n`9`030?n`9`8000001@3oZbH3000000@0^FPI00<000000;m/
6P0000000`0000000`3NOQh000000?:;8@060?:;8@040000003oVR@0oiXT0?nJ90<00000M02?_8l1
0?ooo`00M`2?_8l01P000000Fc/@05/k401K>a00000007Q:4`80000000<0PTdC00000024CA<00`24
CA<010000000Q4dC0000000000040?nc:0030000003o/2L0ok0W00@0ok0W0`0000030?n[9P<00000
0`2iJ1T3000000D0gWhN00<000000?:;8@3bRb401@3bRb400`000000oiXT0?nJ9004000007@0Skb?
0@3oool007P0Skb?00@0000005/k401K>a0000000`1hBQ<3000000<0Q4dC00@0000008A=4`24CA<0
Q4dC0P0000020?nc:0030000003o/2L0ok0W00@0ok0W00<000000?n[9P3oZbH00P0000000`3oZbH0
000000000004000000030<id6`000000gWhN00D0gWhN00<000000?:;8@3bRb401@3bRb46000007D0
Skb?0@3oool007T0Skb?00@0000005/k401K>a0000000`1hBQ<01P000000Q50E000000000000Q4dC
000000@0Q4dC100000060?n`9`030000003oZbH0oj/V0080oj/V0`0000050<id6`030000003NOQh0
gWhN00D0gWhN00<000000?:;8@3bRb400`3bRb43000000030?n^9@000000000007H0Skb?0@3oool0
07X0Skb?0`00000407Q:4`0300000024D1D0Q50E00@000000P24CA<010000000Pd`C08=<4`000006
0?n`9`030000003oZbH0oj/V00<0oj/V0P0000050<id6`030000003NOQh0gWhN00D0gWhN00@00000
0?:;8@3bRb40lX/Q100000020?n^9@030000002?_8l0Skb?07D0Skb?0@3oool007`0Skb?0P000003
07Q:4`0500000024D1D0Q50E08A@5@0000000P28DAD50000000308=<4`000000000000@0ok0W00<0
00000?n[9P3oZbH00`3oZbH2000000D0cW@K00<000000=in7P3NOQh01@3NOQh02@000000lX/Q0000
00000000omP^0000003oh2l000000?n^9@02000007L0Skb?0@3oool007d0Skb?00D0000007Q:4`1h
BQ<0N4XC0000000308A@5@0300000028DAD0R54E0080R54E00<0000008I?5026Ca@01@0000020?n`
9`030000003oZbH0oj/V00<0oj/V0P0000060<id6`030000003NOQh0gWhN00<0gWhN0`0000000`3o
f2h000000000000200000080ojhU00<0000008nlS`2?_8l0MP2?_8l10?ooo`00OP2?_8l200000003
07Q:4`000000Q50E0080Q50E00<0000008QA5@28DAD00P28DAD00`000000QTlD08I?500208I?5003
00000022C1<0PT`C00<000001@3oZbH2000000H0cW@K00@000000=in7P3NOQh0gWhN1P0000001P3o
lS<000000?oP;`000000ojhU000007T0Skb?0@3oool00800Skb?0`00000308A@5@0500000028DAD0
R54E08QA5@0000001026Ca@00`000000PT`C089<4`02089<4`800000103oZbH00`000000cW@K0<id
6`050<id6`030000003NOQh00000008000000`3okc<00`000000oo8c0?ob<`04000007X0Skb?0@3o
ool00880Skb?00D0000008A@5@24D1D0Q50E0000000308QA5@0300000026Ca@0QTlD0080QTlD00<0
0000089<4`22C1<00`22C1<4000000030?n[9P000000cW@K00<0cW@K1@0000020?oT<@040000003o
kc<0onlc00000080oo8c00<000000?oP;`000000O02?_8l10?ooo`00P`2?_8l20000000308A@5@00
0000R54E00<0R54E00<0000008I?5026Ca@00P26Ca@00`000000PT`C089<4`02089<4`040000001j
Aa80NTLB07Y74PH000000`3oebh01@000000on@a0?oT<@3oi34000000080onlc00<000000?ob<`3o
lS<00P00001m08nlS`40oooo002508nlS`<000000`28DAD00`000000QTlD08I?500208I?50030000
0022C1<0PT`C0080PT`C00@0000007Y74P00000000000P2?_8l2000000050?o9:`000000omL^0?oG
;P0000000`3oi3401P000000onlc0?o_<`3okc<000000?ob<`800000OP2?_8l10?ooo`00R02?_8l2
0000000308QA5@000000QTlD00<0QTlD00<00000089<4`22C1<01000000608nlS`8000000P3oebh0
1@000000on@a0?oT<@3oi34000000080onlc00@000000?ob<`0000000000O`2?_8l10?ooo`00RP2?
_8l9000000`0Skb?0`0000030?oT<@030000003okc<0000000800000P@2?_8l10?ooo`00X@2?_8l6
000008@0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?
0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0
Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l1
0?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?
_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40
oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nl
Sb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3o
ool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?
;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?oo
o`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/
08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo
003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0
Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool0
0?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?
_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00
o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nl
S`40oooo003o08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o
08nlSb`0Skb?0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?
0@3oool00?l0Skb?;02?_8l10?ooo`00o`2?_8l/08nlS`40oooo003o08nlSb`0Skb?0@3oool00?l0
Skb?;02?_8l10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {402.625, 0}} -> {0.123341, -0.000354949, \
0.00243422, 0.00243422}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->{},
WindowSize->{494, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 64, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1843, 56, 507, 18, 50, "Usage",
      CellTags->"Function?"],
    Cell[2353, 76, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 397246, 14330}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 64, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1843, 56, 507, 18, 50, "Usage",
  CellTags->"Function?"],
Cell[2353, 76, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2450, 81, 179, 3, 58, "MathCaption"],
Cell[2632, 86, 551, 21, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3208, 111, 33, 0, 39, "ExampleSection"],
Cell[3244, 113, 97, 2, 29, "Input"],
Cell[3344, 117, 72, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[3441, 121, 777, 14, 229, "Input"],
Cell[4221, 137, 392316, 14170, 410, 247338, 12376, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

