(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7390,        225]*)
(*NotebookOutlinePosition[      8361,        259]*)
(*  CellTagsIndexPosition[      8287,        253]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DensityDraw", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] DensityDraw[",
  StyleBox["f", "TI"],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula"],
  StyleBox["x", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["xmin", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["xmax", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula"],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula"],
  StyleBox["y", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["ymin", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["ymax", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula"],
  "] extracts the graphics primitives from the corresponding DensityPlot \
statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Regular DensityPlot options may be used. Basic Graphics options , such as \
Frame have no effect.\
\>", "MathCaption"],

Cell["\<\
DrawingTransform cannot be used on the graphics produced by DensityPlot.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DensityPlot",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["ContourDraw",
    ButtonData:>{"ContourDraw"},
    ButtonStyle->"AddOnsLink"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Here are several ways to emphasize the central section of a DensityPlot.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{DensityDraw[
            Cos[x] Cos[y], {x, \(-2\) \[Pi], 2  \[Pi]}, {y, \(-2\) \[Pi], 
              2  \[Pi]}, 
            PlotPoints \[Rule] 40], \[IndentingNewLine]DensityDraw[
            Cos[x] Cos[y], {x, \(-\[Pi]\), \[Pi]}, {y, \(-\[Pi]\), \[Pi]}, 
            PlotPoints \[Rule] 20, 
            ColorFunction \[Rule] Hue], \[IndentingNewLine]White, 
          Line[{{\(-2\) \[Pi], \(-2\) \[Pi]}, {2  \[Pi], 2  \[Pi]}}], 
          Line[{{2  \[Pi], \(-2\) \[Pi]}, {\(-2\) \[Pi], 
                2  \[Pi]}}]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{DensityDraw[
            Cos[x] Cos[y], {x, \(-2\) \[Pi], 2  \[Pi]}, {y, \(-2\) \[Pi], 
              2  \[Pi]}, PlotPoints \[Rule] 128, 
            ColorFunction \[Rule] Hue], \[IndentingNewLine]DensityDraw[
            Cos[x] Cos[y], {x, \(-\[Pi]\), \[Pi]}, {y, \(-\[Pi]\), \[Pi]}, 
            PlotPoints \[Rule] 64, ColorFunction \[Rule] Hue, 
            Mesh \[Rule] False], \[IndentingNewLine]White, 
          Line[{{\(-2\) \[Pi], \(-2\) \[Pi]}, {2  \[Pi], 2  \[Pi]}}], 
          Line[{{2  \[Pi], \(-2\) \[Pi]}, {\(-2\) \[Pi], 
                2  \[Pi]}}]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
The next graphic combines the following elements
1) A DensityPlot using ColorMix to obtain a two color gradient.
2) The contour lines from a ContourPlot laid over the DensityPlot
3) Line labels added to the contour lines.\
\>", "Text"],

Cell[BoxData[{
    \(\(f[x_, y_] := x\^2 - y\^2;\)\), "\n", 
    \(\(Module[\[IndentingNewLine]{g}, \[IndentingNewLine]Draw2D[\
\[IndentingNewLine]{DensityDraw[f[x, y], {x, \(-2\), 2}, {y, \(-2\), 2}, 
              ColorFunction \[Rule] ColorMix[SteelBlue, Gold], 
              PlotPoints \[Rule] 50, 
              Mesh \[Rule] False], \[IndentingNewLine]\[IndentingNewLine]g = 
              ContourDraw[f[x, y], {x, \(-2\), 2}, {y, \(-2\), 2}, 
                ContourShading \[Rule] False, 
                PlotPoints \[Rule] 
                  50], \[IndentingNewLine]\[IndentingNewLine]g // 
              DrawLineLabels[f, 
                If[# > 0, 0.265  # + 0.05, 
                    0.22  # + 
                      0.8] &, \[IndentingNewLine]DrawLLFormat \[Rule] \
\((NumberForm[#, 2] &)\), 
                DrawLLTextOptions \[Rule] {Background \[Rule] PaleGreen, 
                    TextStyle \[Rule] {FontSize \[Rule] 
                          10}}]}, \
\[IndentingNewLine]\[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Background \[Rule] 
            LightSteelBlue, \[IndentingNewLine]PlotRegion \[Rule] {{0, 
                0.95}, {0, 0.95}}, \[IndentingNewLine]ImageSize \[Rule] 
            400]];\)\)}], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
The position function for the labels was obtained by using different position \
functions for the positive and negative values to space out the labels but \
prevent clashes.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[{\(-3.4\) a + b \[Equal] 0.05, 0  a + b \[Equal] 0.8}]\)], "Input",\

  CellLabel->"In[6]:="],

Cell[BoxData[
    \({{b \[Rule] 0.8`, a \[Rule] 0.22058823529411764`}}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[{0  a + b \[Equal] 0.05, 3.4  a + b \[Equal] 0.95}]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \({{b \[Rule] 0.05`, a \[Rule] 0.2647058823529412`}}\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[BoxData[
    \(Clear[f]\)], "Input",
  CellLabel->"In[8]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{548, 705},
WindowMargins->{{2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 58, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1837, 56, 792, 32, 50, "Usage",
      CellTags->"Function?"],
    Cell[2632, 90, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 8041, 242}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 58, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1837, 56, 792, 32, 50, "Usage",
  CellTags->"Function?"],
Cell[2632, 90, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2729, 95, 128, 3, 58, "MathCaption"],
Cell[2860, 100, 103, 2, 41, "MathCaption"],
Cell[2966, 104, 210, 8, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3201, 116, 34, 0, 39, "ExampleSection"],
Cell[3238, 118, 97, 2, 29, "Input"],
Cell[3338, 122, 96, 2, 25, "Text"],
Cell[3437, 126, 738, 13, 209, "Input"],
Cell[4178, 141, 786, 13, 209, "Input"],
Cell[4967, 156, 245, 5, 100, "Text"],
Cell[5215, 163, 1350, 25, 389, "Input"],
Cell[6568, 190, 197, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[6790, 198, 119, 3, 29, "Input"],
Cell[6912, 203, 108, 2, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7057, 210, 114, 2, 29, "Input"],
Cell[7174, 214, 108, 2, 23, "Output"]
}, Open  ]],
Cell[7297, 219, 65, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

