(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    282185,      12405]*)
(*NotebookOutlinePosition[    283160,      12439]*)
(*  CellTagsIndexPosition[    283082,      12433]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Draw3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["Draw3D",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(f, {x, xmin, xmax}, {y, ymin, ymax}, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " extracts the graphics primitives from the corresponding Plot3D \
statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as Plot3D. Regular Plot3D options may be used. Basic \
Graphics3D options, such as PlotRange have no effect.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ListDraw3D",
    ButtonData:>{"ListDraw3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ParametricDraw3D",
    ButtonData:>{"ParametricDraw3D"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Here, two surfaces are drawn, one as a wireframe.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{Draw3D[
              Sin[x\ y], {x, 0, \[Pi]}, {y, 0, \[Pi]}, 
              PlotPoints \[Rule] 31] // 
            UseWireFrame, \[IndentingNewLine]Draw3D[
            x\ y/\[Pi]\^2, {x, 0, \[Pi]}, {y, 
              0, \[Pi]}]}, \[IndentingNewLine]ImageSize \[Rule] 
          300];\)\)], "Input",
  CellLabel->"In[305]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92391 
%%ImageSize: 300 277.173 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.09504e-017 1.05086 -0.0145186 1.05086 [
[ 0 0 0 0 ]
[ 1 .92391 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05798 .25172 m
0 .6176 L
s
0 .6176 m
.39883 .92391 L
s
.39883 .92391 m
.41039 .59306 L
s
.41039 .59306 m
.05798 .25172 L
s
.68205 0 m
.95219 .42426 L
s
.95219 .42426 m
1 .77405 L
s
1 .77405 m
.7043 .38319 L
s
.7043 .38319 m
.68205 0 L
s
.05798 .25172 m
0 .6176 L
s
0 .6176 m
.7043 .38319 L
s
.7043 .38319 m
.68205 0 L
s
.68205 0 m
.05798 .25172 L
s
.41039 .59306 m
.95219 .42426 L
s
.95219 .42426 m
1 .77405 L
s
1 .77405 m
.39883 .92391 L
s
.39883 .92391 m
.41039 .59306 L
s
0 0 m
1 0 L
1 .92391 L
0 .92391 L
closepath
clip
newpath
.5 Mabswid
.6623 .5163 m
.64498 .51887 L
s
.64498 .51887 m
.63667 .51308 L
s
.64498 .51887 m
.62829 .53715 L
s
.62829 .53715 m
.62004 .53764 L
s
.62829 .53715 m
.61196 .57005 L
s
.486 .695 .96 r
.4181 .73022 m .43032 .7414 L .40986 .74065 L p F P
0 g
s
.486 .695 .96 r
.40986 .74065 m .39756 .72981 L .4181 .73022 L p F P
0 g
s
.40003 .73199 m
.40986 .74065 L
s
.68051 .52931 m
.6623 .5163 L
s
.6623 .5163 m
.65378 .50292 L
s
.61196 .57005 m
.60362 .57509 L
s
.61196 .57005 m
.59571 .61519 L
s
.63667 .51308 m
.65378 .50292 L
s
.62004 .53764 m
.63667 .51308 L
s
.63667 .51308 m
.62836 .51059 L
s
.40003 .73199 m
.415 .77758 L
s
.491 .691 .957 r
.43889 .73064 m .45102 .74216 L .43032 .7414 L p F P
0 g
s
.491 .691 .957 r
.43032 .7414 m .4181 .73022 L .43889 .73064 L p F P
0 g
s
.40995 .74093 m
.42487 .78782 L
s
.40986 .74065 m
.40995 .74093 L
s
.65378 .50292 m
.67163 .50759 L
s
.65378 .50292 m
.64533 .49341 L
s
.496 .699 .96 r
.40571 .71889 m .4181 .73022 L .39756 .72981 L p F P
0 g
s
.496 .699 .96 r
.39756 .72981 m .38507 .71881 L .40571 .71889 L p F P
0 g
s
.39756 .72981 m
.40003 .73199 L
s
.39009 .72323 m
.39756 .72981 L
s
.60362 .57509 m
.62004 .53764 L
s
.62004 .53764 m
.61171 .5407 L
s
.6998 .55647 m
.68051 .52931 L
s
.68051 .52931 m
.67163 .50759 L
s
.39009 .72323 m
.40503 .76722 L
s
.495 .688 .953 r
.45992 .73107 m .47197 .74293 L .45102 .74216 L p F P
0 g
s
.495 .688 .953 r
.45102 .74216 m .43889 .73064 L .45992 .73107 L p F P
0 g
s
.64533 .49341 m
.66289 .49002 L
s
.62836 .51059 m
.64533 .49341 L
s
.64533 .49341 m
.63692 .48777 L
s
.5 .695 .956 r
.42658 .71896 m .43889 .73064 L .4181 .73022 L p F P
0 g
s
.5 .695 .956 r
.4181 .73022 m .40571 .71889 L .42658 .71896 L p F P
0 g
s
.67163 .50759 m
.69042 .52639 L
s
.67163 .50759 m
.66289 .49002 L
s
.61171 .5407 m
.62836 .51059 L
s
.62836 .51059 m
.62 .5113 L
s
.59571 .61519 m
.58716 .6228 L
s
.59571 .61519 m
.57928 .66894 L
s
.505 .702 .959 r
.39313 .70738 m .40571 .71889 L .38507 .71881 L p F P
0 g
s
.505 .702 .959 r
.38507 .71881 m .37241 .70765 L .39313 .70738 L p F P
0 g
s
.38507 .71881 m
.39009 .72323 L
s
.38003 .71437 m
.38507 .71881 L
s
.58716 .6228 m
.60362 .57509 L
s
.60362 .57509 m
.59514 .5819 L
s
.66289 .49002 m
.68124 .50033 L
s
.66289 .49002 m
.65426 .47679 L
s
.499 .684 .949 r
.4812 .7315 m .49316 .7437 L .47197 .74293 L p F P
0 g
s
.499 .684 .949 r
.47197 .74293 m .45992 .73107 L .4812 .7315 L p F P
0 g
s
.59514 .5819 m
.61171 .5407 L
s
.61171 .5407 m
.60326 .54616 L
s
.44057 .83092 m
.42487 .78782 L
s
.42487 .78782 m
.415 .77758 L
s
.504 .691 .952 r
.4477 .71904 m .45992 .73107 L .43889 .73064 L p F P
0 g
s
.504 .691 .952 r
.43889 .73064 m .42658 .71896 L .4477 .71904 L p F P
0 g
s
.63692 .48777 m
.65426 .47679 L
s
.62 .5113 m
.63692 .48777 L
s
.63692 .48777 m
.62851 .48596 L
s
.509 .699 .955 r
.41409 .70711 m .42658 .71896 L .40571 .71889 L p F P
0 g
s
.509 .699 .955 r
.40571 .71889 m .39313 .70738 L .41409 .70711 L p F P
0 g
s
.38009 .71453 m
.39494 .75674 L
s
.38003 .71437 m
.38009 .71453 L
s
.65426 .47679 m
.67226 .47876 L
s
.65426 .47679 m
.64573 .46802 L
s
.515 .706 .957 r
.38037 .6957 m .39313 .70738 L .37241 .70765 L p F P
0 g
s
.515 .706 .957 r
.37241 .70765 m .35955 .69632 L .38037 .6957 L p F P
0 g
s
.37241 .70765 m
.38003 .71437 L
s
.36985 .7054 m
.37241 .70765 L
s
.60326 .54616 m
.62 .5113 L
s
.62 .5113 m
.61157 .51505 L
s
.415 .77758 m
.43065 .81955 L
s
.415 .77758 m
.40503 .76722 L
s
.503 .68 .946 r
.50273 .73193 m .51461 .74449 L .49316 .7437 L p F P
0 g
s
.503 .68 .946 r
.49316 .7437 m .4812 .7315 L .50273 .73193 L p F P
0 g
s
.69042 .52639 m
.7103 .55752 L
s
.6998 .55647 m
.69042 .52639 L
s
.69042 .52639 m
.68124 .50033 L
s
.72024 .59507 m
.6998 .55647 L
s
.57044 .67707 m
.58716 .6228 L
s
.58716 .6228 m
.57843 .63138 L
s
.508 .688 .948 r
.46906 .71912 m .4812 .7315 L .45992 .73107 L p F P
0 g
s
.508 .688 .948 r
.45992 .73107 m .4477 .71904 L .46906 .71912 L p F P
0 g
s
.57928 .66894 m
.57044 .67707 L
s
.57928 .66894 m
.5625 .72652 L
s
.68124 .50033 m
.70059 .52331 L
s
.68124 .50033 m
.67226 .47876 L
s
.57843 .63138 m
.59514 .5819 L
s
.59514 .5819 m
.58649 .59026 L
s
.513 .695 .951 r
.4353 .70683 m .4477 .71904 L .42658 .71896 L p F P
0 g
s
.513 .695 .951 r
.42658 .71896 m .41409 .70711 L .4353 .70683 L p F P
0 g
s
.67226 .47876 m
.69111 .49324 L
s
.67226 .47876 m
.66345 .46199 L
s
.518 .702 .954 r
.40142 .69508 m .41409 .70711 L .39313 .70738 L p F P
0 g
s
.518 .702 .954 r
.39313 .70738 m .38037 .6957 L .40142 .69508 L p F P
0 g
s
.36993 .70562 m
.38475 .74615 L
s
.36985 .7054 m
.36993 .70562 L
s
.64573 .46802 m
.66345 .46199 L
s
.62851 .48596 m
.64573 .46802 L
s
.64573 .46802 m
.63725 .46369 L
s
.58649 .59026 m
.60326 .54616 L
s
.60326 .54616 m
.59468 .55378 L
s
.61157 .51505 m
.62851 .48596 L
s
.62851 .48596 m
.62006 .48784 L
s
.40503 .76722 m
.42064 .80801 L
s
.40503 .76722 m
.39494 .75674 L
s
.524 .71 .956 r
.36741 .68385 m .38037 .6957 L .35955 .69632 L p F P
0 g
s
.524 .71 .956 r
.35955 .69632 m .3465 .68482 L .36741 .68385 L p F P
0 g
s
.35955 .69632 m
.36985 .7054 L
s
.35955 .69632 m
.37444 .73542 L
s
.34913 .68714 m
.35955 .69632 L
s
.506 .677 .942 r
.52452 .73237 m .53632 .74528 L .51461 .74449 L p F P
0 g
s
.506 .677 .942 r
.51461 .74449 m .50273 .73193 L .52452 .73237 L p F P
0 g
s
.511 .684 .945 r
.49068 .71919 m .50273 .73193 L .4812 .7315 L p F P
0 g
s
.511 .684 .945 r
.4812 .7315 m .46906 .71912 L .49068 .71919 L p F P
0 g
s
.66345 .46199 m
.68187 .46796 L
s
.66345 .46199 m
.65478 .45023 L
s
.516 .691 .947 r
.45675 .70656 m .46906 .71912 L .4477 .71904 L p F P
0 g
s
.516 .691 .947 r
.4477 .71904 m .4353 .70683 L .45675 .70656 L p F P
0 g
s
.59468 .55378 m
.61157 .51505 L
s
.61157 .51505 m
.60302 .52161 L
s
.521 .698 .95 r
.42272 .69445 m .4353 .70683 L .41409 .70711 L p F P
0 g
s
.521 .698 .95 r
.41409 .70711 m .40142 .69508 L .42272 .69445 L p F P
0 g
s
.39494 .75674 m
.41052 .79631 L
s
.39494 .75674 m
.38475 .74615 L
s
.45703 .86421 m
.44057 .83092 L
s
.44057 .83092 m
.43065 .81955 L
s
.527 .706 .952 r
.38856 .68288 m .40142 .69508 L .38037 .6957 L p F P
0 g
s
.527 .706 .952 r
.38037 .6957 m .36741 .68385 L .38856 .68288 L p F P
0 g
s
.34913 .68714 m
.36402 .72458 L
s
.51 .673 .938 r
.54657 .73281 m .55829 .74609 L .53632 .74528 L p F P
0 g
s
.51 .673 .938 r
.53632 .74528 m .52452 .73237 L .54657 .73281 L p F P
0 g
s
.56141 .68545 m
.57843 .63138 L
s
.57843 .63138 m
.5695 .64071 L
s
.57044 .67707 m
.56141 .68545 L
s
.63725 .46369 m
.65478 .45023 L
s
.62006 .48784 m
.63725 .46369 L
s
.63725 .46369 m
.62877 .4637 L
s
.514 .68 .941 r
.51255 .71927 m .52452 .73237 L .50273 .73193 L p F P
0 g
s
.514 .68 .941 r
.50273 .73193 m .49068 .71919 L .51255 .71927 L p F P
0 g
s
.532 .713 .955 r
.35427 .67183 m .36741 .68385 L .3465 .68482 L p F P
0 g
s
.532 .713 .955 r
.3465 .68482 m .33326 .67315 L .35427 .67183 L p F P
0 g
s
.3465 .68482 m
.34913 .68714 L
s
.33858 .67784 m
.3465 .68482 L
s
.69111 .49324 m
.71095 .51899 L
s
.70059 .52331 m
.69111 .49324 L
s
.69111 .49324 m
.68187 .46796 L
s
.65478 .45023 m
.67286 .44793 L
s
.65478 .45023 m
.64621 .44354 L
s
.70059 .52331 m
.72101 .55693 L
s
.7103 .55752 m
.70059 .52331 L
s
.55693 .74456 m
.5625 .72652 L
s
.5695 .64071 m
.58649 .59026 L
s
.58649 .59026 m
.57766 .59991 L
s
.519 .687 .943 r
.47845 .70627 m .49068 .71919 L .46906 .71912 L p F P
0 g
s
.519 .687 .943 r
.46906 .71912 m .45675 .70656 L .47845 .70627 L p F P
0 g
s
.68187 .46796 m
.70117 .48528 L
s
.68187 .46796 m
.67286 .44793 L
s
.7103 .55752 m
.7313 .59807 L
s
.72024 .59507 m
.7103 .55752 L
s
.60302 .52161 m
.62006 .48784 L
s
.62006 .48784 m
.61154 .49318 L
s
.525 .695 .946 r
.44426 .69381 m .45675 .70656 L .4353 .70683 L p F P
0 g
s
.525 .695 .946 r
.4353 .70683 m .42272 .69445 L .44426 .69381 L p F P
0 g
s
.38475 .74615 m
.40029 .78444 L
s
.38475 .74615 m
.37444 .73542 L
s
.57766 .59991 m
.59468 .55378 L
s
.59468 .55378 m
.58593 .56329 L
s
.43065 .81955 m
.44707 .85267 L
s
.43065 .81955 m
.42064 .80801 L
s
.53 .702 .949 r
.40995 .68189 m .42272 .69445 L .40142 .69508 L p F P
0 g
s
.53 .702 .949 r
.40142 .69508 m .38856 .68288 L .40995 .68189 L p F P
0 g
s
.74177 .64116 m
.72024 .59507 L
s
.67286 .44793 m
.69168 .45665 L
s
.67286 .44793 m
.66404 .43347 L
s
.33858 .67784 m
.35349 .71361 L
s
.513 .67 .934 r
.56889 .73326 m .58053 .7469 L .55829 .74609 L p F P
0 g
s
.513 .67 .934 r
.55829 .74609 m .54657 .73281 L .56889 .73326 L p F P
0 g
s
.54528 .78231 m
.55648 .74604 L
s
.55648 .74604 m
.55648 .74602 L
s
.55373 .73296 m
.5625 .72652 L
s
.55343 .73295 m
.57044 .67707 L
s
.535 .709 .951 r
.37551 .67049 m .38856 .68288 L .36741 .68385 L p F P
0 g
s
.535 .709 .951 r
.36741 .68385 m .35427 .67183 L .37551 .67049 L p F P
0 g
s
.518 .677 .937 r
.53469 .71935 m .54657 .73281 L .52452 .73237 L p F P
0 g
s
.518 .677 .937 r
.52452 .73237 m .51255 .71927 L .53469 .71935 L p F P
0 g
s
.523 .684 .94 r
.50041 .70599 m .51255 .71927 L .49068 .71919 L p F P
0 g
s
.523 .684 .94 r
.49068 .71919 m .47845 .70627 L .50041 .70599 L p F P
0 g
s
.64621 .44354 m
.66404 .43347 L
s
.62877 .4637 m
.64621 .44354 L
s
.64621 .44354 m
.63769 .44186 L
s
.58593 .56329 m
.60302 .52161 L
s
.60302 .52161 m
.59433 .53067 L
s
.541 .716 .953 r
.34092 .65962 m .35427 .67183 L .33326 .67315 L p F P
0 g
s
.541 .716 .953 r
.33326 .67315 m .31981 .6613 L .34092 .65962 L p F P
0 g
s
.33326 .67315 m
.33858 .67784 L
s
.32791 .66843 m
.33326 .67315 L
s
.528 .691 .942 r
.46605 .69317 m .47845 .70627 L .45675 .70656 L p F P
0 g
s
.528 .691 .942 r
.45675 .70656 m .44426 .69381 L .46605 .69317 L p F P
0 g
s
.42064 .80801 m
.437 .84085 L
s
.42064 .80801 m
.41052 .79631 L
s
.61154 .49318 m
.62877 .4637 L
s
.62877 .4637 m
.62026 .46784 L
s
.37444 .73542 m
.38996 .7724 L
s
.37444 .73542 m
.36402 .72458 L
s
.66404 .43347 m
.68247 .43374 L
s
.66404 .43347 m
.65538 .42472 L
s
.533 .698 .945 r
.43159 .68089 m .44426 .69381 L .42272 .69445 L p F P
0 g
s
.533 .698 .945 r
.42272 .69445 m .40995 .68189 L .43159 .68089 L p F P
0 g
s
.56141 .68545 m
.55216 .69388 L
s
.55216 .69388 m
.5695 .64071 L
s
.5695 .64071 m
.56037 .65053 L
s
.516 .666 .93 r
.59148 .73372 m .60304 .74773 L .58053 .7469 L p F P
0 g
s
.516 .666 .93 r
.58053 .7469 m .56889 .73326 L .59148 .73372 L p F P
0 g
s
.53583 .78606 m
.55256 .73561 L
s
.55256 .73561 m
.55258 .73556 L
s
.54399 .73965 m
.55204 .73413 L
s
.55204 .73413 m
.55207 .73411 L
s
.538 .705 .947 r
.397 .66914 m .40995 .68189 L .38856 .68288 L p F P
0 g
s
.538 .705 .947 r
.38856 .68288 m .37551 .67049 L .397 .66914 L p F P
0 g
s
.521 .673 .933 r
.55709 .71943 m .56889 .73326 L .54657 .73281 L p F P
0 g
s
.521 .673 .933 r
.54657 .73281 m .53469 .71935 L .55709 .71943 L p F P
0 g
s
.54399 .73965 m
.54868 .72505 L
s
.5505 .71941 m
.56141 .68545 L
s
.54868 .72505 m
.54876 .72481 L
s
.54528 .78231 m
.53583 .78606 L
s
.54528 .78231 m
.52766 .8304 L
s
.70117 .48528 m
.72148 .51258 L
s
.71095 .51899 m
.70117 .48528 L
s
.70117 .48528 m
.69168 .45665 L
s
.47419 .88279 m
.45703 .86421 L
s
.45703 .86421 m
.44707 .85267 L
s
.69168 .45665 m
.71139 .47563 L
s
.69168 .45665 m
.68247 .43374 L
s
.56037 .65053 m
.57766 .59991 L
s
.57766 .59991 m
.56863 .61057 L
s
.59433 .53067 m
.61154 .49318 L
s
.61154 .49318 m
.6029 .50167 L
s
.525 .68 .936 r
.52263 .7057 m .53469 .71935 L .51255 .71927 L p F P
0 g
s
.525 .68 .936 r
.51255 .71927 m .50041 .70599 L .52263 .7057 L p F P
0 g
s
.544 .712 .95 r
.36226 .65792 m .37551 .67049 L .35427 .67183 L p F P
0 g
s
.544 .712 .95 r
.35427 .67183 m .34092 .65962 L .36226 .65792 L p F P
0 g
s
.32798 .6686 m
.34283 .70251 L
s
.32791 .66843 m
.32798 .6686 L
s
.71095 .51899 m
.73187 .55387 L
s
.72101 .55693 m
.71095 .51899 L
s
.41052 .79631 m
.42683 .82877 L
s
.41052 .79631 m
.40029 .78444 L
s
.53 .687 .939 r
.4881 .69252 m .50041 .70599 L .47845 .70627 L p F P
0 g
s
.53 .687 .939 r
.47845 .70627 m .46605 .69317 L .4881 .69252 L p F P
0 g
s
.36402 .72458 m
.37953 .76019 L
s
.36402 .72458 m
.35349 .71361 L
s
.68247 .43374 m
.70165 .44409 L
s
.68247 .43374 m
.67351 .41699 L
s
.549 .719 .952 r
.32737 .64723 m .34092 .65962 L .31981 .6613 L p F P
0 g
s
.549 .719 .952 r
.31981 .6613 m .30616 .64927 L .32737 .64723 L p F P
0 g
s
.31981 .6613 m
.32791 .66843 L
s
.3171 .65891 m
.31981 .6613 L
s
.56863 .61057 m
.58593 .56329 L
s
.58593 .56329 m
.57698 .57436 L
s
.535 .694 .941 r
.45347 .67987 m .46605 .69317 L .44426 .69381 L p F P
0 g
s
.535 .694 .941 r
.44426 .69381 m .43159 .68089 L .45347 .67987 L p F P
0 g
s
.72101 .55693 m
.74251 .59818 L
s
.7313 .59807 m
.72101 .55693 L
s
.65538 .42472 m
.67351 .41699 L
s
.63769 .44186 m
.65538 .42472 L
s
.65538 .42472 m
.64683 .42167 L
s
.62026 .46784 m
.63769 .44186 L
s
.63769 .44186 m
.62919 .445 L
s
.541 .701 .944 r
.41873 .66777 m .43159 .68089 L .40995 .68189 L p F P
0 g
s
.541 .701 .944 r
.40995 .68189 m .397 .66914 L .41873 .66777 L p F P
0 g
s
.519 .663 .926 r
.61435 .73418 m .62583 .74856 L .60304 .74773 L p F P
0 g
s
.519 .663 .926 r
.60304 .74773 m .59148 .73372 L .61435 .73418 L p F P
0 g
s
.44707 .85267 m
.46419 .87238 L
s
.44707 .85267 m
.437 .84085 L
s
.523 .669 .929 r
.57976 .71952 m .59148 .73372 L .56889 .73326 L p F P
0 g
s
.523 .669 .929 r
.56889 .73326 m .55709 .71943 L .57976 .71952 L p F P
0 g
s
.546 .708 .946 r
.38385 .65619 m .397 .66914 L .37551 .67049 L p F P
0 g
s
.546 .708 .946 r
.37551 .67049 m .36226 .65792 L .38385 .65619 L p F P
0 g
s
.67351 .41699 m
.69224 .41877 L
s
.67351 .41699 m
.66477 .40661 L
s
.528 .676 .932 r
.54512 .70541 m .55709 .71943 L .53469 .71935 L p F P
0 g
s
.528 .676 .932 r
.53469 .71935 m .52263 .7057 L .54512 .70541 L p F P
0 g
s
.40029 .78444 m
.41657 .81641 L
s
.40029 .78444 m
.38996 .7724 L
s
.7313 .59807 m
.75332 .64399 L
s
.74177 .64116 m
.7313 .59807 L
s
.6029 .50167 m
.62026 .46784 L
s
.62026 .46784 m
.61166 .47581 L
s
.57698 .57436 m
.59433 .53067 L
s
.59433 .53067 m
.58547 .5419 L
s
.35349 .71361 m
.36898 .74781 L
s
.35349 .71361 m
.34283 .70251 L
s
.533 .683 .935 r
.51041 .69186 m .52263 .7057 L .50041 .70599 L p F P
0 g
s
.533 .683 .935 r
.50041 .70599 m .4881 .69252 L .51041 .69186 L p F P
0 g
s
.552 .715 .948 r
.34882 .64515 m .36226 .65792 L .34092 .65962 L p F P
0 g
s
.552 .715 .948 r
.34092 .65962 m .32737 .64723 L .34882 .64515 L p F P
0 g
s
.3172 .65913 m
.33206 .69128 L
s
.3171 .65891 m
.3172 .65913 L
s
.52766 .8304 m
.51795 .83024 L
s
.52766 .8304 m
.50977 .86543 L
s
.538 .69 .937 r
.47561 .67885 m .4881 .69252 L .46605 .69317 L p F P
0 g
s
.538 .69 .937 r
.46605 .69317 m .45347 .67987 L .47561 .67885 L p F P
0 g
s
.51795 .83024 m
.53583 .78606 L
s
.53583 .78606 m
.52618 .78915 L
s
.52618 .78915 m
.54399 .73965 L
s
.54399 .73965 m
.53443 .74559 L
s
.54733 .70799 m
.55216 .69388 L
s
.49185 .88347 m
.47419 .88279 L
s
.47419 .88279 m
.46419 .87238 L
s
.437 .84085 m
.45409 .86154 L
s
.437 .84085 m
.42683 .82877 L
s
.557 .722 .95 r
.31362 .63464 m .32737 .64723 L .30616 .64927 L p F P
0 g
s
.557 .722 .95 r
.30616 .64927 m .2923 .63706 L .31362 .63464 L p F P
0 g
s
.30616 .64927 m
.3171 .65891 L
s
.30616 .64927 m
.32116 .67991 L
s
.29509 .63952 m
.30616 .64927 L
s
.56037 .65053 m
.55101 .66058 L
s
.543 .697 .94 r
.44071 .66638 m .45347 .67987 L .43159 .68089 L p F P
0 g
s
.543 .697 .94 r
.43159 .68089 m .41873 .66777 L .44071 .66638 L p F P
0 g
s
.76418 .68961 m
.74177 .64116 L
s
.70165 .44409 m
.72173 .46373 L
s
.71139 .47563 m
.70165 .44409 L
s
.70165 .44409 m
.69224 .41877 L
s
.522 .659 .922 r
.6375 .73465 m .6489 .74941 L .62583 .74856 L p F P
0 g
s
.522 .659 .922 r
.62583 .74856 m .61435 .73418 L .6375 .73465 L p F P
0 g
s
.71139 .47563 m
.7321 .5035 L
s
.72148 .51258 m
.71139 .47563 L
s
.526 .666 .925 r
.60271 .7196 m .61435 .73418 L .59148 .73372 L p F P
0 g
s
.526 .666 .925 r
.59148 .73372 m .57976 .71952 L .60271 .7196 L p F P
0 g
s
.38996 .7724 m
.4062 .80378 L
s
.38996 .7724 m
.37953 .76019 L
s
.548 .704 .942 r
.40568 .65445 m .41873 .66777 L .397 .66914 L p F P
0 g
s
.548 .704 .942 r
.397 .66914 m .38385 .65619 L .40568 .65445 L p F P
0 g
s
.69224 .41877 m
.71175 .42976 L
s
.69224 .41877 m
.68316 .40023 L
s
.55101 .66058 m
.56863 .61057 L
s
.56863 .61057 m
.55937 .62192 L
s
.64683 .42167 m
.66477 .40661 L
s
.62919 .445 m
.64683 .42167 L
s
.64683 .42167 m
.63833 .42413 L
s
.531 .673 .928 r
.56788 .70512 m .57976 .71952 L .55709 .71943 L p F P
0 g
s
.531 .673 .928 r
.55709 .71943 m .54512 .70541 L .56788 .70512 L p F P
0 g
s
.54528 .71395 m
.54529 .71392 L
s
.54529 .71392 m
.54532 .71383 L
s
.53443 .74559 m
.54528 .71395 L
s
.58547 .5419 m
.6029 .50167 L
s
.6029 .50167 m
.59411 .51294 L
s
.66477 .40661 m
.68316 .40023 L
s
.66477 .40661 m
.65619 .40264 L
s
.34283 .70251 m
.35833 .73526 L
s
.34283 .70251 m
.33206 .69128 L
s
.72148 .51258 m
.74282 .54776 L
s
.73187 .55387 m
.72148 .51258 L
s
.535 .679 .931 r
.53299 .69119 m .54512 .70541 L .52263 .7057 L p F P
0 g
s
.535 .679 .931 r
.52263 .7057 m .51041 .69186 L .53299 .69119 L p F P
0 g
s
.50977 .86543 m
.49988 .86114 L
s
.50977 .86543 m
.49185 .88347 L
s
.554 .711 .945 r
.3705 .64306 m .38385 .65619 L .36226 .65792 L p F P
0 g
s
.554 .711 .945 r
.36226 .65792 m .34882 .64515 L .3705 .64306 L p F P
0 g
s
.49185 .88347 m
.48188 .87557 L
s
.61166 .47581 m
.62919 .445 L
s
.62919 .445 m
.62063 .45262 L
s
.54 .686 .934 r
.49801 .67781 m .51041 .69186 L .4881 .69252 L p F P
0 g
s
.54 .686 .934 r
.4881 .69252 m .47561 .67885 L .49801 .67781 L p F P
0 g
s
.46419 .87238 m
.48188 .87557 L
s
.46419 .87238 m
.45409 .86154 L
s
.42683 .82877 m
.44389 .85025 L
s
.42683 .82877 m
.41657 .81641 L
s
.55937 .62192 m
.57698 .57436 L
s
.57698 .57436 m
.56782 .58664 L
s
.56 .718 .947 r
.33517 .6322 m .34882 .64515 L .32737 .64723 L p F P
0 g
s
.56 .718 .947 r
.32737 .64723 m .31362 .63464 L .33517 .6322 L p F P
0 g
s
.68316 .40023 m
.70217 .40258 L
s
.68316 .40023 m
.67435 .38877 L
s
.545 .693 .936 r
.46294 .66498 m .47561 .67885 L .45347 .67987 L p F P
0 g
s
.545 .693 .936 r
.45347 .67987 m .44071 .66638 L .46294 .66498 L p F P
0 g
s
.29509 .63952 m
.31014 .66842 L
s
.73187 .55387 m
.75381 .59493 L
s
.74251 .59818 m
.73187 .55387 L
s
.37953 .76019 m
.39573 .79089 L
s
.37953 .76019 m
.36898 .74781 L
s
.524 .656 .918 r
.66094 .73512 m .67226 .75026 L .6489 .74941 L p F P
0 g
s
.524 .656 .918 r
.6489 .74941 m .6375 .73465 L .66094 .73512 L p F P
0 g
s
.49988 .86114 m
.51795 .83024 L
s
.51795 .83024 m
.50807 .82926 L
s
.528 .662 .921 r
.62594 .71968 m .6375 .73465 L .61435 .73418 L p F P
0 g
s
.528 .662 .921 r
.61435 .73418 m .60271 .7196 L .62594 .71968 L p F P
0 g
s
.551 .7 .939 r
.42775 .65269 m .44071 .66638 L .41873 .66777 L p F P
0 g
s
.551 .7 .939 r
.41873 .66777 m .40568 .65445 L .42775 .65269 L p F P
0 g
s
.565 .725 .949 r
.29965 .62186 m .31362 .63464 L .2923 .63706 L p F P
0 g
s
.565 .725 .949 r
.2923 .63706 m .27822 .62466 L .29965 .62186 L p F P
0 g
s
.2923 .63706 m
.29509 .63952 L
s
.28388 .62964 m
.2923 .63706 L
s
.533 .669 .924 r
.59091 .70482 m .60271 .7196 L .57976 .71952 L p F P
0 g
s
.533 .669 .924 r
.57976 .71952 m .56788 .70512 L .59091 .70482 L p F P
0 g
s
.33206 .69128 m
.34756 .72254 L
s
.33206 .69128 m
.32116 .67991 L
s
.50807 .82926 m
.52618 .78915 L
s
.52618 .78915 m
.51635 .79146 L
s
.59411 .51294 m
.61166 .47581 L
s
.61166 .47581 m
.60293 .48717 L
s
.556 .707 .941 r
.39243 .64094 m .40568 .65445 L .38385 .65619 L p F P
0 g
s
.556 .707 .941 r
.38385 .65619 m .3705 .64306 L .39243 .64094 L p F P
0 g
s
.538 .676 .927 r
.55583 .69051 m .56788 .70512 L .54512 .70541 L p F P
0 g
s
.538 .676 .927 r
.54512 .70541 m .53299 .69119 L .55583 .69051 L p F P
0 g
s
.54659 .69079 m
.56037 .65053 L
s
.51635 .79146 m
.53443 .74559 L
s
.53443 .74559 m
.52467 .7509 L
s
.56782 .58664 m
.58547 .5419 L
s
.58547 .5419 m
.57639 .55487 L
s
.41657 .81641 m
.43358 .83853 L
s
.41657 .81641 m
.4062 .80378 L
s
.45409 .86154 m
.47178 .86704 L
s
.45409 .86154 m
.44389 .85025 L
s
.48188 .87557 m
.49988 .86114 L
s
.48188 .87557 m
.47178 .86704 L
s
.543 .682 .93 r
.52068 .67676 m .53299 .69119 L .51041 .69186 L p F P
0 g
s
.543 .682 .93 r
.51041 .69186 m .49801 .67781 L .52068 .67676 L p F P
0 g
s
.52467 .7509 m
.54254 .70259 L
s
.54254 .70259 m
.54255 .70258 L
s
.53303 .71003 m
.54249 .70233 L
s
.74251 .59818 m
.76494 .64314 L
s
.75332 .64399 m
.74251 .59818 L
s
.71175 .42976 m
.73214 .4492 L
s
.72173 .46373 m
.71175 .42976 L
s
.71175 .42976 m
.70217 .40258 L
s
.49988 .86114 m
.48986 .85606 L
s
.65619 .40264 m
.67435 .38877 L
s
.63833 .42413 m
.65619 .40264 L
s
.65619 .40264 m
.64771 .40488 L
s
.562 .714 .943 r
.35696 .62972 m .3705 .64306 L .34882 .64515 L p F P
0 g
s
.562 .714 .943 r
.34882 .64515 m .33517 .6322 L .35696 .62972 L p F P
0 g
s
.548 .689 .932 r
.48543 .66356 m .49801 .67781 L .47561 .67885 L p F P
0 g
s
.548 .689 .932 r
.47561 .67885 m .46294 .66498 L .48543 .66356 L p F P
0 g
s
.70217 .40258 m
.72194 .41334 L
s
.70217 .40258 m
.69298 .38286 L
s
.72173 .46373 m
.74279 .49135 L
s
.7321 .5035 m
.72173 .46373 L
s
.67435 .38877 m
.69298 .38286 L
s
.67435 .38877 m
.66577 .38446 L
s
.36898 .74781 m
.38516 .77773 L
s
.36898 .74781 m
.35833 .73526 L
s
.28388 .62964 m
.29899 .65678 L
s
.62063 .45262 m
.63833 .42413 L
s
.63833 .42413 m
.62982 .43175 L
s
.527 .652 .915 r
.68467 .7356 m .69592 .75113 L .67226 .75026 L p F P
0 g
s
.527 .652 .915 r
.67226 .75026 m .66094 .73512 L .68467 .7356 L p F P
0 g
s
.553 .696 .935 r
.45009 .65091 m .46294 .66498 L .44071 .66638 L p F P
0 g
s
.553 .696 .935 r
.44071 .66638 m .42775 .65269 L .45009 .65091 L p F P
0 g
s
.567 .72 .945 r
.3213 .61904 m .33517 .6322 L .31362 .63464 L p F P
0 g
s
.567 .72 .945 r
.31362 .63464 m .29965 .62186 L .3213 .61904 L p F P
0 g
s
.531 .659 .918 r
.64946 .71977 m .66094 .73512 L .6375 .73465 L p F P
0 g
s
.531 .659 .918 r
.6375 .73465 m .62594 .71968 L .64946 .71977 L p F P
0 g
s
.32116 .67991 m
.33668 .70965 L
s
.32116 .67991 m
.31014 .66842 L
s
.535 .665 .92 r
.61422 .70452 m .62594 .71968 L .60271 .7196 L p F P
0 g
s
.535 .665 .92 r
.60271 .7196 m .59091 .70482 L .61422 .70452 L p F P
0 g
s
.55937 .62192 m
.54988 .6336 L
s
.7321 .5035 m
.75383 .53824 L
s
.74282 .54776 m
.7321 .5035 L
s
.558 .703 .937 r
.41461 .6388 m .42775 .65269 L .40568 .65445 L p F P
0 g
s
.558 .703 .937 r
.40568 .65445 m .39243 .64094 L .41461 .6388 L p F P
0 g
s
.75332 .64399 m
.77609 .69038 L
s
.76418 .68961 m
.75332 .64399 L
s
.48986 .85606 m
.50807 .82926 L
s
.50807 .82926 m
.49804 .82741 L
s
.54 .672 .923 r
.57895 .68983 m .59091 .70482 L .56788 .70512 L p F P
0 g
s
.54 .672 .923 r
.56788 .70512 m .55583 .69051 L .57895 .68983 L p F P
0 g
s
.4062 .80378 m
.42317 .82638 L
s
.4062 .80378 m
.39573 .79089 L
s
.57639 .55487 m
.59411 .51294 L
s
.59411 .51294 m
.58512 .52651 L
s
.69298 .38286 m
.71223 .38493 L
s
.69298 .38286 m
.68414 .37099 L
s
.573 .727 .947 r
.28546 .60889 m .29965 .62186 L .27822 .62466 L p F P
0 g
s
.573 .727 .947 r
.27822 .62466 m .26393 .61206 L .28546 .60889 L p F P
0 g
s
.27822 .62466 m
.28388 .62964 L
s
.27253 .61964 m
.27822 .62466 L
s
.44389 .85025 m
.46158 .85787 L
s
.44389 .85025 m
.43358 .83853 L
s
.545 .679 .926 r
.54361 .6757 m .55583 .69051 L .53299 .69119 L p F P
0 g
s
.54493 .6773 m
.55101 .66058 L
s
.545 .679 .926 r
.53299 .69119 m .52068 .67676 L .54361 .6757 L p F P
0 g
s
.53303 .71003 m
.53992 .69107 L
s
.53992 .69107 m
.53995 .69098 L
s
.60293 .48717 m
.62063 .45262 L
s
.62063 .45262 m
.61197 .46427 L
s
.47178 .86704 m
.48986 .85606 L
s
.47178 .86704 m
.46158 .85787 L
s
.563 .71 .939 r
.37899 .62722 m .39243 .64094 L .3705 .64306 L p F P
0 g
s
.563 .71 .939 r
.3705 .64306 m .35696 .62972 L .37899 .62722 L p F P
0 g
s
.35833 .73526 m
.37448 .7643 L
s
.35833 .73526 m
.34756 .72254 L
s
.94521 .51622 m
.93203 .57284 L
s
.94453 .55654 m
.94521 .51622 L
s
.55 .685 .929 r
.50819 .66213 m .52068 .67676 L .49801 .67781 L p F P
0 g
s
.55 .685 .929 r
.49801 .67781 m .48543 .66356 L .50819 .66213 L p F P
0 g
s
.49804 .82741 m
.51635 .79146 L
s
.51635 .79146 m
.50634 .79288 L
s
.48986 .85606 m
.4797 .85018 L
s
.54988 .6336 m
.56782 .58664 L
s
.56782 .58664 m
.55842 .5997 L
s
.569 .716 .941 r
.3432 .61619 m .35696 .62972 L .33517 .6322 L p F P
0 g
s
.569 .716 .941 r
.33517 .6322 m .3213 .61904 L .3432 .61619 L p F P
0 g
s
.555 .692 .931 r
.47267 .64911 m .48543 .66356 L .46294 .66498 L p F P
0 g
s
.555 .692 .931 r
.46294 .66498 m .45009 .65091 L .47267 .64911 L p F P
0 g
s
.74282 .54776 m
.76515 .588 L
s
.75381 .59493 m
.74282 .54776 L
s
.529 .649 .911 r
.7087 .73608 m .71987 .752 L .69592 .75113 L p F P
0 g
s
.529 .649 .911 r
.69592 .75113 m .68467 .7356 L .7087 .73608 L p F P
0 g
s
.78707 .73454 m
.76418 .68961 L
s
.31014 .66842 m
.32569 .69659 L
s
.31014 .66842 m
.29899 .65678 L
s
.533 .655 .914 r
.67327 .71986 m .68467 .7356 L .66094 .73512 L p F P
0 g
s
.533 .655 .914 r
.66094 .73512 m .64946 .71977 L .67327 .71986 L p F P
0 g
s
.50634 .79288 m
.52467 .7509 L
s
.52467 .7509 m
.51471 .75539 L
s
.39573 .79089 m
.41266 .81379 L
s
.39573 .79089 m
.38516 .77773 L
s
.538 .662 .917 r
.63782 .70421 m .64946 .71977 L .62594 .71968 L p F P
0 g
s
.538 .662 .917 r
.62594 .71968 m .61422 .70452 L .63782 .70421 L p F P
0 g
s
.66577 .38446 m
.68414 .37099 L
s
.64771 .40488 m
.66577 .38446 L
s
.66577 .38446 m
.65734 .38708 L
s
.56 .699 .933 r
.43704 .63663 m .45009 .65091 L .42775 .65269 L p F P
0 g
s
.56 .699 .933 r
.42775 .65269 m .41461 .6388 L .43704 .63663 L p F P
0 g
s
.72194 .41334 m
.74259 .43181 L
s
.73214 .4492 m
.72194 .41334 L
s
.72194 .41334 m
.71223 .38493 L
s
.575 .723 .943 r
.30723 .60568 m .3213 .61904 L .29965 .62186 L p F P
0 g
s
.575 .723 .943 r
.29965 .62186 m .28546 .60889 L .30723 .60568 L p F P
0 g
s
.27262 .6198 m
.28771 .64501 L
s
.27253 .61964 m
.27262 .6198 L
s
.43358 .83853 m
.45125 .84806 L
s
.43358 .83853 m
.42317 .82638 L
s
.542 .668 .919 r
.60234 .68914 m .61422 .70452 L .59091 .70482 L p F P
0 g
s
.542 .668 .919 r
.59091 .70482 m .57895 .68983 L .60234 .68914 L p F P
0 g
s
.71223 .38493 m
.73222 .39469 L
s
.71223 .38493 m
.70297 .36476 L
s
.68414 .37099 m
.70297 .36476 L
s
.68414 .37099 m
.67559 .36702 L
s
.62982 .43175 m
.64771 .40488 L
s
.64771 .40488 m
.63926 .41297 L
s
.51471 .75539 m
.53303 .71003 L
s
.53303 .71003 m
.52313 .71728 L
s
.58512 .52651 m
.60293 .48717 L
s
.60293 .48717 m
.59402 .5014 L
s
.547 .675 .922 r
.56681 .67463 m .57895 .68983 L .55583 .69051 L p F P
0 g
s
.547 .675 .922 r
.55583 .69051 m .54361 .6757 L .56681 .67463 L p F P
0 g
s
.73214 .4492 m
.7535 .47586 L
s
.74279 .49135 m
.73214 .4492 L
s
.565 .705 .936 r
.40127 .6247 m .41461 .6388 L .39243 .64094 L p F P
0 g
s
.565 .705 .936 r
.39243 .64094 m .37899 .62722 L .40127 .6247 L p F P
0 g
s
.34756 .72254 m
.3637 .75062 L
s
.34756 .72254 m
.33668 .70965 L
s
.46158 .85787 m
.4797 .85018 L
s
.46158 .85787 m
.45125 .84806 L
s
.55842 .5997 m
.57639 .55487 L
s
.57639 .55487 m
.56708 .5691 L
s
.58 .73 .945 r
.27105 .5957 m .28546 .60889 L .26393 .61206 L p F P
0 g
s
.58 .73 .945 r
.26393 .61206 m .2494 .59926 L .27105 .5957 L p F P
0 g
s
.26393 .61206 m
.27253 .61964 L
s
.26104 .60951 m
.26393 .61206 L
s
.552 .682 .925 r
.53121 .66068 m .54361 .6757 L .52068 .67676 L p F P
0 g
s
.54142 .67057 m
.55937 .62192 L
s
.54142 .67057 m
.55101 .66058 L
s
.552 .682 .925 r
.52068 .67676 m .50819 .66213 L .53121 .66068 L p F P
0 g
s
.4797 .85018 m
.49804 .82741 L
s
.49804 .82741 m
.48785 .8246 L
s
.75381 .59493 m
.77661 .63843 L
s
.76494 .64314 m
.75381 .59493 L
s
.52313 .71728 m
.53813 .67898 L
s
.54076 .67225 m
.54142 .67057 L
s
.53763 .67429 m
.53764 .67427 L
s
.54029 .67168 m
.54142 .67057 L
s
.571 .712 .938 r
.36534 .6133 m .37899 .62722 L .35696 .62972 L p F P
0 g
s
.571 .712 .938 r
.35696 .62972 m .3432 .61619 L .36534 .6133 L p F P
0 g
s
.557 .688 .927 r
.49552 .64729 m .50819 .66213 L .48543 .66356 L p F P
0 g
s
.557 .688 .927 r
.48543 .66356 m .47267 .64911 L .49552 .64729 L p F P
0 g
s
.26104 .60951 m
.27631 .6331 L
s
.61197 .46427 m
.62982 .43175 L
s
.62982 .43175 m
.62123 .44402 L
s
.70297 .36476 m
.7224 .3658 L
s
.70297 .36476 m
.69414 .35325 L
s
.4797 .85018 m
.46941 .84345 L
s
.38516 .77773 m
.40205 .80077 L
s
.38516 .77773 m
.37448 .7643 L
s
.29899 .65678 m
.31459 .68335 L
s
.29899 .65678 m
.28771 .64501 L
s
.531 .646 .907 r
.73303 .73657 m .74413 .75289 L .71987 .752 L p F P
0 g
s
.531 .646 .907 r
.71987 .752 m .7087 .73608 L .73303 .73657 L p F P
0 g
s
.74279 .49135 m
.76484 .52507 L
s
.75383 .53824 m
.74279 .49135 L
s
.535 .652 .91 r
.69737 .71994 m .7087 .73608 L .68467 .7356 L p F P
0 g
s
.535 .652 .91 r
.68467 .7356 m .67327 .71986 L .69737 .71994 L p F P
0 g
s
.562 .695 .93 r
.45972 .63444 m .47267 .64911 L .45009 .65091 L p F P
0 g
s
.562 .695 .93 r
.45009 .65091 m .43704 .63663 L .45972 .63444 L p F P
0 g
s
.576 .719 .94 r
.32923 .60244 m .3432 .61619 L .3213 .61904 L p F P
0 g
s
.576 .719 .94 r
.3213 .61904 m .30723 .60568 L .32923 .60244 L p F P
0 g
s
.42317 .82638 m
.44082 .8376 L
s
.42317 .82638 m
.41266 .81379 L
s
.54 .658 .913 r
.66171 .7039 m .67327 .71986 L .64946 .71977 L p F P
0 g
s
.54 .658 .913 r
.64946 .71977 m .63782 .70421 L .66171 .7039 L p F P
0 g
s
.48785 .8246 m
.50634 .79288 L
s
.50634 .79288 m
.49615 .79329 L
s
.544 .665 .916 r
.62602 .68844 m .63782 .70421 L .61422 .70452 L p F P
0 g
s
.544 .665 .916 r
.61422 .70452 m .60234 .68914 L .62602 .68844 L p F P
0 g
s
.33668 .70965 m
.35282 .73667 L
s
.33668 .70965 m
.32569 .69659 L
s
.567 .701 .932 r
.4238 .62214 m .43704 .63663 L .41461 .6388 L p F P
0 g
s
.567 .701 .932 r
.41461 .6388 m .40127 .6247 L .4238 .62214 L p F P
0 g
s
.549 .671 .918 r
.5903 .67354 m .60234 .68914 L .57895 .68983 L p F P
0 g
s
.549 .671 .918 r
.57895 .68983 m .56681 .67463 L .5903 .67354 L p F P
0 g
s
.45125 .84806 m
.46941 .84345 L
s
.45125 .84806 m
.44082 .8376 L
s
.582 .725 .942 r
.29293 .59211 m .30723 .60568 L .28546 .60889 L p F P
0 g
s
.582 .725 .942 r
.28546 .60889 m .27105 .5957 L .29293 .59211 L p F P
0 g
s
.56708 .5691 m
.58512 .52651 L
s
.58512 .52651 m
.57589 .54184 L
s
.76494 .64314 m
.78803 .68716 L
s
.77609 .69038 m
.76494 .64314 L
s
.553 .678 .921 r
.55451 .65921 m .56681 .67463 L .54361 .6757 L p F P
0 g
s
.553 .678 .921 r
.54361 .6757 m .53121 .66068 L .55451 .65921 L p F P
0 g
s
.53946 .66016 m
.54988 .6336 L
s
.5369 .66668 m
.5369 .66667 L
s
.5369 .66669 m
.5369 .66668 L
s
.5316 .6802 m
.5369 .66669 L
s
.5316 .6802 m
.53762 .6743 L
s
.53762 .6743 m
.53763 .67429 L
s
.572 .708 .934 r
.38772 .61038 m .40127 .6247 L .37899 .62722 L p F P
0 g
s
.572 .708 .934 r
.37899 .62722 m .36534 .6133 L .38772 .61038 L p F P
0 g
s
.93203 .57284 m
.93107 .61523 L
s
.93203 .57284 m
.91877 .63297 L
s
.59402 .5014 m
.61197 .46427 L
s
.61197 .46427 m
.60314 .47934 L
s
.73222 .39469 m
.75307 .41154 L
s
.74259 .43181 m
.73222 .39469 L
s
.73222 .39469 m
.7224 .3658 L
s
.49615 .79329 m
.51471 .75539 L
s
.51471 .75539 m
.50454 .75892 L
s
.67559 .36702 m
.69414 .35325 L
s
.65734 .38708 m
.67559 .36702 L
s
.67559 .36702 m
.66723 .37073 L
s
.37448 .7643 m
.39134 .78733 L
s
.37448 .7643 m
.3637 .75062 L
s
.558 .684 .924 r
.51864 .64544 m .53121 .66068 L .50819 .66213 L p F P
0 g
s
.558 .684 .924 r
.50819 .66213 m .49552 .64729 L .51864 .64544 L p F P
0 g
s
.75383 .53824 m
.7765 .57723 L
s
.76515 .588 m
.75383 .53824 L
s
.7224 .3658 m
.74256 .37388 L
s
.7224 .3658 m
.71314 .34602 L
s
.588 .732 .943 r
.25641 .58231 m .27105 .5957 L .2494 .59926 L p F P
0 g
s
.588 .732 .943 r
.2494 .59926 m .23465 .58626 L .25641 .58231 L p F P
0 g
s
.2494 .59926 m
.26104 .60951 L
s
.2494 .59926 m
.26477 .62105 L
s
.23762 .58887 m
.2494 .59926 L
s
.28771 .64501 m
.30336 .66994 L
s
.28771 .64501 m
.27631 .6331 L
s
.69414 .35325 m
.71314 .34602 L
s
.69414 .35325 m
.68566 .35045 L
s
.63926 .41297 m
.65734 .38708 L
s
.65734 .38708 m
.64897 .39621 L
s
.46941 .84345 m
.48785 .8246 L
s
.48785 .8246 m
.47751 .8208 L
s
.41266 .81379 m
.43027 .8265 L
s
.41266 .81379 m
.40205 .80077 L
s
.55842 .5997 m
.54876 .6131 L
s
.578 .715 .936 r
.35148 .59916 m .36534 .6133 L .3432 .61619 L p F P
0 g
s
.578 .715 .936 r
.3432 .61619 m .32923 .60244 L .35148 .59916 L p F P
0 g
s
.74259 .43181 m
.76419 .45694 L
s
.7535 .47586 m
.74259 .43181 L
s
.533 .642 .903 r
.75767 .73707 m .7687 .75379 L .74413 .75289 L p F P
0 g
s
.533 .642 .903 r
.74413 .75289 m .73303 .73657 L .75767 .73707 L p F P
0 g
s
.46941 .84345 m
.45899 .83587 L
s
.563 .691 .926 r
.48267 .63222 m .49552 .64729 L .47267 .64911 L p F P
0 g
s
.563 .691 .926 r
.47267 .64911 m .45972 .63444 L .48267 .63222 L p F P
0 g
s
.537 .649 .906 r
.72178 .72003 m .73303 .73657 L .7087 .73608 L p F P
0 g
s
.537 .649 .906 r
.7087 .73608 m .69737 .71994 L .72178 .72003 L p F P
0 g
s
.542 .655 .909 r
.68589 .70359 m .69737 .71994 L .67327 .71986 L p F P
0 g
s
.542 .655 .909 r
.67327 .71986 m .66171 .7039 L .68589 .70359 L p F P
0 g
s
.50454 .75892 m
.52313 .71728 L
s
.52313 .71728 m
.513 .72367 L
s
.32569 .69659 m
.34183 .72247 L
s
.32569 .69659 m
.31459 .68335 L
s
.546 .661 .912 r
.64999 .68773 m .66171 .7039 L .63782 .70421 L p F P
0 g
s
.546 .661 .912 r
.63782 .70421 m .62602 .68844 L .64999 .68773 L p F P
0 g
s
.569 .697 .928 r
.44658 .61956 m .45972 .63444 L .43704 .63663 L p F P
0 g
s
.569 .697 .928 r
.43704 .63663 m .4238 .62214 L .44658 .61956 L p F P
0 g
s
.78707 .73454 m
.77609 .69038 L
s
.583 .721 .938 r
.31505 .58848 m .32923 .60244 L .30723 .60568 L p F P
0 g
s
.583 .721 .938 r
.30723 .60568 m .29293 .59211 L .31505 .58848 L p F P
0 g
s
.55 .668 .915 r
.61406 .67244 m .62602 .68844 L .60234 .68914 L p F P
0 g
s
.55 .668 .915 r
.60234 .68914 m .5903 .67354 L .61406 .67244 L p F P
0 g
s
.62123 .44402 m
.63926 .41297 L
s
.63926 .41297 m
.63076 .42629 L
s
.44082 .8376 m
.45899 .83587 L
s
.44082 .8376 m
.43027 .8265 L
s
.71314 .34602 m
.73271 .34538 L
s
.71314 .34602 m
.70438 .33578 L
s
.555 .674 .917 r
.57808 .65773 m .5903 .67354 L .56681 .67463 L p F P
0 g
s
.555 .674 .917 r
.56681 .67463 m .55451 .65921 L .57808 .65773 L p F P
0 g
s
.574 .704 .93 r
.41036 .60743 m .4238 .62214 L .40127 .6247 L p F P
0 g
s
.574 .704 .93 r
.40127 .6247 m .38772 .61038 L .41036 .60743 L p F P
0 g
s
.3637 .75062 m
.38053 .77347 L
s
.3637 .75062 m
.35282 .73667 L
s
.7535 .47586 m
.77583 .5081 L
s
.76484 .52507 m
.7535 .47586 L
s
.47751 .8208 m
.49615 .79329 L
s
.49615 .79329 m
.48578 .7926 L
s
.57589 .54184 m
.59402 .5014 L
s
.59402 .5014 m
.58489 .51786 L
s
.513 .72367 m
.5316 .6802 L
s
.5316 .6802 m
.52153 .68916 L
s
.56 .681 .92 r
.54203 .64358 m .55451 .65921 L .53121 .66068 L p F P
0 g
s
.56 .681 .92 r
.53121 .66068 m .51864 .64544 L .54203 .64358 L p F P
0 g
s
.5415 .64362 m
.54988 .6336 L
s
.54077 .64368 m
.55842 .5997 L
s
.76515 .588 m
.78829 .62983 L
s
.77661 .63843 m
.76515 .588 L
s
.589 .728 .94 r
.27841 .57833 m .29293 .59211 L .27105 .5957 L p F P
0 g
s
.589 .728 .94 r
.27105 .5957 m .25641 .58231 L .27841 .57833 L p F P
0 g
s
.40205 .80077 m
.41963 .81474 L
s
.40205 .80077 m
.39134 .78733 L
s
.54876 .6131 m
.56708 .5691 L
s
.56708 .5691 m
.55751 .58406 L
s
.27631 .6331 m
.29202 .65636 L
s
.27631 .6331 m
.26477 .62105 L
s
.579 .711 .933 r
.37397 .59585 m .38772 .61038 L .36534 .6133 L p F P
0 g
s
.579 .711 .933 r
.36534 .6133 m .35148 .59916 L .37397 .59585 L p F P
0 g
s
.23762 .58887 m
.25309 .60885 L
s
.565 .687 .922 r
.50588 .62998 m .51864 .64544 L .49552 .64729 L p F P
0 g
s
.565 .687 .922 r
.49552 .64729 m .48267 .63222 L .50588 .62998 L p F P
0 g
s
.535 .639 .9 r
.78263 .73757 m .79359 .7547 L .7687 .75379 L p F P
0 g
s
.535 .639 .9 r
.7687 .75379 m .75767 .73707 L .78263 .73757 L p F P
0 g
s
.31459 .68335 m
.33074 .70801 L
s
.31459 .68335 m
.30336 .66994 L
s
.539 .645 .902 r
.7465 .72012 m .75767 .73707 L .73303 .73657 L p F P
0 g
s
.539 .645 .902 r
.73303 .73657 m .72178 .72003 L .7465 .72012 L p F P
0 g
s
.45899 .83587 m
.47751 .8208 L
s
.45899 .83587 m
.44845 .82741 L
s
.60314 .47934 m
.62123 .44402 L
s
.62123 .44402 m
.6125 .46023 L
s
.74256 .37388 m
.76355 .38852 L
s
.75307 .41154 m
.74256 .37388 L
s
.74256 .37388 m
.73271 .34538 L
s
.543 .651 .905 r
.71038 .70327 m .72178 .72003 L .69737 .71994 L p F P
0 g
s
.543 .651 .905 r
.69737 .71994 m .68589 .70359 L .71038 .70327 L p F P
0 g
s
.595 .734 .941 r
.24154 .56871 m .25641 .58231 L .23465 .58626 L p F P
0 g
s
.595 .734 .941 r
.23465 .58626 m .21966 .57305 L .24154 .56871 L p F P
0 g
s
.23465 .58626 m
.23762 .58887 L
s
.22568 .57836 m
.23465 .58626 L
s
.47751 .8208 m
.46702 .81594 L
s
.57 .694 .925 r
.46963 .61694 m .48267 .63222 L .45972 .63444 L p F P
0 g
s
.57 .694 .925 r
.45972 .63444 m .44658 .61956 L .46963 .61694 L p F P
0 g
s
.585 .717 .934 r
.33741 .58481 m .35148 .59916 L .32923 .60244 L p F P
0 g
s
.585 .717 .934 r
.32923 .60244 m .31505 .58848 L .33741 .58481 L p F P
0 g
s
.548 .658 .908 r
.67426 .68701 m .68589 .70359 L .66171 .7039 L p F P
0 g
s
.548 .658 .908 r
.66171 .7039 m .64999 .68773 L .67426 .68701 L p F P
0 g
s
.93107 .61523 m
.94453 .55654 L
s
.94408 .60081 m
.94453 .55654 L
s
.73271 .34538 m
.75298 .35118 L
s
.73271 .34538 m
.72351 .32697 L
s
.43027 .8265 m
.44845 .82741 L
s
.43027 .8265 m
.41963 .81474 L
s
.48578 .7926 m
.50454 .75892 L
s
.50454 .75892 m
.49418 .76131 L
s
.552 .664 .911 r
.63812 .67133 m .64999 .68773 L .62602 .68844 L p F P
0 g
s
.552 .664 .911 r
.62602 .68844 m .61406 .67244 L .63812 .67133 L p F P
0 g
s
.52153 .68916 m
.53645 .65395 L
s
.53645 .65395 m
.5365 .65383 L
s
.53013 .65649 m
.53655 .64928 L
s
.53655 .64928 m
.53663 .6492 L
s
.35282 .73667 m
.36962 .7592 L
s
.35282 .73667 m
.34183 .72247 L
s
.68566 .35045 m
.70438 .33578 L
s
.66723 .37073 m
.68566 .35045 L
s
.68566 .35045 m
.67744 .35604 L
s
.75307 .41154 m
.77484 .4346 L
s
.76419 .45694 m
.75307 .41154 L
s
.575 .7 .927 r
.43325 .60445 m .44658 .61956 L .4238 .62214 L p F P
0 g
s
.575 .7 .927 r
.4238 .62214 m .41036 .60743 L .43325 .60445 L p F P
0 g
s
.557 .67 .914 r
.60193 .65622 m .61406 .67244 L .5903 .67354 L p F P
0 g
s
.557 .67 .914 r
.5903 .67354 m .57808 .65773 L .60193 .65622 L p F P
0 g
s
.70438 .33578 m
.72351 .32697 L
s
.70438 .33578 m
.69604 .33506 L
s
.76484 .52507 m
.78782 .56252 L
s
.7765 .57723 m
.76484 .52507 L
s
.64897 .39621 m
.66723 .37073 L
s
.66723 .37073 m
.659 .38157 L
s
.59 .724 .936 r
.30065 .5743 m .31505 .58848 L .29293 .59211 L p F P
0 g
s
.59 .724 .936 r
.29293 .59211 m .27841 .57833 L .30065 .5743 L p F P
0 g
s
.39134 .78733 m
.40887 .80233 L
s
.39134 .78733 m
.38053 .77347 L
s
.77661 .63843 m
.79999 .68009 L
s
.78803 .68716 m
.77661 .63843 L
s
.562 .677 .916 r
.56569 .64169 m .57808 .65773 L .55451 .65921 L p F P
0 g
s
.562 .677 .916 r
.55451 .65921 m .54203 .64358 L .56569 .64169 L p F P
0 g
s
.26477 .62105 m
.28056 .6426 L
s
.26477 .62105 m
.25309 .60885 L
s
.91877 .63297 m
.91686 .6719 L
s
.91877 .63297 m
.9047 .69075 L
s
.58 .707 .929 r
.39672 .5925 m .41036 .60743 L .38772 .61038 L p F P
0 g
s
.58 .707 .929 r
.38772 .61038 m .37397 .59585 L .39672 .5925 L p F P
0 g
s
.55751 .58406 m
.57589 .54184 L
s
.57589 .54184 m
.5664 .55828 L
s
.566 .683 .919 r
.52936 .62771 m .54203 .64358 L .51864 .64544 L p F P
0 g
s
.566 .683 .919 r
.51864 .64544 m .50588 .62998 L .52936 .62771 L p F P
0 g
s
.30336 .66994 m
.31954 .6933 L
s
.30336 .66994 m
.29202 .65636 L
s
.22568 .57836 m
.24128 .5965 L
s
.49418 .76131 m
.513 .72367 L
s
.513 .72367 m
.50266 .72898 L
s
.72351 .32697 m
.74317 .32409 L
s
.72351 .32697 m
.71489 .31901 L
s
.596 .73 .938 r
.26366 .56433 m .27841 .57833 L .25641 .58231 L p F P
0 g
s
.596 .73 .938 r
.25641 .58231 m .24154 .56871 L .26366 .56433 L p F P
0 g
s
.63076 .42629 m
.64897 .39621 L
s
.64897 .39621 m
.64059 .41112 L
s
.58489 .51786 m
.60314 .47934 L
s
.60314 .47934 m
.5941 .49709 L
s
.537 .636 .896 r
.80791 .73808 m .81881 .75563 L .79359 .7547 L p F P
0 g
s
.78707 .73454 m
.7973 .7504 L
s
.537 .636 .896 r
.79359 .7547 m .78263 .73757 L .80791 .73808 L p F P
0 g
s
.541 .642 .899 r
.77153 .72021 m .78263 .73757 L .75767 .73707 L p F P
0 g
s
.77609 .69038 m
.79919 .73175 L
s
.541 .642 .899 r
.75767 .73707 m .7465 .72012 L .77153 .72021 L p F P
0 g
s
.586 .713 .931 r
.36001 .5811 m .37397 .59585 L .35148 .59916 L p F P
0 g
s
.586 .713 .931 r
.35148 .59916 m .33741 .58481 L .36001 .5811 L p F P
0 g
s
.46702 .81594 m
.48578 .7926 L
s
.48578 .7926 m
.47525 .7907 L
s
.571 .69 .921 r
.49294 .6143 m .50588 .62998 L .48267 .63222 L p F P
0 g
s
.571 .69 .921 r
.48267 .63222 m .46963 .61694 L .49294 .6143 L p F P
0 g
s
.44845 .82741 m
.46702 .81594 L
s
.44845 .82741 m
.43779 .81806 L
s
.545 .648 .902 r
.73517 .70295 m .7465 .72012 L .72178 .72003 L p F P
0 g
s
.545 .648 .902 r
.72178 .72003 m .71038 .70327 L .73517 .70295 L p F P
0 g
s
.76419 .45694 m
.78675 .48727 L
s
.77583 .5081 m
.76419 .45694 L
s
.34183 .72247 m
.35861 .74451 L
s
.34183 .72247 m
.33074 .70801 L
s
.41963 .81474 m
.43779 .81806 L
s
.41963 .81474 m
.40887 .80233 L
s
.549 .654 .904 r
.69882 .68628 m .71038 .70327 L .68589 .70359 L p F P
0 g
s
.549 .654 .904 r
.68589 .70359 m .67426 .68701 L .69882 .68628 L p F P
0 g
s
.554 .66 .907 r
.66246 .6702 m .67426 .68701 L .64999 .68773 L p F P
0 g
s
.554 .66 .907 r
.64999 .68773 m .63812 .67133 L .66246 .6702 L p F P
0 g
s
.576 .696 .923 r
.4564 .60143 m .46963 .61694 L .44658 .61956 L p F P
0 g
s
.576 .696 .923 r
.44658 .61956 m .43325 .60445 L .4564 .60143 L p F P
0 g
s
.46702 .81594 m
.45639 .80998 L
s
.602 .736 .939 r
.22644 .55489 m .24154 .56871 L .21966 .57305 L p F P
0 g
s
.602 .736 .939 r
.21966 .57305 m .20442 .55963 L .22644 .55489 L p F P
0 g
s
.21966 .57305 m
.22568 .57836 L
s
.21359 .56771 m
.21966 .57305 L
s
.38053 .77347 m
.39802 .78929 L
s
.38053 .77347 m
.36962 .7592 L
s
.558 .667 .91 r
.62607 .6547 m .63812 .67133 L .61406 .67244 L p F P
0 g
s
.558 .667 .91 r
.61406 .67244 m .60193 .65622 L .62607 .6547 L p F P
0 g
s
.591 .719 .933 r
.32312 .57023 m .33741 .58481 L .31505 .58848 L p F P
0 g
s
.591 .719 .933 r
.31505 .58848 m .30065 .5743 L .32312 .57023 L p F P
0 g
s
.79919 .73175 m
.78803 .68716 L
s
.75298 .35118 m
.77404 .36305 L
s
.76355 .38852 m
.75298 .35118 L
s
.75298 .35118 m
.74317 .32409 L
s
.7765 .57723 m
.79995 .61731 L
s
.78829 .62983 m
.7765 .57723 L
s
.563 .673 .912 r
.58963 .63978 m .60193 .65622 L .57808 .65773 L p F P
0 g
s
.563 .673 .912 r
.57808 .65773 m .56569 .64169 L .58963 .63978 L p F P
0 g
s
.50266 .72898 m
.52153 .68916 L
s
.52153 .68916 m
.51123 .69715 L
s
.582 .703 .925 r
.41971 .58912 m .43325 .60445 L .41036 .60743 L p F P
0 g
s
.582 .703 .925 r
.41036 .60743 m .39672 .5925 L .41971 .58912 L p F P
0 g
s
.6125 .46023 m
.63076 .42629 L
s
.63076 .42629 m
.62214 .44403 L
s
.25309 .60885 m
.26897 .62866 L
s
.25309 .60885 m
.24128 .5965 L
s
.74317 .32409 m
.76349 .32708 L
s
.74317 .32409 m
.73412 .30814 L
s
.29202 .65636 m
.30824 .67834 L
s
.29202 .65636 m
.28056 .6426 L
s
.76355 .38852 m
.78543 .40898 L
s
.77484 .4346 m
.76355 .38852 L
s
.568 .679 .915 r
.55312 .62542 m .56569 .64169 L .54203 .64358 L p F P
0 g
s
.568 .679 .915 r
.54203 .64358 m .52936 .62771 L .55312 .62542 L p F P
0 g
s
.54305 .62639 m
.54876 .6131 L
s
.53013 .65649 m
.53693 .64066 L
s
.53693 .64066 m
.53694 .64063 L
s
.597 .726 .934 r
.28602 .5599 m .30065 .5743 L .27841 .57833 L p F P
0 g
s
.597 .726 .934 r
.27841 .57833 m .26366 .56433 L .28602 .5599 L p F P
0 g
s
.47525 .7907 m
.49418 .76131 L
s
.49418 .76131 m
.48362 .76242 L
s
.587 .709 .927 r
.38287 .57734 m .39672 .5925 L .37397 .59585 L p F P
0 g
s
.587 .709 .927 r
.37397 .59585 m .36001 .5811 L .38287 .57734 L p F P
0 g
s
.33074 .70801 m
.3475 .72943 L
s
.33074 .70801 m
.31954 .6933 L
s
.573 .686 .917 r
.51652 .61162 m .52936 .62771 L .50588 .62998 L p F P
0 g
s
.573 .686 .917 r
.50588 .62998 m .49294 .6143 L .51652 .61162 L p F P
0 g
s
.40887 .80233 m
.42701 .8078 L
s
.40887 .80233 m
.39802 .78929 L
s
.5664 .55828 m
.58489 .51786 L
s
.58489 .51786 m
.57548 .53581 L
s
.55751 .58406 m
.54765 .59917 L
s
.539 .633 .892 r
.83352 .7386 m .84435 .75656 L .81881 .75563 L p F P
0 g
s
.539 .633 .892 r
.81881 .75563 m .80791 .73808 L .83352 .7386 L p F P
0 g
s
.80642 .74153 m
.82209 .76274 L
s
.80639 .74149 m
.80642 .74153 L
s
.80347 .74701 m
.80988 .76992 L
s
.80341 .74682 m
.80347 .74701 L
s
.80038 .75518 m
.80988 .76992 L
s
.80023 .75495 m
.80038 .75518 L
s
.543 .639 .895 r
.79688 .7203 m .80791 .73808 L .78263 .73757 L p F P
0 g
s
.543 .639 .895 r
.78263 .73757 m .77153 .72021 L .79688 .7203 L p F P
0 g
s
.77583 .5081 m
.79907 .54378 L
s
.78782 .56252 m
.77583 .5081 L
s
.43779 .81806 m
.45639 .80998 L
s
.43779 .81806 m
.42701 .8078 L
s
.547 .645 .898 r
.76028 .70262 m .77153 .72021 L .7465 .72012 L p F P
0 g
s
.547 .645 .898 r
.7465 .72012 m .73517 .70295 L .76028 .70262 L p F P
0 g
s
.69604 .33506 m
.71489 .31901 L
s
.67744 .35604 m
.69604 .33506 L
s
.69604 .33506 m
.68801 .34341 L
s
.551 .651 .901 r
.72369 .68555 m .73517 .70295 L .71038 .70327 L p F P
0 g
s
.551 .651 .901 r
.71038 .70327 m .69882 .68628 L .72369 .68555 L p F P
0 g
s
.71489 .31901 m
.73412 .30814 L
s
.71489 .31901 m
.70676 .32137 L
s
.36962 .7592 m
.38707 .7756 L
s
.36962 .7592 m
.35861 .74451 L
s
.91686 .6719 m
.93107 .61523 L
s
.93107 .61523 m
.92964 .65603 L
s
.603 .732 .936 r
.24868 .55011 m .26366 .56433 L .24154 .56871 L p F P
0 g
s
.603 .732 .936 r
.24154 .56871 m .22644 .55489 L .24868 .55011 L p F P
0 g
s
.21373 .56785 m
.22933 .58401 L
s
.21359 .56771 m
.21373 .56785 L
s
.578 .692 .92 r
.47981 .59838 m .49294 .6143 L .46963 .61694 L p F P
0 g
s
.578 .692 .92 r
.46963 .61694 m .4564 .60143 L .47981 .59838 L p F P
0 g
s
.555 .657 .904 r
.68711 .66906 m .69882 .68628 L .67426 .68701 L p F P
0 g
s
.555 .657 .904 r
.67426 .68701 m .66246 .6702 L .68711 .66906 L p F P
0 g
s
.592 .715 .929 r
.34584 .56611 m .36001 .5811 L .33741 .58481 L p F P
0 g
s
.592 .715 .929 r
.33741 .58481 m .32312 .57023 L .34584 .56611 L p F P
0 g
s
.659 .38157 m
.67744 .35604 L
s
.67744 .35604 m
.66937 .36933 L
s
.83201 .79048 m
.80988 .76992 L
s
.51123 .69715 m
.53013 .65649 L
s
.53013 .65649 m
.51988 .6669 L
s
.56 .663 .906 r
.65051 .65316 m .66246 .6702 L .63812 .67133 L p F P
0 g
s
.56 .663 .906 r
.63812 .67133 m .62607 .6547 L .65051 .65316 L p F P
0 g
s
.45639 .80998 m
.47525 .7907 L
s
.47525 .7907 m
.46455 .78753 L
s
.77484 .4346 m
.79756 .46262 L
s
.78675 .48727 m
.77484 .4346 L
s
.5941 .49709 m
.6125 .46023 L
s
.6125 .46023 m
.60356 .47952 L
s
.583 .699 .922 r
.44296 .58569 m .4564 .60143 L .43325 .60445 L p F P
0 g
s
.583 .699 .922 r
.43325 .60445 m .41971 .58912 L .44296 .58569 L p F P
0 g
s
.73412 .30814 m
.75384 .30257 L
s
.73412 .30814 m
.72574 .30358 L
s
.45639 .80998 m
.44562 .80289 L
s
.564 .669 .909 r
.61386 .63784 m .62607 .6547 L .60193 .65622 L p F P
0 g
s
.564 .669 .909 r
.60193 .65622 m .58963 .63978 L .61386 .63784 L p F P
0 g
s
.78829 .62983 m
.81195 .66933 L
s
.79999 .68009 m
.78829 .62983 L
s
.28056 .6426 m
.29682 .66313 L
s
.28056 .6426 m
.26897 .62866 L
s
.24128 .5965 m
.25726 .61455 L
s
.24128 .5965 m
.22933 .58401 L
s
.48362 .76242 m
.50266 .72898 L
s
.50266 .72898 m
.49211 .73298 L
s
.9047 .69075 m
.90132 .72098 L
s
.9047 .69075 m
.88925 .74004 L
s
.598 .722 .931 r
.30861 .55542 m .32312 .57023 L .30065 .5743 L p F P
0 g
s
.598 .722 .931 r
.30065 .5743 m .28602 .5599 L .30861 .55542 L p F P
0 g
s
.608 .738 .937 r
.21108 .54084 m .22644 .55489 L .20442 .55963 L p F P
0 g
s
.608 .738 .937 r
.20442 .55963 m .18894 .54598 L .21108 .54084 L p F P
0 g
s
.20442 .55963 m
.21359 .56771 L
s
.20135 .55691 m
.20442 .55963 L
s
.569 .676 .911 r
.57716 .6231 m .58963 .63978 L .56569 .64169 L p F P
0 g
s
.569 .676 .911 r
.56569 .64169 m .55312 .62542 L .57716 .6231 L p F P
0 g
s
.64059 .41112 m
.659 .38157 L
s
.659 .38157 m
.65077 .39867 L
s
.76349 .32708 m
.78456 .33568 L
s
.77404 .36305 m
.76349 .32708 L
s
.76349 .32708 m
.75384 .30257 L
s
.31954 .6933 m
.3363 .71396 L
s
.31954 .6933 m
.30824 .67834 L
s
.588 .705 .924 r
.40597 .57355 m .41971 .58912 L .39672 .5925 L p F P
0 g
s
.588 .705 .924 r
.39672 .5925 m .38287 .57734 L .40597 .57355 L p F P
0 g
s
.39802 .78929 m
.41612 .79664 L
s
.39802 .78929 m
.38707 .7756 L
s
.574 .682 .914 r
.54037 .60892 m .55312 .62542 L .52936 .62771 L p F P
0 g
s
.54429 .61399 m
.55751 .58406 L
s
.54622 .61649 m
.54876 .6131 L
s
.574 .682 .914 r
.52936 .62771 m .51652 .61162 L .54037 .60892 L p F P
0 g
s
.20135 .55691 m
.21723 .57136 L
s
.77404 .36305 m
.79596 .38043 L
s
.78543 .40898 m
.77404 .36305 L
s
.35861 .74451 m
.37602 .76129 L
s
.35861 .74451 m
.3475 .72943 L
s
.603 .728 .933 r
.27115 .54527 m .28602 .5599 L .26366 .56433 L p F P
0 g
s
.603 .728 .933 r
.26366 .56433 m .24868 .55011 L .27115 .54527 L p F P
0 g
s
.42701 .8078 m
.44562 .80289 L
s
.42701 .8078 m
.41612 .79664 L
s
.544 .635 .892 r
.82256 .7204 m .83352 .7386 L .80791 .73808 L p F P
0 g
s
.544 .635 .892 r
.80791 .73808 m .79688 .7203 L .82256 .7204 L p F P
0 g
s
.54 .63 .889 r
.85947 .73912 m .87023 .75751 L .84435 .75656 L p F P
0 g
s
.54 .63 .889 r
.84435 .75656 m .83352 .7386 L .85947 .73912 L p F P
0 g
s
.548 .641 .894 r
.7857 .70229 m .79688 .7203 L .77153 .72021 L p F P
0 g
s
.78803 .68716 m
.80834 .72035 L
s
.548 .641 .894 r
.77153 .72021 m .76028 .70262 L .7857 .70229 L p F P
0 g
s
.75384 .30257 m
.77416 .3023 L
s
.75384 .30257 m
.74505 .29031 L
s
.579 .688 .916 r
.50349 .59529 m .51652 .61162 L .49294 .6143 L p F P
0 g
s
.579 .688 .916 r
.49294 .6143 m .47981 .59838 L .50349 .59529 L p F P
0 g
s
.593 .711 .926 r
.3688 .56195 m .38287 .57734 L .36001 .5811 L p F P
0 g
s
.593 .711 .926 r
.36001 .5811 m .34584 .56611 L .3688 .56195 L p F P
0 g
s
.552 .647 .897 r
.74888 .6848 m .76028 .70262 L .73517 .70295 L p F P
0 g
s
.552 .647 .897 r
.73517 .70295 m .72369 .68555 L .74888 .6848 L p F P
0 g
s
.54765 .59917 m
.5664 .55828 L
s
.5664 .55828 m
.55663 .57515 L
s
.78782 .56252 m
.81156 .60087 L
s
.79995 .61731 m
.78782 .56252 L
s
.557 .654 .9 r
.71206 .66791 m .72369 .68555 L .69882 .68628 L p F P
0 g
s
.557 .654 .9 r
.69882 .68628 m .68711 .66906 L .71206 .66791 L p F P
0 g
s
.51988 .6669 m
.53861 .62682 L
s
.52863 .63897 m
.53865 .62657 L
s
.53865 .62657 m
.53866 .62657 L
s
.561 .66 .903 r
.67524 .65161 m .68711 .66906 L .66246 .6702 L p F P
0 g
s
.561 .66 .903 r
.66246 .6702 m .65051 .65316 L .67524 .65161 L p F P
0 g
s
.62214 .44403 m
.64059 .41112 L
s
.64059 .41112 m
.6321 .43085 L
s
.46455 .78753 m
.48362 .76242 L
s
.48362 .76242 m
.47288 .7621 L
s
.79999 .68009 m
.81011 .72035 L
s
.584 .695 .918 r
.46648 .58223 m .47981 .59838 L .4564 .60143 L p F P
0 g
s
.584 .695 .918 r
.4564 .60143 m .44296 .58569 L .46648 .58223 L p F P
0 g
s
.26897 .62866 m
.2853 .64768 L
s
.26897 .62866 m
.25726 .61455 L
s
.49211 .73298 m
.51123 .69715 L
s
.51123 .69715 m
.50068 .70384 L
s
.57548 .53581 m
.5941 .49709 L
s
.5941 .49709 m
.58479 .51665 L
s
.566 .666 .905 r
.63838 .63589 m .65051 .65316 L .62607 .6547 L p F P
0 g
s
.566 .666 .905 r
.62607 .6547 m .61386 .63784 L .63838 .63589 L p F P
0 g
s
.609 .734 .934 r
.23345 .53565 m .24868 .55011 L .22644 .55489 L p F P
0 g
s
.609 .734 .934 r
.22644 .55489 m .21108 .54084 L .23345 .53565 L p F P
0 g
s
.78675 .48727 m
.81021 .52097 L
s
.79907 .54378 m
.78675 .48727 L
s
.599 .718 .928 r
.33144 .5509 m .34584 .56611 L .32312 .57023 L p F P
0 g
s
.599 .718 .928 r
.32312 .57023 m .30861 .55542 L .33144 .5509 L p F P
0 g
s
.22933 .58401 m
.24543 .60026 L
s
.22933 .58401 m
.21723 .57136 L
s
.30824 .67834 m
.325 .6981 L
s
.30824 .67834 m
.29682 .66313 L
s
.57 .672 .908 r
.60148 .62075 m .61386 .63784 L .58963 .63978 L p F P
0 g
s
.57 .672 .908 r
.58963 .63978 m .57716 .6231 L .60148 .62075 L p F P
0 g
s
.44562 .80289 m
.46455 .78753 L
s
.44562 .80289 m
.43473 .79463 L
s
.78543 .40898 m
.80825 .43427 L
s
.79756 .46262 m
.78543 .40898 L
s
.589 .701 .92 r
.42933 .56972 m .44296 .58569 L .41971 .58912 L p F P
0 g
s
.589 .701 .92 r
.41971 .58912 m .40597 .57355 L .42933 .56972 L p F P
0 g
s
.46455 .78753 m
.45371 .78299 L
s
.38707 .7756 m
.40513 .78457 L
s
.38707 .7756 m
.37602 .76129 L
s
.3475 .72943 m
.36488 .74637 L
s
.3475 .72943 m
.3363 .71396 L
s
.575 .678 .91 r
.5645 .60618 m .57716 .6231 L .55312 .62542 L p F P
0 g
s
.575 .678 .91 r
.55312 .62542 m .54037 .60892 L .5645 .60618 L p F P
0 g
s
.92964 .65603 m
.94408 .60081 L
s
.9431 .64319 m
.94408 .60081 L
s
.604 .724 .929 r
.29387 .54038 m .30861 .55542 L .28602 .5599 L p F P
0 g
s
.604 .724 .929 r
.28602 .5599 m .27115 .54527 L .29387 .54038 L p F P
0 g
s
.615 .74 .935 r
.19548 .52657 m .21108 .54084 L .18894 .54598 L p F P
0 g
s
.615 .74 .935 r
.18894 .54598 m .17321 .53212 L .19548 .52657 L p F P
0 g
s
.18894 .54598 m
.20135 .55691 L
s
.18894 .54598 m
.20499 .55856 L
s
.17638 .53491 m
.18894 .54598 L
s
.72574 .30358 m
.74505 .29031 L
s
.70676 .32137 m
.72574 .30358 L
s
.72574 .30358 m
.71793 .31009 L
s
.68801 .34341 m
.70676 .32137 L
s
.70676 .32137 m
.699 .33339 L
s
.81244 .72908 m
.82209 .76274 L
s
.81238 .72888 m
.81244 .72908 L
s
.594 .707 .922 r
.39202 .55775 m .40597 .57355 L .38287 .57734 L p F P
0 g
s
.594 .707 .922 r
.38287 .57734 m .3688 .56195 L .39202 .55775 L p F P
0 g
s
.41612 .79664 m
.43473 .79463 L
s
.41612 .79664 m
.40513 .78457 L
s
.77416 .3023 m
.79517 .30718 L
s
.78456 .33568 m
.77416 .3023 L
s
.77416 .3023 m
.76479 .28171 L
s
.85286 .79266 m
.83201 .79048 L
s
.83201 .79048 m
.82209 .76274 L
s
.58 .685 .912 r
.52744 .59217 m .54037 .60892 L .51652 .61162 L p F P
0 g
s
.58 .685 .912 r
.51652 .61162 m .50349 .59529 L .52744 .59217 L p F P
0 g
s
.90132 .72098 m
.91686 .6719 L
s
.91686 .6719 m
.91392 .70414 L
s
.78456 .33568 m
.80646 .34948 L
s
.79596 .38043 m
.78456 .33568 L
s
.546 .632 .888 r
.84857 .72049 m .85947 .73912 L .83352 .7386 L p F P
0 g
s
.546 .632 .888 r
.83352 .7386 m .82256 .7204 L .84857 .72049 L p F P
0 g
s
.81334 .72763 m
.83436 .75264 L
s
.81324 .72751 m
.81334 .72763 L
s
.55 .638 .891 r
.81145 .70196 m .82256 .7204 L .79688 .7203 L p F P
0 g
s
.55 .638 .891 r
.79688 .7203 m .7857 .70229 L .81145 .70196 L p F P
0 g
s
.542 .627 .885 r
.88575 .73965 m .89645 .75847 L .87023 .75751 L p F P
0 g
s
.872 .77532 m
.88052 .75789 L
s
.88773 .74313 m
.88925 .74004 L
s
.88812 .74381 m
.88925 .74004 L
s
.542 .627 .885 r
.87023 .75751 m .85947 .73912 L .88575 .73965 L p F P
0 g
s
.60356 .47952 m
.62214 .44403 L
s
.62214 .44403 m
.61332 .46517 L
s
.554 .644 .894 r
.77438 .68405 m .7857 .70229 L .76028 .70262 L p F P
0 g
s
.554 .644 .894 r
.76028 .70262 m .74888 .6848 L .77438 .68405 L p F P
0 g
s
.74505 .29031 m
.76479 .28171 L
s
.74505 .29031 m
.73703 .29037 L
s
.558 .65 .896 r
.73732 .66674 m .74888 .6848 L .72369 .68555 L p F P
0 g
s
.558 .65 .896 r
.72369 .68555 m .71206 .66791 L .73732 .66674 L p F P
0 g
s
.66937 .36933 m
.68801 .34341 L
s
.68801 .34341 m
.68016 .35992 L
s
.82209 .76274 m
.84421 .77884 L
s
.25726 .61455 m
.27367 .63199 L
s
.25726 .61455 m
.24543 .60026 L
s
.79995 .61731 m
.8239 .65495 L
s
.81195 .66933 m
.79995 .61731 L
s
.585 .691 .915 r
.49026 .57873 m .50349 .59529 L .47981 .59838 L p F P
0 g
s
.585 .691 .915 r
.47981 .59838 m .46648 .58223 L .49026 .57873 L p F P
0 g
s
.47288 .7621 m
.49211 .73298 L
s
.49211 .73298 m
.48134 .73545 L
s
.562 .656 .899 r
.70027 .65003 m .71206 .66791 L .68711 .66906 L p F P
0 g
s
.562 .656 .899 r
.68711 .66906 m .67524 .65161 L .70027 .65003 L p F P
0 g
s
.61 .73 .931 r
.25605 .53041 m .27115 .54527 L .24868 .55011 L p F P
0 g
s
.61 .73 .931 r
.24868 .55011 m .23345 .53565 L .25605 .53041 L p F P
0 g
s
.52863 .63897 m
.54132 .61242 L
s
.54132 .61242 m
.54133 .6124 L
s
.54314 .6086 m
.54765 .59917 L
s
.50068 .70384 m
.51988 .6669 L
s
.51988 .6669 m
.50936 .67608 L
s
.29682 .66313 m
.31361 .68186 L
s
.29682 .66313 m
.2853 .64768 L
s
.6 .713 .924 r
.35452 .54633 m .3688 .56195 L .34584 .56611 L p F P
0 g
s
.6 .713 .924 r
.34584 .56611 m .33144 .5509 L .35452 .54633 L p F P
0 g
s
.567 .662 .902 r
.6632 .63391 m .67524 .65161 L .65051 .65316 L p F P
0 g
s
.567 .662 .902 r
.65051 .65316 m .63838 .63589 L .6632 .63391 L p F P
0 g
s
.21723 .57136 m
.23346 .58579 L
s
.20499 .55856 m
.21723 .57136 L
s
.55663 .57515 m
.57548 .53581 L
s
.57548 .53581 m
.56579 .55441 L
s
.3363 .71396 m
.35365 .73084 L
s
.3363 .71396 m
.325 .6981 L
s
.37602 .76129 m
.39404 .7716 L
s
.37602 .76129 m
.36488 .74637 L
s
.59 .697 .917 r
.45295 .56584 m .46648 .58223 L .44296 .58569 L p F P
0 g
s
.59 .697 .917 r
.44296 .58569 m .42933 .56972 L .45295 .56584 L p F P
0 g
s
.571 .668 .904 r
.62609 .61837 m .63838 .63589 L .61386 .63784 L p F P
0 g
s
.571 .668 .904 r
.61386 .63784 m .60148 .62075 L .62609 .61837 L p F P
0 g
s
.76479 .28171 m
.78506 .27783 L
s
.76479 .28171 m
.7564 .27449 L
s
.65077 .39867 m
.66937 .36933 L
s
.66937 .36933 m
.66133 .38925 L
s
.79907 .54378 m
.82308 .58043 L
s
.81156 .60087 m
.79907 .54378 L
s
.43473 .79463 m
.45371 .78299 L
s
.43473 .79463 m
.42372 .78518 L
s
.605 .72 .926 r
.31682 .53545 m .33144 .5509 L .30861 .55542 L p F P
0 g
s
.605 .72 .926 r
.30861 .55542 m .29387 .54038 L .31682 .53545 L p F P
0 g
s
.79596 .38043 m
.81881 .40253 L
s
.80825 .43427 m
.79596 .38043 L
s
.79756 .46262 m
.82119 .49406 L
s
.81021 .52097 m
.79756 .46262 L
s
.576 .675 .907 r
.58892 .60341 m .60148 .62075 L .57716 .6231 L p F P
0 g
s
.576 .675 .907 r
.57716 .6231 m .5645 .60618 L .58892 .60341 L p F P
0 g
s
.615 .736 .932 r
.21797 .52097 m .23345 .53565 L .21108 .54084 L p F P
0 g
s
.615 .736 .932 r
.21108 .54084 m .19548 .52657 L .21797 .52097 L p F P
0 g
s
.45371 .78299 m
.47288 .7621 L
s
.47288 .7621 m
.46198 .76022 L
s
.595 .703 .919 r
.41549 .5535 m .42933 .56972 L .40597 .57355 L p F P
0 g
s
.595 .703 .919 r
.40597 .57355 m .39202 .55775 L .41549 .5535 L p F P
0 g
s
.40513 .78457 m
.42372 .78518 L
s
.40513 .78457 m
.39404 .7716 L
s
.872 .77532 m
.85286 .79266 L
s
.85286 .79266 m
.84421 .77884 L
s
.872 .77532 m
.86499 .77724 L
s
.581 .681 .909 r
.55167 .58901 m .5645 .60618 L .54037 .60892 L p F P
0 g
s
.581 .681 .909 r
.54037 .60892 m .52744 .59217 L .55167 .58901 L p F P
0 g
s
.53751 .6138 m
.5431 .60573 L
s
.5431 .60573 m
.54314 .60568 L
s
.45371 .78299 m
.44272 .77702 L
s
.17638 .53491 m
.19261 .5456 L
s
.58479 .51665 m
.60356 .47952 L
s
.60356 .47952 m
.59435 .50085 L
s
.551 .635 .887 r
.83753 .70162 m .84857 .72049 L .82256 .7204 L p F P
0 g
s
.551 .635 .887 r
.82256 .7204 m .81145 .70196 L .83753 .70162 L p F P
0 g
s
.82197 .71306 m
.82352 .71539 L
s
.79999 .68009 m
.81454 .70192 L
s
.82194 .71301 m
.82197 .71306 L
s
.547 .629 .884 r
.87492 .72059 m .88575 .73965 L .85947 .73912 L p F P
0 g
s
.547 .629 .884 r
.85947 .73912 m .84857 .72049 L .87492 .72059 L p F P
0 g
s
.24543 .60026 m
.26192 .61606 L
s
.24543 .60026 m
.23346 .58579 L
s
.611 .726 .927 r
.27889 .52511 m .29387 .54038 L .27115 .54527 L p F P
0 g
s
.611 .726 .927 r
.27115 .54527 m .25605 .53041 L .27889 .52511 L p F P
0 g
s
.555 .641 .89 r
.8002 .68328 m .81145 .70196 L .7857 .70229 L p F P
0 g
s
.555 .641 .89 r
.7857 .70229 m .77438 .68405 L .8002 .68328 L p F P
0 g
s
.2853 .64768 m
.30211 .66526 L
s
.2853 .64768 m
.27367 .63199 L
s
.544 .624 .882 r
.91239 .74019 m .92302 .75944 L .89645 .75847 L p F P
0 g
s
.544 .624 .882 r
.89645 .75847 m .88575 .73965 L .91239 .74019 L p F P
0 g
s
.88408 .75736 m
.88633 .74982 L
s
.88633 .74982 m
.88634 .74979 L
s
.586 .687 .911 r
.51431 .57518 m .52744 .59217 L .50349 .59529 L p F P
0 g
s
.586 .687 .911 r
.50349 .59529 m .49026 .57873 L .51431 .57518 L p F P
0 g
s
.559 .647 .893 r
.7629 .66555 m .77438 .68405 L .74888 .6848 L p F P
0 g
s
.559 .647 .893 r
.74888 .6848 m .73732 .66674 L .7629 .66555 L p F P
0 g
s
.79517 .30718 m
.81696 .31694 L
s
.80646 .34948 m
.79517 .30718 L
s
.79517 .30718 m
.78506 .27783 L
s
.6 .709 .921 r
.37785 .5417 m .39202 .55775 L .3688 .56195 L p F P
0 g
s
.6 .709 .921 r
.3688 .56195 m .35452 .54633 L .37785 .5417 L p F P
0 g
s
.82266 .71197 m
.82352 .71539 L
s
.82264 .71188 m
.82266 .71197 L
s
.81195 .66933 m
.82012 .70185 L
s
.621 .742 .933 r
.17961 .51206 m .19548 .52657 L .17321 .53212 L p F P
0 g
s
.621 .742 .933 r
.17321 .53212 m .15721 .51802 L .17961 .51206 L p F P
0 g
s
.17321 .53212 m
.17638 .53491 L
s
.16364 .52369 m
.17321 .53212 L
s
.48134 .73545 m
.50068 .70384 L
s
.50068 .70384 m
.48992 .70895 L
s
.6321 .43085 m
.65077 .39867 L
s
.65077 .39867 m
.64244 .42086 L
s
.564 .653 .895 r
.72561 .64843 m .73732 .66674 L .71206 .66791 L p F P
0 g
s
.564 .653 .895 r
.71206 .66791 m .70027 .65003 L .72561 .64843 L p F P
0 g
s
.325 .6981 m
.34233 .71472 L
s
.325 .6981 m
.31361 .68186 L
s
.36488 .74637 m
.38286 .75773 L
s
.36488 .74637 m
.35365 .73084 L
s
.78506 .27783 m
.80597 .27862 L
s
.78506 .27783 m
.77614 .26264 L
s
.50936 .67608 m
.52863 .63897 L
s
.52863 .63897 m
.51815 .65041 L
s
.568 .659 .898 r
.68832 .6319 m .70027 .65003 L .67524 .65161 L p F P
0 g
s
.568 .659 .898 r
.67524 .65161 m .6632 .63391 L .68832 .6319 L p F P
0 g
s
.20499 .55856 m
.22137 .57114 L
s
.19261 .5456 m
.20499 .55856 L
s
.591 .693 .913 r
.47684 .56191 m .49026 .57873 L .46648 .58223 L p F P
0 g
s
.591 .693 .913 r
.46648 .58223 m .45295 .56584 L .47684 .56191 L p F P
0 g
s
.573 .665 .901 r
.65099 .61596 m .6632 .63391 L .63838 .63589 L p F P
0 g
s
.573 .665 .901 r
.63838 .63589 m .62609 .61837 L .65099 .61596 L p F P
0 g
s
.88408 .75736 m
.89064 .74352 L
s
.89064 .74352 m
.89066 .74349 L
s
.89241 .73978 m
.90132 .72098 L
s
.53751 .6138 m
.54571 .59722 L
s
.616 .732 .929 r
.24071 .5153 m .25605 .53041 L .23345 .53565 L p F P
0 g
s
.616 .732 .929 r
.23345 .53565 m .21797 .52097 L .24071 .5153 L p F P
0 g
s
.606 .716 .922 r
.34002 .53046 m .35452 .54633 L .33144 .5509 L p F P
0 g
s
.606 .716 .922 r
.33144 .5509 m .31682 .53545 L .34002 .53046 L p F P
0 g
s
.91392 .70414 m
.92964 .65603 L
s
.92964 .65603 m
.92707 .68963 L
s
.577 .671 .903 r
.61362 .6006 m .62609 .61837 L .60148 .62075 L p F P
0 g
s
.577 .671 .903 r
.60148 .62075 m .58892 .60341 L .61362 .6006 L p F P
0 g
s
.80646 .34948 m
.82924 .36791 L
s
.81881 .40253 m
.80646 .34948 L
s
.596 .699 .915 r
.43922 .5492 m .45295 .56584 L .42933 .56972 L p F P
0 g
s
.596 .699 .915 r
.42933 .56972 m .41549 .5535 L .43922 .5492 L p F P
0 g
s
.42372 .78518 m
.44272 .77702 L
s
.42372 .78518 m
.4126 .77453 L
s
.84421 .77884 m
.86499 .77724 L
s
.84421 .77884 m
.83436 .75264 L
s
.39404 .7716 m
.4126 .77453 L
s
.39404 .7716 m
.38286 .75773 L
s
.80825 .43427 m
.83199 .46312 L
s
.82119 .49406 m
.80825 .43427 L
s
.82352 .71539 m
.83436 .75264 L
s
.582 .677 .905 r
.57618 .58582 m .58892 .60341 L .5645 .60618 L p F P
0 g
s
.582 .677 .905 r
.5645 .60618 m .55167 .58901 L .57618 .58582 L p F P
0 g
s
.54964 .58928 m
.55663 .57515 L
s
.81156 .60087 m
.8358 .63697 L
s
.8239 .65495 m
.81156 .60087 L
s
.73703 .29037 m
.7564 .27449 L
s
.71793 .31009 m
.73703 .29037 L
s
.73703 .29037 m
.72962 .30208 L
s
.46198 .76022 m
.48134 .73545 L
s
.48134 .73545 m
.47039 .7362 L
s
.27367 .63199 m
.29053 .6483 L
s
.27367 .63199 m
.26192 .61606 L
s
.611 .722 .924 r
.30197 .51975 m .31682 .53545 L .29387 .54038 L p F P
0 g
s
.611 .722 .924 r
.29387 .54038 m .27889 .52511 L .30197 .51975 L p F P
0 g
s
.7564 .27449 m
.77614 .26264 L
s
.7564 .27449 m
.74886 .28038 L
s
.61332 .46517 m
.6321 .43085 L
s
.6321 .43085 m
.62341 .45415 L
s
.699 .33339 m
.71793 .31009 L
s
.71793 .31009 m
.71051 .32669 L
s
.23346 .58579 m
.25006 .59989 L
s
.23346 .58579 m
.22137 .57114 L
s
.56579 .55441 m
.58479 .51665 L
s
.58479 .51665 m
.57518 .53703 L
s
.81021 .52097 m
.83445 .55588 L
s
.82308 .58043 m
.81021 .52097 L
s
.622 .738 .93 r
.20225 .50604 m .21797 .52097 L .19548 .52657 L p F P
0 g
s
.622 .738 .93 r
.19548 .52657 m .17961 .51206 L .20225 .50604 L p F P
0 g
s
.16378 .52376 m
.18007 .53248 L
s
.16364 .52369 m
.16378 .52376 L
s
.31361 .68186 m
.33093 .69802 L
s
.31361 .68186 m
.30211 .66526 L
s
.83436 .75264 m
.85653 .76549 L
s
.601 .705 .917 r
.40144 .53703 m .41549 .5535 L .39202 .55775 L p F P
0 g
s
.601 .705 .917 r
.39202 .55775 m .37785 .5417 L .40144 .53703 L p F P
0 g
s
.587 .683 .908 r
.53864 .5716 m .55167 .58901 L .52744 .59217 L p F P
0 g
s
.587 .683 .908 r
.52744 .59217 m .51431 .57518 L .53864 .5716 L p F P
0 g
s
.35365 .73084 m
.37158 .74298 L
s
.35365 .73084 m
.34233 .71472 L
s
.553 .632 .884 r
.86395 .70128 m .87492 .72059 L .84857 .72049 L p F P
0 g
s
.553 .632 .884 r
.84857 .72049 m .83753 .70162 L .86395 .70128 L p F P
0 g
s
.82352 .71539 m
.84671 .74011 L
s
.556 .638 .887 r
.82635 .68251 m .83753 .70162 L .81145 .70196 L p F P
0 g
s
.556 .638 .887 r
.81145 .70196 m .8002 .68328 L .82635 .68251 L p F P
0 g
s
.81195 .66933 m
.82152 .68265 L
s
.549 .626 .881 r
.90162 .72068 m .91239 .74019 L .88575 .73965 L p F P
0 g
s
.9013 .72106 m
.90132 .72098 L
s
.549 .626 .881 r
.88575 .73965 m .87492 .72059 L .90162 .72068 L p F P
0 g
s
.89654 .74048 m
.89819 .73375 L
s
.89819 .73375 m
.8982 .73369 L
s
.44272 .77702 m
.46198 .76022 L
s
.44272 .77702 m
.4316 .76957 L
s
.561 .643 .889 r
.7888 .66436 m .8002 .68328 L .77438 .68405 L p F P
0 g
s
.561 .643 .889 r
.77438 .68405 m .7629 .66555 L .7888 .66436 L p F P
0 g
s
.545 .621 .878 r
.93938 .74073 m .94995 .76043 L .92302 .75944 L p F P
0 g
s
.545 .621 .878 r
.92302 .75944 m .91239 .74019 L .93938 .74073 L p F P
0 g
s
.46198 .76022 m
.45091 .75667 L
s
.565 .649 .892 r
.75127 .64681 m .7629 .66555 L .73732 .66674 L p F P
0 g
s
.565 .649 .892 r
.73732 .66674 m .72561 .64843 L .75127 .64681 L p F P
0 g
s
.77614 .26264 m
.79634 .25493 L
s
.77614 .26264 m
.7683 .26185 L
s
.68016 .35992 m
.699 .33339 L
s
.699 .33339 m
.69144 .35388 L
s
.48992 .70895 m
.50936 .67608 L
s
.50936 .67608 m
.49859 .68362 L
s
.80597 .27862 m
.82759 .28394 L
s
.81696 .31694 m
.80597 .27862 L
s
.80597 .27862 m
.79634 .25493 L
s
.569 .655 .895 r
.71374 .62988 m .72561 .64843 L .70027 .65003 L p F P
0 g
s
.569 .655 .895 r
.70027 .65003 m .68832 .6319 L .71374 .62988 L p F P
0 g
s
.592 .689 .91 r
.501 .55795 m .51431 .57518 L .49026 .57873 L p F P
0 g
s
.592 .689 .91 r
.49026 .57873 m .47684 .56191 L .501 .55795 L p F P
0 g
s
.19261 .5456 m
.20914 .55631 L
s
.19261 .5456 m
.18007 .53248 L
s
.617 .728 .925 r
.26367 .50958 m .27889 .52511 L .25605 .53041 L p F P
0 g
s
.617 .728 .925 r
.25605 .53041 m .24071 .5153 L .26367 .50958 L p F P
0 g
s
.86499 .77724 m
.88408 .75736 L
s
.88408 .75736 m
.87737 .76153 L
s
.606 .712 .919 r
.36347 .52541 m .37785 .5417 L .35452 .54633 L p F P
0 g
s
.606 .712 .919 r
.35452 .54633 m .34002 .53046 L .36347 .52541 L p F P
0 g
s
.574 .661 .897 r
.6762 .61353 m .68832 .6319 L .6632 .63391 L p F P
0 g
s
.574 .661 .897 r
.6632 .63391 m .65099 .61596 L .6762 .61353 L p F P
0 g
s
.86499 .77724 m
.85653 .76549 L
s
.627 .744 .931 r
.16349 .49731 m .17961 .51206 L .15721 .51802 L p F P
0 g
s
.627 .744 .931 r
.15721 .51802 m .14095 .50369 L .16349 .49731 L p F P
0 g
s
.15721 .51802 m
.16364 .52369 L
s
.15074 .51232 m
.15721 .51802 L
s
.51815 .65041 m
.53751 .6138 L
s
.53751 .6138 m
.52706 .62732 L
s
.578 .667 .9 r
.63862 .59777 m .65099 .61596 L .62609 .61837 L p F P
0 g
s
.578 .667 .9 r
.62609 .61837 m .61362 .6006 L .63862 .59777 L p F P
0 g
s
.597 .695 .912 r
.46322 .54485 m .47684 .56191 L .45295 .56584 L p F P
0 g
s
.597 .695 .912 r
.45295 .56584 m .43922 .5492 L .46322 .54485 L p F P
0 g
s
.81696 .31694 m
.83961 .33119 L
s
.82924 .36791 m
.81696 .31694 L
s
.38286 .75773 m
.40138 .76266 L
s
.38286 .75773 m
.37158 .74298 L
s
.26192 .61606 m
.27884 .631 L
s
.26192 .61606 m
.25006 .59989 L
s
.66133 .38925 m
.68016 .35992 L
s
.68016 .35992 m
.67236 .38325 L
s
.4126 .77453 m
.4316 .76957 L
s
.4126 .77453 m
.40138 .76266 L
s
.81881 .40253 m
.84257 .42836 L
s
.83199 .46312 m
.81881 .40253 L
s
.583 .673 .902 r
.60097 .58259 m .61362 .6006 L .58892 .60341 L p F P
0 g
s
.583 .673 .902 r
.58892 .60341 m .57618 .58582 L .60097 .58259 L p F P
0 g
s
.30211 .66526 m
.31944 .68077 L
s
.30211 .66526 m
.29053 .6483 L
s
.612 .718 .921 r
.32529 .51433 m .34002 .53046 L .31682 .53545 L p F P
0 g
s
.612 .718 .921 r
.31682 .53545 m .30197 .51975 L .32529 .51433 L p F P
0 g
s
.79634 .25493 m
.81709 .25137 L
s
.79634 .25493 m
.78804 .24671 L
s
.59435 .50085 m
.61332 .46517 L
s
.61332 .46517 m
.60422 .48846 L
s
.622 .734 .927 r
.22511 .49995 m .24071 .5153 L .21797 .52097 L p F P
0 g
s
.622 .734 .927 r
.21797 .52097 m .20225 .50604 L .22511 .49995 L p F P
0 g
s
.22137 .57114 m
.23809 .5835 L
s
.22137 .57114 m
.20914 .55631 L
s
.34233 .71472 m
.36022 .72736 L
s
.34233 .71472 m
.33093 .69802 L
s
.602 .702 .914 r
.42529 .53231 m .43922 .5492 L .41549 .5535 L p F P
0 g
s
.602 .702 .914 r
.41549 .5535 m .40144 .53703 L .42529 .53231 L p F P
0 g
s
.47039 .7362 m
.48992 .70895 L
s
.48992 .70895 m
.47893 .71218 L
s
.587 .679 .904 r
.56325 .56798 m .57618 .58582 L .55167 .58901 L p F P
0 g
s
.587 .679 .904 r
.55167 .58901 m .53864 .5716 L .56325 .56798 L p F P
0 g
s
.54654 .59169 m
.55183 .58144 L
s
.55842 .56869 m
.56579 .55441 L
s
.55183 .58144 m
.55191 .5813 L
s
.54654 .59169 m
.54974 .58644 L
s
.15074 .51232 m
.16738 .5192 L
s
.558 .634 .883 r
.85284 .68172 m .86395 .70128 L .83753 .70162 L p F P
0 g
s
.558 .634 .883 r
.83753 .70162 m .82635 .68251 L .85284 .68172 L p F P
0 g
s
.83404 .69565 m
.83573 .70245 L
s
.83268 .6982 m
.83573 .70245 L
s
.83246 .69789 m
.83268 .6982 L
s
.83244 .69786 m
.83246 .69789 L
s
.554 .629 .88 r
.89072 .70093 m .90162 .72068 L .87492 .72059 L p F P
0 g
s
.554 .629 .88 r
.87492 .72059 m .86395 .70128 L .89072 .70093 L p F P
0 g
s
.82119 .49406 m
.84563 .5271 L
s
.83445 .55588 m
.82119 .49406 L
s
.562 .64 .886 r
.81503 .66314 m .82635 .68251 L .8002 .68328 L p F P
0 g
s
.8239 .65495 m
.83073 .68238 L
s
.562 .64 .886 r
.8002 .68328 m .7888 .66436 L .81503 .66314 L p F P
0 g
s
.55 .623 .878 r
.92867 .72078 m .93938 .74073 L .91239 .74019 L p F P
0 g
s
.55 .623 .878 r
.91239 .74019 m .90162 .72068 L .92867 .72078 L p F P
0 g
s
.906 .7207 m
.91392 .70414 L
s
.89654 .74048 m
.90227 .72849 L
s
.90227 .72849 m
.90229 .72845 L
s
.617 .724 .922 r
.28688 .5038 m .30197 .51975 L .27889 .52511 L p F P
0 g
s
.617 .724 .922 r
.27889 .52511 m .26367 .50958 L .28688 .5038 L p F P
0 g
s
.566 .646 .889 r
.77724 .64518 m .7888 .66436 L .7629 .66555 L p F P
0 g
s
.566 .646 .889 r
.7629 .66555 m .75127 .64681 L .77724 .64518 L p F P
0 g
s
.592 .686 .906 r
.52543 .55394 m .53864 .5716 L .51431 .57518 L p F P
0 g
s
.592 .686 .906 r
.51431 .57518 m .501 .55795 L .52543 .55394 L p F P
0 g
s
.546 .618 .875 r
.96673 .74128 m .97724 .76143 L .94995 .76043 L p F P
0 g
s
.546 .618 .875 r
.94995 .76043 m .93938 .74073 L .96673 .74128 L p F P
0 g
s
.607 .708 .916 r
.38717 .52031 m .40144 .53703 L .37785 .5417 L p F P
0 g
s
.607 .708 .916 r
.37785 .5417 m .36347 .52541 L .38717 .52031 L p F P
0 g
s
.57 .652 .891 r
.73948 .62782 m .75127 .64681 L .72561 .64843 L p F P
0 g
s
.57 .652 .891 r
.72561 .64843 m .71374 .62988 L .73948 .62782 L p F P
0 g
s
.18007 .53248 m
.19678 .5413 L
s
.16738 .5192 m
.18007 .53248 L
s
.82308 .58043 m
.84761 .61526 L
s
.8358 .63697 m
.82308 .58043 L
s
.4316 .76957 m
.45091 .75667 L
s
.4316 .76957 m
.42036 .7606 L
s
.628 .74 .928 r
.18626 .49086 m .20225 .50604 L .17961 .51206 L p F P
0 g
s
.628 .74 .928 r
.17961 .51206 m .16349 .49731 L .18626 .49086 L p F P
0 g
s
.64244 .42086 m
.66133 .38925 L
s
.66133 .38925 m
.65319 .41434 L
s
.574 .658 .894 r
.70171 .61106 m .71374 .62988 L .68832 .6319 L p F P
0 g
s
.574 .658 .894 r
.68832 .6319 m .6762 .61353 L .70171 .61106 L p F P
0 g
s
.45091 .75667 m
.47039 .7362 L
s
.47039 .7362 m
.45926 .73503 L
s
.92707 .68963 m
.9431 .64319 L
s
.94084 .6774 m
.9431 .64319 L
s
.49859 .68362 m
.51815 .65041 L
s
.51815 .65041 m
.50739 .66017 L
s
.85653 .76549 m
.87737 .76153 L
s
.85653 .76549 m
.84671 .74011 L
s
.37158 .74298 m
.39006 .74958 L
s
.37158 .74298 m
.36022 .72736 L
s
.597 .692 .908 r
.48749 .54045 m .501 .55795 L .47684 .56191 L p F P
0 g
s
.597 .692 .908 r
.47684 .56191 m .46322 .54485 L .48749 .54045 L p F P
0 g
s
.25006 .59989 m
.26706 .61336 L
s
.25006 .59989 m
.23809 .5835 L
s
.29053 .6483 m
.30786 .66299 L
s
.29053 .6483 m
.27884 .631 L
s
.45091 .75667 m
.43969 .75134 L
s
.82759 .28394 m
.83961 .33119 L
s
.81709 .25137 m
.82759 .28394 L
s
.579 .664 .896 r
.66391 .5949 m .6762 .61353 L .65099 .61596 L p F P
0 g
s
.579 .664 .896 r
.65099 .61596 m .63862 .59777 L .66391 .5949 L p F P
0 g
s
.80816 .23509 m
.81709 .25137 L
s
.82924 .36791 m
.85294 .39019 L
s
.84257 .42836 m
.82924 .36791 L
s
.83573 .70245 m
.85916 .72544 L
s
.83573 .70245 m
.84671 .74011 L
s
.33093 .69802 m
.34879 .7109 L
s
.33093 .69802 m
.31944 .68077 L
s
.612 .714 .917 r
.34886 .50886 m .36347 .52541 L .34002 .53046 L p F P
0 g
s
.612 .714 .917 r
.34002 .53046 m .32529 .51433 L .34886 .50886 L p F P
0 g
s
.623 .73 .924 r
.24821 .49381 m .26367 .50958 L .24071 .5153 L p F P
0 g
s
.623 .73 .924 r
.24071 .5153 m .22511 .49995 L .24821 .49381 L p F P
0 g
s
.40138 .76266 m
.42036 .7606 L
s
.40138 .76266 m
.39006 .74958 L
s
.57518 .53703 m
.59435 .50085 L
s
.59435 .50085 m
.58483 .52304 L
s
.584 .67 .898 r
.62606 .57932 m .63862 .59777 L .61362 .6006 L p F P
0 g
s
.584 .67 .898 r
.61362 .6006 m .60097 .58259 L .62606 .57932 L p F P
0 g
s
.20914 .55631 m
.226 .56688 L
s
.20914 .55631 m
.19678 .5413 L
s
.84671 .74011 m
.86904 .75092 L
s
.602 .698 .91 r
.44939 .52753 m .46322 .54485 L .43922 .5492 L p F P
0 g
s
.602 .698 .91 r
.43922 .5492 m .42529 .53231 L .44939 .52753 L p F P
0 g
s
.633 .746 .929 r
.14709 .48231 m .16349 .49731 L .14095 .50369 L p F P
0 g
s
.633 .746 .929 r
.14095 .50369 m .12441 .48912 L .14709 .48231 L p F P
0 g
s
.14095 .50369 m
.15074 .51232 L
s
.13766 .5008 m
.14095 .50369 L
s
.588 .676 .901 r
.58815 .56431 m .60097 .58259 L .57618 .58582 L p F P
0 g
s
.588 .676 .901 r
.57618 .58582 m .56325 .56798 L .58815 .56431 L p F P
0 g
s
.52706 .62732 m
.54654 .59169 L
s
.53614 .6071 m
.54654 .59169 L
s
.87737 .76153 m
.89654 .74048 L
s
.89654 .74048 m
.89005 .74591 L
s
.7683 .26185 m
.78804 .24671 L
s
.74886 .28038 m
.7683 .26185 L
s
.7683 .26185 m
.76139 .27474 L
s
.72962 .30208 m
.74886 .28038 L
s
.74886 .28038 m
.74197 .29829 L
s
.62341 .45415 m
.64244 .42086 L
s
.64244 .42086 m
.6339 .44663 L
s
.618 .72 .919 r
.31033 .49796 m .32529 .51433 L .30197 .51975 L p F P
0 g
s
.618 .72 .919 r
.30197 .51975 m .28688 .5038 L .31033 .49796 L p F P
0 g
s
.87737 .76153 m
.86904 .75092 L
s
.13766 .5008 m
.15453 .50575 L
s
.78804 .24671 m
.80816 .23509 L
s
.78804 .24671 m
.78094 .25372 L
s
.628 .736 .925 r
.20926 .48435 m .22511 .49995 L .20225 .50604 L p F P
0 g
s
.628 .736 .925 r
.20225 .50604 m .18626 .49086 L .20926 .48435 L p F P
0 g
s
.607 .704 .912 r
.41114 .51516 m .42529 .53231 L .40144 .53703 L p F P
0 g
s
.607 .704 .912 r
.40144 .53703 m .38717 .52031 L .41114 .51516 L p F P
0 g
s
.593 .682 .903 r
.55014 .54988 m .56325 .56798 L .53864 .5716 L p F P
0 g
s
.56048 .56414 m
.56579 .55441 L
s
.55812 .56846 m
.55812 .56845 L
s
.55577 .57277 m
.55812 .56846 L
s
.593 .682 .903 r
.53864 .5716 m .52543 .55394 L .55014 .54988 L p F P
0 g
s
.83199 .46312 m
.85656 .49402 L
s
.84563 .5271 m
.83199 .46312 L
s
.47893 .71218 m
.49859 .68362 L
s
.49859 .68362 m
.48759 .68914 L
s
.559 .631 .88 r
.87967 .68093 m .89072 .70093 L .86395 .70128 L p F P
0 g
s
.559 .631 .88 r
.86395 .70128 m .85284 .68172 L .87967 .68093 L p F P
0 g
s
.563 .637 .882 r
.84159 .66191 m .85284 .68172 L .82635 .68251 L p F P
0 g
s
.8239 .65495 m
.83549 .67016 L
s
.84449 .68197 m
.84465 .68218 L
s
.84465 .68218 m
.84796 .68653 L
s
.563 .637 .882 r
.82635 .68251 m .81503 .66314 L .84159 .66191 L p F P
0 g
s
.555 .626 .877 r
.91783 .70058 m .92867 .72078 L .90162 .72068 L p F P
0 g
s
.91353 .70592 m
.91392 .70414 L
s
.555 .626 .877 r
.90162 .72068 m .89072 .70093 L .91783 .70058 L p F P
0 g
s
.9109 .7181 m
.91092 .718 L
s
.90943 .72493 m
.9109 .7181 L
s
.567 .643 .885 r
.80355 .64352 m .81503 .66314 L .7888 .66436 L p F P
0 g
s
.567 .643 .885 r
.7888 .66436 m .77724 .64518 L .80355 .64352 L p F P
0 g
s
.71051 .32669 m
.72962 .30208 L
s
.72962 .30208 m
.72264 .32407 L
s
.551 .62 .874 r
.95608 .72088 m .96673 .74128 L .93938 .74073 L p F P
0 g
s
.551 .62 .874 r
.93938 .74073 m .92867 .72078 L .95608 .72088 L p F P
0 g
s
.16738 .5192 m
.18428 .5261 L
s
.15453 .50575 m
.16738 .5192 L
s
.36022 .72736 m
.37865 .7353 L
s
.36022 .72736 m
.34879 .7109 L
s
.571 .649 .888 r
.76554 .62574 m .77724 .64518 L .75127 .64681 L p F P
0 g
s
.571 .649 .888 r
.75127 .64681 m .73948 .62782 L .76554 .62574 L p F P
0 g
s
.27884 .631 m
.29621 .64468 L
s
.27884 .631 m
.26706 .61336 L
s
.83961 .33119 m
.85294 .39019 L
s
.23809 .5835 m
.25518 .5954 L
s
.23809 .5835 m
.226 .56688 L
s
.31944 .68077 m
.33727 .69361 L
s
.31944 .68077 m
.30786 .66299 L
s
.575 .654 .89 r
.72753 .60857 m .73948 .62782 L .71374 .62988 L p F P
0 g
s
.575 .654 .89 r
.71374 .62988 m .70171 .61106 L .72753 .60857 L p F P
0 g
s
.598 .688 .905 r
.51202 .53601 m .52543 .55394 L .501 .55795 L p F P
0 g
s
.598 .688 .905 r
.501 .55795 m .48749 .54045 L .51202 .53601 L p F P
0 g
s
.42036 .7606 m
.43969 .75134 L
s
.42036 .7606 m
.40901 .75008 L
s
.84629 .67973 m
.8463 .67978 L
s
.8358 .63697 m
.84217 .66295 L
s
.8007 .23542 m
.80816 .23509 L
s
.623 .726 .92 r
.27155 .4876 m .28688 .5038 L .26367 .50958 L p F P
0 g
s
.623 .726 .92 r
.26367 .50958 m .24821 .49381 L .27155 .4876 L p F P
0 g
s
.613 .71 .914 r
.37269 .50333 m .38717 .52031 L .36347 .52541 L p F P
0 g
s
.613 .71 .914 r
.36347 .52541 m .34886 .50886 L .37269 .50333 L p F P
0 g
s
.58 .66 .893 r
.68951 .59199 m .70171 .61106 L .6762 .61353 L p F P
0 g
s
.58 .66 .893 r
.6762 .61353 m .66391 .5949 L .68951 .59199 L p F P
0 g
s
.69144 .35388 m
.71051 .32669 L
s
.71051 .32669 m
.7033 .3518 L
s
.83445 .55588 m
.85927 .58958 L
s
.84761 .61526 m
.83445 .55588 L
s
.39006 .74958 m
.40901 .75008 L
s
.39006 .74958 m
.37865 .7353 L
s
.19678 .5413 m
.21379 .55003 L
s
.19678 .5413 m
.18428 .5261 L
s
.634 .741 .926 r
.17001 .47544 m .18626 .49086 L .16349 .49731 L p F P
0 g
s
.634 .741 .926 r
.16349 .49731 m .14709 .48231 L .17001 .47544 L p F P
0 g
s
.584 .666 .895 r
.65145 .57601 m .66391 .5949 L .63862 .59777 L p F P
0 g
s
.584 .666 .895 r
.63862 .59777 m .62606 .57932 L .65145 .57601 L p F P
0 g
s
.45926 .73503 m
.47893 .71218 L
s
.47893 .71218 m
.46775 .71328 L
s
.603 .694 .907 r
.47377 .5227 m .48749 .54045 L .46322 .54485 L p F P
0 g
s
.603 .694 .907 r
.46322 .54485 m .44939 .52753 L .47377 .5227 L p F P
0 g
s
.50739 .66017 m
.52706 .62732 L
s
.52706 .62732 m
.51633 .63906 L
s
.90943 .72493 m
.91553 .71272 L
s
.91978 .70422 m
.92707 .68963 L
s
.60422 .48846 m
.62341 .45415 L
s
.62341 .45415 m
.61444 .47954 L
s
.43969 .75134 m
.45926 .73503 L
s
.43969 .75134 m
.42834 .74415 L
s
.589 .672 .897 r
.61334 .5606 m .62606 .57932 L .60097 .58259 L p F P
0 g
s
.589 .672 .897 r
.60097 .58259 m .58815 .56431 L .61334 .5606 L p F P
0 g
s
.618 .716 .916 r
.33402 .49206 m .34886 .50886 L .32529 .51433 L p F P
0 g
s
.618 .716 .916 r
.32529 .51433 m .31033 .49796 L .33402 .49206 L p F P
0 g
s
.45926 .73503 m
.44796 .7318 L
s
.628 .732 .922 r
.23249 .47777 m .24821 .49381 L .22511 .49995 L p F P
0 g
s
.628 .732 .922 r
.22511 .49995 m .20926 .48435 L .23249 .47777 L p F P
0 g
s
.84257 .42836 m
.8672 .45669 L
s
.85656 .49402 m
.84257 .42836 L
s
.608 .7 .909 r
.43536 .50995 m .44939 .52753 L .42529 .53231 L p F P
0 g
s
.608 .7 .909 r
.42529 .53231 m .41114 .51516 L .43536 .50995 L p F P
0 g
s
.26706 .61336 m
.28447 .62588 L
s
.26706 .61336 m
.25518 .5954 L
s
.594 .678 .9 r
.57514 .54577 m .58815 .56431 L .56325 .56798 L p F P
0 g
s
.594 .678 .9 r
.56325 .56798 m .55014 .54988 L .57514 .54577 L p F P
0 g
s
.56997 .54662 m
.57518 .53703 L
s
.57047 .54654 m
.57518 .53703 L
s
.56522 .55713 m
.56802 .55148 L
s
.55577 .57277 m
.56029 .56444 L
s
.56029 .56444 m
.5603 .56443 L
s
.67236 .38325 m
.69144 .35388 L
s
.69144 .35388 m
.68392 .38109 L
s
.34879 .7109 m
.36717 .71984 L
s
.34879 .7109 m
.33727 .69361 L
s
.30786 .66299 m
.32568 .67553 L
s
.30786 .66299 m
.29621 .64468 L
s
.86904 .75092 m
.89005 .74591 L
s
.86904 .75092 m
.85916 .72544 L
s
.226 .56688 m
.2432 .57713 L
s
.226 .56688 m
.21379 .55003 L
s
.639 .747 .927 r
.13042 .46706 m .14709 .48231 L .12441 .48912 L p F P
0 g
s
.639 .747 .927 r
.12441 .48912 m .10759 .4743 L .13042 .46706 L p F P
0 g
s
.12441 .48912 m
.13766 .5008 L
s
.12441 .48912 m
.14152 .49214 L
s
.11098 .47728 m
.12441 .48912 L
s
.564 .634 .879 r
.86849 .66067 m .87967 .68093 L .85284 .68172 L p F P
0 g
s
.564 .634 .879 r
.85284 .68172 m .84159 .66191 L .86849 .66067 L p F P
0 g
s
.85844 .66541 m
.86018 .6676 L
s
.8583 .66524 m
.85844 .66541 L
s
.84631 .67982 m
.84796 .68653 L
s
.8463 .67978 m
.84631 .67982 L
s
.56 .628 .876 r
.90686 .68013 m .91783 .70058 L .89072 .70093 L p F P
0 g
s
.56 .628 .876 r
.89072 .70093 m .87967 .68093 L .90686 .68013 L p F P
0 g
s
.84796 .68653 m
.87169 .7087 L
s
.84796 .68653 m
.85916 .72544 L
s
.568 .64 .882 r
.83018 .64184 m .84159 .66191 L .81503 .66314 L p F P
0 g
s
.568 .64 .882 r
.81503 .66314 m .80355 .64352 L .83018 .64184 L p F P
0 g
s
.556 .623 .874 r
.94531 .70023 m .95608 .72088 L .92867 .72078 L p F P
0 g
s
.556 .623 .874 r
.92867 .72078 m .91783 .70058 L .94531 .70023 L p F P
0 g
s
.92442 .70266 m
.92443 .70263 L
s
.92486 .70049 m
.92707 .68963 L
s
.92278 .71073 m
.92442 .70266 L
s
.15453 .50575 m
.17164 .51073 L
s
.14152 .49214 m
.15453 .50575 L
s
.572 .645 .884 r
.79192 .62364 m .80355 .64352 L .77724 .64518 L p F P
0 g
s
.572 .645 .884 r
.77724 .64518 m .76554 .62574 L .79192 .62364 L p F P
0 g
s
.598 .684 .902 r
.53684 .53151 m .55014 .54988 L .52543 .55394 L p F P
0 g
s
.598 .684 .902 r
.52543 .55394 m .51202 .53601 L .53684 .53151 L p F P
0 g
s
.623 .722 .917 r
.29513 .48132 m .31033 .49796 L .28688 .5038 L p F P
0 g
s
.623 .722 .917 r
.28688 .5038 m .27155 .4876 L .29513 .48132 L p F P
0 g
s
.613 .706 .911 r
.39677 .49774 m .41114 .51516 L .38717 .52031 L p F P
0 g
s
.613 .706 .911 r
.38717 .52031 m .37269 .50333 L .39677 .49774 L p F P
0 g
s
.576 .651 .887 r
.75367 .60605 m .76554 .62574 L .73948 .62782 L p F P
0 g
s
.576 .651 .887 r
.73948 .62782 m .72753 .60857 L .75367 .60605 L p F P
0 g
s
.634 .737 .923 r
.19315 .46849 m .20926 .48435 L .18626 .49086 L p F P
0 g
s
.634 .737 .923 r
.18626 .49086 m .17001 .47544 L .19315 .46849 L p F P
0 g
s
.40901 .75008 m
.42834 .74415 L
s
.40901 .75008 m
.39756 .73799 L
s
.581 .657 .889 r
.71542 .58906 m .72753 .60857 L .70171 .61106 L p F P
0 g
s
.581 .657 .889 r
.70171 .61106 m .68951 .59199 L .71542 .58906 L p F P
0 g
s
.53614 .6071 m
.55577 .57277 L
s
.55577 .57277 m
.54542 .58991 L
s
.48759 .68914 m
.50739 .66017 L
s
.50739 .66017 m
.49638 .66773 L
s
.85916 .72544 m
.88174 .73536 L
s
.37865 .7353 m
.39756 .73799 L
s
.37865 .7353 m
.36717 .71984 L
s
.18428 .5261 m
.20147 .53296 L
s
.18428 .5261 m
.17164 .51073 L
s
.603 .69 .904 r
.49842 .51782 m .51202 .53601 L .48749 .54045 L p F P
0 g
s
.603 .69 .904 r
.48749 .54045 m .47377 .5227 L .49842 .51782 L p F P
0 g
s
.89005 .74591 m
.90943 .72493 L
s
.90943 .72493 m
.90304 .73051 L
s
.585 .663 .892 r
.67714 .57266 m .68951 .59199 L .66391 .5949 L p F P
0 g
s
.585 .663 .892 r
.66391 .5949 m .65145 .57601 L .67714 .57266 L p F P
0 g
s
.58483 .52304 m
.60422 .48846 L
s
.60422 .48846 m
.59479 .51247 L
s
.85294 .39019 m
.8672 .45669 L
s
.65319 .41434 m
.67236 .38325 L
s
.67236 .38325 m
.66444 .41155 L
s
.84563 .5271 m
.8707 .55967 L
s
.85927 .58958 m
.84563 .5271 L
s
.89005 .74591 m
.88174 .73536 L
s
.618 .712 .912 r
.35797 .48609 m .37269 .50333 L .34886 .50886 L p F P
0 g
s
.618 .712 .912 r
.34886 .50886 m .33402 .49206 L .35797 .48609 L p F P
0 g
s
.629 .727 .918 r
.25597 .47113 m .27155 .4876 L .24821 .49381 L p F P
0 g
s
.629 .727 .918 r
.24821 .49381 m .23249 .47777 L .25597 .47113 L p F P
0 g
s
.25518 .5954 m
.27265 .60661 L
s
.25518 .5954 m
.2432 .57713 L
s
.59 .669 .894 r
.63882 .55685 m .65145 .57601 L .62606 .57932 L p F P
0 g
s
.59 .669 .894 r
.62606 .57932 m .61334 .5606 L .63882 .55685 L p F P
0 g
s
.29621 .64468 m
.31403 .6567 L
s
.29621 .64468 m
.28447 .62588 L
s
.33727 .69361 m
.35561 .70323 L
s
.33727 .69361 m
.32568 .67553 L
s
.85941 .66438 m
.86018 .6676 L
s
.85934 .66411 m
.85941 .66438 L
s
.608 .696 .906 r
.45985 .50468 m .47377 .5227 L .44939 .52753 L p F P
0 g
s
.608 .696 .906 r
.44939 .52753 m .43536 .50995 L .45985 .50468 L p F P
0 g
s
.21379 .55003 m
.23112 .55855 L
s
.21379 .55003 m
.20147 .53296 L
s
.639 .743 .924 r
.15348 .45975 m .17001 .47544 L .14709 .48231 L p F P
0 g
s
.639 .743 .924 r
.14709 .48231 m .13042 .46706 L .15348 .45975 L p F P
0 g
s
.594 .674 .896 r
.60042 .54162 m .61334 .5606 L .58815 .56431 L p F P
0 g
s
.594 .674 .896 r
.58815 .56431 m .57514 .54577 L .60042 .54162 L p F P
0 g
s
.46775 .71328 m
.48759 .68914 L
s
.48759 .68914 m
.47637 .69228 L
s
.42834 .74415 m
.44796 .7318 L
s
.42834 .74415 m
.41688 .73505 L
s
.623 .718 .914 r
.31895 .47498 m .33402 .49206 L .31033 .49796 L p F P
0 g
s
.623 .718 .914 r
.31033 .49796 m .29513 .48132 L .31895 .47498 L p F P
0 g
s
.599 .68 .898 r
.56194 .52697 m .57514 .54577 L .55014 .54988 L p F P
0 g
s
.599 .68 .898 r
.55014 .54988 m .53684 .53151 L .56194 .52697 L p F P
0 g
s
.613 .702 .907 r
.42111 .49209 m .43536 .50995 L .41114 .51516 L p F P
0 g
s
.613 .702 .907 r
.41114 .51516 m .39677 .49774 L .42111 .49209 L p F P
0 g
s
.565 .631 .876 r
.89574 .65941 m .90686 .68013 L .87967 .68093 L p F P
0 g
s
.565 .631 .876 r
.87967 .68093 m .86849 .66067 L .89574 .65941 L p F P
0 g
s
.14152 .49214 m
.15887 .49517 L
s
.12835 .47835 m
.14152 .49214 L
s
.569 .636 .878 r
.85716 .64014 m .86849 .66067 L .84159 .66191 L p F P
0 g
s
.8358 .63697 m
.84824 .65261 L
s
.569 .636 .878 r
.84159 .66191 m .83018 .64184 L .85716 .64014 L p F P
0 g
s
.84761 .61526 m
.85364 .64036 L
s
.634 .733 .92 r
.21652 .46148 m .23249 .47777 L .20926 .48435 L p F P
0 g
s
.634 .733 .92 r
.20926 .48435 m .19315 .46849 L .21652 .46148 L p F P
0 g
s
.561 .625 .873 r
.93439 .67931 m .94531 .70023 L .91783 .70058 L p F P
0 g
s
.561 .625 .873 r
.91783 .70058 m .90686 .68013 L .93439 .67931 L p F P
0 g
s
.11098 .47728 m
.12835 .47835 L
s
.51633 .63906 m
.53614 .6071 L
s
.53614 .6071 m
.52543 .62059 L
s
.573 .642 .881 r
.81863 .62151 m .83018 .64184 L .80355 .64352 L p F P
0 g
s
.573 .642 .881 r
.80355 .64352 m .79192 .62364 L .81863 .62151 L p F P
0 g
s
.44796 .7318 m
.46775 .71328 L
s
.46775 .71328 m
.45638 .71199 L
s
.44796 .7318 m
.43652 .72636 L
s
.78094 .25372 m
.8007 .23542 L
s
.7945 .25142 m
.8007 .23542 L
s
.76139 .27474 m
.78094 .25372 L
s
.78094 .25372 m
.77478 .27459 L
s
.6339 .44663 m
.65319 .41434 L
s
.65319 .41434 m
.64483 .44273 L
s
.36717 .71984 m
.38603 .72434 L
s
.36717 .71984 m
.35561 .70323 L
s
.577 .648 .883 r
.78013 .60349 m .79192 .62364 L .76554 .62574 L p F P
0 g
s
.577 .648 .883 r
.76554 .62574 m .75367 .60605 L .78013 .60349 L p F P
0 g
s
.17164 .51073 m
.18902 .51568 L
s
.15887 .49517 m
.17164 .51073 L
s
.581 .653 .886 r
.74164 .58608 m .75367 .60605 L .72753 .60857 L p F P
0 g
s
.581 .653 .886 r
.72753 .60857 m .71542 .58906 L .74164 .58608 L p F P
0 g
s
.39756 .73799 m
.41688 .73505 L
s
.39756 .73799 m
.38603 .72434 L
s
.56522 .55713 m
.5714 .54639 L
s
.57328 .54312 m
.58483 .52304 L
s
.74197 .29829 m
.76139 .27474 L
s
.76139 .27474 m
.75513 .29962 L
s
.604 .686 .9 r
.52334 .51288 m .53684 .53151 L .51202 .53601 L p F P
0 g
s
.604 .686 .9 r
.51202 .53601 m .49842 .51782 L .52334 .51288 L p F P
0 g
s
.28447 .62588 m
.30231 .63713 L
s
.28447 .62588 m
.27265 .60661 L
s
.2432 .57713 m
.26076 .58689 L
s
.2432 .57713 m
.23112 .55855 L
s
.645 .749 .925 r
.11347 .45155 m .13042 .46706 L .10759 .4743 L p F P
0 g
s
.645 .749 .925 r
.10759 .4743 m .09048 .45922 L .11347 .45155 L p F P
0 g
s
.10759 .4743 m
.11098 .47728 L
s
.09736 .46528 m
.10759 .4743 L
s
.32568 .67553 m
.34399 .68549 L
s
.32568 .67553 m
.31403 .6567 L
s
.586 .659 .888 r
.70314 .56927 m .71542 .58906 L .68951 .59199 L p F P
0 g
s
.586 .659 .888 r
.68951 .59199 m .67714 .57266 L .70314 .56927 L p F P
0 g
s
.629 .723 .915 r
.27968 .46442 m .29513 .48132 L .27155 .4876 L p F P
0 g
s
.629 .723 .915 r
.27155 .4876 m .25597 .47113 L .27968 .46442 L p F P
0 g
s
.618 .708 .909 r
.38218 .48006 m .39677 .49774 L .37269 .50333 L p F P
0 g
s
.618 .708 .909 r
.37269 .50333 m .35797 .48609 L .38218 .48006 L p F P
0 g
s
.85656 .49402 m
.88184 .52523 L
s
.8707 .55967 m
.85656 .49402 L
s
.92278 .71073 m
.9306 .6963 L
s
.9306 .6963 m
.93063 .69624 L
s
.93705 .6844 m
.94084 .6774 L
s
.93661 .69765 m
.93871 .68759 L
s
.93871 .68759 m
.94084 .6774 L
s
.59 .665 .891 r
.6646 .55305 m .67714 .57266 L .65145 .57601 L p F P
0 g
s
.59 .665 .891 r
.65145 .57601 m .63882 .55685 L .6646 .55305 L p F P
0 g
s
.20147 .53296 m
.21894 .53969 L
s
.20147 .53296 m
.18902 .51568 L
s
.72264 .32407 m
.74197 .29829 L
s
.74197 .29829 m
.7355 .32625 L
s
.86018 .6676 m
.88429 .68974 L
s
.86018 .6676 m
.87169 .7087 L
s
.639 .739 .921 r
.17677 .45237 m .19315 .46849 L .17001 .47544 L p F P
0 g
s
.639 .739 .921 r
.17001 .47544 m .15348 .45975 L .17677 .45237 L p F P
0 g
s
.609 .692 .902 r
.48461 .49935 m .49842 .51782 L .47377 .5227 L p F P
0 g
s
.609 .692 .902 r
.47377 .5227 m .45985 .50468 L .48461 .49935 L p F P
0 g
s
.88174 .73536 m
.90304 .73051 L
s
.88174 .73536 m
.87169 .7087 L
s
.595 .671 .893 r
.626 .53742 m .63882 .55685 L .61334 .5606 L p F P
0 g
s
.595 .671 .893 r
.61334 .5606 m .60042 .54162 L .626 .53742 L p F P
0 g
s
.49638 .66773 m
.51633 .63906 L
s
.51633 .63906 m
.50531 .6484 L
s
.624 .714 .911 r
.34303 .46857 m .35797 .48609 L .33402 .49206 L p F P
0 g
s
.624 .714 .911 r
.33402 .49206 m .31895 .47498 L .34303 .46857 L p F P
0 g
s
.61444 .47954 m
.6339 .44663 L
s
.6339 .44663 m
.62506 .47415 L
s
.634 .729 .917 r
.24013 .4544 m .25597 .47113 L .23249 .47777 L p F P
0 g
s
.634 .729 .917 r
.23249 .47777 m .21652 .46148 L .24013 .4544 L p F P
0 g
s
.614 .698 .904 r
.44571 .48638 m .45985 .50468 L .43536 .50995 L p F P
0 g
s
.614 .698 .904 r
.43536 .50995 m .42111 .49209 L .44571 .48638 L p F P
0 g
s
.87169 .7087 m
.89463 .71879 L
s
.35561 .70323 m
.37442 .70914 L
s
.35561 .70323 m
.34399 .68549 L
s
.599 .677 .895 r
.58733 .52237 m .60042 .54162 L .57514 .54577 L p F P
0 g
s
.599 .677 .895 r
.57514 .54577 m .56194 .52697 L .58733 .52237 L p F P
0 g
s
.57495 .54477 m
.57918 .53546 L
s
.57918 .53546 m
.57921 .53539 L
s
.7033 .3518 m
.72264 .32407 L
s
.72264 .32407 m
.71584 .3542 L
s
.41688 .73505 m
.43652 .72636 L
s
.41688 .73505 m
.40531 .724 L
s
.27265 .60661 m
.29053 .61688 L
s
.27265 .60661 m
.26076 .58689 L
s
.12835 .47835 m
.14594 .47942 L
s
.31403 .6567 m
.33231 .66667 L
s
.31403 .6567 m
.30231 .63713 L
s
.54542 .58991 m
.56522 .55713 L
s
.56522 .55713 m
.55492 .57578 L
s
.23112 .55855 m
.24878 .56675 L
s
.23112 .55855 m
.21894 .53969 L
s
.57 .633 .875 r
.88448 .63842 m .89574 .65941 L .86849 .66067 L p F P
0 g
s
.57 .633 .875 r
.86849 .66067 m .85716 .64014 L .88448 .63842 L p F P
0 g
s
.85927 .58958 m
.8709 .63928 L
s
.566 .628 .872 r
.92334 .65813 m .93439 .67931 L .90686 .68013 L p F P
0 g
s
.566 .628 .872 r
.90686 .68013 m .89574 .65941 L .92334 .65813 L p F P
0 g
s
.574 .639 .878 r
.84568 .61935 m .85716 .64014 L .83018 .64184 L p F P
0 g
s
.84761 .61526 m
.86749 .63949 L
s
.574 .639 .878 r
.83018 .64184 m .81863 .62151 L .84568 .61935 L p F P
0 g
s
.15887 .49517 m
.17645 .49818 L
s
.14594 .47942 m
.15887 .49517 L
s
.645 .745 .922 r
.13668 .4438 m .15348 .45975 L .13042 .46706 L p F P
0 g
s
.645 .745 .922 r
.13042 .46706 m .11347 .45155 L .13668 .4438 L p F P
0 g
s
.11502 .46439 m
.12835 .47835 L
s
.578 .644 .88 r
.80692 .6009 m .81863 .62151 L .79192 .62364 L p F P
0 g
s
.578 .644 .88 r
.79192 .62364 m .78013 .60349 L .80692 .6009 L p F P
0 g
s
.8672 .45669 m
.88184 .52523 L
s
.90304 .73051 m
.92278 .71073 L
s
.92278 .71073 m
.91637 .7152 L
s
.09777 .46526 m
.11502 .46439 L
s
.09736 .46528 m
.09777 .46526 L
s
.604 .683 .897 r
.54855 .50788 m .56194 .52697 L .53684 .53151 L p F P
0 g
s
.604 .683 .897 r
.53684 .53151 m .52334 .51288 L .54855 .50788 L p F P
0 g
s
.38603 .72434 m
.40531 .724 L
s
.38603 .72434 m
.37442 .70914 L
s
.90304 .73051 m
.89463 .71879 L
s
.629 .719 .912 r
.30364 .45764 m .31895 .47498 L .29513 .48132 L p F P
0 g
s
.629 .719 .912 r
.29513 .48132 m .27968 .46442 L .30364 .45764 L p F P
0 g
s
.582 .65 .883 r
.76819 .58307 m .78013 .60349 L .75367 .60605 L p F P
0 g
s
.582 .65 .883 r
.75367 .60605 m .74164 .58608 L .76819 .58307 L p F P
0 g
s
.47637 .69228 m
.49638 .66773 L
s
.49638 .66773 m
.48513 .67263 L
s
.619 .704 .906 r
.40664 .47397 m .42111 .49209 L .39677 .49774 L p F P
0 g
s
.619 .704 .906 r
.39677 .49774 m .38218 .48006 L .40664 .47397 L p F P
0 g
s
.586 .656 .885 r
.72945 .56584 m .74164 .58608 L .71542 .58906 L p F P
0 g
s
.586 .656 .885 r
.71542 .58906 m .70314 .56927 L .72945 .56584 L p F P
0 g
s
.18902 .51568 m
.20666 .52055 L
s
.18902 .51568 m
.17645 .49818 L
s
.639 .735 .918 r
.20028 .44491 m .21652 .46148 L .19315 .46849 L p F P
0 g
s
.639 .735 .918 r
.19315 .46849 m .17677 .45237 L .20028 .44491 L p F P
0 g
s
.43652 .72636 m
.45638 .71199 L
s
.43652 .72636 m
.42495 .71861 L
s
.68392 .38109 m
.7033 .3518 L
s
.7033 .3518 m
.6961 .38313 L
s
.609 .688 .899 r
.50964 .49396 m .52334 .51288 L .49842 .51782 L p F P
0 g
s
.609 .688 .899 r
.49842 .51782 m .48461 .49935 L .50964 .49396 L p F P
0 g
s
.591 .662 .887 r
.69069 .54921 m .70314 .56927 L .67714 .57266 L p F P
0 g
s
.591 .662 .887 r
.67714 .57266 m .6646 .55305 L .69069 .54921 L p F P
0 g
s
.45638 .71199 m
.47637 .69228 L
s
.47637 .69228 m
.46495 .6927 L
s
.59479 .51247 m
.61444 .47954 L
s
.45638 .71199 m
.44486 .70813 L
s
.624 .71 .907 r
.36736 .4621 m .38218 .48006 L .35797 .48609 L p F P
0 g
s
.624 .71 .907 r
.35797 .48609 m .34303 .46857 L .36736 .4621 L p F P
0 g
s
.595 .667 .89 r
.65188 .53317 m .6646 .55305 L .63882 .55685 L p F P
0 g
s
.595 .667 .89 r
.63882 .55685 m .626 .53742 L .65188 .53317 L p F P
0 g
s
.26076 .58689 m
.27868 .59598 L
s
.26076 .58689 m
.24878 .56675 L
s
.34399 .68549 m
.36275 .69243 L
s
.34399 .68549 m
.33231 .66667 L
s
.634 .725 .913 r
.26398 .44724 m .27968 .46442 L .25597 .47113 L p F P
0 g
s
.634 .725 .913 r
.25597 .47113 m .24013 .4544 L .26398 .44724 L p F P
0 g
s
.65 .75 .922 r
.09622 .43577 m .11347 .45155 L .09048 .45922 L p F P
0 g
s
.65 .75 .922 r
.09048 .45922 m .07308 .44389 L .09622 .43577 L p F P
0 g
s
.09048 .45922 m
.09736 .46528 L
s
.08356 .45312 m
.09048 .45922 L
s
.30231 .63713 m
.32058 .64681 L
s
.30231 .63713 m
.29053 .61688 L
s
.52543 .62059 m
.54542 .58991 L
s
.54542 .58991 m
.53473 .60485 L
s
.614 .694 .901 r
.47059 .48061 m .48461 .49935 L .45985 .50468 L p F P
0 g
s
.614 .694 .901 r
.45985 .50468 m .44571 .48638 L .47059 .48061 L p F P
0 g
s
.21894 .53969 m
.23672 .5462 L
s
.21894 .53969 m
.20666 .52055 L
s
.6 .673 .892 r
.61301 .51771 m .626 .53742 L .60042 .54162 L p F P
0 g
s
.6 .673 .892 r
.60042 .54162 m .58733 .52237 L .61301 .51771 L p F P
0 g
s
.645 .74 .919 r
.16011 .43598 m .17677 .45237 L .15348 .45975 L p F P
0 g
s
.645 .74 .919 r
.15348 .45975 m .13668 .4438 L .16011 .43598 L p F P
0 g
s
.87339 .6493 m
.88429 .68974 L
s
.87333 .6491 m
.87339 .6493 L
s
.8707 .55967 m
.89616 .58957 L
s
.14594 .47942 m
.16375 .48047 L
s
.13287 .46348 m
.14594 .47942 L
s
.40531 .724 m
.42495 .71861 L
s
.40531 .724 m
.39366 .71098 L
s
.66444 .41155 m
.68392 .38109 L
s
.68392 .38109 m
.67625 .41271 L
s
.11502 .46439 m
.13287 .46348 L
s
.629 .715 .909 r
.32784 .45078 m .34303 .46857 L .31895 .47498 L p F P
0 g
s
.629 .715 .909 r
.31895 .47498 m .30364 .45764 L .32784 .45078 L p F P
0 g
s
.37442 .70914 m
.39366 .71098 L
s
.37442 .70914 m
.36275 .69243 L
s
.604 .679 .894 r
.57404 .50283 m .58733 .52237 L .56194 .52697 L p F P
0 g
s
.604 .679 .894 r
.56194 .52697 m .54855 .50788 L .57404 .50283 L p F P
0 g
s
.57 .63 .872 r
.91215 .63668 m .92334 .65813 L .89574 .65941 L p F P
0 g
s
.57 .63 .872 r
.89574 .65941 m .88448 .63842 L .91215 .63668 L p F P
0 g
s
.87483 .64771 m
.89688 .66816 L
s
.8747 .64759 m
.87483 .64771 L
s
.574 .636 .874 r
.87307 .61716 m .88448 .63842 L .85716 .64014 L p F P
0 g
s
.574 .636 .874 r
.85716 .64014 m .84568 .61935 L .87307 .61716 L p F P
0 g
s
.619 .7 .903 r
.43136 .46781 m .44571 .48638 L .42111 .49209 L p F P
0 g
s
.619 .7 .903 r
.42111 .49209 m .40664 .47397 L .43136 .46781 L p F P
0 g
s
.578 .641 .877 r
.83405 .59828 m .84568 .61935 L .81863 .62151 L p F P
0 g
s
.578 .641 .877 r
.81863 .62151 m .80692 .6009 L .83405 .59828 L p F P
0 g
s
.17645 .49818 m
.19428 .50114 L
s
.17645 .49818 m
.16375 .48047 L
s
.64 .731 .915 r
.22404 .43739 m .24013 .4544 L .21652 .46148 L p F P
0 g
s
.64 .731 .915 r
.21652 .46148 m .20028 .44491 L .22404 .43739 L p F P
0 g
s
.583 .647 .879 r
.79506 .58002 m .80692 .6009 L .78013 .60349 L p F P
0 g
s
.583 .647 .879 r
.78013 .60349 m .76819 .58307 L .79506 .58002 L p F P
0 g
s
.89463 .71879 m
.91637 .7152 L
s
.89463 .71879 m
.88429 .68974 L
s
.587 .652 .882 r
.75608 .56237 m .76819 .58307 L .74164 .58608 L p F P
0 g
s
.587 .652 .882 r
.74164 .58608 m .72945 .56584 L .75608 .56237 L p F P
0 g
s
.57495 .54477 m
.58588 .52697 L
s
.58588 .52697 m
.58592 .52692 L
s
.58889 .52208 m
.59479 .51247 L
s
.24878 .56675 m
.26678 .57448 L
s
.24878 .56675 m
.23672 .5462 L
s
.50531 .6484 m
.52543 .62059 L
s
.52543 .62059 m
.51442 .63135 L
s
.609 .685 .896 r
.53496 .48852 m .54855 .50788 L .52334 .51288 L p F P
0 g
s
.609 .685 .896 r
.52334 .51288 m .50964 .49396 L .53496 .48852 L p F P
0 g
s
.29053 .61688 m
.3088 .62598 L
s
.29053 .61688 m
.27868 .59598 L
s
.33231 .66667 m
.35103 .67424 L
s
.33231 .66667 m
.32058 .64681 L
s
.591 .658 .884 r
.71709 .54532 m .72945 .56584 L .70314 .56927 L p F P
0 g
s
.591 .658 .884 r
.70314 .56927 m .69069 .54921 L .71709 .54532 L p F P
0 g
s
.65 .746 .92 r
.11958 .42758 m .13668 .4438 L .11347 .45155 L p F P
0 g
s
.65 .746 .92 r
.11347 .45155 m .09622 .43577 L .11958 .42758 L p F P
0 g
s
.10152 .45026 m
.11502 .46439 L
s
.08447 .45298 m
.10152 .45026 L
s
.08356 .45312 m
.08447 .45298 L
s
.88429 .68974 m
.90769 .70092 L
s
.624 .706 .904 r
.39194 .45556 m .40664 .47397 L .38218 .48006 L p F P
0 g
s
.624 .706 .904 r
.38218 .48006 m .36736 .4621 L .39194 .45556 L p F P
0 g
s
.634 .721 .91 r
.28808 .44001 m .30364 .45764 L .27968 .46442 L p F P
0 g
s
.634 .721 .91 r
.27968 .46442 m .26398 .44724 L .28808 .44001 L p F P
0 g
s
.20666 .52055 m
.22458 .52529 L
s
.20666 .52055 m
.19428 .50114 L
s
.596 .664 .886 r
.67806 .52887 m .69069 .54921 L .6646 .55305 L p F P
0 g
s
.596 .664 .886 r
.6646 .55305 m .65188 .53317 L .67806 .52887 L p F P
0 g
s
.42495 .71861 m
.44486 .70813 L
s
.42495 .71861 m
.41328 .70849 L
s
.614 .691 .898 r
.49574 .47477 m .50964 .49396 L .48461 .49935 L p F P
0 g
s
.614 .691 .898 r
.48461 .49935 m .47059 .48061 L .49574 .47477 L p F P
0 g
s
.64483 .44273 m
.66444 .41155 L
s
.66444 .41155 m
.65626 .44254 L
s
.645 .736 .916 r
.18378 .42807 m .20028 .44491 L .17677 .45237 L p F P
0 g
s
.645 .736 .916 r
.17677 .45237 m .16011 .43598 L .18378 .42807 L p F P
0 g
s
.6 .67 .888 r
.63898 .51301 m .65188 .53317 L .626 .53742 L p F P
0 g
s
.6 .67 .888 r
.626 .53742 m .61301 .51771 L .63898 .51301 L p F P
0 g
s
.48513 .67263 m
.50531 .6484 L
s
.50531 .6484 m
.49404 .65471 L
s
.77478 .27459 m
.7945 .25142 L
s
.78922 .28086 m
.7945 .25142 L
s
.36275 .69243 m
.38195 .69601 L
s
.36275 .69243 m
.35103 .67424 L
s
.88184 .52523 m
.89616 .58957 L
s
.629 .712 .906 r
.3523 .44386 m .36736 .4621 L .34303 .46857 L p F P
0 g
s
.629 .712 .906 r
.34303 .46857 m .32784 .45078 L .3523 .44386 L p F P
0 g
s
.13287 .46348 m
.15093 .46255 L
s
.11966 .44736 m
.13287 .46348 L
s
.91637 .7152 m
.93661 .69765 L
s
.91637 .7152 m
.90769 .70092 L
s
.64 .727 .912 r
.24803 .42978 m .26398 .44724 L .24013 .4544 L p F P
0 g
s
.64 .727 .912 r
.24013 .4544 m .22404 .43739 L .24803 .42978 L p F P
0 g
s
.619 .696 .899 r
.45636 .46158 m .47059 .48061 L .44571 .48638 L p F P
0 g
s
.619 .696 .899 r
.44571 .48638 m .43136 .46781 L .45636 .46158 L p F P
0 g
s
.92999 .69957 m
.93661 .69765 L
s
.16375 .48047 m
.18179 .48149 L
s
.15093 .46255 m
.16375 .48047 L
s
.605 .675 .891 r
.59982 .49772 m .61301 .51771 L .58733 .52237 L p F P
0 g
s
.605 .675 .891 r
.58733 .52237 m .57404 .50283 L .59982 .49772 L p F P
0 g
s
.58498 .53564 m
.59153 .52017 L
s
.59153 .52017 m
.59155 .52013 L
s
.59155 .52013 m
.59155 .52012 L
s
.55492 .57578 m
.57495 .54477 L
s
.57495 .54477 m
.56469 .56465 L
s
.23672 .5462 m
.25481 .55242 L
s
.23672 .5462 m
.22458 .52529 L
s
.44486 .70813 m
.46495 .6927 L
s
.44486 .70813 m
.4332 .70154 L
s
.39366 .71098 m
.41328 .70849 L
s
.39366 .71098 m
.38195 .69601 L
s
.27868 .59598 m
.29697 .60424 L
s
.27868 .59598 m
.26678 .57448 L
s
.10152 .45026 m
.11966 .44736 L
s
.75513 .29962 m
.77478 .27459 L
s
.77478 .27459 m
.76925 .30681 L
s
.32058 .64681 m
.33927 .65464 L
s
.32058 .64681 m
.3088 .62598 L
s
.656 .751 .92 r
.07868 .41972 m .09622 .43577 L .07308 .44389 L p F P
0 g
s
.08785 .43594 m
.10152 .45026 L
s
.656 .751 .92 r
.07308 .44389 m .05538 .42829 L .07868 .41972 L p F P
0 g
s
.07308 .44389 m
.08356 .45312 L
s
.06957 .44079 m
.07308 .44389 L
s
.46495 .6927 m
.48513 .67263 L
s
.48513 .67263 m
.47366 .67444 L
s
.575 .633 .871 r
.90081 .61495 m .91215 .63668 L .88448 .63842 L p F P
0 g
s
.575 .633 .871 r
.88448 .63842 m .87307 .61716 L .90081 .61495 L p F P
0 g
s
.85927 .58958 m
.88177 .61647 L
s
.579 .638 .874 r
.86151 .59563 m .87307 .61716 L .84568 .61935 L p F P
0 g
s
.8707 .55967 m
.88362 .61632 L
s
.579 .638 .874 r
.84568 .61935 m .83405 .59828 L .86151 .59563 L p F P
0 g
s
.46495 .6927 m
.45336 .69014 L
s
.583 .644 .876 r
.82226 .57693 m .83405 .59828 L .80692 .6009 L p F P
0 g
s
.583 .644 .876 r
.80692 .6009 m .79506 .58002 L .82226 .57693 L p F P
0 g
s
.19428 .50114 m
.21236 .50403 L
s
.19428 .50114 m
.18179 .48149 L
s
.65 .742 .917 r
.14317 .4193 m .16011 .43598 L .13668 .4438 L p F P
0 g
s
.65 .742 .917 r
.13668 .4438 m .11958 .42758 L .14317 .4193 L p F P
0 g
s
.61 .681 .893 r
.56056 .48301 m .57404 .50283 L .54855 .50788 L p F P
0 g
s
.61 .681 .893 r
.54855 .50788 m .53496 .48852 L .56056 .48301 L p F P
0 g
s
.8943 .62902 m
.9094 .64336 L
s
.89418 .6289 m
.8943 .62902 L
s
.88834 .635 m
.89688 .66816 L
s
.88832 .63493 m
.88834 .635 L
s
.587 .649 .878 r
.78303 .55886 m .79506 .58002 L .76819 .58307 L p F P
0 g
s
.587 .649 .878 r
.76819 .58307 m .75608 .56237 L .78303 .55886 L p F P
0 g
s
.62506 .47415 m
.64483 .44273 L
s
.634 .717 .907 r
.31242 .43271 m .32784 .45078 L .30364 .45764 L p F P
0 g
s
.634 .717 .907 r
.30364 .45764 m .28808 .44001 L .31242 .43271 L p F P
0 g
s
.624 .702 .901 r
.41679 .44894 m .43136 .46781 L .40664 .47397 L p F P
0 g
s
.624 .702 .901 r
.40664 .47397 m .39194 .45556 L .41679 .44894 L p F P
0 g
s
.06957 .44079 m
.08785 .43594 L
s
.05538 .42829 m
.06957 .44079 L
s
.592 .655 .881 r
.74381 .54139 m .75608 .56237 L .72945 .56584 L p F P
0 g
s
.592 .655 .881 r
.72945 .56584 m .71709 .54532 L .74381 .54139 L p F P
0 g
s
.7355 .32625 m
.75513 .29962 L
s
.75513 .29962 m
.74924 .33374 L
s
.645 .732 .913 r
.20768 .42009 m .22404 .43739 L .20028 .44491 L p F P
0 g
s
.645 .732 .913 r
.20028 .44491 m .18378 .42807 L .20768 .42009 L p F P
0 g
s
.614 .687 .894 r
.52117 .46887 m .53496 .48852 L .50964 .49396 L p F P
0 g
s
.614 .687 .894 r
.50964 .49396 m .49574 .47477 L .52117 .46887 L p F P
0 g
s
.596 .66 .883 r
.70456 .52452 m .71709 .54532 L .69069 .54921 L p F P
0 g
s
.596 .66 .883 r
.69069 .54921 m .67806 .52887 L .70456 .52452 L p F P
0 g
s
.53473 .60485 m
.55492 .57578 L
s
.55492 .57578 m
.54425 .59181 L
s
.35103 .67424 m
.37017 .67911 L
s
.35103 .67424 m
.33927 .65464 L
s
.26678 .57448 m
.28511 .58164 L
s
.26678 .57448 m
.25481 .55242 L
s
.22458 .52529 m
.24279 .52985 L
s
.22458 .52529 m
.21236 .50403 L
s
.3088 .62598 m
.32747 .63369 L
s
.3088 .62598 m
.29697 .60424 L
s
.6 .666 .885 r
.66526 .50825 m .67806 .52887 L .65188 .53317 L p F P
0 g
s
.6 .666 .885 r
.65188 .53317 m .63898 .51301 L .66526 .50825 L p F P
0 g
s
.629 .708 .903 r
.37702 .43686 m .39194 .45556 L .36736 .4621 L p F P
0 g
s
.629 .708 .903 r
.36736 .4621 m .3523 .44386 L .37702 .43686 L p F P
0 g
s
.41328 .70849 m
.4332 .70154 L
s
.41328 .70849 m
.40153 .69596 L
s
.639 .723 .908 r
.27226 .4221 m .28808 .44001 L .26398 .44724 L p F P
0 g
s
.639 .723 .908 r
.26398 .44724 m .24803 .42978 L .27226 .4221 L p F P
0 g
s
.15093 .46255 m
.16919 .46159 L
s
.13798 .44443 m
.15093 .46255 L
s
.11966 .44736 m
.13798 .44443 L
s
.656 .747 .917 r
.1022 .41108 m .11958 .42758 L .09622 .43577 L p F P
0 g
s
.10629 .43105 m
.11966 .44736 L
s
.656 .747 .917 r
.09622 .43577 m .07868 .41972 L .1022 .41108 L p F P
0 g
s
.71584 .3542 m
.7355 .32625 L
s
.7355 .32625 m
.72916 .36141 L
s
.619 .693 .896 r
.48163 .45529 m .49574 .47477 L .47059 .48061 L p F P
0 g
s
.619 .693 .896 r
.47059 .48061 m .45636 .46158 L .48163 .45529 L p F P
0 g
s
.90769 .70092 m
.92999 .69957 L
s
.90769 .70092 m
.89688 .66816 L
s
.38195 .69601 m
.40153 .69596 L
s
.38195 .69601 m
.37017 .67911 L
s
.605 .672 .887 r
.6259 .49256 m .63898 .51301 L .61301 .51771 L p F P
0 g
s
.605 .672 .887 r
.61301 .51771 m .59982 .49772 L .6259 .49256 L p F P
0 g
s
.60847 .49601 m
.61444 .47954 L
s
.89688 .66816 m
.92084 .6812 L
s
.61143 .49542 m
.62506 .47415 L
s
.18179 .48149 m
.20005 .48246 L
s
.18179 .48149 m
.16919 .46159 L
s
.65 .738 .914 r
.16699 .41095 m .18378 .42807 L .16011 .43598 L p F P
0 g
s
.65 .738 .914 r
.16011 .43598 m .14317 .4193 L .16699 .41095 L p F P
0 g
s
.08785 .43594 m
.10629 .43105 L
s
.074 .42144 m
.08785 .43594 L
s
.51442 .63135 m
.53473 .60485 L
s
.53473 .60485 m
.52372 .61662 L
s
.634 .713 .904 r
.33701 .42533 m .3523 .44386 L .32784 .45078 L p F P
0 g
s
.634 .713 .904 r
.32784 .45078 m .31242 .43271 L .33701 .42533 L p F P
0 g
s
.58 .635 .87 r
.88933 .59294 m .90081 .61495 L .87307 .61716 L p F P
0 g
s
.58 .635 .87 r
.87307 .61716 m .86151 .59563 L .88933 .59294 L p F P
0 g
s
.61 .677 .889 r
.58645 .47744 m .59982 .49772 L .57404 .50283 L p F P
0 g
s
.61 .677 .889 r
.57404 .50283 m .56056 .48301 L .58645 .47744 L p F P
0 g
s
.584 .64 .873 r
.84981 .57381 m .86151 .59563 L .83405 .59828 L p F P
0 g
s
.584 .64 .873 r
.83405 .59828 m .82226 .57693 L .84981 .57381 L p F P
0 g
s
.624 .698 .898 r
.44191 .44226 m .45636 .46158 L .43136 .46781 L p F P
0 g
s
.624 .698 .898 r
.43136 .46781 m .41679 .44894 L .44191 .44226 L p F P
0 g
s
.25481 .55242 m
.27321 .55826 L
s
.25481 .55242 m
.24279 .52985 L
s
.588 .646 .875 r
.81032 .5553 m .82226 .57693 L .79506 .58002 L p F P
0 g
s
.588 .646 .875 r
.79506 .58002 m .78303 .55886 L .81032 .5553 L p F P
0 g
s
.645 .728 .91 r
.23181 .41203 m .24803 .42978 L .22404 .43739 L p F P
0 g
s
.645 .728 .91 r
.22404 .43739 m .20768 .42009 L .23181 .41203 L p F P
0 g
s
.4332 .70154 m
.45336 .69014 L
s
.4332 .70154 m
.42144 .69211 L
s
.29697 .60424 m
.31564 .61148 L
s
.29697 .60424 m
.28511 .58164 L
s
.21236 .50403 m
.2307 .50682 L
s
.21236 .50403 m
.20005 .48246 L
s
.33927 .65464 m
.35836 .66035 L
s
.33927 .65464 m
.32747 .63369 L
s
.6961 .38313 m
.71584 .3542 L
s
.71584 .3542 m
.70898 .38953 L
s
.90382 .62072 m
.9094 .64336 L
s
.90379 .6206 m
.90382 .62072 L
s
.89616 .58957 m
.90379 .6206 L
s
.592 .651 .878 r
.77085 .53741 m .78303 .55886 L .75608 .56237 L p F P
0 g
s
.592 .651 .878 r
.75608 .56237 m .74381 .54139 L .77085 .53741 L p F P
0 g
s
.614 .683 .891 r
.54688 .4629 m .56056 .48301 L .53496 .48852 L p F P
0 g
s
.614 .683 .891 r
.53496 .48852 m .52117 .46887 L .54688 .4629 L p F P
0 g
s
.05538 .42829 m
.074 .42144 L
s
.596 .657 .88 r
.73137 .52012 m .74381 .54139 L .71709 .54532 L p F P
0 g
s
.596 .657 .88 r
.71709 .54532 m .70456 .52452 L .73137 .52012 L p F P
0 g
s
.49404 .65471 m
.51442 .63135 L
s
.51442 .63135 m
.50313 .63863 L
s
.629 .704 .9 r
.402 .42979 m .41679 .44894 L .39194 .45556 L p F P
0 g
s
.629 .704 .9 r
.39194 .45556 m .37702 .43686 L .402 .42979 L p F P
0 g
s
.58498 .53564 m
.60475 .50583 L
s
.60475 .50583 m
.60476 .50582 L
s
.59536 .52954 m
.605 .50557 L
s
.639 .719 .905 r
.29675 .41434 m .31242 .43271 L .28808 .44001 L p F P
0 g
s
.639 .719 .905 r
.28808 .44001 m .27226 .4221 L .29675 .41434 L p F P
0 g
s
.655 .743 .914 r
.12594 .40235 m .14317 .4193 L .11958 .42758 L p F P
0 g
s
.655 .743 .914 r
.11958 .42758 m .1022 .41108 L .12594 .40235 L p F P
0 g
s
.13798 .44443 m
.15648 .44147 L
s
.12489 .42611 m
.13798 .44443 L
s
.45336 .69014 m
.47366 .67444 L
s
.45336 .69014 m
.44162 .68437 L
s
.601 .663 .882 r
.69185 .50343 m .70456 .52452 L .67806 .52887 L p F P
0 g
s
.601 .663 .882 r
.67806 .52887 m .66526 .50825 L .69185 .50343 L p F P
0 g
s
.92084 .6812 m
.92999 .69957 L
s
.16919 .46159 m
.18766 .4606 L
s
.15648 .44147 m
.16919 .46159 L
s
.619 .689 .893 r
.50717 .44892 m .52117 .46887 L .49574 .47477 L p F P
0 g
s
.619 .689 .893 r
.49574 .47477 m .48163 .45529 L .50717 .44892 L p F P
0 g
s
.47366 .67444 m
.49404 .65471 L
s
.49404 .65471 m
.48254 .65746 L
s
.37017 .67911 m
.38971 .68102 L
s
.37017 .67911 m
.35836 .66035 L
s
.10629 .43105 m
.12489 .42611 L
s
.09345 .41539 m
.10629 .43105 L
s
.09276 .41454 m
.09345 .41539 L
s
.40153 .69596 m
.42144 .69211 L
s
.40153 .69596 m
.38971 .68102 L
s
.47366 .67444 m
.46201 .67278 L
s
.24279 .52985 m
.26128 .53418 L
s
.24279 .52985 m
.2307 .50682 L
s
.65 .734 .911 r
.19104 .40251 m .20768 .42009 L .18378 .42807 L p F P
0 g
s
.65 .734 .911 r
.18378 .42807 m .16699 .41095 L .19104 .40251 L p F P
0 g
s
.605 .668 .884 r
.65228 .48733 m .66526 .50825 L .63898 .51301 L p F P
0 g
s
.605 .668 .884 r
.63898 .51301 m .6259 .49256 L .65228 .48733 L p F P
0 g
s
.67625 .41271 m
.6961 .38313 L
s
.6961 .38313 m
.68869 .41781 L
s
.28511 .58164 m
.3038 .58809 L
s
.28511 .58164 m
.27321 .55826 L
s
.20005 .48246 m
.21855 .48337 L
s
.20005 .48246 m
.18766 .4606 L
s
.32747 .63369 m
.34653 .63979 L
s
.32747 .63369 m
.31564 .61148 L
s
.634 .71 .901 r
.36186 .41787 m .37702 .43686 L .3523 .44386 L p F P
0 g
s
.634 .71 .901 r
.3523 .44386 m .33701 .42533 L .36186 .41787 L p F P
0 g
s
.624 .695 .895 r
.4673 .43551 m .48163 .45529 L .45636 .46158 L p F P
0 g
s
.624 .695 .895 r
.45636 .46158 m .44191 .44226 L .4673 .43551 L p F P
0 g
s
.074 .42144 m
.07868 .41972 L
s
.07868 .41972 m
.09276 .41454 L
s
.61 .674 .886 r
.61263 .47181 m .6259 .49256 L .59982 .49772 L p F P
0 g
s
.62127 .48532 m
.62506 .47415 L
s
.61921 .49137 m
.61922 .49135 L
s
.61 .674 .886 r
.59982 .49772 m .58645 .47744 L .61263 .47181 L p F P
0 g
s
.645 .725 .907 r
.25619 .40389 m .27226 .4221 L .24803 .42978 L p F P
0 g
s
.645 .725 .907 r
.24803 .42978 m .23181 .41203 L .25619 .40389 L p F P
0 g
s
.56469 .56465 m
.58498 .53564 L
s
.58498 .53564 m
.57476 .5563 L
s
.584 .637 .87 r
.8777 .57064 m .88933 .59294 L .86151 .59563 L p F P
0 g
s
.584 .637 .87 r
.86151 .59563 m .84981 .57381 L .8777 .57064 L p F P
0 g
s
.588 .643 .872 r
.83794 .5517 m .84981 .57381 L .82226 .57693 L p F P
0 g
s
.588 .643 .872 r
.82226 .57693 m .81032 .5553 L .83794 .5517 L p F P
0 g
s
.9094 .64336 m
.92084 .6812 L
s
.615 .68 .888 r
.57287 .45687 m .58645 .47744 L .56056 .48301 L p F P
0 g
s
.615 .68 .888 r
.56056 .48301 m .54688 .4629 L .57287 .45687 L p F P
0 g
s
.592 .648 .874 r
.79822 .53338 m .81032 .5553 L .78303 .55886 L p F P
0 g
s
.592 .648 .874 r
.78303 .55886 m .77085 .53741 L .79822 .53338 L p F P
0 g
s
.2307 .50682 m
.2493 .50947 L
s
.2307 .50682 m
.21855 .48337 L
s
.655 .739 .912 r
.14992 .39353 m .16699 .41095 L .14317 .4193 L p F P
0 g
s
.655 .739 .912 r
.14317 .4193 m .12594 .40235 L .14992 .39353 L p F P
0 g
s
.639 .715 .902 r
.32148 .4065 m .33701 .42533 L .31242 .43271 L p F P
0 g
s
.639 .715 .902 r
.31242 .43271 m .29675 .41434 L .32148 .4065 L p F P
0 g
s
.629 .7 .896 r
.42724 .42264 m .44191 .44226 L .41679 .44894 L p F P
0 g
s
.629 .7 .896 r
.41679 .44894 m .402 .42979 L .42724 .42264 L p F P
0 g
s
.15648 .44147 m
.17517 .43847 L
s
.14366 .42113 m
.15648 .44147 L
s
.27321 .55826 m
.29194 .56364 L
s
.27321 .55826 m
.26128 .53418 L
s
.65626 .44254 m
.67625 .41271 L
s
.67625 .41271 m
.66826 .44592 L
s
.597 .654 .877 r
.7585 .51567 m .77085 .53741 L .74381 .54139 L p F P
0 g
s
.597 .654 .877 r
.74381 .54139 m .73137 .52012 L .7585 .51567 L p F P
0 g
s
.12489 .42611 m
.14366 .42113 L
s
.11197 .40802 m
.12489 .42611 L
s
.11167 .40759 m
.11197 .40802 L
s
.35836 .66035 m
.37785 .66371 L
s
.35836 .66035 m
.34653 .63979 L
s
.42144 .69211 m
.44162 .68437 L
s
.42144 .69211 m
.40959 .67977 L
s
.31564 .61148 m
.33468 .61755 L
s
.31564 .61148 m
.3038 .58809 L
s
.18766 .4606 m
.20634 .45956 L
s
.17517 .43847 m
.18766 .4606 L
s
.601 .659 .879 r
.71875 .49856 m .73137 .52012 L .70456 .52452 L p F P
0 g
s
.601 .659 .879 r
.70456 .52452 m .69185 .50343 L .71875 .49856 L p F P
0 g
s
.65 .73 .908 r
.21533 .39399 m .23181 .41203 L .20768 .42009 L p F P
0 g
s
.65 .73 .908 r
.20768 .42009 m .19104 .40251 L .21533 .39399 L p F P
0 g
s
.619 .685 .89 r
.53299 .44249 m .54688 .4629 L .52117 .46887 L p F P
0 g
s
.619 .685 .89 r
.52117 .46887 m .50717 .44892 L .53299 .44249 L p F P
0 g
s
.54425 .59181 m
.56469 .56465 L
s
.56469 .56465 m
.55404 .58127 L
s
.09276 .41454 m
.1022 .41108 L
s
.1022 .41108 m
.11167 .40759 L
s
.38971 .68102 m
.40959 .67977 L
s
.38971 .68102 m
.37785 .66371 L
s
.605 .665 .881 r
.67896 .48204 m .69185 .50343 L .66526 .50825 L p F P
0 g
s
.605 .665 .881 r
.66526 .50825 m .65228 .48733 L .67896 .48204 L p F P
0 g
s
.634 .706 .898 r
.38697 .41034 m .402 .42979 L .37702 .43686 L p F P
0 g
s
.634 .706 .898 r
.37702 .43686 m .36186 .41787 L .38697 .41034 L p F P
0 g
s
.644 .721 .904 r
.28082 .39567 m .29675 .41434 L .27226 .4221 L p F P
0 g
s
.644 .721 .904 r
.27226 .4221 m .25619 .40389 L .28082 .39567 L p F P
0 g
s
.624 .691 .892 r
.49296 .42868 m .50717 .44892 L .48163 .45529 L p F P
0 g
s
.624 .691 .892 r
.48163 .45529 m .4673 .43551 L .49296 .42868 L p F P
0 g
s
.21855 .48337 m
.23729 .4842 L
s
.21855 .48337 m
.20634 .45956 L
s
.26128 .53418 m
.28006 .53822 L
s
.26128 .53418 m
.2493 .50947 L
s
.61 .67 .883 r
.63911 .46611 m .65228 .48733 L .6259 .49256 L p F P
0 g
s
.61 .67 .883 r
.6259 .49256 m .61263 .47181 L .63911 .46611 L p F P
0 g
s
.63785 .46638 m
.64483 .44273 L
s
.61582 .50138 m
.61921 .49139 L
s
.61921 .49139 m
.61921 .49137 L
s
.63967 .46701 m
.65626 .44254 L
s
.44162 .68437 m
.46201 .67278 L
s
.44162 .68437 m
.42978 .67524 L
s
.52372 .61662 m
.54425 .59181 L
s
.54425 .59181 m
.53324 .60406 L
s
.3038 .58809 m
.32283 .59373 L
s
.3038 .58809 m
.29194 .56364 L
s
.655 .735 .909 r
.17412 .38463 m .19104 .40251 L .16699 .41095 L p F P
0 g
s
.655 .735 .909 r
.16699 .41095 m .14992 .39353 L .17412 .38463 L p F P
0 g
s
.34653 .63979 m
.36597 .64409 L
s
.34653 .63979 m
.33468 .61755 L
s
.14366 .42113 m
.16259 .4161 L
s
.13083 .40077 m
.14366 .42113 L
s
.13072 .40059 m
.13083 .40077 L
s
.615 .676 .885 r
.59916 .45076 m .61263 .47181 L .58645 .47744 L p F P
0 g
s
.615 .676 .885 r
.58645 .47744 m .57287 .45687 L .59916 .45076 L p F P
0 g
s
.17517 .43847 m
.19406 .43543 L
s
.16259 .4161 m
.17517 .43847 L
s
.589 .64 .869 r
.86591 .54806 m .8777 .57064 L .84981 .57381 L p F P
0 g
s
.589 .64 .869 r
.84981 .57381 m .83794 .5517 L .86591 .54806 L p F P
0 g
s
.639 .711 .899 r
.34646 .39858 m .36186 .41787 L .33701 .42533 L p F P
0 g
s
.639 .711 .899 r
.33701 .42533 m .32148 .4065 L .34646 .39858 L p F P
0 g
s
.76925 .30681 m
.78922 .28086 L
s
.78445 .32014 m
.78922 .28086 L
s
.629 .696 .893 r
.45275 .41542 m .4673 .43551 L .44191 .44226 L p F P
0 g
s
.629 .696 .893 r
.44191 .44226 m .42724 .42264 L .45275 .41542 L p F P
0 g
s
.11167 .40759 m
.12594 .40235 L
s
.12594 .40235 m
.13072 .40059 L
s
.593 .645 .871 r
.82592 .5293 m .83794 .5517 L .81032 .5553 L p F P
0 g
s
.593 .645 .871 r
.81032 .5553 m .79822 .53338 L .82592 .5293 L p F P
0 g
s
.46201 .67278 m
.48254 .65746 L
s
.46201 .67278 m
.45021 .66737 L
s
.50313 .63863 m
.52372 .61662 L
s
.52372 .61662 m
.51241 .62432 L
s
.65 .726 .905 r
.23986 .38539 m .25619 .40389 L .23181 .41203 L p F P
0 g
s
.65 .726 .905 r
.23181 .41203 m .21533 .39399 L .23986 .38539 L p F P
0 g
s
.597 .65 .874 r
.78595 .51116 m .79822 .53338 L .77085 .53741 L p F P
0 g
s
.597 .65 .874 r
.77085 .53741 m .7585 .51567 L .78595 .51116 L p F P
0 g
s
.2493 .50947 m
.26817 .51194 L
s
.2493 .50947 m
.23729 .4842 L
s
.20634 .45956 m
.22523 .45847 L
s
.20634 .45956 m
.19406 .43543 L
s
.619 .682 .887 r
.5591 .43598 m .57287 .45687 L .54688 .4629 L p F P
0 g
s
.619 .682 .887 r
.54688 .4629 m .53299 .44249 L .5591 .43598 L p F P
0 g
s
.48254 .65746 m
.50313 .63863 L
s
.48254 .65746 m
.47084 .65618 L
s
.50313 .63863 m
.49159 .64178 L
s
.37785 .66371 m
.3977 .66453 L
s
.37785 .66371 m
.36597 .64409 L
s
.40959 .67977 m
.42978 .67524 L
s
.40959 .67977 m
.3977 .66453 L
s
.601 .656 .876 r
.74597 .49363 m .7585 .51567 L .73137 .52012 L p F P
0 g
s
.601 .656 .876 r
.73137 .52012 m .71875 .49856 L .74597 .49363 L p F P
0 g
s
.61582 .50138 m
.62887 .48264 L
s
.62887 .48264 m
.62895 .48252 L
s
.62697 .50038 m
.63432 .47779 L
s
.63432 .47779 m
.63435 .47768 L
s
.29194 .56364 m
.31098 .56846 L
s
.29194 .56364 m
.28006 .53822 L
s
.74924 .33374 m
.76925 .30681 L
s
.76925 .30681 m
.76394 .34665 L
s
.634 .702 .895 r
.41234 .40272 m .42724 .42264 L .402 .42979 L p F P
0 g
s
.634 .702 .895 r
.402 .42979 m .38697 .41034 L .41234 .40272 L p F P
0 g
s
.644 .717 .901 r
.30569 .38737 m .32148 .4065 L .29675 .41434 L p F P
0 g
s
.644 .717 .901 r
.29675 .41434 m .28082 .39567 L .30569 .38737 L p F P
0 g
s
.606 .661 .878 r
.70596 .47669 m .71875 .49856 L .69185 .50343 L p F P
0 g
s
.606 .661 .878 r
.69185 .50343 m .67896 .48204 L .70596 .47669 L p F P
0 g
s
.33468 .61755 m
.35408 .62228 L
s
.33468 .61755 m
.32283 .59373 L
s
.624 .687 .889 r
.5189 .42177 m .53299 .44249 L .50717 .44892 L p F P
0 g
s
.624 .687 .889 r
.50717 .44892 m .49296 .42868 L .5189 .42177 L p F P
0 g
s
.16259 .4161 m
.1817 .41103 L
s
.14992 .39353 m
.16259 .4161 L
s
.13072 .40059 m
.14992 .39353 L
s
.61 .667 .88 r
.6659 .46035 m .67896 .48204 L .65228 .48733 L p F P
0 g
s
.61 .667 .88 r
.65228 .48733 m .63911 .46611 L .6659 .46035 L p F P
0 g
s
.23729 .4842 m
.25627 .48494 L
s
.23729 .4842 m
.22523 .45847 L
s
.655 .732 .906 r
.19857 .37565 m .21533 .39399 L .19104 .40251 L p F P
0 g
s
.655 .732 .906 r
.19104 .40251 m .17412 .38463 L .19857 .37565 L p F P
0 g
s
.19406 .43543 m
.21313 .43234 L
s
.1817 .41103 m
.19406 .43543 L
s
.72916 .36141 m
.74924 .33374 L
s
.74924 .33374 m
.74334 .37336 L
s
.59536 .52954 m
.61582 .50138 L
s
.61582 .50138 m
.60612 .52608 L
s
.639 .708 .896 r
.3717 .39058 m .38697 .41034 L .36186 .41787 L p F P
0 g
s
.639 .708 .896 r
.36186 .41787 m .34646 .39858 L .3717 .39058 L p F P
0 g
s
.28006 .53822 m
.29914 .54191 L
s
.28006 .53822 m
.26817 .51194 L
s
.615 .673 .882 r
.62575 .44459 m .63911 .46611 L .61263 .47181 L p F P
0 g
s
.615 .673 .882 r
.61263 .47181 m .59916 .45076 L .62575 .44459 L p F P
0 g
s
.629 .693 .89 r
.47854 .40812 m .49296 .42868 L .4673 .43551 L p F P
0 g
s
.629 .693 .89 r
.4673 .43551 m .45275 .41542 L .47854 .40812 L p F P
0 g
s
.649 .722 .902 r
.26463 .3767 m .28082 .39567 L .25619 .40389 L p F P
0 g
s
.649 .722 .902 r
.25619 .40389 m .23986 .38539 L .26463 .3767 L p F P
0 g
s
.42978 .67524 m
.45021 .66737 L
s
.42978 .67524 m
.41786 .66266 L
s
.36597 .64409 m
.38577 .64642 L
s
.36597 .64409 m
.35408 .62228 L
s
.593 .642 .868 r
.85397 .52517 m .86591 .54806 L .83794 .5517 L p F P
0 g
s
.593 .642 .868 r
.83794 .5517 m .82592 .5293 L .85397 .52517 L p F P
0 g
s
.32283 .59373 m
.34221 .59842 L
s
.32283 .59373 m
.31098 .56846 L
s
.597 .647 .871 r
.81374 .5066 m .82592 .5293 L .79822 .53338 L p F P
0 g
s
.597 .647 .871 r
.79822 .53338 m .78595 .51116 L .81374 .5066 L p F P
0 g
s
.619 .678 .884 r
.5855 .42941 m .59916 .45076 L .57287 .45687 L p F P
0 g
s
.619 .678 .884 r
.57287 .45687 m .5591 .43598 L .5855 .42941 L p F P
0 g
s
.22523 .45847 m
.24435 .45732 L
s
.22523 .45847 m
.21313 .43234 L
s
.3977 .66453 m
.41786 .66266 L
s
.3977 .66453 m
.38577 .64642 L
s
.601 .653 .873 r
.77352 .48864 m .78595 .51116 L .7585 .51567 L p F P
0 g
s
.601 .653 .873 r
.7585 .51567 m .74597 .49363 L .77352 .48864 L p F P
0 g
s
.634 .698 .892 r
.43798 .39503 m .45275 .41542 L .42724 .42264 L p F P
0 g
s
.634 .698 .892 r
.42724 .42264 m .41234 .40272 L .43798 .39503 L p F P
0 g
s
.14992 .39353 m
.16926 .38642 L
s
.70898 .38953 m
.72916 .36141 L
s
.72916 .36141 m
.72263 .40004 L
s
.26817 .51194 m
.28732 .51422 L
s
.26817 .51194 m
.25627 .48494 L
s
.57476 .5563 m
.59536 .52954 L
s
.59536 .52954 m
.58516 .55032 L
s
.644 .713 .898 r
.33081 .37898 m .34646 .39858 L .32148 .4065 L p F P
0 g
s
.644 .713 .898 r
.32148 .4065 m .30569 .38737 L .33081 .37898 L p F P
0 g
s
.1817 .41103 m
.20098 .40591 L
s
.16926 .38642 m
.1817 .41103 L
s
.606 .658 .875 r
.73328 .47128 m .74597 .49363 L .71875 .49856 L p F P
0 g
s
.606 .658 .875 r
.71875 .49856 m .70596 .47669 L .73328 .47128 L p F P
0 g
s
.624 .684 .886 r
.54513 .41479 m .5591 .43598 L .53299 .44249 L p F P
0 g
s
.624 .684 .886 r
.53299 .44249 m .5189 .42177 L .54513 .41479 L p F P
0 g
s
.654 .728 .903 r
.22325 .36657 m .23986 .38539 L .21533 .39399 L p F P
0 g
s
.654 .728 .903 r
.21533 .39399 m .19857 .37565 L .22325 .36657 L p F P
0 g
s
.45021 .66737 m
.47084 .65618 L
s
.45021 .66737 m
.43831 .65801 L
s
.31098 .56846 m
.33035 .57266 L
s
.31098 .56846 m
.29914 .54191 L
s
.61 .664 .877 r
.69299 .45452 m .70596 .47669 L .67896 .48204 L p F P
0 g
s
.61 .664 .877 r
.67896 .48204 m .6659 .46035 L .69299 .45452 L p F P
0 g
s
.21313 .43234 m
.2324 .42922 L
s
.21313 .43234 m
.20098 .40591 L
s
.55404 .58127 m
.57476 .5563 L
s
.57476 .5563 m
.56412 .57281 L
s
.639 .704 .893 r
.39721 .38249 m .41234 .40272 L .38697 .41034 L p F P
0 g
s
.639 .704 .893 r
.38697 .41034 m .3717 .39058 L .39721 .38249 L p F P
0 g
s
.35408 .62228 m
.37384 .62554 L
s
.35408 .62228 m
.34221 .59842 L
s
.25627 .48494 m
.2755 .48556 L
s
.25627 .48494 m
.24435 .45732 L
s
.68869 .41781 m
.70898 .38953 L
s
.649 .718 .899 r
.28965 .36792 m .30569 .38737 L .28082 .39567 L p F P
0 g
s
.649 .718 .899 r
.28082 .39567 m .26463 .3767 L .28965 .36792 L p F P
0 g
s
.629 .689 .887 r
.5046 .40075 m .5189 .42177 L .49296 .42868 L p F P
0 g
s
.629 .689 .887 r
.49296 .42868 m .47854 .40812 L .5046 .40075 L p F P
0 g
s
.615 .669 .879 r
.65264 .43835 m .6659 .46035 L .63911 .46611 L p F P
0 g
s
.65592 .44379 m
.65626 .44254 L
s
.615 .669 .879 r
.63911 .46611 m .62575 .44459 L .65264 .43835 L p F P
0 g
s
.65019 .46448 m
.6502 .46448 L
s
.65017 .46456 m
.65019 .46448 L
s
.64768 .47356 m
.65017 .46456 L
s
.47084 .65618 m
.49159 .64178 L
s
.47084 .65618 m
.45898 .65053 L
s
.16926 .38642 m
.17412 .38463 L
s
.17412 .38463 m
.18876 .37925 L
s
.53324 .60406 m
.55404 .58127 L
s
.55404 .58127 m
.54302 .59327 L
s
.29914 .54191 m
.31853 .54521 L
s
.29914 .54191 m
.28732 .51422 L
s
.619 .675 .881 r
.6122 .42276 m .62575 .44459 L .59916 .45076 L p F P
0 g
s
.619 .675 .881 r
.59916 .45076 m .5855 .42941 L .6122 .42276 L p F P
0 g
s
.38577 .64642 m
.4059 .64663 L
s
.38577 .64642 m
.37384 .62554 L
s
.41786 .66266 m
.43831 .65801 L
s
.41786 .66266 m
.4059 .64663 L
s
.20098 .40591 m
.22043 .40075 L
s
.18876 .37925 m
.20098 .40591 L
s
.24435 .45732 m
.26369 .45611 L
s
.24435 .45732 m
.2324 .42922 L
s
.644 .709 .895 r
.3562 .3705 m .3717 .39058 L .34646 .39858 L p F P
0 g
s
.644 .709 .895 r
.34646 .39858 m .33081 .37898 L .3562 .3705 L p F P
0 g
s
.49159 .64178 m
.51241 .62432 L
s
.49159 .64178 m
.47985 .64023 L
s
.634 .695 .889 r
.46389 .38726 m .47854 .40812 L .45275 .41542 L p F P
0 g
s
.634 .695 .889 r
.45275 .41542 m .43798 .39503 L .46389 .38726 L p F P
0 g
s
.597 .644 .867 r
.84187 .50198 m .85397 .52517 L .82592 .5293 L p F P
0 g
s
.597 .644 .867 r
.82592 .5293 m .81374 .5066 L .84187 .50198 L p F P
0 g
s
.51241 .62432 m
.53324 .60406 L
s
.53324 .60406 m
.52191 .61146 L
s
.51241 .62432 m
.50084 .62717 L
s
.34221 .59842 m
.36192 .60206 L
s
.34221 .59842 m
.33035 .57266 L
s
.66826 .44592 m
.68869 .41781 L
s
.602 .649 .87 r
.80139 .48359 m .81374 .5066 L .78595 .51116 L p F P
0 g
s
.602 .649 .87 r
.78595 .51116 m .77352 .48864 L .80139 .48359 L p F P
0 g
s
.654 .724 .9 r
.24817 .35741 m .26463 .3767 L .23986 .38539 L p F P
0 g
s
.654 .724 .9 r
.23986 .38539 m .22325 .36657 L .24817 .35741 L p F P
0 g
s
.624 .68 .883 r
.57164 .40774 m .5855 .42941 L .5591 .43598 L p F P
0 g
s
.624 .68 .883 r
.5591 .43598 m .54513 .41479 L .57164 .40774 L p F P
0 g
s
.28732 .51422 m
.30673 .51627 L
s
.28732 .51422 m
.2755 .48556 L
s
.606 .655 .872 r
.76091 .4658 m .77352 .48864 L .74597 .49363 L p F P
0 g
s
.606 .655 .872 r
.74597 .49363 m .73328 .47128 L .76091 .4658 L p F P
0 g
s
.2324 .42922 m
.25188 .42604 L
s
.2324 .42922 m
.22043 .40075 L
s
.639 .7 .891 r
.42298 .37432 m .43798 .39503 L .41234 .40272 L p F P
0 g
s
.639 .7 .891 r
.41234 .40272 m .39721 .38249 L .42298 .37432 L p F P
0 g
s
.18876 .37925 m
.19857 .37565 L
s
.19857 .37565 m
.20841 .37203 L
s
.61 .66 .874 r
.7204 .44862 m .73328 .47128 L .70596 .47669 L p F P
0 g
s
.61 .66 .874 r
.70596 .47669 m .69299 .45452 L .7204 .44862 L p F P
0 g
s
.649 .715 .896 r
.31492 .35906 m .33081 .37898 L .30569 .38737 L p F P
0 g
s
.649 .715 .896 r
.30569 .38737 m .28965 .36792 L .31492 .35906 L p F P
0 g
s
.629 .686 .884 r
.53094 .39329 m .54513 .41479 L .5189 .42177 L p F P
0 g
s
.629 .686 .884 r
.5189 .42177 m .5046 .40075 L .53094 .39329 L p F P
0 g
s
.2755 .48556 m
.29498 .48606 L
s
.2755 .48556 m
.26369 .45611 L
s
.33035 .57266 m
.35004 .57615 L
s
.33035 .57266 m
.31853 .54521 L
s
.615 .666 .876 r
.67984 .43204 m .69299 .45452 L .6659 .46035 L p F P
0 g
s
.615 .666 .876 r
.6659 .46035 m .65264 .43835 L .67984 .43204 L p F P
0 g
s
.65977 .47752 m
.66672 .45164 L
s
.66672 .45164 m
.66674 .45156 L
s
.64768 .47356 m
.66026 .45666 L
s
.66026 .45666 m
.6603 .45662 L
s
.37384 .62554 m
.39392 .62721 L
s
.37384 .62554 m
.36192 .60206 L
s
.43831 .65801 m
.45898 .65053 L
s
.43831 .65801 m
.42633 .6446 L
s
.22043 .40075 m
.24006 .39553 L
s
.20852 .37228 m
.22043 .40075 L
s
.20841 .37203 m
.20852 .37228 L
s
.643 .706 .892 r
.38184 .36194 m .39721 .38249 L .3717 .39058 L p F P
0 g
s
.643 .706 .892 r
.3717 .39058 m .3562 .3705 L .38184 .36194 L p F P
0 g
s
.619 .671 .878 r
.6392 .41603 m .65264 .43835 L .62575 .44459 L p F P
0 g
s
.619 .671 .878 r
.62575 .44459 m .6122 .42276 L .6392 .41603 L p F P
0 g
s
.633 .691 .886 r
.49008 .3794 m .5046 .40075 L .47854 .40812 L p F P
0 g
s
.633 .691 .886 r
.47854 .40812 m .46389 .38726 L .49008 .3794 L p F P
0 g
s
.26369 .45611 m
.28325 .45483 L
s
.26369 .45611 m
.25188 .42604 L
s
.4059 .64663 m
.42633 .6446 L
s
.4059 .64663 m
.39392 .62721 L
s
.654 .72 .897 r
.27334 .34816 m .28965 .36792 L .26463 .3767 L p F P
0 g
s
.654 .72 .897 r
.26463 .3767 m .24817 .35741 L .27334 .34816 L p F P
0 g
s
.31853 .54521 m
.33821 .54806 L
s
.31853 .54521 m
.30673 .51627 L
s
.62697 .50038 m
.64768 .47356 L
s
.64768 .47356 m
.63858 .50167 L
s
.20841 .37203 m
.22325 .36657 L
s
.22325 .36657 m
.22821 .36475 L
s
.602 .646 .867 r
.82961 .47847 m .84187 .50198 L .81374 .5066 L p F P
0 g
s
.602 .646 .867 r
.81374 .5066 m .80139 .48359 L .82961 .47847 L p F P
0 g
s
.624 .677 .88 r
.59845 .4006 m .6122 .42276 L .5855 .42941 L p F P
0 g
s
.624 .677 .88 r
.5855 .42941 m .57164 .40774 L .59845 .4006 L p F P
0 g
s
.25188 .42604 m
.27155 .42282 L
s
.25188 .42604 m
.24006 .39553 L
s
.45898 .65053 m
.47985 .64023 L
s
.45898 .65053 m
.44703 .64027 L
s
.606 .652 .869 r
.78888 .46026 m .80139 .48359 L .77352 .48864 L p F P
0 g
s
.606 .652 .869 r
.77352 .48864 m .76091 .4658 L .78888 .46026 L p F P
0 g
s
.36192 .60206 m
.38196 .60455 L
s
.36192 .60206 m
.35004 .57615 L
s
.638 .697 .888 r
.44902 .36607 m .46389 .38726 L .43798 .39503 L p F P
0 g
s
.638 .697 .888 r
.43798 .39503 m .42298 .37432 L .44902 .36607 L p F P
0 g
s
.648 .711 .893 r
.34044 .3501 m .3562 .3705 L .33081 .37898 L p F P
0 g
s
.648 .711 .893 r
.33081 .37898 m .31492 .35906 L .34044 .3501 L p F P
0 g
s
.30673 .51627 m
.32643 .51805 L
s
.30673 .51627 m
.29498 .48606 L
s
.61 .657 .871 r
.74814 .44266 m .76091 .4658 L .73328 .47128 L p F P
0 g
s
.61 .657 .871 r
.73328 .47128 m .7204 .44862 L .74814 .44266 L p F P
0 g
s
.60612 .52608 m
.62697 .50038 L
s
.62697 .50038 m
.61729 .52456 L
s
.24006 .39553 m
.25986 .39026 L
s
.22826 .36487 m
.24006 .39553 L
s
.22821 .36475 m
.22826 .36487 L
s
.629 .682 .881 r
.55758 .38575 m .57164 .40774 L .54513 .41479 L p F P
0 g
s
.629 .682 .881 r
.54513 .41479 m .53094 .39329 L .55758 .38575 L p F P
0 g
s
.615 .662 .873 r
.70735 .42565 m .7204 .44862 L .69299 .45452 L p F P
0 g
s
.615 .662 .873 r
.69299 .45452 m .67984 .43204 L .70735 .42565 L p F P
0 g
s
.68577 .43066 m
.68869 .41781 L
s
.68084 .45237 m
.68389 .43896 L
s
.29498 .48606 m
.31471 .48642 L
s
.29498 .48606 m
.28325 .45483 L
s
.47985 .64023 m
.50084 .62717 L
s
.47985 .64023 m
.46795 .63357 L
s
.39392 .62721 m
.41432 .62716 L
s
.39392 .62721 m
.38196 .60455 L
s
.643 .702 .889 r
.40774 .35329 m .42298 .37432 L .39721 .38249 L p F P
0 g
s
.643 .702 .889 r
.39721 .38249 m .38184 .36194 L .40774 .35329 L p F P
0 g
s
.22821 .36475 m
.24817 .35741 L
s
.35004 .57615 m
.37004 .57885 L
s
.35004 .57615 m
.33821 .54806 L
s
.42633 .6446 m
.44703 .64027 L
s
.42633 .6446 m
.41432 .62716 L
s
.58516 .55032 m
.60612 .52608 L
s
.60612 .52608 m
.59593 .54599 L
s
.633 .687 .883 r
.51655 .37146 m .53094 .39329 L .5046 .40075 L p F P
0 g
s
.633 .687 .883 r
.5046 .40075 m .49008 .3794 L .51655 .37146 L p F P
0 g
s
.619 .668 .875 r
.6665 .40923 m .67984 .43204 L .65264 .43835 L p F P
0 g
s
.619 .668 .875 r
.65264 .43835 m .6392 .41603 L .6665 .40923 L p F P
0 g
s
.653 .716 .894 r
.29876 .33882 m .31492 .35906 L .28965 .36792 L p F P
0 g
s
.653 .716 .894 r
.28965 .36792 m .27334 .34816 L .29876 .33882 L p F P
0 g
s
.28325 .45483 m
.30304 .45347 L
s
.28325 .45483 m
.27155 .42282 L
s
.76394 .34665 m
.78445 .32014 L
s
.77966 .36431 m
.78445 .32014 L
s
.50084 .62717 m
.52191 .61146 L
s
.50084 .62717 m
.48906 .62451 L
s
.56412 .57281 m
.58516 .55032 L
s
.58516 .55032 m
.57451 .56574 L
s
.27155 .42282 m
.29143 .41954 L
s
.27155 .42282 m
.25986 .39026 L
s
.624 .673 .877 r
.62556 .39339 m .6392 .41603 L .6122 .42276 L p F P
0 g
s
.624 .673 .877 r
.6122 .42276 m .59845 .4006 L .62556 .39339 L p F P
0 g
s
.33821 .54806 m
.35819 .55041 L
s
.33821 .54806 m
.32643 .51805 L
s
.648 .707 .89 r
.36622 .34106 m .38184 .36194 L .3562 .3705 L p F P
0 g
s
.648 .707 .89 r
.3562 .3705 m .34044 .3501 L .36622 .34106 L p F P
0 g
s
.638 .693 .885 r
.47534 .35773 m .49008 .3794 L .46389 .38726 L p F P
0 g
s
.638 .693 .885 r
.46389 .38726 m .44902 .36607 L .47534 .35773 L p F P
0 g
s
.52191 .61146 m
.54302 .59327 L
s
.52191 .61146 m
.51031 .61312 L
s
.54302 .59327 m
.56412 .57281 L
s
.56412 .57281 m
.55308 .58361 L
s
.25986 .39026 m
.27985 .38495 L
s
.24817 .35741 m
.25986 .39026 L
s
.54302 .59327 m
.53167 .59945 L
s
.606 .648 .866 r
.81718 .45466 m .82961 .47847 L .80139 .48359 L p F P
0 g
s
.606 .648 .866 r
.80139 .48359 m .78888 .46026 L .81718 .45466 L p F P
0 g
s
.74334 .37336 m
.76394 .34665 L
s
.38196 .60455 m
.40232 .60578 L
s
.38196 .60455 m
.37004 .57885 L
s
.24817 .35741 m
.26829 .35002 L
s
.628 .679 .878 r
.5845 .37813 m .59845 .4006 L .57164 .40774 L p F P
0 g
s
.628 .679 .878 r
.57164 .40774 m .55758 .38575 L .5845 .37813 L p F P
0 g
s
.61 .654 .868 r
.77619 .43662 m .78888 .46026 L .76091 .4658 L p F P
0 g
s
.61 .654 .868 r
.76091 .4658 m .74814 .44266 L .77619 .43662 L p F P
0 g
s
.32643 .51805 m
.3464 .51954 L
s
.32643 .51805 m
.31471 .48642 L
s
.44703 .64027 m
.46795 .63357 L
s
.44703 .64027 m
.43501 .62531 L
s
.615 .659 .87 r
.73518 .41919 m .74814 .44266 L .7204 .44862 L p F P
0 g
s
.615 .659 .87 r
.7204 .44862 m .70735 .42565 L .73518 .41919 L p F P
0 g
s
.643 .698 .886 r
.43392 .34455 m .44902 .36607 L .42298 .37432 L p F P
0 g
s
.643 .698 .886 r
.42298 .37432 m .40774 .35329 L .43392 .34455 L p F P
0 g
s
.31471 .48642 m
.3347 .48661 L
s
.31471 .48642 m
.30304 .45347 L
s
.653 .713 .892 r
.32443 .32938 m .34044 .3501 L .31492 .35906 L p F P
0 g
s
.653 .713 .892 r
.31492 .35906 m .29876 .33882 L .32443 .32938 L p F P
0 g
s
.41432 .62716 m
.43501 .62531 L
s
.41432 .62716 m
.40232 .60578 L
s
.633 .684 .88 r
.5433 .36343 m .55758 .38575 L .53094 .39329 L p F P
0 g
s
.633 .684 .88 r
.53094 .39329 m .51655 .37146 L .5433 .36343 L p F P
0 g
s
.72263 .40004 m
.74334 .37336 L
s
.619 .664 .872 r
.69411 .40235 m .70735 .42565 L .67984 .43204 L p F P
0 g
s
.70333 .41858 m
.70898 .38953 L
s
.619 .664 .872 r
.67984 .43204 m .6665 .40923 L .69411 .40235 L p F P
0 g
s
.30304 .45347 m
.32307 .45203 L
s
.30304 .45347 m
.29143 .41954 L
s
.37004 .57885 m
.39036 .5807 L
s
.37004 .57885 m
.35819 .55041 L
s
.29143 .41954 m
.31152 .41621 L
s
.29143 .41954 m
.27985 .38495 L
s
.27985 .38495 m
.30002 .37958 L
s
.26829 .35002 m
.27985 .38495 L
s
.624 .67 .874 r
.65297 .3861 m .6665 .40923 L .6392 .41603 L p F P
0 g
s
.624 .67 .874 r
.6392 .41603 m .62556 .39339 L .65297 .3861 L p F P
0 g
s
.648 .704 .888 r
.39227 .33192 m .40774 .35329 L .38184 .36194 L p F P
0 g
s
.648 .704 .888 r
.38184 .36194 m .36622 .34106 L .39227 .33192 L p F P
0 g
s
.26829 .35002 m
.27334 .34816 L
s
.27334 .34816 m
.28856 .34256 L
s
.638 .689 .882 r
.50193 .3493 m .51655 .37146 L .49008 .3794 L p F P
0 g
s
.638 .689 .882 r
.49008 .3794 m .47534 .35773 L .50193 .3493 L p F P
0 g
s
.70529 .42203 m
.72263 .40004 L
s
.46795 .63357 m
.48906 .62451 L
s
.46795 .63357 m
.45595 .62158 L
s
.35819 .55041 m
.37846 .55221 L
s
.35819 .55041 m
.3464 .51954 L
s
.628 .675 .876 r
.61172 .37042 m .62556 .39339 L .59845 .4006 L p F P
0 g
s
.628 .675 .876 r
.59845 .4006 m .5845 .37813 L .61172 .37042 L p F P
0 g
s
.61 .65 .865 r
.80458 .43051 m .81718 .45466 L .78888 .46026 L p F P
0 g
s
.61 .65 .865 r
.78888 .46026 m .77619 .43662 L .80458 .43051 L p F P
0 g
s
.40232 .60578 m
.42298 .60569 L
s
.40232 .60578 m
.39036 .5807 L
s
.642 .695 .883 r
.46037 .33572 m .47534 .35773 L .44902 .36607 L p F P
0 g
s
.642 .695 .883 r
.44902 .36607 m .43392 .34455 L .46037 .33572 L p F P
0 g
s
.653 .709 .889 r
.35036 .31985 m .36622 .34106 L .34044 .3501 L p F P
0 g
s
.653 .709 .889 r
.34044 .3501 m .32443 .32938 L .35036 .31985 L p F P
0 g
s
.68084 .45237 m
.70133 .42705 L
s
.69403 .46084 m
.70173 .42677 L
s
.70173 .42677 m
.70173 .42677 L
s
.3464 .51954 m
.36665 .5207 L
s
.3464 .51954 m
.3347 .48661 L
s
.615 .656 .867 r
.76333 .41266 m .77619 .43662 L .74814 .44266 L p F P
0 g
s
.615 .656 .867 r
.74814 .44266 m .73518 .41919 L .76333 .41266 L p F P
0 g
s
.43501 .62531 m
.45595 .62158 L
s
.43501 .62531 m
.42298 .60569 L
s
.633 .68 .877 r
.57034 .35532 m .5845 .37813 L .55758 .38575 L p F P
0 g
s
.633 .68 .877 r
.55758 .38575 m .5433 .36343 L .57034 .35532 L p F P
0 g
s
.48906 .62451 m
.51031 .61312 L
s
.48906 .62451 m
.47713 .61594 L
s
.3347 .48661 m
.35494 .48663 L
s
.3347 .48661 m
.32307 .45203 L
s
.28856 .34256 m
.29876 .33882 L
s
.29876 .33882 m
.309 .33505 L
s
.28856 .34256 m
.30002 .37958 L
s
.619 .661 .869 r
.72204 .39539 m .73518 .41919 L .70735 .42565 L p F P
0 g
s
.619 .661 .869 r
.70735 .42565 m .69411 .40235 L .72204 .39539 L p F P
0 g
s
.71559 .43769 m
.7199 .41464 L
s
.7199 .41464 m
.71993 .41445 L
s
.30002 .37958 m
.32038 .37416 L
s
.31152 .41621 m
.30002 .37958 L
s
.32307 .45203 m
.34333 .45049 L
s
.32307 .45203 m
.31152 .41621 L
s
.31152 .41621 m
.33182 .41282 L
s
.65977 .47752 m
.68084 .45237 L
s
.68084 .45237 m
.67238 .48303 L
s
.647 .7 .885 r
.41858 .32269 m .43392 .34455 L .40774 .35329 L p F P
0 g
s
.647 .7 .885 r
.40774 .35329 m .39227 .33192 L .41858 .32269 L p F P
0 g
s
.637 .686 .879 r
.52881 .34078 m .5433 .36343 L .51655 .37146 L p F P
0 g
s
.637 .686 .879 r
.51655 .37146 m .50193 .3493 L .52881 .34078 L p F P
0 g
s
.623 .666 .871 r
.68069 .37872 m .69411 .40235 L .6665 .40923 L p F P
0 g
s
.623 .666 .871 r
.6665 .40923 m .65297 .3861 L .68069 .37872 L p F P
0 g
s
.39036 .5807 m
.41097 .58162 L
s
.39036 .5807 m
.37846 .55221 L
s
.51031 .61312 m
.53167 .59945 L
s
.51031 .61312 m
.4985 .60835 L
s
.63858 .50167 m
.65977 .47752 L
s
.65977 .47752 m
.65065 .5041 L
s
.628 .672 .873 r
.63924 .36263 m .65297 .3861 L .62556 .39339 L p F P
0 g
s
.628 .672 .873 r
.62556 .39339 m .61172 .37042 L .63924 .36263 L p F P
0 g
s
.642 .691 .88 r
.48709 .3268 m .50193 .3493 L .47534 .35773 L p F P
0 g
s
.642 .691 .88 r
.47534 .35773 m .46037 .33572 L .48709 .3268 L p F P
0 g
s
.652 .705 .886 r
.37655 .31022 m .39227 .33192 L .36622 .34106 L p F P
0 g
s
.652 .705 .886 r
.36622 .34106 m .35036 .31985 L .37655 .31022 L p F P
0 g
s
.309 .33505 m
.32443 .32938 L
s
.32443 .32938 m
.32959 .32748 L
s
.309 .33505 m
.32038 .37416 L
s
.37846 .55221 m
.39903 .55341 L
s
.37846 .55221 m
.36665 .5207 L
s
.45595 .62158 m
.47713 .61594 L
s
.45595 .62158 m
.44391 .60419 L
s
.53167 .59945 m
.55308 .58361 L
s
.53167 .59945 m
.52003 .59882 L
s
.61729 .52456 m
.63858 .50167 L
s
.63858 .50167 m
.62887 .52388 L
s
.42298 .60569 m
.44391 .60419 L
s
.42298 .60569 m
.41097 .58162 L
s
.32038 .37416 m
.34092 .36869 L
s
.33182 .41282 m
.32038 .37416 L
s
.632 .677 .874 r
.59768 .34711 m .61172 .37042 L .5845 .37813 L p F P
0 g
s
.632 .677 .874 r
.5845 .37813 m .57034 .35532 L .59768 .34711 L p F P
0 g
s
.615 .652 .864 r
.79182 .40604 m .80458 .43051 L .77619 .43662 L p F P
0 g
s
.615 .652 .864 r
.77619 .43662 m .76333 .41266 L .79182 .40604 L p F P
0 g
s
.59593 .54599 m
.61729 .52456 L
s
.61729 .52456 m
.60705 .54223 L
s
.55308 .58361 m
.57451 .56574 L
s
.55308 .58361 m
.54168 .58738 L
s
.36665 .5207 m
.38718 .5215 L
s
.36665 .5207 m
.35494 .48663 L
s
.33182 .41282 m
.35233 .40937 L
s
.34333 .45049 m
.33182 .41282 L
s
.57451 .56574 m
.59593 .54599 L
s
.59593 .54599 m
.58523 .559 L
s
.57451 .56574 m
.56343 .57409 L
s
.619 .658 .866 r
.7503 .38836 m .76333 .41266 L .73518 .41919 L p F P
0 g
s
.619 .658 .866 r
.73518 .41919 m .72204 .39539 L .7503 .38836 L p F P
0 g
s
.73705 .41377 m
.73878 .40268 L
s
.74063 .39076 m
.74334 .37336 L
s
.73878 .40268 m
.73879 .40259 L
s
.35494 .48663 m
.37545 .48645 L
s
.35494 .48663 m
.34333 .45049 L
s
.34333 .45049 m
.36383 .44885 L
s
.647 .696 .882 r
.44516 .31337 m .46037 .33572 L .43392 .34455 L p F P
0 g
s
.647 .696 .882 r
.43392 .34455 m .41858 .32269 L .44516 .31337 L p F P
0 g
s
.637 .682 .876 r
.55597 .33216 m .57034 .35532 L .5433 .36343 L p F P
0 g
s
.637 .682 .876 r
.5433 .36343 m .52881 .34078 L .55597 .33216 L p F P
0 g
s
.623 .663 .868 r
.70872 .37126 m .72204 .39539 L .69411 .40235 L p F P
0 g
s
.623 .663 .868 r
.69411 .40235 m .68069 .37872 L .70872 .37126 L p F P
0 g
s
.41097 .58162 m
.43187 .58154 L
s
.41097 .58162 m
.39903 .55341 L
s
.32959 .32748 m
.35036 .31985 L
s
.32959 .32748 m
.34092 .36869 L
s
.47713 .61594 m
.4985 .60835 L
s
.47713 .61594 m
.4651 .60122 L
s
.628 .668 .87 r
.66707 .35475 m .68069 .37872 L .65297 .3861 L p F P
0 g
s
.628 .668 .87 r
.65297 .3861 m .63924 .36263 L .66707 .35475 L p F P
0 g
s
.652 .702 .883 r
.403 .30049 m .41858 .32269 L .39227 .33192 L p F P
0 g
s
.652 .702 .883 r
.39227 .33192 m .37655 .31022 L .403 .30049 L p F P
0 g
s
.642 .688 .878 r
.5141 .31778 m .52881 .34078 L .50193 .3493 L p F P
0 g
s
.642 .688 .878 r
.50193 .3493 m .48709 .3268 L .5141 .31778 L p F P
0 g
s
.34092 .36869 m
.36166 .36316 L
s
.35233 .40937 m
.34092 .36869 L
s
.44391 .60419 m
.4651 .60122 L
s
.44391 .60419 m
.43187 .58154 L
s
.39903 .55341 m
.41989 .55396 L
s
.39903 .55341 m
.38718 .5215 L
s
.632 .674 .872 r
.62531 .33882 m .63924 .36263 L .61172 .37042 L p F P
0 g
s
.632 .674 .872 r
.61172 .37042 m .59768 .34711 L .62531 .33882 L p F P
0 g
s
.35233 .40937 m
.37306 .40586 L
s
.36383 .44885 m
.35233 .40937 L
s
.646 .693 .879 r
.47202 .30395 m .48709 .3268 L .46037 .33572 L p F P
0 g
s
.646 .693 .879 r
.46037 .33572 m .44516 .31337 L .47202 .30395 L p F P
0 g
s
.38718 .5215 m
.40799 .52192 L
s
.38718 .5215 m
.37545 .48645 L
s
.619 .655 .863 r
.77887 .38124 m .79182 .40604 L .76333 .41266 L p F P
0 g
s
.619 .655 .863 r
.76333 .41266 m .7503 .38836 L .77887 .38124 L p F P
0 g
s
.7588 .38624 m
.76394 .34665 L
s
.36383 .44885 m
.38457 .44711 L
s
.37545 .48645 m
.36383 .44885 L
s
.4985 .60835 m
.52003 .59882 L
s
.4985 .60835 m
.48653 .59675 L
s
.35036 .31985 m
.37129 .31215 L
s
.35036 .31985 m
.36166 .36316 L
s
.37545 .48645 m
.39622 .48606 L
s
.637 .679 .873 r
.58343 .32346 m .59768 .34711 L .57034 .35532 L p F P
0 g
s
.637 .679 .873 r
.57034 .35532 m .55597 .33216 L .58343 .32346 L p F P
0 g
s
.623 .66 .865 r
.73707 .36372 m .7503 .38836 L .72204 .39539 L p F P
0 g
s
.623 .66 .865 r
.72204 .39539 m .70872 .37126 L .73707 .36372 L p F P
0 g
s
.43187 .58154 m
.45305 .58042 L
s
.43187 .58154 m
.41989 .55396 L
s
.651 .698 .88 r
.42972 .29067 m .44516 .31337 L .41858 .32269 L p F P
0 g
s
.651 .698 .88 r
.41858 .32269 m .403 .30049 L .42972 .29067 L p F P
0 g
s
.36166 .36316 m
.38259 .35758 L
s
.37306 .40586 m
.36166 .36316 L
s
.627 .665 .867 r
.69521 .34679 m .70872 .37126 L .68069 .37872 L p F P
0 g
s
.627 .665 .867 r
.68069 .37872 m .66707 .35475 L .69521 .34679 L p F P
0 g
s
.641 .684 .875 r
.54139 .30867 m .55597 .33216 L .52881 .34078 L p F P
0 g
s
.641 .684 .875 r
.52881 .34078 m .5141 .31778 L .54139 .30867 L p F P
0 g
s
.4651 .60122 m
.48653 .59675 L
s
.4651 .60122 m
.45305 .58042 L
s
.52003 .59882 m
.54168 .58738 L
s
.52003 .59882 m
.50817 .59072 L
s
.37129 .31215 m
.37655 .31022 L
s
.37655 .31022 m
.39239 .3044 L
s
.37129 .31215 m
.38259 .35758 L
s
.632 .67 .869 r
.65326 .33044 m .66707 .35475 L .63924 .36263 L p F P
0 g
s
.632 .67 .869 r
.63924 .36263 m .62531 .33882 L .65326 .33044 L p F P
0 g
s
.76156 .38555 m
.77966 .36431 L
s
.37306 .40586 m
.39401 .40228 L
s
.38457 .44711 m
.37306 .40586 L
s
.41989 .55396 m
.44103 .55382 L
s
.41989 .55396 m
.40799 .52192 L
s
.646 .689 .876 r
.49916 .29443 m .5141 .31778 L .48709 .3268 L p F P
0 g
s
.646 .689 .876 r
.48709 .3268 m .47202 .30395 L .49916 .29443 L p F P
0 g
s
.54168 .58738 m
.56343 .57409 L
s
.54168 .58738 m
.52999 .58314 L
s
.38457 .44711 m
.40556 .44524 L
s
.39622 .48606 m
.38457 .44711 L
s
.73705 .41377 m
.75545 .39264 L
s
.75545 .39264 m
.75548 .39261 L
s
.7522 .42887 m
.75813 .39101 L
s
.75813 .39101 m
.75814 .39096 L
s
.636 .676 .87 r
.61118 .31466 m .62531 .33882 L .59768 .34711 L p F P
0 g
s
.636 .676 .87 r
.59768 .34711 m .58343 .32346 L .61118 .31466 L p F P
0 g
s
.40799 .52192 m
.42908 .52192 L
s
.40799 .52192 m
.39622 .48606 L
s
.39622 .48606 m
.41725 .48544 L
s
.623 .657 .862 r
.76575 .35608 m .77887 .38124 L .7503 .38836 L p F P
0 g
s
.77781 .37919 m
.77966 .36431 L
s
.77432 .40728 m
.77781 .37919 L
s
.623 .657 .862 r
.7503 .38836 m .73707 .36372 L .76575 .35608 L p F P
0 g
s
.38259 .35758 m
.40372 .35194 L
s
.39401 .40228 m
.38259 .35758 L
s
.71559 .43769 m
.73705 .41377 L
s
.73705 .41377 m
.73001 .44965 L
s
.651 .695 .878 r
.45672 .28075 m .47202 .30395 L .44516 .31337 L p F P
0 g
s
.651 .695 .878 r
.44516 .31337 m .42972 .29067 L .45672 .28075 L p F P
0 g
s
.48653 .59675 m
.50817 .59072 L
s
.48653 .59675 m
.47449 .57821 L
s
.56343 .57409 m
.58523 .559 L
s
.56343 .57409 m
.55196 .574 L
s
.45305 .58042 m
.47449 .57821 L
s
.45305 .58042 m
.44103 .55382 L
s
.641 .681 .872 r
.56897 .29946 m .58343 .32346 L .55597 .33216 L p F P
0 g
s
.641 .681 .872 r
.55597 .33216 m .54139 .30867 L .56897 .29946 L p F P
0 g
s
.39239 .3044 m
.403 .30049 L
s
.403 .30049 m
.41366 .29658 L
s
.39239 .3044 m
.40372 .35194 L
s
.627 .662 .864 r
.72367 .33873 m .73707 .36372 L .70872 .37126 L p F P
0 g
s
.627 .662 .864 r
.70872 .37126 m .69521 .34679 L .72367 .33873 L p F P
0 g
s
.69403 .46084 m
.71559 .43769 L
s
.71559 .43769 m
.70777 .4695 L
s
.58523 .559 m
.60705 .54223 L
s
.58523 .559 m
.57406 .56332 L
s
.39401 .40228 m
.41518 .39864 L
s
.40556 .44524 m
.39401 .40228 L
s
.67238 .48303 m
.69403 .46084 L
s
.69403 .46084 m
.68548 .48831 L
s
.632 .667 .866 r
.68151 .32196 m .69521 .34679 L .66707 .35475 L p F P
0 g
s
.632 .667 .866 r
.66707 .35475 m .65326 .33044 L .68151 .32196 L p F P
0 g
s
.646 .686 .874 r
.52658 .28481 m .54139 .30867 L .5141 .31778 L p F P
0 g
s
.646 .686 .874 r
.5141 .31778 m .49916 .29443 L .52658 .28481 L p F P
0 g
s
.60705 .54223 m
.62887 .52388 L
s
.60705 .54223 m
.59626 .55112 L
s
.65065 .5041 m
.67238 .48303 L
s
.67238 .48303 m
.66316 .50596 L
s
.62887 .52388 m
.65065 .5041 L
s
.62887 .52388 m
.61853 .53745 L
s
.65065 .5041 m
.64083 .52237 L
s
.44103 .55382 m
.46244 .55294 L
s
.44103 .55382 m
.42908 .52192 L
s
.636 .672 .868 r
.63924 .30577 m .65326 .33044 L .62531 .33882 L p F P
0 g
s
.636 .672 .868 r
.62531 .33882 m .61118 .31466 L .63924 .30577 L p F P
0 g
s
.40556 .44524 m
.42679 .44326 L
s
.41725 .48544 m
.40556 .44524 L
s
.40372 .35194 m
.42505 .34624 L
s
.41518 .39864 m
.40372 .35194 L
s
.50817 .59072 m
.52999 .58314 L
s
.50817 .59072 m
.49617 .57485 L
s
.41366 .29658 m
.42972 .29067 L
s
.42972 .29067 m
.4351 .28869 L
s
.41366 .29658 m
.42505 .34624 L
s
.42908 .52192 m
.45044 .52148 L
s
.42908 .52192 m
.41725 .48544 L
s
.41725 .48544 m
.43854 .48458 L
s
.65 .691 .875 r
.48399 .27072 m .49916 .29443 L .47202 .30395 L p F P
0 g
s
.65 .691 .875 r
.47202 .30395 m .45672 .28075 L .48399 .27072 L p F P
0 g
s
.47449 .57821 m
.49617 .57485 L
s
.47449 .57821 m
.46244 .55294 L
s
.641 .677 .869 r
.59684 .29015 m .61118 .31466 L .58343 .32346 L p F P
0 g
s
.641 .677 .869 r
.58343 .32346 m .56897 .29946 L .59684 .29015 L p F P
0 g
s
.627 .659 .861 r
.75245 .33058 m .76575 .35608 L .73707 .36372 L p F P
0 g
s
.627 .659 .861 r
.73707 .36372 m .72367 .33873 L .75245 .33058 L p F P
0 g
s
.41518 .39864 m
.43658 .39492 L
s
.42679 .44326 m
.41518 .39864 L
s
.631 .664 .863 r
.71007 .31339 m .72367 .33873 L .69521 .34679 L p F P
0 g
s
.631 .664 .863 r
.69521 .34679 m .68151 .32196 L .71007 .31339 L p F P
0 g
s
.645 .683 .871 r
.55429 .27509 m .56897 .29946 L .54139 .30867 L p F P
0 g
s
.645 .683 .871 r
.54139 .30867 m .52658 .28481 L .55429 .27509 L p F P
0 g
s
.52999 .58314 m
.55196 .574 L
s
.52999 .58314 m
.51808 .57032 L
s
.4351 .28869 m
.45672 .28075 L
s
.4351 .28869 m
.44658 .34049 L
s
.42505 .34624 m
.44658 .34049 L
s
.43658 .39492 m
.42505 .34624 L
s
.46244 .55294 m
.48411 .5513 L
s
.46244 .55294 m
.45044 .52148 L
s
.636 .669 .865 r
.6676 .29678 m .68151 .32196 L .65326 .33044 L p F P
0 g
s
.636 .669 .865 r
.65326 .33044 m .63924 .30577 L .6676 .29678 L p F P
0 g
s
.42679 .44326 m
.44827 .44114 L
s
.43854 .48458 m
.42679 .44326 L
s
.65 .688 .872 r
.51155 .26059 m .52658 .28481 L .49916 .29443 L p F P
0 g
s
.65 .688 .872 r
.49916 .29443 m .48399 .27072 L .51155 .26059 L p F P
0 g
s
.49617 .57485 m
.51808 .57032 L
s
.49617 .57485 m
.48411 .5513 L
s
.45044 .52148 m
.47207 .52056 L
s
.45044 .52148 m
.43854 .48458 L
s
.43854 .48458 m
.4601 .48346 L
s
.64 .674 .867 r
.62502 .28074 m .63924 .30577 L .61118 .31466 L p F P
0 g
s
.64 .674 .867 r
.61118 .31466 m .59684 .29015 L .62502 .28074 L p F P
0 g
s
.55196 .574 m
.57406 .56332 L
s
.55196 .574 m
.5402 .5646 L
s
.43658 .39492 m
.45821 .39113 L
s
.44827 .44114 m
.43658 .39492 L
s
.45672 .28075 m
.47852 .27273 L
s
.45672 .28075 m
.46831 .33468 L
s
.645 .679 .868 r
.58229 .26527 m .59684 .29015 L .56897 .29946 L p F P
0 g
s
.645 .679 .868 r
.56897 .29946 m .55429 .27509 L .58229 .26527 L p F P
0 g
s
.631 .66 .86 r
.73895 .30472 m .75245 .33058 L .72367 .33873 L p F P
0 g
s
.631 .66 .86 r
.72367 .33873 m .71007 .31339 L .73895 .30472 L p F P
0 g
s
.44658 .34049 m
.46831 .33468 L
s
.45821 .39113 m
.44658 .34049 L
s
.57406 .56332 m
.59626 .55112 L
s
.57406 .56332 m
.56249 .55766 L
s
.635 .666 .862 r
.69628 .28769 m .71007 .31339 L .68151 .32196 L p F P
0 g
s
.635 .666 .862 r
.68151 .32196 m .6676 .29678 L .69628 .28769 L p F P
0 g
s
.48411 .5513 m
.50604 .54885 L
s
.48411 .5513 m
.47207 .52056 L
s
.649 .684 .87 r
.53939 .25036 m .55429 .27509 L .52658 .28481 L p F P
0 g
s
.649 .684 .87 r
.52658 .28481 m .51155 .26059 L .53939 .25036 L p F P
0 g
s
.44827 .44114 m
.47 .43888 L
s
.4601 .48346 m
.44827 .44114 L
s
.51808 .57032 m
.5402 .5646 L
s
.51808 .57032 m
.50604 .54885 L
s
.64 .671 .864 r
.6535 .27123 m .6676 .29678 L .63924 .30577 L p F P
0 g
s
.64 .671 .864 r
.63924 .30577 m .62502 .28074 L .6535 .27123 L p F P
0 g
s
.59626 .55112 m
.61853 .53745 L
s
.59626 .55112 m
.58496 .54949 L
s
.47852 .27273 m
.48399 .27072 L
s
.48399 .27072 m
.50049 .26466 L
s
.47852 .27273 m
.49026 .3288 L
s
.47207 .52056 m
.49397 .51914 L
s
.47207 .52056 m
.4601 .48346 L
s
.4601 .48346 m
.48193 .48206 L
s
.45821 .39113 m
.48007 .38726 L
s
.47 .43888 m
.45821 .39113 L
s
.46831 .33468 m
.49026 .3288 L
s
.48007 .38726 m
.46831 .33468 L
s
.644 .676 .865 r
.61059 .25534 m .62502 .28074 L .59684 .29015 L p F P
0 g
s
.644 .676 .865 r
.59684 .29015 m .58229 .26527 L .61059 .25534 L p F P
0 g
s
.61853 .53745 m
.64083 .52237 L
s
.61853 .53745 m
.60756 .54011 L
s
.5402 .5646 m
.56249 .55766 L
s
.5402 .5646 m
.52822 .54556 L
s
.50604 .54885 m
.52822 .54556 L
s
.50604 .54885 m
.49397 .51914 L
s
.635 .662 .859 r
.72527 .2785 m .73895 .30472 L .71007 .31339 L p F P
0 g
s
.635 .662 .859 r
.71007 .31339 m .69628 .28769 L .72527 .2785 L p F P
0 g
s
.64083 .52237 m
.66316 .50596 L
s
.64083 .52237 m
.63028 .52952 L
s
.649 .681 .867 r
.56752 .24001 m .58229 .26527 L .55429 .27509 L p F P
0 g
s
.649 .681 .867 r
.55429 .27509 m .53939 .25036 L .56752 .24001 L p F P
0 g
s
.50049 .26466 m
.51155 .26059 L
s
.51155 .26059 m
.52265 .25651 L
s
.50049 .26466 m
.51241 .32287 L
s
.47 .43888 m
.49198 .43647 L
s
.48193 .48206 m
.47 .43888 L
s
.66316 .50596 m
.68548 .48831 L
s
.66316 .50596 m
.6531 .51774 L
s
.639 .667 .861 r
.68229 .26162 m .69628 .28769 L .6676 .29678 L p F P
0 g
s
.639 .667 .861 r
.6676 .29678 m .6535 .27123 L .68229 .26162 L p F P
0 g
s
.68548 .48831 m
.70777 .4695 L
s
.68548 .48831 m
.67599 .5048 L
s
.7522 .42887 m
.77432 .40728 L
s
.7679 .44234 m
.77432 .40728 L
s
.49397 .51914 m
.51612 .51719 L
s
.49397 .51914 m
.48193 .48206 L
s
.70777 .4695 m
.73001 .44965 L
s
.70777 .4695 m
.69894 .49074 L
s
.48193 .48206 m
.50402 .48037 L
s
.73001 .44965 m
.7522 .42887 L
s
.7522 .42887 m
.74491 .45945 L
s
.49026 .3288 m
.51241 .32287 L
s
.50216 .38331 m
.49026 .3288 L
s
.73001 .44965 m
.72191 .4756 L
s
.48007 .38726 m
.50216 .38331 L
s
.49198 .43647 m
.48007 .38726 L
s
.644 .673 .863 r
.63919 .24531 m .6535 .27123 L .62502 .28074 L p F P
0 g
s
.644 .673 .863 r
.62502 .28074 m .61059 .25534 L .63919 .24531 L p F P
0 g
s
.56249 .55766 m
.58496 .54949 L
s
.56249 .55766 m
.55062 .54141 L
s
.52265 .25651 m
.53939 .25036 L
s
.53939 .25036 m
.54499 .2483 L
s
.52265 .25651 m
.53478 .31687 L
s
.52822 .54556 m
.55062 .54141 L
s
.52822 .54556 m
.51612 .51719 L
s
.648 .678 .864 r
.59594 .22957 m .61059 .25534 L .58229 .26527 L p F P
0 g
s
.648 .678 .864 r
.58229 .26527 m .56752 .24001 L .59594 .22957 L p F P
0 g
s
.49198 .43647 m
.51422 .43391 L
s
.50402 .48037 m
.49198 .43647 L
s
.639 .664 .858 r
.71139 .2519 m .72527 .2785 L .69628 .28769 L p F P
0 g
s
.639 .664 .858 r
.69628 .28769 m .68229 .26162 L .71139 .2519 L p F P
0 g
s
.51241 .32287 m
.53478 .31687 L
s
.5245 .37928 m
.51241 .32287 L
s
.58496 .54949 m
.60756 .54011 L
s
.58496 .54949 m
.57323 .53637 L
s
.50216 .38331 m
.5245 .37928 L
s
.51422 .43391 m
.50216 .38331 L
s
.51612 .51719 m
.53854 .51469 L
s
.51612 .51719 m
.50402 .48037 L
s
.50402 .48037 m
.52637 .47837 L
s
.54499 .2483 m
.56752 .24001 L
s
.54499 .2483 m
.55736 .31081 L
s
.643 .669 .86 r
.6681 .23517 m .68229 .26162 L .6535 .27123 L p F P
0 g
s
.643 .669 .86 r
.6535 .27123 m .63919 .24531 L .6681 .23517 L p F P
0 g
s
.55062 .54141 m
.57323 .53637 L
s
.55062 .54141 m
.53854 .51469 L
s
.648 .674 .862 r
.62467 .21901 m .63919 .24531 L .61059 .25534 L p F P
0 g
s
.648 .674 .862 r
.61059 .25534 m .59594 .22957 L .62467 .21901 L p F P
0 g
s
.60756 .54011 m
.63028 .52952 L
s
.60756 .54011 m
.59604 .53043 L
s
.53478 .31687 m
.55736 .31081 L
s
.54707 .37516 m
.53478 .31687 L
s
.51422 .43391 m
.53671 .43119 L
s
.52637 .47837 m
.51422 .43391 L
s
.56752 .24001 m
.59023 .23166 L
s
.56752 .24001 m
.58016 .30468 L
s
.5245 .37928 m
.54707 .37516 L
s
.53671 .43119 m
.5245 .37928 L
s
.53854 .51469 m
.56119 .51163 L
s
.53854 .51469 m
.52637 .47837 L
s
.63028 .52952 m
.6531 .51774 L
s
.63028 .52952 m
.61904 .52357 L
s
.643 .666 .857 r
.69732 .22492 m .71139 .2519 L .68229 .26162 L p F P
0 g
s
.643 .666 .857 r
.68229 .26162 m .6681 .23517 L .69732 .22492 L p F P
0 g
s
.52637 .47837 m
.54898 .47604 L
s
.57323 .53637 m
.59604 .53043 L
s
.57323 .53637 m
.56119 .51163 L
s
.647 .671 .859 r
.6537 .20833 m .6681 .23517 L .63919 .24531 L p F P
0 g
s
.647 .671 .859 r
.63919 .24531 m .62467 .21901 L .6537 .20833 L p F P
0 g
s
.6531 .51774 m
.67599 .5048 L
s
.6531 .51774 m
.64221 .51578 L
s
.55736 .31081 m
.58016 .30468 L
s
.56989 .37096 m
.55736 .31081 L
s
.59023 .23166 m
.59594 .22957 L
s
.59594 .22957 m
.61314 .22324 L
s
.59023 .23166 m
.60319 .29849 L
s
.53671 .43119 m
.55946 .4283 L
s
.54898 .47604 m
.53671 .43119 L
s
.54707 .37516 m
.56989 .37096 L
s
.55946 .4283 m
.54707 .37516 L
s
.67599 .5048 m
.69894 .49074 L
s
.67599 .5048 m
.66553 .50707 L
s
.56119 .51163 m
.58409 .50797 L
s
.56119 .51163 m
.54898 .47604 L
s
.59604 .53043 m
.61904 .52357 L
s
.59604 .53043 m
.58409 .50797 L
s
.54898 .47604 m
.57185 .47338 L
s
.69894 .49074 m
.72191 .4756 L
s
.69894 .49074 m
.68898 .49743 L
s
.61314 .22324 m
.62467 .21901 L
s
.62467 .21901 m
.63624 .21475 L
s
.61314 .22324 m
.62644 .29223 L
s
.646 .668 .856 r
.68304 .19755 m .69732 .22492 L .6681 .23517 L p F P
0 g
s
.646 .668 .856 r
.6681 .23517 m .6537 .20833 L .68304 .19755 L p F P
0 g
s
.58016 .30468 m
.60319 .29849 L
s
.59295 .36666 m
.58016 .30468 L
s
.72191 .4756 m
.74491 .45945 L
s
.72191 .4756 m
.71255 .48688 L
s
.55946 .4283 m
.58247 .42523 L
s
.57185 .47338 m
.55946 .4283 L
s
.61904 .52357 m
.64221 .51578 L
s
.61904 .52357 m
.60722 .5037 L
s
.56989 .37096 m
.59295 .36666 L
s
.58247 .42523 m
.56989 .37096 L
s
.74491 .45945 m
.7679 .44234 L
s
.74491 .45945 m
.73622 .47542 L
s
.58409 .50797 m
.60722 .5037 L
s
.58409 .50797 m
.57185 .47338 L
s
.63624 .21475 m
.6537 .20833 L
s
.6537 .20833 m
.65954 .20619 L
s
.63624 .21475 m
.64992 .28591 L
s
.75997 .46307 m
.7679 .44234 L
s
.57185 .47338 m
.59498 .47036 L
s
.60319 .29849 m
.62644 .29223 L
s
.61627 .36226 m
.60319 .29849 L
s
.64221 .51578 m
.66553 .50707 L
s
.64221 .51578 m
.63058 .4988 L
s
.58247 .42523 m
.60574 .42197 L
s
.59498 .47036 m
.58247 .42523 L
s
.59295 .36666 m
.61627 .36226 L
s
.60574 .42197 m
.59295 .36666 L
s
.60722 .5037 m
.63058 .4988 L
s
.60722 .5037 m
.59498 .47036 L
s
.65954 .20619 m
.68304 .19755 L
s
.65954 .20619 m
.67363 .27951 L
s
.59498 .47036 m
.61836 .46698 L
s
.62644 .29223 m
.64992 .28591 L
s
.63983 .35777 m
.62644 .29223 L
s
.66553 .50707 m
.68898 .49743 L
s
.66553 .50707 m
.65414 .49326 L
s
.68304 .19755 m
.69758 .27304 L
s
.63058 .4988 m
.65414 .49326 L
s
.63058 .4988 m
.61836 .46698 L
s
.60574 .42197 m
.62928 .41853 L
s
.61836 .46698 m
.60574 .42197 L
s
.61627 .36226 m
.63983 .35777 L
s
.62928 .41853 m
.61627 .36226 L
s
.68898 .49743 m
.71255 .48688 L
s
.68898 .49743 m
.67791 .48707 L
s
.64992 .28591 m
.67363 .27951 L
s
.66365 .35318 m
.64992 .28591 L
s
.61836 .46698 m
.64198 .46322 L
s
.71255 .48688 m
.73622 .47542 L
s
.71255 .48688 m
.70187 .48022 L
s
.65414 .49326 m
.67791 .48707 L
s
.65414 .49326 m
.64198 .46322 L
s
.63983 .35777 m
.66365 .35318 L
s
.65307 .41488 m
.63983 .35777 L
s
.62928 .41853 m
.65307 .41488 L
s
.64198 .46322 m
.62928 .41853 L
s
.67363 .27951 m
.69758 .27304 L
s
.68774 .34849 m
.67363 .27951 L
s
.73622 .47542 m
.75997 .46307 L
s
.73622 .47542 m
.72601 .47269 L
s
.64198 .46322 m
.66586 .45906 L
s
.67791 .48707 m
.70187 .48022 L
s
.67791 .48707 m
.66586 .45906 L
s
.75032 .46449 m
.75997 .46307 L
s
.66365 .35318 m
.68774 .34849 L
s
.67713 .41102 m
.66365 .35318 L
s
.65307 .41488 m
.67713 .41102 L
s
.66586 .45906 m
.65307 .41488 L
s
.69758 .27304 m
.71208 .34368 L
s
.66586 .45906 m
.68998 .45451 L
s
.70187 .48022 m
.72601 .47269 L
s
.70187 .48022 m
.68998 .45451 L
s
.68774 .34849 m
.71208 .34368 L
s
.70145 .40695 m
.68774 .34849 L
s
.67713 .41102 m
.70145 .40695 L
s
.68998 .45451 m
.67713 .41102 L
s
.68998 .45451 m
.71433 .44954 L
s
.72601 .47269 m
.75032 .46449 L
s
.72601 .47269 m
.71433 .44954 L
s
.71208 .34368 m
.72603 .40265 L
s
.73892 .44414 m
.75032 .46449 L
s
.70145 .40695 m
.72603 .40265 L
s
.71433 .44954 m
.70145 .40695 L
s
.71433 .44954 m
.73892 .44414 L
s
.72603 .40265 m
.73892 .44414 L
s
.25 Mabswid
.68205 0 m
.95219 .42426 L
s
.95219 .42426 m
1 .77405 L
s
1 .77405 m
.7043 .38319 L
s
.7043 .38319 m
.68205 0 L
s
.05798 .25172 m
0 .6176 L
s
0 .6176 m
.7043 .38319 L
s
.7043 .38319 m
.68205 0 L
s
.68205 0 m
.05798 .25172 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[305]:=",
  ImageSize->{300, 277.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/00015B000`400?l00000o`00003obP3oool2
00000600oooo00380?ooo`80000000<0oooo000000000000G`3oool00<D0oooo0`0000030?ooo`80
0000G`3oool00<<0oooo0P0000060?ooo`030000003oool0000005h0oooo00300?ooo`<00000203o
ool010000000oooo0?ooo`00001M0?ooo`00_P3oool2000000/0oooo00@000000?ooo`3oool00000
G@3oool00;`0oooo0P00000=0?ooo`050000003oool0oooo0?ooo`000000G03oool00;T0oooo0`00
000?0?ooo`050000003oool0oooo0?ooo`000000G03oool00;L0oooo0P00000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0F@3oool00;@0oooo0`00000E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0F03oool00;80oooo0P00000H0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0F03oool00:l0oooo0`00000J0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0E`3oool00:d0oooo0P00000M0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0EP3oool00:X0oooo0`00000O0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0EP3oool00:P0oooo0P00000R0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0E@3oool00:H0oooo0P00000T0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0E03oool00:<0oooo0`00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0E03oool00:40oooo0P00000Y0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
D`3oool009h0oooo0`00000[0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0D`3o
ool009`0oooo0P00000^0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0DP3oool0
09T0oooo0`00000`0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0D@3oool009L0
oooo0P00000c0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0D@3oool009@0oooo
0`00000e0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0D03oool00980oooo0P00
000h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C`3oool00900oooo0P00000j
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C`3oool008d0oooo0`00000m0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0CP3oool008/0oooo0P0000100?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0C@3oool008P0oooo0`0000120?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0C@3oool008H0oooo0P0000150?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0C03oool008<0oooo0`0000170?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0C03oool00840oooo0P00001:0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0B`3oool007h0oooo0`00001<0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0BP3oool007`0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0BP3oool007X0oooo0P00001A0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0B@3oool007L0oooo0`00001C0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0B03oool007D0oooo0P00001F0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0B03oool00780oooo0`00001H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0A`3oool00700oooo0P00001K0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
AP3oool006d0oooo0`00001M0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0AP3o
ool006/0oooo0P00001P0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0A@3oool0
06P0oooo0`00001R0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0A03oool006H0
oooo0P00001U0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0A03oool006<0oooo
0`00001X0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0@`3oool00640oooo0P00
001[0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0@`3oool005l0oooo0P00001]
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0@P3oool005`0oooo0`00001_0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0@@3oool005X0oooo0P00001b0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0@@3oool005L0oooo0`00001d0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0@03oool005D0oooo0P00001g0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0?`3oool00580oooo0`00001i0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0?`3oool00500oooo0P00001l0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0?P3oool004d0oooo0`00001n0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0?@3oool004/0oooo0P0000210?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0?@3oool004T0oooo0P0000230?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0?03oool004H0oooo0`0000250?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0?03oool004@0oooo0P0000280?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0>`3oool00440oooo0`00002:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0>P3oool003l0oooo0P00002=0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
>P3oool003`0oooo0`00002@0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0>@3o
ool003X0oooo0P00002?0?ooo`8000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo03P0oooo000g0?ooo`<00000S`3oool2000000050:F[f`000000oooo0?ooo`0000008@3oool0
0`000000oooo0?ooo`0h0?ooo`00=@3oool200000900oooo0P0000030:F[f`80000000<0oooo0000
003oool08@3oool00`000000oooo0?ooo`0g0?ooo`00<`3oool200000900oooo0P0000060:F[f`03
0000003oool0000002<0oooo00<000000?ooo`3oool0=P3oool00300oooo0`00002?0?ooo`@00000
1`2UZm/3000002<0oooo00<000000?ooo`3oool0=P3oool002h0oooo0P00002?0?ooo`<0000000@0
YJ_K0000002UZm/000001`2UZm/3000002@0oooo00<000000?ooo`3oool0=@3oool002/0oooo0`00
002>0?ooo`@00000102UZm/00`000000YJ_K000000060:F[f`030000002UZm/0000002@0oooo00<0
00000?ooo`3oool0=@3oool002T0oooo0P00002>0?ooo`@0000000<0YJ_K0000002UZm/0102UZm/0
0`000000YJ_K000000060:F[f`030000002UZm/0000002D0oooo00<000000?ooo`3oool0=03oool0
02H0oooo0`00002=0?ooo`<000000P2U[=`010000000YJ_K0:F[f`0000060:F[f`8000001P2UZm/0
10000000YJ_K00000000000U0?ooo`030000003oool0oooo03<0oooo000T0?ooo`800000SP3oool4
000000<0YJcL00D000000:F[f`2UZm/0YJ_K000000050:F[f`8000001`2UZm/3000002D0oooo00<0
00000?ooo`3oool0<`3oool00240oooo0`00002=0?ooo`<000000`2U[=`00`000000YJcL0:F/g002
0:F/g0040000002UZm/0YJ_K000000H0YJ_K00<000000:F[f`2UZm/00`2UZm/5000002H0oooo00<0
00000?ooo`3oool0<P3oool001l0oooo0P00002=0?ooo`D000001@2U[=`01@000000YJcL0:F/g02U
[=`000000080YJ_K00<000000:F[f`2UZm/0102UZm/00`000000YJ_K0:F[f`0300000080Y:[K0P00
00000`2TZ]/000000?ooo`0U0?ooo`030000003oool0oooo0340oooo000M0?ooo`800000S03oool4
000000050:F]g@000000YJgM0:F]g@000000102U[=`00`000000YJcL0:F/g0020:F/g0030000002U
Zm/0000000H0YJ_K0`0000050:BZf`80000000<0Y:[K0000003oool0703oool3000000H0oooo00<0
00000?ooo`3oool0<@3oool001X0oooo0`00002;0?ooo`<000001@2U[Md010000000YJgM0:F]g@00
00040:F/g0030000002U[=`0YJcL00<0YJcL0P0000040:F[f`80000000<0Y:_L0000002TZ]/01@2T
Z]/200000080Y:[K00<000000?ooo`3oool06@3oool3000000030?ooo`000000oooo00D0oooo00<0
00000?ooo`3oool0<03oool001P0oooo0P00002<0?ooo`80000000<0YZkM0000000000001P2U[Md0
10000000YJgM0:F]g@0000030:F/g0030000002U[=`0YJcL00<0YJcL00<000000:F[f`0000000`00
00030:B[g08000001@2TZ]/200000080Y:[K00<000000?ooo`3oool0603oool2000000<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0_0?ooo`005@3oool3000008/0oooo0`000003
0:J^g@8000001P2U[Md010000000YJgM0:F]g@0000030:F/g0030000002U[=`0YJcL00<0YJcL0`00
00060:B[g08000001P2TZ]/200000080Y:[K00<000000?ooo`3oool05@3oool2000000030?ooo`00
0000oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0_0?ooo`004`3oool2
000008/0oooo100000060:J^g@8000001@2U[Md01@000000YJgM0:F]g@2U[Md0000000<0YJcL00<0
00000:F/g00000000P0000020:B/g0030000002TZm`0Y:_L00@0Y:_L00<000000:B[g00000001@2T
Z]/200000080Y:[K00<000000?ooo`3oool0503oool010000000oooo0000000000050?ooo`800000
1P3oool00`000000oooo0?ooo`0^0?ooo`004@3oool2000008X0oooo0`0000000`2V[mh000000000
00070:J^g@8000001@2U[Md01@000000YJgM0:F]g@2U[Md000000080YJcL0`0000050:B/g0030000
002TZm`0Y:_L00D0Y:_L0P0000050:BZf`8000000P2TZ]/2000001@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`<0000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0^0?ooo`00
4@3oool2000008L0oooo100000040:J_gP030000002V[]d0YZkM00D0YZkM00<000000:J^g@000000
102U[Md010000000YJgM0:F]g@2U[Md3000000030:B/g0000000Y:cL00D0Y:cL0P0000060:B[g003
0000002TZm`0000000@0Y:[K100000000`2SZM/000000?ooo`0A0?ooo`<000000P3oool4000000D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0]0?ooo`004@3oool00`000000oooo
000000230?ooo`@0000000<0YZoN0000002V[mh0102V[mh2000000H0YZkM00@000000:J^g@2V[]d0
0000102U[Md300000080Y:gM00<000000:B/g00000001P2T[=`2000000H0Y:_L00<000000:B[g000
00000P2TZ]/4000000@0XjWK00<000000?ooo`3oool03P3oool3000000060?ooo`00000000000000
003oool000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02`0oooo000A0?oo
o`040000003oool0oooo000007l0oooo0`0000020:J`g`040000002V[mh0YZoN000000H0YZoN00<0
00000:J^g@2V[]d0102V[]d010000000YZkM0:J^g@0000020:F]g@<00000102T[Md00`000000Y:cL
000000070:B/g08000001@2TZm`00`000000Y:_L0000000200000080XjWK0P0000040:>Yf`030000
003oool0oooo00d0oooo1P0000001@3oool000000?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0/0?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo07X0oooo100000030:J`g`040000002V[mh0YZoN000000H0YZoN00<000000:J^g@2V
[]d01@2V[]d00`000000YZkM0000000200000080Y:gM00<000000:B]g@2T[Md00`2T[Md2000000L0
Y:cL0P0000030:B[g0@000000P2SZ]`01@000000XjWK0:>Yf`2SZM/0000000D0XjWK00<000000?oo
o`3oool02`3oool600000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo02/0oooo000@0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0MP3oool3000000<0Y[3O00<000000:J`g`2V/=l00P2V/=l010000000YZoN0:J_gP000005
0:J_gP8000001@2V[]d300000080YJgN00@000000:B]g@2T[Md000001@2T[Md00`000000Y:cL0000
00060:B/g0D000000P2SZ]`01@000000Xj[L0:>Zg02SZ]`0000000<0XjWK00<000000:>Yf`2SZM/0
0`2SZM/00`000000oooo0?ooo`0:0?ooo`<0000000@0oooo00000000000000000P3oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:P3oool00100
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1c0?ooo`<0000000<0Y[3O0000002V
/=l00`2V/=l00`000000Y[3O0:J`g`020:J`g`030000002V[mh0000000H0YZoN00<000000:J^g@2V
[]d00`0000000`2U[Mh000000:F]gP020:F]gP040000002T[Md0Y:gM000000H0Y:gM0P0000040:B/
g0<0000000<0Xj_M0000002SZ]`0102SZ]`01P000000Xj[L0:>Zg02SZ]`000000:>Yf`8000001P2S
ZM/00`000000oooo0?ooo`070?ooo`<000000`3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02X0oooo
000@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0K`3oool4000000040:J`g`00
0000Y[3O000000@0Y[3O00<000000:J`g`2V/=l00`2V/=l2000000H0YZoN0`0000040:F]gP030000
002U[Mh0YJgN0080YJgN00@000000:B]g@2T[Md000001@2T[Md2000000040:B/g000000000000000
0080Xj_M00@000000:>[g@2SZmd00000102SZ]`00`000000Xj[L00000003000000030:>Yf`000000
XjWK00D0XjWK00<000000?ooo`3oool01P3oool400000080oooo0P0000000`3oool0000000000002
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo02T0oooo000@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0J`3oool30000
00D0Y[3O00@000000:J`g`2V/=l000000`2V/=l00`000000Y[3O0:J`g`030:J`g`8000000P2V[mh5
000000030:F^gP000000YJgN00@0YJgN00D000000:F]gP2U[Mh0YJgN000000020:B]g@030000002T
[Md0Y:gM00<0Y:gM0`0000060:>[g@030000002SZmd0000000<0Xj[L0`0000040:>Zg08000001P2S
ZM/2000000H0oooo1@0000000`3oool0000000000002000000040?ooo`00000000000?ooo`L00000
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02P0oooo000@0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0J03oool5000000H0Y[3O00@000000:J`g`2V/=l00000
0P2V/=l00`000000Y[3O0:J`g`030:J`g`@00000102U[]h00`000000YJkN000000050:F]gP030000
002U[Mh0YJgN0080YJgN00<000000:B]g@0000000`2T[Md2000000030:>/g@000000000000H0Xj_M
00<000000:>[g@0000000`0000000`2SZ]`000000:>Zg0040:>Zg0<0000000<0XjWK000000000000
0P0000020::Yf`030000003oool0oooo0080oooo0P0000000`3oool0000000000004000000<0oooo
0P0000040?ooo`040000003oool0oooo0?ooo`@000002@3oool00`000000oooo0?ooo`0X0?ooo`00
3`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06@0oooo100000020:Jah0800000
1P2V/=l01@000000Y[3O0:J`g`2V/=l000000080Y[3O00<000000:J`g`2V/=l00P0000000`2U[ml0
00000:F^gP050:F^gP040000002U[]h0YJkN000000@0YJgN00<000000:F]gP2U[Mh00P2U[Mh00`00
0000Y:gM00000003000000@0XjcM00<000000:>[g@2SZmd00`2SZmd3000000030:>[g@000000Xj[L
0080Xj[L00<000000:>Zg02SZ]`00`2SZ]`4000000H0XZWK00@000000?ooo`3oool0oooo0P000000
203oool00000000000000000oooo0000003oool000000P3oool00`000000oooo000000050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0W0?ooo`00
3`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0600oooo1@0000050:Jah0800000
1@2V/=l01@000000Y[3O0:J`g`2V/=l000000080Y[3O0`0000040:F_g`030000002U[]h0YJkN00@0
YJkN00@000000:F^gP2U[]h000000`2U[Mh00`000000YJgN0:F]gP020:F]gP<000001`2S[=d60000
00030:>[g@000000Xj_M0080Xj_M00H000000:>Zg02SZ]`0Xj[L0000002SZ]`3000000030::Zg000
0000000000P0XZWK00<000000?ooo`0000000`0000020?ooo`80000000<0oooo0000000000000P3o
ool00`000000oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0W0?ooo`003`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo05d0oooo0P0000020:Jbh@8000001P2V/N000`000000Y[7P000000040:J`g`040000002V/=l0
Y[3O0:J`g`@000001P2U[ml00`000000YJkN0:F^gP040:F^gP050000002U[]h0YJkN0:F^gP000000
0P2U[Mh00`000000YJgN0:F]gP0200000080Y:gN0P0000050:>/g@<000001@2SZmd01@000000Xj_M
0:>[g@2SZmd000000080Xj[L0`0000040::Zg0800000202RZM/6000000030?ooo`00000000000080
oooo0P000000103oool000000?ooo`3oool2000000@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo02H0oooo000?0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0F@3oool3000000@0Y[;Q0P0000060:Jah0040000002V/N00Y[7P0000
00<0Y[3O00@000000:J`g`00000000000P2U/>02000000H0YJoO0P0000050:F^gP050000002U[]h0
YJkN0:F^gP0000000P2U[Mh3000000@0Y:gN0P0000000`2S[=d0000000000002000000040:>/g@00
0000XjcM000000D0Xj_M00<000000:>[g@2SZmd00`0000000`2RZ]`000000::Zg0040::Zg0800000
2@2RZM/00`000000oooo00000002000000030?ooo`000000000000<0oooo0P0000030?ooo`800000
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
9@3oool000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1E0?ooo`<0000000<0
Y[;Q0000002V/^401@2V/^42000000D0Y[7P00@000000:Jah02V/N0000000P2V/=l3000000@0YK3P
0P0000060:F_g`8000001@2U[]h010000000YJkN0:F^gP2U[]h3000000030:B]gP000000Y:gN0080
Y:gN1@0000050:>/g@040000002S[=d0XjcM000000@0Xj_M0`0000001@2RZmd000000::Zg02RZ]`0
000000D0XZ[L00<000000::Zg0000000202RZM/00`000000oooo000000020?ooo`8000000`3oool2
000000<0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool09@3oool000l0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`1A0?ooo`<000000P2V/n8010000000Y[;Q0:Jbh@0000060:Jbh@030000002V/N00
Y[7P00@0Y[7P00<000000:Jah00000000P0000020:F`h0030000002U/>00YK3P00<0YK3P0P000005
0:F_g`030000002U[ml0000000D0YJkN0`0000020:B^g`H000000`2T[Mh00`000000XjcM0:>/g@05
0:>/g@030000002S[=d000000080Xj_M0`0000040::[g@030000002RZ]`0000000H0XZ[L0P000008
0::Yf`<0000000<0oooo0000000000002P0000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02@0oooo000?0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0CP3oool4000000<0Y[?R00@000000:Jb
h@2V/^4000001P2V/^42000000D0Y[7P0P0000020:Fah@040000002U/>00YK3P000000D0YK3P0P00
00050:F_g`030000002U[ml000000080YJkN100000000`2T[]l0000000000002000000030:B]gP00
0000Y:gN00D0Y:gN0P0000060:>/g@D000000P2RZmd00`000000XZ_M0::[g@020::[g@040000002R
Z]`0XZ[L000000D0XZ[L0`0000050::Yf`80000000<0XJSL0000000000000P0000000`3oool00000
0?ooo`020?ooo`030000003oool000000080oooo1@0000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`003P3oool00`000000oooo0?oo
o`0A0?ooo`800000B`3oool3000000<0Y[?R00<000000:JchP2V/n800P2V/n800`000000Y[;Q0000
00060:Jbh@8000000P2V/N04000000<0YK7Q00@000000:F`h02U/>0000001P2U/>000`000000YJoO
0:F_g`040:F_g`@000000P2T[]l3000000@0Y:kO0P0000070:B]gP040000002S[=d0XjcM0:>/g@@0
00000`2R[=h010000000XZ_M0::[g@0000050::[g@030000002RZ]`0000000D0XZ[L0`0000020::Y
f`<00000102QZ=`01`000000oooo000000000000oooo0000003oool00P0000020?ooo`030000003o
ool000000080oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool000h0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`160?ooo`<0000000<0Y[CR0000002V/n800`2V/n800`000000Y[?R0:Jc
hP020:JchP8000001P2V/^44000000<0YK7Q00<000000:Fah@2U/N400P2U/N400`000000YK3P0000
00060:F`h0040000002U[ml0YJoO0:F_g`@0000000<0Y:oO0000000000000P0000000`2T[]l00000
0:B^g`040:B^g`030000002T[Mh0000000H0Y:gN100000030::/gP050000002R[=h0XZcN0::/gP00
00000`2RZmd00`000000XZ_M0::[g@020::[g@030000002RZ]`0000000D0XZ[L1@0000070:6Xg080
000000<0oooo0000003oool00P0000001`3oool000000?ooo`3oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`02000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0R0?ooo`003P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0480oooo10000000102V]>8000000:JdhP0000040:JchP030000002V/n80Y[?R00<0Y[?R0P000004
0:Jbh@<0000000<0YK;Q0000002U/N400`2U/N401`000000YK7Q0:Fah@2U/N4000000:F`h0000000
1P2U/>0400000080Y:oO0`0000000`2T[ml000000:B^g`020:B^g`030000002T[]l0Y:kO00@0Y:kO
0P0000040:B]gP@000001@2R[=h00`000000XZcN0::/gP020::/gP040000002RZmd0XZ_M000000D0
XZ_M0P0000040::Zg0<0000000<0XJWL0000002QZ=`0202QZ=`00`000000oooo000000020?ooo`03
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`80
0000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0240oooo000>0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0?P3oool3000000D0Y[CR00@000000:JdhP2V]>80
00000`2V/n800`000000Y[?R0:JchP030:JchP80000000@0Y[;Q00000000000000000P2U/^400`00
0000YK;Q000000040:Fah@030000002U/N40YK7Q0080YK7Q0P0000040:F`h080000000<0Y;3P0000
000000000`0000000`2T[ml000000:B_g`020:B_g`050000002T[]l0Y:kO0:B^g`0000001@2T[]l2
000000040:B]gP000000000000000080XZgN00<000000::]gP0000001@2R[=h01@000000XZcN0::/
gP2R[=h000000080XZ_M00<000000::[g@2RZmd00`2RZmd20000000:0::Zg000000000000000002Q
ZM`000000:6Yg0000000XJWL000000P0XJSL00@000000?ooo`000000oooo0P0000001`3oool00000
0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`<000000P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0240oooo000>0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0>P3oool3000000030:Neh`000000000000H0Y[CR00@000000:JdhP2V
]>8000000P2V/n800`000000Y[?R0:JchP030:JchP<000001@2U/^4010000000YK;Q0:Fbh@000003
0:Fah@030000002U/N40YK7Q0080YK7Q00<000000:F`h00000000`0000020:B`h0<00000102T[ml0
0`000000Y:oO0:B_g`020:B_g`040000002T[]l0Y:kO000000D0Y:kO0`0000050::]gP030000002R
[Mh0000000D0XZcN00<000000::/gP2R[=h00P2R[=h00`000000XZ_M000000050::[g@<00000102Q
ZM`01@000000XJWL0000002QZM`0000000T0XJSL0`0000020?ooo`8000000`3oool2000000@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0803oool000h0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0g0?ooo`<00000102W]N<2000000D0Y[CR00L000000:JdhP2V]>80Y[CR0000002V/n800000
00<0Y[?R0P0000000`2U/n800000000000050:Fbh@040000002U/^40YK;Q000000<0YK7Q00<00000
0:Fah@2U/N400P2U/N43000000030:B`h000000000000080000000@0Y;3P0000002T/>000000102T
[ml00`000000Y:oO0:B_g`020:B_g`030000002T[]l0000000<0Y:kO0P0000000`2S[Ml000000000
00060::]gP030000002R[Mh0000000@0XZcN00<000000::/gP2R[=h00P2R[=h010000000XZ_M0000
002RZmd400000080XJ[M00<000000:6Yg02QZM`00P2QZM`00`000000XJWL000000020:6Yg0030000
002QZ=`0XJSL00H0XJSL1P0000030?ooo`<00000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<000003`3oool00`000000oooo0?ooo`0O0?ooo`003@3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo03@0oooo0`0000060:Neh`8000001@2V]>801@000000Y[CR0:Jd
hP2V]>8000000080Y[?R0`0000040:FchP030000002U/^40YK;Q00<0YK;Q00D000000:Fbh@2U/^40
YK;Q000000030:Fah@030000002U/N40000000D000001@2T/>0010000000Y;3P0:B`h00000030:B_
g`030000002T[ml0Y:oO0080Y:oO00<000000:B^g`0000000`0000040:>]g`030000002R[Mh0XZgN
00@0XZgN00<000000::]gP000000102R[=h00`000000XZcN0::/gP020::/gP@000001P2QZ]d00`00
0000XJWL0:6Yg0020:6Yg0030000002QZM`000000080XJWL00<000000:6Xg02QZ=`01P2QZ=`20000
00<0oooo0`000000103oool000000000000000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01l0oooo000=0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0<@3oool200000080YkKT00<000000:Ne
h`2W]N<0102W]N<00`000000YkGS000000040:JdhP040000002V]>80Y[CR0:JdhP@000001P2U/n82
000000D0YK;Q00@000000:Fbh@2U/^4000000P2U/N4500000080Y;3Q00<000000:B`h02T/>001@2T
/>0010000000Y;3P0:B`h00000020:B_g`030000002T[ml0Y:oO0080Y:oO100000060:>]g`800000
1@2R[Mh010000000XZgN0::]gP0000040::/gP@000000P2QZmh2000000H0XJ[M0P0000030:6Yg003
0000002QZM`0000000<0XJWL00<000000:6Xg02QZ=`00`2QZ=`2000000030:2Xg0000000oooo0080
oooo0P0000001@3oool000000000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool000d0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0]0?ooo`<00000102W]^@2000000H0
YkGS00<000000:Neh`0000000`2V]>8400000080YKCS0P0000060:FchP030000002U/n80000000@0
YK;Q00<000000:Fbh@0000000`0000000`2T/>4000000:B`h@040:B`h@8000001P2T/>0010000000
Y;3P0:B`h00000020:B_g`D000000P2S[^02000000H0XjgO0P0000050::]gP040000002R[Mh0XZgN
00000080XZcN0`0000050:6[gP8000001P2QZ]d2000000<0XJWL00@000000:6Yg02QZM`000000P2Q
ZM`00`000000XJSL0:6Xg003000000@0X:SL00<000000?ooo`3oool00`0000020?ooo`8000001@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0N0?ooo`003@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo02T0oooo0`0000000`2W]^@000000:Nfi0050:Nfi0030000002W]N<0YkGS00@0YkGS00<00000
0:Neh`0000000`0000000`2U]><000000:Fdh`030:Fdh`8000001P2U/n800`000000YK?R00000003
0:Fbh@@000000P2T/N800`000000Y;3Q000000060:B`h@8000001@2T/>000`000000Y;3P0:B`h005
000000D0XjkP0P0000060:>]g`030000002S[Ml0000000D0XZgN00<000000::]gP0000000P000002
0:6[gP030000002QZmh0XJ_N00@0XJ_N00<000000:6Zg@2QZ]d0102QZ]d00`000000XJ[M00000002
0:6Yg0050000002QZM`0XJWL0000002QZM`0100000070:2Xg0030000003oool0oooo00800000103o
ool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool07@3oool000d0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0T0?ooo`@000000P2W]n@010000000YkKT0:Nfi00000050:Nfi08000001@2W
]N<200000080YKCS00@000000:Fdh`2U]><000001@2U]><00`000000YK?R0:FchP050:FchPD00000
00<0Y;7R0000002T/N80102T/N800`000000Y;3Q000000050:B`h@030000002T/>40000000@0Y;3P
0`0000020:>_h@030000002S[^00000000H0XjkP00<000000:>]g`2S[Ml01@2S[Ml2000000<0XZgN
100000020:6/g`040000002QZmh0XJ_N000000H0XJ_N00<000000:6Zg@2QZ]d01@2QZ]d200000080
XJWL1@0000030:2Yg@030000002PZ=`0X:SL00H0X:SL00@000000?ooo`00000000000`3oool20000
0080oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`003@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01l0oooo100000020:Ngi0030000002W]n@0YkOT0080YkOT00<000000:Nfi000
00001@2W]^@200000080YkGS100000030:Fdh`040000002U]><0YKCS000000H0YKCS00<000000:Fc
hP2U/n800`2U/n83000000030:BbhP000000Y;7R0080Y;7R00<000000:BahP2T/N800P2T/N800`00
0000Y;3Q000000050:B`h@030000002T/>4000000080Y;3P0`0000040:>_h@030000002S[^000000
00H0XjkP00<000000:>]g`2S[Ml01@2S[Ml500000080XJcO00D000000:6/g`2Q[=l0XJcO00000002
0:6[gP030000002QZmh0XJ_N00D0XJ_N00<000000:6Zg@2QZ]d0102QZ]d6000000030:2Yg@000000
X:WM00<0X:WM00<000000:2Xg02PZ=`01P2PZ=`01@000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01`0oooo000<0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0703oool3000000030:Nhi@000000YkOT00<0YkOT00L000000:Ngi02W]n@0YkOT0000
002W]^@0000000H0YkKT0`0000040:Fdh`050000002U]><0YKCS0:Fdh`0000000P2U]><00`000000
YKCS0:Fdh`030:Fdh`030000002U/n80000000<0000000D0Y;;R0000002T/^80Y;;R000000030:Ba
hP030000002T/N80Y;7R00<0Y;7R0P0000050:B`h@030000002T/>400000008000000P2S[n400`00
0000XjoQ0:>_h@030:>_h@8000001`2S[^000`000000XjgO0:>]g`030:>]g`8000000P2Q[Ml01@00
0000XJcO0:6/g`2Q[=l0000000@0XJcO00@000000:6[gP2QZmh000001P2QZmh010000000XJ[M0:6Z
g@2QZ]d5000000030:2Zg@000000000000<0X:WM00<000000:2Yg@2PZMd00P2PZMd00`000000X:SL
0:2Xg0060:2Xg080000000L0oooo0000003oool0oooo0000003oool0000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool06`3oool000`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0I0?ooo`<0
000000D0YkSU0000002W^>D0YkSU000000030:Ngi0030000002W]n@0YkOT0080YkOT0P0000040:Nf
i0<0000000<0YKKT0000002U]><00`2U]><00`000000YKCS0:Fdh`020:Fdh`030000002U]><00000
00<0YKCS1@0000040:BbhP050000002T/^80Y;;R0:BbhP0000000P2T/N800`000000Y;7R0:BahP04
0:BahP040000002T/>40Y;3Q0:B`h@@000000P2S/>401@000000XjoQ0:>_h@2S[n40000000@0XjoQ
00<000000:>^h00000001P2S[^000`000000XjgO0:>]g`03000000050:6]g`000000XJgO0:6]g`00
00000`2Q[=l00`000000XJcO0:6/g`030:6/g`030000002QZmh0000000<0XJ_N1`0000030:2Zg@03
0000002PZ]d0X:[M008000000`2PZMd00`000000X:WM0:2Yg@020:2Yg@030000002PZ=`0X:SL00H0
X:SL0P0000001`3oool000000?ooo`3oool000000?ooo`0000001@3oool2000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo000<0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool05@3oool3000000D0YkSU00<000000:Nh
i@0000000`2W]n@00`000000YkOT0:Ngi0030:Ngi080000000<0YkKT0000000000000P2U]^@01000
0000YKKT0:Ffi00000030:Fdh`030000002U]><0YKCS00<0YKCS200000000`2T/n<000000:BbhP04
0:BbhP070000002T/^80Y;;R0:BbhP000000Y;7R000000060:BahP@000000`2S/>4010000000Xk3Q
0:>`h@0000030:>_h@030000002S[n40XjoQ00<0XjoQ0P0000060:>^h0<00000102Q[Ml01@000000
XJgO0:6]g`2Q[Ml0000000<0XJcO00<000000:6/g`2Q[=l00`2Q[=l5000000030:6[gP0000000000
008000001@2PZ]d010000000X:[M0:2Zg@2PZ]d200000080X:WM00<000000:2Yg@2PZMd00`2PZMd0
0`000000X:SL0:2Xg0050:2Xg080000000L0oooo0000003oool0oooo0000003oool0000000D0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool06P3oool000`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0A0?ooo`<0000000<0YkWV0000000000001@2W^>D010000000YkSU0:Nhi@0000020:Ngi0030000
002W]n@0YkOT00<0YkOT0`0000040:Ffi0040000002U]^@0YKKT000000@0YKCS00<000000:Fdh`00
0000100000000`2U]><00000000000030:Bch`030000002T/n<0000000@0Y;;R00<000000:BbhP2T
/^800P2T/^800`000000Y;7R000000030:BahP<0000000<0Xk7R0000002S/>400`2S/>401@000000
Xk3Q0:>`h@2S/>4000000080XjoQ00<000000:>_h@2S[n400`2S[n4200000080XjkP1@0000000`2R
[^0000000:6]g`040:6]g`040000002Q[Ml0XJgO000000<0XJcO00<000000:6/g`0000001@000000
102QZmh000000000000000020:2[gP030000002PZmh0000000D0X:[M00<000000:2Zg@2PZ]d00P00
00020:2Yg@030000002PZMd0X:WM00<0X:WM00@000000:2Xg02PZ=`0X:SL1000000209nXg0<00000
00D0oooo0000003oool0oooo000000050?ooo`060000003oool000000000003oool00000103oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01T0oooo000<0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool03P3oool3000000@0YkWV0P0000040:Nhi@050000002W^>D0YkSU
0:Nhi@0000000P2W]n@5000000030:Jgi@000000000000D0YKKT00@000000:Ffi02U]^@000000P2U
]><3000000<0YKCS0`0000050:Bch`030000002T/n<0000000@0Y;;R00<000000:BbhP2T/^800P2T
/^800`000000Y;7R00000003000000<0Xk7R0P0000040:>`h@030000002S/>40Xk3Q0080Xk3Q00<0
00000:>_h@0000001@2S[n44000000D0XZkP0P0000050:6]g`040000002Q[Ml0XJgO0:6]g`D00000
0`2Q[=l4000000H0X:_N0P0000050:2Zg@050000002PZ]d0X:[M0:2Zg@0000000`2PZMd010000000
X:WM0:2Yg@2PZMd5000000H0WjSL00D000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0603oool000`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0:
0?ooo`@000001P2W^NH2000000@0YkSU00@000000:Nhi@2W^>D0YkSU100000050:Jgi@8000001@2U
]^@00`000000YKKT00000003000000030:Fdh`000000000000<000000P2T]>@00`000000Y;?S0:Bc
h`030:Bch`040000002T/n<0Y;?S000000<0Y;;R00<000000:BbhP2T/^800P2T/^83000000H0Xk7R
00<000000:>ahP000000102S/>4020000000Xk3Q0:>`h@2S/>4000000:>_h@000000XjoQ10000002
0::_h@030000002R[^00XZkP00@0XZkP00@000000::^h0000000XJgO200000020:6/g`D000000`2P
[=l00`000000X:_N0:2[gP040:2[gP030000002PZmh0000000@0X:[M00D000000:2Zg@2PZ]d0X:[M
000000030:2Yg@@000000`2OZ=d00`000000WjSL09nXg00609nXg0@000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01P0oooo000<0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool01`3oool3000000040:Nji`000000YkWV000000D0YkWV00<000000:NiiP000000
102W^>D300000080Y[OV0P0000060:Jgi@8000000P2U]^@400000080YKKT100000060:Bdi0030000
002T/n<0Y;?S00<0Y;?S00D000000:Bch`2T/n<0Y;?S000000020:BbhPD000000P2S/^<00`000000
Xk7R0:>ahP040:>ahP030000002S/N80000000@0Xk3Q00@000000:>`h@2S/>40Xk3Q100000060::_
h@040000002R[^00XZkP0::^h0L000000`2Q[Ml010000000XJgO0:6]g`2Q[Ml4000000L0X:cO00<0
00000:2[gP2PZmh0102PZmh00`000000X:_N000000040:2Zg@040000002PZ]d0X:[M0:2Zg@D00000
1P2OZ=d00`000000WjSL09nXg00609nXg080000000D0oooo0000003oool0oooo000000050?ooo`03
0000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool05`3oool000/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`040?ooo`<00000
102W^^L2000000D0YkWV00@000000:NiiP2W^NH000000P2W^>D2000000D0Y[OV00<000000:Jgi@2V
]nD00`2V]nD500000080YKKT00@000000:Ffi000000000000P2T]ND00`000000Y;CT000000050:Bd
i08000001@2T/n<00`000000Y;?S0:Bch`05000000D0Xk;S0P0000050:>ahP040000002S/N80Xk7R
000000<0Xk3Q00@000000:>`h@00000000000P2R[n82000000D0XZoQ1@0000030::^h0040000002R
[^00XZkP000000<0XJgO100000020:2/h0030000002P[=l0000000H0X:cO0P0000050:2[gP040000
002PZmh0X:_N000000@0X:[M1@00000209nXg@030000002OZ=d0WjSM00D0WjSM00<0000009nXg02O
Z=`01P2OZ=`2000000050?ooo`00000000000?ooo`000000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?oo
o`002`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00<0000000<0Yk[W0000002W
^^L0102W^^L2000000H0YkWV00<000000:NiiP0000000P0000000`2V]nH000000:JgiP040:JgiP80
000000P0Y[OU00000000000000000:Jgi@000000Y[OU00000080YKKT0`0000050:Bei@8000001@2T
]>@00`000000Y;CT000000040:Bch`<000000P2S/n@00`000000Xk;S000000060:>bh`030000002S
/N80Xk7R00<0Xk7R00@000000:>ahP2S/N8000000P2S/>43000000@0XZoR0P0000000`2R[n400000
00000002000000030::_h@000000000000D0XZkP00<000000::^h02R[^00100000000`2P[>000000
0:2/h0030:2/h0030000002P[=l0000000H0X:cO0P0000060:2[gP030000002PZmh000000080X:[M
0`00000209nYgP030000002OZMh000000080WjSM00<0000009nXg@2OZ=d0102OZ=d00`000000WjSL
09nXg00609nXg08000000`3oool2000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool000/0oooo00<0
00000?ooo`3oool0:03oool400000080Yk_W00@000000:Nji`2W^^L000001@2W^^L00`000000YkWV
0:NiiP040:NiiP8000000P2V^>H010000000Y[OV0:JgiP0000030:JgiP@000001@2V]nD400000080
Y;GU00<000000:Bei@2T]ND00`2T]ND2000000D0Y;CT00<000000:Bdi00000000P2T/n<3000000@0
Xk?T00<000000:>bh`0000001P2S/^<2000000D0Xk7R00<000000:>ahP0000000P0000020::_hP04
0000002R[n80XZoR0::_hP@000001@2R[n400`000000XZoQ000000050::^h08000000P2P[N001000
0000X:cP0:2/h00000050:2/h08000001`2P[=l2000000D0X:_N00<000000:2[gP0000000P000002
09nYgP060000002OZMh0WjWN0000002OZMh000000P2OZ=d00`000000WjSM09nXg@0509nXg@030000
002OZ=`0WjSL00D0WjSL0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool01P000000oooo0?ooo`000000oooo000001H0oooo00<000000?ooo`3oool05@3oool000/0
oooo00<000000?ooo`3oool09@3oool4000000030:Nki`000000Yk_W00<0Yk_W00<000000:Nji`00
00001P2W^^L00`000000YkWV0:NiiP04000000<0Y[SV00<000000:JgiP000000100000020:JgiP80
00000P2V]nD400000080Y;KU00@000000:Bei@2T]ND000001P2T]ND00`000000Y;CT0:Bdi0040:Bd
i0@000000`2S/n@00`000000Xk?T0:>ci0020:>ci08000001P2S/^<2000000<0Xk7R100000020::`
hPL000000P2R[n800`000000XZoQ0::_h@050::_h@8000000P2R[^04000000<0X:gP00@000000:2/
h02P[>0000001P2P[>000`000000X:cO0:2/g`050:2/g`8000000`2PZmh400000080Wj[N00D00000
09nYgP2OZMh0000009nYgP0200000080WjWN00<0000009nXg@0000001`2OZ=d010000000WjSL09nX
g02OZ=`40000000309jWg0000000oooo00<0oooo0P0000040?ooo`030000003oool0oooo0080oooo
00L000000?ooo`3oool0oooo0000003oool0000001D0oooo00<000000?ooo`3oool05@3oool000/0
oooo00<000000?ooo`3oool08`3oool3000000030:Nlj0000000Yk_W0080Yk_W00<000000:Nki`2W
^nL00P2W^nL2000000H0Yk[W0`0000040:JhiP030000002V^>H000000080000000<0Y[OV0000002V
]nH01@2V]nH3000000<0Y;KU00D000000:Bfi@2T]^D0Y;KU000000020:Bei@030000002T]ND0Y;GU
00@0Y;GU00<000000:Bdi02T]>@0100000020:>di0050000002S/n@0Xk?T0:>ci00000001@2S/n@2
000000H0Xk;S2`0000020::_hP030000002R[n80XZoR00@0XZoR00<000000::_h@2R[n40102R[n44
000000<0X:gP00<000000:2]h02P[N000P2P[N000`000000X:cP000000070:2/h0030000002P[=l0
X:cO00@0X:cO1@00000209nZgP060000002OZ]h0Wj[N09nZgP000000WjWN0`00000209nYgP030000
002OZMh000000080WjSM00<0000009nXg@2OZ=d0102OZ=d5000000@0WZOL0P0000030?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000
5P3oool00`000000oooo0?ooo`0D0?ooo`002`3oool00`000000oooo0?ooo`0P0?ooo`<000000P2W
_>P010000000YkcX0:Nlj00000020:Nki`030000002W^nL0Yk_W00<0Yk_W0P0000000`2W^^L00000
00000003000000030:Jii`000000Y[SV0080Y[SV0`0000030:JhiP030000002V]nH0000000<0Y[OV
0`0000000`2T]nH000000:Bfi@030:Bfi@070000002T]^D0Y;KU0:Bfi@000000Y;GU000000060:Be
i@<000000`2S]>@01@000000XkCT0:>di02S]>@000000080Xk?T00<000000:>ci02S/n@00`2S/n@2
00000080Xk;S200000020::`hP030000002R/>80X[3R0080X[3R00<000000::_hP0000001P2R[n80
10000000XZoQ0::_h@2R[n4400000080XJkQ00D000000:2]h02P[N00X:gP000000040:2]h0040000
002P[>00X:cP000000H0X:cP00@000000:2/g`2P[=l0X:cO1000000209n[g`030000002OZ]h0Wj[N
0080Wj[N00<0000009nZgP0000000P00000209nYgP090000002OZMh0WjWN09nYgP000000WjWN0000
002OZ=d0000000<0WjSM0`000000102NZ=d0000009jWg000000509jWg0800000103oool00`000000
oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo000:0?ooo`030000003oool0oooo01h0oooo
0`0000050:Nlj0040000002W_>P0YkcX000000<0Yk_W00<000000:Nki`2W^nL00P2W^nL3000000D0
Y[WW00<000000:Jii`0000000P0000000`2V^>H000000:JhiP030:JhiP030000002V]nH0000000<0
00000P2T]nH010000000Y;OV0:BgiP0000030:Bfi@030000002T]^D0Y;KU0080Y;KU0P0000020:Be
i@D0000000<0XkGU0000002S]>@00P2S]>@01@000000XkCT0:>di02S]>@000000080Xk?T00<00000
0:>ci02S/n@00`2S/n@5000000<0X[7S00@000000::ah`2R/N<000000`2R/>800`000000X[3R0::`
hP020::`hP030000002R[n80000000D0XZoR100000030:6^h@040000002Q[^40XJkQ000000@0X:gP
00<000000:2]h02P[N000P2P[N000`000000X:cP000000050:2/h0D00000102OZml00`000000Wj_O
0000000309nZgP<000000P2OZ]h010000000WjWN09nYgP00000309nYgP040000002OZMh0000009nX
g@@000001@2NZ=d2000000@0WZOL00@0000009jWg02NYm`000000`3oool01P000000oooo0?ooo`00
0000oooo000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01<0oooo000:0?ooo`030000003oool0oooo01`0oooo0P0000020:Nmj@030000002W
_>P0YkcX00@0YkcX00@000000:Nlj02W_>P000000P2W^nL00`000000Yk_W0:Nki`0200000080Y[[X
00@000000:Jii`2V^NL0Y[WW100000000`2V^NL000000:JhiP020:JhiP040000002V^>H0Y[SV0:Jh
iP<000001P2T]nH00`000000Y;OV000000030:Bfi@030000002T]^D0Y;KU0080Y;KU100000040:>e
i@030000002S]ND0000000@0XkCT00D000000:>di02S]>@0XkCT000000020:>ci0030000002S/n@0
00000080000000<0X[;T0000000000001@2R/N<010000000X[7S0::ah`0000030::`hP030000002R
/>80X[3R0080X[3R00@000000::_hP000000XZoR1@0000000`2Q[n8000000:6^h@040:6^h@040000
002Q[^40XJkQ000000<0X:gP00<000000:2]h02P[N000P2P[N0010000000X:cP0000002P[>040000
000409n/h0000000WjcP000000D0Wj_O00<0000009n[g`2OZml00`0000000`2OZ]h0000009nZgP03
09nZgP030000002OZMh0000000@0WjWN1000000709jXg@<00000102NYm`010000000WZOL09jWg000
00030?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`002P3oool00`000000oooo
0?ooo`0J0?ooo`800000102W_NT2000000D0YkcX00D000000:Nlj02W_>P0YkcX000000020:Nki`80
00000`2V^^P500000080Y[WW00D000000:Jii`2V^NL0Y[WW000000020:JhiP@000000P2T^>L20000
00D0Y;OV00@000000:BgiP2T]nH000000`2T]^D010000000Y;KU0000000000020:>fiP030000002S
]ND0XkGU00@0XkGU00<000000:>ei@0000000`2S]>@010000000XkCT0:>di02S]>@6000000@0X[;T
00<000000::ah`2R/N<0102R/N<010000000X[7S0::ah`0000020::`hP030000002R/>80X[3R0080
X[3R100000050:6_hP8000001@2Q[^401@000000XJkQ0:6^h@2Q[^4000000080X:gP00<000000:2]
h02P[N000P2P[N04000000H0WjcP0P00000509n[g`@000000`2OZ]h00`000000Wj[N09nZgP0209nZ
gP030000002OZMh0WjWN00H0000000<0WZWN0000000000000`2NZ=d010000000WZSM0000002NZ=d2
000000@0WZOL00D0000009jWg02NYm`0WZOL000000020?ooo`030000003oool0oooo0080oooo0P00
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0A0?ooo`002P3oool00`000000oooo0?ooo`0G0?ooo`<0000000<0YkgY0000002W_NT0102W_NT2
000000D0YkcX00<000000:Nlj02W_>P0100000020:Jjj080000000<0Y[[X0000000000001@2V^NL0
0`000000Y[WW0:Jii`03000000030:Bhi`000000Y;SW00@0Y;SW00<000000:BgiP2T]nH0102T]nH0
10000000Y;OV0:BgiP0000020:Bfi@800000102S]^H2000000D0XkGU00<000000:>ei@2S]ND01`00
0000102S]>@000000000000000060::bi08000001@2R/N<01P000000X[7S0::ah`2R/N<000000::`
hPD000000P2Q/><00`000000XJoR0:6_hP040:6_hP030000002Q[n80000000@0XJkQ00D000000:6^
h@2Q[^40XJkQ000000020:2]h0D000000P2O[N42000000H0WjcP00@0000009n/h0000000Wj_O1000
000309n[g`050000002OZ]h0Wj[N09nZgP0000000`2OZ]h4000000@0WZWN1000000209jXg@030000
002NZ=d000000080WZSM0P00000409jWg0050000002NYm`0WZOL09jWg00000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo000:0?ooo`030000003oool0oooo01<0oooo
100000020:Nnj@030000002W_NT0000000D0YkgY00<000000:Nmj@0000000`2W_>P400000080Y[_Y
100000040:Jjj0800000102V^NL300000080YKWX00<000000:Bhi`0000001P2T^>L00`000000Y;OV
0:BgiP030:BgiP030000002T]nH0Y;OV00@000001P2S]^H010000000XkGU0:>ei@2S]ND600000080
XkCT1@0000020::ci@030000002R/^@0X[;T00@0X[;T00<000000::bi0000000102R/N<010000000
X[7S0::ah`2R/N<4000000D0XK3S0P0000050:6_hP040000002Q[n80XJoR000000<0XJkQ00@00000
0:6^h@2Q[^40XJkQ1@00000509n]h@8000001P2O[>04000000@0Wj_O00@0000009n[g`2OZml00000
0`2OZ]h<0000000409jYgP000000WZWN00000080WZSM00<0000009jXg@0000000P2NZ=d00`000000
WZSM0000000309jWg0040000002NYm`0WZOL09jWg08000000P3oool00`000000oooo0?ooo`020?oo
o`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0403oool000X0oooo00<000000?ooo`3oool0403oool300000080YkkY00<000000:Nnj@2W
_^T00P2W_^T00`000000YkgY000000050:Nmj@D0000000<0Y[_Y0000000000000`0000000`2V^nT0
0000000000050:Jjj0030000002V^^P000000080Y[WW0`0000040:Fij08000001P2T^>L2000000<0
Y;OV100000020:>giP030000002S]^H0000000<0XkKV1P0000020:>ei@030000002S]ND0XkGU00D0
00001@2R/nD2000000D0X[;T00@000000::bi02R/^@000000`2R/N<010000000X[7S000000000002
0:6ah`8000001P2Q/><00`000000XJoR0:6_hP030:6_hP040000002Q[n80XJoR000000<0XJkQ1000
000209n^hP030000002O[N40000000H0WjgQ00<0000009n/h02O[>000P2O[>0300000080WjcP00<0
000009n[g`2OZml00P2OZml00`000000Wj_O09n[g`0800000080WZWO0P00000609jYgP8000000P2N
Z=d2000000<0WZSM00<0000009jXg@0000000P2NYm`500000080WJKM00<000000?ooo`000000103o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0@0?ooo`002P3oool00`000000oooo0?ooo`0>0?ooo`8000000P2W_nX0
10000000YkkY0:Nnj@0000050:Nnj@030000002W_NT0000000<0YkgY0P0000020:Jlj@<0000000<0
Y[_Y0000002V^nT0102V^nT2000000D0Y[[X100000020:Fij0030000002U^NP0YKWX0080YKWX00<0
00000:Bhi`0000001@2T^>L500000080XkOV00@000000:>giP2S]nH0XkOV1P0000020:>fiP030000
002S]^H000000080XkGU100000020::di@030000002R/nD0000000H0X[?U00<000000::bi02R/^@0
102R/^@00`000000X[;T000000020::ah`<00000102Q/N<2000000H0XK3S0P0000050:6_hP030000
002Q[n80000000<0000000<0WjkR0000002O[^800`2O[^800`000000WjgQ0000000609n]h@D00000
0`2O[>0010000000WjcP0000002OZml70000000409j[g`000000WZWO000000H0WZWO0P00000409jY
gP060000002NZMh000000000002NZ=d00000102NZ=d7000000D0WJKM00<000000?ooo`0000001@3o
ool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0?0?ooo`002@3oool00`000000oooo0?ooo`0=0?ooo`<00000102W_nX0
10000000YkkY0:Nnj@0000050:Nnj@80000000<0YkgY000000000000100000000`2V_>T000000:Jk
j@020:Jkj@030000002V^nT0Y[_Y00<0Y[_Y00<000000:Jjj02V^^P0100000020:Fjj0050000002U
^NP0YKWX0:Fij0000000102U^NP2000000@0Y;SW0`0000000`2S^>L000000:>giP06000000030:>g
iP000000000000D0XkKV00<000000:>fiP0000000P0000020::di@030000002R]>D0X[CU0080X[CU
0P0000060::ci@8000001@2R/^@00`000000X[;T0000000200000080XK7S00<000000:6ah`2Q/N<0
0`2Q/N<00`000000XK3S0:6`h`040:6`h`030000002Q/><000000080XJoR1000000209n_hP040000
002O[^80WjkR000000D0WjkR0P00000509n]h@@000000P2O[>090000000309j[g`000000WZ_O00<0
WZ_O00@0000009jYg`2NZMl000001@2NZMl2000000@0WZWN00<0000009jYgP2NZMh00`0000000`2N
Z=d000000000000200000080WJOM0`00000709fVg@030000003oool0000000@0oooo00H000000?oo
o`3oool000000?ooo`0000050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03P3o
ool000T0oooo00<000000?ooo`3oool02@3oool4000000<0YkoZ00<000000:NojP2W_nX00P2W_nX0
10000000YkkY0:Nnj@0000040:Nnj@D000000`2V_>T010000000Y[cY0:Jlj@0000020:Jkj@030000
002V^nT0Y[_Y00<0Y[_Y0`0000040:Fjj0040000002U^^P0YK[X00000080YKWX00<000000:Fij02U
^NP00`2U^NP2000000030:Bhi`000000000000H000000P2S]nH00`000000XkOV0:>giP030:>giP80
00000P2S]^H400000080X[GV00@000000::di@2R]>D00000102R]>D00`000000X[?U000000050::c
i@8000000`2R/^@400000080XK;T00@000000:6ah`2Q/N<000001P2Q/N<00`000000XK3S0:6`h`03
0:6`h`030000002Q/><00000008000000P2O[n801@000000WjoR09n_hP2O[n8000000080WjkR00<0
000009n^hP2O[^80102O[^820000000309n]h@000000000000L0000000<0WjcP0000000000000P00
000209j[h0050000002NZml0WZ_O09j[g`000000102NZml00`000000WZWO0000000609jYg`050000
002NZMh0WZWN09jYgP0000000`2NZMh400000080WJOM00D0000009fWg@2MYmd0000009fWg@020000
00L0WJKM00<000000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000103o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00h0oooo00090?ooo`030000003oool0
oooo00H0oooo100000000`2W`>/00000000000040:NojP030000002W_nX0YkoZ0080YkoZ00<00000
0:Nnj@0000001@0000000`2V_NX000000:Jlj@040:Jlj@050000002V_>T0Y[cY0:Jlj@0000000P2V
^nT5000000030:Fkj@000000000000@0YK[X00D000000:Fjj02U^^P0YK[X000000020:Fij0040000
002U^NP0YKWX0:Fij0H000000P2S^>L010000000XkSW0:>hi`0000030:>giP030000002S]nH0XkOV
0080XkOV100000030::eiP040000002R]NH0X[GV000000<0X[CU00<000000::di@2R]>D00P2R]>D2
000000H0X[?U100000030:6bi0040000002Q/^@0XK;T00000080XK7S00<000000:6ah`2Q/N<0102Q
/N<010000000XK3S0:6`h`2Q/><400000080WjoS00@0000009n_hP2O[n800000102O[n8010000000
WjkR09n^hP00000309n^hPL000000`2O[N4500000080WZ_P00D0000009j[h02NZn00WZ_P00000003
09j[g`030000002NZml0WZ_O00<0WZ_O0P00000609jYg`8000000P2NZMh7000000<0WJOM00<00000
09fWg@0000000`2MYmd00`000000WJKM09fVg@0609fVg@800000103oool00`000000oooo0?ooo`02
0?ooo`800000103oool00`000000oooo0?ooo`0H0?ooo`8000003`3oool000T0oooo00<000000?oo
o`3oool0103oool2000000H0Yl3[0P0000040:NojP040000002W_nX0YkoZ0:NojPD000001@2V_NX0
0`000000Y[cY0:Jlj@030:Jlj@030000002V_>T0Y[cY00@000001@2U^nT00`000000YK_Y00000004
0:Fjj0040000002U^^P0YK[X0:Fjj0L0000000<0XkWX0000000000001@2S^>L010000000XkSW0:>h
i`0000020:>giP030000002S]nH0XkOV0080000000<0X[KW000000000000102R]NH01@000000X[GV
0::eiP2R]NH000000080X[CU00<000000::di@2R]>D00`2R]>D00`000000X[?U0::ci@0500000003
0:6ci@000000XK;T00<0XK;T00L000000:6bi02Q/^@0XK;T0000002Q/N<0000000H0XK7S10000003
09n_h`040000002O[n<0WjoS000000<0WjoR00@0000009n_hP2O[n80WjoR2@0000000`2O[^800000
09n]h@0209n]h@@000000P2N[>400`000000WZ_P09j[h00209j[h0050000002NZn00WZ_P09j[h000
00000P2NZml00`000000WZ_O09j[g`0309j[g`030000002NZMl0000000<0WZWO1`000000102MZ=h0
000009fXgP2MZ=h2000000<0WJOM0P00000409fWg@030000002MY]d0WJKM00H0WJKM0P0000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?oo
o`<0000000<0oooo0000003oool03P3oool000T0oooo00<000000?ooo`3oool01@3oool00`000000
Yl3[0:O0j`040:O0j`030000002W`>/0000000<0YkoZ1@000000102V_^/000000:JmjP0000050:Jm
jP8000001@2V_>T200000080YKcZ00<000000:Fkj@0000001@2U^nT010000000YK_Y0000002U^^P9
000000H0XkWX0P0000040:>hi`060000002S^>L0XkSW0:>hi`000000XkOV0`0000030::fi`030000
002R]^L0000000<0X[GV00<000000::eiP2R]NH00P2R]NH00`000000X[CU000000050::di@<00000
102Q/nD010000000XK?U0:6ci@0000030:6bi0030000002Q/^@0XK;T0080XK;T0P0000040:6ah`<0
000000<0Wk3T0000002O[n<00`2O[n<010000000WjoS09n_h`2O[n<700000080WjoR1000000409n^
hP@00000102N[>400`000000WZcQ0000000409j[h0030000002NZn00WZ_P0080WZ_P00<0000009j[
g`0000001@2NZml80000000409fYg`000000000009fXgP8000000`2MZ=h00`000000WJSN00000002
09fWg@030000002MYmd0WJOM00<0WJOM0P00000709fVg@<00000103oool00`000000oooo0?ooo`02
0?ooo`800000103oool00`000000oooo0?ooo`0A0?ooo`<00000103oool00`000000oooo0?ooo`0=
0?ooo`002@3oool00`000000oooo0?ooo`060?ooo`030000002W`>/0Yl3[00@0Yl3[00<000000:O0
j`0000001@0000040:Jnj`030000002V_NX0000000D0Y[gZ0P0000020:Jlj@<00000102U_>X20000
00<0YK_Y1P0000020:Fjj0@000000P2S^^T2000000D0XkWX00<000000:>ij00000000`2S^>L01000
0000XkSW0:>hi`2S^>L3000000H0X[KW0P0000040::eiP050000002R]NH0X[GV0::eiP0000000P2R
]>D5000000030:6diP000000000000@0XK?U00@000000:6ci@2Q/nD000000`2Q/^@00`000000XK;T
0:6bi0020:6bi0030000002Q/N<0000000<000000`2O/>@200000080WjoS1`00000209n_hP040000
002O[n80WjoR09n_hP@000000P2O[^840000000309j]hP000000000000D0WZcQ00@0000009j/h@2N
[>4000000`2NZn000`000000WZ_P09j[h00209j[h0030000002NZml0WZ_O00D000000P2MZ^001`00
0000WJWO09fYg`000000WJWO0000002MZMl01000000409fXgP040000002MZ=h0000009fWg@800000
1@2MYmd2000000<0WJKM1000000209bVg@030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000030?ooo`030000003oool0oooo00d0oooo100000070?ooo`030000
003oool0oooo00d0oooo00080?ooo`030000003oool0oooo00P0oooo00<000000:O0j`2W`>/00P2W
`>/6000000<0Y[k[00<000000:Jnj`2V_^/00P2V_^/2000000D0Y[gZ100000000`2U_>X000000000
0009000000<0YK_Y00<000000:Fkj@0000000P0000000`2S^^T000000:>jj@040:>jj@030000002S
^NP0XkWX00<0XkWX00@000000:>ij02S^NP000000P2S^>L400000080X[OX0P0000050::fi`030000
002R]^L0000000<0X[GV00@000000::eiP2R]NH0X[GV100000050:6diP8000001@2Q/nD010000000
XK?U0:6ci@0000030:6bi0040000002Q/^@0XK;T0:6bi0<000000`2O/>@700000080WjoS00<00000
09n_h`2O[n<00P2O[n<00`000000WjoR09n_hP0300000080WjoR1000000509j]hP8000001@2N[>40
1@000000WZcQ09j/h@2N[>4000000080WZ_P00<0000009j[h02NZn000P2NZn04000000H0WJ[P00<0
000009fYg`2MZMl00P00000309fYg`8000001@2MZ=h01P000000WJSN09fXgP000000WJOM000000@0
WJOM1P00000609bVg@8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080
oooo00<000000?ooo`3oool02P3oool3000000`0oooo00<000000?ooo`3oool0303oool000P0oooo
00<000000?ooo`3oool02@3oool8000000030:Jok0000000Y[k[0080Y[k[00<000000:Jnj`2V_^/0
0`2V_^/2000000030:JmjP000000000000H000000`2U_>X00`000000YKcZ0:FljP020:FljP040000
002U^nT0YK_Y0:Fkj@@000000P2S^nX00`000000Xk[Y000000050:>jj@030000002S^NP0XkWX00@0
XkWX00<000000:>ij00000000P0000000`2R]nP000000::gj0040::gj0030000002R]^L0X[KW00<0
X[KW00@000000::fi`2R]^L000000P2R]NH400000080XKGW0P0000060:6diP800000102Q/nD01000
0000XK?U0:6ci@2Q/nD=000000<0Wk3T00<0000009n`i0000000102O[n<010000000WjoS09n_h`2O
[n<800000080WZkS00<0000009j]hP2N[N80102N[N800`000000WZgR0000000409j/h@050000002N
[>40WZcQ09j/h@0000000P2NZn0500000080WJ_Q0P00000609fZh0<0000000<0WJWO0000002MZMl0
0P2MZMl3000000@0WJSN1@00000209fWg@@000000P2LYmh00`000000W:KM09bVg@0709bVg@800000
0P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool01P3oool3000000l0oooo00<000000?ooo`3oool0303oool000P0oooo00<000000?ooo`3oool0
2P3oool2000000D0Y[o/00@000000:Jok000000000000P2V_^/00`000000Y[k[0:Jnj`020:Jnj`D0
00000`2U_N/00`000000YKg[000000030:FljP030000002U_>X0YKcZ0080YKcZ100000030:>kjP07
0000002S^nX0Xk_Z0:>kjP000000Xk[Y000000050:>jj@040000002S^NP0XkWX0:>ij0@000000P2R
^>P00`000000X[OX000000050::gj0800000102R]^L00`000000X[KW0::fi`04000000H0XKGW0P00
00030:6diQ0000001@2O/ND2000000D0Wk3T00@0000009n`i02O/>@000000`2O[n<8000000H0WZkS
00<0000009j]hP2N[N80102N[N8010000000WZgR09j]hP00000309j/h@040000002N[>40WZcQ09j/
h@D000001@2MZn400`000000WJ[P0000000509fZh08000000P2MZMl00`000000WJWO09fYg`040000
00<0WJSN2000000309bWgP050000002LYmh0W:ON09bWgP000000202LY]d2000000<0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo0`00
000B0?ooo`030000003oool0oooo00`0oooo00080?ooo`030000003oool0oooo00/0oooo00<00000
0:Jok02V_n`0102V_n`00`000000Y[o/0:Jok00700000080YKk/0P0000040:Fmj`040000002U_N/0
YKg[000000<0YKcZ00D000000:FljP00000000000:>lj`02000000@0Xk_Z00L000000:>kjP2S^nX0
Xk_Z0000002S^^T0000000D0Xk[Y100000020::hj0030000002R^>P0X[SX0080X[SX0P0000060::g
j08000000P2R]^L400000080XKKW00<000000:6ei`0000000`2Q]NL700000080XKCV00<000000:6d
iP0000000`2Q/nD400000080Wk;U0P00000609nai@8000001@2O/>@010000000Wk3T0000002O[n<6
00000080WZoS0P00000609j^h`8000001@2N[N8010000000WZgR09j]hP00000309j/h@@000000P2M
[>400`000000WJ_Q0000000609f[h@800000102MZ^040000000509fYg`000000WJWO0000002MZMl0
200000000`2LZ=h0000009bXgP0200000080W:ON0`00000309bWgP030000002LY]d0W:KM00L0W:KM
0P0000020?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo0`00000E0?ooo`030000003oool0oooo00`0oooo00080?ooo`030000003oool0oooo00`0
oooo0P0000030:Jok0L0000000<0YKk/0000002U_^`0102U_^`00`000000YKg[0:Fmj`030:Fmj`04
0000002U_N/0YKg[00000080YKcZ0P0000040:>lj`800000102S^nX01P000000Xk_Z0:>kjP2S^nX0
00000:>jj@H0000000<0X[WY0000002R^>P00`2R^>P01`000000X[SX0::hj02R^>P000000::gj000
00000`2R]nPB000000<0XKGW00<000000:6diP2Q]>H00`2Q]>H00`000000XKCV0000000300000003
09nbi@000000Wk;U00@0Wk;U0P00000509nai@030000002O/ND0000000@0Wk3T1P0000000`2N[n<0
000009j_h`0309j_h`030000002N[^<0000000D0WZkS00<0000009j^h`0000001@2N[N800`000000
WZgR000000030000000309f/h@000000WJcQ00<0WJcQ00<0000009f[h@0000001P2MZn43000000<0
WJ[P0P0000001@2MZ^00000009fYg`000000WJWO00D0000000@0W:SO0000002LZ=h000000P2LZ=h0
0`000000W:SN000000030000000309bWgP000000W:ON00@0W:ON00<0000009bVg@2LY]d01P2LY]d0
1@000000oooo0000003oool0000000D0oooo00@000000?ooo`3oool0oooo1000000H0?ooo`030000
003oool0oooo00`0oooo00080?ooo`030000003oool0oooo00d0oooo100000030:Jok080000000D0
YKo/0000002U_^`0YKk/000000050:Fnk0030000002U_N/0YKg[00<0YKg[00<000000:Fmj`000000
0P0000000`2S_>/000000:>lj`030:>lj`030000002S_>/0000000<0Xk_Z00@000000:>kjP2S^nX0
Xk_Z0`0000050::ij@040000002R^NT000000::hj0l000000P2Q]nP010000000XKKW0:6fi`000004
0:6fi`8000001P2Q]NL200000080XKCV1000000209nciP040000002O/^D0Wk;U000000D0Wk;U0P00
000509nai@030000002O/ND0000000D000000`2N/>@010000000WZoS09j_h`00000509j_h`800000
1P2N[^<2000000<0WZgR1000000209f]hP040000002M[>40WJcQ000000D0WJcQ0P00000709f[h@80
00000`2MZ^000`000000WJ[P0000000400000080W:SO00@0000009bXg`000000W:SO0`00000309bX
gP030000002LZ=h0W:SN0080000000<0W:ON0000002LYmh0102LYmh00`000000W:KM09bVg@0509bV
g@<0000000<0oooo0000000000001@3oool7000001T0oooo00<000000?ooo`3oool0303oool000L0
oooo00<000000?ooo`3oool0403oool00`000000Y[o/0:Jok002000000070:Fok0000000YKo/0:Fo
k0000000YKk/000000060:Fnk0030000002U_N/0YKg[00@000000P2S_N/00`000000Xkc[00000005
0:>lj`040000002S_>/000000:>kjQ4000000P2R^>P00`000000X[SX0::hj0020::hj0@00000102Q
]nP010000000XKOX0:6gj00000020:6fi`030000002Q]^L0XKKW0080XKKW0P0000040:6ei`D00000
0`2O/nH01`000000Wk?V09nciP2O/nH0000009nbi@0000001P2O/^D010000000Wk7U09nai@2O/ND7
00000080W[3T00D0000009j`i02N/>@0W[3T0000000209j_h`030000002N[n<0WZoS00@0WZoS00<0
000009j^h`2N[^<0102N[^<500000080WJgR00D0000009f]hP2M[N80WJgR0000000209f/h@030000
002M[>40WJcQ00<0WJcQ00<0000009f[h@0000001@2MZn430000000309fZh0000000000000H00000
0`2LZ=l010000000W:SO0000002LZ=l2000000@0W:SN100000000`2LYmh000000000000609bWgP03
0000002LY]d0W:KM00@000000`2KYMd2000000040?ooo`000000oooo0?ooo`<000001@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00`0oooo00070?ooo`030000003oool0oooo0140
oooo0P0000040:Fok0030000002U_n`0YKo/00<000001@2U_^`3000000030:>mj`00000000000100
000000<0X[[Z0000002R^^X0102R^^X00`000000X[WY0::ij@020::ij@050000002R^NT0X[WY0::i
j@0000000P2R^>P400000080XKSY00<000000:6gj02Q]nP00`2Q]nP010000000XKOX0:6gj0000002
0:6fi`030000002Q]^L0XKKW0080XKKW1P00000209ndi`030000002O]>L0000000<0Wk?V00D00000
09nciP2O/nH0Wk?V0000000209nbi@030000002O/^D0Wk;U00<0Wk;U10000000102N/ND000000000
0000000209jai@050000002N/>@0W[3T09j`i00000000`2N/>@00`000000WZoS0000000609j_h`80
00000P2N[^<400000080WJkS00D0000009f]hP2M[N80WJgR0000000409f]hP040000002M[>40WJcQ
000000D0WJcQ0P00000409f[h@H0000000<0W:WP0000002LZN000P2LZN02000000<0W:SO00H00000
09bXg`000000000009bXg`00000409bXgP8000000P2LZ=h2000000H0W:ON1000000709^Ug@030000
003oool0000000<000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0303oool000L0oooo00<000000?ooo`3oool04P3ooolD000000<0Xkg[00<0
00000:>mj`2S_N/00P2S_N/00`000000Xkc[0:>lj`0400000080X[_[00@000000::jjP2R^^X00000
1@2R^^X00`000000X[WY0::ij@020::ij@030000002R^NT0X[WY00@000001@2Q^>T2000000@0XKOX
00H000000:6gj02Q]nP0XKOX0000002Q]^L50000000309nej0000000000000D0WkCW00@0000009nd
i`2O]>L000000P2O/nH00`000000Wk?V09nciP0209nciP040000002O/^D0000009nbi@@0000000<0
W[;V0000000000000P00000209jai@050000002N/ND0W[7U09jai@0000000P2N/>@00`000000W[3T
09j`i00209j`i0030000002N[n<0000000D0WZoS1000000309f^h`040000002M[^<0WJkS000000@0
WJgR00<0000009f]hP2M[N800P2M[N800`000000WJcQ0000000309f/h@d0000000<0W:WP0000002L
ZN000P2LZN020000000709bYh0000000W:SO0000002LZ=l0000009bXg`020000000309bXg`000000
W:SN0080000000<0W:SN000000000000100000000`2LYmh000000000000200000080VjKN00<00000
09^Ug@2KYMd01`2KYMd3000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00/0oooo00070?ooo`030000003oool0oooo01<0oooo0P0000040:Fo
k0030000002U_n`0YKo/00<000001@2S_^`300000080Xkg[00<000000:>mj`2S_N/00P2S_N/30000
00<0X[_[00L000000::kj`2R^n/0X[_[0000002R^^X0000000D0X[[Z0P0000020::ij@@000000P2Q
^NX00`000000XKSY000000050:6hj@800000102Q]nP00`000000XKOX0:6gj004000000D0WkGX0P00
000409ndi`040000002O]>L0WkCW000000<0Wk?V00@0000009nciP2O/nH0Wk?V1000000309jbiP@0
00001@2N/ND01`000000W[7U09jai@2N/ND0000009j`i0000000102N/>@010000000WZoS0000002N
[n<40000000309f^i0000000000000D0WJkS00@0000009f^h`2M[^<000000`2M[N8010000000WJgR
09f]hP2M[N8?00000080W:[Q00D0000009bZh@000000W:WP0000000209bYh0<0000000<0W:WP0000
002LZ=l00P00000309bXg`050000002LZ=l000000000002LZ=h00P0000000`2LZ=h0000000000004
000000H0VjKN00<0000009^Ug@2KYMd01`2KYMd010000000oooo0000000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`001`3oool0
0`000000oooo0?ooo`0E0?ooo`030000002U_n`0YKo/00@000000P2S_nd2000000D0Xkk/00<00000
0:>nk00000000P2S_N/4000000030::lk0000000000000@0X[_[00@000000::kj`2R^n/0X[_[0P00
00050::jjP@000000P2Q^NX00`000000XKWZ0:6ijP020:6ijP8000001@2Q^>T00`000000XKSY0000
00020:6gj0@000000P2O]^T2000000D0WkGX0P00000509ndi`040000002O]>L0WkCW00000080Wk?V
1000000209jci`D000000P2N/^H00`000000W[;V0000000409jai@070000002N/ND0W[7U09jai@00
0000W[3T0000000209j`i0H000001@2M[^@2000000D0WJkS00@0000009f^h`2M[^<0WJkS1`000000
0`2M[N80000000000004000000@0W:_R0`00000209bZh@0=0000002LZ^4000000000002LZN000000
09bYh0000000W:WP0000002LZN00000009bYh002000000@0W:SO00<0000009bXg`0000001@000004
09^Wg`030000002KY]h0000000H0VjKN00<0000009^Ug@2KYMd01`2KYMd2000000030?ooo`000000
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00/0oooo00070?ooo`030000003oool0oooo01H0oooo0P0000030:>ok@050000002S_nd0Xko]
0:>ok@0000001@2S_^`00`000000Xkk/0:>nk002000000030::lk0000000X[c/00<0X[c/0P000003
0::kj`030000002R^n/0X[_[0080X[_[0P0000000`2R^^X0000000000003000000050:6jj`000000
XKWZ0:6ijP0000001@2Q^NX00`000000XKSY0:6hj@030:6hj@030000002Q^>T00000008000000P2O
]^T00`000000WkKY09nfj@0209nfj@8000001@2O]NP2000000@0WkCW00<0000009ndi`2O]>L01000
000409jci`<000001@2N/^H010000000W[;V09jbiP00000309jai@040000002N/ND0W[7U09jai@D0
0000102M[n@2000000H0WJkT0P00000209f^h`L000000P2M[N8500000080W:cR0P00000609b[hP80
00000`2LZ^420000000509bZh@00000000000000002LZN000P00000209bYh0<000000`2LZ=l80000
00H0VjOO00<0000009^VgP0000001P2KY]h00`000000VjGM09^Ug@0709^Ug@050000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool02`3oool000L0oooo00<000000?ooo`3oool05`3oool8000000030:>ok@000000Xkk/
00@0Xkk/0P000000102R_Nd000000::lk00000040::lk0030000002R_>`0000000<0X[_[00@00000
0::kj`2R^n/0X[_[0`0000040:6jj`040000002Q^^/0XK[[00000080XKWZ00<000000:6ijP2Q^NX0
0`2Q^NX00`000000XKSY0:6hj@0400000080WkOY00@0000009nfj@2O]^T00000102O]^T2000000D0
WkGX00<0000009nej00000000P2O]>L400000080W[CW0P000000102N/nL0000000000000000209jc
i`030000002N/^H0W[;V00@0W[;V00<0000009jbiP0000000`2N/ND400000080WK3U0P00000309f_
i0h000000P2M[^<010000000WJkS09f^h`2M[^<5000000D0W:cR0P00000309b[hP030000002LZn80
W:_R008000000`2LZ^402P000000W:[Q09bZh@2LZ^40000009bYh0000000W:WP0000002LZN090000
0080VjSO0`00000809^Wg`030000002KY]h0000000H0VjKN00<0000009^Ug@2KYMd01@2KYMd40000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00/0oooo00060?ooo`030000003oool0oooo01T0oooo00<000000:>ok@2S_nd00P2S_nd00`00
0000Xko]0000000?00000080X[c/00<000000::lk00000000P2R^n/400000080X;_/00<000000:6j
j`2Q^^/00`2Q^^/01P000000XK[[0:6jj`000000XKWZ000000D0XKWZ0`00000309ngj@070000002O
]nT0WkOY09ngj@000000WkKY0000000509nfj@030000002O]NP0WkGX00<0WkGX00<0000009nej000
00000P0000000`2N]>L0000009jdi`0309jdi`<000001P2N/nL00`000000W[;V09jbiP0309jbiP03
0000002N/^H0000000h000000`2M[n@00`000000WJkT09f^i00409f^i0030000002M[^@0000000<0
WJkS1000000209b]h`030000002L[>80000000H0W:cR0P000000102LZn8000000000002LZn840000
000309bZh@000000000000<0W:[Q2`000000102KZ=l000000000002KZ=l2000000<0VjSO00<00000
09^Wg`2KYml01P2KYml00`000000VjKN0000000509^VgP040000002KYMd0VjGM09^Ug@@000000P2J
YMd200000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00/0oooo00060?ooo`030000003oool0oooo01X0oooo00<000000:>ok@2S_nd00P2S
_nd00`000000Xko]0:>ok@03000000@0X[g]00L000000::mk@2R_Nd000000::lk0000000X[c/01h0
000000<0WkSZ000000000000102O]nT010000000WkOY09ngj@00000209nfj@030000002O]^T0WkKY
00<0WkKY00<0000009nej02O]NP01000000209jej0030000002N]>L0W[CW01P000000P2M/>D00`00
0000WK3U09f`i@0309f`i@030000002M[n@0WJoT00D0WJoT00<0000009f^i02M[^@00`2M[^@60000
000309b]h`000000W:gS00<0W:gS00@0000009b/hP2L[>8000001@2L[>820000000409b[hP000000
W:_R09b[hP80000000<0W:_R000000000000300000000`2KZN000000000000020000000309^Xg`00
0000000000D0VjSO00<0000009^Wg`2KYml01P2KYml010000000VjKN09^VgP00000209^VgPH00000
1`2JYMd01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00/0oooo00060?ooo`030000003oool0oooo01/0oooo00<000000:>ok@2S
_nd0100000020::nk@030000002R_Nd0X[g]0080X[g]00@000000::mk@2R_Nd0X[g]0P0000000`2R
_>`000000000000200000080X;c/00@000000:2kk02P^n`000000`2P^n`00`000000X;_/00000003
0:6jj`040000002Q^^/0XK[[0:6jj`<000000P2O^>XU00000080W[CW00<0000009jci`2N/nL00`2N
/nL500000080WK7V00D0000009faiP2M/NH0WK7V0000000209f`i@030000002M/>D0WK3U00@0WK3U
00<0000009f_i02M[n@0102M[n@60000000509b^i0000000W:kT09b^i00000000`2L[N<00`000000
W:gS09b]h`0209b]h`030000002L[>80000000H0W:cR0`0000000`2LZn8000000000000209b[hP<0
00000`2JZ^45000000<0VjWP0`0000000`2KZN0000000000000809^Xg`030000002KYml0VjOO00D0
VjOO1P00000409ZVgP030000002JYMd0VZGM00H0VZGM00<000000?ooo`3oool00P3oool2000000D0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0:0?ooo`001P3oool00`000000oooo
0?ooo`0L0?ooo`P0000000<0X[k]0000002R_Nd00`2R_Nd00`000000X[g]0::mk@03000000<0X;c/
00L000000:2lk02P_>`0X;c/0000002P^n`0000000@0X;_/00<000000:2kk00000000P2Q^^/40000
0080WkW[0P00000409nhjP030000002O^>X0000000<0WkOY00@0000009ngj@2O]nT0WkOY1P000002
09jfj@030000002N]^T0000000<0W[GX1@0000000`2N]>L0000009jdi`0409jdi`H000000P2M/^L0
0`000000WK;W0000000309faiP050000002M/NH0WK7V09faiP0000000P2M/>D00`000000WK3U09f`
i@0309f`i@030000002M[n@0WJoT00D0000000<0VjoU0000002L[^@00`2L[^@010000000W:kT09b^
i000000309b]h`030000002L[N<0W:gS00<0W:gS0P00000509b/hPT0000000<0VZ_R0000002JZ^40
1000000209ZZh@8000000`2KZN001P000000VjWP000000000000VjWP000000P0VjSO00@0000009^W
g`2KYml0VjOO100000001@2IYml0000009ZVgP2JY]h0000000D0VZKN00<0000009ZUg@2JYMd01`2J
YMd00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00X0oooo00060?ooo`030000003oool0oooo01d0oooo00<000000::nk@2R_^d00P2R_^d0
0`000000X[k]0000000800000080X;g]0P0000030:2lk0070000002P_>`0X;c/0:2lk0000000X;_/
000000030:2kk0030000002P^n`000000080000000<0WkW[0000002O^N/0102O^N/00`000000WkSZ
09nhjP0309nhjP030000002O^>X000000080WkOY1000000209jgjP8000001@2N]^T00`000000W[KY
00000004000000<0W[GX00<0000009jdi`000000100000000`2L/nP000000000000509fbi`040000
002M/^L0WK;W00000080WK7V00<0000009faiP2M/NH00P2M/NH00`000000WK3U0000000509f`i@<0
00001@2K[nD00`000000VjoU0000000309b^i0050000002L[^@0W:kT09b^i00000000P2L[N<00`00
0000W:gS09b]h`0309b]h`030000002L[>80000000<0W:cR1P0000000`2JZn800000000000060000
000309ZZh@000000VZ[Q00<0000000<0VjWP0000000000000P00000309^Yh0030000002KZ=l0VjSO
00<0VjSO1`00000609VWg`040000002JY]h0VZKN000000D0VZKN00<0000009ZUg@2JYMd01P2JYMd0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0:0?ooo`001P3oool00`000000oooo0?ooo`0N0?ooo`8000000`2R_^d00`00
0000X[k]0::nk@0800000080X;g]00<000000:2lk02P_>`00P2P_>`010000000X;c/0:2lk02P_>`2
000000030:2kk00000000000008000000P2O^^`010000000WkW[09nij`00000409nij`030000002O
^>X0WkSZ00<0WkSZ00<0000009nhjP0000000P0000000`2N]nX0000009jgjP0409jgjP030000002N
]^T0W[KY00<0W[KY0`00000309jej0040000002N]NP0W[GX09jej0<000001@2L/nP00`000000W;?X
0000000409fbi`040000002M/^L0WK;W00000080WK7V00<0000009faiP2M/NH00P2M/NH010000000
WK3U0000002M/>D40000000309^`iP000000000000D0VjoU00<0000009^_i@000000102L[^@01@00
0000W:kT09b^i02L[^@000000080W:gS00<0000009b]h`2L[N<00P2L[N<80000000309Z/h`000000
000000<000000`2JZn8200000080VZ[Q00@0000009ZZh@000000VZ[Q1000000609^Yh0H00000102I
Yn000`000000VJOO09VWg`0609VWg`050000002JY]h0VZKN09ZVgP000000102JY]h00`000000VZGM
09ZUg@0709ZUg@030000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool02P3oool000D0oooo00<000000?ooo`3oool08@3oool2000000040::nk@00
0000000000000080X;k^00H000000:2mk@2P_Nd0X;g]0000002P_Nd6000000030:2lk0000000X;c/
0080X;c/0`00000309njk0070000002O^^`0Wk[/09njk0000000WkW[0000000509nij`030000002O
^>X0WkSZ00@000000P2N^>/00`000000W[OZ0000000509jgjP80000000<0W[KY0000000000000P00
000209jfj@030000002N]NP0W[GX00@000000P2L]>T2000000D0W;?X0P00000409fbi`050000002M
/^L0WK;W09fbi`0000000P2M/NH00`000000WK7V00000005000000D0Vk3V0P00000609^_i@030000
002K[nD0000000<0W:kT00D0000009b^i02L[^@0W:kT0000000209b]h`D000000P2J[>@200000003
09Z/h`000000000000H000000`2JZn840000000409ZZh@000000000009ZZh@@000000`2KZN040000
0080VJSQ00<0000009VWh02IYn001P2IYn000`000000VJOO09VWg`0609VWg`040000002JY]h0VZKN
000000D0VZKN00<0000009ZUg@2JYMd01@2JYMd2000000@0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo00050?ooo`030000003oool0oooo
0280oooo100000030:2nkP<000000P2P_Nd010000000X;g]0:2mk@2P_Nd2000000030:2lk0000000
000000<000000P2O^nd00`000000Wk[/09njk00209njk0040000002O^^`0Wk[/00000080WkW[00<0
000009nij`2O^N/00P2O^N/3000000<0W[S[00L0000009jhj`2N^>/0W[S[0000002N]nX0000000@0
W[OZ0`00000309jfj@L000001P2L]>T00`000000W;?X09bcj00309bcj0030000002L/nP0000000@0
WK;W00<0000009fbi`2M/^L01@00000409^aiP8000001P2K/>H2000000D0VjoU00@0000009^_i@2K
[nD000000P2L[^@00`000000W:kT00000006000000<0VZcT1`000000102J[><000000000002J[><2
000000<0VZ_R00<0000009Z[hP2JZn803000000609VXh@030000002IYn00VJOP00H0VJOP00<00000
09VWg`2IYml01P2IYml01@000000VZKN09ZVgP2JY]h0000000@0VZKN00@0000009ZUg@2JYMd0VZGM
1000000209RTg@030000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool02P3oool000D0oooo00<000000?ooo`3oool08`3oool6000000060:2nkP00
0000X;k^0000002P_Nd000000P2P_Nd500000080Wk_]00<0000009nkk@0000001@0000000`2O^^`0
000009njk00209njk0030000002O^N/0000000D0000000<0WKW/0000002N^>/00P2N^>/00`000000
W[S[09jhj`0209jhj`80000000D0W[OZ000000000000000009jgjP07000000<0W;GY00<0000009bd
j@0000001@2L]>T00`000000W;?X09bcj00409bcj0030000002L/nP000000080WK;W1000000209^b
i`030000002K/NH0000000D0Vk7V00<0000009^`iP2K/>H0102K/>H00`000000Vk3V0000000409^_
i@030000002K[nD0VjoU00D000000`2J[N@700000080VZcT10000000102J[><000000000002J[><3
00000080VZ_R00@0000009Z[hP2JZn80VZ_R1P00000409VYh@030000002IZ>40VJSQ00H0VJSQ00<0
000009VWh02IYn001P2IYn000`000000VJOO09VWg`0609VWg`040000002JY]h0VZKN09ZVgPP00000
1P2HY=d00`000000oooo0?ooo`020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0:0?ooo`001@3oool00`000000oooo0?ooo`0T0?ooo`80000000<0
X;k^0000002P_^h02000000209nlkP030000002O_>h000000080Wk_]00<0000009nkk@2O^nd00P2O
^nd00`000000Wk_]0000000;00000080WKW/00<0000009fik00000000P2N^>/00`000000W[S[09jh
j`0209jhj`<0000000<0W[OZ0000000000000P00000209bfjP040000002L]NT0W;GY000000@0W;GY
0P00000609bdj@030000002L/nP0W;?X00<0W;?X1@0000000`2K/^L0000009^bi`0309^bi`030000
002K/NH0000000D0Vk7V0P00000509^`iP030000002K/>H0000000<0VjoU1000000209Z^i@H00000
0P2J[N@00`000000VZcT0000000309Z/i0030000002J[>@0VZcT0080000000D0VZcS000000000000
000009Z/h`0;000000L0VJWQ00<0000009VXh@2IZ>401P2IZ>400`000000VJOP09VWh00609VWh003
0000002IYml0VJOO00<0VJOO2@00000309RUgP030000002HY=d0V:CM00L0V:CM00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0000001P0oooo00<000000?ooo`3oool02P3oool000D0
oooo00<000000?ooo`3oool09P3oool70000000309jmkP0000000000008000000P2O_>h01P000000
Wkc^000000000000Wk_]000000@0Wk_]1P00000309fjk08000000P2M^N`600000080W[S[10000000
102N^>/0000000000000000309bfjP070000002L]^X0W;KZ09bfjP000000W;GY0000000409bej@80
00001P2L]>T7000000<0Vk?X00<0000009^bi`0000001@2K/^L2000000D0Vk7V00<0000009^aiP00
0000102K/>H=0000000309Z]i0000000VZgT00@0VZgT00<0000009Z/i00000000P2J[>@200000003
09Z/i0000000000000<0000000<0VZcS000000000000100000000`2IZ^8000000000000200000003
09VZhP000000VJWQ00L0VJWQ00<0000009VXh@2IZ>401P2IZ>400`000000VJOP09VWh00509VWh0H0
0000102HY]l01@000000V:GN09RUgP2HYMh0000000@0V:GN00<0000009RTg@2HY=d01P2HY=d01@00
0000oooo0?ooo`3oool0000000<0oooo0P00000I0?ooo`030000003oool0oooo00T0oooo00050?oo
o`030000003oool0oooo02L0oooo0`00000309jmkP040000002N_Nh0000009nlkP@000000`2O_>h0
0`000000Wk_]0000000400000080WK_]00<0000009fjk0000000102M^^`2000000<0WKW/00<00000
09fik02M^N`03000000309bfjP040000002L]^X0W;KZ00000080W;GY00<0000009bej@2L]NT00P2L
]NT20000000309bdj@00000000000080000000<0VkCY000000000000102K/nP01`000000Vk?X09^c
j02K/nP0000009^bi`0000001@2K/^L2000000D0Vk7V2`00000309Z^i@030000002J[^D0VZkU0080
VZkU00<0000009Z]i00000001@2J[N@010000000VZcT0000002J[>@:0000000309V[h`0000000000
00D00000102IZ^800`000000VJWQ09VYh@0609VYh@030000002IZ>40VJSQ00D0VJSQ00@0000009VW
h02IYn00VJOP1000000209RWh0030000002HY]l0V:KO00D0V:KO00<0000009RUgP2HYMh00P2HYMh0
1@000000V:GN09RUgP2HYMh0000000T0V:CM00@000000?ooo`3oool000000`3oool00`000000oooo
0000000B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool000D0oooo00<0
00000?ooo`3oool09`3oool20000000509jmkP000000000009jmkP0000000P2N_Nh200000080Wkc^
1`00000409fkk@060000002M^nd0WK_]0000002M^^`00000102M^^`2000000<0WKW/1P00000509bg
j`030000002L]n/0000003<000000`2J[nH01@000000VZoV09Z_iP2J[nH0000000<0VZkU00<00000
09Z^i@2J[^D00P2J[^D2000000D0VZgT1`0000000`2I[>@0000009V/i0020000000309V[h`000000
000000H000001P2IZ^800`000000VJWQ09VYh@0509VYh@030000002IZ>40VJSQ00<0VJSQ1P000006
09RWh0030000002HY]l0V:KO00H0V:KO00<0000009RUgP2HYMh00P2HYMh01@000000V:GN09RUgP2H
YMh0000000P0V:CM00D000000?ooo`3oool0oooo000000030?ooo`8000004P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo00040?ooo`030000003oool0oooo02T0oooo0P00
00000`2N_Nh000000000000200000080W[g^0P0000000`2O_>h000000000000700000080WK_]00H0
000009fkk@2M^nd0000009fjk000000409fjk0H00000102L^>`2000000D0W;O[0P00000309bfjP04
0000002L]^X0W;KZ09bfjPD000000`2K]NX2000000D0VkCY00@0000009^dj@2K]>T000000P2K/nP0
0`000000Vk?X09^cj00209^cj08000000`2K/^L6000000<0V[3W00@0000009Z`i`2J/>L00000102J
[nH010000000VZoV09Z_iP00000309Z^i@030000002J[^D0VZkU0080VZkU00<0000009Z]i0000000
100000000`2I[ND00000000000030000000409V/i0000000000009V/i0<0000000<0VJ_S00000000
00000`00000809VZhP030000002IZN40VJWQ00<0VJWQ2000000409RXh@030000002HYn00V:OP00H0
V:OP00<0000009RVg`2HY]l01@2HY]l00`000000V:GN09RUgP0309RUgP040000002HYMh0V:GN0000
00L0V:CM0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00040?ooo`030000003oool0oooo02X0
oooo0`00000209jmkPH000000P2M_>h00`000000WKc^09flkP0209flkP060000002M^nd000000000
002M^nd000000P2M^nd00`000000WK[/000000050000000509bik@000000W;S/09bhk0000000102L
^>`00`000000W;O[09bgj`0309bgj`030000002L]n/000000080W;KZ1000000209^fj`8000001@2K
]NX2000000D0VkCY00@0000009^dj@2K]>T000000P2K/nP00`000000Vk?X00000006000000@0V[7X
00<0000009Z`i`2J/>L00`2J/>L010000000V[3W09Z`i`00000309Z_iP050000002J[nH0VZoV09Z_
iP0000000P2J[^D00`000000VZkU09Z^i@05000000D0VJgU2@0000000`2I[>@00000000000040000
0080VJ_S00<0000009VZhP2IZ^801@2IZ^86000000@0V:SR00<0000009RXh@2HZ>401@2HZ>400`00
0000V:OP09RWh00609RWh0030000002HY]l0V:KO00H0V:KO00<0000009RUgP2HYMh00P2HYMh01@00
0000V:GN09RUgP2HYMh000000080V:CM1000000209NTgP040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool03`3oool2000000D0oooo00<000000?ooo`3oool02@3oool000@0oooo00<00000
0?ooo`3oool0;03oool40000000309fmk`0000000000008000000`2M_>h00`000000WKc^09flkP02
09flkP030000002M^nd0WK_]00T000000P2L^Nd01P000000W;W]09bik@000000W;S/000000D0W;S/
00<0000009bgj`2L]n/00P2L]n/50000000309^fj`000000VkK[00@0VkK[00<0000009^ejP2K]NX0
0`2K]NX00`000000VkGZ0000000409^dj@030000002K]>T0VkCY00D00000102J/^P00`000000V[7X
09Zaj00409Zaj0800000102J/>L01@000000V[3W09Z`i`2J/>L000000080VZoV00@0000009Z_iP2J
[nH0VZoV1P00000409V^i@8000000`2I[ND20000000309V]i@00000000000080000000@0VJcT0000
00000000VJcT1000000409V[h`040000002IZ^80VJ[R09VZhP@000000P2HZN800`000000V:SR09RX
hP0509RXhP030000002HZ>40V:SQ00H0V:SQ00<0000009RWh02HYn001P2HYn000`000000V:KO09RV
g`0509RVg`030000002HYMh0V:GN00<0V:GN1P00000709NTgP030000003oool0000000@0oooo00<0
00000?ooo`3oool03`3oool2000000D0oooo00<000000?ooo`3oool02@3oool000@0oooo00<00000
0?ooo`3oool0;@3oool30000000409fmk`000000WKg_09fmk`<000000P2M_>h010000000WKc^09fl
kP2M_>h=00000080W;W]00<0000009bik@0000000P2L^>`00`000000W;S/09bhk00209bhk0D00000
00D0VkO/0000002K]n`0VkO/0000000209^fj`030000002K]^/0VkK[0080VkK[0P00000509^ejP03
0000002K]NX000000080VkCY1000000209Zcj@8000001P2J/^P00`000000V[7X09Zaj00309Zaj080
00001@2J/>L010000000V[3W09Z`i`00000209Z_iP@000000P2I[nH00`000000VJkU0000000509V^
i@8000000P2I[ND:0000000409V/i00000000000000000@0VJ_S1P00000609RYhP030000002HZ>80
V:SR00H0V:SR00<0000009RXh@2HZ>401P2HZ>400`000000V:OP09RWh00509RWh0030000002HY]l0
V:KO00<0V:KO200000001@2GYMh0000009NUgP2GYMh0000000P0UjCN00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`0>0?ooo`8000001@3oool00`000000oooo0?ooo`090?ooo`00103oool0
0`000000oooo0?ooo`0^0?ooo`D000000`2M_Nl70000000309^kk`000000000000<00000102L^^h2
0000000309bik@000000000000@0000000<0W;S/0000000000000`0000000`2J^>d0000000000004
09^gk0060000002K]n`0VkO/0000002K]^/000001@2K]^/00`000000VkGZ09^ejP0309^ejPD00000
00<0V[?Y0000002J/nT00`2J/nT2000000H0V[;X00<0000009Zaj02J/NP0102J/NP2000000@0V[3W
1P0000000`2I[nH0000009V_iP0309V_iP040000002I[^D0VJkU000000<0VJkU1`0000000`2I[ND0
00000000000=000000@0V:[S00<0000009RYhP2HZN801P2HZN800`000000V:SR09RXhP0609RXhP03
0000002HZ>40V:SQ00D0V:SQ00<0000009RWh02HYn000`2HYn08000000@0UjGO00<0000009NUgP2G
YMh00`2GYMh00`000000UjGN0000000909NTgP030000003oool0000000@0oooo00<000000?ooo`3o
ool03P3oool2000000H0oooo00<000000?ooo`3oool0203oool000@0oooo00<000000?ooo`3oool0
;`3oool500000080WKg_1P0000000`2K^nl000000000000200000080W;[^00<0000009bjkP2L^^h0
0P2L^^h200000080W;W]00<0000009bik@0000001P00000209Zhk@030000002J^>d0000000<0VkO/
00L0000009^gk02K]n`0VkO/0000002K]^/0000000@0VkK[1`00000309VdjP040000002J/nT0V[?Y
000000@0V[?Y0P00000509Zbj0800000102J/NP9000000<0VK3W00@0000009V_iP2I[nH000000`2I
[nH700000080VJkU00D0000009V]i@000000000009V]i@09000000<0V:_T00<0000009RZh`2HZ^<0
1@2HZ^<00`000000V:WR09RYhP0609RYhP030000002HZ>80V:SR00H0V:SR00<0000009RXh@2HZ>40
0`2HZ>48000000@0UjKP00<0000009NUg`2GYMl01@2GYMl00`000000UjGN09NUgP0309NUgP040000
002GYMh0UjGN000000P0UjCN00<000000?ooo`000000103oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0000000H0oooo00<000000?ooo`3oool0203oool000<0oooo00<000000?ooo`3oool0
<@3oool00`000000WKg_000000050000000309^lk`000000000000<0000000@0Vk__0000002K^nl0
00000P2L^^h010000000W;[^09bjkP2L^^h6000000<0V[W]0P00000209Zhk@H000000`2K]n`01000
0000VkO/09^gk02K]n`20000000509^fj`00000000000000002I]N/00P00000409VdjP070000002I
]>X0VKCZ09VdjP000000V[?Y0000000509Zcj@030000002J/^P0V[;X00@0V[;X1@0000001@2H/NP0
000009Raj02H/NP0000000<0VK3W00<0000009V`i`2I/>L00P2I/>L600000080VJoV00<0000009V^
i@000000102I[^D70000000309R/i@0000000000008000001P2HZn@00`000000V:[S09RZh`0509RZ
h`030000002HZN80V:WR00H0V:WR00<0000009RXhP2HZ>801@2HZ>86000000@0UjOQ00<0000009NV
h02GY^001@2GY^000`000000UjGO09NUg`0609NUg`030000002GYMh0UjGN00<0UjGN00@0000009NU
gP2GYMh00000202GY=h2000000@0oooo00<000000?ooo`3oool03@3oool00`000000oooo00000006
0?ooo`030000003oool0oooo00P0oooo00030?ooo`030000003oool0oooo0380oooo0`0000000`2K
_>l00000000000040000000309^kk`000000Vk__00D0000000<0W;[^00000000000010000000102J
^^h0000009Zik@00000409Zik@800000102J^>d00`000000V[S]09Zhk@0:000000D0VKG[0P000003
09VdjP070000002I]>X0VKCZ09VdjP000000V[?Y0000000509Zcj@030000002J/^P0V[;X00D00000
00<0V;7Y0000002H/NP00`2H/NP00`000000V;7X09Raj00900000080VJoV00<0000009V_iP2I[nH0
0P2I[nH00`000000VJkU09V^i@0?000000L0V:_T00<0000009RZh`2HZ^<01P2HZ^<00`000000V:WR
09RYhP0509RYhP040000002HZ>80V:SR09RXhP@000000P2GZ>800`000000UjOQ09NWh@0509NWh@03
0000002GY^00UjKP00H0UjKP00<0000009NUg`2GYMl01P2GYMl00`000000UjGN09NUgP0309NUgP03
0000002GYMh0000000D0UjCN1@0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`00
00001P3oool00`000000oooo0?ooo`080?ooo`000`3oool00`000000oooo0?ooo`0c0?ooo`D00000
00@0Vkc_000000000000Vkc_0P00000309^kk`L000000P2J^^h01P000000V[[^09ZjkP000000V[W]
000000@0V[W]0P00000409Zhk@L0000000<0VKK/0000000000002P00000309VdjP070000002I]>X0
VKCZ09VdjP000000V[?Y0000000209Zcj@D000001@2H/NT010000000V;7Y0000002H/NP6000000<0
VK3W00<0000009V`i`2I/>L00P2I/>L00`000000VJoV0000000209V_iPH000000P2H[NH:00000080
V:cU00<0000009R[i02HZn@01@2HZn@00`000000V:[S09RZh`0509RZh`030000002HZN80V:WR00<0
V:WR1P00000609NXhP030000002GYn40UjOQ00H0UjOQ00<0000009NVh02GY^001P2GY^000`000000
UjGO09NUg`0509NUg`030000002GYMh0UjGN00<0UjGN2000000409JSgP030000003oool0oooo00<0
oooo00<000000?ooo`3oool0303oool00`000000oooo000000060?ooo`030000003oool0oooo00P0
oooo00030?ooo`030000003oool0oooo0380oooo1P00000209^lk`P000000`2J^nl20000000909Zj
kP000000000009ZjkP000000V[[^0000002J^Nd0000000D0V[W]1P00000309Vgk@030000002I]^`0
000000@0VKK/0P00000409Vej`030000002I]N/0VKG[01X000000`2H/NP010000000V;7X09Raj000
000309V`i`030000002I/>L0000000H00000102G[^L00`000000V:gV000000060000000409R/i@00
00000000000000@0V:cU00<0000009R[i02HZn@0102HZn@00`000000V:[S09RZh`0309RZh`P00000
102GZN<00`000000UjSR09NXhP0609NXhP030000002GYn40UjOQ00H0UjOQ00<0000009NVh02GY^00
1@2GY^000`000000UjGO09NUg`0309NUg`P0000000D0UZCO0000002FY=l0UZCO0000000709JSgP80
0000103oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0203oool000<0oooo00<000000?ooo`3oool0;`3oool3000000@0oooo1P00000209Zll080
00000P2J^nl010000000V[__09Zkk`2J^nl200000080V[[^0`0000000`2J^^h0000009Zik@060000
000509VhkP000000VKO]09Vgk@000000102I]nd2000000D0VKK/0P00000409Vej`L00000102H/n/0
0`000000V;;Z09RbjP0309RbjP030000002H/^X0000000@0V;7Y00@0000009Raj@2H/NT000000`2H
/NP9000000@0UjoW00<0000009N^i`0000001@2G[^L40000000409R]iP000000000009R]iP800000
1P2H[>D00`000000V:_T09R[i00209R[i0P00000102GZ^@00`000000UjWS09NYh`0509NYh`030000
002GZ>80UjSR00L0UjSR00<0000009NWh@2GYn401@2GYn400`000000UjKP09NVh00309NVh0P00000
0`2FYMl00`000000UZCO09JTg`0409JTg`030000002FY=l0000000P0UZ?N00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0203oool000<0oooo00<000000?ooo`3oool0;03oool3000000P0oooo1@00000309Zll0<00000
00<0V[__0000002J^nl00P2J^nl00`000000V[[^09ZjkP0209ZjkPD000001@2I^>h00`000000VKS^
0000000209Vgk@040000002I]nd0VKO]09Vgk@8000001@2I]^`7000000<0V;C/00<0000009Rcj`00
00001@2H/n/00`000000V;;Z09RbjP0309RbjP030000002H/^X0000000@0V;7Y2000000309N`j004
0000002G[nL0UjoW000000D0UjoW0P00000209N^i``000001@2H[>D7000000@0Uj_T00<0000009NZ
i02GZ^@01@2GZ^@00`000000UjWS09NYh`0609NYh`030000002GZ>80UjSR00H0UjSR00<0000009NW
h@2GYn400`2GYn48000000<0UZKP00<0000009JUg`2FYMl01P2FYMl00`000000UZCO09JTg`0409JT
g`030000002FY=l0000000L0UZ?N00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0203oool00080oooo00<000000?oo
o`3oool0:P3oool3000000`0oooo1@00000309Zll0@000000P2J^nl7000000<0V;W_1000000209Vh
kP030000002I^>h000000080VKO]00<0000009Vgk@2I]nd00P2I]nd20000000309Vfk00000000000
008000000P2G]^d010000000V;C/09Rdk000000409Rdk08000001@2H/n/00`000000V;;Z09RbjP03
09RbjP030000002H/^X0000000D000000`2G/NT010000000Uk3X09N`j000000409N`j0030000002G
[nL0000000D0UjoW1000000409N^i`d00000102F[>D00`000000Uj_T09N[i00409N[i0030000002G
Z^@0Uj[T00H0Uj[T00<0000009NYh`2GZN<01P2GZN<00`000000UjSR09NXhP0509NXhPH000000`2F
Y^400`000000UZKP09JVh00609JVh0030000002FYMl0UZGO00D0UZGO00<0000009JTg`2FY=l01@2F
Y=l2000000P0UZ?N00D000000?ooo`3oool0oooo0000000=0?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool01`3oool00080oooo00<000000?ooo`3oool09`3oool300000100oooo
00D0000009Zll0000000V[c`0000000209Zll0H000000P2H^_02000000<0V;W_00D0000009Rik`2H
^Nl0V;W_0000000209VhkPH0000000@0VKO]0000002I]nd0VKO]1@00000409Nfk@040000002G]^d0
UkK]00000080V;C/00@0000009Rdk02H]>`0V;C/0P00000609Rcj`030000002H/^X0V;;Z00@00000
0P2G/^X01@000000Uk7Y09Naj@2G/NT0000000<0Uk7Y00@0000009N`j02G/>P000000`2G/>P01@00
0000UjoW09N_i`000000UjoW00D0000000@0UjkW0000002G[^L0UjkW1`00000409J]iP030000002F
[>D0UZcU00D0UZcU00<0000009N[i02GZn@01@2GZn@00`000000Uj[T09NZi00609NZi0030000002G
ZN<0UjWS00D0UjWS00@0000009NXhP2GZ>80UjSR100000000`2FYn80000009JVh@0709JVh@030000
002FY^00UZKP00D0UZKP00<0000009JUg`2FYMl01P2FYMl00`000000UZCO09JTg`0409JTg`030000
002FY=l0000000L0UZ?N0P0000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0P0000070?ooo`030000003oool0oooo00L0oooo00020?ooo`030000003oool0oooo02@0oooo0`00
000D0?ooo`030000002J_?00000000D0000000<0V;_`0000002H^_000`0000001P2H^_0000000000
00000000V;W_000000@0V;W_00<0000009VhkP2I^>h00P2I^>h7000000<0UkO]0P00000409Nfk@04
0000002G]^d0UkK]00000080V;C/00<0000009Rdk02H]>`00P2H]>`2000000<0V;?[1@00000309Nb
jP050000002G/^X0Uk;Z09NbjP0000000P2G/NT01@000000Uk7Y09Naj@2G/NT000000080Uk3X00<0
000009N`j02G/>P00P2G/>P400000080UjoW1`0000000`2F[NL0000000000002000000L0UZgV00<0
000009J/i@2F[>D01@2F[>D00`000000Uj_T09N[i00509N[i0030000002GZ^@0Uj[T00D0Uj[T00<0
000009NYh`2GZN<00`2GZN<6000000H0UZOR00<0000009JVh@2FY^401@2FY^400`000000UZKP09JV
h00609JVh0030000002FYMl0UZGO00D0UZGO00<0000009JTg`2FY=l01@2FY=l2000000D0UZ?N1000
00030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P0000070?ooo`030000003o
ool0oooo00L0oooo00020?ooo`030000003oool0oooo0240oooo0`00000H0?ooo`<0000000@0V;_`
00000000000000000P2H^o0200000080V;[`0`000000102H^_00000009Rik`00000209Rik`H00000
00@0UkS^0000002G^>h0UkS^1000000309Ngk@800000102G]^d01P000000UkK]09Nfk@000000V;C/
00000080V;C/1`00000309Jcj`800000102G/^X010000000Uk;Z09NbjP00000309Naj@040000002G
/NT0Uk7Y09Naj@d00000102F[^P00`000000UZgW000000040000000309J]i`000000UZgV00D0UZgV
00<0000009J/i@2F[>D01P2F[>D00`000000Uj_T09N[i00409N[i0030000002GZ^@0Uj[T00<0Uj[T
2000000409JXh`030000002FYn80UZOR00D0UZOR00<0000009JVh@2FY^401P2FY^400`000000UZKP
09JVh00509JVh0030000002FYMl0UZGO00H0UZGO00<0000009JTg`2FY=l00P2FY=l9000000<0UJ?N
0P0000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P0000070?ooo`030000
003oool0oooo00L0oooo00020?ooo`030000003oool0oooo01h0oooo0`00000L0?ooo`@000000P2H
^o000`000000V;_`09Rkl002000000<0V;[`1`00000209Nik`8000000`2G^>h010000000UkS^09Nh
kP2G^>h20000000309Ngk@000000000000l00000102F]>`00`000000U[?[09Jcj`0309Jcj`030000
002F/n/0000000<0Uk;Z00@0000009NbjP2G/^X0Uk;Z3000000409J_j@030000002F[^P0000000D0
UZkX1P00000209J]i`030000002F[NH0UZgV00D0UZgV00<0000009J/i@2F[>D01@2F[>D00`000000
Uj_T09N[i00209N[i0P00000102EZN@00`000000UZSS09JXh`0509JXh`030000002FYn80UZOR00H0
UZOR00<0000009JVh@2FY^401@2FY^400`000000UZKP09JVh00609JVh0030000002FYMl0UZGO0080
UZGO2000000409FSg`030000002EXmh0UJ?N00H0UJ?N0P0000000`3oool000000?ooo`0:0?ooo`03
0000003oool0oooo008000001`3oool00`000000oooo0?ooo`070?ooo`000P3oool00`000000oooo
0?ooo`0K0?ooo`<00000803oool20000000409Rkl0000000V;_`09Rkl0P000000`2F^_0300000080
UkW_00H0000009Nik`000000000009NhkP00000409NhkP030000002G]nd0UkO]0080UkO]1`000002
09JekAh00000102E/>X00`000000UZoY0000000509J_j@030000002F[^P000000080UZkX0P000000
0`2F[^P0000000000002000000@0UZgW00<0000009J]iP2F[NH00P2F[NH?000000@0UJ[U00<00000
09FYi02EZN@01P2EZN@00`000000UZSS09JXh`0509JXh`030000002FYn80UZOR00D0UZOR00<00000
09JVh@2FY^401P2FY^400`000000UZKP09JVh00209JVh0P00000102EY>000`000000UJ?O09FSg`05
09FSg`8000001`2EXmh010000000oooo00000000000;0?ooo`050000003oool000000?ooo`000000
1`3oool00`000000oooo0?ooo`070?ooo`000P3oool00`000000oooo0?ooo`0H0?ooo`<00000903o
ool20000000309Rkl0000000000000D000000`2F^_001P000000U[[`09Jjl02F^_00000009Nik`80
000000L0UkW_0000002G^Nl0UkW_0000002G^>h000000080UkS^1P0000001@2F]^h0000009JfkP2F
]^h000000080U[G]00<0000009Jek@2F]Nd00P2F]Nd2000000D0U[C/0P00000409Jcj`P000000`2E
/N/00`000000UK3Z0000000509F`jP030000002F[nT0000000@0UZoY00<0000009J^j00000000P00
000209J^j0@000000`2F[NL7000000@0UJcV00<0000009F[i@2EZnD01@2EZnD00`000000UJ[U09FZ
i@0509FZi@030000002EZN@0UJWT00D0UJWT00<0000009JXh`2FZ><01@2FZ><00`000000UZOR09JW
hP0609JWhP030000002FY^40UZKQ0080UZKQ2000000409FUh@030000002EY>00UJCP00D0UJCP00<0
000009FSg`2EXml01P2EXml00`000000UJ?N09FSgP0609FSgP80000000<0oooo0000003oool0203o
ool2000000040?ooo`000000oooo000000L0oooo00<000000?ooo`3oool01`3oool000030?ooo`00
0000oooo01L0oooo0`00000X0?ooo`H000000P2F^o4300000080U[[`00D0000009Jjl02F^_00U[[`
0000000209Nik`T000000P2E]nl2000000@0U[K^00H0000009JfkP2F]^h0000009Jek@00000509Je
k@030000002F]>`0U[C/0080U[C/1`0000001@2E/^`0000009Fbk02E/^`000000080UK7[00<00000
09Faj`2E/N/00P2E/N/00`000000UK3Z0000000409F`jP030000002F[nT000000080UZoY10000003
09J^j0T00000102D[NL00`000000UJcV09F/iP0409F/iP030000002EZnD0UJ_U00D0UJ_U00<00000
09FZi@2EZ^D01@2EZ^D00`000000UJWT09FYi00609FYi0030000002FZ><0UZSS0080UZSS40000004
09BVhP030000002EYN40UJGQ00D0UJGQ00<0000009FTh02EY>001P2EY>000`000000UJ?O09FSg`06
09FSg`030000002EXmh0UJ?N00D0UJ?N00@000000?ooo`00000000002@3oool2000000040?ooo`00
0000oooo000000P0oooo00<000000?ooo`3oool01P3oool000030?ooo`000000oooo01@0oooo0`00
000/0?ooo`<0000000<0U[_a0000000000000P2F^o400`000000U[_a0000000200000080U[[`3000
000409Fgk`<000000P2F]^h01`000000U[K^09JfkP2F]^h0000009Jek@0000000P2F]Nd700000080
U;?/00<0000009Bck00000000`2E/^`01@000000UK;/09Fbk02E/^`000000080UK7[00D0000009Fa
j`2E/N/0UK7[0000000209F`jP030000002E/>X0UK3Z0080UK3Z100000000`2F[nT0000000000005
0000000509B^j0000000000009B^j00000001`2D[NL00`000000UJcV09F/iP0509F/iP030000002E
ZnD0UJ_U00D0UJ_U00<0000009FZi@2EZ^D01@2EZ^D00`000000UJWT09FYi00309FYi0L00000102D
Z><00`000000U:OR09BWhP0509BWhP030000002DY^80U:KR00D0U:KR00<0000009FUh@2EYN401P2E
YN400`000000UJCP09FTh00609FTh0030000002EXml0UJ?O00D0UJ?O0P00000709FSgP030000003o
ool0000000T0oooo0P000000103oool000000?ooo`0000080?ooo`030000003oool0oooo00H0oooo
00000`3oool000000?ooo`0A0?ooo`<00000<03oool300000080U[_a00<0000009Jkl@0000001P00
000209Bil@8000000P2E^?0010000000UKS`09Fhl02E^?0400000080UKO_00@0000009Fgk`2E]nl0
00000P2F]^h00`000000U[K^00000005000000<0U;C]0P00000409Bck0040000002D/n`0U;?/0000
00<0UK;/00@0000009Fbk02E/^`000000`2E/N/01`000000UK7[09Faj`2E/N/0000009F`jP000000
0P2E/>X7000000<0U:oY0P00000209B^j08000000P2D[^P00`000000U:gW09B]i`0609B]i`030000
002E[>H0UJcV00D0UJcV00<0000009F[i@2EZnD0102EZnD00`000000UJ[U09FZi@0309FZi@P00000
0`2DZ>@00`000000U:SS09BXh`0509BXh`030000002DYn80U:OR00D0U:OR00<0000009BVhP2DY^80
1P2DY^800`000000UJGQ09FUh@0609FUh@030000002EY>00UJCP00D0UJCP00<0000009FSg`2EXml0
0`2EXml<000000030?ooo`000000oooo00P0oooo0`0000020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool000030?ooo`000000oooo00h0oooo0`00000d0?ooo`H0000000@0
U;[a0000002D^_40U;[a10000000102D^O40000009Bil@00000209Fhl0030000002E^?00UKS`0080
UKS`00<0000009Fgk`0000002@00000309BfkP8000001@2D]>d2000000@0U;?/00<0000009Bck000
00000`2E/^`01@000000UK;/09Fbk02E/^`000000080UK7[00<0000009Faj`0000001P00000409B`
jP030000002D[nT0U:oY00<000000P2D[nT500000080U:kX00<0000009B]i`2D[NL01P2D[NL00`00
0000UJcV09F/iP0409F/iP030000002EZnD0UJ_U0080UJ_U2000000409BYi@030000002DZ>@0U:ST
00D0U:ST00<0000009BXh`2DZ><01@2DZ><00`000000U:OR09BWhP0509BWhP030000002DY^80U:KR
00H0U:KR00<0000009FUh@2EYN401@2EYN400`000000UJCP09FTh00309FTh0P000000`2DXml20000
00L0U:;N00<000000?ooo`0000001`3oool010000000oooo0000000000020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool000030?ooo`000000oooo00/0oooo0`00000h0?oo
o`<0000000<0U;[a0000000000000P00000209Bjl@80000000P0U;Wa000000000000000009Bil@00
0000UKS`00000080UKS`2000000209>gk`H000000P2D]^h00`000000U;C]09Bdk@0309Bdk@800000
102D/n`010000000U;?/09Bck000000309Fbk0/0000000@0Tk7[0000002D/>X000001@2D/>X30000
0080U:oY1P00000409B^j0030000002D[NL0U:gW00D0U:gW00<0000009F/iP2E[>H00P2E[>H70000
00@0Tj[V00<0000009BYi@2DZND01@2DZND00`000000U:ST09BXi00509BXi0030000002DZ><0U:SS
00H0U:SS00<0000009BWhP2DYn801@2DYn800`000000U:KR09BVhP0509BVhP030000002EYN40UJGQ
00<0UJGQ2000000309>Th0030000002DXml0U:?O00H0U:?O0P00000609BRgP030000003oool00000
00L0oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00000`3oool000000?ooo`080?ooo`<00000?03oool400000080U;[a00D0000009Bj
l@2D^_40U;[a0000000309Bil@L000000`2C^?02000000<0TkO_00@0000009>gk`2C]nl0TkO_0P00
000209BfkQT0000000D0Tk;/0000002C/N/0Tk7[0000000409>aj`040000002D/>X0000000000080
U;3Z0P00000309B_j@L00000102D[^P00`000000U:gW09B]i`0309B]i`L00000102CZnL00`000000
Tj[V09>ZiP0509>ZiP030000002DZND0U:WU00D0U:WU00<0000009BXi02DZ>@01@2DZ>@00`000000
U:SS09BXh`0509BXh`030000002DYn80U:OR00D0U:OR00<0000009BVhP2DY^800`2DY^88000000<0
TjCQ00<0000009>Th02CY>001P2CY>000`000000U:?O09BSg`0509BSg`030000002DX]h0000000H0
U:;N0P0000070?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`0000<000000?ooo`3oool01@3oool3000003l0oooo1@00000209Bjl@d0
0000102C^?000`000000TkS`0000000209>gk`070000002C]nl0TkO_09>gk`000000U;K^00000004
09BfkP030000002D]>d0U;C]0080U;C]1`0000001@2C/nd0000009>ck@2C/nd000000080Tk;/00<0
000009>bk02C/^`00P2C/^`00`000000Tk7[0000000409>aj`030000002D/>X0U;3Z00<000000P2D
/>X010000000U:oY0000002D[nT@000000@0TjcX00<0000009>[i`2CZnL01@2CZnL00`000000Tj[V
09>ZiP0409>ZiP030000002DZND0U:WU00H0U:WU00<0000009BXi02DZ>@0102DZ>@00`000000U:SS
09BXh`0309BXha0000000`2CYN800`000000TjCQ09>Th@0609>Th@030000002CY>00TjCP00D0TjCP
00<0000009BSg`2DXml01P2DXml2000000L0U:;N0P0000060?ooo`030000003oool000000080oooo
0P0000080?ooo`030000003oool0oooo00H0oooo00000`000000oooo0?ooo`020?ooo`<00000@`3o
ool90000000309:jlP00000000000080TkWa00@0000009>il@2C^O40TkWa0`00000309>hl0800000
0`2C]nl010000000TkO_09>gk`2C]nl2000000<0U;K^1P00000209:dkP030000002B]>h0000000<0
Tk?]00D0000009>ck@2C/nd0Tk?]0000000209>bk0050000002C/^`0Tk;/09>bk00000000P2C/N/0
0`000000Tk7[09>aj`0400000080U;3Z200000000`2B[^T0000000000002000000H0TjgX00<00000
09>/j02C[>P01@2C[>P00`000000Tj_W09>[i`0509>[i`030000002CZ^H0Tj[V00D0Tj[V00<00000
09BYi@2DZND01@2DZND00`000000U:ST09BXi00209BXi0P00000102CYn<00`000000TjKS09>Vh`05
09>Vh`030000002CYN80TjGR00D0TjGR00<0000009>Th@2CY>401@2CY>400`000000TjCP09>Th006
09>Th0030000002DXml0U:?O00D0U:?O00<0000009BRgP0000001P2DX]h2000000H0oooo00<00000
0?ooo`0000000P3oool2000000P0oooo00<000000?ooo`3oool01P3oool000030000003oool00000
00800000A`3oool4000000<0T[[b1@00000209>il@040000002C^O40TkWa09>il@H0000000H0TkS`
0000002C]nl0TkO_0000002C]nl700000080T[G_0P00000409:dkP040000002B]>h0T[C^000000<0
Tk?]00@0000009>ck@2C/nd000000P2C/^`00`000000Tk;/09>bk00209>bk0030000002C/N/00000
00T0000000<0TZoZ0000000000002P00000609>]j0030000002C[>P0TjcX00D0TjcX00<0000009>[
i`2CZnL01@2CZnL00`000000Tj[V09>ZiP0209>ZiPl00000102BZ>@00`000000TjOS09>Wh`0509>W
h`030000002CY^<0TjKS00D0TjKS00<0000009>UhP2CYN801@2CYN800`000000TjCQ09>Th@0609>T
h@030000002CY>00TjCP00D0TjCP00<0000009BSg`2DXml01P2DXml00`000000U:;N0000000209BR
gPD000001@3oool010000000oooo0?ooo`0000020?ooo`8000002@3oool00`000000oooo0?ooo`05
0?ooo`000P00001;0?ooo`D0000000@0T[[b0000002B^_80T[[b0`00000209>il@030000002C^O40
000000`00000102B]_000`000000T[G_09:ek`0309:ek`800000102B]>h010000000T[C^09:dkP00
000309>ck@040000002C/nd0Tk?]00000080Tk;/00<0000009>bk00000001P00000409:`j`070000
002B[nX000000000002B[nX0000009:_jP020000000409:^j@000000000000000080TZkY00<00000
09>]j02C[NP0102C[NP00`000000TjcX09>/j00509>/j0030000002CZnL0Tj_W00<0Tj_W1`000004
09:ZiP030000002BZND0TZWU00D0TZWU00<0000009:Xi02BZ>@0102BZ>@00`000000TjOS09>Wh`06
09>Wh`030000002CY^<0TjKS00D0TjKS00<0000009>UhP2CYN801@2CYN800`000000TjCQ09>Th@05
09>Th@030000002CY>00TjCP00<0TjCP4000000409>RgP800000103oool020000000oooo0?ooo`00
0000oooo0000003oool000002@3oool00`000000oooo0?ooo`050?ooo`0000<0oooo0000003oool0
B`3oool700000080T[[b1P000002096hl@030000002A^?4000000080TKO`00<00000096gl02A]o00
1@00000309:fl0030000002B]Nl0T[G_0080T[G_00<0000009:ek`0000000`2B]>h@000000<0TK7/
00<0000009:`j`2B/>/00P00000209:`j`8000000P2B[nX00`000000TZoZ00000006000000<0TZkY
00<0000009>]j02C[NP0102C[NP00`000000TjcX09>/j00209>/j0P00000102BZnL00`000000TZ[V
09:ZiP0409:ZiP030000002BZND0TZWU00D0TZWU00<0000009:Xi02BZ>@01@2BZ>@00`000000TjOS
09>Wh`0609>Wh`030000002CY^<0TjKS00@0TjKS00<0000009>UhP2CYN801@2CYN800`000000TjCQ
09>Th@0309>Th@P00000102BXn000`000000TZ;O09:Rg`0509:Rg`030000002CX]h0000000H0Tj;N
00<000000?ooo`3oool00P3oool020000000oooo0?ooo`000000oooo0000003oool000002@3oool0
0`000000oooo0?ooo`050?ooo`000P3oool2000004/0oooo2@000002092ilP<000000`2A^?400`00
0000TKSa00000002096gl0070000002A]o00TKO`0000002B]_00000009:fl006000000<0T[G_1`00
0003096ckPP000000P2A/N`00`000000TK7/096ak002096ak0030000002B/>/0T[3[00<0000000<0
T[3[000000000000100000000`2B[nX00000000000020000000309:^j@000000000000d00000102A
[>P00`000000TZ_W09:[i`0509:[i`030000002BZ^H0TZ[V00D0TZ[V00<0000009:Yi@2BZND01@2B
ZND00`000000TZST09:Xi00509:Xi0030000002CYn<0TjOS00D0TjOS00<0000009>Vh`2CY^<00P2C
Y^<@000000@0TZCQ00<0000009:Sh02BXn001@2BXn000`000000TZ;O09:Rg`0509:Rg`040000002C
X]h0Tj;N000000D0Tj;N00<000000?ooo`3oool00P3oool01@000000oooo000000000000oooo0080
00002P3oool00`000000oooo0?ooo`050?ooo`00103oool00`000000oooo0?ooo`190?ooo`L00000
00@0T;Wb0000002@^O80T;Wb100000001`2A^?400000096hl@2A^?400000096gl00000000`2A]o02
000000<0T[K`4@0000001@2A/nh00000096bk@2A/^d0000000<0TK;]00<00000096ak00000001@2A
/N`2000000<0T[3[3`000003096]jP030000002A[NT0TJgY00@0TJgY00<00000096/j02A[>P01@2A
[>P00`000000TZ_W09:[i`0509:[i`030000002BZ^H0TZ[V00D0TZ[V00<0000009:Yi@2BZND0102B
ZND00`000000TZST09:Xi00509:Xi0030000002CYn<0TjOS00<0TjOS1`00000409:Vh`030000002B
YN80TZGR00D0TZGR00<0000009:Th@2BY>401@2BY>400`000000TZ?P09:Sh00609:Sh0030000002B
X]l0TZ;O00D0TZ;O00H0000009>RgP2CX]h0000009>RgP00000209>RgP8000000P3oool00`000000
oooo0?ooo`03000000030?ooo`000000oooo00T0oooo00<000000?ooo`3oool01@3oool000D0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0000000600000080T;Wb0P0000000`2A^?400000
0000000=00000080T;G`00<00000092el00000000`2@]>l010000000T;C_092dk`000002096ckP05
0000002A/nh0TK?^096ckP0000000P2A/^d00`000000TK;]096bk@02096bk@030000002A/N`00000
0080TK7/4@0000000`2@[^/0000000000006096]jP030000002A[NT0TJgY00@0TJgY00<00000096/
j02A[>P0102A[>P00`000000TZ_W09:[i`0509:[i`030000002BZ^H0TZ[V00D0TZ[V00<0000009:Y
i@2BZND00P2BZND@000000<0TJKT00<0000009:Vh`2BY^<01@2BY^<00`000000TZGR09:UhP0509:U
hP030000002BY>40TZCQ00H0TZCQ00<0000009:Sh02BXn001@2BXn000`000000TZ;O09:Rg`0609:R
g`070000002CX]h0Tj;N0000002CX]h0000009>RgP0200000080oooo00<000000?ooo`3oool00`00
00000`3oool000000?ooo`090?ooo`030000003oool0oooo00D0oooo00060?ooo`800000B@3oool2
000000040?ooo`000000000000000080T;Wb00<00000092ilP0000001`00000208nglP800000102?
]_400`000000T;G`092el003092el0030000002@]O0000000080T;C_00D00000092dk`2@]>l0T;C_
00000002096ckP050000002A/nh0TK?^096ckP0000000P2A/^d00`000000TK;]00000006000000@0
T;3]0P000002092_k0050000002@[n`000000000002@[^/01`000006096]jP030000002A[NT0TJgY
00@0TJgY00<00000096/j02A[>P01@2A[>P00`000000TZ_W09:[i`0209:[i`l00000102AZ>D00`00
0000TJOU096Wi@05096Wi@030000002AY^@0TJKT00D0TJKT00<0000009:Vh`2BY^<01@2BY^<00`00
0000TZGR09:UhP0509:UhP030000002BY>40TZCQ00H0TZCQ00<0000009:Sh02BXn001@2BXn000`00
0000TZ;O09:Rg`0509:Rg`040000002CX]h0000000000080Tj;N00H0000009>RgP00000000000?oo
o`0000020?ooo`050000003oool000000?ooo`0000002P3oool00`000000oooo0?ooo`050?ooo`00
203oool00`000000oooo0?ooo`170?ooo`T000000`2>^?<010000000SkOb08nglP2?]o86000000@0
SkKa00<00000092el02@]O000P2@]O0010000000T;G`092el0000002092dk`030000002@]>l00000
00`0000000<0Sk7^0000000000000P0000000`2@/>d0000000000002092`k@P0000000<0T:o/0000
000000000P000000102@[^/00000000000000007096]jP030000002A[NT0TJgY00@0TJgY00<00000
096/j02A[>P00P2A[>P7000000@0T:[W00<00000096YiP2AZNH01@2AZNH00`000000TJSU096Xi@04
096Xi@030000002AYnD0TJOU00D0TJOU00<00000096Vi02AY^@01@2AY^@00`000000TZKS09:Vh`06
09:Vh`030000002BYN80TZGR00D0TZGR00<0000009:Th@2BY>401@2BY>400`000000TZ?P09:Sh005
09:Sh0030000002BX]l0TZ;O00<0TZ;O300000000`3oool000000?ooo`02000000040?ooo`000000
oooo000000/0oooo00<000000?ooo`3oool0103oool000T0oooo00<000000?ooo`3oool0A`3oool6
0000000508jhl`00000000000000002>^?<00P00000208nglP040000002?]o80SkOb08nglP@00000
0P2?]_42000000@0T;G`1`00000308jck`030000002?/^h0000000@0Sk;^1000000408nakP030000
002@/>d0T;3]00T0000000<0T:o/00000000000010000000102@[^/00000000000000004096]jPh0
0000102@ZnP00`000000T:[W092Zi`04092Zi`030000002AZNH0TJWV00D0TJWV00<00000096Xi@2A
Z>D01@2AZ>D00`000000TJOU096Wi@05096Wi@030000002AY^@0TJKT00D0TJKT00<0000009:Vh`2B
Y^<01@2BY^<00`000000TZGR09:UhP0509:UhP030000002BY>40TZCQ00<0TZCQ40000003096Rg`06
0000002AXMl00000096Qg`000000TJ7O0P000000102AXMl000000000003oool300000080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`002P3oool2000004P0oooo0`000000
0`3oool00000000000020000000308jhl`0000000000008000000P2?]o800`000000SkOb0000000=
000000<0S[C`00<0000008jck`000000102>/nl60000000408nbkP000000Sk7^000000D0Sk7^0`00
0000102@/>d000000000002@/>d200000003092_k0000000T:o/00h00000102?[NX00`000000T:cY
092/j@04092/j@030000002@ZnP0T:_X00D0T:_X00<00000092Zi`2@Z^L0102@Z^L00`000000TJWV
096YiP05096YiP030000002AZ>D0TJSU00D0TJSU00<00000096Wi@2AYnD0102AYnD00`000000TJKT
096Vi005096Vi0030000002BY^<0TZKS00<0TZKS40000003096Sh@030000002AX^00TJ;P00D0TJ;P
00<00000096Rg`2AX]l01P2AX]l200000080TJ7O00@00000096Qg`000000TJ7O0P000000103oool0
00000000000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool000`0
oooo00<000000?ooo`3oool0A@3oool4000000030?ooo`000000oooo00X000000`2=]o82000000<0
SKKa00<0000008ffl@0000003@000000102>/nl0000008nbkP00000408nbkP050000002?/Nh00000
0000002?/Nh040000000102>[n`000000000002?[^/300000080Sjk[00<0000008n]jP2?[NX0102?
[NX00`000000T:cY092/j@04092/j@030000002@ZnP0T:_X00D0T:_X00<00000092Zi`2@Z^L01@2@
Z^L00`000000TJWV096YiP04096YiP030000002AZ>D0TJSU00D0TJSU00<00000096Wi@2AYnD00P2A
YnD@000000<0T:GS00<00000096ThP2AY>801@2AY>800`000000TJ?Q096Sh@06096Sh@030000002A
X^00TJ;P00D0TJ;P00D00000096Rg`2AX]l0TJ;O00000003096Rg`8000000P2AXMl00`000000TJ7O
00000002096Qg`030000003oool00000008000000P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo000=0?ooo`030000003oool0oooo04D0oooo2000000308bhl`D00000102=
]o82000000<0SKKa00@0000008ffl@00000000000P2>]?001`000000S[C`08jdl02>]?00000008jc
k`0000000P2>/nl>00000080S[7^0P00000308j`k@030000002>/>d0000000<0000000@0SZo/0000
00000000SZo/0P0000000`2?[^/0000008n^j`0208n^j`030000002?[NX0SjgZ00D0SjgZ00<00000
092/j@2@[>T0102@[>T00`000000T:_X092[j005092[j0030000002@Z^L0T:[W00@0T:[W00<00000
096YiP2AZNH00P2AZNH?000000@0T:OU00<00000092Vi02@Y^@01@2@Y^@00`000000T:GS092Uh`05
092Uh`030000002AY>80TJCR00D0TJCR00<00000096Sh@2AXn401@2AXn400`000000TJ;P096Rh005
096Rh0040000002AX]l0TJ;O096Rg`8000000`2AX]l01`000000TJ7O096Qg`2AXMl00000096Qg`00
00000P2AXMl00`000000oooo000000020?ooo`8000002`3oool00`000000oooo0?ooo`040?ooo`00
3P3oool2000004H0oooo0`0000000`3oool000000?ooo`0200000080S;Sc00<0000008bhl`2<^?<0
1000000308fglP8000000P2=]_400`000000SKKa0000000<000000<0SK?`00<0000008fbk`000000
0P2=/^l3000000<0S[7^0`0000000`2>/Nh0000008j`k@050000000708j_k000000000000000002>
[n`0000008j_k004000000<0Sjk[00<0000008n]jP2?[NX0102?[NX00`000000T:cY092/j@02092/
jAH00000102?Z>L00`000000SjOV08nWiP0508nWiP030000002@YnD0T:OU00@0T:OU00<00000092V
i02@Y^@01P2@Y^@00`000000T:GS092Uh`04092Uh`030000002AY>80TJCR00D0TJCR00<00000096S
h@2AXn401P2AXn400`000000TJ;P096Rh005096Rh0060000002AX]l0TJ;O0000002AX]l000000P2A
X]l2000000<0TJ7O0P000002096Qg`030000003oool000000080oooo0P00000;0?ooo`030000003o
ool0oooo00@0oooo000@0?ooo`030000003oool0oooo04@0oooo2000000208bhl`030000002<^?<0
S;Sc0080000000<0SKOb0000000000001`00000308^elP030000002<]?40000000@0S;Ca0P000004
08fcl0D000000`2=/^l010000000S[7^00000000000208jakPD0000000D0S[3]0000002>/>d00000
08j_k0020000000308j_k0000000000000<000000P2?[^/>000000@0SZ_Y00<0000008jZj02>Z^P0
1@2>Z^P00`000000SjWW08nYi`0408nYi`030000002?Z>L0SjSW00D0SjSW00<0000008nWiP2?YnH0
102?YnH00`000000T:OU092Wi@05092Wi@030000002@Y^@0T:KT00D0T:KT00<00000092Uh`2@YN<0
1@2@YN<00`000000TJCR096ThP05096ThP030000002AXn40TJ?Q00D0TJ?Q00<00000096Rh02AX^00
1@2AX^001P000000TJ;O096Rg`2AX]l00000096Rg`h000000P3oool2000000/0oooo00<000000?oo
o`3oool0103oool00140oooo00<000000?ooo`3oool0@`3oool5000000030?ooo`000000000000X0
000000<0RkKc0000000000000P0000000`2;]O80000008^elP0308^elP800000102<]?4600000005
08fcl0000000SK;_08fbk`000000102=/^l00`000000S[7^08jakP0208jakP@000000P2>/>d>0000
00@0SJg[00<0000008j/jP2>[>X0102>[>X00`000000SZ_Y08j[j@0508j[j@030000002>Z^P0SZ[X
00@0SZ[X00<0000008nYi`2?ZNL01@2?ZNL00`000000SjSW08nXi`0408nXi`030000002?YnH0SjOV
00D0SjOV00<00000092Wi@2@YnD01@2@YnD00`000000T:KT092Vi005092Vi0030000002@YN<0T:GS
00@0T:GS00<00000096ThP2AY>801@2AY>800`000000TJ?Q096Sh@03096ShA0000000P2@XN030000
00<0T:3O0P000002092Pg`80000000@0oooo0000003oool000002`3oool00`000000oooo0?ooo`04
0?ooo`004P3oool00`000000oooo0?ooo`130?ooo`H0000000<0oooo0000000000000P00000308Zg
l`030000002;]_<0RkKc00<0RkKc00<0000008^fl`0000002`00000208bdl@800000102=/o001@00
0000SK;_08fbk`000000SK;_0100000000<0S:o]0000002=[^`01`00000608f]j`030000002>[>X0
SZcZ00@0SZcZ00<0000008j[j@2>ZnT0102>ZnT00`000000SZ[X08jZj00508jZj0030000002?ZNL0
SjWW00@0SjWW00<0000008nXi`2?Z>L01@2?Z>L00`000000SjOV08nWiP0408nWiP030000002@YnD0
T:OU00D0T:OU00<00000092Vi02@Y^@00`2@Y^@G000000<0T:?Q00<00000092Rh@2@X^400P2@X^40
10000000T:;Q092Rh@000002092Qh0030000002@XN00T:7P0080T:7P0P000004092Pg`090000002@
X=l0T:3O092Pg`000000oooo0000003oool0000000`0oooo00<000000?ooo`3oool00`3oool001<0
oooo0P0000140?ooo`030000003oool0000000@0000000<0oooo0000000000000P00000208Zgl`80
00000`2;]_<01P000000RkKc08^fl`000000RkGb00000080RkGb5000000308^ak`8000000P2</>h0
0`000000S;3^08b`kP040000000508b_k@000000S:o]0000002=[^`00P000000102=[^`0000008f^
k000000608f]j`030000002>[>X0SZcZ00@0SZcZ00<0000008j[j@2>ZnT01@2>ZnT00`000000SZ[X
08jZj00408jZj0030000002?ZNL0SjWW00D0SjWW00<0000008nXi`2?Z>L00P2?Z>LG000000<0SjGT
00<0000008nTh`2?Y><01@2?Y><00`000000Sj?R08nShP0508nShP030000002@Xn40T:?Q00D0T:?Q
00<00000092Rh@2@X^400P2@X^401P000000T:;Q092Rh@000000T:7P000000D0T:7P0P000004092P
g`080000002@X=l0T:3O0000003oool000000?ooo`00000<0?ooo`030000003oool0oooo00<0oooo
000E0?ooo`030000003oool0oooo0480oooo1`0000000`3oool0000008Zgl`0@000000<0RKCb0P00
000508Zcl@8000000P2;/_03000000<0Rk7_1@0000000`2</>h0000008b`kP040000000508b_k@00
0000S:o]0000002<[nd00P0000001`2=[^`000000000002=[^`0000008f^k00000001P2=[N/00`00
0000SZcZ08j/jP0408j/jP030000002>ZnT0SZ_Y0080SZ_Y5P00000408jXi`030000002>YnH0SZOV
00@0SZOV00<0000008jVi@2>Y^D01@2>Y^D00`000000SjGT08nUi00508nUi0030000002?Y><0SjCS
00@0SjCS00<0000008nShP2?Xn801P2?Xn801@000000T:?Q092Sh@2@Xn4000000080T:?Q00<00000
092Rh@2@X^400P2@X^4200000005092Rh@000000T:7P092Qh0000000102@XN03000000<0T:3O0P00
0002092Pg`80000000<0oooo0000003oool02`3oool00`000000oooo0?ooo`030?ooo`005P3oool0
0`000000oooo0?ooo`120?ooo`L0000000<0oooo0000000000001P00000208Rel`0400000028]O<0
R;Gc08Rel`8000001@29]?800`000000R[?a08Zcl@0408Zcl@<000000`2;/_000`000000Rk7_08^a
k`0200000080Rk7_1@0000002@2</>h00000000000000000S:o]0000002<[nd0000008b_k@020000
000308f^k0000000SJk/01D00000102<ZnX00`000000SJWY08fYj@0408fYj@030000002=Z>P0SJSX
00D0SJSX00<0000008jXi`2>Z>L0102>Z>L00`000000SZOV08jWiP0508jWiP030000002>Y^D0SZKU
00@0SZKU00<0000008nUi02?YN@01@2?YN@00`000000SjCS08nTh`0508nTh`030000002?Xn80Sj?R
00D0Sj?R00<00000092Sh@2@Xn401@2@Xn402`000000T:;Q092Rh@2@X^400000092Rh@000000T:;Q
0000002@XN00000000D0T:7P100000000`2@X=l0000000000002092Pg`040000003oool0oooo0000
00`0oooo00<000000?ooo`3oool00`3oool001L0oooo0P0000120?ooo`D0000000<0oooo00000000
00000`00000308Rfm00300000028]_@0000000D0000000<0R;Gc0000000000001@29]?800`000000
R[?a08Zcl@030000000308Zcl@000000000000@0Rk;`0P00000308^akaH0000000<0Rjg]00000000
00001P2<[>`00`000000S:_[08b[j`0408b[j`030000002<ZnX0S:_Z00D0S:_Z00<0000008fYj@2=
ZNT0102=ZNT00`000000SJSX08fXj00408fXj0030000002>Z>L0SZSW00D0SZSW00<0000008jWiP2>
YnH0102>YnH00`000000SZKU08jVi@0508jVi@030000002?YN@0SjGT00D0SjGT00<0000008nTh`2?
Y><01@2?Y><00`000000Sj?R08nShP0508nShP030000002@Xn40T:?Q00@0T:?Q00<00000092Rh@2@
X^400P2@X^401P000000T:;Q000000000000T:7P000000D0T:7P0P000002092Pg`L0000000<0oooo
0000003oool02`3oool00`000000oooo0?ooo`030?ooo`006@3oool00`000000oooo0?ooo`100?oo
o`L0000000@0oooo00000000000000000`28]_@00`000000R;Kd0000000208Rel`0300000028]O<0
000001X000000P29/>l20000000308Z_k`00000000000080RZo_0`0000002@2;[^h000000000002;
[^h0000008^]k@000000Rjg]0000000308^]k@030000002<[>`0S:c/00@0S:c/00<0000008b[j`2<
Zn/0102<Zn/00`000000S:_Z08b[jP0408b[jP030000002=ZNT0SJWY00@0SJWY00<0000008fXj02=
Z>P01@2=Z>P00`000000SZSW08jXi`0408jXi`030000002>YnH0SZOV00D0SZOV00<0000008jVi@2>
Y^D0102>Y^D00`000000SjGT08nUi00508nUi0030000002?Y><0SjCS00D0SjCS00<0000008nShP2?
Xn800`2?Xn8P0000000308nOg`000000SioO00<00000303oool00`000000oooo0?ooo`030?ooo`00
6P3oool00`000000oooo0?ooo`100?ooo`H0000000<0oooo0000003oool02`00000408Jdl`030000
0027/o80Qk?b00<0Qk?b00<0000008Rbl@28/_401028/_43000000<0R;7`0`00000208V`k`070000
0029/>l000000000002:[nl0000008Z_k`030000000308^^kP000000Rjk^00H00000102;[Nd00`00
0000S:c/08b/k00408b/k0030000002<Zn/0S:_[00D0S:_[00<0000008b[jP2<ZnX0102<ZnX00`00
0000SJWY08fYj@0408fYj@030000002=Z>P0SJSX00@0SJSX00<0000008jXi`2>Z>L00P2>Z>LW0000
00<0SZ?S00<0000008jRhP2>X^800P2>X^820000000508jRhP000000Sj7Q08nQh@0000000`2?XN43
000000@0Sj3P00<0000008nPh0000000102?Wml01@000000SioO0000002?Wml0000000d0oooo00<0
00000?ooo`3oool00`3oool001/0oooo0P0000110?ooo`L0000000<0oooo00000000000010000002
08Jem00300000026]?<0000000D0Q[Cc00<0000008NclP27/o800`27/o8200000080R;;a0`000002
08Ral080000000<0R;7`0000000000000P29/>l00`000000RK3_08V`k`060000000308Z_k`000000
00000080000000<0Rjk^0000002;[^h00`00000508^]k@030000002<[>`0S:c/00@0S:c/00<00000
08b[j`2<Zn/00P2<Zn/L000000@0S:OW00<0000008fViP2=Y^H01@2=Y^H00`000000SJGU08fUi@04
08fUi@030000002=Y>@0SJCT00D0SJCT00<0000008jTh`2>Y><01@2>Y><00`000000SZ?S08jSh`05
08jSh`030000002>X^80SZ;R0080SZ;R00<0000008jRhP0000000P2?XN400`000000Sj7Q08nQh@02
08nQh@8000001@2?X>000`000000Sj3P0000000308nOg`050000002?Wml0000008nOg`0000003P3o
ool00`000000oooo0?ooo`020?ooo`007@3oool00`000000oooo0?ooo`0n0?ooo`@0000000<0oooo
0000003oool03@00000508Jdl`0300000027/o80Qk?b0080Qk?b1000000308Rbl@0400000028/O00
R;7`08Ral2X00000102:Zn/00`000000Rj[Z08^ZjP0408^ZjP030000002;ZNT0RjWY00@0RjWY00<0
000008bXj02<Z>P0102<Z>P00`000000S:OW08bWi`0408bWi`030000002=Y^H0SJKV00D0SJKV00<0
000008fUi@2=YND01@2=YND00`000000SJCT08fTi00408fTi0030000002>Y><0SZCS00D0SZCS00<0
000008jSh`2>Xn<01@2>Xn<00`000000SZ;R08jRhP0208jRhP80000000D0SZ;R0000002?XN40Sj7Q
0000000408nQh@800000102?X>000`000000Sj3P0000000408nOg`030000002?Wml0000000800000
3@3oool00`000000oooo0?ooo`020?ooo`007P3oool00`000000oooo0?ooo`0n0?ooo`L0000000D0
oooo00000000000000000?ooo`0U00000080Qjo`0`00000208R^k`@0000000D0R:g^00000028[Nh0
000008R]kP02000000D0RJg]00<0000008Z/k02:[>`0102:[>`00`000000RZ_[08Z[j`0408Z[j`03
0000002;Z^X0Rj[Z00@0Rj[Z00<0000008^Yj@2;ZNT0102;ZNT00`000000S:SX08bXj00508bXj003
0000002<YnL0S:OW00@0S:OW00<0000008fViP2=Y^H01@2=Y^H00`000000SJGU08fUi@0408fUi@03
0000002=Y>@0SJCT00D0SJCT00<0000008jTh`2>Y><01@2>Y><00`000000SZ?S08jSh`0508jSh`03
0000002>X^80SZ;R0080SZ;R0P000000102>X^80000008nQh@00000408nQh@@000000P2?X>001000
0000Sj3P08nPh000000308nOg`D000003@3oool00`000000oooo0?ooo`020?ooo`007`3oool20000
03l0oooo0`0000000`3oool0000000000002000000030?ooo`000000oooo00<000001023]?@20000
00D0Q;?d00<0000008Fbl`25/_<00`25/_<200000080Q[7b0`00000308N`l@0400000027/?40Qk3a
00000080Qjo`00<0000008N_l027[o000`0000003028[^l0000008R^k`000000R:k_00000028[Nh0
000008R]kP000000R:g^000000H0RJg]00<0000008Z/k02:[>`0102:[>`00`000000RZ_[08Z[j`05
08Z[j`030000002;Z^X0Rj[Z00@0Rj[Z00<0000008^Yj@2;ZNT0102;ZNT00`000000S:SX08bXj004
08bXj0030000002<YnL0S:OW00D0S:OW00<0000008fViP2=Y^H0102=Y^H00`000000SJGU08fUi@05
08fUi@030000002=Y>@0SJCT00@0SJCT00<0000008jTh`2>Y><01@2>Y><00`000000SZ?S08jSh`04
08jSh`800000102>X^801P000000SZ;R000000000000Sj7Q000000D0Sj7Q00<0000008nPh02?X>00
0P0000001@2?X>00000008nPh0000000SioO00D0000000<0SioO000000000000303oool00`000000
oooo0?ooo`020?ooo`008@3oool00`000000oooo0?ooo`0l0?ooo`D0000000<0oooo000000000000
0P0000020?ooo`<000001023]?@00`000000Q;?d08Bcm00308Bcm00300000025/_<0QK;c00@0QK;c
0`00000308JalP<000000P27/?4010000000Qk3a00000000000208N_l00500000027[o0000000000
0028[^l00P0000000`28[^l0000008R^k`020000000308R]kP000000R:g^00<000001@29[Nd00`00
0000RZc/08Z/k00408Z/k0030000002:Zn/0RZ_[00@0RZ_[00<0000008^ZjP2;Z^X0102;Z^X00`00
0000RjWY08^Yj@0408^Yj@030000002<Z>P0S:SX00D0S:SX00<0000008bWi`2<YnL0102<YnL00`00
0000SJKV08fViP0208fViT<00000303oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000
oooo0?ooo`0l0?ooo``0000000<0oooo00000023]?@01023]?@00`000000Q;?d08Bcm00308Bcm003
00000025/_<0QK;c00<0000000@0QK;c00000000000000000P26/O8200000080Qk3a00<0000008N`
l@000000B`00000408^UiP030000002<YND0S:GU00@0S:GU00<0000008bTi02<Y>@01@2<Y>@00`00
0000S:?T08bSi00408bSi0030000002=X^<0SJ;S00@0SJ;S0P00000308fQhP040000002=XN80SJ7R
08fQhP<00000102=XN42000000@0SZ3P00D0000008jPh02>X>00000008jOg`02000000@0SYoO00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`008`3oool00`000000oooo0?ooo`0l
0?ooo`L0000000<0oooo0000000000008@00000308B_l@D0000000@0QJo`00000026[^l000000P26
[^l010000000QZk_00000027[Nh30000000308N]kP000000Qjc]00D0Qjc]00<0000008R[k028Zn`0
1028Zn`00`000000R:[[08RZj`0408RZj`0300000029ZNX0RJWZ00@0RJWZ00<0000008ZXj@2:Z>T0
102:Z>T00`000000RZOX08ZWj00508ZWj0030000002;Y^L0RjKW00@0RjKW00<0000008^UiP2;YNH0
102;YNH00`000000S:GU08bUi@0508bUi@030000002<Y>@0S:CT00@0S:CT00<0000008bSi02<Xn@0
1@2<Xn@00`000000SJ;S08fRh`0408fRh`8000000`2=XN8010000000SJ7R08fQhP2=XN83000000@0
SJ7Q0P00000408jPh0030000002>X>00SZ3P008000001P2>Wml00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo000T0?ooo`800000?@3oool7000000050?ooo`000000oooo0000003o
ool00P0000000`21/oD0000000000005000000<0P[;d00<0000008>al`23/O<01023/O<200000080
Q;3b0`00000208B_l@0300000024[o40000000<000000P25[o000`000000QJo`0000000200000080
QZk_00P0000008J^k`000000Qjg^00000027[Nh0000008N]kP8000001P27[>d00`000000R:_/08R[
k00408R[k00300000028Z^/0R:[[00@0R:[[00<0000008VYjP29ZNX01029ZNX00`000000RZSY08ZX
j@0408ZXj@030000002:YnP0RZOX00@0RZOX00<0000008^Vi`2;Y^L0102;Y^L00`000000RjGV08^U
iP0508^UiP030000002<YND0S:GU00@0S:GU00<0000008bTi02<Y>@01@2<Y>@00`000000S:?T08bS
i00408bSi0040000002=X^<00000000000<0SJ;S0`00000208fQhP040000002=XN80SJ7R08fQhP80
000000<0SJ7Q0000000000000P2=XN42000000@0SZ3P1000000708jOg`8000002P3oool00`000000
oooo0?ooo`020?ooo`009P3oool00`000000oooo0?ooo`0k0?ooo`<0000000<0oooo000000000000
100000000`3oool000000?ooo`02000000<0PK?e0`00000408:bm08000000P23/O<20000000308>a
l`000000Q;3b008000000P24/?850000000708B_l@000000000008F_l0000000QJo`0000000208F_
l00400000026[^l0000008J^k`D000000P27[Nh00`000000Qjg^0000000608N/k@0300000028Zn`0
R:_/00@0R:_/00<0000008RZj`28Z^/01028Z^/00`000000RJWZ08VYjP0408VYjP030000002:Z>T0
RZSY00<0RZSY00<0000008ZWj02:YnP01@2:YnP00`000000RjKW08^Vi`0408^Vi`030000002;YNH0
RjGV00D0RjGV00<0000008bUi@2<YND0102<YND00`000000S:CT08bTi00508bTi0030000002<Xn@0
S:?T00@0S:?T00<0000008fRh`0000000`2=X^<01P000000SJ;S000000000000SJ7R000000@0SJ7R
0P00000208fQh@80000000<0SJ7Q0000000000000P2>X>040000000308jPh0000000SYoO00H0SYoO
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`009`3oool00`000000oooo0?oo
o`0j0?ooo`X000000P3ooomF00000080RZSY00<0000008ZWj02:YnP0102:YnP00`000000RjKW08^V
i`0408^Vi`030000002;YNH0RjGV00D0RjGV00<0000008bUi@2<YND0102<YND00`000000S:CT08bT
i00508bTi0030000002<Xn@0S:?T00@0S:?T00@0000008fRh`00000000000`2=X^<20000000308fQ
hP000000000000@0SJ7R0P00000408fQh@D0000000<0SZ3P0000000000000P2>X>000`000000SYoO
08jOg`0508jOg`8000002P3oool00`000000oooo0?ooo`010?ooo`00:03oool2000003/0oooo3000
0000103oool0000000000000000307jbm@030000001n/_D0000000<000000P1o/O@200000005086`
l`0000000000086`l`0000000P22/?800`000000P[3b08:`lP020000000408:_l@000000PZoa08:_
l@<000000P23[_000`000000Pjk`0000000200000080Q:g_00D0000008B]k`000000QJc^00000004
08F/kP0300000025Znd0QJ_]00@0QJ_]00<0000008JZk026Z^`01026Z^`00`000000QjW[08NYj`04
08NYj`0300000027Z>/0QjS[00@0QjS[00<0000008RWj@28YnT0F@0000090?ooo`030000003oool0
oooo0040oooo000Z0?ooo`030000003oool0oooo03T0oooo1@0000001@3oool000000?ooo`000000
oooo00`000001@1o/O@2000000@0PK3c0P00000308:`lP<000000P22[o401`000000PZoa08:_l@00
0000Pjk`00000023[_00100000001@24[Nl0000008B]k`000000Q:g_0080000000<0QJc^00000025
[>h00P25[>h00`000000QJ_]08F[k@0308F[k@0300000026Z^`0QZ[/00@0QZ[/00<0000008NYj`27
ZN/01027ZN/00`000000QjS[08NXj`0408NXj`0300000028YnT0R:OY00@0R:OY00<0000008RVj028
Y^P01028Y^P00`000000RJKW08VVi`0408VVi`0300000029YNH0RJGV00D0RJGV00<0000008ZTiP2:
Y>H0102:Y>H00`000000Rj?U08^Si@0508^Si@030000002;X^@0Rj;T00@0Rj;T0P000000102;XN<0
000008^Qh`00000208^Qh`040000002<XN800000000000@0S:7R00<0000008bPh@2<X>400`2<X>42
0000000308bOh0000000S9oP00@0S9oP00<0000008fNg`2=W]l01@2=W]l00`000000oooo00000008
0?ooo`030000003oool0oooo0040oooo000[0?ooo`030000003oool0oooo03T0oooo2@0000000`3o
ool000000?ooo`080000000307jbm@000000Ok7d0080Ok7d1@0000001021/?<00000086`l`000002
08:`lP0600000022/?80000000000022[o4000000P22[o400`000000PZoa000000030000000808>^
l0000000000008B]k`000000Q:g_00000024[Nl3000000@0QJc^00<0000008F[k@25Znd01025Znd0
0`000000QZ[/08JZk00408JZk00300000027ZN/0QjW[00@0QjW[00<0000008NXj`27Z>/01027Z>/0
0`000000R:OY08RWj@0308RWj@0300000028Y^P0R:KX00@0R:KX00<0000008VVi`29Y^L01@29Y^L0
0`000000RJGV08VUiP0408VUiP030000002:Y>H0RZCV00@0RZCV00<0000008^Si@2;XnD01@2;XnD0
0`000000Rj;T08^Ri002000000<0Rj;T00<0000008^Qh`0000000P2;XN<01P000000Rj7S0000002<
XN80000008bQhP8000000P2<XN800`000000S:3Q08bPh@0308bPh@<000001`2<Wn000`000000SIkO
08fNg`0508fNg`800000203oool00`000000oooo0?ooo`010?ooo`00;03oool2000003X0oooo2P00
00001P3oool00000000000000000oooo00000080O;7e;@00000208F/kP0300000025Znd0QJ_]00<0
QJ_]00<0000008JZk026Z^`01026Z^`00`000000QjW[08NYj`0408NYj`0300000027Z>/0QjS[00@0
QjS[00<0000008RWj@28YnT01028YnT00`000000R:KX08RVj00408RVj00300000029Y^L0RJKW00@0
RJKW00<0000008VUiP29YNH01@29YNH00`000000RZCV08ZTiP0408ZTiP030000002;XnD0Rj?U00D0
Rj?U00D0000008^Ri0000000Rj;T0000000208^Ri0060000002;XN<0Rj7S0000002;XN<000000P2;
XN<00`000000S:7R0000000208bQhP80000000<0S:7R0000002<X>400P2<X>44000000L0S9oP00<0
000008fNg`2=W]l01@2=W]l00`000000oooo000000070?ooo`030000003oool0oooo0040oooo000^
0?ooo`030000003oool0oooo03L0oooo1P0000000`3oool0000000000003000000030?ooo`000000
oooo0080000000<0O;7e0000000000000`00000507f`m0030000001n/?<0O[3c00`000000P20[_80
1@000000P:kb00000021[O4000000080PJga0`0000001@22[?00000008:/l0000000PZc`00800000
00<0Pj__000000000000;P00000308VVi`0300000029YNH0RJGV00@0RJGV00<0000008ZTiP2:Y>H0
102:Y>H00`000000Rj?U08^Si@0508^Si@060000002;X^@0Rj;T0000002;X^@000000P2;X^@00`00
0000Rj7S08^Qh`0200000080Rj7S00<0000008bQhP000000102<XN850000000508bPh@000000S:3Q
08bPh@0000001`2<Wn000`000000SIkO08fNg`0508fNg`030000003oool0000000H0oooo00<00000
0?ooo`3oool00@3oool002l0oooo00<000000?ooo`3oool0=`3oool8000000030?ooo`000000oooo
00H000000`1l/OD00`000000O;7e0000000207f`m080000000D0OK3d0000001n/?<0O[3c00000002
07j`l`80000000@0Ojob0000001o[o80Ojob0P0000002@20[_800000082^lP20[_800000086]l@00
0000PJga00000002086]l@0400000022[?00000008:/l0@000001@23Znl00`000000Q:[^08BZkP03
08BZkP0300000024ZNd0Q:W]00@0Q:W]00<0000008FXk025Z>`01025Z>`00`000000QZO[08JWj`04
08JWj`0300000026Y^X0QZKZ00@0QZKZ00<0000008NVj@27Y^T01027Y^T00`000000QjGX08NUj00f
00000080S:3Q00<0000008bOh02<Wn001@2<Wn000`000000SIkO08fNg`0508fNg`040000003oool0
oooo000000H0oooo0@0000010?ooo`40oooo000`0?ooo`800000>03oool00`000000oooo00000008
000000030?ooo`000000000001P0000000T0Ojob000000000000P:kb00000020[_800000082^lP00
00000P21[O4010000000PJga00000021[O440000000308:/l0000000000000D0Pj__00<0000008BZ
kP24Z^h01024Z^h00`000000Q:W]08BYk@0408BYk@0300000025Z>`0QJS/00@0QJS/00<0000008JW
j`26Yn/00`26Yn/00`000000QZKZ08JVjP0508JVjP0300000027Y^T0QjKY00@0QjKY00<0000008NU
j027YNP01027YNP00`000000R:CW08RTi`0408RTi`0300000028XnH0R:?V00@0R:?V00<0000008VR
i@29X^D01029X^D300000080RJ;T00D0000008VRi0000000RJ;T0000000208ZQh`040000002:XN<0
RZ7S08ZQh`8000001@2:X>820000000308^Oh@000000000001@0000000<0oooo0000003oool01@3o
ool100000040oooo0@3oool00380oooo00<000000?ooo`3oool0=@3oool4000000030?ooo`000000
000000@0000000<0oooo0000003oool00`0000040?ooo`800000103oool200000080oooo00D00000
0?ooo`3oool0oooo000000020?oooaX000000P23Znl00`000000Q:[^08BZkP0408BZkP0300000024
ZNd0Q:W]00@0Q:W]00<0000008FXk025Z>`01025Z>`00`000000QZO[08JWj`0308JWj`0300000026
Y^X0QZKZ00@0QZKZ00<0000008NVj@27Y^T01027Y^T00`000000QjGX08NUj00408NUj00300000028
Y>L0R:CW00@0R:CW00<0000008RSiP28XnH01@28XnH00`000000RJ;U08VRi@0408VRi@8000000`29
X^@20000000408VRi0000000RZ7S08ZQh`<0000000<0RZ7S0000000000001P2:X>83000000D0RioQ
00<0000008^Nh02;W^00102;W^000`000000RikO08^Ng`0608^Ng`030000003oool0000000D0oooo
0@0000010?ooo`40oooo000c0?ooo`030000003oool0oooo03D0oooo1`0000000`3oool000000000
0003000000030?ooo`000000oooo00@000000P3oool2000000030?ooo`000000oooo00<0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo000000020?ooo`030000003oool000000080oooo
00<000000?ooo`0000000`0000001`3oool000000?ooo`3oool000000?ooo`0000000`3ooolK0000
0080QZO[00<0000008JVjP26Y^X01@26Y^X00`000000QjKY08NVj@0408NVj@0300000027YNP0QjGX
00@0QjGX00<0000008RTi`28Y>L01028Y>L00`000000R:?V08RSiP0408RSiP0300000029X^D0RJ;U
0080RJ;U00<0000008VRi@0000000P00000308VRi080000000H0RJ;T0000002:XN<0RZ7S0000002:
XN<40000000308ZPhP000000000000@000001P2;Wn400`000000RikP08^Nh00508^Nh0030000002;
W]l0RikO00D0RikO00@000000?ooo`3oool00000103oool100000040oooo0@3oool003@0oooo00<0
00000?ooo`3oool0=@3oool600000080oooo0P0000000`3oool0000000000003000000L0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool01P000000oooo0000003oool000000?ooo`80000000T0oooo0000003oool0oooo0000
003oool000000?ooo`0000007`3ooolM00000080R:CW00<0000008RSiP28XnH01@28XnH01@000000
RJ;U00000029X^D000000080RJ;U0P00000408VRi00300000029X^@000000080RZ7S00@0000008ZQ
h`2:XN<0RZ7S0`00000308ZPhP<000001`2;Wn400`000000RikP08^Nh00408^Nh0030000002;W]l0
RikO00H0RikO00@000000?ooo`3oool000000`3oool100000040oooo0@3oool003D0oooo0P00000f
0?ooo`H0000000<0oooo0000000000000P000000103oool000000?ooo`0000050?ooo`80000000D0
oooo000000000000oooo000000030?ooo`040000003oool0oooo00000080oooo00L000000?ooo`3o
ool000000?ooo`000000oooo00<0000000H0oooo0000003oool000000?ooo`0000020?ooo`030000
003oool0000003`0oooo7P00000308ZQh`8000000`2:X>800`000000RZ3R0000000708^Oh@030000
002;W^00RikP00D0RikP00<0000008^Ng`2;W]l01P2;W]l00`000000oooo000000030?ooo`400000
0@3oool10?ooo`00=`3oool00`000000oooo0?ooo`0c0?ooo`P0000000P0oooo0000000000000000
0?ooo`000000oooo00000080oooo0P0000050?ooo`8000000`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00@0000000@0oooo0000003oool000000P3oool00`000000oooo0000
00020?ooo`030000003oool0000004X0oooo0P0000020?ooo`800000103oool01@000000oooo0000
00000000oooo01P000000`2;W^000`000000RikO08^Ng`0608^Ng`040000003oool0oooo00000080
oooo0@0000010?ooo`40oooo000h0?ooo`030000003oool0oooo03<0oooo100000000`3oool00000
0?ooo`0:000000D0oooo0P0000020?ooo`h000000P3oool01P000000oooo0?ooo`000000oooo0000
0080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`180?ooo`8000000`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000000`3oool4000000l0oooo3P000002
0?ooo`030000003oool000000080oooo000i0?ooo`800000=03oool5000000030?ooo`000000oooo
00<0000000@0oooo000000000000oooo0P0000020?ooo`8000001@3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000020?oo
o`030000003oool000000080oooo00<000000?ooo`000000C03oool200000080oooo0`0000020?oo
o`030000003oool0oooo00<0oooo100000020?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`0000000@3oool003/0oooo00<000000?ooo`3oool0<P3oool6000000080?ooo`00000000000000
003oool000000?ooo`0000020?ooo`8000001P3oool010000000oooo0?ooo`0000020?ooo`070000
003oool0oooo0?ooo`000000oooo000000020?ooo`060000003oool0oooo0000003oool000000P3o
ool01P000000oooo0?ooo`000000oooo000004d0oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0200oooo00<000000?ooo`0000000@3oool003`0oooo00<000000?ooo`3oool0<@3oool<0000
00040?ooo`000000000000000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo04`0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo008000008`3o
ool200000040oooo000m0?ooo`800000<P3oool6000000030?ooo`000000000000<0000000<0oooo
0000003oool00`3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000
0P3oool010000000oooo0?ooo`00001?0?ooo`030000003oool0000000<0oooo0`0000040?ooo`04
0000003oool00000000002<0oooo0`0000010?ooo`00?`3oool00`000000oooo0?ooo`0`0?ooo`L0
000000H0oooo0000003oool000000?ooo`0000040?ooo`<000000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo0000
0080oooo00H000000?ooo`3oool000000?ooo`00001A0?ooo`030000003oool0000000@0oooo2000
000P0?ooo`@00000103oool00400oooo00<000000?ooo`3oool0<03oool8000000050?ooo`000000
00000000003oool00`0000030?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool000000080oooo00@000000?ooo`3oool000000P3oool01`000000oooo0?ooo`000000oooo0000
003oool00P00001A0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0K0?ooo`@00000203oool00440oooo0P00000a0?ooo``000001@3oool200000005
0?ooo`00000000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`000000oooo0`0000000`3oool000000?ooo`1A0?ooo`800000
1@3oool00`000000oooo0?ooo`02000001X0oooo1000000<0?ooo`00@`3oool00`000000oooo0?oo
o`0_0?ooo`L0000000@0oooo0000003oool00000103oool00`000000oooo0?ooo`030?ooo`800000
0`3oool00`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`00
00000P000000103oool000000?ooo`00001D0?ooo`800000103oool00`000000oooo0000000H0?oo
o`@00000403oool004@0oooo00<000000?ooo`3oool0;`3oool6000000030?ooo`000000oooo0080
000000<0oooo0000000000001@3oool00`000000oooo0?ooo`0A00000080oooo00@000000?ooo`3o
ool00000E@3oool7000001D0oooo1000000D0?ooo`00A@3oool00`000000oooo0?ooo`0^0?ooo``0
00001@3oool2000000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000KP3oool4000001P0oooo0016
0?ooo`800000;`3oool8000000030?ooo`000000oooo008000000P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
000000020?ooo`040000003oool0oooo000006X0oooo1000000L0?ooo`00B03oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0000000@0000000<0oooo0000003oool00P3oool2000000@0oooo
0P0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0I03oool400000200oooo00190?oo
o`030000003oool0oooo02`0oooo20000000103oool000000000000000020?ooo`80000000<0oooo
0000003oool00`3oool010000000oooo0?ooo`0000030?ooo`060000003oool0oooo0000003oool0
00000P3oool010000000oooo0?ooo`00001S0?ooo`@00000903oool004X0oooo0P00000/0?ooo`X0
00001P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0G@3o
ool4000002P0oooo001<0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`0000001`000004
0?ooo`80000000D0oooo000000000000oooo000000030?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`0000000`3oool00`000000oooo0000001L0?ooo`@00000;03oool004d0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0700000080oooo0P0000050?ooo`050000003o
ool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0EP3oool400000300oooo001>0?ooo`800000:03oool010000000
oooo0?ooo`3oool3000000030?ooo`0000000000008000001P3oool01P000000oooo000000000000
oooo00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00@000000?ooo`3o
ool00000E03oool4000003@0oooo001@0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool00P3oool7000000@0oooo0P0000040?ooo`8000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0C`3oool4000003P0oooo001A0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool00`3oool5000000050?ooo`0000000000
0?ooo`0000001@3oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`0000000`3oool0
10000000oooo0?ooo`00001<0?ooo`D00000?03oool00580oooo0P00000T0?ooo`030000003oool0
oooo00@0oooo200000040?ooo`8000000`3oool00`000000oooo0?ooo`06000000050?ooo`000000
oooo0?ooo`000000B@3oool400000440oooo001D0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0103oool5000000<0oooo0P0000000`3oool000000?ooo`030?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`05000004D0oooo100000150?ooo`00E@3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo100000030?ooo`<00000103oool0
1@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`100?ooo`@00000B@3oool005H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0000000<000000`3oool2000000030?ooo`000000oooo0080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000003h0oooo1000001=0?ooo`00
E`3oool2000001l0oooo00<000000?ooo`3oool01`3oool3000000H0oooo0P0000040?ooo`040000
003oool0oooo000000<0oooo00@000000?ooo`3oool00000>`3oool400000540oooo001I0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0203oool300000080oooo0`0000020?ooo`80
000000<0oooo0000003oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0=@3oool4000005D0oooo001J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool02@3oool4000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo
000003@0oooo1000001I0?ooo`00F`3oool2000001/0oooo00<000000?ooo`3oool02@3oool40000
00D0oooo0P0000001@3oool000000000003oool0000000<0oooo00@000000?ooo`3oool00000<03o
ool4000005d0oooo001M0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool5
000000030?ooo`000000000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo02/0oooo1000001Q0?ooo`00GP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00/0oooo0P0000000`3oool00000000000060?ooo`060000003oool000000000003oool00000
0P3oool00`000000oooo0?ooo`0W0?ooo`@00000I@3oool005l0oooo0P00000G0?ooo`030000003o
ool0oooo00`0oooo0P0000020?ooo`040000003oool0oooo0?ooo`800000103oool2000000030?oo
o`000000oooo02D0oooo1000001Y0?ooo`00H@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00d0oooo1@0000000`3oool000000?ooo`040?ooo`030000003oool0oooo008000008P3o
ool4000006d0oooo001R0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`02000000@0oooo0P0000030?ooo`030000003oool0oooo01d0oooo1000001a
0?ooo`00H`3oool200000180oooo00<000000?ooo`3oool0403oool3000000050?ooo`0000000000
0?ooo`000000103oool00`000000oooo0?ooo`0I0?ooo`D00000M@3oool006D0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0000000<00000103oool00`00
0000oooo0?ooo`0F0?ooo`@00000NP3oool006H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo0P0000000`3oool000000?ooo`0D0?ooo`@0
0000OP3oool006L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`L00000
4P3oool400000880oooo001X0?ooo`8000003@3oool00`000000oooo0?ooo`0X0?ooo`@00000QP3o
ool006X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0T0?ooo`@00000RP3oool0
06/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`@00000SP3oool006`0
oooo0P0000090?ooo`030000003oool0oooo01`0oooo1000002B0?ooo`00KP3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01P0oooo1000002F0?ooo`00K`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01@0oooo1000002J0?ooo`00L03oool2000000D0oooo00<00000
0?ooo`3oool0403oool4000009h0oooo001b0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0303oool400000:80oooo001c0?ooo`050000003oool0oooo0?ooo`0000002P3oool40000
0:H0oooo001d0?ooo`80000000<0oooo0000003oool01@3oool400000:X0oooo001f0?ooo`800000
0P3oool400000:h0oooo001g0?ooo`<00000/P3oool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {276.125, 0}} -> {-0.000218584, 0.0138115, \
0.00318408, 0.00318408}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->{},
WindowSize->{494, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 53, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1832, 56, 407, 15, 50, "Usage",
      CellTags->"Function?"],
    Cell[2242, 73, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 282836, 12422}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 53, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1832, 56, 407, 15, 50, "Usage",
  CellTags->"Function?"],
Cell[2242, 73, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2339, 78, 157, 3, 58, "MathCaption"],
Cell[2499, 83, 321, 13, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[2845, 100, 33, 0, 39, "ExampleSection"],
Cell[2881, 102, 97, 2, 29, "Input"],
Cell[2981, 106, 65, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[3071, 110, 380, 8, 113, "Input"],
Cell[3454, 120, 278691, 12280, 284, 156688, 10770, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

