(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5850,        181]*)
(*NotebookOutlinePosition[      6821,        215]*)
(*  CellTagsIndexPosition[      6747,        209]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawContourLines", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["DrawContourLines",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(f[x, y], {x, xmin, xmax}, {y, ymin, ymax}, opt\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will extract the 2D contours from a ContourPlot and raise them to \
primitive Graphics3D Lines."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell[TextData[{
  Cell[BoxData[
      \(f[x, y]\)]],
  " must be a defined function, not just an expression."
}], "MathCaption"],

Cell["\<\
In plotting contours of a surface, it is useful to lower the surface slightly \
and possibly use many plot points so it will not intersect the contours.\
\>", "MathCaption"],

Cell[TextData[{
  "Alternatively, the option ",
  Cell[BoxData[
      \(DrawContourOffset\)]],
  " can be used to offset the contour lines. The default offset is ",
  Cell[BoxData[
      \({0, 0, 0}\)]],
  "."
}], "MathCaption"],

Cell["\<\
DrawContourLines just picks off the contour lines and not any styles \
associated with them. Any desired styles can be given preceeding \
DrawContourLines.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ContourDraw",
    ButtonData:>{"ContourDraw"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
The following draws contours of constant energy on a Keplerian phase space \
portrait. The surface and contour lines were broken into several sections to \
obtain a better representation. The graphical elements were calculated \
outside the Draw3DItems statement to save recalculation time while perfecting \
each part.\
\>", "Text"],

Cell[BoxData[
    \(energy[r_, v_] := v\^2/2 + 1/r\^2 - 4/r\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[{
    \(\(surfacea = 
        Draw3D[energy[r, v] // Evaluate, {r, 0.1, 1}, {v, \(-5\), 
            5}];\)\), "\n", 
    \(\(surfaceb = 
        Draw3D[energy[r, v] // Evaluate, {r, 1, 7}, {v, \(-5\), 
            5}];\)\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[{
    \(\(contourlinesa = 
        DrawContourLines[energy[r, v], {r, 0.2, 7}, {v, \(-5\), 5}, 
          Contours \[Rule] Range[\(-3\), 2, 0.5], PlotPoints \[Rule] 50, 
          DrawContourOffset \[Rule] {0, 0, 0.3}];\)\), "\n", 
    \(\(contourlinesb = 
        DrawContourLines[energy[r, v], {r, 0.1, 7}, {v, \(-5\), 5}, 
          Contours \[Rule] {3, 4, 5, 6, 7}, PlotPoints \[Rule] 50, 
          DrawContourOffset \[Rule] {0.1, 0, 1}];\)\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{EdgeForm[], surfacea, 
          surfaceb, \[IndentingNewLine]White, contourlinesa, 
          contourlinesb}, \[IndentingNewLine]PlotRange \[Rule] {All, 
            All, {\(-4\), 8}}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            0.5}, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]AxesLabel \[Rule] {r, 
            v, "\<E\>"}, \[IndentingNewLine]AxesEdge \[Rule] {{\(-1\), \
\(-1\)}, {1, \(-1\)}, {\(-1\), \(-1\)}}, 
        ViewPoint -> {1.348, \ \(-0.997\), \ 2.939}, 
        Background \[Rule] 
          GrayLevel[
            0.2], \[IndentingNewLine]TextStyle \[Rule] {FontFamily \[Rule] \
"\<Helvetica\>", FontSize \[Rule] 12, FontWeight \[Rule] "\<Bold\>"}, 
        PlotRegion \[Rule] {{0.05, 0.95}, {0, 
              1}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Keplerian Radial \
Phase Portrait\>", \[IndentingNewLine]ImageSize \[Rule] 400];\)\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(Clear[energy, surfacea, surfaceb, contourlinesa, 
      contourlinesb]\)], "Input",
  CellLabel->"In[8]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{548, 705},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 63, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1842, 56, 437, 15, 50, "Usage",
      CellTags->"Function?"],
    Cell[2282, 73, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6501, 198}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 63, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1842, 56, 437, 15, 50, "Usage",
  CellTags->"Function?"],
Cell[2282, 73, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2379, 78, 128, 4, 41, "MathCaption"],
Cell[2510, 84, 183, 3, 58, "MathCaption"],
Cell[2696, 89, 228, 8, 58, "MathCaption"],
Cell[2927, 99, 186, 4, 58, "MathCaption"],
Cell[3116, 105, 211, 8, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3352, 117, 33, 0, 39, "ExampleSection"],
Cell[3388, 119, 97, 2, 29, "Input"],
Cell[3488, 123, 343, 6, 59, "Text"],
Cell[3834, 131, 96, 2, 29, "Input"],
Cell[3933, 135, 272, 7, 49, "Input"],
Cell[4208, 144, 496, 9, 129, "Input"],
Cell[4707, 155, 985, 17, 289, "Input"],
Cell[5695, 174, 127, 3, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

