(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    353834,      16277]*)
(*NotebookOutlinePosition[    354809,      16311]*)
(*  CellTagsIndexPosition[    354731,      16305]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawGradientField3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["DrawGradientField",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(f, {x, x0, x1, \ \((xu)\)}, {y, y0, y1, \((yu)\)}, {z, z0, 
            z1, \((zu)\)}, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " extracts the graphics primitives from the corresponding \
PlotGradientField3D statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as PlotGradientField3D. Regular PlotGradientField3D options \
may be used. Basic Graphics3D options, such as PlotRange have no effect.\
\>", "MathCaption"],

Cell[TextData[{
  "Also consider using lists of ",
  ButtonBox["Arrow3D",
    ButtonData:>{"Arrow3D"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawVectorField3D",
    ButtonData:>{"DrawVectorField3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ListDrawVectorField3D",
    ButtonData:>{"ListDrawVectorField3D"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["PlotGradientField3D",
    ButtonData:>{"Graphics`PlotField3D`", "1.3"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Here, a gradient field is drawn on top of a single contour plot of the same \
function. Since calculating the contour takes some time, it was done outside \
the plotting statement so the rest of the plot could be perfected without \
recalculation. NeutralLighting was used to give a nice color to the constant \
surface.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(contour = 
        ContourDraw3D[
          x\ y\ z, {x, \(-1\), 1}, {y, \(-1\), 1}, {z, \(-1\), 1}, 
          Contours \[Rule] {0.05}, PlotPoints \[Rule] {5, 5}];\)\)], "Input",
  CellLabel->"In[307]:="],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(contour\\)\\\" is similar to existing symbol \
\\\"\\!\\(contours\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[307]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{SurfaceColor[SteelBlue, SteelBlue, 
            2], contour, \[IndentingNewLine]IndianRed, \
\[IndentingNewLine]DrawGradientField3D[
            x\ y\ z, {x, \(-1\), 1}, {y, \(-1\), 1}, {z, \(-1\), 1}, 
            VectorHeads \[Rule] True]}, \[IndentingNewLine]NeutralLighting[
          0.3, 0.5, 0.1], \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]Boxed \[Rule] 
          False, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)], "Input",
  CellLabel->"In[308]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.08567 
%%ImageSize: 400 434.267 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-0.0567956 1.16621 -1.23762e-016 1.16621 [
[ 0 0 0 0 ]
[ 1 1.08567 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.08567 L
0 1.08567 L
closepath
clip
newpath
.69 .09 .12 r
.5 Mabswid
[ ] 0 setdash
.42214 .5817 m
.42315 .59198 L
s
.4266 .5715 m
.42214 .5817 L
s
.42214 .5817 m
.41481 .57999 L
s
.43493 .58349 m
.42214 .5817 L
s
.43617 .58189 m
.42214 .5817 L
s
.42315 .59198 m
.43493 .58349 L
s
.43493 .58349 m
.4266 .5715 L
s
.4266 .5715 m
.41481 .57999 L
s
.41481 .57999 m
.42315 .59198 L
s
.47808 .56499 m
.48072 .57218 L
s
.48459 .5561 m
.47808 .56499 L
s
.47808 .56499 m
.47516 .56178 L
s
.49013 .56647 m
.47808 .56499 L
s
.50141 .56062 m
.47808 .56499 L
s
.48072 .57218 m
.49013 .56647 L
s
.49013 .56647 m
.48459 .5561 L
s
.48459 .5561 m
.47516 .56178 L
s
.47516 .56178 m
.48072 .57218 L
s
.42517 .63004 m
.42528 .64074 L
s
.42867 .62449 m
.42517 .63004 L
s
.42517 .63004 m
.41879 .63124 L
s
.43515 .634 m
.42517 .63004 L
s
.43439 .6432 m
.42517 .63004 L
s
.39625 .55053 m
.39609 .55728 L
s
.39696 .54052 m
.39625 .55053 L
s
.39625 .55053 m
.38805 .54843 L
s
.405 .54936 m
.39625 .55053 L
s
.39766 .54219 m
.39625 .55053 L
s
.42528 .64074 m
.43515 .634 L
s
.43515 .634 m
.42867 .62449 L
s
.41879 .63124 m
.42528 .64074 L
s
.42867 .62449 m
.41879 .63124 L
s
.39696 .54052 m
.38805 .54843 L
s
.405 .54936 m
.39696 .54052 L
s
.39609 .55728 m
.405 .54936 L
s
.38805 .54843 m
.39609 .55728 L
s
.53636 .54757 m
.54128 .55199 L
s
.54408 .5397 m
.53636 .54757 L
s
.53636 .54757 m
.53767 .54299 L
s
.54767 .54868 m
.53636 .54757 L
s
.56834 .5388 m
.53636 .54757 L
s
.54128 .55199 m
.54767 .54868 L
s
.54767 .54868 m
.54408 .5397 L
s
.54408 .5397 m
.53767 .54299 L
s
.48504 .61637 m
.48621 .62376 L
s
.49011 .61132 m
.48504 .61637 L
s
.48504 .61637 m
.48235 .61577 L
s
.49397 .6193 m
.48504 .61637 L
s
.50091 .6223 m
.48504 .61637 L
s
.53767 .54299 m
.54128 .55199 L
s
.48621 .62376 m
.49397 .6193 L
s
.49397 .6193 m
.49011 .61132 L
s
.4534 .52879 m
.45465 .53336 L
s
.45632 .52072 m
.4534 .52879 L
s
.4534 .52879 m
.44916 .5259 L
s
.4618 .52818 m
.4534 .52879 L
s
.46398 .51989 m
.4534 .52879 L
s
.48235 .61577 m
.48621 .62376 L
s
.49011 .61132 m
.48235 .61577 L
s
.45465 .53336 m
.4618 .52818 L
s
.4618 .52818 m
.45632 .52072 L
s
.45632 .52072 m
.44916 .5259 L
s
.42836 .68097 m
.42752 .69191 L
s
.43085 .68026 m
.42836 .68097 L
s
.42836 .68097 m
.42243 .68499 L
s
.43592 .68719 m
.42836 .68097 L
s
.43253 .70697 m
.42836 .68097 L
s
.44916 .5259 m
.45465 .53336 L
s
.42752 .69191 m
.43592 .68719 L
s
.42243 .68499 m
.42752 .69191 L
s
.39447 .60084 m
.39422 .60806 L
s
.39495 .59494 m
.39447 .60084 L
s
.39447 .60084 m
.388 .60115 L
s
.40117 .60185 m
.39447 .60084 L
s
.39506 .60418 m
.39447 .60084 L
s
.43592 .68719 m
.43085 .68026 L
s
.43085 .68026 m
.42243 .68499 L
s
.39422 .60806 m
.40117 .60185 L
s
.40117 .60185 m
.39495 .59494 L
s
.388 .60115 m
.39422 .60806 L
s
.36879 .51746 m
.36673 .5207 L
s
.36632 .50759 m
.36879 .51746 L
s
.36879 .51746 m
.35969 .51489 L
s
.37337 .51339 m
.36879 .51746 L
s
.35728 .50056 m
.36879 .51746 L
s
.39495 .59494 m
.388 .60115 L
s
.36632 .50759 m
.35969 .51489 L
s
.37337 .51339 m
.36632 .50759 L
s
.60521 .53186 m
.60794 .53023 L
s
.60794 .53023 m
.60495 .5218 L
s
.60794 .53023 m
.59715 .52941 L
s
.60495 .5218 m
.6022 .5234 L
s
.60495 .5218 m
.59715 .52941 L
s
.35969 .51489 m
.36673 .5207 L
s
.59715 .52941 m
.60521 .53186 L
s
.59715 .52941 m
.6022 .5234 L
s
.36673 .5207 m
.37337 .51339 L
s
.5473 .60216 m
.5502 .60644 L
s
.55307 .59736 m
.5473 .60216 L
s
.5473 .60216 m
.54804 .59992 L
s
.55522 .60388 m
.5473 .60216 L
s
.56919 .60085 m
.5473 .60216 L
s
.6022 .5234 m
.60521 .53186 L
s
.5502 .60644 m
.55522 .60388 L
s
.55522 .60388 m
.55307 .59736 L
s
.55307 .59736 m
.54804 .59992 L
s
.442 .763 1 r
.61209 .50451 m .62661 .5198 L .62587 .54337 L p F P
0 0 0 r
s
.69 .09 .12 r
.62661 .5198 m
.63702 .51641 L
s
.59715 .52941 m
.61845 .52246 L
s
.54804 .59992 m
.5502 .60644 L
s
.51288 .50617 m
.51585 .50883 L
s
.5175 .49988 m
.51288 .50617 L
s
.51288 .50617 m
.51258 .50258 L
s
.52076 .50612 m
.51288 .50617 L
s
.53205 .49699 m
.51288 .50617 L
s
.51585 .50883 m
.52076 .50612 L
s
.52076 .50612 m
.5175 .49988 L
s
.5175 .49988 m
.51258 .50258 L
s
.49236 .67041 m
.49197 .67783 L
s
.49592 .66934 m
.49236 .67041 L
s
.49236 .67041 m
.48951 .67229 L
s
.49838 .67489 m
.49236 .67041 L
s
.50039 .68649 m
.49236 .67041 L
s
.51258 .50258 m
.51585 .50883 L
s
.49197 .67783 m
.49838 .67489 L
s
.49838 .67489 m
.49592 .66934 L
s
.48951 .67229 m
.49197 .67783 L
s
.4556 .58215 m
.45618 .58705 L
s
.45782 .57729 m
.4556 .58215 L
s
.4556 .58215 m
.45222 .58134 L
s
.46178 .58301 m
.4556 .58215 L
s
.4627 .58225 m
.4556 .58215 L
s
.49592 .66934 m
.48951 .67229 L
s
.45 .778 1 r
.61103 .52825 m .62587 .54337 L .62462 .56745 L p F P
0 0 0 r
s
.442 .763 1 r
.62587 .54337 m .61103 .52825 L .61209 .50451 L p F P
0 0 0 r
s
.69 .09 .12 r
.45618 .58705 m
.46178 .58301 L
s
.46178 .58301 m
.45782 .57729 L
s
.45782 .57729 m
.45222 .58134 L
s
.45222 .58134 m
.45618 .58705 L
s
.446 .771 1 r
.59681 .48911 m .61209 .50451 L .61103 .52825 L p F P
0 0 0 r
s
.69 .09 .12 r
.42727 .49045 m
.42674 .49249 L
s
.42679 .48316 m
.42727 .49045 L
s
.42727 .49045 m
.42175 .48792 L
s
.43178 .48772 m
.42727 .49045 L
s
.4247 .47714 m
.42727 .49045 L
s
.43172 .73471 m
.43477 .7454 L
s
.42822 .73932 m
.43172 .73471 L
s
.43172 .73471 m
.42592 .74401 L
s
.43709 .74072 m
.43172 .73471 L
s
.43477 .7454 m
.43709 .74072 L
s
.42592 .74401 m
.43477 .7454 L
s
.42679 .48316 m
.42175 .48792 L
s
.43178 .48772 m
.42679 .48316 L
s
.42175 .48792 m
.42674 .49249 L
s
.42674 .49249 m
.43178 .48772 L
s
.42822 .73932 m
.42592 .74401 L
s
.3926 .65386 m
.39227 .66137 L
s
.39283 .65222 m
.3926 .65386 L
s
.3926 .65386 m
.38751 .65654 L
s
.39759 .65706 m
.3926 .65386 L
s
.39235 .66874 m
.3926 .65386 L
s
.6724 .51219 m
.67088 .51139 L
s
.67088 .51139 m
.6676 .5019 L
s
.67088 .51139 m
.66061 .51044 L
s
.6676 .5019 m
.66911 .50266 L
s
.6676 .5019 m
.66061 .51044 L
s
.46 .799 1 r
.60937 .55252 m .62462 .56745 L .62255 .59213 L p F P
0 0 0 r
s
.45 .778 1 r
.62462 .56745 m .60937 .55252 L .61103 .52825 L p F P
0 0 0 r
s
.69 .09 .12 r
.43709 .74072 m
.42822 .73932 L
s
.39227 .66137 m
.39759 .65706 L
s
.38751 .65654 m
.39227 .66137 L
s
.70753 .49342 m
.66061 .51044 L
s
.39759 .65706 m
.39283 .65222 L
s
.454 .786 1 r
.59534 .51304 m .61103 .52825 L .60937 .55252 L p F P
0 0 0 r
s
.446 .771 1 r
.61103 .52825 m .59534 .51304 L .59681 .48911 L p F P
0 0 0 r
s
.69 .09 .12 r
.66061 .51044 m
.6724 .51219 L
s
.66061 .51044 m
.66911 .50266 L
s
.39283 .65222 m
.38751 .65654 L
s
.36192 .56989 m
.36062 .57352 L
s
.36 .56363 m
.36192 .56989 L
s
.36192 .56989 m
.35538 .56909 L
s
.36524 .56805 m
.36192 .56989 L
s
.35377 .56323 m
.36192 .56989 L
s
.61762 .58917 m
.61945 .58791 L
s
.61741 .58217 m
.61945 .58791 L
s
.61209 .58737 m
.61945 .58791 L
s
.61557 .58342 m
.61741 .58217 L
s
.61209 .58737 m
.61741 .58217 L
s
.61209 .58737 m
.61762 .58917 L
s
.61209 .58737 m
.61557 .58342 L
s
.62324 .58387 m
.6393 .57882 L
s
.61209 .58737 m
.62013 .58485 L
s
.45 .778 1 r
.58046 .4737 m .59681 .48911 L .59534 .51304 L p F P
0 0 0 r
s
.69 .09 .12 r
.66911 .50266 m
.6724 .51219 L
s
.36 .56363 m
.35538 .56909 L
s
.36524 .56805 m
.36 .56363 L
s
.35538 .56909 m
.36062 .57352 L
s
.61557 .58342 m
.61762 .58917 L
s
.36062 .57352 m
.36524 .56805 L
s
.482 .924 1 r
.4566 .75433 m .43089 .76324 L .41583 .74795 L p F P
0 0 0 r
s
.69 .09 .12 r
.4306 .77338 m
.43089 .76324 L
s
.43127 .75037 m
.43172 .73471 L
s
.58029 .48419 m
.58222 .48319 L
s
.58016 .4774 m
.58222 .48319 L
s
.57482 .48261 m
.58222 .48319 L
s
.58016 .4774 m
.57822 .47839 L
s
.58016 .4774 m
.57482 .48261 L
s
.57482 .48261 m
.58029 .48419 L
s
.57482 .48261 m
.57822 .47839 L
s
.57482 .48261 m
.58281 .47992 L
s
.55877 .65945 m
.55953 .66343 L
s
.5625 .65785 m
.55877 .65945 L
s
.55877 .65945 m
.55874 .65942 L
s
.5633 .66186 m
.55877 .65945 L
s
.57008 .66546 m
.55877 .65945 L
s
.33962 .48234 m
.3344 .4824 L
s
.33505 .47222 m
.33962 .48234 L
s
.33962 .48234 m
.3292 .47925 L
s
.34027 .47534 m
.33962 .48234 L
s
.474 .828 1 r
.60676 .57744 m .62255 .59213 L .61902 .61761 L p F P
0 0 0 r
s
.46 .799 1 r
.62255 .59213 m .60676 .57744 L .60937 .55252 L p F P
0 0 0 r
s
.69 .09 .12 r
.55953 .66343 m
.5633 .66186 L
s
.5633 .66186 m
.5625 .65785 L
s
.33505 .47222 m
.3292 .47925 L
s
.34027 .47534 m
.33505 .47222 L
s
.5625 .65785 m
.55874 .65942 L
s
.55874 .65942 m
.55953 .66343 L
s
.3292 .47925 m
.3344 .4824 L
s
.464 .807 1 r
.59316 .53754 m .60937 .55252 L .60676 .57744 L p F P
0 0 0 r
s
.454 .786 1 r
.60937 .55252 m .59316 .53754 L .59534 .51304 L p F P
0 0 0 r
s
.69 .09 .12 r
.57822 .47839 m
.58029 .48419 L
s
.51908 .56274 m
.52084 .56547 L
s
.52251 .55882 m
.51908 .56274 L
s
.51908 .56274 m
.51875 .56092 L
s
.5246 .56337 m
.51908 .56274 L
s
.53217 .55972 m
.51908 .56274 L
s
.485 .927 1 r
.48254 .74485 m .4566 .75433 L .4417 .73868 L p F P
0 0 0 r
s
.482 .924 1 r
.41583 .74795 m .4417 .73868 L .4566 .75433 L p F P
0 0 0 r
s
.458 .793 1 r
.57844 .49787 m .59534 .51304 L .59316 .53754 L p F P
0 0 0 r
s
.45 .778 1 r
.59534 .51304 m .57844 .49787 L .58046 .4737 L p F P
0 0 0 r
s
.69 .09 .12 r
.58607 .47882 m
.60195 .47349 L
s
.58594 .47887 m
.58607 .47882 L
s
.3344 .4824 m
.34027 .47534 L
s
.52084 .56547 m
.5246 .56337 L
s
.5246 .56337 m
.52251 .55882 L
s
.52251 .55882 m
.51875 .56092 L
s
.452 .783 1 r
.56239 .45852 m .58046 .4737 L .57844 .49787 L p F P
0 0 0 r
s
.69 .09 .12 r
.51875 .56092 m
.52084 .56547 L
s
.77993 .46981 m
.72691 .49063 L
s
.488 .858 1 r
.61902 .61761 m .61423 .63884 L .60037 .61236 L p F P
0 0 0 r
s
.488 .858 1 r
.60037 .61236 m .60247 .60324 L .61902 .61761 L p F P
0 0 0 r
s
.474 .828 1 r
.61902 .61761 m .60247 .60324 L .60676 .57744 L p F P
0 0 0 r
s
.69 .09 .12 r
.50006 .7273 m
.50214 .73455 L
s
.481 .921 1 r
.4417 .73868 m .41583 .74795 L .40051 .7319 L p F P
0 0 0 r
s
.69 .09 .12 r
.48804 .46238 m
.48899 .46339 L
s
.48944 .45769 m
.48804 .46238 L
s
.48804 .46238 m
.48615 .45996 L
s
.49228 .46111 m
.48804 .46238 L
s
.49394 .45309 m
.48804 .46238 L
s
.488 .931 1 r
.50873 .73451 m .48254 .74485 L .46781 .72877 L p F P
0 0 0 r
s
.69 .09 .12 r
.50262 .73366 m
.50386 .73136 L
s
.49985 .75337 m
.49998 .73797 L
s
.50001 .73329 m
.50006 .7273 L
s
.50006 .7273 m
.50386 .73136 L
s
.49667 .73282 m
.50006 .7273 L
s
.49789 .73041 m
.50006 .7273 L
s
.485 .927 1 r
.4417 .73868 m .46781 .72877 L .48254 .74485 L p F P
0 0 0 r
s
.69 .09 .12 r
.49661 .73281 m
.49789 .73041 L
s
.48944 .45769 m
.48615 .45996 L
s
.49228 .46111 m
.48944 .45769 L
s
.478 .837 1 r
.58987 .56275 m .60676 .57744 L .60247 .60324 L p F P
0 0 0 r
s
.464 .807 1 r
.60676 .57744 m .58987 .56275 L .59316 .53754 L p F P
0 0 0 r
s
.69 .09 .12 r
.48899 .46339 m
.49228 .46111 L
s
.45791 .63826 m
.45779 .64334 L
s
.4594 .63673 m
.45791 .63826 L
s
.45791 .63826 m
.45513 .63945 L
s
.46206 .64062 m
.45791 .63826 L
s
.46137 .64722 m
.45791 .63826 L
s
.49789 .73041 m
.50386 .73136 L
s
.48615 .45996 m
.48899 .46339 L
s
.235 .409 .6 r
.3207 .48789 m .32138 .46353 L .34771 .45541 L p F P
0 0 0 r
s
.69 .09 .12 r
.31488 .45684 m
.32138 .46353 L
s
.33192 .4744 m
.33962 .48234 L
s
.466 .811 1 r
.57558 .52265 m .59316 .53754 L .58987 .56275 L p F P
0 0 0 r
s
.458 .793 1 r
.59316 .53754 m .57558 .52265 L .57844 .49787 L p F P
0 0 0 r
s
.69 .09 .12 r
.45779 .64334 m
.46206 .64062 L
s
.45513 .63945 m
.45779 .64334 L
s
.46206 .64062 m
.4594 .63673 L
s
.4594 .63673 m
.45513 .63945 L
s
.7424 .49291 m
.73609 .49208 L
s
.73609 .49208 m
.73281 .47998 L
s
.73609 .49208 m
.72691 .49063 L
s
.494 .936 1 r
.53513 .72273 m .50873 .73451 L .49417 .71788 L p F P
0 0 0 r
s
.488 .931 1 r
.46781 .72877 m .49417 .71788 L .50873 .73451 L p F P
0 0 0 r
s
.455 .789 1 r
.55962 .48298 m .57844 .49787 L .57558 .52265 L p F P
0 0 0 r
s
.452 .783 1 r
.57844 .49787 m .55962 .48298 L .56239 .45852 L p F P
0 0 0 r
s
.484 .923 1 r
.46781 .72877 m .4417 .73868 L .42655 .72219 L p F P
0 0 0 r
s
.481 .921 1 r
.40051 .7319 m .42655 .72219 L .4417 .73868 L p F P
0 0 0 r
s
.496 .877 1 r
.61258 .64431 m .61423 .63884 L .60037 .61236 L p F P
0 0 0 r
s
.69 .09 .12 r
.42443 .54592 m
.42407 .54829 L
s
.42405 .54128 m
.42443 .54592 L
s
.42443 .54592 m
.42047 .54485 L
s
.42765 .54471 m
.42443 .54592 L
s
.42256 .54018 m
.42443 .54592 L
s
.73281 .47998 m
.73911 .48075 L
s
.73281 .47998 m
.72691 .49063 L
s
.445 .77 1 r
.5458 .44684 m .56239 .45852 L .55962 .48298 L p F P
0 0 0 r
s
.508 .913 1 r
.59484 .6304 m .61258 .64431 L .59886 .67351 L p F P
0 0 0 r
s
.496 .877 1 r
.60037 .61236 m .59484 .6304 L .61258 .64431 L p F P
0 0 0 r
s
.69 .09 .12 r
.68833 .57232 m
.68655 .57182 L
s
.68655 .57182 m
.68356 .5653 L
s
.68655 .57182 m
.67959 .57196 L
s
.71131 .5562 m
.67959 .57196 L
s
.68356 .5653 m
.68533 .56577 L
s
.68356 .5653 m
.67959 .57196 L
s
.42405 .54128 m
.42047 .54485 L
s
.42765 .54471 m
.42405 .54128 L
s
.42047 .54485 m
.42407 .54829 L
s
.42407 .54829 m
.42765 .54471 L
s
.24 .418 .612 r
.34736 .47996 m .34771 .45541 L .37459 .44755 L p F P
0 0 0 r
s
.235 .409 .6 r
.34771 .45541 m .34736 .47996 L .3207 .48789 L p F P
0 0 0 r
s
.502 .949 1 r
.55638 .71142 m .53513 .72273 L .52075 .70535 L p F P
0 0 0 r
s
.494 .936 1 r
.49417 .71788 m .52075 .70535 L .53513 .72273 L p F P
0 0 0 r
s
.69 .09 .12 r
.43234 .80224 m
.44105 .80275 L
s
.42684 .8006 m
.43234 .80224 L
s
.43234 .80224 m
.43528 .7915 L
s
.484 .851 1 r
.60037 .61236 m .60247 .60324 L .59194 .59464 L closepath p F P
0 0 0 r
s
.478 .837 1 r
.58628 .58183 m .58987 .56275 L p .60247 .60324 L F P
0 0 0 r
s
.478 .837 1 r
.60247 .60324 m .59194 .59464 L .58628 .58183 L p F P
0 0 0 r
s
.69 .09 .12 r
.67959 .57196 m
.68833 .57232 L
s
.67959 .57196 m
.68533 .56577 L
s
.479 .914 1 r
.42655 .72219 m .40051 .7319 L .38495 .71478 L p F P
0 0 0 r
s
.487 .925 1 r
.49417 .71788 m .46781 .72877 L .45283 .71175 L p F P
0 0 0 r
s
.484 .923 1 r
.42655 .72219 m .45283 .71175 L .46781 .72877 L p F P
0 0 0 r
s
.69 .09 .12 r
.73911 .48075 m
.7424 .49291 L
s
.72691 .49063 m
.7424 .49291 L
s
.72691 .49063 m
.73911 .48075 L
s
.68533 .56577 m
.68833 .57232 L
s
.473 .826 1 r
.58628 .58183 m .58987 .56275 L .57369 .54995 L closepath p F P
0 0 0 r
s
.466 .811 1 r
.57197 .54511 m .57558 .52265 L p .58987 .56275 L F P
0 0 0 r
s
.466 .811 1 r
.58987 .56275 m .57369 .54995 L .57197 .54511 L p F P
0 0 0 r
s
.241 .419 .615 r
.32033 .51291 m .3207 .48789 L .34736 .47996 L p F P
0 0 0 r
s
.69 .09 .12 r
.43528 .7915 m
.43556 .80111 L
s
.43528 .7915 m
.44105 .80275 L
s
.42684 .8006 m
.43528 .7915 L
s
.42859 .84257 m
.43528 .7915 L
s
.49 .866 1 r
.59484 .6304 m .60037 .61236 L .59194 .59464 L p F P
0 0 0 r
s
.69 .09 .12 r
.44105 .80275 m
.43556 .80111 L
s
.3965 .44289 m
.39955 .44978 L
s
.39955 .44978 m
.39255 .44765 L
s
.502 .949 1 r
.52075 .70535 m .5299 .70045 L .55638 .71142 L p F P
0 0 0 r
s
.504 .947 1 r
.5475 .68963 m .5299 .70045 L .55638 .71142 L p F P
0 0 0 r
s
.504 .947 1 r
.55638 .71142 m .56171 .70816 L .5475 .68963 L p F P
0 0 0 r
s
.69 .09 .12 r
.64791 .46011 m
.64622 .45959 L
s
.64622 .45959 m
.64464 .45251 L
s
.64622 .45959 m
.63939 .45805 L
s
.67375 .44934 m
.63939 .45805 L
s
.521 .953 1 r
.59886 .67351 m .58831 .68677 L .57428 .66612 L p F P
0 0 0 r
s
.521 .953 1 r
.57428 .66612 m .57885 .6604 L .59886 .67351 L p F P
0 0 0 r
s
.508 .913 1 r
.59886 .67351 m .57885 .6604 L .59484 .6304 L p F P
0 0 0 r
s
.69 .09 .12 r
.39062 .70979 m
.39241 .71611 L
s
.38722 .71518 m
.39062 .70979 L
s
.39037 .71574 m
.39062 .70979 L
s
.63058 .64905 m
.6315 .64833 L
s
.6315 .64833 m
.63046 .6454 L
s
.6315 .64833 m
.62774 .64806 L
s
.509 .943 1 r
.58831 .68677 m .56171 .70816 L .5475 .68963 L p F P
0 0 0 r
s
.69 .09 .12 r
.63046 .6454 m
.62954 .64612 L
s
.63046 .6454 m
.62774 .64806 L
s
.62774 .64806 m
.63058 .64905 L
s
.62774 .64806 m
.62954 .64612 L
s
.64167 .64386 m
.62774 .64806 L
s
.64464 .45251 m
.64632 .45301 L
s
.64464 .45251 m
.63939 .45805 L
s
.3965 .44289 m
.39255 .44765 L
s
.462 .804 1 r
.57197 .54511 m .57558 .52265 L .56135 .51195 L closepath p F P
0 0 0 r
s
.455 .789 1 r
.55747 .49798 m .55962 .48298 L p .57558 .52265 L F P
0 0 0 r
s
.455 .789 1 r
.57558 .52265 m .56135 .51195 L .55747 .49798 L p F P
0 0 0 r
s
.248 .431 .63 r
.3746 .47232 m .37459 .44755 L .40218 .44013 L p F P
0 0 0 r
s
.69 .09 .12 r
.3947 .44887 m
.3962 .44972 L
s
.39874 .44415 m
.40015 .44495 L
s
.39663 .44661 m
.39955 .44978 L
s
.39955 .44978 m
.40015 .44495 L
s
.3962 .44972 m
.39955 .44978 L
s
.24 .418 .612 r
.37459 .44755 m .3746 .47232 L .34736 .47996 L p F P
0 0 0 r
s
.69 .09 .12 r
.43556 .80111 m
.42684 .8006 L
s
.509 .943 1 r
.5475 .68963 m .57428 .66612 L .58831 .68677 L p F P
0 0 0 r
s
.445 .77 1 r
.55962 .48298 m .55247 .47803 L .5458 .44684 L p F P
0 0 0 r
s
.442 .766 1 r
.54117 .44405 m .5458 .44684 L .55247 .47803 L p F P
0 0 0 r
s
.69 .09 .12 r
.62954 .64612 m
.63058 .64905 L
s
.85431 .44556 m
.79625 .46991 L
s
.451 .782 1 r
.55747 .49798 m .55962 .48298 L .55247 .47803 L closepath p F P
0 0 0 r
s
.493 .933 1 r
.52075 .70535 m .49417 .71788 L .47936 .70018 L p F P
0 0 0 r
s
.487 .925 1 r
.45283 .71175 m .47936 .70018 L .49417 .71788 L p F P
0 0 0 r
s
.69 .09 .12 r
.63939 .45805 m
.64791 .46011 L
s
.63939 .45805 m
.64632 .45301 L
s
.481 .914 1 r
.45283 .71175 m .42655 .72219 L .41116 .70452 L p F P
0 0 0 r
s
.479 .914 1 r
.38495 .71478 m .41116 .70452 L .42655 .72219 L p F P
0 0 0 r
s
.69 .09 .12 r
.38772 .71369 m
.3881 .71287 L
s
.38952 .73601 m
.39016 .72065 L
s
.39016 .72065 m
.39017 .72052 L
s
.39062 .70979 m
.39244 .71185 L
s
.3881 .71287 m
.39062 .70979 L
s
.3962 .44972 m
.40015 .44495 L
s
.49 .866 1 r
.59194 .59464 m .5846 .58893 L p .59484 .6304 L F P
0 0 0 r
s
.481 .845 1 r
.59194 .59464 m .58628 .58183 L .5846 .58893 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.3881 .71287 m
.38932 .71307 L
s
.35468 .62511 m
.35419 .62897 L
s
.35336 .62262 m
.35468 .62511 L
s
.35468 .62511 m
.35063 .62612 L
s
.35692 .62547 m
.35468 .62511 L
s
.35012 .62855 m
.35468 .62511 L
s
.442 .766 1 r
.55247 .47803 m .53719 .46895 L .54117 .44405 L p F P
0 0 0 r
s
.416 .723 .991 r
.51246 .43185 m .54117 .44405 L .53719 .46895 L p F P
0 0 0 r
s
.69 .09 .12 r
.64632 .45301 m
.64791 .46011 L
s
.58878 .54374 m
.59008 .54296 L
s
.58868 .53902 m
.59008 .54296 L
s
.58504 .54257 m
.59008 .54296 L
s
.51 .925 1 r
.57541 .61667 m .59484 .6304 L .57885 .6604 L p F P
0 0 0 r
s
.49 .866 1 r
.5846 .58893 m .57541 .61667 L .59484 .6304 L p F P
0 0 0 r
s
.69 .09 .12 r
.58738 .5398 m
.58868 .53902 L
s
.58504 .54257 m
.58868 .53902 L
s
.58504 .54257 m
.58878 .54374 L
s
.58504 .54257 m
.58738 .5398 L
s
.58504 .54257 m
.60354 .53658 L
s
.247 .43 .63 r
.34735 .50522 m .34736 .47996 L .3746 .47232 L p F P
0 0 0 r
s
.241 .419 .615 r
.34736 .47996 m .34735 .50522 L .32033 .51291 L p F P
0 0 0 r
s
.476 .835 1 r
.5846 .58893 m .58628 .58183 L .57369 .54995 L p F P
0 0 0 r
s
.69 .09 .12 r
.35063 .62612 m
.35419 .62897 L
s
.35336 .62262 m
.35063 .62612 L
s
.35419 .62897 m
.35692 .62547 L
s
.45 .782 1 r
.55247 .47803 m .53719 .46895 L p .55577 .50814 L F P
0 0 0 r
s
.45 .782 1 r
.55577 .50814 m .55747 .49798 L .55247 .47803 L p F P
0 0 0 r
s
.69 .09 .12 r
.35692 .62547 m
.35336 .62262 L
s
.26 .453 .659 r
.40263 .46521 m .40218 .44013 L .43082 .43357 L p F P
0 0 0 r
s
.248 .431 .63 r
.40218 .44013 m .40263 .46521 L .3746 .47232 L p F P
0 0 0 r
s
.69 .09 .12 r
.38342 .43223 m
.39288 .44252 L
s
.39288 .44252 m
.39296 .44261 L
s
.58738 .5398 m
.58878 .54374 L
s
.497 .938 1 r
.52075 .70535 m .5299 .70045 L .512 .69434 L closepath p F P
0 0 0 r
s
.493 .933 1 r
.512 .69434 m .52075 .70535 L p .47936 .70018 L F P
0 0 0 r
s
.486 .862 1 r
.56477 .57491 m .5846 .58893 L .57541 .61667 L p F P
0 0 0 r
s
.476 .835 1 r
.57136 .54823 m .56477 .57491 L .5846 .58893 L p F P
0 0 0 r
s
.476 .835 1 r
.57369 .54995 m .57136 .54823 L p .5846 .58893 L F P
0 0 0 r
s
.456 .792 1 r
.56135 .51195 m .55747 .49798 L .55577 .50814 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.57083 .71963 m
.57189 .72332 L
s
.56983 .7212 m
.57083 .71963 L
s
.57083 .71963 m
.56889 .72284 L
s
.57284 .72169 m
.57083 .71963 L
s
.57101 .73282 m
.57083 .71963 L
s
.474 .898 1 r
.41116 .70452 m .38495 .71478 L .36919 .696 L p F P
0 0 0 r
s
.249 .435 .638 r
.32045 .53879 m .32033 .51291 L .34735 .50522 L p F P
0 0 0 r
s
.69 .09 .12 r
.57189 .72332 m
.57284 .72169 L
s
.56889 .72284 m
.57189 .72332 L
s
.483 .915 1 r
.47936 .70018 m .45283 .71175 L .43762 .69339 L p F P
0 0 0 r
s
.481 .914 1 r
.41116 .70452 m .43762 .69339 L .45283 .71175 L p F P
0 0 0 r
s
.468 .818 1 r
.57369 .54995 m .57197 .54511 L .57136 .54823 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.56983 .7212 m
.56889 .72284 L
s
.498 .936 1 r
.53305 .6695 m .5475 .68963 L .5299 .70045 L p F P
0 0 0 r
s
.498 .936 1 r
.50612 .6867 m .53305 .6695 L p .5299 .70045 L F P
0 0 0 r
s
.498 .936 1 r
.5299 .70045 m .512 .69434 L .50612 .6867 L p F P
0 0 0 r
s
.463 .808 1 r
.57136 .54823 m .57197 .54511 L .56135 .51195 L p F P
0 0 0 r
s
.463 .808 1 r
.56135 .51195 m .55577 .50814 L p .57136 .54823 L F P
0 0 0 r
s
.69 .09 .12 r
.32374 .53721 m
.32734 .537 L
s
.32536 .53266 m
.32734 .537 L
s
.3202 .53496 m
.32043 .53502 L
s
.3229 .53573 m
.32734 .537 L
s
.32734 .537 m
.32775 .53237 L
s
.31038 .52018 m
.32041 .53013 L
s
.3243 .53399 m
.32734 .537 L
s
.57284 .72169 m
.56983 .7212 L
s
.469 .825 1 r
.55022 .53421 m .57136 .54823 L .56477 .57491 L p F P
0 0 0 r
s
.463 .808 1 r
.55577 .50814 m .55022 .53421 L .57136 .54823 L p F P
0 0 0 r
s
.69 .09 .12 r
.3202 .53496 m
.32043 .53469 L
s
.32632 .53146 m
.32775 .53237 L
s
.256 .446 .651 r
.37502 .49788 m .3746 .47232 L .40263 .46521 L p F P
0 0 0 r
s
.247 .43 .63 r
.3746 .47232 m .37502 .49788 L .34735 .50522 L p F P
0 0 0 r
s
.69 .09 .12 r
.3202 .53496 m
.32043 .5351 L
s
.3224 .53636 m
.32374 .53721 L
s
.513 .937 1 r
.57428 .66612 m .57885 .6604 L .56575 .65272 L closepath p F P
0 0 0 r
s
.51 .925 1 r
.56002 .64323 m .57541 .61667 L p .57885 .6604 L F P
0 0 0 r
s
.51 .925 1 r
.57885 .6604 m .56575 .65272 L .56002 .64323 L p F P
0 0 0 r
s
.69 .09 .12 r
.52558 .62209 m
.52606 .62476 L
s
.52777 .62063 m
.52558 .62209 L
s
.52558 .62209 m
.52508 .62195 L
s
.52874 .62343 m
.52558 .62209 L
s
.53229 .62511 m
.52558 .62209 L
s
.513 .948 1 r
.57428 .66612 m .5475 .68963 L .53305 .6695 L p F P
0 0 0 r
s
.279 .485 .701 r
.43082 .43357 m .45498 .42954 L .44225 .45738 L p F P
0 0 0 r
s
.279 .485 .701 r
.44225 .45738 m .43183 .45909 L .43082 .43357 L p F P
0 0 0 r
s
.26 .453 .659 r
.43082 .43357 m .43183 .45909 L .40263 .46521 L p F P
0 0 0 r
s
.69 .09 .12 r
.55402 .43395 m
.55505 .4335 L
s
.55505 .4335 m
.55399 .43052 L
s
.55505 .4335 m
.55124 .43319 L
s
.55399 .43052 m
.55296 .43096 L
s
.55399 .43052 m
.55124 .43319 L
s
.55124 .43319 m
.55402 .43395 L
s
.55124 .43319 m
.55296 .43096 L
s
.56509 .42838 m
.55124 .43319 L
s
.513 .948 1 r
.56575 .65272 m .57428 .66612 L p .53305 .6695 L F P
0 0 0 r
s
.448 .785 1 r
.53178 .49468 m .55577 .50814 L .55022 .53421 L p F P
0 0 0 r
s
.45 .782 1 r
.53719 .46895 m .53178 .49468 L .55577 .50814 L p F P
0 0 0 r
s
.69 .09 .12 r
.52606 .62476 m
.52874 .62343 L
s
.52874 .62343 m
.52777 .62063 L
s
.78529 .53296 m
.74995 .5559 L
s
.416 .723 .991 r
.53719 .46895 m .5062 .45754 L .51246 .43185 L p F P
0 0 0 r
s
.373 .647 .9 r
.49588 .42867 m .51246 .43185 L .5062 .45754 L p F P
0 0 0 r
s
.69 .09 .12 r
.32374 .53721 m
.32775 .53237 L
s
.52777 .62063 m
.52508 .62195 L
s
.52508 .62195 m
.52606 .62476 L
s
.55296 .43096 m
.55402 .43395 L
s
.408 .708 .974 r
.5062 .45754 m .53719 .46895 L .53178 .49468 L p F P
0 0 0 r
s
.493 .933 1 r
.47936 .70018 m .49896 .69055 L .512 .69434 L p F P
0 0 0 r
s
.488 .921 1 r
.47936 .70018 m .49896 .69055 L .46614 .68334 L closepath p F P
0 0 0 r
s
.483 .915 1 r
.46614 .68334 m .47936 .70018 L p .43762 .69339 L F P
0 0 0 r
s
.473 .893 1 r
.43762 .69339 m .41116 .70452 L .39557 .68498 L p F P
0 0 0 r
s
.474 .898 1 r
.36919 .696 m .39557 .68498 L .41116 .70452 L p F P
0 0 0 r
s
.257 .449 .656 r
.34791 .53141 m .34735 .50522 L .37502 .49788 L p F P
0 0 0 r
s
.249 .435 .638 r
.34735 .50522 m .34791 .53141 L .32045 .53879 L p F P
0 0 0 r
s
.493 .93 1 r
.512 .69434 m .50612 .6867 L .49896 .69055 L closepath p F P
0 0 0 r
s
.298 .519 .746 r
.45498 .42954 m .46129 .42882 L .4631 .45503 L p F P
0 0 0 r
s
.298 .519 .746 r
.4631 .45503 m .44225 .45738 L .45498 .42954 L p F P
0 0 0 r
s
.323 .56 .794 r
.4631 .45503 m .46129 .42882 L .49588 .42867 L p F P
0 0 0 r
s
.373 .647 .9 r
.5062 .45754 m .49905 .45619 L .49588 .42867 L p F P
0 0 0 r
s
.323 .56 .794 r
.49588 .42867 m .49905 .45619 L .4631 .45503 L p F P
0 0 0 r
s
.273 .475 .69 r
.40263 .46521 m .43183 .45909 L p .42531 .48693 L F P
0 0 0 r
s
.273 .475 .69 r
.42531 .48693 m .40357 .49117 L .40263 .46521 L p F P
0 0 0 r
s
.256 .446 .651 r
.40263 .46521 m .40357 .49117 L .37502 .49788 L p F P
0 0 0 r
s
.502 .904 1 r
.57541 .61667 m .56002 .64323 L .54553 .61695 L p F P
0 0 0 r
s
.502 .904 1 r
.54553 .61695 m .55343 .6034 L .57541 .61667 L p F P
0 0 0 r
s
.486 .862 1 r
.57541 .61667 m .55343 .6034 L .56477 .57491 L p F P
0 0 0 r
s
.69 .09 .12 r
.30313 .43372 m
.29631 .44167 L
s
.30563 .43468 m
.30313 .43372 L
s
.30313 .43372 m
.30857 .44496 L
s
.48924 .52108 m
.48982 .52228 L
s
.49026 .51805 m
.48924 .52108 L
s
.48924 .52108 m
.48788 .51977 L
s
.4922 .52056 m
.48924 .52108 L
s
.49325 .51649 m
.48924 .52108 L
s
.29631 .44167 m
.29878 .44267 L
s
.30857 .44496 m
.29631 .44167 L
s
.30857 .44496 m
.29878 .44267 L
s
.30563 .43468 m
.30857 .44496 L
s
.2703 .41087 m
.30857 .44496 L
s
.81503 .47361 m
.8036 .47203 L
s
.8036 .47203 m
.80107 .45635 L
s
.8036 .47203 m
.79625 .46991 L
s
.513 .948 1 r
.53305 .6695 m .55643 .64771 L .56575 .65272 L p F P
0 0 0 r
s
.507 .924 1 r
.56575 .65272 m .56002 .64323 L .55643 .64771 L closepath p F P
0 0 0 r
s
.487 .916 1 r
.49126 .66617 m .50612 .6867 L .49896 .69055 L p F P
0 0 0 r
s
.487 .916 1 r
.46432 .68092 m .49126 .66617 L p .49896 .69055 L F P
0 0 0 r
s
.487 .916 1 r
.49896 .69055 m .46614 .68334 L .46432 .68092 L p F P
0 0 0 r
s
.263 .46 .674 r
.32146 .5659 m .32045 .53879 L .34791 .53141 L p F P
0 0 0 r
s
.69 .09 .12 r
.49026 .51805 m
.48788 .51977 L
s
.4922 .52056 m
.49026 .51805 L
s
.48982 .52228 m
.4922 .52056 L
s
.74753 .42452 m
.70675 .43243 L
s
.50435 .79417 m
.51106 .79571 L
s
.50175 .79317 m
.50435 .79417 L
s
.50435 .79417 m
.50819 .78729 L
s
.48788 .51977 m
.48982 .52228 L
s
.49 .91 1 r
.53305 .6695 m .50612 .6867 L .49126 .66617 L p F P
0 0 0 r
s
.69 .09 .12 r
.76185 .55585 m
.75586 .55549 L
s
.75586 .55549 m
.75231 .54671 L
s
.75586 .55549 m
.74995 .5559 L
s
.476 .849 1 r
.54169 .56158 m .56477 .57491 L .55343 .6034 L p F P
0 0 0 r
s
.469 .825 1 r
.56477 .57491 m .54169 .56158 L .55022 .53421 L p F P
0 0 0 r
s
.464 .875 1 r
.39019 .67762 m .39557 .68498 L .36919 .696 L p F P
0 0 0 r
s
.464 .875 1 r
.36919 .696 m .35649 .6789 L .39019 .67762 L p F P
0 0 0 r
s
.483 .915 1 r
.43762 .69339 m .46111 .68251 L .46614 .68334 L p F P
0 0 0 r
s
.478 .903 1 r
.43762 .69339 m .46111 .68251 L .42633 .67865 L closepath p F P
0 0 0 r
s
.473 .893 1 r
.42633 .67865 m .43762 .69339 L p .39557 .68498 L F P
0 0 0 r
s
.272 .474 .69 r
.37502 .49788 m .40357 .49117 L p .40173 .51898 L F P
0 0 0 r
s
.272 .474 .69 r
.40173 .51898 m .37611 .52448 L .37502 .49788 L p F P
0 0 0 r
s
.257 .449 .656 r
.37502 .49788 m .37611 .52448 L .34791 .53141 L p F P
0 0 0 r
s
.69 .09 .12 r
.51106 .79571 m
.50848 .79472 L
s
.50819 .78729 m
.51106 .79571 L
s
.80107 .45635 m
.81251 .45784 L
s
.80107 .45635 m
.79625 .46991 L
s
.285 .496 .717 r
.43271 .47487 m .44225 .45738 L .43183 .45909 L closepath p F P
0 0 0 r
s
.273 .475 .69 r
.43183 .45909 m .43271 .47487 L .42531 .48693 L p F P
0 0 0 r
s
.69 .09 .12 r
.50819 .78729 m
.50848 .79472 L
s
.50175 .79317 m
.50819 .78729 L
s
.49929 .8231 m
.50819 .78729 L
s
.75231 .54671 m
.75829 .54704 L
s
.75231 .54671 m
.74995 .5559 L
s
.495 .899 1 r
.55643 .64771 m .56002 .64323 L .54553 .61695 L p F P
0 0 0 r
s
.448 .788 1 r
.52409 .5215 m .55022 .53421 L .54169 .56158 L p F P
0 0 0 r
s
.448 .785 1 r
.55022 .53421 m .52409 .5215 L .53178 .49468 L p F P
0 0 0 r
s
.408 .708 .974 r
.50148 .47344 m .5062 .45754 L p .53178 .49468 L F P
0 0 0 r
s
.38 .66 .92 r
.50148 .47344 m .5062 .45754 L .49905 .45619 L closepath p F P
0 0 0 r
s
.503 .928 1 r
.55643 .64771 m .53305 .6695 L .51838 .64698 L p F P
0 0 0 r
s
.503 .928 1 r
.51838 .64698 m .53034 .63583 L .55643 .64771 L p F P
0 0 0 r
s
.495 .899 1 r
.54553 .61695 m .53034 .63583 L .55643 .64771 L p F P
0 0 0 r
s
.295 .514 .741 r
.44225 .45738 m .4631 .45503 L p .43345 .48561 L F P
0 0 0 r
s
.295 .514 .741 r
.43345 .48561 m .43271 .47487 L .44225 .45738 L p F P
0 0 0 r
s
.49 .91 1 r
.49126 .66617 m .51838 .64698 L .53305 .6695 L p F P
0 0 0 r
s
.69 .09 .12 r
.29878 .44267 m
.30563 .43468 L
s
.46034 .69731 m
.46176 .70228 L
s
.45877 .69938 m
.46034 .69731 L
s
.45766 .70162 m
.46034 .69731 L
s
.46034 .69731 m
.46288 .70004 L
s
.45998 .71497 m
.46034 .69731 L
s
.71524 .62166 m
.69942 .63623 L
s
.46176 .70228 m
.46288 .70004 L
s
.45766 .70162 m
.46176 .70228 L
s
.416 .725 .998 r
.50339 .48533 m .53178 .49468 L .52409 .5215 L p F P
0 0 0 r
s
.408 .708 .974 r
.53178 .49468 m .50339 .48533 L .50148 .47344 L p F P
0 0 0 r
s
.69 .09 .12 r
.50848 .79472 m
.50175 .79317 L
s
.344 .598 .843 r
.49905 .45619 m .50148 .47344 L .4978 .48429 L p F P
0 0 0 r
s
.344 .598 .843 r
.4631 .45503 m .49905 .45619 L p .4978 .48429 L F P
0 0 0 r
s
.69 .09 .12 r
.45766 .70162 m
.45877 .69938 L
s
.276 .483 .705 r
.34791 .53141 m .37611 .52448 L p .36669 .55505 L F P
0 0 0 r
s
.276 .483 .705 r
.36669 .55505 m .34949 .55896 L .34791 .53141 L p F P
0 0 0 r
s
.263 .46 .674 r
.34791 .53141 m .34949 .55896 L .32146 .5659 L p F P
0 0 0 r
s
.344 .598 .843 r
.4978 .48429 m .4657 .48245 L .4631 .45503 L p F P
0 0 0 r
s
.295 .514 .741 r
.4631 .45503 m .4657 .48245 L .43345 .48561 L p F P
0 0 0 r
s
.482 .909 1 r
.46614 .68334 m .46432 .68092 L .46111 .68251 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.70495 .63504 m
.70296 .63516 L
s
.70296 .63516 m
.70024 .63159 L
s
.70296 .63516 m
.69942 .63623 L
s
.75829 .54704 m
.76185 .55585 L
s
.74995 .5559 m
.76185 .55585 L
s
.46288 .70004 m
.45877 .69938 L
s
.46174 .416 m
.46013 .41592 L
s
.46021 .41248 m
.46174 .416 L
s
.46174 .416 m
.45821 .4149 L
s
.46213 .4135 m
.46174 .416 L
s
.45387 .40694 m
.46174 .416 L
s
.475 .893 1 r
.44909 .65916 m .46432 .68092 L .46111 .68251 L p F P
0 0 0 r
s
.475 .893 1 r
.4222 .6729 m .44909 .65916 L p .46111 .68251 L F P
0 0 0 r
s
.475 .893 1 r
.46111 .68251 m .42633 .67865 L .4222 .6729 L p F P
0 0 0 r
s
.69 .09 .12 r
.70024 .63159 m
.70223 .63146 L
s
.70024 .63159 m
.69942 .63623 L
s
.46021 .41248 m
.45821 .4149 L
s
.46213 .4135 m
.46021 .41248 L
s
.74995 .5559 m
.75829 .54704 L
s
.475 .885 1 r
.49126 .66617 m .46432 .68092 L .44909 .65916 L p F P
0 0 0 r
s
.282 .492 .714 r
.40504 .51496 m .42531 .48693 L .40357 .49117 L closepath p F P
0 0 0 r
s
.272 .474 .69 r
.40357 .49117 m .40504 .51496 L .40173 .51898 L p F P
0 0 0 r
s
.69 .09 .12 r
.45821 .4149 m
.46013 .41592 L
s
.81251 .45784 m
.81503 .47361 L
s
.79625 .46991 m
.81503 .47361 L
s
.473 .893 1 r
.39557 .68498 m .41152 .67789 L .42633 .67865 L p F P
0 0 0 r
s
.468 .881 1 r
.39557 .68498 m .41152 .67789 L .39019 .67762 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.71812 .4363 m
.7125 .4352 L
s
.7125 .4352 m
.71183 .42538 L
s
.7125 .4352 m
.70675 .43243 L
s
.289 .504 .729 r
.43345 .48561 m .43271 .47487 L .42531 .48693 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.42145 .60422 m
.42128 .60681 L
s
.42116 .60232 m
.42145 .60422 L
s
.42145 .60422 m
.41897 .60461 L
s
.42348 .60452 m
.42145 .60422 L
s
.42033 .60592 m
.42145 .60422 L
s
.46013 .41592 m
.46213 .4135 L
s
.284 .5 .731 r
.32349 .589 m .32146 .5659 L .34949 .55896 L p F P
0 0 0 r
s
.69 .09 .12 r
.69942 .63623 m
.70495 .63504 L
s
.69942 .63623 m
.70223 .63146 L
s
.70223 .63146 m
.70495 .63504 L
s
.485 .87 1 r
.54553 .61695 m .55343 .6034 L .53478 .59427 L closepath p F P
0 0 0 r
s
.476 .849 1 r
.53085 .58498 m .54169 .56158 L p .55343 .6034 L F P
0 0 0 r
s
.476 .849 1 r
.55343 .6034 m .53478 .59427 L .53085 .58498 L p F P
0 0 0 r
s
.69 .09 .12 r
.71183 .42538 m
.71744 .42645 L
s
.71183 .42538 m
.70675 .43243 L
s
.385 .671 .935 r
.50339 .48533 m .50148 .47344 L .4978 .48429 L closepath p F P
0 0 0 r
s
.456 .855 1 r
.37987 .662 m .39019 .67762 L .35649 .6789 L p F P
0 0 0 r
s
.456 .855 1 r
.35649 .6789 m .35332 .67417 L .37987 .662 L p F P
0 0 0 r
s
.69 .09 .12 r
.42128 .60681 m
.42348 .60452 L
s
.41897 .60461 m
.42128 .60681 L
s
.42116 .60232 m
.41897 .60461 L
s
.42348 .60452 m
.42116 .60232 L
s
.471 .886 1 r
.42633 .67865 m .4222 .6729 L .41152 .67789 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.79625 .46991 m
.81251 .45784 L
s
.6769 .51279 m
.65364 .5216 L
s
.294 .514 .744 r
.42531 .48693 m .43345 .48561 L p .4053 .5183 L F P
0 0 0 r
s
.294 .514 .744 r
.4053 .5183 m .40504 .51496 L .42531 .48693 L p F P
0 0 0 r
s
.46 .862 1 r
.40668 .64844 m .4222 .6729 L .41152 .67789 L p F P
0 0 0 r
s
.46 .862 1 r
.37987 .662 m .40668 .64844 L p .41152 .67789 L F P
0 0 0 r
s
.46 .862 1 r
.41152 .67789 m .39019 .67762 L .37987 .662 L p F P
0 0 0 r
s
.283 .496 .722 r
.3776 .5449 m .40173 .51898 L .37611 .52448 L closepath p F P
0 0 0 r
s
.276 .483 .705 r
.37611 .52448 m .3776 .5449 L .36669 .55505 L p F P
0 0 0 r
s
.69 .09 .12 r
.65993 .52247 m
.65825 .5221 L
s
.65825 .5221 m
.65668 .5172 L
s
.65825 .5221 m
.65364 .5216 L
s
.48 .887 1 r
.51838 .64698 m .49126 .66617 L .47621 .64259 L p F P
0 0 0 r
s
.475 .885 1 r
.44909 .65916 m .47621 .64259 L .49126 .66617 L p F P
0 0 0 r
s
.311 .544 .782 r
.43605 .51351 m .43345 .48561 L .4657 .48245 L p F P
0 0 0 r
s
.294 .514 .744 r
.43345 .48561 m .43605 .51351 L .4053 .5183 L p F P
0 0 0 r
s
.425 .785 1 r
.37987 .662 m .35332 .67417 L .33761 .64518 L p F P
0 0 0 r
s
.69 .09 .12 r
.65668 .5172 m
.65835 .51756 L
s
.65668 .5172 m
.65364 .5216 L
s
.48 .873 1 r
.53478 .59427 m .54553 .61695 L .53034 .63583 L p F P
0 0 0 r
s
.416 .725 .998 r
.52409 .5215 m .5096 .51681 L .50339 .48533 L p F P
0 0 0 r
s
.394 .69 .964 r
.4978 .48429 m .50339 .48533 L .5096 .51681 L p F P
0 0 0 r
s
.459 .815 1 r
.53085 .58498 m .54169 .56158 L .51903 .55205 L closepath p F P
0 0 0 r
s
.448 .788 1 r
.51607 .54215 m .52409 .5215 L p .54169 .56158 L F P
0 0 0 r
s
.448 .788 1 r
.54169 .56158 m .51903 .55205 L .51607 .54215 L p F P
0 0 0 r
s
.394 .69 .964 r
.5096 .51681 m .48598 .5125 L .4978 .48429 L p F P
0 0 0 r
s
.355 .62 .875 r
.4657 .48245 m .4978 .48429 L .48598 .5125 L p F P
0 0 0 r
s
.456 .846 1 r
.44909 .65916 m .4222 .6729 L .40668 .64844 L p F P
0 0 0 r
s
.69 .09 .12 r
.71744 .42645 m
.71812 .4363 L
s
.70675 .43243 m
.71812 .4363 L
s
.86134 .50907 m
.82337 .53914 L
s
.428 .752 1 r
.51607 .54215 m .52409 .5215 L .5096 .51681 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.65364 .5216 m
.65993 .52247 L
s
.65364 .5216 m
.65835 .51756 L
s
.70675 .43243 m
.71744 .42645 L
s
.43495 .86182 m
.4456 .86557 L
s
.42744 .86295 m
.43495 .86182 L
s
.43495 .86182 m
.43904 .85161 L
s
.486 .892 1 r
.51838 .64698 m .53034 .63583 L .50749 .6281 L closepath p F P
0 0 0 r
s
.48 .873 1 r
.52722 .59115 m .53478 .59427 L p .53034 .63583 L F P
0 0 0 r
s
.48 .873 1 r
.50351 .62051 m .52722 .59115 L p .53034 .63583 L F P
0 0 0 r
s
.48 .873 1 r
.53034 .63583 m .50749 .6281 L .50351 .62051 L p F P
0 0 0 r
s
.48 .887 1 r
.50749 .6281 m .51838 .64698 L p .47621 .64259 L F P
0 0 0 r
s
.355 .62 .875 r
.48598 .5125 m .46959 .51157 L .4657 .48245 L p F P
0 0 0 r
s
.311 .544 .782 r
.4657 .48245 m .46959 .51157 L .43605 .51351 L p F P
0 0 0 r
s
.288 .507 .74 r
.35041 .56886 m .36669 .55505 L .34949 .55896 L closepath p F P
0 0 0 r
s
.284 .5 .731 r
.34949 .55896 m .35041 .56886 L .32349 .589 L p F P
0 0 0 r
s
.69 .09 .12 r
.65835 .51756 m
.65993 .52247 L
s
.38907 .50758 m
.39138 .5075 L
s
.38929 .50282 m
.39138 .5075 L
s
.38659 .50609 m
.39138 .5075 L
s
.39138 .5075 m
.39177 .5043 L
s
.38034 .49593 m
.39138 .5075 L
s
.01 w
.64415 .71169 Mdot
.5 Mabswid
.303 .537 .783 r
.32427 .59507 m .32349 .589 L .35041 .56886 L p F P
0 0 0 r
s
.288 .504 .732 r
.4053 .5183 m .40504 .51496 L .40173 .51898 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.38659 .50609 m
.38929 .50282 L
s
.38929 .50282 m
.39177 .5043 L
s
.298 .523 .76 r
.40173 .51898 m .4053 .5183 L p .37836 .5526 L F P
0 0 0 r
s
.298 .523 .76 r
.37836 .5526 m .3776 .5449 L .40173 .51898 L p F P
0 0 0 r
s
.69 .09 .12 r
.38659 .50609 m
.38907 .50758 L
s
.331 .594 .866 r
.33157 .62875 m .32427 .59507 L .35309 .58883 L p F P
0 0 0 r
s
.303 .537 .783 r
.35041 .56886 m .35309 .58883 L .32427 .59507 L p F P
0 0 0 r
s
.305 .536 .776 r
.40842 .54719 m .4053 .5183 L .43605 .51351 L p F P
0 0 0 r
s
.298 .523 .76 r
.4053 .5183 m .40842 .54719 L .37836 .5526 L p F P
0 0 0 r
s
.69 .09 .12 r
.42649 .91474 m
.43904 .85161 L
s
.63822 .40298 m
.61702 .40281 L
s
.471 .842 1 r
.53478 .59427 m .53085 .58498 L .52722 .59115 L closepath p F P
0 0 0 r
s
.309 .546 .794 r
.35309 .58883 m .35041 .56886 L .36669 .55505 L p F P
0 0 0 r
s
.69 .09 .12 r
.38907 .50758 m
.39177 .5043 L
s
.4 .704 .984 r
.5096 .51681 m .51607 .54215 L .51242 .54995 L p F P
0 0 0 r
s
.4 .704 .984 r
.48598 .5125 m .5096 .51681 L p .51242 .54995 L F P
0 0 0 r
s
.69 .09 .12 r
.38804 .77636 m
.39345 .77659 L
s
.38282 .77608 m
.38804 .77636 L
s
.38804 .77636 m
.38853 .76888 L
s
.402 .735 1 r
.40668 .64844 m .37987 .662 L .36434 .63089 L p F P
0 0 0 r
s
.425 .785 1 r
.33761 .64518 m .36434 .63089 L .37987 .662 L p F P
0 0 0 r
s
.292 .513 .747 r
.37836 .5526 m .3776 .5449 L .36669 .55505 L closepath p F P
0 0 0 r
s
.309 .546 .794 r
.36669 .55505 m .37836 .5526 L p .35309 .58883 L F P
0 0 0 r
s
.45 .829 1 r
.47621 .64259 m .44909 .65916 L .43375 .63269 L p F P
0 0 0 r
s
.456 .846 1 r
.40668 .64844 m .43375 .63269 L .44909 .65916 L p F P
0 0 0 r
s
.69 .09 .12 r
.59766 .60598 m
.59832 .60552 L
s
.59832 .60552 m
.5976 .60351 L
s
.59832 .60552 m
.59574 .60534 L
s
.449 .8 1 r
.52722 .59115 m .53085 .58498 L .51903 .55205 L p F P
0 0 0 r
s
.69 .09 .12 r
.4456 .86557 m
.43812 .86672 L
s
.43904 .85161 m
.4456 .86557 L
s
.5976 .60351 m
.59694 .60397 L
s
.5976 .60351 m
.59574 .60534 L
s
.59574 .60534 m
.59766 .60598 L
s
.59574 .60534 m
.59694 .60397 L
s
.60521 .60238 m
.59574 .60534 L
s
.62207 .40544 m
.62022 .40492 L
s
.62022 .40492 m
.62047 .40026 L
s
.62022 .40492 m
.61702 .40281 L
s
.384 .699 1 r
.36175 .62382 m .36434 .63089 L .33761 .64518 L p F P
0 0 0 r
s
.384 .699 1 r
.33761 .64518 m .33157 .62875 L .36175 .62382 L p F P
0 0 0 r
s
.69 .09 .12 r
.82337 .39901 m
.77708 .40568 L
s
.62047 .40026 m
.62232 .40077 L
s
.62047 .40026 m
.61702 .40281 L
s
.59694 .60397 m
.59766 .60598 L
s
.461 .832 1 r
.52722 .59115 m .50351 .62051 L .48855 .58651 L p F P
0 0 0 r
s
.461 .832 1 r
.48855 .58651 m .49284 .58123 L .52722 .59115 L p F P
0 0 0 r
s
.449 .8 1 r
.51242 .54995 m .49284 .58123 L .52722 .59115 L p F P
0 0 0 r
s
.449 .8 1 r
.51903 .55205 m .51242 .54995 L p .52722 .59115 L F P
0 0 0 r
s
.315 .558 .81 r
.38295 .58336 m .37836 .5526 L .40842 .54719 L p F P
0 0 0 r
s
.309 .546 .794 r
.37836 .5526 m .38295 .58336 L .35309 .58883 L p F P
0 0 0 r
s
.437 .772 1 r
.51903 .55205 m .51607 .54215 L .51242 .54995 L closepath p F P
0 0 0 r
s
.344 .603 .86 r
.43605 .51351 m .46959 .51157 L p .46822 .54296 L F P
0 0 0 r
s
.344 .603 .86 r
.46822 .54296 m .44035 .54351 L .43605 .51351 L p F P
0 0 0 r
s
.305 .536 .776 r
.43605 .51351 m .44035 .54351 L .40842 .54719 L p F P
0 0 0 r
s
.69 .09 .12 r
.38853 .76888 m
.38824 .77631 L
s
.38853 .76888 m
.39345 .77659 L
s
.38282 .77608 m
.38853 .76888 L
s
.38657 .80619 m
.38853 .76888 L
s
.331 .594 .866 r
.35309 .58883 m .36175 .62382 L .33157 .62875 L p F P
0 0 0 r
s
.69 .09 .12 r
.43904 .85161 m
.43812 .86672 L
s
.42744 .86295 m
.43904 .85161 L
s
.39345 .77659 m
.38824 .77631 L
s
.48 .887 1 r
.47621 .64259 m .49804 .62561 L .50749 .6281 L p F P
0 0 0 r
s
.472 .863 1 r
.50749 .6281 m .50351 .62051 L .49804 .62561 L closepath p F P
0 0 0 r
s
.4 .704 .984 r
.47377 .53454 m .48598 .5125 L p .51242 .54995 L F P
0 0 0 r
s
.368 .648 .916 r
.47377 .53454 m .48598 .5125 L .46959 .51157 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.38824 .77631 m
.38282 .77608 L
s
.43812 .86672 m
.42744 .86295 L
s
.61702 .40281 m
.62207 .40544 L
s
.61702 .40281 m
.62232 .40077 L
s
.355 .637 .921 r
.35309 .58883 m .38295 .58336 L p .38051 .6214 L F P
0 0 0 r
s
.355 .637 .921 r
.38051 .6214 m .36175 .62382 L .35309 .58883 L p F P
0 0 0 r
s
.69 .09 .12 r
.62232 .40077 m
.62207 .40544 L
s
.462 .849 1 r
.47621 .64259 m .49804 .62561 L .46409 .61981 L closepath p F P
0 0 0 r
s
.45 .829 1 r
.46409 .61981 m .47621 .64259 L p .43375 .63269 L F P
0 0 0 r
s
.344 .603 .86 r
.46959 .51157 m .47377 .53454 L .46822 .54296 L p F P
0 0 0 r
s
.415 .738 1 r
.47571 .54338 m .51242 .54995 L .49284 .58123 L p F P
0 0 0 r
s
.4 .704 .984 r
.51242 .54995 m .47571 .54338 L .47377 .53454 L p F P
0 0 0 r
s
.424 .779 1 r
.42703 .61825 m .43375 .63269 L .40668 .64844 L p F P
0 0 0 r
s
.424 .779 1 r
.40668 .64844 m .39335 .62007 L .42703 .61825 L p F P
0 0 0 r
s
.402 .735 1 r
.39335 .62007 m .40668 .64844 L p .36434 .63089 L F P
0 0 0 r
s
.69 .09 .12 r
.36561 .39896 m
.36129 .40512 L
s
.3669 .3994 m
.36561 .39896 L
s
.36561 .39896 m
.37009 .40656 L
s
.34705 .68336 m
.34811 .68714 L
s
.34568 .68491 m
.34705 .68336 L
s
.34705 .68336 m
.34496 .68663 L
s
.34884 .68542 m
.34705 .68336 L
s
.3463 .69671 m
.34705 .68336 L
s
.36129 .40512 m
.36258 .40557 L
s
.37009 .40656 m
.36129 .40512 L
s
.34811 .68714 m
.34884 .68542 L
s
.34496 .68663 m
.34811 .68714 L
s
.451 .82 1 r
.48855 .58651 m .50351 .62051 L .49804 .62561 L p F P
0 0 0 r
s
.451 .82 1 r
.46106 .61323 m .48855 .58651 L p .49804 .62561 L F P
0 0 0 r
s
.451 .82 1 r
.49804 .62561 m .46409 .61981 L .46106 .61323 L p F P
0 0 0 r
s
.69 .09 .12 r
.34568 .68491 m
.34496 .68663 L
s
.37009 .40656 m
.36258 .40557 L
s
.3669 .3994 m
.37009 .40656 L
s
.34 .38498 m
.37009 .40656 L
s
.79088 .59883 m
.77398 .62393 L
s
.57957 .78577 m
.58358 .78815 L
s
.57882 .7858 m
.57957 .78577 L
s
.57957 .78577 m
.58351 .78295 L
s
.347 .614 .881 r
.40842 .54719 m .44035 .54351 L p .43874 .57749 L F P
0 0 0 r
s
.347 .614 .881 r
.43874 .57749 m .41431 .57918 L .40842 .54719 L p F P
0 0 0 r
s
.315 .558 .81 r
.40842 .54719 m .41431 .57918 L .38295 .58336 L p F P
0 0 0 r
s
.402 .735 1 r
.36434 .63089 m .38051 .6214 L .39335 .62007 L p F P
0 0 0 r
s
.388 .707 1 r
.36434 .63089 m .38051 .6214 L .36175 .62382 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.55839 .49586 m
.55908 .4955 L
s
.55908 .4955 m
.55836 .49347 L
s
.55908 .4955 m
.55649 .4953 L
s
.34884 .68542 m
.34568 .68491 L
s
.55836 .49347 m
.55766 .49383 L
s
.55836 .49347 m
.55649 .4953 L
s
.55649 .4953 m
.55839 .49586 L
s
.55649 .4953 m
.55766 .49383 L
s
.56593 .49214 m
.55649 .4953 L
s
.58358 .78815 m
.58283 .78818 L
s
.58351 .78295 m
.58358 .78815 L
s
.57197 .80308 m
.58351 .78295 L
s
.55766 .49383 m
.55839 .49586 L
s
.58351 .78295 m
.58283 .78818 L
s
.57882 .7858 m
.58351 .78295 L
s
.378 .669 .948 r
.47571 .54338 m .47377 .53454 L .46822 .54296 L closepath p F P
0 0 0 r
s
.361 .649 .939 r
.39134 .61456 m .38295 .58336 L .41431 .57918 L p F P
0 0 0 r
s
.355 .637 .921 r
.38295 .58336 m .39134 .61456 L .38051 .6214 L p F P
0 0 0 r
s
.392 .713 1 r
.39335 .62007 m .39134 .61456 L .38051 .6214 L closepath p F P
0 0 0 r
s
.45 .829 1 r
.43375 .63269 m .45375 .61893 L .46409 .61981 L p F P
0 0 0 r
s
.433 .794 1 r
.43375 .63269 m .45375 .61893 L .42703 .61825 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.58283 .78818 m
.57882 .7858 L
s
.36258 .40557 m
.3669 .3994 L
s
.365 .647 .924 r
.44609 .5701 m .46822 .54296 L .44035 .54351 L closepath p F P
0 0 0 r
s
.347 .614 .881 r
.44035 .54351 m .44609 .5701 L .43874 .57749 L p F P
0 0 0 r
s
.415 .738 1 r
.49284 .58123 m .48623 .58007 L .47571 .54338 L p F P
0 0 0 r
s
.393 .701 .994 r
.47571 .54338 m .48623 .58007 L .44805 .57731 L p F P
0 0 0 r
s
.393 .701 .994 r
.46822 .54296 m .47571 .54338 L p .44805 .57731 L F P
0 0 0 r
s
.69 .09 .12 r
.31441 .59458 m
.31255 .59478 L
s
.3128 .59107 m
.31441 .59458 L
s
.31441 .59458 m
.31074 .59357 L
s
.31461 .59228 m
.31441 .59458 L
s
.30568 .58627 m
.31441 .59458 L
s
.393 .701 .994 r
.44805 .57731 m .44609 .5701 L .46822 .54296 L p F P
0 0 0 r
s
.69 .09 .12 r
.53241 .68442 m
.53313 .68695 L
s
.53168 .68546 m
.53241 .68442 L
s
.53241 .68442 m
.53107 .68661 L
s
.53375 .6858 m
.53241 .68442 L
s
.53242 .69334 m
.53241 .68442 L
s
.53313 .68695 m
.53375 .6858 L
s
.53107 .68661 m
.53313 .68695 L
s
.399 .725 1 r
.41859 .59505 m .42703 .61825 L .39335 .62007 L p F P
0 0 0 r
s
.399 .725 1 r
.39335 .62007 m .39134 .61456 L .41859 .59505 L p F P
0 0 0 r
s
.432 .775 1 r
.48855 .58651 m .49284 .58123 L .48623 .58007 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.83798 .5394 m
.8274 .53855 L
s
.8274 .53855 m
.82417 .5267 L
s
.8274 .53855 m
.82337 .53914 L
s
.44 .805 1 r
.46409 .61981 m .46106 .61323 L .45375 .61893 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.53168 .68546 m
.53107 .68661 L
s
.361 .649 .939 r
.41431 .57918 m .41859 .59505 L .39134 .61456 L p F P
0 0 0 r
s
.69 .09 .12 r
.3128 .59107 m
.31074 .59357 L
s
.31461 .59228 m
.3128 .59107 L
s
.31074 .59357 m
.31255 .59478 L
s
.418 .754 1 r
.48623 .58007 m .48855 .58651 L .46106 .61323 L p F P
0 0 0 r
s
.69 .09 .12 r
.53375 .6858 m
.53168 .68546 L
s
.411 .743 1 r
.44805 .57731 m .46106 .61323 L .45375 .61893 L p F P
0 0 0 r
s
.411 .743 1 r
.43874 .57749 m .44805 .57731 L p .45375 .61893 L F P
0 0 0 r
s
.411 .743 1 r
.41859 .59505 m .43874 .57749 L p .45375 .61893 L F P
0 0 0 r
s
.411 .743 1 r
.45375 .61893 m .42703 .61825 L .41859 .59505 L p F P
0 0 0 r
s
.418 .754 1 r
.46106 .61323 m .44805 .57731 L .48623 .58007 L p F P
0 0 0 r
s
.69 .09 .12 r
.31255 .59478 m
.31461 .59228 L
s
.372 .667 .958 r
.41859 .59505 m .43874 .57749 L .41431 .57918 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.75232 .48833 m
.72504 .49977 L
s
.38 .681 .973 r
.44805 .57731 m .44609 .5701 L .43874 .57749 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.82417 .5267 m
.83476 .5275 L
s
.82417 .5267 m
.82337 .53914 L
s
.7821 .62137 m
.77642 .62196 L
s
.77642 .62196 m
.77266 .61638 L
s
.77642 .62196 m
.77398 .62393 L
s
.4905 .58262 m
.49069 .58393 L
s
.49113 .58132 m
.4905 .58262 L
s
.4905 .58262 m
.48963 .5824 L
s
.49218 .58285 m
.4905 .58262 L
s
.49253 .58265 m
.4905 .58262 L
s
.49069 .58393 m
.49218 .58285 L
s
.49218 .58285 m
.49113 .58132 L
s
.49113 .58132 m
.48963 .5824 L
s
.48963 .5824 m
.49069 .58393 L
s
.77266 .61638 m
.77835 .61578 L
s
.77266 .61638 m
.77398 .62393 L
s
.28751 .49378 m
.28206 .49903 L
s
.28873 .49416 m
.28751 .49378 L
s
.28751 .49378 m
.29054 .50201 L
s
.83476 .5275 m
.83798 .5394 L
s
.82337 .53914 m
.83798 .5394 L
s
.28206 .49903 m
.28327 .49943 L
s
.29054 .50201 m
.28206 .49903 L
s
.71935 .68996 m
.72017 .70345 L
s
.77835 .61578 m
.7821 .62137 L
s
.77398 .62393 m
.7821 .62137 L
s
.29054 .50201 m
.28327 .49943 L
s
.28873 .49416 m
.29054 .50201 L
s
.26471 .47487 m
.29054 .50201 L
s
.79093 .41207 m
.78127 .40981 L
s
.78127 .40981 m
.78204 .3966 L
s
.78127 .40981 m
.77708 .40568 L
s
.4987 .89586 m
.51677 .85064 L
s
.71343 .37686 m
.68552 .37117 L
s
.51103 .85685 m
.51953 .86137 L
s
.50674 .85805 m
.51103 .85685 L
s
.51103 .85685 m
.51677 .85064 L
s
.77398 .62393 m
.77835 .61578 L
s
.82337 .53914 m
.83476 .5275 L
s
.73365 .50143 m
.72865 .50063 L
s
.72865 .50063 m
.72742 .49351 L
s
.72865 .50063 m
.72504 .49977 L
s
.78204 .3966 m
.79171 .3988 L
s
.78204 .3966 m
.77708 .40568 L
s
.28327 .49943 m
.28873 .49416 L
s
.72096 .70185 m
.7179 .70134 L
s
.72211 .70014 m
.72096 .70185 L
s
.72017 .70345 m
.72096 .70185 L
s
.72742 .49351 m
.73243 .49428 L
s
.72742 .49351 m
.72504 .49977 L
s
.51953 .86137 m
.51527 .86258 L
s
.51677 .85064 m
.51953 .86137 L
s
.7179 .70134 m
.71904 .69962 L
s
.7179 .70134 m
.72017 .70345 L
s
.45766 .47696 m
.45656 .47697 L
s
.45661 .47457 m
.45766 .47696 L
s
.45766 .47696 m
.45525 .47623 L
s
.45792 .47531 m
.45766 .47696 L
s
.45228 .47099 m
.45766 .47696 L
s
.45661 .47457 m
.45525 .47623 L
s
.45792 .47531 m
.45661 .47457 L
s
.46125 .76449 m
.46567 .76536 L
s
.45838 .76422 m
.46125 .76449 L
s
.46125 .76449 m
.4629 .75957 L
s
.45525 .47623 m
.45656 .47697 L
s
.71904 .69962 m
.72211 .70014 L
s
.72017 .70345 m
.72211 .70014 L
s
.71904 .69962 m
.72017 .70345 L
s
.45656 .47697 m
.45792 .47531 L
s
.68019 .57901 m
.66852 .58795 L
s
.73243 .49428 m
.73365 .50143 L
s
.72504 .49977 m
.73365 .50143 L
s
.26137 .40211 m
.26017 .4015 L
s
.2699 .39168 m
.26137 .40211 L
s
.27545 .40508 m
.26137 .40211 L
s
.46567 .76536 m
.4628 .7651 L
s
.4629 .75957 m
.46567 .76536 L
s
.26874 .39101 m
.2699 .39168 L
s
.2699 .39168 m
.27545 .40508 L
s
.51677 .85064 m
.51527 .86258 L
s
.50674 .85805 m
.51677 .85064 L
s
.79171 .3988 m
.79093 .41207 L
s
.77708 .40568 m
.79093 .41207 L
s
.4629 .75957 m
.4628 .7651 L
s
.45838 .76422 m
.4629 .75957 L
s
.45853 .78569 m
.4629 .75957 L
s
.51527 .86258 m
.50674 .85805 L
s
.72504 .49977 m
.73243 .49428 L
s
.4628 .7651 m
.45838 .76422 L
s
.67247 .58752 m
.67082 .58752 L
s
.67082 .58752 m
.66925 .5848 L
s
.67082 .58752 m
.66852 .58795 L
s
.66925 .5848 m
.6709 .58479 L
s
.66925 .5848 m
.66852 .58795 L
s
.77708 .40568 m
.79171 .3988 L
s
.86867 .57535 m
.85157 .61112 L
s
.6709 .58479 m
.67247 .58752 L
s
.66852 .58795 m
.67247 .58752 L
s
.4183 .66558 m
.41903 .66813 L
s
.41745 .66661 m
.4183 .66558 L
s
.4183 .66558 m
.41691 .66778 L
s
.41957 .66696 m
.4183 .66558 L
s
.418 .67455 m
.4183 .66558 L
s
.66852 .58795 m
.6709 .58479 L
s
.41903 .66813 m
.41957 .66696 L
s
.41691 .66778 m
.41903 .66813 L
s
.41745 .66661 m
.41691 .66778 L
s
.27545 .40508 m
.26017 .4015 L
s
.26874 .39101 m
.27545 .40508 L
s
.22338 .36249 m
.27545 .40508 L
s
.64673 .78249 m
.66136 .77846 L
s
.69259 .37681 m
.68779 .37527 L
s
.68779 .37527 m
.68971 .36783 L
s
.68779 .37527 m
.68552 .37117 L
s
.41957 .66696 m
.41745 .66661 L
s
.68971 .36783 m
.69452 .36936 L
s
.68971 .36783 m
.68552 .37117 L
s
.4243 .99007 m
.44303 .91533 L
s
.64068 .46709 m
.6263 .46854 L
s
.42855 .36726 m
.42857 .36742 L
s
.43023 .36279 m
.42855 .36726 L
s
.43383 .36679 m
.42855 .36726 L
s
.65944 .78033 m
.65851 .78126 L
s
.65835 .77727 m
.65944 .78033 L
s
.66136 .77846 m
.65944 .78033 L
s
.65742 .7782 m
.65835 .77727 L
s
.65835 .77727 m
.66136 .77846 L
s
.43025 .36294 m
.43023 .36279 L
s
.43023 .36279 m
.43383 .36679 L
s
.566 1 1 r
.73069 .71539 m .70265 .7378 L .68948 .72889 L p F P
0 0 0 r
s
.569 1 1 r
.6917 .75177 m .70265 .7378 L .68948 .72889 L p F P
0 0 0 r
s
.69 .09 .12 r
.43383 .36679 m
.42857 .36742 L
s
.43025 .36294 m
.43383 .36679 L
s
.41168 .35834 m
.43383 .36679 L
s
.69452 .36936 m
.69259 .37681 L
s
.68552 .37117 m
.69259 .37681 L
s
.62998 .47009 m
.62844 .46965 L
s
.62844 .46965 m
.62839 .4664 L
s
.62844 .46965 m
.6263 .46854 L
s
.66136 .77846 m
.65851 .78126 L
s
.65742 .7782 m
.66136 .77846 L
s
.65851 .78126 m
.65742 .7782 L
s
.54 1 1 r
.73637 .71197 m .73069 .71539 L .71772 .70416 L p F P
0 0 0 r
s
.566 1 1 r
.68948 .72889 m .71772 .70416 L .73069 .71539 L p F P
0 0 0 r
s
.69 .09 .12 r
.62839 .4664 m
.62993 .46684 L
s
.62839 .4664 m
.6263 .46854 L
s
.26017 .4015 m
.26874 .39101 L
s
.548 1 1 r
.68473 .73495 m .6917 .75177 L .67765 .78318 L p F P
0 0 0 r
s
.569 1 1 r
.68948 .72889 m .68473 .73495 L .6917 .75177 L p F P
0 0 0 r
s
.69 .09 .12 r
.68552 .37117 m
.69452 .36936 L
s
.38279 .56814 m
.3816 .56825 L
s
.38171 .56576 m
.38279 .56814 L
s
.38279 .56814 m
.38033 .56745 L
s
.38298 .56656 m
.38279 .56814 L
s
.37711 .56244 m
.38279 .56814 L
s
.8299 .46317 m
.79941 .47703 L
s
.54 1 1 r
.71772 .70416 m .73661 .69276 L .73637 .71197 L p F P
0 0 0 r
s
.528 1 1 r
.74654 .68756 m .73661 .69276 L .73637 .71197 L p F P
0 0 0 r
s
.528 1 1 r
.73637 .71197 m .75929 .70002 L .74654 .68756 L p F P
0 0 0 r
s
.69 .09 .12 r
.38171 .56576 m
.38033 .56745 L
s
.38298 .56656 m
.38171 .56576 L
s
.42857 .36742 m
.43025 .36294 L
s
.38033 .56745 m
.3816 .56825 L
s
.62993 .46684 m
.62998 .47009 L
s
.6263 .46854 m
.62998 .47009 L
s
.6263 .46854 m
.62993 .46684 L
s
.3816 .56825 m
.38298 .56656 L
s
.01 w
.60694 .67109 Mdot
.5 Mabswid
.4377 .92468 m
.451 .93203 L
s
.42748 .92878 m
.4377 .92468 L
s
.4377 .92468 m
.44303 .91533 L
s
.38349 .87947 m
.38632 .83142 L
s
.60082 .35418 m
.5934 .34449 L
s
.515 .999 1 r
.78831 .68738 m .75929 .70002 L .74654 .68756 L p F P
0 0 0 r
s
.69 .09 .12 r
.38576 .83849 m
.39307 .8414 L
s
.37843 .84074 m
.38576 .83849 L
s
.38576 .83849 m
.38632 .83142 L
s
.57298 .87644 m
.59687 .84964 L
s
.79079 .34999 m
.75694 .33818 L
s
.56295 .56058 m
.5633 .56036 L
s
.5633 .56036 m
.56293 .55933 L
s
.5633 .56036 m
.56197 .56026 L
s
.56293 .55933 m
.56258 .55954 L
s
.56293 .55933 m
.56197 .56026 L
s
.56197 .56026 m
.56295 .56058 L
s
.56197 .56026 m
.56258 .55954 L
s
.5668 .55871 m
.56197 .56026 L
s
.35368 .46108 m
.35019 .46519 L
s
.35419 .46123 m
.35368 .46108 L
s
.35368 .46108 m
.35626 .46668 L
s
.35019 .46519 m
.35069 .46535 L
s
.35626 .46668 m
.35019 .46519 L
s
.56258 .55954 m
.56295 .56058 L
s
.86182 .60774 m
.85196 .60822 L
s
.85196 .60822 m
.84825 .60002 L
s
.85196 .60822 m
.85157 .61112 L
s
.487 .876 1 r
.67765 .78318 m .67597 .78919 L .66265 .78718 L p F P
0 0 0 r
s
.487 .876 1 r
.66265 .78718 m .66827 .76723 L .67765 .78318 L p F P
0 0 0 r
s
.548 1 1 r
.67765 .78318 m .66827 .76723 L .68473 .73495 L p F P
0 0 0 r
s
.69 .09 .12 r
.451 .93203 m
.44083 .93619 L
s
.44303 .91533 m
.451 .93203 L
s
.35626 .46668 m
.35069 .46535 L
s
.35419 .46123 m
.35626 .46668 L
s
.33587 .44932 m
.35626 .46668 L
s
.59484 .34469 m
.59697 .34568 L
s
.5928 .34718 m
.59484 .34469 L
s
.59484 .34469 m
.5934 .34449 L
s
.59493 .34818 m
.5928 .34718 L
s
.5928 .34718 m
.5934 .34449 L
s
.59035 .85154 m
.59597 .85687 L
s
.58816 .85317 m
.59035 .85154 L
s
.59035 .85154 m
.59687 .84964 L
s
.39307 .8414 m
.38574 .84366 L
s
.38632 .83142 m
.39307 .8414 L
s
.469 .835 1 r
.67117 .81286 m .67597 .78919 L .66265 .78718 L p F P
0 0 0 r
s
.69 .09 .12 r
.34033 .74864 m
.34296 .74919 L
s
.33634 .74982 m
.34033 .74864 L
s
.34033 .74864 m
.33898 .74491 L
s
.34232 .76788 m
.33898 .74491 L
s
.59697 .34568 m
.59493 .34818 L
s
.5934 .34449 m
.59697 .34568 L
s
.38574 .84366 m
.37843 .84074 L
s
.37843 .84074 m
.38632 .83142 L
s
.503 .976 1 r
.8177 .67607 m .78831 .68738 L .77578 .67412 L p F P
0 0 0 r
s
.69 .09 .12 r
.79808 .68362 m
.79904 .6949 L
s
.79672 .66761 m
.79736 .67512 L
s
.515 .999 1 r
.74654 .68756 m .77578 .67412 L .78831 .68738 L p F P
0 0 0 r
s
.69 .09 .12 r
.59597 .85687 m
.5938 .85852 L
s
.59687 .84964 m
.59597 .85687 L
s
.5934 .34449 m
.59493 .34818 L
s
.35069 .46535 m
.35419 .46123 L
s
.84825 .60002 m
.85813 .59952 L
s
.84825 .60002 m
.85157 .61112 L
s
.38632 .83142 m
.38574 .84366 L
s
.44083 .93619 m
.42748 .92878 L
s
.42748 .92878 m
.44303 .91533 L
s
.75733 .55496 m
.74409 .5699 L
s
.85813 .59952 m
.86182 .60774 L
s
.85157 .61112 m
.86182 .60774 L
s
.33897 .75038 m
.33634 .74982 L
s
.33634 .74982 m
.33898 .74491 L
s
.34296 .74919 m
.33897 .75038 L
s
.33898 .74491 m
.34296 .74919 L
s
.33898 .74491 m
.33897 .75038 L
s
.53727 .75209 m
.54009 .75361 L
s
.53626 .75218 m
.53727 .75209 L
s
.53727 .75209 m
.53958 .74996 L
s
.44303 .91533 m
.44083 .93619 L
s
.8004 .69169 m
.79423 .69064 L
s
.80292 .68816 m
.8004 .69169 L
s
.79904 .6949 m
.8004 .69169 L
s
.53256 .7646 m
.53958 .74996 L
s
.54009 .75361 m
.53909 .7537 L
s
.53958 .74996 m
.54009 .75361 L
s
.59687 .84964 m
.5938 .85852 L
s
.58816 .85317 m
.59687 .84964 L
s
.79423 .69064 m
.79673 .68711 L
s
.79423 .69064 m
.79904 .6949 L
s
.5938 .85852 m
.58816 .85317 L
s
.53958 .74996 m
.53909 .7537 L
s
.53626 .75218 m
.53958 .74996 L
s
.80994 .48001 m
.80151 .47831 L
s
.80151 .47831 m
.80123 .46844 L
s
.80151 .47831 m
.79941 .47703 L
s
.53909 .7537 m
.53626 .75218 L
s
.01 w
.52631 .44533 Mdot
.5 Mabswid
.85157 .61112 m
.85813 .59952 L
s
.555 1 1 r
.68148 .72438 m .68948 .72889 L .71772 .70416 L p F P
0 0 0 r
s
.565 1 1 r
.68473 .73495 m .68148 .72438 L .68948 .72889 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.32822 .3602 m
.3264 .35986 L
s
.33323 .3511 m
.32822 .3602 L
s
.33872 .36054 m
.32822 .3602 L
s
.543 1 1 r
.73661 .69276 m .71772 .70416 L .70454 .69405 L p F P
0 0 0 r
s
.555 1 1 r
.71772 .70416 m .70454 .69405 L p .68148 .72438 L F P
0 0 0 r
s
.69 .09 .12 r
.79673 .68711 m
.80292 .68816 L
s
.79904 .6949 m
.80292 .68816 L
s
.33143 .35072 m
.33323 .3511 L
s
.33323 .3511 m
.33872 .36054 L
s
.549 1 1 r
.68148 .72438 m .68473 .73495 L .66827 .76723 L p F P
0 0 0 r
s
.69 .09 .12 r
.72365 .7613 m
.74188 .77381 L
s
.495 .962 1 r
.84743 .66546 m .8177 .67607 L .80539 .66221 L p F P
0 0 0 r
s
.503 .976 1 r
.77578 .67412 m .80539 .66221 L .8177 .67607 L p F P
0 0 0 r
s
.69 .09 .12 r
.80123 .46844 m
.80967 .47012 L
s
.80123 .46844 m
.79941 .47703 L
s
.79673 .68711 m
.79904 .6949 L
s
.49182 .64723 m
.4922 .64853 L
s
.49143 .64774 m
.49182 .64723 L
s
.49182 .64723 m
.49113 .64835 L
s
.4925 .64792 m
.49182 .64723 L
s
.49177 .65176 m
.49182 .64723 L
s
.4922 .64853 m
.4925 .64792 L
s
.49113 .64835 m
.4922 .64853 L
s
.49143 .64774 m
.49113 .64835 L
s
.45 .793 1 r
.66053 .79743 m .67117 .81286 L .66771 .84213 L p F P
0 0 0 r
s
.469 .835 1 r
.66265 .78718 m .66053 .79743 L .67117 .81286 L p F P
0 0 0 r
s
.69 .09 .12 r
.49808 .97187 m
.52584 .91763 L
s
.71759 .44131 m
.69883 .44073 L
s
.29425 .3352 m
.33872 .36054 L
s
.74982 .56921 m
.74537 .56909 L
s
.74537 .56909 m
.74369 .56458 L
s
.74537 .56909 m
.74409 .5699 L
s
.4925 .64792 m
.49143 .64774 L
s
.543 1 1 r
.73879 .68041 m .73661 .69276 L p .70454 .69405 L F P
0 0 0 r
s
.527 1 1 r
.73661 .69276 m .73879 .68041 L .74654 .68756 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.80967 .47012 m
.80994 .48001 L
s
.79941 .47703 m
.80994 .48001 L
s
.33872 .36054 m
.3264 .35986 L
s
.33143 .35072 m
.33872 .36054 L
s
.74369 .56458 m
.74814 .56469 L
s
.74369 .56458 m
.74409 .5699 L
s
.514 1 1 r
.73879 .68041 m .74654 .68756 L .77578 .67412 L p F P
0 0 0 r
s
.69 .09 .12 r
.74814 .56469 m
.74982 .56921 L
s
.74409 .5699 m
.74982 .56921 L
s
.73856 .77307 m
.736 .77364 L
s
.74043 .76896 m
.73856 .77307 L
s
.74188 .77381 m
.73856 .77307 L
s
.79941 .47703 m
.80967 .47012 L
s
.27106 .557 m
.26691 .55952 L
s
.27114 .55652 m
.27106 .557 L
s
.27106 .557 m
.27156 .56209 L
s
.48545 .33093 m
.49989 .32557 L
s
.236 .392 .552 r
.55517 .35026 m .55837 .33061 L .59484 .33045 L p F P
0 0 0 r
s
.294 .487 .67 r
.54095 .32708 m .55837 .33061 L .55517 .35026 L p F P
0 0 0 r
s
.224 .377 .538 r
.59484 .33045 m .60155 .32965 L .61546 .34893 L p F P
0 0 0 r
s
.224 .377 .538 r
.61546 .34893 m .59317 .35157 L .59484 .33045 L p F P
0 0 0 r
s
.236 .392 .552 r
.59484 .33045 m .59317 .35157 L .55517 .35026 L p F P
0 0 0 r
s
.69 .09 .12 r
.26691 .55952 m
.26698 .55904 L
s
.27156 .56209 m
.26691 .55952 L
s
.73787 .76953 m
.74043 .76896 L
s
.74043 .76896 m
.74188 .77381 L
s
.74409 .5699 m
.74814 .56469 L
s
.3264 .35986 m
.33143 .35072 L
s
.22 .373 .536 r
.60155 .32965 m .6275 .32514 L .6267 .347 L p F P
0 0 0 r
s
.22 .373 .536 r
.6267 .347 m .61546 .34893 L .60155 .32965 L p F P
0 0 0 r
s
.69 .09 .12 r
.68363 .64819 m
.68408 .65729 L
s
.25887 .54173 m
.27156 .56209 L
s
.27156 .56209 m
.26698 .55904 L
s
.27114 .55652 m
.27156 .56209 L
s
.736 .77364 m
.73787 .76953 L
s
.74188 .77381 m
.736 .77364 L
s
.49814 .32806 m
.49698 .32839 L
s
.49702 .3249 m
.49814 .32806 L
s
.49989 .32557 m
.49814 .32806 L
s
.76586 .34725 m
.75797 .34445 L
s
.75797 .34445 m
.76175 .33392 L
s
.75797 .34445 m
.75694 .33818 L
s
.474 .854 1 r
.66827 .76723 m .66017 .75051 L p .65455 .78787 L F P
0 0 0 r
s
.474 .854 1 r
.65455 .78787 m .66265 .78718 L .66827 .76723 L p F P
0 0 0 r
s
.549 1 1 r
.6761 .72186 m .68148 .72438 L p .66827 .76723 L F P
0 0 0 r
s
.549 1 1 r
.66827 .76723 m .66017 .75051 L .6761 .72186 L p F P
0 0 0 r
s
.69 .09 .12 r
.49585 .32522 m
.49702 .3249 L
s
.49702 .3249 m
.49989 .32557 L
s
.45338 .54085 m
.45282 .54089 L
s
.45285 .53963 m
.45338 .54085 L
s
.45338 .54085 m
.45215 .54049 L
s
.45351 .54003 m
.45338 .54085 L
s
.45063 .5379 m
.45338 .54085 L
s
.49 .952 1 r
.87751 .65527 m .84743 .66546 L .83536 .65114 L p F P
0 0 0 r
s
.495 .962 1 r
.80539 .66221 m .83536 .65114 L .84743 .66546 L p F P
0 0 0 r
s
.69 .09 .12 r
.45285 .53963 m
.45215 .54049 L
s
.45351 .54003 m
.45285 .53963 L
s
.45215 .54049 m
.45282 .54089 L
s
.294 .487 .67 r
.55517 .35026 m .54763 .34875 L .54095 .32708 L p F P
0 0 0 r
s
.336 .558 .755 r
.51037 .31323 m .54095 .32708 L .54763 .34875 L p F P
0 0 0 r
s
.69 .09 .12 r
.73787 .76953 m
.74188 .77381 L
s
.26698 .55904 m
.27114 .55652 L
s
.45282 .54089 m
.45351 .54003 L
s
.51806 .92288 m
.52889 .9307 L
s
.51157 .92642 m
.51806 .92288 L
s
.51806 .92288 m
.52584 .91763 L
s
.76175 .33392 m
.76966 .33669 L
s
.76175 .33392 m
.75694 .33818 L
s
.45701 .85957 m
.4656 .82528 L
s
.49989 .32557 m
.49698 .32839 L
s
.49585 .32522 m
.49989 .32557 L
s
.49698 .32839 m
.49585 .32522 L
s
.68466 .65625 m
.68256 .65589 L
s
.68542 .65504 m
.68466 .65625 L
s
.68408 .65729 m
.68466 .65625 L
s
.70401 .44415 m
.7002 .44288 L
s
.7002 .44288 m
.70121 .43755 L
s
.7002 .44288 m
.69883 .44073 L
s
.205 .35 .507 r
.6267 .347 m .6275 .32514 L .65884 .31772 L p F P
0 0 0 r
s
.69 .09 .12 r
.68256 .65589 m
.68331 .65468 L
s
.68256 .65589 m
.68408 .65729 L
s
.507 .985 1 r
.80539 .66221 m .77578 .67412 L .76304 .66139 L p F P
0 0 0 r
s
.514 1 1 r
.77578 .67412 m .76304 .66139 L p .73879 .68041 L F P
0 0 0 r
s
.69 .09 .12 r
.70121 .43755 m
.70503 .43881 L
s
.70121 .43755 m
.69883 .44073 L
s
.558 1 1 r
.6761 .72186 m .67985 .7171 L .68148 .72438 L closepath p F P
0 0 0 r
s
.555 1 1 r
.70454 .69405 m .67985 .7171 L .68148 .72438 L p F P
0 0 0 r
s
.69 .09 .12 r
.68331 .65468 m
.68542 .65504 L
s
.68408 .65729 m
.68542 .65504 L
s
.68331 .65468 m
.68408 .65729 L
s
.46312 .8298 m
.46916 .83295 L
s
.45859 .83138 m
.46312 .8298 L
s
.46312 .8298 m
.4656 .82528 L
s
.52889 .9307 m
.52245 .93429 L
s
.52584 .91763 m
.52889 .9307 L
s
.70503 .43881 m
.70401 .44415 L
s
.69883 .44073 m
.70401 .44415 L
s
.24154 .46133 m
.2395 .46018 L
s
.24918 .45417 m
.24154 .46133 L
s
.2513 .46469 m
.24154 .46133 L
s
.76966 .33669 m
.76586 .34725 L
s
.75694 .33818 m
.76586 .34725 L
s
.24717 .45298 m
.24918 .45417 L
s
.24918 .45417 m
.2513 .46469 L
s
.429 .75 .972 r
.65629 .82708 m .66771 .84213 L .66577 .87144 L p F P
0 0 0 r
s
.69 .09 .12 r
.66707 .85185 m
.67945 .84861 L
s
.64943 .85646 m
.66187 .85321 L
s
.45 .793 1 r
.66771 .84213 m .65629 .82708 L .66053 .79743 L p F P
0 0 0 r
s
.69 .09 .12 r
.69883 .44073 m
.70503 .43881 L
s
.75694 .33818 m
.76966 .33669 L
s
.46916 .83295 m
.46464 .83455 L
s
.4656 .82528 m
.46916 .83295 L
s
.64324 .53407 m
.63599 .53711 L
s
.21658 .42712 m
.2513 .46469 L
s
.46 .819 1 r
.66053 .79743 m .65455 .78787 L .66265 .78718 L closepath p F P
0 0 0 r
s
.525 1 1 r
.73357 .67585 m .74139 .67174 L .73879 .68041 L closepath p F P
0 0 0 r
s
.514 1 1 r
.76304 .66139 m .74139 .67174 L .73879 .68041 L p F P
0 0 0 r
s
.543 1 1 r
.70454 .69405 m .73357 .67585 L .73879 .68041 L p F P
0 0 0 r
s
.69 .09 .12 r
.46464 .83455 m
.45859 .83138 L
s
.45859 .83138 m
.4656 .82528 L
s
.41557 .74627 m
.41499 .73024 L
s
.49 .952 1 r
.83536 .65114 m .86568 .64054 L .87751 .65527 L p F P
0 0 0 r
s
.69 .09 .12 r
.87634 .64461 m
.87751 .65527 L
s
.87751 .65527 m
.88092 .68602 L
s
.202 .347 .504 r
.65866 .34004 m .65884 .31772 L .68968 .30919 L p F P
0 0 0 r
s
.69 .09 .12 r
.67527 .32353 m
.6775 .32665 L
s
.205 .35 .507 r
.65884 .31772 m .65866 .34004 L .6267 .347 L p F P
0 0 0 r
s
.69 .09 .12 r
.41527 .7328 m
.41748 .73341 L
s
.41273 .73349 m
.41527 .7328 L
s
.41527 .7328 m
.41499 .73024 L
s
.63822 .53753 m
.637 .5373 L
s
.637 .5373 m
.63666 .53547 L
s
.637 .5373 m
.63599 .53711 L
s
.42056 .43021 m
.42032 .43031 L
s
.42198 .42717 m
.42056 .43021 L
s
.42416 .43017 m
.42056 .43021 L
s
.42174 .42727 m
.42198 .42717 L
s
.42198 .42717 m
.42416 .43017 L
s
.4656 .82528 m
.46464 .83455 L
s
.63666 .53547 m
.63789 .5357 L
s
.63666 .53547 m
.63599 .53711 L
s
.52245 .93429 m
.51157 .92642 L
s
.51157 .92642 m
.52584 .91763 L
s
.67546 .85226 m
.6736 .85436 L
s
.67324 .84602 m
.67546 .85226 L
s
.67945 .84861 m
.67546 .85226 L
s
.63789 .5357 m
.63822 .53753 L
s
.63599 .53711 m
.63822 .53753 L
s
.2513 .46469 m
.2395 .46018 L
s
.24717 .45298 m
.2513 .46469 L
s
.498 .969 1 r
.83536 .65114 m .80539 .66221 L .79288 .64874 L p F P
0 0 0 r
s
.507 .985 1 r
.76304 .66139 m .79288 .64874 L .80539 .66221 L p F P
0 0 0 r
s
.69 .09 .12 r
.42416 .43017 m
.42032 .43031 L
s
.42174 .42727 m
.42416 .43017 L
s
.40911 .42303 m
.42416 .43017 L
s
.67137 .84811 m
.67324 .84602 L
s
.67324 .84602 m
.67945 .84861 L
s
.63599 .53711 m
.63789 .5357 L
s
.83673 .53021 m
.8226 .55115 L
s
.52584 .91763 m
.52245 .93429 L
s
.41494 .7341 m
.41273 .73349 L
s
.41273 .73349 m
.41499 .73024 L
s
.41748 .73341 m
.41494 .7341 L
s
.41499 .73024 m
.41748 .73341 L
s
.548 1 1 r
.73357 .67585 m .70454 .69405 L .69116 .68593 L p F P
0 0 0 r
s
.559 1 1 r
.67985 .7171 m .70454 .69405 L .69116 .68593 L p F P
0 0 0 r
s
.69 .09 .12 r
.41499 .73024 m
.41494 .7341 L
s
.535 1 1 r
.67985 .7171 m .6761 .72186 L .66252 .71801 L p F P
0 0 0 r
s
.535 1 1 r
.66252 .71801 m .67846 .69777 L .67985 .7171 L p F P
0 0 0 r
s
.559 1 1 r
.69116 .68593 m .67846 .69777 L .67985 .7171 L p F P
0 0 0 r
s
.447 .791 1 r
.65455 .78787 m .66053 .79743 L .65629 .82708 L p F P
0 0 0 r
s
.69 .09 .12 r
.42032 .43031 m
.42174 .42727 L
s
.532 .987 1 r
.66017 .75051 m .6761 .72186 L .66252 .71801 L p F P
0 0 0 r
s
.69 .09 .12 r
.60876 .74289 m
.6187 .74006 L
s
.336 .558 .755 r
.54763 .34875 m .51461 .33573 L .51037 .31323 L p F P
0 0 0 r
s
.349 .58 .773 r
.50534 .31001 m .51037 .31323 L .51461 .33573 L p F P
0 0 0 r
s
.69 .09 .12 r
.66587 .30713 m
.67035 .30907 L
s
.66175 .3122 m
.66587 .30713 L
s
.66587 .30713 m
.66315 .30659 L
s
.2395 .46018 m
.24717 .45298 L
s
.61742 .74137 m
.61674 .74197 L
s
.61667 .73928 m
.61742 .74137 L
s
.6187 .74006 m
.61742 .74137 L
s
.61599 .73988 m
.61667 .73928 L
s
.61667 .73928 m
.6187 .74006 L
s
.38027 .95604 m
.38398 .89771 L
s
.6025 .41891 m
.59745 .41254 L
s
.17391 .31149 m
.24005 .36247 L
s
.67945 .84861 m
.6736 .85436 L
s
.67137 .84811 m
.67945 .84861 L
s
.212 .355 .506 r
.5907 .37213 m .59317 .35157 L .61546 .34893 L p F P
0 0 0 r
s
.256 .425 .594 r
.55517 .35026 m .59317 .35157 L .5907 .37213 L p F P
0 0 0 r
s
.69 .09 .12 r
.6736 .85436 m
.67137 .84811 L
s
.2245 .36021 m
.21885 .35845 L
s
.23463 .34604 m
.2245 .36021 L
s
.24005 .36247 m
.2245 .36021 L
s
.522 1 1 r
.74139 .67174 m .73357 .67585 L .72041 .66553 L p F P
0 0 0 r
s
.548 1 1 r
.69116 .68593 m .72041 .66553 L .73357 .67585 L p F P
0 0 0 r
s
.69 .09 .12 r
.6187 .74006 m
.61674 .74197 L
s
.61599 .73988 m
.6187 .74006 L
s
.349 .58 .773 r
.51461 .33573 m .49789 .32514 L .50534 .31001 L p F P
0 0 0 r
s
.365 .609 .807 r
.48695 .29631 m .50534 .31001 L .49789 .32514 L p F P
0 0 0 r
s
.69 .09 .12 r
.61674 .74197 m
.61599 .73988 L
s
.256 .425 .594 r
.5527 .36159 m .55517 .35026 L p .5907 .37213 L F P
0 0 0 r
s
.282 .464 .639 r
.5527 .36159 m .54763 .34875 L .55517 .35026 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.80282 .73949 m
.8252 .769 L
s
.201 .346 .505 r
.69001 .33183 m .68968 .30919 L .72039 .29999 L p F P
0 0 0 r
s
.202 .347 .504 r
.68968 .30919 m .69001 .33183 L .65866 .34004 L p F P
0 0 0 r
s
.69 .09 .12 r
.66175 .3122 m
.66315 .30659 L
s
.66175 .3122 m
.66622 .31415 L
s
.66315 .30659 m
.66895 .31469 L
s
.66895 .31469 m
.66909 .31489 L
s
.66622 .31415 m
.67035 .30907 L
s
.66315 .30659 m
.67035 .30907 L
s
.22905 .34417 m
.23463 .34604 L
s
.23463 .34604 m
.24005 .36247 L
s
.88261 .68116 m
.87326 .67956 L
s
.88674 .67575 m
.88261 .68116 L
s
.88092 .68602 m
.88261 .68116 L
s
.522 1 1 r
.75166 .65102 m .74139 .67174 L p .72041 .66553 L F P
0 0 0 r
s
.515 1 1 r
.74139 .67174 m .75166 .65102 L .76304 .66139 L closepath p F P
0 0 0 r
s
.213 .36 .518 r
.62596 .35999 m .61546 .34893 L .6267 .347 L closepath p F P
0 0 0 r
s
.212 .355 .506 r
.61546 .34893 m .62596 .35999 L p .5907 .37213 L F P
0 0 0 r
s
.318 .526 .713 r
.54763 .34875 m .5527 .36159 L .55074 .36887 L p F P
0 0 0 r
s
.318 .526 .713 r
.51461 .33573 m .54763 .34875 L p .55074 .36887 L F P
0 0 0 r
s
.69 .09 .12 r
.66315 .30659 m
.66622 .31415 L
s
.57404 .95313 m
.61096 .91999 L
s
.79677 .41478 m
.77425 .41182 L
s
.36721 .30711 m
.40416 .31448 L
s
.492 .958 1 r
.86568 .64054 m .83536 .65114 L .82309 .63708 L p F P
0 0 0 r
s
.498 .969 1 r
.79288 .64874 m .82309 .63708 L .83536 .65114 L p F P
0 0 0 r
s
.69 .09 .12 r
.59843 .41261 m
.59988 .41333 L
s
.59705 .41432 m
.59843 .41261 L
s
.59843 .41261 m
.59745 .41254 L
s
.87326 .67956 m
.87736 .67413 L
s
.87326 .67956 m
.88092 .68602 L
s
.59849 .41504 m
.59705 .41432 L
s
.59705 .41432 m
.59745 .41254 L
s
.207 .352 .507 r
.6267 .347 m .65866 .34004 L .65805 .36219 L p F P
0 0 0 r
s
.207 .352 .507 r
.62596 .35999 m .6267 .347 L p .65805 .36219 L F P
0 0 0 r
s
.474 .854 1 r
.66017 .75051 m .6508 .78135 L .65455 .78787 L p F P
0 0 0 r
s
.497 .904 1 r
.6543 .73273 m .66017 .75051 L .6508 .78135 L p F P
0 0 0 r
s
.532 .987 1 r
.66252 .71801 m .6543 .73273 L .66017 .75051 L p F P
0 0 0 r
s
.417 .726 .942 r
.65378 .8567 m .66577 .87144 L .6647 .90099 L p F P
0 0 0 r
s
.429 .75 .972 r
.66577 .87144 m .65378 .8567 L .65629 .82708 L p F P
0 0 0 r
s
.69 .09 .12 r
.39719 .31683 m
.39497 .31699 L
s
.39852 .30903 m
.39719 .31683 L
s
.40416 .31448 m
.39719 .31683 L
s
.59988 .41333 m
.59849 .41504 L
s
.59745 .41254 m
.59988 .41333 L
s
.59745 .41254 m
.59849 .41504 L
s
.01 w
.56772 .62829 Mdot
.5 Mabswid
.39631 .30916 m
.39852 .30903 L
s
.39852 .30903 m
.40416 .31448 L
s
.502 .982 1 r
.75166 .65102 m .76304 .66139 L .79288 .64874 L p F P
0 0 0 r
s
.69 .09 .12 r
.33815 .84228 m
.33045 .81002 L
s
.56139 .30272 m
.56842 .28281 L
s
.45 .804 1 r
.64911 .78941 m .6508 .78135 L .65455 .78787 L closepath p F P
0 0 0 r
s
.447 .791 1 r
.64911 .78941 m .65455 .78787 L p .65629 .82708 L F P
0 0 0 r
s
.69 .09 .12 r
.87736 .67413 m
.88674 .67575 L
s
.88092 .68602 m
.88674 .67575 L
s
.34114 .52632 m
.33845 .52837 L
s
.34094 .52597 m
.34114 .52632 L
s
.34114 .52632 m
.34173 .52982 L
s
.33845 .52837 m
.33823 .52803 L
s
.34173 .52982 m
.33845 .52837 L
s
.40416 .31448 m
.39497 .31699 L
s
.39631 .30916 m
.40416 .31448 L
s
.8196 .766 m
.81618 .7653 L
s
.82521 .76083 m
.8196 .766 L
s
.8252 .769 m
.8196 .766 L
s
.82968 .55057 m
.82232 .54991 L
s
.82232 .54991 m
.82122 .54327 L
s
.82232 .54991 m
.8226 .55115 L
s
.33155 .51658 m
.34173 .52982 L
s
.429 .753 .974 r
.64552 .81145 m .65629 .82708 L .65378 .8567 L p F P
0 0 0 r
s
.447 .791 1 r
.65629 .82708 m .64552 .81145 L .64911 .78941 L p F P
0 0 0 r
s
.69 .09 .12 r
.24005 .36247 m
.21885 .35845 L
s
.22905 .34417 m
.24005 .36247 L
s
.87736 .67413 m
.88092 .68602 L
s
.201 .346 .506 r
.72116 .32286 m .72039 .29999 L .75113 .29031 L p F P
0 0 0 r
s
.201 .346 .505 r
.72039 .29999 m .72116 .32286 L .69001 .33183 L p F P
0 0 0 r
s
.69 .09 .12 r
.34173 .52982 m
.33823 .52803 L
s
.34094 .52597 m
.34173 .52982 L
s
.38335 .90406 m
.39315 .90992 L
s
.3733 .90906 m
.38335 .90406 L
s
.38335 .90406 m
.38398 .89771 L
s
.197 .337 .489 r
.65805 .36219 m .65866 .34004 L .69001 .33183 L p F P
0 0 0 r
s
.69 .09 .12 r
.39497 .31699 m
.39631 .30916 L
s
.33823 .52803 m
.34094 .52597 L
s
.82179 .76012 m
.82521 .76083 L
s
.82521 .76083 m
.8252 .769 L
s
.5327 .83909 m
.54714 .81897 L
s
.60168 .92069 m
.60918 .92922 L
s
.59783 .9241 m
.60168 .92069 L
s
.60168 .92069 m
.61096 .91999 L
s
.492 .958 1 r
.82309 .63708 m .85365 .626 L .86568 .64054 L p F P
0 0 0 r
s
.69 .09 .12 r
.8286 .54393 m
.82968 .55057 L
s
.8226 .55115 m
.82968 .55057 L
s
.82122 .54327 m
.8286 .54393 L
s
.82122 .54327 m
.8226 .55115 L
s
.256 .425 .594 r
.5907 .37213 m .55666 .37005 L .5527 .36159 L p F P
0 0 0 r
s
.272 .446 .614 r
.55666 .37005 m .55074 .36887 L .5527 .36159 L closepath p F P
0 0 0 r
s
.365 .609 .807 r
.49789 .32514 m .48991 .31926 L .48695 .29631 L p F P
0 0 0 r
s
.372 .625 .824 r
.46619 .27792 m .48695 .29631 L .48991 .31926 L p F P
0 0 0 r
s
.69 .09 .12 r
.60918 .92922 m
.60537 .93267 L
s
.61096 .91999 m
.60918 .92922 L
s
.01 w
.52631 .51265 Mdot
.5 Mabswid
.21885 .35845 m
.22905 .34417 L
s
.318 .526 .713 r
.55074 .36887 m .52041 .35812 L .51461 .33573 L p F P
0 0 0 r
s
.344 .569 .759 r
.49789 .32514 m .51461 .33573 L .52041 .35812 L p F P
0 0 0 r
s
.69 .09 .12 r
.81618 .7653 m
.82179 .76012 L
s
.8252 .769 m
.81618 .7653 L
s
.207 .352 .507 r
.65805 .36219 m .63417 .36704 L .62596 .35999 L p F P
0 0 0 r
s
.207 .35 .502 r
.63417 .36704 m .62533 .36855 L .62596 .35999 L closepath p F P
0 0 0 r
s
.212 .355 .506 r
.62596 .35999 m .62533 .36855 L .5907 .37213 L p F P
0 0 0 r
s
.501 .978 1 r
.82309 .63708 m .79288 .64874 L .78018 .63608 L p F P
0 0 0 r
s
.502 .982 1 r
.79288 .64874 m .78018 .63608 L p .75166 .65102 L F P
0 0 0 r
s
.69 .09 .12 r
.76257 .62462 m
.76395 .643 L
s
.56673 .28487 m
.57034 .28751 L
s
.56367 .28612 m
.56673 .28487 L
s
.56673 .28487 m
.56842 .28281 L
s
.33284 .81333 m
.33747 .81602 L
s
.32653 .81701 m
.33284 .81333 L
s
.33284 .81333 m
.33045 .81002 L
s
.5433 .82056 m
.54745 .82415 L
s
.54104 .82187 m
.5433 .82056 L
s
.5433 .82056 m
.54714 .81897 L
s
.72813 .83589 m
.76464 .84755 L
s
.29565 .72748 m
.28637 .71945 L
s
.8226 .55115 m
.8286 .54393 L
s
.82179 .76012 m
.8252 .769 L
s
.43 .77 .991 r
.6508 .78135 m .64266 .76441 L p .63703 .7971 L F P
0 0 0 r
s
.43 .77 .991 r
.63703 .7971 m .64911 .78941 L .6508 .78135 L p F P
0 0 0 r
s
.497 .904 1 r
.6508 .78135 m .64266 .76441 L .6543 .73273 L p F P
0 0 0 r
s
.69 .09 .12 r
.76072 .64018 m
.76496 .64092 L
s
.76496 .64092 m
.76662 .63844 L
s
.76395 .643 m
.76496 .64092 L
s
.57034 .28751 m
.56728 .28876 L
s
.56842 .28281 m
.57034 .28751 L
s
.54745 .82415 m
.54519 .82547 L
s
.54714 .81897 m
.54745 .82415 L
s
.76072 .64018 m
.76238 .6377 L
s
.76072 .64018 m
.76395 .643 L
s
.39315 .90992 m
.3831 .91497 L
s
.38398 .89771 m
.39315 .90992 L
s
.56728 .28876 m
.56367 .28612 L
s
.56367 .28612 m
.56842 .28281 L
s
.72195 .5087 m
.71268 .51312 L
s
.28897 .40017 m
.31888 .42322 L
s
.3117 .42206 m
.30947 .42148 L
s
.31628 .41573 m
.3117 .42206 L
s
.31888 .42322 m
.3117 .42206 L
s
.3831 .91497 m
.3733 .90906 L
s
.3733 .90906 m
.38398 .89771 L
s
.197 .338 .492 r
.68999 .35439 m .69001 .33183 L .72116 .32286 L p F P
0 0 0 r
s
.197 .337 .489 r
.69001 .33183 m .68999 .35439 L .65805 .36219 L p F P
0 0 0 r
s
.69 .09 .12 r
.33116 .81972 m
.32653 .81701 L
s
.32653 .81701 m
.33045 .81002 L
s
.488 .96 1 r
.68124 .68217 m .69116 .68593 L .72041 .66553 L p F P
0 0 0 r
s
.526 1 1 r
.67846 .69777 m .68124 .68217 L .69116 .68593 L closepath p F P
0 0 0 r
s
.196 .326 .464 r
.58694 .39158 m .5907 .37213 L .62533 .36855 L p F P
0 0 0 r
s
.242 .399 .558 r
.55666 .37005 m .5907 .37213 L .58694 .39158 L p F P
0 0 0 r
s
.455 .874 1 r
.67846 .69777 m .68124 .68217 L p .65245 .71868 L F P
0 0 0 r
s
.455 .874 1 r
.65245 .71868 m .66252 .71801 L .67846 .69777 L p F P
0 0 0 r
s
.69 .09 .12 r
.31407 .41513 m
.31628 .41573 L
s
.31628 .41573 m
.31888 .42322 L
s
.76238 .6377 m
.76662 .63844 L
s
.76395 .643 m
.76662 .63844 L
s
.201 .346 .506 r
.75113 .29031 m .7523 .31337 L .72116 .32286 L p F P
0 0 0 r
s
.69 .09 .12 r
.75113 .29031 m
.75644 .2983 L
s
.73575 .26716 m
.75113 .29031 L
s
.56842 .28281 m
.56728 .28876 L
s
.41 .712 .924 r
.65228 .88653 m .6647 .90099 L .66418 .93088 L p F P
0 0 0 r
s
.417 .726 .942 r
.6647 .90099 m .65228 .88653 L .65378 .8567 L p F P
0 0 0 r
s
.69 .09 .12 r
.54519 .82547 m
.54104 .82187 L
s
.54104 .82187 m
.54714 .81897 L
s
.54714 .81897 m
.54519 .82547 L
s
.78075 .41737 m
.77459 .41509 L
s
.77459 .41509 m
.77685 .40747 L
s
.77459 .41509 m
.77425 .41182 L
s
.428 .76 .979 r
.64552 .81145 m .63703 .7971 L .64911 .78941 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.33747 .81602 m
.33116 .81972 L
s
.33045 .81002 m
.33747 .81602 L
s
.76238 .6377 m
.76395 .643 L
s
.49099 .72402 m
.49321 .71514 L
s
.61096 .91999 m
.60537 .93267 L
s
.59783 .9241 m
.61096 .91999 L
s
.60537 .93267 m
.59783 .9241 L
s
.49256 .71638 m
.49411 .71713 L
s
.49143 .7167 m
.49256 .71638 L
s
.49256 .71638 m
.49321 .71514 L
s
.242 .399 .558 r
.58694 .39158 m .56947 .39052 L .55666 .37005 L p F P
0 0 0 r
s
.251 .409 .564 r
.55074 .36887 m .55666 .37005 L .56947 .39052 L p F P
0 0 0 r
s
.69 .09 .12 r
.77685 .40747 m
.78302 .40974 L
s
.77685 .40747 m
.77425 .41182 L
s
.49411 .71713 m
.49298 .71746 L
s
.49321 .71514 m
.49411 .71713 L
s
.75782 .84797 m
.75519 .84988 L
s
.7594 .84055 m
.75782 .84797 L
s
.76464 .84755 m
.75782 .84797 L
s
.482 .903 1 r
.6543 .73273 m .65245 .71868 L .66252 .71801 L closepath p F P
0 0 0 r
s
.251 .409 .564 r
.56947 .39052 m .54428 .38556 L .55074 .36887 L p F P
0 0 0 r
s
.296 .483 .657 r
.52041 .35812 m .55074 .36887 L .54428 .38556 L p F P
0 0 0 r
s
.69 .09 .12 r
.49298 .71746 m
.49143 .7167 L
s
.49143 .7167 m
.49321 .71514 L
s
.48452 .39595 m
.49436 .39242 L
s
.33045 .81002 m
.33116 .81972 L
s
.49321 .71514 m
.49298 .71746 L
s
.522 1 1 r
.72041 .66553 m .7501 .6497 L .75166 .65102 L p F P
0 0 0 r
s
.524 1 1 r
.7501 .6497 m .72041 .66553 L .70709 .6579 L p F P
0 0 0 r
s
.488 .96 1 r
.72041 .66553 m .70709 .6579 L p .68124 .68217 L F P
0 0 0 r
s
.196 .33 .473 r
.62302 .38936 m .62533 .36855 L .63417 .36704 L p F P
0 0 0 r
s
.196 .326 .464 r
.62533 .36855 m .62302 .38936 L .58694 .39158 L p F P
0 0 0 r
s
.69 .09 .12 r
.28838 .71903 m
.29026 .72044 L
s
.28621 .72169 m
.28838 .71903 L
s
.28838 .71903 m
.28637 .71945 L
s
.38398 .89771 m
.3831 .91497 L
s
.31888 .42322 m
.30947 .42148 L
s
.31407 .41513 m
.31888 .42322 L
s
.28809 .7231 m
.28621 .72169 L
s
.28621 .72169 m
.28637 .71945 L
s
.75677 .84243 m
.7594 .84055 L
s
.7594 .84055 m
.76464 .84755 L
s
.495 .966 1 r
.85365 .626 m .82309 .63708 L .81062 .62367 L p F P
0 0 0 r
s
.501 .978 1 r
.78018 .63608 m .81062 .62367 L .82309 .63708 L p F P
0 0 0 r
s
.69 .09 .12 r
.78302 .40974 m
.78075 .41737 L
s
.77425 .41182 m
.78075 .41737 L
s
.199 .337 .486 r
.65693 .38128 m .63417 .36704 L .65805 .36219 L closepath p F P
0 0 0 r
s
.196 .33 .473 r
.63417 .36704 m .65693 .38128 L p .62302 .38936 L F P
0 0 0 r
s
.69 .09 .12 r
.49317 .39406 m
.49237 .39435 L
s
.4924 .39191 m
.49317 .39406 L
s
.49436 .39242 m
.49317 .39406 L
s
.4916 .3922 m
.4924 .39191 L
s
.4924 .39191 m
.49436 .39242 L
s
.416 .726 .94 r
.64229 .84144 m .65378 .8567 L .65228 .88653 L p F P
0 0 0 r
s
.429 .753 .974 r
.65378 .8567 m .64229 .84144 L .64552 .81145 L p F P
0 0 0 r
s
.69 .09 .12 r
.68722 .72053 m
.70035 .72983 L
s
.25276 .61164 m
.25155 .62546 L
s
.29026 .72044 m
.28809 .7231 L
s
.28637 .71945 m
.29026 .72044 L
s
.30947 .42148 m
.31407 .41513 L
s
.71589 .51422 m
.71303 .51345 L
s
.71303 .51345 m
.7132 .51024 L
s
.71303 .51345 m
.71268 .51312 L
s
.28637 .71945 m
.28809 .7231 L
s
.344 .569 .759 r
.49221 .33305 m .49789 .32514 L p .52041 .35812 L F P
0 0 0 r
s
.352 .586 .776 r
.49221 .33305 m .48991 .31926 L .49789 .32514 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.77425 .41182 m
.78302 .40974 L
s
.49436 .39242 m
.49237 .39435 L
s
.4916 .3922 m
.49436 .39242 L
s
.49237 .39435 m
.4916 .3922 L
s
.7132 .51024 m
.71606 .51101 L
s
.7132 .51024 m
.71268 .51312 L
s
.51 .999 1 r
.7501 .6497 m .75369 .64797 L .75166 .65102 L closepath p F P
0 0 0 r
s
.502 .982 1 r
.78018 .63608 m .75369 .64797 L .75166 .65102 L p F P
0 0 0 r
s
.472 .87 1 r
.65245 .71868 m .6543 .73273 L .64266 .76441 L p F P
0 0 0 r
s
.69 .09 .12 r
.71606 .51101 m
.71589 .51422 L
s
.71268 .51312 m
.71589 .51422 L
s
.45542 .93683 m
.46846 .89476 L
s
.246 .28269 m
.30526 .31144 L
s
.197 .339 .494 r
.72164 .34573 m .72116 .32286 L .7523 .31337 L p F P
0 0 0 r
s
.197 .338 .492 r
.72116 .32286 m .72164 .34573 L .68999 .35439 L p F P
0 0 0 r
s
.69 .09 .12 r
.69765 .72927 m
.69618 .72952 L
s
.69925 .72642 m
.69765 .72927 L
s
.70035 .72983 m
.69765 .72927 L
s
.71268 .51312 m
.71606 .51101 L
s
.75519 .84988 m
.75677 .84243 L
s
.76464 .84755 m
.75519 .84988 L
s
.69778 .72666 m
.69925 .72642 L
s
.69925 .72642 m
.70035 .72983 L
s
.75677 .84243 m
.76464 .84755 L
s
.88435 .71704 m
.91148 .76403 L
s
.01 w
.44889 .60789 Mdot
.5 Mabswid
.502 .987 1 r
.75369 .64797 m .7501 .6497 L .73701 .64007 L p F P
0 0 0 r
s
.524 1 1 r
.70709 .6579 m .73701 .64007 L .7501 .6497 L p F P
0 0 0 r
s
.194 .329 .475 r
.65805 .36219 m .68999 .35439 L .68939 .3766 L p F P
0 0 0 r
s
.194 .329 .475 r
.65693 .38128 m .65805 .36219 L p .68939 .3766 L F P
0 0 0 r
s
.69 .09 .12 r
.67168 .37915 m
.68096 .39172 L
s
.25315 .62391 m
.24977 .62335 L
s
.25381 .62202 m
.25315 .62391 L
s
.25155 .62546 m
.25315 .62391 L
s
.502 .987 1 r
.77076 .62776 m .75369 .64797 L p .73701 .64007 L F P
0 0 0 r
s
.502 .985 1 r
.75369 .64797 m .77076 .62776 L .78018 .63608 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.69618 .72952 m
.69778 .72666 L
s
.70035 .72983 m
.69618 .72952 L
s
.423 .748 .965 r
.63703 .7971 m .64552 .81145 L .64229 .84144 L p F P
0 0 0 r
s
.69 .09 .12 r
.29325 .31252 m
.28792 .31181 L
s
.29874 .29955 m
.29325 .31252 L
s
.30526 .31144 m
.29325 .31252 L
s
.69778 .72666 m
.70035 .72983 L
s
.24977 .62335 m
.25043 .62145 L
s
.24977 .62335 m
.25155 .62546 L
s
.359 .6 .792 r
.48991 .31926 m .49221 .33305 L .48775 .33764 L p F P
0 0 0 r
s
.359 .6 .792 r
.46831 .30116 m .48991 .31926 L p .48775 .33764 L F P
0 0 0 r
s
.372 .625 .824 r
.48991 .31926 m .46831 .30116 L .46619 .27792 L p F P
0 0 0 r
s
.375 .632 .831 r
.44656 .25857 m .46619 .27792 L .46831 .30116 L p F P
0 0 0 r
s
.69 .09 .12 r
.44235 .27819 m
.45424 .27361 L
s
.45969 .27151 m
.47186 .26682 L
s
.73953 .26819 m
.74662 .27103 L
s
.73328 .2759 m
.73953 .26819 L
s
.73953 .26819 m
.73575 .26716 L
s
.25043 .62145 m
.25381 .62202 L
s
.25155 .62546 m
.25381 .62202 L
s
.29343 .29875 m
.29874 .29955 L
s
.29874 .29955 m
.30526 .31144 L
s
.25043 .62145 m
.25155 .62546 L
s
.296 .483 .657 r
.54428 .38556 m .52871 .38009 L .52041 .35812 L p F P
0 0 0 r
s
.325 .534 .716 r
.49403 .34223 m .52041 .35812 L .52871 .38009 L p F P
0 0 0 r
s
.344 .569 .759 r
.52041 .35812 m .49403 .34223 L .49221 .33305 L p F P
0 0 0 r
s
.495 .966 1 r
.81062 .62367 m .84143 .61198 L .85365 .626 L p F P
0 0 0 r
s
.69 .09 .12 r
.64593 .60412 m
.64611 .60873 L
s
.20947 .49472 m
.22588 .52746 L
s
.74034 .27877 m
.73328 .2759 L
s
.73328 .2759 m
.73575 .26716 L
s
.64643 .60822 m
.64534 .60803 L
s
.6468 .60758 m
.64643 .60822 L
s
.64611 .60873 m
.64643 .60822 L
s
.64534 .60803 m
.64571 .60739 L
s
.64534 .60803 m
.64611 .60873 L
s
.41 .712 .924 r
.66418 .93088 m .6514 .91669 L .65228 .88653 L p F P
0 0 0 r
s
.69 .09 .12 r
.65225 .93383 m
.66418 .93088 L
s
.66418 .93088 m
.69848 .92242 L
s
.41302 .82128 m
.4115 .79847 L
s
.63959 .27366 m
.63954 .23843 L
s
.64571 .60739 m
.6468 .60758 L
s
.64611 .60873 m
.6468 .60758 L
s
.67339 .3789 m
.67612 .38017 L
s
.67026 .38222 m
.67289 .37898 L
s
.64571 .60739 m
.64611 .60873 L
s
.266 .482 .729 r
.27554 .72 m .2679 .68366 L .29156 .67109 L p F P
0 0 0 r
s
.328 .607 .91 r
.28876 .66352 m .29156 .67109 L .2679 .68366 L p F P
0 0 0 r
s
.328 .607 .91 r
.2679 .68366 m .2614 .66613 L .28876 .66352 L p F P
0 0 0 r
s
.69 .09 .12 r
.67331 .38364 m
.67026 .38222 L
s
.67026 .38222 m
.67105 .37924 L
s
.197 .339 .494 r
.7523 .31337 m .75323 .33648 L .72164 .34573 L p F P
0 0 0 r
s
.491 .965 1 r
.77076 .62776 m .78018 .63608 L .81062 .62367 L p F P
0 0 0 r
s
.189 .323 .47 r
.68939 .3766 m .68999 .35439 L .72164 .34573 L p F P
0 0 0 r
s
.69 .09 .12 r
.46586 .27264 m
.46834 .27211 L
s
.46601 .26558 m
.46834 .27211 L
s
.47186 .26682 m
.46834 .27211 L
s
.46509 .89861 m
.47318 .90428 L
s
.45847 .9022 m
.46509 .89861 L
s
.46509 .89861 m
.46846 .89476 L
s
.46352 .2661 m
.46601 .26558 L
s
.46601 .26558 m
.47186 .26682 L
s
.84556 .61696 m
.84671 .6282 L
s
.84554 .61669 m
.84556 .61696 L
s
.84387 .60034 m
.84554 .61669 L
s
.375 .704 1 r
.28876 .66352 m .2614 .66613 L .24398 .63492 L p F P
0 0 0 r
s
.69 .09 .12 r
.40641 .49069 m
.41403 .49656 L
s
.41216 .49622 m
.41168 .49614 L
s
.41332 .49463 m
.41216 .49622 L
s
.41403 .49656 m
.41216 .49622 L
s
.41285 .49455 m
.41332 .49463 L
s
.41332 .49463 m
.41403 .49656 L
s
.74662 .27103 m
.74034 .27877 L
s
.73575 .26716 m
.74662 .27103 L
s
.474 .924 1 r
.67762 .68153 m .68347 .67607 L .68124 .68217 L closepath p F P
0 0 0 r
s
.488 .96 1 r
.70709 .6579 m .68347 .67607 L .68124 .68217 L p F P
0 0 0 r
s
.455 .874 1 r
.68124 .68217 m .67762 .68153 L p .65245 .71868 L F P
0 0 0 r
s
.43 .77 .991 r
.64266 .76441 m .63598 .79508 L .63703 .7971 L p F P
0 0 0 r
s
.435 .787 1 r
.63754 .74616 m .64266 .76441 L .63598 .79508 L p F P
0 0 0 r
s
.472 .87 1 r
.64877 .72006 m .65245 .71868 L p .64266 .76441 L F P
0 0 0 r
s
.472 .87 1 r
.64266 .76441 m .63754 .74616 L .64877 .72006 L p F P
0 0 0 r
s
.69 .09 .12 r
.22047 .52396 m
.21779 .5218 L
s
.22736 .51997 m
.22047 .52396 L
s
.22588 .52746 m
.22047 .52396 L
s
.67331 .38364 m
.67612 .38017 L
s
.67263 .37901 m
.67612 .38017 L
s
.2247 .51779 m
.22736 .51997 L
s
.22736 .51997 m
.22588 .52746 L
s
.41403 .49656 m
.41168 .49614 L
s
.41285 .49455 m
.41403 .49656 L
s
.67149 .37918 m
.67331 .38364 L
s
.73575 .26716 m
.74034 .27877 L
s
.41168 .49614 m
.41285 .49455 L
s
.30526 .31144 m
.28792 .31181 L
s
.29343 .29875 m
.30526 .31144 L
s
.61066 .81799 m
.63104 .81248 L
s
.69228 .92773 m
.68948 .93128 L
s
.68886 .91817 m
.69228 .92773 L
s
.69848 .92242 m
.69228 .92773 L
s
.408 .711 .921 r
.64024 .87159 m .65228 .88653 L .6514 .91669 L p F P
0 0 0 r
s
.416 .726 .94 r
.65228 .88653 m .64024 .87159 L .64229 .84144 L p F P
0 0 0 r
s
.69 .09 .12 r
.90266 .75865 m
.89959 .75638 L
s
.91239 .75272 m
.90266 .75865 L
s
.91148 .76403 m
.90266 .75865 L
s
.68605 .92169 m
.68886 .91817 L
s
.68886 .91817 m
.69848 .92242 L
s
.197 .324 .457 r
.58694 .39158 m .62302 .38936 L .61906 .40857 L p F P
0 0 0 r
s
.197 .324 .457 r
.58283 .40449 m .58694 .39158 L p .61906 .40857 L F P
0 0 0 r
s
.216 .353 .493 r
.58283 .40449 m .56947 .39052 L .58694 .39158 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.47318 .90428 m
.46659 .9079 L
s
.46846 .89476 m
.47318 .90428 L
s
.34 .565 .749 r
.49403 .34223 m .48775 .33764 L .49221 .33305 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.41203 .80075 m
.41578 .80299 L
s
.40783 .80312 m
.41203 .80075 L
s
.41203 .80075 m
.4115 .79847 L
s
.28792 .31181 m
.29343 .29875 L
s
.234 .379 .521 r
.56947 .39052 m .58283 .40449 L .5809 .40873 L p F P
0 0 0 r
s
.234 .379 .521 r
.54428 .38556 m .56947 .39052 L p .5809 .40873 L F P
0 0 0 r
s
.69 .09 .12 r
.60426 .48664 m
.60168 .48351 L
s
.16579 .37674 m
.20937 .42481 L
s
.46586 .27264 m
.47186 .26682 L
s
.46352 .2661 m
.47186 .26682 L
s
.244 .437 .657 r
.27633 .72667 m .27554 .72 L .30074 .70892 L p F P
0 0 0 r
s
.266 .482 .729 r
.29156 .67109 m .30074 .70892 L .27554 .72 L p F P
0 0 0 r
s
.69 .09 .12 r
.46352 .2661 m
.46586 .27264 L
s
.90937 .75042 m
.91239 .75272 L
s
.91239 .75272 m
.91148 .76403 L
s
.171 .285 .409 r
.61906 .40857 m .62302 .38936 L .65671 .38383 L p F P
0 0 0 r
s
.196 .33 .473 r
.65693 .38128 m .65671 .38383 L .62302 .38936 L p F P
0 0 0 r
s
.69 .09 .12 r
.22588 .52746 m
.21779 .5218 L
s
.2247 .51779 m
.22588 .52746 L
s
.6284 .81504 m
.62703 .81641 L
s
.62686 .81077 m
.6284 .81504 L
s
.63104 .81248 m
.6284 .81504 L
s
.416 .787 1 r
.64877 .72006 m .65257 .71328 L .65245 .71868 L closepath p F P
0 0 0 r
s
.455 .874 1 r
.67762 .68153 m .65257 .71328 L .65245 .71868 L p F P
0 0 0 r
s
.69 .09 .12 r
.6255 .81213 m
.62686 .81077 L
s
.62686 .81077 m
.63104 .81248 L
s
.46659 .9079 m
.45847 .9022 L
s
.45847 .9022 m
.46846 .89476 L
s
.8092 .81469 m
.85255 .84646 L
s
.37023 .70466 m
.36423 .69916 L
s
.235 .418 .626 r
.2783 .75243 m .27633 .72667 L .30346 .73099 L p F P
0 0 0 r
s
.244 .437 .657 r
.30074 .70892 m .30346 .73099 L .27633 .72667 L p F P
0 0 0 r
s
.69 .09 .12 r
.60218 .4835 m
.60292 .48389 L
s
.60147 .48438 m
.60218 .4835 L
s
.60218 .4835 m
.60168 .48351 L
s
.60221 .48477 m
.60147 .48438 L
s
.60147 .48438 m
.60168 .48351 L
s
.21779 .5218 m
.2247 .51779 L
s
.41158 .80536 m
.40783 .80312 L
s
.40783 .80312 m
.4115 .79847 L
s
.41578 .80299 m
.41158 .80536 L
s
.4115 .79847 m
.41578 .80299 L
s
.60292 .48389 m
.60221 .48477 L
s
.60168 .48351 m
.60292 .48389 L
s
.60168 .48351 m
.60221 .48477 L
s
.411 .722 .932 r
.63178 .82552 m .64229 .84144 L .64024 .87159 L p F P
0 0 0 r
s
.423 .748 .965 r
.63537 .79874 m .63703 .7971 L p .64229 .84144 L F P
0 0 0 r
s
.423 .748 .965 r
.64229 .84144 m .63178 .82552 L .63537 .79874 L p F P
0 0 0 r
s
.365 .714 .939 r
.68347 .67607 m .67762 .68153 L .66404 .68501 L p F P
0 0 0 r
s
.365 .714 .939 r
.69639 .65565 m .68347 .67607 L p .66404 .68501 L F P
0 0 0 r
s
.44 .869 1 r
.68347 .67607 m .69639 .65565 L .70709 .6579 L closepath p F P
0 0 0 r
s
.496 .971 1 r
.84143 .61198 m .81062 .62367 L .79801 .61161 L p F P
0 0 0 r
s
.491 .965 1 r
.81062 .62367 m .79801 .61161 L p .77076 .62776 L F P
0 0 0 r
s
.19 .326 .475 r
.72164 .36835 m .72164 .34573 L .75323 .33648 L p F P
0 0 0 r
s
.189 .323 .47 r
.72164 .34573 m .72164 .36835 L .68939 .3766 L p F P
0 0 0 r
s
.386 .745 .969 r
.65257 .71328 m .67762 .68153 L .66404 .68501 L p F P
0 0 0 r
s
.194 .329 .475 r
.68939 .3766 m .66067 .38303 L .65693 .38128 L p F P
0 0 0 r
s
.191 .323 .465 r
.66067 .38303 m .65671 .38383 L .65693 .38128 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.80302 .48257 m
.79221 .48824 L
s
.36354 .37241 m
.38856 .38045 L
s
.46846 .89476 m
.46659 .9079 L
s
.4115 .79847 m
.41158 .80536 L
s
.234 .379 .521 r
.53742 .3956 m .54428 .38556 L p .5809 .40873 L F P
0 0 0 r
s
.259 .418 .568 r
.53742 .3956 m .52871 .38009 L .54428 .38556 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.63104 .81248 m
.62703 .81641 L
s
.6255 .81213 m
.63104 .81248 L
s
.62703 .81641 m
.6255 .81213 L
s
.39 .778 1 r
.69639 .65565 m .70709 .6579 L .73701 .64007 L p F P
0 0 0 r
s
.69 .09 .12 r
.69848 .92242 m
.68948 .93128 L
s
.68605 .92169 m
.69848 .92242 L
s
.63938 .24276 m
.64527 .2454 L
s
.63383 .24567 m
.63938 .24276 L
s
.63938 .24276 m
.63954 .23843 L
s
.68948 .93128 m
.68605 .92169 L
s
.84157 .62393 m
.84798 .62507 L
s
.84798 .62507 m
.85071 .62124 L
s
.84671 .6282 m
.84798 .62507 L
s
.19884 .42142 m
.19269 .41907 L
s
.20846 .41121 m
.19884 .42142 L
s
.20937 .42481 m
.19884 .42142 L
s
.89959 .75638 m
.90937 .75042 L
s
.91148 .76403 m
.89959 .75638 L
s
.56868 .70109 m
.57374 .6996 L
s
.375 .704 1 r
.24398 .63492 m .27154 .62996 L .28876 .66352 L p F P
0 0 0 r
s
.406 .775 1 r
.2597 .6127 m .27154 .62996 L .24398 .63492 L p F P
0 0 0 r
s
.406 .775 1 r
.24398 .63492 m .24037 .62973 L .2597 .6127 L p F P
0 0 0 r
s
.69 .09 .12 r
.38388 .38149 m
.38178 .38163 L
s
.38531 .37605 m
.38388 .38149 L
s
.38856 .38045 m
.38388 .38149 L
s
.359 .6 .792 r
.48775 .33764 m .47138 .32451 L .46831 .30116 L p F P
0 0 0 r
s
.364 .611 .804 r
.44809 .28204 m .46831 .30116 L .47138 .32451 L p F P
0 0 0 r
s
.375 .632 .831 r
.46831 .30116 m .44809 .28204 L .44656 .25857 L p F P
0 0 0 r
s
.178 .299 .43 r
.6541 .40427 m .65671 .38383 L .66067 .38303 L p F P
0 0 0 r
s
.171 .285 .409 r
.65671 .38383 m .6541 .40427 L .61906 .40857 L p F P
0 0 0 r
s
.69 .09 .12 r
.3655 .6989 m
.36682 .69984 L
s
.36404 .70069 m
.3655 .6989 L
s
.3655 .6989 m
.36423 .69916 L
s
.325 .534 .716 r
.52871 .38009 m .50003 .36498 L .49403 .34223 L p F P
0 0 0 r
s
.324 .535 .71 r
.48775 .33764 m .49403 .34223 L .50003 .36498 L p F P
0 0 0 r
s
.69 .09 .12 r
.36536 .70163 m
.36404 .70069 L
s
.36404 .70069 m
.36423 .69916 L
s
.41 .731 .941 r
.63537 .79874 m .63598 .79508 L .63703 .7971 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.90937 .75042 m
.91148 .76403 L
s
.84157 .62393 m
.84429 .6201 L
s
.84157 .62393 m
.84671 .6282 L
s
.5731 .70029 m
.57274 .70058 L
s
.57272 .69921 m
.5731 .70029 L
s
.57374 .6996 m
.5731 .70029 L
s
.38321 .37618 m
.38531 .37605 L
s
.38531 .37605 m
.38856 .38045 L
s
.186 .314 .454 r
.68834 .39235 m .66067 .38303 L .68939 .3766 L closepath p F P
0 0 0 r
s
.178 .299 .43 r
.66067 .38303 m .68834 .39235 L p .6541 .40427 L F P
0 0 0 r
s
.69 .09 .12 r
.57235 .6995 m
.57272 .69921 L
s
.57272 .69921 m
.57374 .6996 L
s
.376 .637 .835 r
.42744 .2385 m .44656 .25857 L .44809 .28204 L p F P
0 0 0 r
s
.69 .09 .12 r
.20236 .4088 m
.20846 .41121 L
s
.20846 .41121 m
.20937 .42481 L
s
.36682 .69984 m
.36536 .70163 L
s
.36423 .69916 m
.36682 .69984 L
s
.36423 .69916 m
.36536 .70163 L
s
.57374 .6996 m
.57274 .70058 L
s
.57235 .6995 m
.57374 .6996 L
s
.57274 .70058 m
.57235 .6995 L
s
.84227 .84388 m
.83947 .845 L
s
.84817 .83514 m
.84227 .84388 L
s
.85255 .84646 m
.84227 .84388 L
s
.309 .586 .765 r
.65257 .71328 m .65947 .69079 L p .63774 .72998 L F P
0 0 0 r
s
.309 .586 .765 r
.63774 .72998 m .64877 .72006 L .65257 .71328 L p F P
0 0 0 r
s
.386 .745 .969 r
.66404 .68501 m .65947 .69079 L .65257 .71328 L p F P
0 0 0 r
s
.69 .09 .12 r
.33379 .92012 m
.3214 .87904 L
s
.5622 .36806 m
.56697 .35338 L
s
.63972 .24832 m
.63383 .24567 L
s
.63383 .24567 m
.63954 .23843 L
s
.424 .812 1 r
.2534 .60441 m .2597 .6127 L .24037 .62973 L p F P
0 0 0 r
s
.424 .812 1 r
.24037 .62973 m .22566 .61063 L .2534 .60441 L p F P
0 0 0 r
s
.268 .49 .743 r
.30074 .70892 m .29156 .67109 L .30532 .66288 L p F P
0 0 0 r
s
.32 .593 .893 r
.29156 .67109 m .28876 .66352 L .30532 .66288 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.64527 .2454 m
.63972 .24832 L
s
.63954 .23843 m
.64527 .2454 L
s
.385 .69 .888 r
.63598 .79508 m .6288 .77762 L p .6252 .81326 L F P
0 0 0 r
s
.385 .69 .888 r
.6252 .81326 m .63537 .79874 L .63598 .79508 L p F P
0 0 0 r
s
.435 .787 1 r
.63598 .79508 m .6288 .77762 L .63754 .74616 L p F P
0 0 0 r
s
.35 .662 .996 r
.30532 .66288 m .28876 .66352 L .27154 .62996 L p F P
0 0 0 r
s
.347 .65 .839 r
.63754 .74616 m .63774 .72998 L .64877 .72006 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.8454 .83623 m
.84817 .83514 L
s
.84817 .83514 m
.85255 .84646 L
s
.283 .461 .62 r
.52871 .38009 m .53742 .3956 L .53424 .39853 L p F P
0 0 0 r
s
.283 .461 .62 r
.50003 .36498 m .52871 .38009 L p .53424 .39853 L F P
0 0 0 r
s
.69 .09 .12 r
.38856 .38045 m
.38178 .38163 L
s
.38321 .37618 m
.38856 .38045 L
s
.84429 .6201 m
.85071 .62124 L
s
.84671 .6282 m
.85071 .62124 L
s
.502 .987 1 r
.73701 .64007 m .76732 .62506 L .77076 .62776 L p F P
0 0 0 r
s
.477 .944 1 r
.76732 .62506 m .73701 .64007 L .72388 .63493 L p F P
0 0 0 r
s
.39 .778 1 r
.73701 .64007 m .72388 .63493 L p .69639 .65565 L F P
0 0 0 r
s
.69 .09 .12 r
.76805 .6975 m
.78467 .71927 L
s
.32704 .58696 m
.32644 .59623 L
s
.38178 .38163 m
.38321 .37618 L
s
.217 .384 .574 r
.27911 .78359 m .2783 .75243 L .30437 .74211 L p F P
0 0 0 r
s
.235 .418 .626 r
.30346 .73099 m .30437 .74211 L .2783 .75243 L p F P
0 0 0 r
s
.393 .698 .899 r
.63178 .82552 m .6252 .81326 L .63537 .79874 L closepath p F P
0 0 0 r
s
.324 .535 .71 r
.47528 .34499 m .48775 .33764 L p .50003 .36498 L F P
0 0 0 r
s
.336 .558 .737 r
.47528 .34499 m .47138 .32451 L .48775 .33764 L closepath p F P
0 0 0 r
s
.49 .966 1 r
.76732 .62506 m .77955 .61954 L .77076 .62776 L closepath p F P
0 0 0 r
s
.491 .965 1 r
.79801 .61161 m .77955 .61954 L .77076 .62776 L p F P
0 0 0 r
s
.69 .09 .12 r
.84429 .6201 m
.84671 .6282 L
s
.496 .971 1 r
.79801 .61161 m .82908 .59909 L .84143 .61198 L p F P
0 0 0 r
s
.19 .326 .475 r
.75323 .33648 m .75376 .35942 L .72164 .36835 L p F P
0 0 0 r
s
.69 .09 .12 r
.53285 .91704 m
.55511 .89173 L
s
.7478 .34327 m
.75345 .35152 L
s
.75345 .35152 m
.75358 .35172 L
s
.32026 .25303 m
.37256 .25877 L
s
.56574 .35512 m
.56836 .3568 L
s
.56367 .35586 m
.56574 .35512 L
s
.56574 .35512 m
.56697 .35338 L
s
.63954 .23843 m
.63972 .24832 L
s
.408 .711 .921 r
.6514 .91669 m .63892 .90204 L .64024 .87159 L p F P
0 0 0 r
s
.237 .425 .641 r
.30074 .70892 m .32538 .69684 L p .31987 .73558 L F P
0 0 0 r
s
.237 .425 .641 r
.31987 .73558 m .30346 .73099 L .30074 .70892 L p F P
0 0 0 r
s
.268 .49 .743 r
.31641 .66299 m .32538 .69684 L .30074 .70892 L p F P
0 0 0 r
s
.268 .49 .743 r
.30532 .66288 m .31641 .66299 L p .30074 .70892 L F P
0 0 0 r
s
.179 .302 .437 r
.68939 .3766 m .72164 .36835 L .72079 .39023 L p F P
0 0 0 r
s
.179 .302 .437 r
.68834 .39235 m .68939 .3766 L p .72079 .39023 L F P
0 0 0 r
s
.69 .09 .12 r
.56836 .3568 m
.56628 .35753 L
s
.56697 .35338 m
.56836 .3568 L
s
.32744 .59522 m
.32518 .59483 L
s
.32795 .59392 m
.32744 .59522 L
s
.32644 .59623 m
.32744 .59522 L
s
.77984 .717 m
.77842 .71635 L
s
.78424 .71346 m
.77984 .717 L
s
.78467 .71927 m
.77984 .717 L
s
.32518 .59483 m
.32568 .59353 L
s
.32518 .59483 m
.32644 .59623 L
s
.56628 .35753 m
.56367 .35586 L
s
.56367 .35586 m
.56697 .35338 L
s
.01 w
.52631 .5831 Mdot
.5 Mabswid
.78283 .7128 m
.78424 .71346 L
s
.78424 .71346 m
.78467 .71927 L
s
.32568 .59353 m
.32795 .59392 L
s
.32644 .59623 m
.32795 .59392 L
s
.7962 .49018 m
.7917 .48873 L
s
.7917 .48873 m
.79257 .48402 L
s
.7917 .48873 m
.79221 .48824 L
s
.20937 .42481 m
.19269 .41907 L
s
.20236 .4088 m
.20937 .42481 L
s
.56697 .35338 m
.56628 .35753 L
s
.32568 .59353 m
.32644 .59623 L
s
.85255 .84646 m
.83947 .845 L
s
.8454 .83623 m
.85255 .84646 L
s
.197 .324 .457 r
.61906 .40857 m .58895 .40921 L .58283 .40449 L p F P
0 0 0 r
s
.19 .309 .429 r
.58895 .40921 m .5809 .40873 L .58283 .40449 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.83947 .845 m
.8454 .83623 L
s
.73283 .91394 m
.78851 .92492 L
s
.51975 .24839 m
.54196 .21748 L
s
.79257 .48402 m
.79708 .48547 L
s
.79257 .48402 m
.79221 .48824 L
s
.19269 .41907 m
.20236 .4088 L
s
.79708 .48547 m
.7962 .49018 L
s
.79221 .48824 m
.7962 .49018 L
s
.466 .925 1 r
.77955 .61954 m .76732 .62506 L .75443 .61772 L p F P
0 0 0 r
s
.477 .944 1 r
.72388 .63493 m .75443 .61772 L .76732 .62506 L p F P
0 0 0 r
s
.403 .704 .911 r
.62899 .85604 m .64024 .87159 L .63892 .90204 L p F P
0 0 0 r
s
.411 .722 .932 r
.64024 .87159 m .62899 .85604 L .63178 .82552 L p F P
0 0 0 r
s
.69 .09 .12 r
.78467 .71927 m
.77842 .71635 L
s
.78283 .7128 m
.78467 .71927 L
s
.77842 .71635 m
.78283 .7128 L
s
.354 .655 .843 r
.63774 .72998 m .63754 .74616 L .6288 .77762 L p F P
0 0 0 r
s
.313 .581 .878 r
.31641 .66299 m .30532 .66288 L .31422 .65705 L closepath p F P
0 0 0 r
s
.35 .662 .996 r
.29939 .62633 m .31422 .65705 L .30532 .66288 L p F P
0 0 0 r
s
.35 .662 .996 r
.27154 .62996 m .29939 .62633 L p .30532 .66288 L F P
0 0 0 r
s
.69 .09 .12 r
.79221 .48824 m
.79708 .48547 L
s
.36392 .2633 m
.35929 .26357 L
s
.36477 .25169 m
.36392 .2633 L
s
.37256 .25877 m
.36392 .2633 L
s
.72651 .57922 m
.72711 .58851 L
s
.28344 .46817 m
.29803 .48904 L
s
.397 .76 1 r
.28145 .59915 m .29939 .62633 L .27154 .62996 L p F P
0 0 0 r
s
.397 .76 1 r
.27019 .6011 m .28145 .59915 L p .27154 .62996 L F P
0 0 0 r
s
.397 .76 1 r
.27154 .62996 m .2597 .6127 L .27019 .6011 L p F P
0 0 0 r
s
.23 .409 .614 r
.30437 .74211 m .30346 .73099 L .31987 .73558 L closepath p F P
0 0 0 r
s
.466 .925 1 r
.79367 .60805 m .77955 .61954 L p .75443 .61772 L F P
0 0 0 r
s
.483 .955 1 r
.77955 .61954 m .79367 .60805 L .79801 .61161 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.36014 .2519 m
.36477 .25169 L
s
.36477 .25169 m
.37256 .25877 L
s
.49016 .79965 m
.49467 .78661 L
s
.436 .839 1 r
.2534 .60441 m .22566 .61063 L .20673 .58886 L p F P
0 0 0 r
s
.69 .09 .12 r
.72017 .24372 m
.71341 .19233 L
s
.54964 .89257 m
.55532 .89841 L
s
.54593 .89524 m
.54964 .89257 L
s
.54964 .89257 m
.55511 .89173 L
s
.178 .303 .44 r
.72079 .39023 m .72164 .36835 L .75376 .35942 L p F P
0 0 0 r
s
.69 .09 .12 r
.75358 .35172 m
.75393 .35223 L
s
.75393 .35223 m
.76179 .3637 L
s
.163 .265 .373 r
.61363 .42148 m .58895 .40921 L .61906 .40857 L closepath p F P
0 0 0 r
s
.127 .197 .27 r
.58895 .40921 m .61363 .42148 L p .57021 .42081 L F P
0 0 0 r
s
.127 .197 .27 r
.57021 .42081 m .5809 .40873 L .58895 .40921 L p F P
0 0 0 r
s
.69 .09 .12 r
.72767 .5875 m
.72548 .58711 L
s
.72849 .58619 m
.72767 .5875 L
s
.72711 .58851 m
.72767 .5875 L
s
.55532 .89841 m
.55162 .90109 L
s
.55511 .89173 m
.55532 .89841 L
s
.29427 .48727 m
.29172 .48608 L
s
.29848 .48362 m
.29427 .48727 L
s
.29803 .48904 m
.29427 .48727 L
s
.72548 .58711 m
.72631 .58579 L
s
.72548 .58711 m
.72711 .58851 L
s
.177 .282 .383 r
.54142 .40102 m .5809 .40873 L .57021 .42081 L p F P
0 0 0 r
s
.234 .379 .521 r
.5809 .40873 m .54142 .40102 L .53742 .3956 L p F P
0 0 0 r
s
.137 .219 .311 r
.61906 .40857 m .6541 .40427 L .64886 .42187 L p F P
0 0 0 r
s
.137 .219 .311 r
.61363 .42148 m .61906 .40857 L p .64886 .42187 L F P
0 0 0 r
s
.69 .09 .12 r
.77801 .9265 m
.77534 .92993 L
s
.77927 .91551 m
.77801 .9265 L
s
.78851 .92492 m
.77801 .9265 L
s
.48354 .46401 m
.48857 .46227 L
s
.216 .384 .575 r
.3058 .77378 m .30437 .74211 L .31987 .73558 L p F P
0 0 0 r
s
.217 .384 .574 r
.30437 .74211 m .3058 .77378 L .27911 .78359 L p F P
0 0 0 r
s
.39 .691 .891 r
.6252 .81326 m .63178 .82552 L .62899 .85604 L p F P
0 0 0 r
s
.345 .576 .759 r
.47138 .32451 m .47528 .34499 L .47322 .34561 L p F P
0 0 0 r
s
.345 .576 .759 r
.45039 .30566 m .47138 .32451 L p .47322 .34561 L F P
0 0 0 r
s
.364 .611 .804 r
.47138 .32451 m .45039 .30566 L .44809 .28204 L p F P
0 0 0 r
s
.69 .09 .12 r
.29594 .48243 m
.29848 .48362 L
s
.29848 .48362 m
.29803 .48904 L
s
.211 .371 .553 r
.27894 .8144 m .27911 .78359 L .3058 .77378 L p F P
0 0 0 r
s
.69 .09 .12 r
.28781 .80099 m
.29028 .80302 L
s
.72631 .58579 m
.72849 .58619 L
s
.72711 .58851 m
.72849 .58619 L
s
.48797 .46308 m
.48756 .46326 L
s
.48757 .46198 m
.48797 .46308 L
s
.48857 .46227 m
.48797 .46308 L
s
.366 .618 .811 r
.42848 .26214 m .44809 .28204 L .45039 .30566 L p F P
0 0 0 r
s
.376 .637 .835 r
.44809 .28204 m .42848 .26214 L .42744 .2385 L p F P
0 0 0 r
s
.69 .09 .12 r
.48716 .46216 m
.48757 .46198 L
s
.48757 .46198 m
.48857 .46227 L
s
.72631 .58579 m
.72711 .58851 L
s
.32493 .88161 m
.3319 .88666 L
s
.31593 .88804 m
.32493 .88161 L
s
.32493 .88161 m
.3214 .87904 L
s
.283 .461 .62 r
.53424 .39853 m .50934 .38706 L .50003 .36498 L p F P
0 0 0 r
s
.301 .494 .657 r
.47594 .34777 m .50003 .36498 L .50934 .38706 L p F P
0 0 0 r
s
.324 .535 .71 r
.50003 .36498 m .47594 .34777 L .47528 .34499 L p F P
0 0 0 r
s
.277 .508 .77 r
.32538 .69684 m .31641 .66299 L .34432 .66588 L p F P
0 0 0 r
s
.299 .557 .848 r
.33506 .64067 m .34432 .66588 L .31641 .66299 L p F P
0 0 0 r
s
.299 .557 .848 r
.31641 .66299 m .31422 .65705 L .33506 .64067 L p F P
0 0 0 r
s
.223 .358 .483 r
.54142 .40102 m .53424 .39853 L .53742 .3956 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.7766 .91889 m
.77927 .91551 L
s
.77927 .91551 m
.78851 .92492 L
s
.48857 .46227 m
.48756 .46326 L
s
.48716 .46216 m
.48857 .46227 L
s
.48756 .46326 m
.48716 .46216 L
s
.346 .651 .98 r
.32751 .62491 m .33506 .64067 L .31422 .65705 L p F P
0 0 0 r
s
.346 .651 .98 r
.31422 .65705 m .29939 .62633 L .32751 .62491 L p F P
0 0 0 r
s
.475 .94 1 r
.79367 .60805 m .79801 .61161 L .82908 .59909 L p F P
0 0 0 r
s
.69 .09 .12 r
.69098 .79626 m
.71739 .8058 L
s
.24636 .68481 m
.23041 .69238 L
s
.53652 .22073 m
.5422 .22608 L
s
.53276 .22132 m
.53652 .22073 L
s
.53652 .22073 m
.54196 .21748 L
s
.49356 .78763 m
.49615 .78959 L
s
.49139 .78886 m
.49356 .78763 L
s
.49356 .78763 m
.49467 .78661 L
s
.378 .641 .839 r
.40849 .21779 m .42744 .2385 L .42848 .26214 L p F P
0 0 0 r
s
.69 .09 .12 r
.75033 .34371 m
.75516 .3458 L
s
.74608 .34898 m
.75033 .34371 L
s
.7478 .34327 m
.75033 .34371 L
s
.49615 .78959 m
.49397 .79082 L
s
.49467 .78661 m
.49615 .78959 L
s
.5422 .22608 m
.53846 .22669 L
s
.54196 .21748 m
.5422 .22608 L
s
.55162 .90109 m
.54593 .89524 L
s
.54593 .89524 m
.55511 .89173 L
s
.74608 .34898 m
.75091 .35109 L
s
.74608 .34898 m
.7478 .34327 L
s
.323 .634 .846 r
.69372 .65601 m .70172 .64985 L .69639 .65565 L closepath p F P
0 0 0 r
s
.39 .778 1 r
.72388 .63493 m .70172 .64985 L .69639 .65565 L p F P
0 0 0 r
s
.365 .714 .939 r
.66404 .68501 m .69372 .65601 L .69639 .65565 L p F P
0 0 0 r
s
.69 .09 .12 r
.29803 .48904 m
.29172 .48608 L
s
.29594 .48243 m
.29803 .48904 L
s
.37256 .25877 m
.35929 .26357 L
s
.36014 .2519 m
.37256 .25877 L
s
.29172 .48608 m
.29594 .48243 L
s
.136 .223 .323 r
.64886 .42187 m .6541 .40427 L .68776 .39787 L p F P
0 0 0 r
s
.178 .299 .43 r
.68834 .39235 m .68776 .39787 L .6541 .40427 L p F P
0 0 0 r
s
.69 .09 .12 r
.49397 .79082 m
.49139 .78886 L
s
.49139 .78886 m
.49467 .78661 L
s
.35929 .26357 m
.36014 .2519 L
s
.68458 .45983 m
.67963 .45337 L
s
.23944 .34826 m
.279 .37687 L
s
.71196 .80595 m
.71061 .80711 L
s
.71357 .80067 m
.71196 .80595 L
s
.71739 .8058 m
.71196 .80595 L
s
.224 .403 .614 r
.33011 .73105 m .32538 .69684 L .34894 .68322 L p F P
0 0 0 r
s
.277 .508 .77 r
.34432 .66588 m .34894 .68322 L .32538 .69684 L p F P
0 0 0 r
s
.237 .425 .641 r
.32538 .69684 m .33011 .73105 L .31987 .73558 L p F P
0 0 0 r
s
.69 .09 .12 r
.55511 .89173 m
.55162 .90109 L
s
.179 .302 .437 r
.72079 .39023 m .70102 .39494 L .68834 .39235 L p F P
0 0 0 r
s
.174 .293 .423 r
.70102 .39494 m .68776 .39787 L .68834 .39235 L closepath p F P
0 0 0 r
s
.417 .801 1 r
.2597 .6127 m .2534 .60441 L .27019 .6011 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.71223 .80181 m
.71357 .80067 L
s
.71357 .80067 m
.71739 .8058 L
s
.49467 .78661 m
.49397 .79082 L
s
.32289 .89313 m
.31593 .88804 L
s
.31593 .88804 m
.3214 .87904 L
s
.89274 .79286 m
.94333 .84533 L
s
.44708 .68115 m
.44418 .67832 L
s
.75091 .35109 m
.75516 .3458 L
s
.7478 .34327 m
.75516 .3458 L
s
.178 .303 .44 r
.75376 .35942 m .75357 .38176 L .72079 .39023 L p F P
0 0 0 r
s
.69 .09 .12 r
.27532 .78622 m
.27915 .78926 L
s
.27085 .7917 m
.27532 .78622 L
s
.27532 .78622 m
.27113 .78731 L
s
.177 .282 .383 r
.57021 .42081 m .56303 .41942 L .54142 .40102 L p F P
0 0 0 r
s
.163 .257 .339 r
.53424 .39853 m .54142 .40102 L .56303 .41942 L p F P
0 0 0 r
s
.69 .09 .12 r
.3319 .88666 m
.32289 .89313 L
s
.3214 .87904 m
.3319 .88666 L
s
.7478 .34327 m
.75091 .35109 L
s
.53846 .22669 m
.53276 .22132 L
s
.53276 .22132 m
.54196 .21748 L
s
.27467 .79476 m
.27085 .7917 L
s
.27085 .7917 m
.27113 .78731 L
s
.78851 .92492 m
.77534 .92993 L
s
.7766 .91889 m
.78851 .92492 L
s
.385 .69 .888 r
.6288 .77762 m .62319 .80864 L .6252 .81326 L p F P
0 0 0 r
s
.348 .635 .818 r
.62668 .75826 m .6288 .77762 L .62319 .80864 L p F P
0 0 0 r
s
.354 .655 .843 r
.635 .73443 m .63774 .72998 L p .6288 .77762 L F P
0 0 0 r
s
.354 .655 .843 r
.6288 .77762 m .62668 .75826 L .635 .73443 L p F P
0 0 0 r
s
.216 .384 .575 r
.31987 .73558 m .33086 .73978 L p .3058 .77378 L F P
0 0 0 r
s
.225 .401 .604 r
.33086 .73978 m .31987 .73558 L .33011 .73105 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.71739 .8058 m
.71061 .80711 L
s
.71223 .80181 m
.71739 .8058 L
s
.77534 .92993 m
.7766 .91889 L
s
.44038 .3438 m
.46047 .33632 L
s
.44478 .6782 m
.44547 .67867 L
s
.44404 .6791 m
.44478 .6782 L
s
.44478 .6782 m
.44418 .67832 L
s
.54196 .21748 m
.53846 .22669 L
s
.71061 .80711 m
.71223 .80181 L
s
.68056 .45338 m
.68212 .45416 L
s
.67913 .45516 m
.68056 .45338 L
s
.68056 .45338 m
.67963 .45337 L
s
.44474 .67957 m
.44404 .6791 L
s
.44404 .6791 m
.44418 .67832 L
s
.68069 .45594 m
.67913 .45516 L
s
.67913 .45516 m
.67963 .45337 L
s
.44547 .67867 m
.44474 .67957 L
s
.44418 .67832 m
.44547 .67867 L
s
.44418 .67832 m
.44474 .67957 L
s
.383 .728 1 r
.32751 .62491 m .29939 .62633 L .28145 .59915 L p F P
0 0 0 r
s
.239 .468 .617 r
.69372 .65601 m .68237 .66582 L .66194 .68683 L p F P
0 0 0 r
s
.239 .468 .617 r
.66194 .68683 m .66404 .68501 L .69372 .65601 L p F P
0 0 0 r
s
.027 .051 .071 r
.68237 .66582 m .69372 .65601 L .70172 .64985 L p F P
0 0 0 r
s
.163 .257 .339 r
.52127 .40351 m .53424 .39853 L p .56303 .41942 L F P
0 0 0 r
s
.204 .328 .433 r
.52127 .40351 m .50934 .38706 L .53424 .39853 L closepath p F P
0 0 0 r
s
.403 .704 .911 r
.63892 .90204 m .6271 .88682 L .62899 .85604 L p F P
0 0 0 r
s
.69 .09 .12 r
.68212 .45416 m
.68069 .45594 L
s
.67963 .45337 m
.68212 .45416 L
s
.451 .897 1 r
.78538 .60264 m .79367 .60805 L .81916 .59055 L p F P
0 0 0 r
s
.475 .94 1 r
.82908 .59909 m .81916 .59055 L .79367 .60805 L p F P
0 0 0 r
s
.466 .925 1 r
.75443 .61772 m .78538 .60264 L .79367 .60805 L p F P
0 0 0 r
s
.423 .817 1 r
.27019 .6011 m .2534 .60441 L .23467 .5818 L p F P
0 0 0 r
s
.436 .839 1 r
.20673 .58886 m .23467 .5818 L .2534 .60441 L p F P
0 0 0 r
s
.027 .051 .071 r
.70172 .64985 m .71816 .63558 L p .68237 .66582 L F P
0 0 0 r
s
.304 .595 .802 r
.70172 .64985 m .71816 .63558 L .72388 .63493 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.67963 .45337 m
.68069 .45594 L
s
.148 .245 .356 r
.684 .41684 m .68776 .39787 L .70102 .39494 L p F P
0 0 0 r
s
.136 .223 .323 r
.68776 .39787 m .684 .41684 L .64886 .42187 L p F P
0 0 0 r
s
.69 .09 .12 r
.27103 .37627 m
.26564 .37532 L
s
.27643 .36693 m
.27103 .37627 L
s
.279 .37687 m
.27103 .37627 L
s
.274 .525 .691 r
.65947 .69079 m .66194 .68683 L .66404 .68501 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.64874 .67747 m
.65668 .68359 L
s
.65462 .68313 m
.65435 .68321 L
s
.65584 .68152 m
.65462 .68313 L
s
.65668 .68359 m
.65462 .68313 L
s
.27467 .79476 m
.27915 .78926 L
s
.65556 .6816 m
.65584 .68152 L
s
.65584 .68152 m
.65668 .68359 L
s
.309 .586 .765 r
.65947 .69079 m .63881 .72558 L .63774 .72998 L p F P
0 0 0 r
s
.027 .051 .071 r
.66194 .68683 m .65947 .69079 L .63881 .72558 L p F P
0 0 0 r
s
.69 .09 .12 r
.3214 .87904 m
.32289 .89313 L
s
.27113 .78731 m
.27467 .79476 L
s
.65668 .68359 m
.65435 .68321 L
s
.65556 .6816 m
.65668 .68359 L
s
.27105 .36594 m
.27643 .36693 L
s
.27643 .36693 m
.279 .37687 L
s
.45638 .34029 m
.45809 .3398 L
s
.4565 .33536 m
.45809 .3398 L
s
.45809 .3398 m
.46047 .33632 L
s
.65435 .68321 m
.65556 .6816 L
s
.9288 .83969 m
.92701 .83986 L
s
.93924 .82969 m
.9288 .83969 L
s
.94333 .84533 m
.9288 .83969 L
s
.45479 .33584 m
.4565 .33536 L
s
.4565 .33536 m
.46047 .33632 L
s
.208 .367 .549 r
.30611 .80495 m .3058 .77378 L .33228 .76335 L p F P
0 0 0 r
s
.216 .384 .575 r
.33086 .73978 m .33228 .76335 L .3058 .77378 L p F P
0 0 0 r
s
.211 .371 .553 r
.3058 .77378 m .30611 .80495 L .27894 .8144 L p F P
0 0 0 r
s
.69 .09 .12 r
.27113 .78731 m
.27915 .78926 L
s
.27113 .78731 m
.27887 .79365 L
s
.27887 .79365 m
.27906 .79381 L
s
.41036 .89982 m
.4078 .87058 L
s
.64226 .33932 m
.64212 .31297 L
s
.282 .553 .754 r
.71816 .63558 m .72388 .63493 L .75443 .61772 L p F P
0 0 0 r
s
.17 .287 .415 r
.72016 .39739 m .70102 .39494 L .72079 .39023 L closepath p F P
0 0 0 r
s
.148 .245 .356 r
.70102 .39494 m .72016 .39739 L p .684 .41684 L F P
0 0 0 r
s
.69 .09 .12 r
.23542 .69398 m
.23143 .69231 L
s
.23143 .69231 m
.23183 .68772 L
s
.23143 .69231 m
.23041 .69238 L
s
.217 .388 .587 r
.33011 .73105 m .35512 .71882 L p .35518 .75342 L F P
0 0 0 r
s
.217 .388 .587 r
.35518 .75342 m .33086 .73978 L .33011 .73105 L p F P
0 0 0 r
s
.224 .403 .614 r
.34894 .68322 m .35512 .71882 L .33011 .73105 L p F P
0 0 0 r
s
.69 .09 .12 r
.71466 .19894 m
.72303 .20169 L
s
.70654 .20377 m
.71466 .19894 L
s
.71466 .19894 m
.71341 .19233 L
s
.93751 .8298 m
.93924 .82969 L
s
.93924 .82969 m
.94333 .84533 L
s
.208 .365 .542 r
.27818 .84522 m .27894 .8144 L .30611 .80495 L p F P
0 0 0 r
s
.446 .86 1 r
.23467 .5818 m .20673 .58886 L .18729 .56816 L p F P
0 0 0 r
s
.69 .09 .12 r
.19907 .59364 m
.20029 .58201 L
s
.20132 .5722 m
.20203 .5655 L
s
.271 .507 .656 r
.635 .73443 m .63881 .72558 L .63774 .72998 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.85135 .67377 m
.87179 .70836 L
s
.40359 .56154 m
.4034 .5662 L
s
.23183 .68772 m
.23582 .68939 L
s
.23183 .68772 m
.23041 .69238 L
s
.388 .684 .883 r
.61937 .83963 m .62899 .85604 L .6271 .88682 L p F P
0 0 0 r
s
.39 .691 .891 r
.62149 .82102 m .6252 .81326 L p .62899 .85604 L F P
0 0 0 r
s
.39 .691 .891 r
.62899 .85604 m .61937 .83963 L .62149 .82102 L p F P
0 0 0 r
s
.69 .09 .12 r
.23582 .68939 m
.23542 .69398 L
s
.23041 .69238 m
.23542 .69398 L
s
.45638 .34029 m
.46047 .33632 L
s
.45479 .33584 m
.46047 .33632 L
s
.45479 .33584 m
.45638 .34029 L
s
.361 .645 .831 r
.62149 .82102 m .62319 .80864 L .6252 .81326 L closepath p F P
0 0 0 r
s
.317 .525 .694 r
.47594 .34777 m .47322 .34561 L .47528 .34499 L closepath p F P
0 0 0 r
s
.027 .051 .071 r
.68237 .66582 m .66194 .68683 L .6525 .70365 L p F P
0 0 0 r
s
.027 .051 .071 r
.63881 .72558 m .6525 .70365 L .66194 .68683 L p F P
0 0 0 r
s
.215 .383 .575 r
.33228 .76335 m .33086 .73978 L .35518 .75342 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.40387 .5657 m
.40273 .5655 L
s
.40415 .56503 m
.40387 .5657 L
s
.4034 .5662 m
.40387 .5657 L
s
.23041 .69238 m
.23582 .68939 L
s
.40273 .5655 m
.40301 .56483 L
s
.40273 .5655 m
.4034 .5662 L
s
.63107 .89193 m
.64401 .88862 L
s
.61264 .89664 m
.63107 .89193 L
s
.40301 .56483 m
.40415 .56503 L
s
.4034 .5662 m
.40415 .56503 L
s
.40301 .56483 m
.4034 .5662 L
s
.411 .791 1 r
.28145 .59915 m .27019 .6011 L .27655 .59261 L closepath p F P
0 0 0 r
s
.423 .817 1 r
.2629 .57549 m .27655 .59261 L .27019 .6011 L p F P
0 0 0 r
s
.423 .817 1 r
.23467 .5818 m .2629 .57549 L p .27019 .6011 L F P
0 0 0 r
s
.166 .28 .406 r
.72016 .39739 m .72079 .39023 L .75357 .38176 L p F P
0 0 0 r
s
.345 .576 .759 r
.47322 .34561 m .45394 .32928 L .45039 .30566 L p F P
0 0 0 r
s
.35 .587 .771 r
.43019 .28598 m .45039 .30566 L .45394 .32928 L p F P
0 0 0 r
s
.366 .618 .811 r
.45039 .30566 m .43019 .28598 L .42848 .26214 L p F P
0 0 0 r
s
.301 .494 .657 r
.50934 .38706 m .48315 .37055 L .47594 .34777 L p F P
0 0 0 r
s
.29 .477 .63 r
.47322 .34561 m .47594 .34777 L .48315 .37055 L p F P
0 0 0 r
s
.69 .09 .12 r
.279 .37687 m
.26564 .37532 L
s
.27105 .36594 m
.279 .37687 L
s
.7149 .20654 m
.70654 .20377 L
s
.70654 .20377 m
.71341 .19233 L
s
.26564 .37532 m
.27105 .36594 L
s
.257 .473 .726 r
.34894 .68322 m .34432 .66588 L .36495 .67165 L closepath p F P
0 0 0 r
s
.272 .508 .786 r
.36495 .67165 m .34432 .66588 L .33506 .64067 L p F P
0 0 0 r
s
.69 .09 .12 r
.64202 .31666 m
.64623 .31817 L
s
.63807 .31836 m
.64202 .31666 L
s
.64202 .31666 m
.64212 .31297 L
s
.267 .527 .722 r
.7435 .61876 m .75443 .61772 L .78538 .60264 L p F P
0 0 0 r
s
.282 .553 .754 r
.75443 .61772 m .7435 .61876 L .71816 .63558 L p F P
0 0 0 r
s
.69 .09 .12 r
.01 w
.6061 .55756 Mdot
.5 Mabswid
.15728 .44506 m
.17707 .49045 L
s
.369 .624 .817 r
.40912 .24159 m .42848 .26214 L .43019 .28598 L p F P
0 0 0 r
s
.378 .641 .839 r
.42848 .26214 m .40912 .24159 L .40849 .21779 L p F P
0 0 0 r
s
.69 .09 .12 r
.3968 .22246 m
.40849 .21779 L
s
.40849 .21779 m
.44207 .20438 L
s
.86434 .70424 m
.86381 .70265 L
s
.87155 .70018 m
.86434 .70424 L
s
.87179 .70836 m
.86434 .70424 L
s
.245 .458 .583 r
.62668 .75826 m .629 .74865 L .635 .73443 L closepath p F P
0 0 0 r
s
.027 .051 .071 r
.63881 .72558 m .6525 .70365 L p .629 .74865 L F P
0 0 0 r
s
.027 .051 .071 r
.629 .74865 m .635 .73443 L .63881 .72558 L p F P
0 0 0 r
s
.69 .09 .12 r
.87104 .69858 m
.87155 .70018 L
s
.87155 .70018 m
.87179 .70836 L
s
.72303 .20169 m
.7149 .20654 L
s
.71341 .19233 m
.72303 .20169 L
s
.29 .477 .63 r
.45786 .34642 m .47322 .34561 L p .48315 .37055 L F P
0 0 0 r
s
.311 .516 .68 r
.45786 .34642 m .45394 .32928 L .47322 .34561 L closepath p F P
0 0 0 r
s
.216 .393 .606 r
.35512 .71882 m .34894 .68322 L .36495 .67165 L p F P
0 0 0 r
s
.137 .219 .311 r
.64886 .42187 m .62193 .42389 L .61363 .42148 L p F P
0 0 0 r
s
.114 .175 .245 r
.62193 .42389 m .61174 .42411 L .61363 .42148 L closepath p F P
0 0 0 r
s
.127 .197 .27 r
.61363 .42148 m .61174 .42411 L .57021 .42081 L p F P
0 0 0 r
s
.272 .508 .786 r
.33506 .64067 m .3483 .62623 L p .36495 .67165 L F P
0 0 0 r
s
.324 .612 .932 r
.33506 .64067 m .32751 .62491 L .3483 .62623 L closepath p F P
0 0 0 r
s
.224 .362 .478 r
.50934 .38706 m .52127 .40351 L .51686 .40346 L p F P
0 0 0 r
s
.224 .362 .478 r
.48315 .37055 m .50934 .38706 L p .51686 .40346 L F P
0 0 0 r
s
.69 .09 .12 r
.20256 .59056 m
.19555 .58937 L
s
.20256 .59056 m
.20379 .58656 L
s
.19907 .59364 m
.20256 .59056 L
s
.81589 .89345 m
.88116 .92749 L
s
.59953 .21767 m
.61458 .16637 L
s
.64228 .31988 m
.63807 .31836 L
s
.63807 .31836 m
.64212 .31297 L
s
.331 .595 .767 r
.62319 .80864 m .61879 .79014 L p .61672 .83373 L F P
0 0 0 r
s
.331 .595 .767 r
.61672 .83373 m .62149 .82102 L .62319 .80864 L p F P
0 0 0 r
s
.348 .635 .818 r
.62319 .80864 m .61879 .79014 L .62668 .75826 L p F P
0 0 0 r
s
.69 .09 .12 r
.64623 .31817 m
.64228 .31988 L
s
.64212 .31297 m
.64623 .31817 L
s
.94333 .84533 m
.92701 .83986 L
s
.93751 .8298 m
.94333 .84533 L
s
.19555 .58937 m
.19677 .58537 L
s
.19555 .58937 m
.19907 .59364 L
s
.63785 .89468 m
.63992 .89235 L
s
.63756 .8858 m
.63992 .89235 L
s
.64401 .88862 m
.63992 .89235 L
s
.383 .728 1 r
.28145 .59915 m .30977 .59551 L .32751 .62491 L p F P
0 0 0 r
s
.401 .772 1 r
.29142 .57045 m .30977 .59551 L .28145 .59915 L p F P
0 0 0 r
s
.401 .772 1 r
.28799 .57096 m .29142 .57045 L p .28145 .59915 L F P
0 0 0 r
s
.401 .772 1 r
.28145 .59915 m .27655 .59261 L .28799 .57096 L p F P
0 0 0 r
s
.69 .09 .12 r
.6355 .88811 m
.63756 .8858 L
s
.63756 .8858 m
.64401 .88862 L
s
.80956 .55356 m
.81086 .56761 L
s
.35969 .4408 m
.37223 .44953 L
s
.92701 .83986 m
.93751 .8298 L
s
.64212 .31297 m
.64228 .31988 L
s
.339 .649 .99 r
.3483 .62623 m .32751 .62491 L .30977 .59551 L p F P
0 0 0 r
s
.69 .09 .12 r
.71341 .19233 m
.7149 .20654 L
s
.40862 .87235 m
.41416 .87638 L
s
.40248 .87657 m
.40862 .87235 L
s
.40862 .87235 m
.4078 .87058 L
s
.86584 .92549 m
.86388 .92855 L
s
.87217 .91278 m
.86584 .92549 L
s
.88116 .92749 m
.86584 .92549 L
s
.166 .28 .406 r
.75357 .38176 m .7524 .39855 L .72016 .39739 L p F P
0 0 0 r
s
.151 .252 .366 r
.71817 .41018 m .72016 .39739 L .7524 .39855 L p F P
0 0 0 r
s
.148 .245 .356 r
.72016 .39739 m .71817 .41018 L .684 .41684 L p F P
0 0 0 r
s
.69 .09 .12 r
.87179 .70836 m
.86381 .70265 L
s
.87104 .69858 m
.87179 .70836 L
s
.19677 .58537 m
.20379 .58656 L
s
.19907 .59364 m
.20379 .58656 L
s
.204 .361 .542 r
.33317 .79498 m .33228 .76335 L .35518 .75342 L p F P
0 0 0 r
s
.69 .09 .12 r
.35418 .77006 m
.36654 .78082 L
s
.208 .367 .549 r
.33228 .76335 m .33317 .79498 L .30611 .80495 L p F P
0 0 0 r
s
.69 .09 .12 r
.56968 .77734 m
.58006 .77443 L
s
.43675 .2128 m
.43277 .21337 L
s
.43313 .20269 m
.43675 .2128 L
s
.44207 .20438 m
.43675 .2128 L
s
.86381 .70265 m
.87104 .69858 L
s
.052 .083 .115 r
.61174 .42411 m .62193 .42389 L p .63696 .43156 L F P
0 0 0 r
s
.052 .083 .115 r
.59887 .43001 m .61174 .42411 L p .63696 .43156 L F P
0 0 0 r
s
.086 .127 .175 r
.61174 .42411 m .59887 .43001 L .56781 .42185 L p F P
0 0 0 r
s
.086 .127 .175 r
.56781 .42185 m .57021 .42081 L .61174 .42411 L p F P
0 0 0 r
s
.451 .897 1 r
.81916 .59055 m .8167 .58885 L .78538 .60264 L p F P
0 0 0 r
s
.338 .674 .916 r
.8167 .58885 m .78538 .60264 L .77307 .60198 L p F P
0 0 0 r
s
.267 .527 .722 r
.78538 .60264 m .77307 .60198 L p .7435 .61876 L F P
0 0 0 r
s
.098 .146 .207 r
.64492 .4277 m .62193 .42389 L .64886 .42187 L closepath p F P
0 0 0 r
s
.052 .083 .115 r
.62193 .42389 m .64492 .4277 L .63696 .43156 L p F P
0 0 0 r
s
.027 .051 .071 r
.71107 .64171 m .71816 .63558 L .7435 .61876 L p F P
0 0 0 r
s
.027 .051 .071 r
.71816 .63558 m .71107 .64171 L p .68237 .66582 L F P
0 0 0 r
s
.69 .09 .12 r
.42914 .20321 m
.43313 .20269 L
s
.43313 .20269 m
.44207 .20438 L
s
.205 .361 .538 r
.30577 .83607 m .30611 .80495 L .33317 .79498 L p F P
0 0 0 r
s
.208 .365 .542 r
.30611 .80495 m .30577 .83607 L .27818 .84522 L p F P
0 0 0 r
s
.437 .845 1 r
.2629 .57549 m .23467 .5818 L .21542 .56047 L p F P
0 0 0 r
s
.446 .86 1 r
.18729 .56816 m .21542 .56047 L .23467 .5818 L p F P
0 0 0 r
s
.69 .09 .12 r
.36994 .44938 m
.36797 .44926 L
s
.37146 .4463 m
.36994 .44938 L
s
.37223 .44953 m
.36994 .44938 L
s
.19677 .58537 m
.19907 .59364 L
s
.416 .802 1 r
.27655 .59261 m .2629 .57549 L .28799 .57096 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.87024 .91576 m
.87217 .91278 L
s
.87217 .91278 m
.88116 .92749 L
s
.3695 .44618 m
.37146 .4463 L
s
.37146 .4463 m
.37223 .44953 L
s
.347 .62 .799 r
.61937 .83963 m .61672 .83373 L .62149 .82102 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.57875 .77578 m
.578 .77645 L
s
.57796 .77358 m
.57875 .77578 L
s
.58006 .77443 m
.57875 .77578 L
s
.57721 .77425 m
.57796 .77358 L
s
.57796 .77358 m
.58006 .77443 L
s
.56305 .43651 m
.56546 .4269 L
s
.63785 .89468 m
.64401 .88862 L
s
.6355 .88811 m
.64401 .88862 L
s
.6355 .88811 m
.63785 .89468 L
s
.198 .356 .544 r
.35825 .75199 m .35512 .71882 L .37862 .70463 L p F P
0 0 0 r
s
.217 .388 .587 r
.35512 .71882 m .35825 .75199 L .35518 .75342 L p F P
0 0 0 r
s
.216 .393 .606 r
.37248 .67492 m .37862 .70463 L .35512 .71882 L p F P
0 0 0 r
s
.216 .393 .606 r
.36495 .67165 m .37248 .67492 L p .35512 .71882 L F P
0 0 0 r
s
.085 .127 .178 r
.64492 .4277 m .64886 .42187 L .684 .41684 L p F P
0 0 0 r
s
.69 .09 .12 r
.40802 .88062 m
.40248 .87657 L
s
.40248 .87657 m
.4078 .87058 L
s
.56472 .42844 m
.56636 .42909 L
s
.56359 .42856 m
.56472 .42844 L
s
.56472 .42844 m
.56546 .4269 L
s
.41416 .87638 m
.40802 .88062 L
s
.4078 .87058 m
.41416 .87638 L
s
.81157 .5661 m
.80827 .5655 L
s
.81293 .56407 m
.81157 .5661 L
s
.81086 .56761 m
.81157 .5661 L
s
.36797 .44926 m
.3695 .44618 L
s
.37223 .44953 m
.36797 .44926 L
s
.207 .361 .536 r
.27704 .87627 m .27818 .84522 L .30577 .83607 L p F P
0 0 0 r
s
.69 .09 .12 r
.58006 .77443 m
.578 .77645 L
s
.57721 .77425 m
.58006 .77443 L
s
.3695 .44618 m
.37223 .44953 L
s
.578 .77645 m
.57721 .77425 L
s
.80827 .5655 m
.80963 .56347 L
s
.80827 .5655 m
.81086 .56761 L
s
.106 .156 .214 r
.56781 .42185 m .56303 .41942 L .57021 .42081 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.56636 .42909 m
.56524 .42922 L
s
.56546 .4269 m
.56636 .42909 L
s
.56524 .42922 m
.56359 .42856 L
s
.56359 .42856 m
.56546 .4269 L
s
.77379 .77385 m
.8063 .79892 L
s
.3223 .66069 m
.31034 .66617 L
s
.56546 .4269 m
.56524 .42922 L
s
.388 .684 .883 r
.6271 .88682 m .61666 .87083 L .61937 .83963 L p F P
0 0 0 r
s
.69 .09 .12 r
.1717 .4863 m
.16522 .48272 L
s
.1809 .47987 m
.1717 .4863 L
s
.17707 .49045 m
.1717 .4863 L
s
.7976 .79676 m
.797 .79749 L
s
.80257 .79031 m
.7976 .79676 L
s
.8063 .79892 m
.7976 .79676 L
s
.35682 .76936 m
.35952 .77139 L
s
.35382 .77306 m
.35682 .76936 L
s
.35418 .77006 m
.35682 .76936 L
s
.094 .138 .191 r
.56303 .41942 m .56781 .42185 L .55189 .42093 L p F P
0 0 0 r
s
.094 .138 .191 r
.55189 .42093 m .5253 .40732 L .56303 .41942 L p F P
0 0 0 r
s
.163 .257 .339 r
.56303 .41942 m .5253 .40732 L .52127 .40351 L p F P
0 0 0 r
s
.69 .09 .12 r
.80963 .56347 m
.81293 .56407 L
s
.81086 .56761 m
.81293 .56407 L
s
.35382 .77306 m
.35652 .7751 L
s
.35382 .77306 m
.35418 .77006 L
s
.80199 .79101 m
.80257 .79031 L
s
.80257 .79031 m
.8063 .79892 L
s
.80963 .56347 m
.81086 .56761 L
s
.61033 .1741 m
.61902 .17837 L
s
.60405 .17506 m
.61033 .1741 L
s
.61033 .1741 m
.61458 .16637 L
s
.207 .386 .478 r
.629 .74865 m .62668 .75826 L .61879 .79014 L p F P
0 0 0 r
s
.451 .873 1 r
.21542 .56047 m .18729 .56816 L .16738 .54789 L p F P
0 0 0 r
s
.69 .09 .12 r
.76738 .4322 m
.76029 .42218 L
s
.31537 .3189 m
.35068 .32753 L
s
.4078 .87058 m
.40802 .88062 L
s
.17445 .47626 m
.1809 .47987 L
s
.1809 .47987 m
.17707 .49045 L
s
.35952 .77139 m
.35652 .7751 L
s
.35418 .77006 m
.35952 .77139 L
s
.44207 .20438 m
.43277 .21337 L
s
.42914 .20321 m
.44207 .20438 L
s
.063 .097 .134 r
.684 .41684 m .71817 .41018 L .71104 .42459 L p F P
0 0 0 r
s
.063 .097 .134 r
.67666 .42837 m .684 .41684 L p .71104 .42459 L F P
0 0 0 r
s
.085 .127 .178 r
.684 .41684 m .67666 .42837 L .64492 .4277 L p F P
0 0 0 r
s
.69 .09 .12 r
.43277 .21337 m
.42914 .20321 L
s
.35418 .77006 m
.35652 .7751 L
s
.24 .443 .687 r
.37248 .67492 m .36495 .67165 L .37035 .66695 L closepath p F P
0 0 0 r
s
.272 .508 .786 r
.35589 .62747 m .37035 .66695 L .36495 .67165 L p F P
0 0 0 r
s
.272 .508 .786 r
.3483 .62623 m .35589 .62747 L p .36495 .67165 L F P
0 0 0 r
s
.69 .09 .12 r
.88116 .92749 m
.86388 .92855 L
s
.87024 .91576 m
.88116 .92749 L
s
.01 w
.52631 .65691 Mdot
.5 Mabswid
.338 .674 .916 r
.77307 .60198 m .80466 .58582 L .8167 .58885 L p F P
0 0 0 r
s
.055 .087 .121 r
.56781 .42185 m .59887 .43001 L .59579 .42962 L p F P
0 0 0 r
s
.055 .087 .121 r
.55189 .42093 m .56781 .42185 L p .59579 .42962 L F P
0 0 0 r
s
.69 .09 .12 r
.8063 .79892 m
.797 .79749 L
s
.80199 .79101 m
.8063 .79892 L
s
.61902 .17837 m
.61276 .17935 L
s
.61458 .16637 m
.61902 .17837 L
s
.317 .527 .694 r
.45394 .32928 m .45786 .34642 L .45077 .34507 L p F P
0 0 0 r
s
.317 .527 .694 r
.43297 .30988 m .45394 .32928 L p .45077 .34507 L F P
0 0 0 r
s
.35 .587 .771 r
.45394 .32928 m .43297 .30988 L .43019 .28598 L p F P
0 0 0 r
s
.69 .09 .12 r
.86388 .92855 m
.87024 .91576 L
s
.331 .59 .76 r
.61672 .83373 m .61937 .83963 L .61666 .87083 L p F P
0 0 0 r
s
.353 .595 .781 r
.41034 .2656 m .43019 .28598 L .43297 .30988 L p F P
0 0 0 r
s
.369 .624 .817 r
.43019 .28598 m .41034 .2656 L .40912 .24159 L p F P
0 0 0 r
s
.69 .09 .12 r
.51959 .31431 m
.5347 .29076 L
s
.797 .79749 m
.80199 .79101 L
s
.304 .575 .885 r
.35589 .62747 m .3483 .62623 L .35244 .62022 L closepath p F P
0 0 0 r
s
.339 .649 .99 r
.33836 .59481 m .35244 .62022 L .3483 .62623 L p F P
0 0 0 r
s
.339 .649 .99 r
.30977 .59551 m .33836 .59481 L p .3483 .62623 L F P
0 0 0 r
s
.383 .735 1 r
.33836 .59481 m .30977 .59551 L .29142 .57045 L p F P
0 0 0 r
s
.69 .09 .12 r
.31409 .66717 m
.31146 .66623 L
s
.31146 .66623 m
.3114 .66297 L
s
.31146 .66623 m
.31034 .66617 L
s
.224 .362 .478 r
.51686 .40346 m .49569 .39196 L .48315 .37055 L p F P
0 0 0 r
s
.241 .393 .516 r
.45971 .35257 m .48315 .37055 L .49569 .39196 L p F P
0 0 0 r
s
.29 .477 .63 r
.48315 .37055 m .45971 .35257 L .45786 .34642 L p F P
0 0 0 r
s
.204 .361 .542 r
.35518 .75342 m .35851 .7559 L p .33317 .79498 L F P
0 0 0 r
s
.209 .372 .562 r
.35851 .7559 m .35518 .75342 L .35825 .75199 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.74117 .66329 m
.73837 .66546 L
s
.74158 .66314 m
.74117 .66329 L
s
.74117 .66329 m
.74214 .6671 L
s
.73837 .66546 m
.73877 .66531 L
s
.74214 .6671 m
.73837 .66546 L
s
.3114 .66297 m
.31404 .66391 L
s
.3114 .66297 m
.31034 .66617 L
s
.14 .218 .284 r
.5253 .40732 m .51686 .40346 L .52127 .40351 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.34497 .32975 m
.34086 .33004 L
s
.34628 .32156 m
.34497 .32975 L
s
.35068 .32753 m
.34497 .32975 L
s
.61276 .17935 m
.60405 .17506 L
s
.60405 .17506 m
.61458 .16637 L
s
.16522 .48272 m
.17445 .47626 L
s
.17707 .49045 m
.16522 .48272 L
s
.31404 .66391 m
.31409 .66717 L
s
.31034 .66617 m
.31409 .66717 L
s
.73128 .65311 m
.74214 .6671 L
s
.76156 .42226 m
.76404 .42341 L
s
.7594 .42497 m
.76156 .42226 L
s
.76156 .42226 m
.76029 .42218 L
s
.2 .353 .529 r
.33332 .82646 m .33317 .79498 L .35987 .78423 L p F P
0 0 0 r
s
.204 .361 .542 r
.35851 .7559 m .35987 .78423 L .33317 .79498 L p F P
0 0 0 r
s
.205 .361 .538 r
.33317 .79498 m .33332 .82646 L .30577 .83607 L p F P
0 0 0 r
s
.42 .814 1 r
.28799 .57096 m .2629 .57549 L .24384 .55339 L p F P
0 0 0 r
s
.69 .09 .12 r
.27612 .55824 m
.27765 .53941 L
s
.437 .845 1 r
.21542 .56047 m .24384 .55339 L .2629 .57549 L p F P
0 0 0 r
s
.214 .395 .62 r
.37035 .66695 m .38708 .64539 L p .39514 .69064 L F P
0 0 0 r
s
.214 .395 .62 r
.39514 .69064 m .37248 .67492 L .37035 .66695 L p F P
0 0 0 r
s
.255 .477 .744 r
.38446 .63821 m .38708 .64539 L .37035 .66695 L p F P
0 0 0 r
s
.255 .477 .744 r
.37035 .66695 m .35589 .62747 L .38446 .63821 L p F P
0 0 0 r
s
.69 .09 .12 r
.74214 .6671 m
.73877 .66531 L
s
.74158 .66314 m
.74214 .6671 L
s
.76187 .42613 m
.7594 .42497 L
s
.7594 .42497 m
.76029 .42218 L
s
.202 .36 .545 r
.35825 .75199 m .38309 .73907 L p .37892 .77557 L F P
0 0 0 r
s
.202 .36 .545 r
.37892 .77557 m .35851 .7559 L .35825 .75199 L p F P
0 0 0 r
s
.198 .356 .544 r
.37862 .70463 m .38309 .73907 L .35825 .75199 L p F P
0 0 0 r
s
.69 .09 .12 r
.17445 .47626 m
.17707 .49045 L
s
.31034 .66617 m
.31404 .66391 L
s
.212 .389 .604 r
.37862 .70463 m .37248 .67492 L .39514 .69064 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.34217 .32183 m
.34628 .32156 L
s
.34628 .32156 m
.35068 .32753 L
s
.082 .125 .179 r
.71104 .42459 m .71817 .41018 L .75188 .40247 L p F P
0 0 0 r
s
.151 .252 .366 r
.7524 .39855 m .75188 .40247 L .71817 .41018 L p F P
0 0 0 r
s
.027 .051 .071 r
.68068 .66926 m .68874 .66108 L .68237 .66582 L closepath p F P
0 0 0 r
s
.027 .051 .071 r
.71107 .64171 m .68874 .66108 L .68237 .66582 L p F P
0 0 0 r
s
.027 .051 .071 r
.68068 .66926 m .68237 .66582 L p .6525 .70365 L F P
0 0 0 r
s
.69 .09 .12 r
.5307 .29369 m
.53505 .29713 L
s
.52829 .29385 m
.5307 .29369 L
s
.5307 .29369 m
.5347 .29076 L
s
.73877 .66531 m
.74158 .66314 L
s
.4893 .87889 m
.49621 .86192 L
s
.7248 .30969 m
.71996 .27112 L
s
.203 .36 .542 r
.35987 .78423 m .35851 .7559 L .37892 .77557 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.76404 .42341 m
.76187 .42613 L
s
.76029 .42218 m
.76404 .42341 L
s
.204 .357 .532 r
.30501 .86736 m .30577 .83607 L .33332 .82646 L p F P
0 0 0 r
s
.207 .361 .536 r
.30577 .83607 m .30501 .86736 L .27704 .87627 L p F P
0 0 0 r
s
.69 .09 .12 r
.27704 .87627 m
.28466 .88215 L
s
.25499 .85922 m
.27704 .87627 L
s
.61458 .16637 m
.61276 .17935 L
s
.059 .093 .128 r
.63696 .43156 m .64492 .4277 L .67666 .42837 L p F P
0 0 0 r
s
.69 .09 .12 r
.76029 .42218 m
.76187 .42613 L
s
.53505 .29713 m
.53265 .29729 L
s
.5347 .29076 m
.53505 .29713 L
s
.27 .512 .8 r
.36714 .60015 m .38446 .63821 L .35589 .62747 L p F P
0 0 0 r
s
.27 .512 .8 r
.36137 .59832 m .36714 .60015 L p .35589 .62747 L F P
0 0 0 r
s
.27 .512 .8 r
.35589 .62747 m .35244 .62022 L .36137 .59832 L p F P
0 0 0 r
s
.087 .128 .177 r
.5253 .40732 m .55189 .42093 L .54755 .41917 L p F P
0 0 0 r
s
.087 .128 .177 r
.51686 .40346 m .5253 .40732 L p .54755 .41917 L F P
0 0 0 r
s
.69 .09 .12 r
.01 w
.48252 .53532 Mdot
.5 Mabswid
.207 .386 .478 r
.61879 .79014 m .62331 .77137 L .629 .74865 L p F P
0 0 0 r
s
.027 .051 .071 r
.63782 .73459 m .629 .74865 L .62331 .77137 L p F P
0 0 0 r
s
.027 .051 .071 r
.65078 .70917 m .63782 .73459 L .629 .74865 L p F P
0 0 0 r
s
.027 .051 .071 r
.6525 .70365 m .65078 .70917 L p .629 .74865 L F P
0 0 0 r
s
.311 .595 .916 r
.35244 .62022 m .33836 .59481 L .36137 .59832 L closepath p F P
0 0 0 r
s
.444 .86 1 r
.24384 .55339 m .21542 .56047 L .19569 .53969 L p F P
0 0 0 r
s
.451 .873 1 r
.16738 .54789 m .19569 .53969 L .21542 .56047 L p F P
0 0 0 r
s
.295 .532 .685 r
.6133 .82182 m .61672 .83373 L .61038 .85717 L p F P
0 0 0 r
s
.331 .595 .767 r
.61879 .79014 m .6133 .82182 L .61672 .83373 L p F P
0 0 0 r
s
.331 .59 .76 r
.61666 .87083 m .61038 .85717 L .61672 .83373 L p F P
0 0 0 r
s
.69 .09 .12 r
.34086 .33004 m
.34217 .32183 L
s
.35068 .32753 m
.34086 .33004 L
s
.34217 .32183 m
.35068 .32753 L
s
.53265 .29729 m
.52829 .29385 L
s
.52829 .29385 m
.5347 .29076 L
s
.5347 .29076 m
.53265 .29729 L
s
.181 .328 .509 r
.38309 .73907 m .37862 .70463 L .39514 .69064 L p F P
0 0 0 r
s
.231 .427 .537 r
.62331 .77137 m .61879 .79014 L .6133 .82182 L p F P
0 0 0 r
s
.69 .09 .12 r
.69492 .87561 m
.73525 .88544 L
s
.23966 .7615 m
.20805 .76316 L
s
.47572 .19094 m
.51389 .14817 L
s
.267 .527 .722 r
.77307 .60198 m .75431 .61259 L .7435 .61876 L p F P
0 0 0 r
s
.027 .051 .071 r
.74187 .62018 m .75431 .61259 L .7435 .61876 L closepath p F P
0 0 0 r
s
.027 .051 .071 r
.7435 .61876 m .74187 .62018 L .71107 .64171 L p F P
0 0 0 r
s
.69 .09 .12 r
.2736 .55542 m
.2783 .55624 L
s
.2783 .55624 m
.27925 .55349 L
s
.27612 .55824 m
.2783 .55624 L
s
.063 .106 .162 r
.68874 .66108 m .70753 .64918 L p .67582 .68555 L F P
0 0 0 r
s
.063 .106 .162 r
.67582 .68555 m .68068 .66926 L .68874 .66108 L p F P
0 0 0 r
s
.028 .051 .071 r
.68874 .66108 m .70753 .64918 L .71107 .64171 L closepath p F P
0 0 0 r
s
.032 .059 .087 r
.65078 .70917 m .65672 .69962 L .6525 .70365 L closepath p F P
0 0 0 r
s
.027 .051 .071 r
.6525 .70365 m .65672 .69962 L .68068 .66926 L p F P
0 0 0 r
s
.045 .08 .122 r
.65672 .69962 m .67582 .68555 L .68068 .66926 L closepath p F P
0 0 0 r
s
.042 .069 .096 r
.70753 .64918 m .71107 .64171 L .74187 .62018 L p F P
0 0 0 r
s
.69 .09 .12 r
.72694 .88633 m
.72576 .88852 L
s
.72856 .87842 m
.72694 .88633 L
s
.73525 .88544 m
.72694 .88633 L
s
.2736 .55542 m
.27455 .55267 L
s
.2736 .55542 m
.27612 .55824 L
s
.087 .128 .177 r
.50453 .40039 m .51686 .40346 L p .54755 .41917 L F P
0 0 0 r
s
.132 .204 .269 r
.50453 .40039 m .49569 .39196 L .51686 .40346 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.01 w
.68837 .53122 Mdot
.5 Mabswid
.23256 .41697 m
.25144 .44556 L
s
.082 .125 .179 r
.75188 .40247 m .74634 .41834 L .71104 .42459 L p F P
0 0 0 r
s
.69 .09 .12 r
.72739 .88059 m
.72856 .87842 L
s
.72856 .87842 m
.73525 .88544 L
s
.27455 .55267 m
.27925 .55349 L
s
.27612 .55824 m
.27925 .55349 L
s
.49462 .86257 m
.49837 .86585 L
s
.49127 .86482 m
.49462 .86257 L
s
.49462 .86257 m
.49621 .86192 L
s
.72093 .27674 m
.72685 .27817 L
s
.71502 .27961 m
.72093 .27674 L
s
.72093 .27674 m
.71996 .27112 L
s
.28 .462 .607 r
.45971 .35257 m .45077 .34507 L .45786 .34642 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.27455 .55267 m
.27612 .55824 L
s
.90153 .87231 m
.97655 .93014 L
s
.44518 .75793 m
.43922 .7524 L
s
.68181 .186 m
.68985 .11338 L
s
.05 .08 .112 r
.73528 .6347 m .74187 .62018 L .75431 .61259 L p F P
0 0 0 r
s
.042 .069 .096 r
.74187 .62018 m .73528 .6347 L .70753 .64918 L p F P
0 0 0 r
s
.69 .09 .12 r
.49837 .86585 m
.49503 .8681 L
s
.49621 .86192 m
.49837 .86585 L
s
.95576 .92448 m
.95568 .92719 L
s
.96722 .90991 m
.95576 .92448 L
s
.97655 .93014 m
.95576 .92448 L
s
.455 .881 1 r
.19569 .53969 m .16738 .54789 L .14698 .52773 L p F P
0 0 0 r
s
.407 .786 1 r
.29142 .57045 m .28799 .57096 L .28919 .5676 L closepath p F P
0 0 0 r
s
.42 .814 1 r
.27256 .54734 m .28919 .5676 L .28799 .57096 L p F P
0 0 0 r
s
.42 .814 1 r
.24384 .55339 m .27256 .54734 L p .28799 .57096 L F P
0 0 0 r
s
.06 .105 .167 r
.65672 .69962 m .67582 .68555 L p .64712 .72579 L F P
0 0 0 r
s
.06 .105 .167 r
.64712 .72579 m .65078 .70917 L .65672 .69962 L p F P
0 0 0 r
s
.69 .09 .12 r
.73525 .88544 m
.72576 .88852 L
s
.72739 .88059 m
.73525 .88544 L
s
.49503 .8681 m
.49127 .86482 L
s
.49127 .86482 m
.49621 .86192 L
s
.43831 .41257 m
.44858 .40888 L
s
.66369 .7617 m
.66382 .76233 L
s
.66525 .7585 m
.66369 .7617 L
s
.66775 .76193 m
.66369 .7617 L
s
.96724 .91249 m
.96722 .90991 L
s
.96722 .90991 m
.97655 .93014 L
s
.05 .08 .112 r
.75431 .61259 m .77107 .60376 L p .73528 .6347 L F P
0 0 0 r
s
.027 .051 .071 r
.75431 .61259 m .77107 .60376 L .77307 .60198 L closepath p F P
0 0 0 r
s
.194 .343 .517 r
.3606 .81617 m .35987 .78423 L .37892 .77557 L p F P
0 0 0 r
s
.2 .353 .529 r
.35987 .78423 m .3606 .81617 L .33332 .82646 L p F P
0 0 0 r
s
.383 .735 1 r
.29142 .57045 m .32021 .56773 L .33836 .59481 L p F P
0 0 0 r
s
.396 .766 1 r
.30156 .5432 m .32021 .56773 L .29142 .57045 L p F P
0 0 0 r
s
.396 .766 1 r
.2938 .54404 m .30156 .5432 L p .29142 .57045 L F P
0 0 0 r
s
.396 .766 1 r
.29142 .57045 m .28919 .5676 L .2938 .54404 L p F P
0 0 0 r
s
.69 .09 .12 r
.66538 .75912 m
.66525 .7585 L
s
.66525 .7585 m
.66775 .76193 L
s
.72093 .28104 m
.71502 .27961 L
s
.71502 .27961 m
.71996 .27112 L
s
.315 .609 .938 r
.36137 .59832 m .33836 .59481 L .32021 .56773 L p F P
0 0 0 r
s
.69 .09 .12 r
.72576 .88852 m
.72739 .88059 L
s
.043 .079 .127 r
.63782 .73459 m .64712 .72579 L .65078 .70917 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.49621 .86192 m
.49503 .8681 L
s
.199 .351 .523 r
.33299 .85805 m .33332 .82646 L .3606 .81617 L p F P
0 0 0 r
s
.204 .357 .532 r
.33332 .82646 m .33299 .85805 L .30501 .86736 L p F P
0 0 0 r
s
.69 .09 .12 r
.66775 .76193 m
.66382 .76233 L
s
.66538 .75912 m
.66775 .76193 L
s
.65168 .75434 m
.66775 .76193 L
s
.44737 .41059 m
.44648 .41091 L
s
.44656 .40833 m
.44737 .41059 L
s
.44858 .40888 m
.44737 .41059 L
s
.72685 .27817 m
.72093 .28104 L
s
.71996 .27112 m
.72685 .27817 L
s
.44567 .40865 m
.44656 .40833 L
s
.44656 .40833 m
.44858 .40888 L
s
.19423 .63968 m
.17076 .66352 L
s
.317 .527 .694 r
.45077 .34507 m .43765 .33355 L .43297 .30988 L p F P
0 0 0 r
s
.325 .544 .714 r
.41249 .28973 m .43297 .30988 L .43765 .33355 L p F P
0 0 0 r
s
.353 .595 .781 r
.43297 .30988 m .41249 .28973 L .41034 .2656 L p F P
0 0 0 r
s
.69 .09 .12 r
.44045 .75207 m
.44188 .75308 L
s
.43895 .75394 m
.44045 .75207 L
s
.44045 .75207 m
.43922 .7524 L
s
.241 .393 .516 r
.49569 .39196 m .46993 .37477 L .45971 .35257 L p F P
0 0 0 r
s
.236 .388 .505 r
.45077 .34507 m .45971 .35257 L .46993 .37477 L p F P
0 0 0 r
s
.409 .793 1 r
.28919 .5676 m .27256 .54734 L .2938 .54404 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.44037 .75495 m
.43895 .75394 L
s
.43895 .75394 m
.43922 .7524 L
s
.50451 .15257 m
.5124 .16108 L
s
.49997 .15249 m
.50451 .15257 L
s
.50451 .15257 m
.51389 .14817 L
s
.66382 .76233 m
.66538 .75912 L
s
.172 .31 .478 r
.38567 .77218 m .38309 .73907 L .40528 .72307 L p F P
0 0 0 r
s
.181 .328 .509 r
.40082 .69658 m .40528 .72307 L .38309 .73907 L p F P
0 0 0 r
s
.181 .328 .509 r
.39514 .69064 m .40082 .69658 L p .38309 .73907 L F P
0 0 0 r
s
.202 .36 .545 r
.38309 .73907 m .38567 .77218 L .37892 .77557 L p F P
0 0 0 r
s
.69 .09 .12 r
.44858 .40888 m
.44648 .41091 L
s
.44567 .40865 m
.44858 .40888 L
s
.44648 .41091 m
.44567 .40865 L
s
.44188 .75308 m
.44037 .75495 L
s
.43922 .7524 m
.44188 .75308 L
s
.43922 .7524 m
.44037 .75495 L
s
.027 .051 .071 r
.77107 .60376 m .77307 .60198 L .80466 .58582 L p F P
0 0 0 r
s
.69 .09 .12 r
.5124 .16108 m
.50789 .16103 L
s
.51389 .14817 m
.5124 .16108 L
s
.24768 .4436 m
.24229 .44186 L
s
.25299 .43774 m
.24768 .4436 L
s
.25144 .44556 m
.24768 .4436 L
s
.64505 .40815 m
.64481 .3904 L
s
.71996 .27112 m
.72093 .28104 L
s
.434 .84 1 r
.27256 .54734 m .24384 .55339 L .22431 .53199 L p F P
0 0 0 r
s
.444 .86 1 r
.19569 .53969 m .22431 .53199 L .24384 .55339 L p F P
0 0 0 r
s
.69 .09 .12 r
.64478 .39364 m
.64741 .3939 L
s
.6423 .39401 m
.64478 .39364 L
s
.64478 .39364 m
.64481 .3904 L
s
.88552 .78726 m
.88651 .78763 L
s
.89376 .77958 m
.88552 .78726 L
s
.8979 .79183 m
.88552 .78726 L
s
.8948 .77992 m
.89376 .77958 L
s
.89376 .77958 m
.8979 .79183 L
s
.26153 .85715 m
.2674 .86207 L
s
.25462 .86566 m
.26153 .85715 L
s
.26153 .85715 m
.25499 .85922 L
s
.052 .083 .115 r
.63696 .43156 m .60724 .43072 L .59887 .43001 L p F P
0 0 0 r
s
.15 .321 .464 r
.60724 .43072 m .59579 .42962 L .59887 .43001 L closepath p F P
0 0 0 r
s
.121 .182 .244 r
.49569 .39196 m .50453 .40039 L .48731 .39142 L p F P
0 0 0 r
s
.121 .182 .244 r
.48731 .39142 m .46993 .37477 L .49569 .39196 L p F P
0 0 0 r
s
.69 .09 .12 r
.2476 .43599 m
.25299 .43774 L
s
.25299 .43774 m
.25144 .44556 L
s
.85919 .75074 m
.8979 .79183 L
s
.40063 .6358 m
.39224 .63932 L
s
.26047 .87062 m
.25462 .86566 L
s
.25462 .86566 m
.25499 .85922 L
s
.64493 .39428 m
.6423 .39401 L
s
.6423 .39401 m
.64481 .3904 L
s
.64741 .3939 m
.64493 .39428 L
s
.64481 .3904 m
.64741 .3939 L
s
.063 .097 .134 r
.71104 .42459 m .68947 .42764 L .67666 .42837 L p F P
0 0 0 r
s
.049 .079 .11 r
.68947 .42764 m .67484 .42929 L .67666 .42837 L closepath p F P
0 0 0 r
s
.059 .093 .128 r
.67666 .42837 m .67484 .42929 L .63696 .43156 L p F P
0 0 0 r
s
.69 .09 .12 r
.64481 .3904 m
.64493 .39428 L
s
.295 .532 .685 r
.61038 .85717 m .60931 .85357 L .6133 .82182 L p F P
0 0 0 r
s
.231 .427 .537 r
.62157 .78124 m .62331 .77137 L p .62175 .77922 L F P
0 0 0 r
s
.231 .427 .537 r
.6133 .82182 m .61899 .79392 L .62175 .77922 L F
.61899 .79392 m .62157 .78124 L .62175 .77922 L F
.6133 .82182 m .61668 .80091 L .62157 .78124 L p F P
0 0 0 r
s
.241 .442 .559 r
.61668 .80091 m .6133 .82182 L .60931 .85357 L p F P
0 0 0 r
s
.241 .442 .559 r
.61024 .83361 m .61668 .80091 L p .61379 .82153 L F P
0 0 0 r
s
.241 .442 .559 r
.60931 .85357 m .60982 .84267 L p .61379 .82153 L F P
0 0 0 r
s
.241 .442 .559 r
.60982 .84267 m .61024 .83361 L p .61379 .82153 L F P
0 0 0 r
s
.69 .09 .12 r
.61071 .63491 m
.61019 .63501 L
s
.61015 .63361 m
.61071 .63491 L
s
.61071 .63491 m
.60941 .63454 L
s
.61093 .63408 m
.61071 .63491 L
s
.60803 .63191 m
.61071 .63491 L
s
.088 .143 .224 r
.70288 .67072 m .70753 .64918 L .73528 .6347 L p F P
0 0 0 r
s
.063 .106 .162 r
.70753 .64918 m .70288 .67072 L .67582 .68555 L p F P
0 0 0 r
s
.69 .09 .12 r
.61015 .63361 m
.60941 .63454 L
s
.61093 .63408 m
.61015 .63361 L
s
.60941 .63454 m
.61019 .63501 L
s
.61019 .63501 m
.61093 .63408 L
s
.027 .051 .071 r
.62331 .77137 m .62541 .76805 L .63782 .73459 L p F P
0 0 0 r
s
.063 .111 .183 r
.64712 .72579 m .63782 .73459 L .62541 .76805 L p F P
0 0 0 r
s
.69 .09 .12 r
.41177 .28163 m
.42448 .27672 L
s
.39368 .28863 m
.41177 .28163 L
s
.39471 .63974 m
.39357 .63942 L
s
.39357 .63942 m
.39314 .63749 L
s
.39357 .63942 m
.39224 .63932 L
s
.97655 .93014 m
.95568 .92719 L
s
.96724 .91249 m
.97655 .93014 L
s
.186 .343 .538 r
.40082 .69658 m .39514 .69064 L .39872 .68654 L closepath p F P
0 0 0 r
s
.214 .395 .62 r
.38708 .64539 m .39872 .68654 L .39514 .69064 L p F P
0 0 0 r
s
.69 .09 .12 r
.39314 .63749 m
.39428 .63781 L
s
.39314 .63749 m
.39224 .63932 L
s
.205 .422 .597 r
.63043 .43071 m .63696 .43156 L .67484 .42929 L p F P
0 0 0 r
s
.174 .366 .524 r
.63043 .43071 m .60724 .43072 L .63696 .43156 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.68708 .12555 m
.69869 .12879 L
s
.67775 .12733 m
.68708 .12555 L
s
.68708 .12555 m
.68985 .11338 L
s
.236 .388 .505 r
.43998 .34152 m .45077 .34507 L p .46993 .37477 L F P
0 0 0 r
s
.274 .454 .594 r
.43998 .34152 m .43765 .33355 L .45077 .34507 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.24229 .44186 m
.2476 .43599 L
s
.25144 .44556 m
.24229 .44186 L
s
.061 .098 .144 r
.7647 .62143 m .77107 .60376 L .80021 .58987 L p F P
0 0 0 r
s
.027 .051 .071 r
.80466 .58582 m .80021 .58987 L .77107 .60376 L p F P
0 0 0 r
s
.05 .08 .112 r
.77107 .60376 m .7647 .62143 L .73528 .6347 L p F P
0 0 0 r
s
.69 .09 .12 r
.39428 .63781 m
.39471 .63974 L
s
.39224 .63932 m
.39471 .63974 L
s
.449 .87 1 r
.22431 .53199 m .19569 .53969 L .17548 .51909 L p F P
0 0 0 r
s
.455 .881 1 r
.14698 .52773 m .17548 .51909 L .19569 .53969 L p F P
0 0 0 r
s
.69 .09 .12 r
.8979 .79183 m
.88651 .78763 L
s
.8948 .77992 m
.8979 .79183 L
s
.225 .454 .652 r
.60724 .43072 m .63043 .43071 L p .58321 .42442 L F P
0 0 0 r
s
.225 .454 .652 r
.58321 .42442 m .59579 .42962 L .60724 .43072 L p F P
0 0 0 r
s
.69 .09 .12 r
.21607 .76835 m
.21085 .76512 L
s
.21085 .76512 m
.21282 .7573 L
s
.21085 .76512 m
.20805 .76316 L
s
.39224 .63932 m
.39428 .63781 L
s
.14301 .55964 m
.14698 .52773 L
s
.14698 .52773 m
.14836 .51669 L
s
.2476 .43599 m
.25144 .44556 L
s
.2674 .86207 m
.26047 .87062 L
s
.25499 .85922 m
.2674 .86207 L
s
.194 .343 .517 r
.37892 .77557 m .38637 .78525 L p .3606 .81617 L F P
0 0 0 r
s
.194 .345 .522 r
.38637 .78525 m .37892 .77557 L .38567 .77218 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.51389 .14817 m
.50789 .16103 L
s
.49997 .15249 m
.51389 .14817 L
s
.055 .087 .121 r
.59579 .42962 m .55811 .42233 L .55189 .42093 L p F P
0 0 0 r
s
.192 .395 .574 r
.58321 .42442 m .55811 .42233 L .59579 .42962 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.50789 .16103 m
.49997 .15249 L
s
.221 .448 .632 r
.66245 .42755 m .67484 .42929 L .68947 .42764 L p F P
0 0 0 r
s
.205 .422 .597 r
.67484 .42929 m .66245 .42755 L .63043 .43071 L p F P
0 0 0 r
s
.165 .309 .494 r
.38891 .64119 m .38708 .64539 L .39872 .68654 L p F P
0 0 0 r
s
.211 .396 .629 r
.38708 .64539 m .38446 .63821 L .38891 .64119 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.21282 .7573 m
.21805 .76052 L
s
.21282 .7573 m
.20805 .76316 L
s
.2 .381 .609 r
.38891 .64119 m .38446 .63821 L .36714 .60015 L p F P
0 0 0 r
s
.69 .09 .12 r
.25499 .85922 m
.26047 .87062 L
s
.82895 .64445 m
.82465 .64721 L
s
.83032 .64412 m
.82895 .64445 L
s
.82895 .64445 m
.83025 .65009 L
s
.60131 .28389 m
.61138 .2437 L
s
.95568 .92719 m
.96724 .91249 L
s
.044 .072 .1 r
.70881 .42577 m .68947 .42764 L .71104 .42459 L closepath p F P
0 0 0 r
s
.221 .448 .632 r
.68947 .42764 m .70881 .42577 L p .66245 .42755 L F P
0 0 0 r
s
.69 .09 .12 r
.82465 .64721 m
.82601 .6469 L
s
.83025 .65009 m
.82465 .64721 L
s
.88651 .78763 m
.8948 .77992 L
s
.157 .29 .461 r
.39872 .68654 m .40921 .66346 L p .41329 .71414 L F P
0 0 0 r
s
.157 .29 .461 r
.41329 .71414 m .40082 .69658 L .39872 .68654 L p F P
0 0 0 r
s
.165 .309 .494 r
.39872 .68654 m .40921 .66346 L .38891 .64119 L p F P
0 0 0 r
s
.152 .321 .476 r
.55811 .42233 m .54755 .41917 L .55189 .42093 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.41814 .28285 m
.4209 .28226 L
s
.41843 .27539 m
.4209 .28226 L
s
.4209 .28226 m
.42448 .27672 L
s
.191 .338 .507 r
.36078 .84815 m .3606 .81617 L .38717 .80478 L p F P
0 0 0 r
s
.194 .343 .517 r
.38637 .78525 m .38717 .80478 L .3606 .81617 L p F P
0 0 0 r
s
.199 .351 .523 r
.3606 .81617 m .36078 .84815 L .33299 .85805 L p F P
0 0 0 r
s
.69 .09 .12 r
.35129 .85131 m
.35148 .85146 L
s
.35148 .85146 m
.36267 .86066 L
s
.34357 .84497 m
.35129 .85131 L
s
.21805 .76052 m
.21607 .76835 L
s
.20805 .76316 m
.21607 .76835 L
s
.41567 .27596 m
.41843 .27539 L
s
.41843 .27539 m
.42448 .27672 L
s
.81643 .62799 m
.83025 .65009 L
s
.35565 .51249 m
.35512 .52195 L
s
.83025 .65009 m
.82601 .6469 L
s
.83032 .64412 m
.83025 .65009 L
s
.104 .172 .269 r
.67233 .70951 m .67582 .68555 L .70288 .67072 L p F P
0 0 0 r
s
.06 .105 .167 r
.67582 .68555 m .67233 .70951 L .64712 .72579 L p F P
0 0 0 r
s
.186 .333 .505 r
.38567 .77218 m .40933 .75759 L p .39596 .80046 L F P
0 0 0 r
s
.186 .333 .505 r
.39596 .80046 m .38637 .78525 L .38567 .77218 L p F P
0 0 0 r
s
.172 .31 .478 r
.40528 .72307 m .40933 .75759 L .38567 .77218 L p F P
0 0 0 r
s
.315 .609 .938 r
.32021 .56773 m .3492 .56979 L p .36137 .59832 L F P
0 0 0 r
s
.358 .692 1 r
.3492 .56979 m .32021 .56773 L .30156 .5432 L p F P
0 0 0 r
s
.168 .308 .483 r
.40528 .72307 m .40082 .69658 L .41329 .71414 L closepath p F P
0 0 0 r
s
.271 .518 .812 r
.36714 .60015 m .36137 .59832 L .36241 .59154 L closepath p F P
0 0 0 r
s
.315 .609 .938 r
.3492 .56979 m .36241 .59154 L .36137 .59832 L p F P
0 0 0 r
s
.69 .09 .12 r
.20805 .76316 m
.21805 .76052 L
s
.60818 .25061 m
.61499 .25297 L
s
.60371 .25058 m
.60818 .25061 L
s
.60818 .25061 m
.61138 .2437 L
s
.037 .069 .106 r
.62157 .78124 m .62541 .76805 L .62331 .77137 L closepath p F P
0 0 0 r
s
.087 .128 .177 r
.54755 .41917 m .52171 .40921 L .50453 .40039 L p F P
0 0 0 r
s
.113 .228 .356 r
.52171 .40921 m .50453 .40039 L .48731 .39142 L p F P
0 0 0 r
s
.037 .064 .088 r
.70881 .42577 m .71104 .42459 L .74634 .41834 L p F P
0 0 0 r
s
.122 .238 .391 r
.39209 .61653 m .38891 .64119 L .40921 .66346 L p F P
0 0 0 r
s
.2 .381 .609 r
.36714 .60015 m .39209 .61653 L .38891 .64119 L p F P
0 0 0 r
s
.69 .09 .12 r
.69869 .12879 m
.68938 .13059 L
s
.68985 .11338 m
.69869 .12879 L
s
.56388 .50357 m
.56429 .50498 L
s
.5635 .50405 m
.56388 .50357 L
s
.56388 .50357 m
.56314 .50476 L
s
.56465 .50426 m
.56388 .50357 L
s
.56394 .50828 m
.56388 .50357 L
s
.56429 .50498 m
.56465 .50426 L
s
.56314 .50476 m
.56429 .50498 L
s
.82601 .6469 m
.83032 .64412 L
s
.5635 .50405 m
.56314 .50476 L
s
.18007 .66261 m
.17337 .66169 L
s
.17337 .66169 m
.17095 .65479 L
s
.17337 .66169 m
.17076 .66352 L
s
.57073 .85729 m
.5867 .85306 L
s
.411 .8 1 r
.2938 .54404 m .27256 .54734 L .25323 .52515 L p F P
0 0 0 r
s
.434 .84 1 r
.22431 .53199 m .25323 .52515 L .27256 .54734 L p F P
0 0 0 r
s
.69 .09 .12 r
.56465 .50426 m
.5635 .50405 L
s
.68938 .13059 m
.67775 .12733 L
s
.67775 .12733 m
.68985 .11338 L
s
.816 .88025 m
.81645 .88247 L
s
.82171 .87057 m
.816 .88025 L
s
.82892 .88216 m
.816 .88025 L
s
.205 .416 .61 r
.55811 .42233 m .58321 .42442 L p .5354 .41228 L F P
0 0 0 r
s
.205 .416 .61 r
.5354 .41228 m .54755 .41917 L .55811 .42233 L p F P
0 0 0 r
s
.69 .09 .12 r
.35613 .52097 m
.35377 .52055 L
s
.35668 .51955 m
.35613 .52097 L
s
.35512 .52195 m
.35613 .52097 L
s
.094 .156 .251 r
.64381 .75091 m .64712 .72579 L .67233 .70951 L p F P
0 0 0 r
s
.063 .111 .183 r
.62541 .76805 m .64381 .75091 L .64712 .72579 L p F P
0 0 0 r
s
.69 .09 .12 r
.35377 .52055 m
.35432 .51913 L
s
.35377 .52055 m
.35512 .52195 L
s
.82219 .87274 m
.82171 .87057 L
s
.82171 .87057 m
.82892 .88216 L
s
.61499 .25297 m
.61054 .25294 L
s
.61138 .2437 m
.61499 .25297 L
s
.41814 .28285 m
.42448 .27672 L
s
.41567 .27596 m
.42448 .27672 L
s
.41567 .27596 m
.41814 .28285 L
s
.35432 .51913 m
.35668 .51955 L
s
.35512 .52195 m
.35668 .51955 L
s
.58468 .85503 m
.58354 .85616 L
s
.58346 .85166 m
.58468 .85503 L
s
.5867 .85306 m
.58468 .85503 L
s
.182 .353 .563 r
.39209 .61653 m .36714 .60015 L .36241 .59154 L p F P
0 0 0 r
s
.047 .088 .143 r
.62541 .76805 m .64381 .75091 L p .61939 .79669 L F P
0 0 0 r
s
.047 .088 .143 r
.61939 .79669 m .62157 .78124 L .62541 .76805 L p F P
0 0 0 r
s
.69 .09 .12 r
.58232 .85279 m
.58346 .85166 L
s
.58346 .85166 m
.5867 .85306 L
s
.267 .442 .578 r
.43765 .33355 m .43998 .34152 L .42165 .33241 L p F P
0 0 0 r
s
.267 .442 .578 r
.42165 .33241 m .41632 .31371 L .43765 .33355 L p F P
0 0 0 r
s
.325 .544 .714 r
.43765 .33355 m .41632 .31371 L .41249 .28973 L p F P
0 0 0 r
s
.69 .09 .12 r
.17765 .65571 m
.18007 .66261 L
s
.17076 .66352 m
.18007 .66261 L
s
.35432 .51913 m
.35512 .52195 L
s
.189 .336 .509 r
.38717 .80478 m .38637 .78525 L .39596 .80046 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.17095 .65479 m
.17765 .65571 L
s
.17095 .65479 m
.17076 .66352 L
s
.61054 .25294 m
.60371 .25058 L
s
.60371 .25058 m
.61138 .2437 L
s
.7798 .85391 m
.82892 .88216 L
s
.31734 .73799 m
.29337 .73992 L
s
.55714 .15842 m
.58814 .09006 L
s
.168 .351 .521 r
.5354 .41228 m .52171 .40921 L .54755 .41917 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.68985 .11338 m
.68938 .13059 L
s
.145 .263 .415 r
.41329 .71414 m .40528 .72307 L .40933 .75759 L p F P
0 0 0 r
s
.44 .853 1 r
.25323 .52515 m .22431 .53199 L .2043 .51086 L p F P
0 0 0 r
s
.449 .87 1 r
.17548 .51909 m .2043 .51086 L .22431 .53199 L p F P
0 0 0 r
s
.69 .09 .12 r
.61138 .2437 m
.61054 .25294 L
s
.037 .064 .088 r
.74634 .41834 m .74138 .42106 L .70881 .42577 L p F P
0 0 0 r
s
.283 .565 .796 r
.74138 .42106 m .70881 .42577 L .69489 .42213 L p F P
0 0 0 r
s
.221 .448 .632 r
.70881 .42577 m .69489 .42213 L .66245 .42755 L p F P
0 0 0 r
s
.136 .212 .278 r
.46993 .37477 m .48731 .39142 L .48029 .38675 L p F P
0 0 0 r
s
.136 .212 .278 r
.44617 .35634 m .46993 .37477 L p .48029 .38675 L F P
0 0 0 r
s
.236 .388 .505 r
.46993 .37477 m .44617 .35634 L .43998 .34152 L p F P
0 0 0 r
s
.69 .09 .12 r
.5867 .85306 m
.58354 .85616 L
s
.58232 .85279 m
.5867 .85306 L
s
.58354 .85616 m
.58232 .85279 L
s
.349 .697 1 r
.66245 .42755 m .63043 .43071 L .61504 .42216 L p F P
0 0 0 r
s
.225 .454 .652 r
.63043 .43071 m .61504 .42216 L .58321 .42442 L p F P
0 0 0 r
s
.182 .353 .563 r
.36241 .59154 m .36198 .57372 L p .39209 .61653 L F P
0 0 0 r
s
.269 .517 .811 r
.36241 .59154 m .3492 .56979 L .36198 .57372 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.82892 .88216 m
.81645 .88247 L
s
.82219 .87274 m
.82892 .88216 L
s
.131 .221 .332 r
.7647 .62143 m .73528 .6347 L .73202 .6575 L p F P
0 0 0 r
s
.088 .143 .224 r
.73528 .6347 m .73202 .6575 L .70288 .67072 L p F P
0 0 0 r
s
.69 .09 .12 r
.01 w
.77325 .50404 Mdot
.5 Mabswid
.31023 .38798 m
.32777 .39949 L
s
.17076 .66352 m
.17765 .65571 L
s
.75463 .74266 m
.75084 .74723 L
s
.75623 .74355 m
.75463 .74266 L
s
.75463 .74266 m
.75783 .74908 L
s
.75084 .74723 m
.75243 .74814 L
s
.75783 .74908 m
.75084 .74723 L
s
.061 .098 .144 r
.80021 .58987 m .79531 .60886 L .7647 .62143 L p F P
0 0 0 r
s
.042 .078 .124 r
.61668 .80091 m .61939 .79669 L .62157 .78124 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.01 w
.52631 .73431 Mdot
.5 Mabswid
.75783 .74908 m
.75243 .74814 L
s
.75623 .74355 m
.75783 .74908 L
s
.73629 .73061 m
.75783 .74908 L
s
.1487 .55505 m
.13779 .55318 L
s
.15042 .54873 m
.1487 .55505 L
s
.14301 .55964 m
.1487 .55505 L
s
.34767 .84363 m
.35181 .84692 L
s
.34305 .84936 m
.34767 .84363 L
s
.34357 .84497 m
.34767 .84363 L
s
.224 .369 .476 r
.44617 .35634 m .43998 .34152 L .42165 .33241 L p F P
0 0 0 r
s
.69 .09 .12 r
.81645 .88247 m
.82219 .87274 L
s
.34305 .84936 m
.34719 .85267 L
s
.34305 .84936 m
.34357 .84497 L
s
.52462 .36982 m
.52772 .37131 L
s
.52349 .36934 m
.52462 .36982 L
s
.52462 .36982 m
.52715 .36705 L
s
.394 .766 1 r
.30156 .5432 m .2938 .54404 L .29396 .53379 L closepath p F P
0 0 0 r
s
.411 .8 1 r
.28242 .51994 m .29396 .53379 L .2938 .54404 L p F P
0 0 0 r
s
.411 .8 1 r
.25323 .52515 m .28242 .51994 L p .2938 .54404 L F P
0 0 0 r
s
.69 .09 .12 r
.51943 .38344 m
.52715 .36705 L
s
.52772 .37131 m
.52659 .37083 L
s
.52715 .36705 m
.52772 .37131 L
s
.13779 .55318 m
.13947 .54684 L
s
.13779 .55318 m
.14301 .55964 L
s
.183 .326 .493 r
.39596 .80046 m .38717 .80478 L .38799 .83727 L p F P
0 0 0 r
s
.191 .338 .507 r
.38717 .80478 m .38799 .83727 L .36078 .84815 L p F P
0 0 0 r
s
.69 .09 .12 r
.75243 .74814 m
.75623 .74355 L
s
.52715 .36705 m
.52659 .37083 L
s
.52349 .36934 m
.52715 .36705 L
s
.32516 .39961 m
.32159 .39954 L
s
.3269 .39482 m
.32516 .39961 L
s
.32777 .39949 m
.32516 .39961 L
s
.57925 .10098 m
.59123 .10765 L
s
.57252 .10004 m
.57925 .10098 L
s
.57925 .10098 m
.58814 .09006 L
s
.52659 .37083 m
.52349 .36934 L
s
.27157 .61413 m
.25305 .63109 L
s
.35181 .84692 m
.34719 .85267 L
s
.34357 .84497 m
.35181 .84692 L
s
.32332 .39475 m
.3269 .39482 L
s
.3269 .39482 m
.32777 .39949 L
s
.193 .392 .585 r
.52171 .40921 m .5354 .41228 L .51841 .39947 L p F P
0 0 0 r
s
.193 .392 .585 r
.51841 .39947 m .4914 .39352 L .52171 .40921 L p F P
0 0 0 r
s
.113 .228 .356 r
.48731 .39142 m .4914 .39352 L .52171 .40921 L p F P
0 0 0 r
s
.69 .09 .12 r
.34357 .84497 m
.34719 .85267 L
s
.358 .692 1 r
.30156 .5432 m .33075 .54302 L .3492 .56979 L p F P
0 0 0 r
s
.381 .742 1 r
.31183 .51809 m .33075 .54302 L .30156 .5432 L p F P
0 0 0 r
s
.381 .742 1 r
.29248 .51878 m .31183 .51809 L p .30156 .5432 L F P
0 0 0 r
s
.381 .742 1 r
.30156 .5432 m .29396 .53379 L .29248 .51878 L p F P
0 0 0 r
s
.69 .09 .12 r
.29946 .74334 m
.29606 .74139 L
s
.29606 .74139 m
.29693 .73574 L
s
.29606 .74139 m
.29337 .73992 L
s
.136 .232 .349 r
.73202 .6575 m .70288 .67072 L .70067 .69583 L p F P
0 0 0 r
s
.104 .172 .269 r
.70288 .67072 m .70067 .69583 L .67233 .70951 L p F P
0 0 0 r
s
.69 .09 .12 r
.69748 .61229 m
.69653 .61246 L
s
.69638 .60965 m
.69748 .61229 L
s
.69748 .61229 m
.69489 .61153 L
s
.69802 .61058 m
.69748 .61229 L
s
.69235 .6061 m
.69748 .61229 L
s
.72744 .35763 m
.73107 .35752 L
s
.72357 .3584 m
.72744 .35763 L
s
.72744 .35763 m
.72673 .35272 L
s
.72966 .37888 m
.72673 .35272 L
s
.145 .263 .415 r
.40933 .75759 m .42534 .7402 L .41329 .71414 L p F P
0 0 0 r
s
.108 .201 .332 r
.42024 .69942 m .41329 .71414 L .42534 .7402 L p F P
0 0 0 r
s
.157 .29 .461 r
.413 .67004 m .42024 .69942 L .41329 .71414 L p F P
0 0 0 r
s
.157 .29 .461 r
.40921 .66346 m .413 .67004 L p .41329 .71414 L F P
0 0 0 r
s
.69 .09 .12 r
.29693 .73574 m
.30034 .73768 L
s
.29693 .73574 m
.29337 .73992 L
s
.47723 .61217 m
.47766 .61191 L
s
.47766 .61191 m
.47725 .61076 L
s
.47766 .61191 m
.47619 .6118 L
s
.47725 .61076 m
.47681 .61102 L
s
.47725 .61076 m
.47619 .6118 L
s
.47619 .6118 m
.47723 .61217 L
s
.47619 .6118 m
.47681 .61102 L
s
.48145 .61013 m
.47619 .6118 L
s
.69638 .60965 m
.69489 .61153 L
s
.69802 .61058 m
.69638 .60965 L
s
.128 .23 .366 r
.41195 .79123 m .40933 .75759 L .42534 .7402 L p F P
0 0 0 r
s
.186 .333 .505 r
.40933 .75759 m .41195 .79123 L .39596 .80046 L p F P
0 0 0 r
s
.262 .507 .794 r
.36198 .57372 m .3492 .56979 L .33075 .54302 L p F P
0 0 0 r
s
.69 .09 .12 r
.32159 .39954 m
.32332 .39475 L
s
.32777 .39949 m
.32159 .39954 L
s
.69489 .61153 m
.69653 .61246 L
s
.13947 .54684 m
.15042 .54873 L
s
.14301 .55964 m
.15042 .54873 L
s
.047 .088 .143 r
.61939 .79669 m .61668 .80091 L .61024 .83361 L p F P
0 0 0 r
s
.368 .733 1 r
.61504 .42216 m .58321 .42442 L .56697 .41281 L p F P
0 0 0 r
s
.205 .416 .61 r
.58321 .42442 m .56697 .41281 L .5354 .41228 L p F P
0 0 0 r
s
.69 .09 .12 r
.47681 .61102 m
.47723 .61217 L
s
.183 .326 .493 r
.38799 .83727 m .40875 .8273 L .39596 .80046 L p F P
0 0 0 r
s
.176 .315 .481 r
.41195 .79123 m .39596 .80046 L .40875 .8273 L p F P
0 0 0 r
s
.69 .09 .12 r
.69653 .61246 m
.69802 .61058 L
s
.59123 .10765 m
.58455 .10675 L
s
.58814 .09006 m
.59123 .10765 L
s
.32332 .39475 m
.32777 .39949 L
s
.72719 .35829 m
.72357 .3584 L
s
.72357 .3584 m
.72673 .35272 L
s
.424 .822 1 r
.28242 .51994 m .25323 .52515 L .23342 .50338 L p F P
0 0 0 r
s
.44 .853 1 r
.2043 .51086 m .23342 .50338 L .25323 .52515 L p F P
0 0 0 r
s
.69 .09 .12 r
.30034 .73768 m
.29946 .74334 L
s
.29337 .73992 m
.29946 .74334 L
s
.13947 .54684 m
.14301 .55964 L
s
.73107 .35752 m
.72719 .35829 L
s
.72673 .35272 m
.73107 .35752 L
s
.72673 .35272 m
.72719 .35829 L
s
.29337 .73992 m
.30034 .73768 L
s
.23263 .84194 m
.18436 .83815 L
s
.283 .565 .796 r
.69489 .42213 m .72775 .41522 L .74138 .42106 L p F P
0 0 0 r
s
.69 .09 .12 r
.47448 .25739 m
.5005 .22438 L
s
.135 .232 .35 r
.70067 .69583 m .67233 .70951 L .6704 .7359 L p F P
0 0 0 r
s
.094 .156 .251 r
.67233 .70951 m .6704 .7359 L .64381 .75091 L p F P
0 0 0 r
s
.391 .78 1 r
.66245 .42755 m .69489 .42213 L .68521 .41467 L p F P
0 0 0 r
s
.391 .78 1 r
.64732 .41693 m .66245 .42755 L p .68521 .41467 L F P
0 0 0 r
s
.349 .697 1 r
.61504 .42216 m .64732 .41693 L .66245 .42755 L p F P
0 0 0 r
s
.395 .769 1 r
.29396 .53379 m .28242 .51994 L .29248 .51878 L closepath p F P
0 0 0 r
s
.124 .209 .315 r
.76301 .63661 m .7647 .62143 L .79531 .60886 L p F P
0 0 0 r
s
.131 .221 .332 r
.76301 .63661 m .7647 .62143 L p .73202 .6575 L F P
0 0 0 r
s
.08 .137 .225 r
.61659 .82386 m .61939 .79669 L .6417 .77799 L p F P
0 0 0 r
s
.047 .088 .143 r
.64381 .75091 m .6417 .77799 L .61939 .79669 L p F P
0 0 0 r
s
.047 .088 .143 r
.61024 .83361 m .61659 .82386 L .61939 .79669 L p F P
0 0 0 r
s
.69 .09 .12 r
.22248 .51775 m
.22364 .50617 L
s
.22364 .50617 m
.22367 .50588 L
s
.22367 .50588 m
.22535 .48905 L
s
.26002 .63025 m
.25596 .63001 L
s
.25596 .63001 m
.25353 .6251 L
s
.25596 .63001 m
.25305 .63109 L
s
.136 .212 .278 r
.48029 .38675 m .46436 .37617 L .44617 .35634 L p F P
0 0 0 r
s
.151 .242 .311 r
.42351 .33695 m .44617 .35634 L .46436 .37617 L p F P
0 0 0 r
s
.224 .369 .476 r
.42165 .33241 m .42351 .33695 L .44617 .35634 L p F P
0 0 0 r
s
.089 .169 .292 r
.413 .67004 m .40921 .66346 L .40964 .65868 L closepath p F P
0 0 0 r
s
.122 .238 .391 r
.3959 .62102 m .39209 .61653 L p .40921 .66346 L F P
0 0 0 r
s
.122 .238 .391 r
.40921 .66346 m .40964 .65868 L .3959 .62102 L p F P
0 0 0 r
s
.69 .09 .12 r
.49356 .22845 m
.49975 .23398 L
s
.49079 .22803 m
.49356 .22845 L
s
.49356 .22845 m
.5005 .22438 L
s
.58455 .10675 m
.57252 .10004 L
s
.57252 .10004 m
.58814 .09006 L
s
.127 .218 .334 r
.6704 .7359 m .64381 .75091 L .6417 .77799 L p F P
0 0 0 r
s
.341 .677 1 r
.56697 .41281 m .5354 .41228 L .51841 .39947 L p F P
0 0 0 r
s
.69 .09 .12 r
.44318 .83848 m
.43399 .83043 L
s
.68563 .25249 m
.69061 .19507 L
s
.25353 .6251 m
.2576 .62533 L
s
.25353 .6251 m
.25305 .63109 L
s
.58814 .09006 m
.58455 .10675 L
s
.49975 .23398 m
.49699 .23358 L
s
.5005 .22438 m
.49975 .23398 L
s
.67316 .844 m
.67375 .84529 L
s
.67511 .8391 m
.67316 .844 L
s
.67934 .84399 m
.67316 .844 L
s
.90728 .87399 m
.91025 .87647 L
s
.91691 .86228 m
.90728 .87399 L
s
.92512 .8788 m
.90728 .87399 L
s
.91995 .86469 m
.91691 .86228 L
s
.91691 .86228 m
.92512 .8788 L
s
.6476 .4709 m
.64843 .47375 L
s
.64691 .47183 m
.6476 .4709 L
s
.6476 .4709 m
.64611 .47331 L
s
.64923 .47227 m
.6476 .4709 L
s
.64798 .48037 m
.6476 .4709 L
s
.2576 .62533 m
.26002 .63025 L
s
.25305 .63109 m
.26002 .63025 L
s
.6757 .84038 m
.67511 .8391 L
s
.67511 .8391 m
.67934 .84399 L
s
.64843 .47375 m
.64923 .47227 L
s
.64611 .47331 m
.64843 .47375 L
s
.182 .353 .563 r
.36198 .57372 m .37818 .58416 L p .39209 .61653 L F P
0 0 0 r
s
.173 .339 .54 r
.36198 .57372 m .37818 .58416 L .35995 .55303 L p F P
0 0 0 r
s
.173 .339 .54 r
.35995 .55303 m .35607 .55058 L .36198 .57372 L p F P
0 0 0 r
s
.262 .507 .794 r
.33075 .54302 m .35607 .55058 L .36198 .57372 L p F P
0 0 0 r
s
.69 .09 .12 r
.64691 .47183 m
.64611 .47331 L
s
.124 .252 .393 r
.4914 .39352 m .48029 .38675 L .48731 .39142 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.01 w
.43614 .48472 Mdot
.5 Mabswid
.68857 .20594 m
.6977 .20715 L
s
.68152 .20607 m
.68857 .20594 L
s
.68857 .20594 m
.69061 .19507 L
s
.106 .208 .346 r
.3959 .62102 m .39209 .61653 L .39123 .61038 L closepath p F P
0 0 0 r
s
.182 .353 .563 r
.37818 .58416 m .39123 .61038 L .39209 .61653 L p F P
0 0 0 r
s
.69 .09 .12 r
.67934 .84399 m
.67375 .84529 L
s
.6757 .84038 m
.67934 .84399 L
s
.65477 .83501 m
.67934 .84399 L
s
.64923 .47227 m
.64691 .47183 L
s
.25305 .63109 m
.2576 .62533 L
s
.128 .229 .363 r
.41368 .82452 m .41195 .79123 L .43167 .77238 L p F P
0 0 0 r
s
.128 .23 .366 r
.42909 .75114 m .43167 .77238 L .41195 .79123 L p F P
0 0 0 r
s
.128 .23 .366 r
.42534 .7402 m .42909 .75114 L p .41195 .79123 L F P
0 0 0 r
s
.176 .315 .481 r
.40875 .8273 m .41368 .82452 L .41195 .79123 L p F P
0 0 0 r
s
.69 .09 .12 r
.18604 .71752 m
.14083 .73742 L
s
.072 .134 .234 r
.40964 .65868 m .40725 .64055 L p .42127 .68904 L F P
0 0 0 r
s
.072 .134 .234 r
.42127 .68904 m .413 .67004 L .40964 .65868 L p F P
0 0 0 r
s
.08 .149 .264 r
.40964 .65868 m .3959 .62102 L .40725 .64055 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.67375 .84529 m
.6757 .84038 L
s
.5005 .22438 m
.49699 .23358 L
s
.49079 .22803 m
.5005 .22438 L
s
.077 .143 .253 r
.42024 .69942 m .413 .67004 L .42127 .68904 L closepath p F P
0 0 0 r
s
.148 .308 .468 r
.4914 .39352 m .51841 .39947 L p .46962 .37886 L F P
0 0 0 r
s
.148 .308 .468 r
.46962 .37886 m .48029 .38675 L .4914 .39352 L p F P
0 0 0 r
s
.69 .09 .12 r
.49699 .23358 m
.49079 .22803 L
s
.138 .236 .353 r
.73155 .66418 m .74408 .65248 L .73202 .6575 L closepath p F P
0 0 0 r
s
.136 .232 .349 r
.73155 .66418 m .73202 .6575 L p .70067 .69583 L F P
0 0 0 r
s
.131 .221 .332 r
.73202 .6575 m .74408 .65248 L .76301 .63661 L p F P
0 0 0 r
s
.69 .09 .12 r
.92512 .8788 m
.91025 .87647 L
s
.91995 .86469 m
.92512 .8788 L
s
.86741 .83152 m
.92512 .8788 L
s
.61553 .71578 m
.61448 .71608 L
s
.6144 .71315 m
.61553 .71578 L
s
.61553 .71578 m
.61288 .71507 L
s
.61599 .71416 m
.61553 .71578 L
s
.61005 .70994 m
.61553 .71578 L
s
.254 .493 .77 r
.35607 .55058 m .33075 .54302 L .31183 .51809 L p F P
0 0 0 r
s
.69 .09 .12 r
.4359 .82978 m
.4381 .83142 L
s
.43358 .83267 m
.4359 .82978 L
s
.4359 .82978 m
.43399 .83043 L
s
.6144 .71315 m
.61288 .71507 L
s
.61599 .71416 m
.6144 .71315 L
s
.074 .138 .242 r
.40725 .64055 m .3959 .62102 L .39123 .61038 L p F P
0 0 0 r
s
.69 .09 .12 r
.61288 .71507 m
.61448 .71608 L
s
.43578 .83433 m
.43358 .83267 L
s
.43358 .83267 m
.43399 .83043 L
s
.84632 .72626 m
.8404 .73235 L
s
.84975 .72755 m
.84632 .72626 L
s
.84632 .72626 m
.85041 .73588 L
s
.396 .772 1 r
.29248 .51878 m .28242 .51994 L .26282 .49729 L p F P
0 0 0 r
s
.424 .822 1 r
.23342 .50338 m .26282 .49729 L .28242 .51994 L p F P
0 0 0 r
s
.69 .09 .12 r
.6977 .20715 m
.69066 .2073 L
s
.69061 .19507 m
.6977 .20715 L
s
.8404 .73235 m
.84382 .73365 L
s
.85041 .73588 m
.8404 .73235 L
s
.61448 .71608 m
.61599 .71416 L
s
.394 .785 1 r
.61504 .42216 m .64732 .41693 L .64319 .41327 L p F P
0 0 0 r
s
.394 .785 1 r
.59906 .40865 m .61504 .42216 L p .64319 .41327 L F P
0 0 0 r
s
.368 .733 1 r
.56697 .41281 m .59906 .40865 L .61504 .42216 L p F P
0 0 0 r
s
.066 .123 .214 r
.42127 .68904 m .42024 .69942 L .42703 .73674 L p F P
0 0 0 r
s
.108 .201 .332 r
.42534 .7402 m .42703 .73674 L .42024 .69942 L p F P
0 0 0 r
s
.69 .09 .12 r
.21873 .5135 m
.22604 .51479 L
s
.22604 .51479 m
.22739 .51043 L
s
.22248 .51775 m
.22604 .51479 L
s
.39752 .71374 m
.38052 .71619 L
s
.64117 .12485 m
.66495 .02995 L
s
.4381 .83142 m
.43578 .83433 L
s
.43399 .83043 m
.4381 .83142 L
s
.69066 .2073 m
.68152 .20607 L
s
.68152 .20607 m
.69061 .19507 L
s
.074 .138 .242 r
.39123 .61038 m .38659 .59396 L p .40725 .64055 L F P
0 0 0 r
s
.1 .194 .327 r
.39123 .61038 m .37818 .58416 L .38659 .59396 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.43399 .83043 m
.43578 .83433 L
s
.85041 .73588 m
.84382 .73365 L
s
.84975 .72755 m
.85041 .73588 L
s
.82363 .70612 m
.85041 .73588 L
s
.21873 .5135 m
.22007 .50912 L
s
.21873 .5135 m
.22248 .51775 L
s
.69061 .19507 m
.69066 .2073 L
s
.124 .209 .315 r
.79531 .60886 m .79488 .61346 L .76301 .63661 L p F P
0 0 0 r
s
.381 .762 1 r
.68521 .41467 m .69489 .42213 L .72775 .41522 L p F P
0 0 0 r
s
.69 .09 .12 r
.39039 .35807 m
.40612 .3522 L
s
.152 .262 .389 r
.74408 .65248 m .76253 .64515 L p .73078 .68341 L F P
0 0 0 r
s
.152 .262 .389 r
.73078 .68341 m .73155 .66418 L .74408 .65248 L p F P
0 0 0 r
s
.141 .241 .36 r
.74408 .65248 m .76253 .64515 L .76301 .63661 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.60594 .3303 m
.61115 .33068 L
s
.60301 .32902 m
.60594 .3303 L
s
.60594 .3303 m
.60806 .32397 L
s
.136 .232 .349 r
.70067 .69583 m .7042 .69429 L .73155 .66418 L p F P
0 0 0 r
s
.147 .254 .378 r
.7042 .69429 m .73078 .68341 L .73155 .66418 L closepath p F P
0 0 0 r
s
.129 .263 .409 r
.46962 .37886 m .46436 .37617 L .48029 .38675 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.38468 .71791 m
.38331 .71707 L
s
.38331 .71707 m
.38317 .71349 L
s
.38331 .71707 m
.38052 .71619 L
s
.145 .248 .368 r
.76253 .64515 m .76301 .63661 L .79488 .61346 L p F P
0 0 0 r
s
.088 .163 .278 r
.42909 .75114 m .42534 .7402 L .42703 .73674 L closepath p F P
0 0 0 r
s
.143 .246 .368 r
.7005 .699 m .7042 .69429 L .70067 .69583 L closepath p F P
0 0 0 r
s
.135 .232 .35 r
.7005 .699 m .70067 .69583 L p .6704 .7359 L F P
0 0 0 r
s
.368 .718 1 r
.29248 .51878 m .31183 .51809 L .29243 .49414 L p F P
0 0 0 r
s
.368 .718 1 r
.29243 .49414 m .2865 .4944 L .29248 .51878 L p F P
0 0 0 r
s
.396 .772 1 r
.26282 .49729 m .2865 .4944 L .29248 .51878 L p F P
0 0 0 r
s
.69 .09 .12 r
.38317 .71349 m
.38455 .71433 L
s
.38317 .71349 m
.38052 .71619 L
s
.91025 .87647 m
.91995 .86469 L
s
.22007 .50912 m
.22739 .51043 L
s
.22248 .51775 m
.22739 .51043 L
s
.139 .59187 m
.10706 .63269 L
s
.84382 .73365 m
.84975 .72755 L
s
.40431 .35493 m
.40288 .35534 L
s
.40305 .35142 m
.40431 .35493 L
s
.40612 .3522 m
.40431 .35493 L
s
.61115 .33068 m
.60823 .3294 L
s
.60806 .32397 m
.61115 .33068 L
s
.56224 .58359 m
.56252 .58508 L
s
.56302 .5821 m
.56224 .58359 L
s
.56224 .58359 m
.56132 .58334 L
s
.56421 .58385 m
.56224 .58359 L
s
.56488 .58362 m
.56224 .58359 L
s
.40162 .35183 m
.40305 .35142 L
s
.40305 .35142 m
.40612 .3522 L
s
.154 .266 .396 r
.7042 .69429 m .73078 .68341 L p .69971 .72303 L F P
0 0 0 r
s
.154 .266 .396 r
.69971 .72303 m .7005 .699 L .7042 .69429 L p F P
0 0 0 r
s
.69 .09 .12 r
.22007 .50912 m
.22248 .51775 L
s
.38455 .71433 m
.38468 .71791 L
s
.38052 .71619 m
.38468 .71791 L
s
.60806 .32397 m
.60823 .3294 L
s
.60301 .32902 m
.60806 .32397 L
s
.60317 .35338 m
.60806 .32397 L
s
.38052 .71619 m
.38455 .71433 L
s
.135 .232 .35 r
.6704 .7359 m .67802 .73232 L .7005 .699 L p F P
0 0 0 r
s
.149 .258 .386 r
.67802 .73232 m .69971 .72303 L .7005 .699 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.56252 .58508 m
.56421 .58385 L
s
.56421 .58385 m
.56302 .5821 L
s
.145 .248 .368 r
.79488 .61346 m .79406 .6333 L .76253 .64515 L p F P
0 0 0 r
s
.69 .09 .12 r
.60823 .3294 m
.60301 .32902 L
s
.56302 .5821 m
.56132 .58334 L
s
.56132 .58334 m
.56252 .58508 L
s
.65716 .04757 m
.67308 .05216 L
s
.64718 .04607 m
.65716 .04757 L
s
.65716 .04757 m
.66495 .02995 L
s
.78671 .58903 m
.78543 .58925 L
s
.78508 .58501 m
.78671 .58903 L
s
.78671 .58903 m
.78283 .58786 L
s
.78768 .58639 m
.78671 .58903 L
s
.77942 .57947 m
.78671 .58903 L
s
.073 .136 .238 r
.42703 .73674 m .42916 .71656 L p .43388 .76799 L F P
0 0 0 r
s
.073 .136 .238 r
.43388 .76799 m .42909 .75114 L .42703 .73674 L p F P
0 0 0 r
s
.066 .123 .214 r
.42703 .73674 m .42916 .71656 L .42127 .68904 L p F P
0 0 0 r
s
.092 .174 .3 r
.38659 .59396 m .37818 .58416 L .35995 .55303 L p F P
0 0 0 r
s
.69 .09 .12 r
.40612 .3522 m
.40288 .35534 L
s
.40162 .35183 m
.40612 .3522 L
s
.40288 .35534 m
.40162 .35183 L
s
.151 .242 .311 r
.46436 .37617 m .4392 .35762 L .42351 .33695 L p F P
0 0 0 r
s
.69 .09 .12 r
.78508 .58501 m
.78283 .58786 L
s
.78768 .58639 m
.78508 .58501 L
s
.142 .246 .371 r
.66991 .74694 m .67802 .73232 L .6704 .7359 L closepath p F P
0 0 0 r
s
.127 .218 .334 r
.66991 .74694 m .6704 .7359 L p .6417 .77799 L F P
0 0 0 r
s
.383 .761 1 r
.56697 .41281 m .59906 .40865 L .5971 .40682 L p F P
0 0 0 r
s
.383 .761 1 r
.55023 .39792 m .56697 .41281 L p .5971 .40682 L F P
0 0 0 r
s
.341 .677 1 r
.51841 .39947 m .55023 .39792 L .56697 .41281 L p F P
0 0 0 r
s
.69 .09 .12 r
.78283 .58786 m
.78543 .58925 L
s
.128 .229 .363 r
.43167 .77238 m .43497 .80721 L .41368 .82452 L p F P
0 0 0 r
s
.69 .09 .12 r
.35141 .58775 m
.33715 .59795 L
s
.19558 .8471 m
.18896 .8421 L
s
.18896 .8421 m
.19275 .83076 L
s
.18896 .8421 m
.18436 .83815 L
s
.08 .137 .225 r
.6417 .77799 m .64036 .80653 L .61659 .82386 L p F P
0 0 0 r
s
.69 .09 .12 r
.78543 .58925 m
.78768 .58639 L
s
.158 .273 .404 r
.76209 .67166 m .76253 .64515 L .79406 .6333 L p F P
0 0 0 r
s
.152 .262 .389 r
.76253 .64515 m .76209 .67166 L .73078 .68341 L p F P
0 0 0 r
s
.69 .09 .12 r
.19275 .83076 m
.19939 .83572 L
s
.19275 .83076 m
.18436 .83815 L
s
.134 .231 .352 r
.65954 .76847 m .6417 .77799 L .64036 .80653 L p F P
0 0 0 r
s
.127 .218 .334 r
.6417 .77799 m .65954 .76847 L .66991 .74694 L p F P
0 0 0 r
s
.188 .327 .398 r
.41612 .66726 m .42127 .68904 L .42916 .71656 L p F P
0 0 0 r
s
.072 .134 .234 r
.40725 .64055 m .41612 .66726 L .42127 .68904 L p F P
0 0 0 r
s
.69 .09 .12 r
.34166 .59746 m
.34027 .59744 L
s
.34027 .59744 m
.33836 .59435 L
s
.34027 .59744 m
.33715 .59795 L
s
.077 .143 .251 r
.43167 .77238 m .42909 .75114 L .43388 .76799 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.33836 .59435 m
.33975 .59436 L
s
.33836 .59435 m
.33715 .59795 L
s
.152 .263 .394 r
.67802 .73232 m .69971 .72303 L p .66938 .76393 L F P
0 0 0 r
s
.152 .263 .394 r
.66938 .76393 m .66991 .74694 L .67802 .73232 L p F P
0 0 0 r
s
.134 .273 .425 r
.46436 .37617 m .46962 .37886 L .45148 .36386 L p F P
0 0 0 r
s
.134 .273 .425 r
.45148 .36386 m .4392 .35762 L .46436 .37617 L p F P
0 0 0 r
s
.69 .09 .12 r
.76869 .82556 m
.76375 .83271 L
s
.77167 .82763 m
.76869 .82556 L
s
.76869 .82556 m
.77421 .8347 L
s
.76375 .83271 m
.76672 .83481 L
s
.77421 .8347 m
.76375 .83271 L
s
.391 .78 1 r
.68521 .41467 m .66036 .4143 L .64732 .41693 L p F P
0 0 0 r
s
.404 .804 1 r
.66036 .4143 m .64319 .41327 L .64732 .41693 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.33975 .59436 m
.34166 .59746 L
s
.33715 .59795 m
.34166 .59746 L
s
.33715 .59795 m
.33975 .59436 L
s
.254 .493 .77 r
.31183 .51809 m .34123 .52496 L p .35607 .55058 L F P
0 0 0 r
s
.304 .589 .909 r
.34123 .52496 m .31183 .51809 L .29243 .49414 L p F P
0 0 0 r
s
.69 .09 .12 r
.67308 .05216 m
.66317 .05068 L
s
.66495 .02995 m
.67308 .05216 L
s
.15438 .74009 m
.14712 .7373 L
s
.14712 .7373 m
.14562 .72669 L
s
.14712 .7373 m
.14083 .73742 L
s
.77421 .8347 m
.76672 .83481 L
s
.77167 .82763 m
.77421 .8347 L
s
.74155 .812 m
.77421 .8347 L
s
.355 .705 1 r
.51841 .39947 m .55023 .39792 L .54341 .39135 L p F P
0 0 0 r
s
.355 .705 1 r
.50096 .38408 m .51841 .39947 L p .54341 .39135 L F P
0 0 0 r
s
.148 .308 .468 r
.51841 .39947 m .50096 .38408 L .46962 .37886 L p F P
0 0 0 r
s
.69 .09 .12 r
.31214 .81916 m
.27544 .81782 L
s
.381 .762 1 r
.72775 .41522 m .7249 .41293 L .68521 .41467 L p F P
0 0 0 r
s
.69 .09 .12 r
.55791 .22513 m
.57885 .17043 L
s
.57203 .18038 m
.58188 .18424 L
s
.5674 .17857 m
.57203 .18038 L
s
.57203 .18038 m
.57885 .17043 L
s
.074 .138 .242 r
.38659 .59396 m .39857 .6191 L .40725 .64055 L p F P
0 0 0 r
s
.194 .335 .409 r
.39857 .6191 m .40725 .64055 L .41612 .66726 L p F P
0 0 0 r
s
.69 .09 .12 r
.19939 .83572 m
.19558 .8471 L
s
.18436 .83815 m
.19558 .8471 L
s
.51928 .44652 m
.52012 .44941 L
s
.51843 .44743 m
.51928 .44652 L
s
.51928 .44652 m
.51773 .44896 L
s
.52082 .44789 m
.51928 .44652 L
s
.51926 .45604 m
.51928 .44652 L
s
.147 .255 .383 r
.65954 .76847 m .66938 .76393 L .66991 .74694 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.52012 .44941 m
.52082 .44789 L
s
.51773 .44896 m
.52012 .44941 L
s
.159 .317 .503 r
.35995 .55303 m .35607 .55058 L .35252 .54153 L closepath p F P
0 0 0 r
s
.254 .493 .77 r
.34123 .52496 m .35252 .54153 L .35607 .55058 L p F P
0 0 0 r
s
.69 .09 .12 r
.51843 .44743 m
.51773 .44896 L
s
.18436 .83815 m
.19939 .83572 L
s
.30484 .46051 m
.30377 .47489 L
s
.283 .559 .844 r
.50096 .38408 m .46962 .37886 L .45148 .36386 L p F P
0 0 0 r
s
.165 .286 .423 r
.73058 .71118 m .73078 .68341 L .76209 .67166 L p F P
0 0 0 r
s
.154 .266 .396 r
.73078 .68341 m .73058 .71118 L .69971 .72303 L p F P
0 0 0 r
s
.69 .09 .12 r
.73375 .43728 m
.73504 .44161 L
s
.73287 .43863 m
.73375 .43728 L
s
.73375 .43728 m
.73154 .44093 L
s
.73637 .43931 m
.73375 .43728 L
s
.73476 .45155 m
.73375 .43728 L
s
.175 .296 .367 r
.37651 .57224 m .38659 .59396 L .39857 .6191 L p F P
0 0 0 r
s
.092 .174 .3 r
.35995 .55303 m .37651 .57224 L .38659 .59396 L p F P
0 0 0 r
s
.69 .09 .12 r
.52082 .44789 m
.51843 .44743 L
s
.072 .134 .235 r
.43388 .76799 m .43167 .77238 L .43497 .80721 L p F P
0 0 0 r
s
.69 .09 .12 r
.14562 .72669 m
.15289 .72945 L
s
.14562 .72669 m
.14083 .73742 L
s
.73504 .44161 m
.73637 .43931 L
s
.73154 .44093 m
.73504 .44161 L
s
.423 .84 1 r
.68005 .40994 m .68521 .41467 L .7249 .41293 L p F P
0 0 0 r
s
.413 .821 1 r
.68005 .40994 m .66036 .4143 L .68521 .41467 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.73287 .43863 m
.73154 .44093 L
s
.58188 .18424 m
.57729 .18245 L
s
.57885 .17043 m
.58188 .18424 L
s
.427 .847 1 r
.66036 .4143 m .68005 .40994 L p .63161 .40206 L F P
0 0 0 r
s
.427 .847 1 r
.63161 .40206 m .64319 .41327 L .66036 .4143 L p F P
0 0 0 r
s
.69 .09 .12 r
.70505 .69735 m
.70696 .69679 L
s
.70473 .69146 m
.70696 .69679 L
s
.70168 .69533 m
.70696 .69679 L
s
.70696 .69679 m
.7081 .69347 L
s
.69653 .68476 m
.70696 .69679 L
s
.66317 .05068 m
.64718 .04607 L
s
.64718 .04607 m
.66495 .02995 L
s
.01 w
.52631 .81559 Mdot
.5 Mabswid
.76672 .83481 m
.77167 .82763 L
s
.416 .825 1 r
.63161 .40206 m .60294 .40796 L .64319 .41327 L closepath p F P
0 0 0 r
s
.394 .785 1 r
.64319 .41327 m .60294 .40796 L .59906 .40865 L p F P
0 0 0 r
s
.086 .16 .282 r
.37651 .57224 m .35995 .55303 L .35252 .54153 L p F P
0 0 0 r
s
.69 .09 .12 r
.73637 .43931 m
.73287 .43863 L
s
.423 .84 1 r
.7249 .41293 m .7132 .40179 L .68005 .40994 L p F P
0 0 0 r
s
.69 .09 .12 r
.70168 .69533 m
.70473 .69146 L
s
.70473 .69146 m
.7081 .69347 L
s
.15289 .72945 m
.15438 .74009 L
s
.14083 .73742 m
.15438 .74009 L
s
.70168 .69533 m
.70505 .69735 L
s
.66495 .02995 m
.66317 .05068 L
s
.134 .231 .352 r
.64036 .80653 m .64582 .80367 L .65954 .76847 L p F P
0 0 0 r
s
.152 .265 .398 r
.66938 .76393 m .65954 .76847 L .64582 .80367 L p F P
0 0 0 r
s
.69 .09 .12 r
.30543 .47347 m
.30176 .4728 L
s
.30621 .47121 m
.30543 .47347 L
s
.30377 .47489 m
.30543 .47347 L
s
.57885 .17043 m
.57729 .18245 L
s
.5674 .17857 m
.57885 .17043 L
s
.1211 .62879 m
.11227 .62927 L
s
.11227 .62927 m
.10597 .62004 L
s
.11227 .62927 m
.10706 .63269 L
s
.70505 .69735 m
.7081 .69347 L
s
.072 .134 .235 r
.43497 .80721 m .44021 .79709 L .43388 .76799 L p F P
0 0 0 r
s
.04 .075 .118 r
.43466 .74547 m .43388 .76799 L .44021 .79709 L p F P
0 0 0 r
s
.073 .136 .238 r
.42916 .71656 m .43466 .74547 L .43388 .76799 L p F P
0 0 0 r
s
.166 .288 .428 r
.69947 .75168 m .69971 .72303 L .73058 .71118 L p F P
0 0 0 r
s
.152 .263 .394 r
.69971 .72303 m .69947 .75168 L .66938 .76393 L p F P
0 0 0 r
s
.404 .801 1 r
.60294 .40796 m .5971 .40682 L .59906 .40865 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.30176 .4728 m
.30254 .47053 L
s
.30176 .4728 m
.30377 .47489 L
s
.158 .273 .404 r
.79406 .6333 m .79431 .66029 L .76209 .67166 L p F P
0 0 0 r
s
.69 .09 .12 r
.57729 .18245 m
.5674 .17857 L
s
.14083 .73742 m
.15289 .72945 L
s
.26519 .6926 m
.22873 .70789 L
s
.47167 .69277 m
.47257 .69216 L
s
.47257 .69216 m
.47172 .68982 L
s
.47257 .69216 m
.46955 .69195 L
s
.47172 .68982 m
.47083 .69044 L
s
.47172 .68982 m
.46955 .69195 L
s
.46955 .69195 m
.47167 .69277 L
s
.46955 .69195 m
.47083 .69044 L
s
.48032 .68869 m
.46955 .69195 L
s
.30254 .47053 m
.30621 .47121 L
s
.30377 .47489 m
.30621 .47121 L
s
.422 .834 1 r
.60294 .40796 m .63161 .40206 L p .58259 .3924 L F P
0 0 0 r
s
.422 .834 1 r
.58259 .3924 m .5971 .40682 L .60294 .40796 L p F P
0 0 0 r
s
.69 .09 .12 r
.30254 .47053 m
.30377 .47489 L
s
.086 .16 .282 r
.35252 .54153 m .34623 .52808 L p .37651 .57224 L F P
0 0 0 r
s
.151 .304 .481 r
.35252 .54153 m .34123 .52496 L .34623 .52808 L closepath p F P
0 0 0 r
s
.41 .812 1 r
.58259 .3924 m .55881 .39673 L .5971 .40682 L closepath p F P
0 0 0 r
s
.383 .761 1 r
.5971 .40682 m .55881 .39673 L .55023 .39792 L p F P
0 0 0 r
s
.69 .09 .12 r
.47083 .69044 m
.47167 .69277 L
s
.447 .882 1 r
.7132 .40179 m .68005 .40994 L .66462 .39402 L p F P
0 0 0 r
s
.427 .847 1 r
.68005 .40994 m .66462 .39402 L .63161 .40206 L p F P
0 0 0 r
s
.69 .09 .12 r
.6505 .55465 m
.65065 .55761 L
s
.65056 .55232 m
.6505 .55465 L
s
.6505 .55465 m
.64795 .55502 L
s
.65327 .55491 m
.6505 .55465 L
s
.65106 .55624 m
.6505 .55465 L
s
.69012 .28948 m
.6972 .28852 L
s
.6849 .28773 m
.69012 .28948 L
s
.69012 .28948 m
.6914 .27959 L
s
.161 .281 .419 r
.66894 .79323 m .66938 .76393 L .69947 .75168 L p F P
0 0 0 r
s
.152 .265 .398 r
.64582 .80367 m .66894 .79323 L .66938 .76393 L p F P
0 0 0 r
s
.69 .09 .12 r
.10597 .62004 m
.11481 .61954 L
s
.10597 .62004 m
.10706 .63269 L
s
.28402 .82377 m
.27974 .82066 L
s
.27974 .82066 m
.28169 .81242 L
s
.27974 .82066 m
.27544 .81782 L
s
.48214 .30763 m
.48675 .31017 L
s
.48103 .30653 m
.48214 .30763 L
s
.48214 .30763 m
.48657 .30364 L
s
.11481 .61954 m
.1211 .62879 L
s
.10706 .63269 m
.1211 .62879 L
s
.48675 .31017 m
.48565 .30907 L
s
.48657 .30364 m
.48675 .31017 L
s
.28169 .81242 m
.28598 .8155 L
s
.28169 .81242 m
.27544 .81782 L
s
.65065 .55761 m
.65327 .55491 L
s
.64795 .55502 m
.65065 .55761 L
s
.65056 .55232 m
.64795 .55502 L
s
.65327 .55491 m
.65056 .55232 L
s
.47318 .32718 m
.48657 .30364 L
s
.174 .301 .444 r
.76254 .69987 m .76209 .67166 L .79431 .66029 L p F P
0 0 0 r
s
.165 .286 .423 r
.76209 .67166 m .76254 .69987 L .73058 .71118 L p F P
0 0 0 r
s
.2 .349 .426 r
.42182 .69561 m .42916 .71656 L .43466 .74547 L p F P
0 0 0 r
s
.188 .327 .398 r
.42916 .71656 m .42182 .69561 L .41612 .66726 L p F P
0 0 0 r
s
.69 .09 .12 r
.48657 .30364 m
.48565 .30907 L
s
.48103 .30653 m
.48657 .30364 L
s
.304 .589 .909 r
.29243 .49414 m .32204 .49859 L .34123 .52496 L p F P
0 0 0 r
s
.392 .776 1 r
.55881 .39673 m .54341 .39135 L .55023 .39792 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.6914 .27959 m
.69199 .28677 L
s
.6914 .27959 m
.6972 .28852 L
s
.6849 .28773 m
.6914 .27959 L
s
.68965 .32233 m
.6914 .27959 L
s
.6972 .28852 m
.69199 .28677 L
s
.48565 .30907 m
.48103 .30653 L
s
.21777 .56476 m
.192 .59372 L
s
.69199 .28677 m
.6849 .28773 L
s
.42523 .56477 m
.42618 .56428 L
s
.42618 .56428 m
.42533 .56193 L
s
.42618 .56428 m
.42314 .56406 L
s
.42533 .56193 m
.42438 .56242 L
s
.42533 .56193 m
.42314 .56406 L
s
.10706 .63269 m
.11481 .61954 L
s
.42314 .56406 m
.42523 .56477 L
s
.42314 .56406 m
.42438 .56242 L
s
.43387 .56051 m
.42314 .56406 L
s
.28598 .8155 m
.28402 .82377 L
s
.27544 .81782 m
.28402 .82377 L
s
.23922 .70958 m
.23493 .70803 L
s
.23493 .70803 m
.23294 .70003 L
s
.23493 .70803 m
.22873 .70789 L
s
.8644 .81146 m
.8566 .82112 L
s
.87026 .81456 m
.8644 .81146 L
s
.8644 .81146 m
.87139 .82518 L
s
.27544 .81782 m
.28598 .8155 L
s
.142 .289 .457 r
.34623 .52808 m .34123 .52496 L .32204 .49859 L p F P
0 0 0 r
s
.69 .09 .12 r
.42438 .56242 m
.42523 .56477 L
s
.8566 .82112 m
.86242 .82427 L
s
.87139 .82518 m
.8566 .82112 L
s
.213 .371 .462 r
.40543 .64656 m .41612 .66726 L .42182 .69561 L p F P
0 0 0 r
s
.194 .335 .409 r
.41612 .66726 m .40543 .64656 L .39857 .6191 L p F P
0 0 0 r
s
.408 .808 1 r
.55881 .39673 m .58259 .3924 L p .53304 .38095 L F P
0 0 0 r
s
.408 .808 1 r
.53304 .38095 m .54341 .39135 L .55881 .39673 L p F P
0 0 0 r
s
.69 .09 .12 r
.87139 .82518 m
.86242 .82427 L
s
.87026 .81456 m
.87139 .82518 L
s
.8312 .78822 m
.87139 .82518 L
s
.23294 .70003 m
.23723 .70156 L
s
.23294 .70003 m
.22873 .70789 L
s
.176 .306 .452 r
.73099 .74028 m .73058 .71118 L .76254 .69987 L p F P
0 0 0 r
s
.166 .288 .428 r
.73058 .71118 m .73099 .74028 L .69947 .75168 L p F P
0 0 0 r
s
.448 .88 1 r
.66462 .39402 m .63161 .40206 L .61542 .38481 L p F P
0 0 0 r
s
.422 .834 1 r
.63161 .40206 m .61542 .38481 L .58259 .3924 L p F P
0 0 0 r
s
.69 .09 .12 r
.62057 .80042 m
.61897 .80104 L
s
.61884 .79643 m
.62057 .80042 L
s
.62057 .80042 m
.61651 .79939 L
s
.6213 .79808 m
.62057 .80042 L
s
.61218 .79193 m
.62057 .80042 L
s
.355 .705 1 r
.54341 .39135 m .52197 .38255 L .50096 .38408 L p F P
0 0 0 r
s
.363 .719 1 r
.52197 .38255 m .50096 .38408 L .48306 .36686 L p F P
0 0 0 r
s
.283 .559 .844 r
.45148 .36386 m .48306 .36686 L .50096 .38408 L p F P
0 0 0 r
s
.69 .09 .12 r
.61884 .79643 m
.61651 .79939 L
s
.6213 .79808 m
.61884 .79643 L
s
.213 .367 .459 r
.38627 .59818 m .39857 .6191 L .40543 .64656 L p F P
0 0 0 r
s
.175 .296 .367 r
.39857 .6191 m .38627 .59818 L .37651 .57224 L p F P
0 0 0 r
s
.69 .09 .12 r
.60461 .40732 m
.60632 .41316 L
s
.6031 .40907 m
.60461 .40732 L
s
.60153 .41223 m
.60461 .40732 L
s
.60461 .40732 m
.6079 .41001 L
s
.60461 .40732 m
.60512 .42641 L
s
.61651 .79939 m
.61897 .80104 L
s
.17745 .79929 m
.10912 .8157 L
s
.447 .882 1 r
.66462 .39402 m .69806 .385 L .7132 .40179 L p F P
0 0 0 r
s
.69 .09 .12 r
.60632 .41316 m
.6079 .41001 L
s
.60153 .41223 m
.60632 .41316 L
s
.086 .16 .282 r
.34623 .52808 m .3636 .55079 L .37651 .57224 L p F P
0 0 0 r
s
.132 .212 .273 r
.33373 .50581 m .34623 .52808 L .3636 .55079 L p F P
0 0 0 r
s
.142 .289 .457 r
.32204 .49859 m .33373 .50581 L .34623 .52808 L p F P
0 0 0 r
s
.69 .09 .12 r
.23723 .70156 m
.23922 .70958 L
s
.22873 .70789 m
.23922 .70958 L
s
.6031 .40907 m
.60153 .41223 L
s
.65363 .13083 m
.66698 .13262 L
s
.64604 .12788 m
.65363 .13083 L
s
.65363 .13083 m
.65964 .11481 L
s
.199 .342 .423 r
.3636 .55079 m .37651 .57224 L .38627 .59818 L p F P
0 0 0 r
s
.396 .783 1 r
.53304 .38095 m .52197 .38255 L .54341 .39135 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.61897 .80104 m
.6213 .79808 L
s
.80069 .67732 m
.79814 .6781 L
s
.79738 .6692 m
.80069 .67732 L
s
.80272 .67222 m
.80069 .67732 L
s
.22873 .70789 m
.23723 .70156 L
s
.04 .075 .118 r
.44021 .79709 m .43865 .77547 L .43466 .74547 L p F P
0 0 0 r
s
.175 .305 .451 r
.69971 .78147 m .69947 .75168 L .73099 .74028 L p F P
0 0 0 r
s
.161 .281 .419 r
.69947 .75168 m .69971 .78147 L .66894 .79323 L p F P
0 0 0 r
s
.69 .09 .12 r
.6079 .41001 m
.6031 .40907 L
s
.80272 .67222 m
.79738 .6692 L
s
.174 .301 .444 r
.79431 .66029 m .79534 .68885 L .76254 .69987 L p F P
0 0 0 r
s
.69 .09 .12 r
.79475 .67257 m
.79738 .6692 L
s
.79439 .66942 m
.79465 .66974 L
s
.79465 .66974 m
.80069 .67732 L
s
.78589 .65875 m
.79439 .66942 L
s
.79486 .67566 m
.80069 .67732 L
s
.86242 .82427 m
.87026 .81456 L
s
.20232 .59077 m
.19735 .59154 L
s
.19735 .59154 m
.19207 .58498 L
s
.19735 .59154 m
.192 .59372 L
s
.79488 .67625 m
.79814 .6781 L
s
.56053 .66717 m
.56135 .66888 L
s
.56183 .66373 m
.56053 .66717 L
s
.56053 .66717 m
.55903 .66588 L
s
.56415 .66674 m
.56053 .66717 L
s
.56586 .66281 m
.56053 .66717 L
s
.39426 .79562 m
.36817 .79712 L
s
.64408 .19181 m
.65964 .11481 L
s
.56183 .66373 m
.55903 .66588 L
s
.56415 .66674 m
.56183 .66373 L
s
.56135 .66888 m
.56415 .66674 L
s
.443 .87 1 r
.61542 .38481 m .58259 .3924 L .56566 .37437 L p F P
0 0 0 r
s
.408 .808 1 r
.58259 .3924 m .56566 .37437 L .53304 .38095 L p F P
0 0 0 r
s
.69 .09 .12 r
.01 w
.38695 .43104 Mdot
.5 Mabswid
.19207 .58498 m
.19704 .58419 L
s
.19207 .58498 m
.192 .59372 L
s
.66698 .13262 m
.65945 .12968 L
s
.65964 .11481 m
.66698 .13262 L
s
.79814 .6781 m
.80272 .67222 L
s
.55903 .66588 m
.56135 .66888 L
s
.37413 .80023 m
.3725 .79874 L
s
.3725 .79874 m
.37268 .79341 L
s
.3725 .79874 m
.36817 .79712 L
s
.12916 .67086 m
.06904 .70993 L
s
.37268 .79341 m
.37431 .79489 L
s
.37268 .79341 m
.36817 .79712 L
s
.19704 .58419 m
.20232 .59077 L
s
.192 .59372 m
.20232 .59077 L
s
.399 .789 1 r
.52197 .38255 m .53304 .38095 L .5154 .36247 L p F P
0 0 0 r
s
.399 .789 1 r
.5154 .36247 m .48948 .36636 L .52197 .38255 L p F P
0 0 0 r
s
.363 .719 1 r
.48306 .36686 m .48948 .36636 L .52197 .38255 L p F P
0 0 0 r
s
.214 .375 .465 r
.42939 .73201 m .43466 .74547 L .43865 .77547 L p F P
0 0 0 r
s
.2 .349 .426 r
.42354 .7073 m .42182 .69561 L p .43466 .74547 L F P
0 0 0 r
s
.2 .349 .426 r
.43466 .74547 m .42939 .73201 L .42354 .7073 L p F P
0 0 0 r
s
.183 .317 .468 r
.76351 .72932 m .76254 .69987 L .79534 .68885 L p F P
0 0 0 r
s
.176 .306 .452 r
.76254 .69987 m .76351 .72932 L .73099 .74028 L p F P
0 0 0 r
s
.456 .894 1 r
.69806 .385 m .66462 .39402 L .6487 .37596 L p F P
0 0 0 r
s
.448 .88 1 r
.61542 .38481 m .6487 .37596 L .66462 .39402 L p F P
0 0 0 r
s
.69 .09 .12 r
.65964 .11481 m
.65945 .12968 L
s
.64604 .12788 m
.65964 .11481 L
s
.74104 .52497 m
.74128 .52943 L
s
.74043 .52169 m
.74104 .52497 L
s
.74104 .52497 m
.73695 .52597 L
s
.74476 .52514 m
.74104 .52497 L
s
.74012 .52795 m
.74104 .52497 L
s
.65945 .12968 m
.64604 .12788 L
s
.192 .59372 m
.19704 .58419 L
s
.56451 .26306 m
.57264 .26411 L
s
.5616 .25996 m
.56451 .26306 L
s
.56451 .26306 m
.56922 .25376 L
s
.36817 .79712 m
.37413 .80023 L
s
.36817 .79712 m
.37431 .79489 L
s
.37431 .79489 m
.37413 .80023 L
s
.34696 .66685 m
.31827 .6778 L
s
.51108 .5294 m
.51164 .53248 L
s
.5137 .5275 m
.51108 .5294 L
s
.51108 .5294 m
.51045 .52905 L
s
.51488 .53093 m
.51108 .5294 L
s
.51908 .53236 m
.51108 .5294 L
s
.73695 .52597 m
.74128 .52943 L
s
.74043 .52169 m
.73695 .52597 L
s
.74128 .52943 m
.74476 .52514 L
s
.57264 .26411 m
.56976 .26102 L
s
.56922 .25376 m
.57264 .26411 L
s
.32561 .67892 m
.32448 .67806 L
s
.32448 .67806 m
.32244 .6723 L
s
.32448 .67806 m
.31827 .6778 L
s
.432 .848 1 r
.56566 .37437 m .53304 .38095 L .5154 .36247 L p F P
0 0 0 r
s
.69 .09 .12 r
.74476 .52514 m
.74043 .52169 L
s
.229 .4 .504 r
.42354 .7073 m .42182 .69561 L .41893 .6902 L closepath p F P
0 0 0 r
s
.213 .371 .462 r
.40605 .64996 m .40543 .64656 L p .42182 .69561 L F P
0 0 0 r
s
.213 .371 .462 r
.42182 .69561 m .41893 .6902 L .40605 .64996 L p F P
0 0 0 r
s
.69 .09 .12 r
.56922 .25376 m
.56976 .26102 L
s
.5616 .25996 m
.56922 .25376 L
s
.55871 .29526 m
.56922 .25376 L
s
.51164 .53248 m
.51488 .53093 L
s
.51488 .53093 m
.5137 .5275 L
s
.32244 .6723 m
.32356 .67314 L
s
.32244 .6723 m
.31827 .6778 L
s
.183 .318 .471 r
.7318 .77044 m .73099 .74028 L .76351 .72932 L p F P
0 0 0 r
s
.175 .305 .451 r
.73099 .74028 m .7318 .77044 L .69971 .78147 L p F P
0 0 0 r
s
.69 .09 .12 r
.5137 .5275 m
.51045 .52905 L
s
.51045 .52905 m
.51164 .53248 L
s
.71686 .78494 m
.71397 .78613 L
s
.71344 .77685 m
.71686 .78494 L
s
.71686 .78494 m
.70878 .78282 L
s
.71686 .78494 m
.71863 .78014 L
s
.70093 .76748 m
.71028 .77773 L
s
.71028 .77773 m
.71036 .77781 L
s
.71036 .77781 m
.71686 .78494 L
s
.56976 .26102 m
.5616 .25996 L
s
.31827 .6778 m
.32561 .67892 L
s
.31827 .6778 m
.32356 .67314 L
s
.23 .398 .504 r
.40605 .64996 m .40543 .64656 L .40392 .64411 L closepath p F P
0 0 0 r
s
.213 .367 .459 r
.38803 .60549 m .38627 .59818 L p .40543 .64656 L F P
0 0 0 r
s
.213 .367 .459 r
.40543 .64656 m .40392 .64411 L .38803 .60549 L p F P
0 0 0 r
s
.69 .09 .12 r
.70878 .78282 m
.71344 .77685 L
s
.71344 .77685 m
.71863 .78014 L
s
.32356 .67314 m
.32561 .67892 L
s
.70878 .78282 m
.71397 .78613 L
s
.454 .889 1 r
.6487 .37596 m .61542 .38481 L .59877 .36597 L p F P
0 0 0 r
s
.443 .87 1 r
.56566 .37437 m .59877 .36597 L .61542 .38481 L p F P
0 0 0 r
s
.253 .439 .561 r
.41893 .6902 m .40972 .67548 L p .42569 .72517 L F P
0 0 0 r
s
.253 .439 .561 r
.42569 .72517 m .42354 .7073 L .41893 .6902 L p F P
0 0 0 r
s
.246 .426 .544 r
.41893 .6902 m .40605 .64996 L .40972 .67548 L closepath p F P
0 0 0 r
s
.26 .447 .574 r
.40972 .67548 m .40605 .64996 L .40392 .64411 L p F P
0 0 0 r
s
.26 .447 .574 r
.40392 .64411 m .39172 .62619 L p .40972 .67548 L F P
0 0 0 r
s
.241 .416 .53 r
.40392 .64411 m .38803 .60549 L .39172 .62619 L closepath p F P
0 0 0 r
s
.217 .374 .469 r
.38803 .60549 m .38627 .59818 L .38068 .58985 L closepath p F P
0 0 0 r
s
.199 .342 .423 r
.36951 .56798 m .3636 .55079 L p .38627 .59818 L F P
0 0 0 r
s
.199 .342 .423 r
.38627 .59818 m .38068 .58985 L .36951 .56798 L p F P
0 0 0 r
s
.69 .09 .12 r
.29917 .53675 m
.2786 .55397 L
s
.239 .418 .53 r
.42939 .73201 m .42354 .7073 L .42569 .72517 L closepath p F P
0 0 0 r
s
.183 .317 .468 r
.79534 .68885 m .79683 .71858 L .76351 .72932 L p F P
0 0 0 r
s
.132 .212 .273 r
.3636 .55079 m .34875 .52935 L .33373 .50581 L p F P
0 0 0 r
s
.456 .894 1 r
.6487 .37596 m .68243 .36627 L .69806 .385 L p F P
0 0 0 r
s
.69 .09 .12 r
.69222 .36707 m
.69484 .37594 L
s
.69024 .36959 m
.69222 .36707 L
s
.68834 .37335 m
.69222 .36707 L
s
.69222 .36707 m
.69747 .37105 L
s
.6929 .37895 m
.69387 .39579 L
s
.69289 .37881 m
.6929 .37895 L
s
.69222 .36707 m
.69289 .37881 L
s
.71397 .78613 m
.71863 .78014 L
s
.12716 .82216 m
.11921 .81739 L
s
.11921 .81739 m
.11888 .8026 L
s
.11921 .81739 m
.10912 .8157 L
s
.69484 .37594 m
.69747 .37105 L
s
.68962 .37489 m
.69484 .37594 L
s
.189 .32 .395 r
.3636 .55079 m .36951 .56798 L .35052 .53456 L p F P
0 0 0 r
s
.189 .32 .395 r
.35052 .53456 m .34875 .52935 L .3636 .55079 L p F P
0 0 0 r
s
.69 .09 .12 r
.65352 .64185 m
.65378 .64506 L
s
.65356 .63635 m
.65352 .64185 L
s
.65352 .64185 m
.64924 .64079 L
s
.65811 .64062 m
.65352 .64185 L
s
.6543 .63606 m
.65352 .64185 L
s
.68828 .37328 m
.69024 .36959 L
s
.28517 .55252 m
.28374 .55286 L
s
.28374 .55286 m
.28027 .54852 L
s
.28374 .55286 m
.2786 .55397 L
s
.252 .441 .563 r
.42569 .72517 m .42939 .73201 L .43705 .77144 L p F P
0 0 0 r
s
.214 .375 .465 r
.43865 .77547 m .43705 .77144 L .42939 .73201 L p F P
0 0 0 r
s
.69 .09 .12 r
.28027 .54852 m
.2817 .54818 L
s
.28027 .54852 m
.2786 .55397 L
s
.11888 .8026 m
.12685 .8073 L
s
.11888 .8026 m
.10912 .8157 L
s
.254 .435 .558 r
.39172 .62619 m .38803 .60549 L .38068 .58985 L p F P
0 0 0 r
s
.69 .09 .12 r
.47208 .38615 m
.47336 .3906 L
s
.47068 .38745 m
.47208 .38615 L
s
.47208 .38615 m
.46966 .38988 L
s
.47439 .38817 m
.47208 .38615 L
s
.47181 .40057 m
.47208 .38615 L
s
.47336 .3906 m
.47439 .38817 L
s
.46966 .38988 m
.47336 .3906 L
s
.46584 .77742 m
.46723 .77634 L
s
.46723 .77634 m
.46593 .77277 L
s
.46723 .77634 m
.46258 .77604 L
s
.65356 .63635 m
.64924 .64079 L
s
.65811 .64062 m
.65356 .63635 L
s
.46593 .77277 m
.46454 .77385 L
s
.46593 .77277 m
.46258 .77604 L
s
.46258 .77604 m
.46584 .77742 L
s
.46258 .77604 m
.46454 .77385 L
s
.47914 .7713 m
.46258 .77604 L
s
.69024 .36959 m
.69747 .37105 L
s
.47068 .38745 m
.46966 .38988 L
s
.64924 .64079 m
.65378 .64506 L
s
.65378 .64506 m
.65811 .64062 L
s
.2786 .55397 m
.28517 .55252 L
s
.2786 .55397 m
.2817 .54818 L
s
.448 .878 1 r
.59877 .36597 m .56566 .37437 L .54829 .35501 L p F P
0 0 0 r
s
.432 .848 1 r
.5154 .36247 m .54829 .35501 L .56566 .37437 L p F P
0 0 0 r
s
.189 .327 .484 r
.76484 .75978 m .76351 .72932 L .79683 .71858 L p F P
0 0 0 r
s
.183 .318 .471 r
.76351 .72932 m .76484 .75978 L .7318 .77044 L p F P
0 0 0 r
s
.69 .09 .12 r
.25848 .77509 m
.20305 .78896 L
s
.2817 .54818 m
.28517 .55252 L
s
.47439 .38817 m
.47068 .38745 L
s
.46454 .77385 m
.46584 .77742 L
s
.08859 .70974 m
.07977 .70789 L
s
.07977 .70789 m
.07395 .69426 L
s
.07977 .70789 m
.06904 .70993 L
s
.254 .435 .558 r
.38068 .58985 m .37172 .57735 L p .39172 .62619 L F P
0 0 0 r
s
.224 .384 .486 r
.38068 .58985 m .36951 .56798 L .37172 .57735 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.12685 .8073 m
.12716 .82216 L
s
.10912 .8157 m
.12716 .82216 L
s
.46 .899 1 r
.68243 .36627 m .6487 .37596 L .63234 .35646 L p F P
0 0 0 r
s
.454 .889 1 r
.59877 .36597 m .63234 .35646 L .6487 .37596 L p F P
0 0 0 r
s
.252 .441 .563 r
.43705 .77144 m .4284 .75573 L .42569 .72517 L p F P
0 0 0 r
s
.307 .53 .686 r
.41252 .70552 m .42569 .72517 L .4284 .75573 L p F P
0 0 0 r
s
.253 .439 .561 r
.40972 .67548 m .41252 .70552 L .42569 .72517 L p F P
0 0 0 r
s
.69 .09 .12 r
.60103 .49395 m
.60116 .49998 L
s
.60333 .4916 m
.60103 .49395 L
s
.60103 .49395 m
.598 .495 L
s
.60648 .49658 m
.60103 .49395 L
s
.60718 .50326 m
.60103 .49395 L
s
.41379 .64876 m
.41575 .64758 L
s
.41575 .64758 m
.414 .64278 L
s
.40952 .64715 m
.41575 .64758 L
s
.64995 .21731 m
.66133 .21626 L
s
.64417 .21253 m
.64995 .21731 L
s
.64995 .21731 m
.65416 .2025 L
s
.414 .64278 m
.41203 .64395 L
s
.40952 .64715 m
.414 .64278 L
s
.07395 .69426 m
.08277 .69605 L
s
.07395 .69426 m
.06904 .70993 L
s
.10912 .8157 m
.12685 .8073 L
s
.81522 .76912 m
.8114 .77084 L
s
.81018 .75682 m
.81522 .76912 L
s
.81522 .76912 m
.80318 .76587 L
s
.81841 .76175 m
.81522 .76912 L
s
.233 .397 .506 r
.37172 .57735 m .36951 .56798 L .35052 .53456 L p F P
0 0 0 r
s
.69 .09 .12 r
.60116 .49998 m
.60648 .49658 L
s
.598 .495 m
.60116 .49998 L
s
.60648 .49658 m
.60333 .4916 L
s
.318 .546 .708 r
.395 .65555 m .40972 .67548 L .41252 .70552 L p F P
0 0 0 r
s
.26 .447 .574 r
.39172 .62619 m .395 .65555 L .40972 .67548 L p F P
0 0 0 r
s
.69 .09 .12 r
.40952 .64715 m
.43148 .64023 L
s
.40952 .64715 m
.41203 .64395 L
s
.40952 .64715 m
.41379 .64876 L
s
.20981 .64438 m
.15988 .67377 L
s
.41203 .64395 m
.41379 .64876 L
s
.81018 .75682 m
.80318 .76587 L
s
.81841 .76175 m
.81018 .75682 L
s
.60333 .4916 m
.598 .495 L
s
.08277 .69605 m
.08859 .70974 L
s
.06904 .70993 m
.08859 .70974 L
s
.65416 .2025 m
.65559 .21145 L
s
.65416 .2025 m
.66133 .21626 L
s
.64417 .21253 m
.65416 .2025 L
s
.64714 .26226 m
.65416 .2025 L
s
.66133 .21626 m
.65559 .21145 L
s
.80318 .76587 m
.8114 .77084 L
s
.21724 .79338 m
.21272 .79041 L
s
.21272 .79041 m
.21126 .77896 L
s
.21272 .79041 m
.20305 .78896 L
s
.314 .537 .697 r
.37609 .60581 m .39172 .62619 L .395 .65555 L p F P
0 0 0 r
s
.254 .435 .558 r
.37172 .57735 m .37609 .60581 L .39172 .62619 L p F P
0 0 0 r
s
.189 .327 .484 r
.79683 .71858 m .79864 .74929 L .76484 .75978 L p F P
0 0 0 r
s
.69 .09 .12 r
.79852 .74915 m
.79864 .74929 L
s
.79864 .74929 m
.81522 .76912 L
s
.79271 .7422 m
.79852 .74915 L
s
.457 .893 1 r
.63234 .35646 m .59877 .36597 L .58168 .34593 L p F P
0 0 0 r
s
.448 .878 1 r
.54829 .35501 m .58168 .34593 L .59877 .36597 L p F P
0 0 0 r
s
.69 .09 .12 r
.65559 .21145 m
.64417 .21253 L
s
.21126 .77896 m
.21578 .78188 L
s
.21126 .77896 m
.20305 .78896 L
s
.74859 .61596 m
.74863 .62076 L
s
.74744 .60818 m
.74859 .61596 L
s
.74859 .61596 m
.74163 .61511 L
s
.75444 .61382 m
.74859 .61596 L
s
.74576 .60839 m
.74859 .61596 L
s
.294 .502 .651 r
.35557 .5564 m .37172 .57735 L .37609 .60581 L p F P
0 0 0 r
s
.233 .397 .506 r
.35052 .53456 m .35557 .5564 L .37172 .57735 L p F P
0 0 0 r
s
.69 .09 .12 r
.06904 .70993 m
.08277 .69605 L
s
.55873 .75458 m
.56011 .75668 L
s
.56059 .74914 m
.55873 .75458 L
s
.55873 .75458 m
.55654 .7523 L
s
.56416 .75351 m
.55873 .75458 L
s
.5669 .74615 m
.55873 .75458 L
s
.8114 .77084 m
.81841 .76175 L
s
.46 .899 1 r
.63234 .35646 m .66637 .3462 L .68243 .36627 L p F P
0 0 0 r
s
.69 .09 .12 r
.37007 .51449 m
.37162 .51381 L
s
.37162 .51381 m
.37029 .51016 L
s
.37162 .51381 m
.3669 .51345 L
s
.37029 .51016 m
.36874 .51083 L
s
.37029 .51016 m
.3669 .51345 L
s
.3669 .51345 m
.37007 .51449 L
s
.3669 .51345 m
.36874 .51083 L
s
.38332 .5078 m
.3669 .51345 L
s
.56059 .74914 m
.55654 .7523 L
s
.56416 .75351 m
.56059 .74914 L
s
.56011 .75668 m
.56416 .75351 L
s
.55923 .3402 m
.56186 .34919 L
s
.55673 .34266 m
.55923 .3402 L
s
.55443 .3477 m
.55923 .3402 L
s
.56417 .34416 m
.55923 .3402 L
s
.55937 .35214 m
.55956 .36906 L
s
.55937 .352 m
.55937 .35214 L
s
.55923 .3402 m
.55937 .352 L
s
.56186 .34919 m
.56417 .34416 L
s
.55443 .3477 m
.56186 .34919 L
s
.36874 .51083 m
.37007 .51449 L
s
.55654 .7523 m
.56011 .75668 L
s
.1749 .67362 m
.17025 .67263 L
s
.17025 .67263 m
.16502 .66207 L
s
.17025 .67263 m
.15988 .67377 L
s
.21578 .78188 m
.21724 .79338 L
s
.20305 .78896 m
.21724 .79338 L
s
.74744 .60818 m
.74163 .61511 L
s
.75444 .61382 m
.74744 .60818 L
s
.74163 .61511 m
.74863 .62076 L
s
.55443 .3477 m
.55673 .34266 L
s
.20305 .78896 m
.21578 .78188 L
s
.74863 .62076 m
.75444 .61382 L
s
.16502 .66207 m
.16966 .66301 L
s
.16502 .66207 m
.15988 .67377 L
s
.50251 .6159 m
.50469 .6195 L
s
.50682 .61105 m
.50251 .6159 L
s
.50251 .6159 m
.50204 .61377 L
s
.50946 .61676 m
.50251 .6159 L
s
.51889 .6127 m
.50251 .6159 L
s
.307 .53 .686 r
.4284 .75573 m .41438 .73648 L .41252 .70552 L p F P
0 0 0 r
s
.69 .09 .12 r
.56417 .34416 m
.55673 .34266 L
s
.11881 .75398 m
.02879 .79173 L
s
.69306 .45768 m
.69341 .46679 L
s
.69479 .45465 m
.69306 .45768 L
s
.69306 .45768 m
.68771 .46036 L
s
.70049 .4611 m
.69306 .45768 L
s
.69832 .47315 m
.69306 .45768 L
s
.50469 .6195 m
.50946 .61676 L
s
.50946 .61676 m
.50682 .61105 L
s
.462 .902 1 r
.66637 .3462 m .63234 .35646 L .61554 .33585 L p F P
0 0 0 r
s
.457 .893 1 r
.58168 .34593 m .61554 .33585 L .63234 .35646 L p F P
0 0 0 r
s
.69 .09 .12 r
.50682 .61105 m
.50204 .61377 L
s
.339 .582 .756 r
.39701 .68596 m .41252 .70552 L .41438 .73648 L p F P
0 0 0 r
s
.318 .546 .708 r
.41252 .70552 m .39701 .68596 L .395 .65555 L p F P
0 0 0 r
s
.69 .09 .12 r
.50204 .61377 m
.50469 .6195 L
s
.16966 .66301 m
.1749 .67362 L
s
.15988 .67377 m
.1749 .67362 L
s
.15988 .67377 m
.16966 .66301 L
s
.69341 .46679 m
.70049 .4611 L
s
.68771 .46036 m
.69341 .46679 L
s
.30869 .76472 m
.30792 .76287 L
s
.30792 .76287 m
.30572 .75423 L
s
.30792 .76287 m
.29841 .76182 L
s
.34227 .75007 m
.29841 .76182 L
s
.30572 .75423 m
.30649 .75604 L
s
.30572 .75423 m
.29841 .76182 L
s
.34 .582 .757 r
.37858 .63553 m .395 .65555 L .39701 .68596 L p F P
0 0 0 r
s
.314 .537 .697 r
.395 .65555 m .37858 .63553 L .37609 .60581 L p F P
0 0 0 r
s
.69 .09 .12 r
.70049 .4611 m
.69479 .45465 L
s
.65667 .73272 m
.65706 .73648 L
s
.65669 .724 m
.65667 .73272 L
s
.65667 .73272 m
.65039 .73035 L
s
.66335 .73012 m
.65667 .73272 L
s
.65771 .72013 m
.65667 .73272 L
s
.69479 .45465 m
.68771 .46036 L
s
.332 .568 .738 r
.35907 .58523 m .37609 .60581 L .37858 .63553 L p F P
0 0 0 r
s
.294 .502 .651 r
.37609 .60581 m .35907 .58523 L .35557 .5564 L p F P
0 0 0 r
s
.69 .09 .12 r
.45697 .47211 m
.45773 .4768 L
s
.46153 .4697 m
.45697 .47211 L
s
.45697 .47211 m
.45662 .47151 L
s
.46264 .47499 m
.45697 .47211 L
s
.47037 .47785 m
.45697 .47211 L
s
.29841 .76182 m
.30869 .76472 L
s
.29841 .76182 m
.30649 .75604 L
s
.65669 .724 m
.65039 .73035 L
s
.66335 .73012 m
.65669 .724 L
s
.45773 .4768 m
.46264 .47499 L
s
.46264 .47499 m
.46153 .4697 L
s
.30649 .75604 m
.30869 .76472 L
s
.65039 .73035 m
.65706 .73648 L
s
.462 .902 1 r
.61554 .33585 m .64987 .32508 L .66637 .3462 L p F P
0 0 0 r
s
.69 .09 .12 r
.65706 .73648 m
.66335 .73012 L
s
.46153 .4697 m
.45662 .47151 L
s
.45662 .47151 m
.45773 .4768 L
s
.26268 .63755 m
.26211 .63667 L
s
.26211 .63667 m
.2581 .62849 L
s
.26211 .63667 m
.25216 .63702 L
s
.2932 .617 m
.25216 .63702 L
s
.2581 .62849 m
.25865 .62934 L
s
.2581 .62849 m
.25216 .63702 L
s
.5973 .58406 m
.59862 .59044 L
s
.60072 .57774 m
.5973 .58406 L
s
.5973 .58406 m
.59354 .583 L
s
.60579 .58517 m
.5973 .58406 L
s
.60934 .58422 m
.5973 .58406 L
s
.64848 .29315 m
.65251 .30677 L
s
.64518 .29661 m
.64848 .29315 L
s
.64848 .29315 m
.64134 .30445 L
s
.65639 .29895 m
.64848 .29315 L
s
.64988 .32532 m
.65036 .33647 L
s
.64987 .32508 m
.64988 .32532 L
s
.64848 .29315 m
.64987 .32508 L
s
.65251 .30677 m
.65639 .29895 L
s
.64134 .30445 m
.65251 .30677 L
s
.64518 .29661 m
.64134 .30445 L
s
.25216 .63702 m
.26268 .63755 L
s
.25216 .63702 m
.25865 .62934 L
s
.59862 .59044 m
.60579 .58517 L
s
.60579 .58517 m
.60072 .57774 L
s
.25865 .62934 m
.26268 .63755 L
s
.339 .582 .756 r
.41438 .73648 m .39823 .71727 L .39701 .68596 L p F P
0 0 0 r
s
.69 .09 .12 r
.60072 .57774 m
.59354 .583 L
s
.59354 .583 m
.59862 .59044 L
s
.40176 .73699 m
.40482 .73489 L
s
.40213 .72753 m
.40482 .73489 L
s
.39524 .73426 m
.40482 .73489 L
s
.75644 .71045 m
.75631 .71603 L
s
.75472 .69813 m
.75644 .71045 L
s
.75644 .71045 m
.74622 .70795 L
s
.76481 .70618 m
.75644 .71045 L
s
.75171 .69319 m
.75644 .71045 L
s
.65639 .29895 m
.64518 .29661 L
s
.39906 .7296 m
.40213 .72753 L
s
.39524 .73426 m
.40213 .72753 L
s
.39524 .73426 m
.40176 .73699 L
s
.39524 .73426 m
.39906 .7296 L
s
.40921 .73008 m
.42896 .72419 L
s
.40905 .73013 m
.40921 .73008 L
s
.39524 .73426 m
.40905 .73013 L
s
.356 .61 .793 r
.37996 .66626 m .39701 .68596 L .39823 .71727 L p F P
0 0 0 r
s
.34 .582 .757 r
.39701 .68596 m .37996 .66626 L .37858 .63553 L p F P
0 0 0 r
s
.69 .09 .12 r
.05415 .79554 m
.04536 .79126 L
s
.04536 .79126 m
.04015 .77258 L
s
.04536 .79126 m
.02879 .79173 L
s
.54886 .42995 m
.5485 .43906 L
s
.55379 .42749 m
.54886 .42995 L
s
.54886 .42995 m
.54538 .4313 L
s
.5569 .43525 m
.54886 .42995 L
s
.56046 .44685 m
.54886 .42995 L
s
.353 .604 .787 r
.3609 .61527 m .37858 .63553 L .37996 .66626 L p F P
0 0 0 r
s
.332 .568 .738 r
.37858 .63553 m .3609 .61527 L .35907 .58523 L p F P
0 0 0 r
s
.69 .09 .12 r
.39906 .7296 m
.40176 .73699 L
s
.04015 .77258 m
.04892 .77673 L
s
.04015 .77258 m
.02879 .79173 L
s
.75472 .69813 m
.74622 .70795 L
s
.76481 .70618 m
.75472 .69813 L
s
.20142 .72823 m
.12598 .75824 L
s
.74622 .70795 m
.75631 .71603 L
s
.5485 .43906 m
.5569 .43525 L
s
.5569 .43525 m
.55379 .42749 L
s
.35235 .60205 m
.35558 .60038 L
s
.35558 .60038 m
.35286 .59295 L
s
.35558 .60038 m
.34593 .59969 L
s
.54538 .4313 m
.5485 .43906 L
s
.69394 .55159 m
.69516 .56099 L
s
.69627 .5434 m
.69394 .55159 L
s
.69394 .55159 m
.68698 .55172 L
s
.70444 .55269 m
.69394 .55159 L
s
.70301 .55472 m
.69394 .55159 L
s
.35286 .59295 m
.34962 .59459 L
s
.35286 .59295 m
.34593 .59969 L
s
.34593 .59969 m
.35235 .60205 L
s
.34593 .59969 m
.34962 .59459 L
s
.35968 .59517 m
.3795 .58867 L
s
.34593 .59969 m
.35968 .59517 L
s
.75631 .71603 m
.76481 .70618 L
s
.55379 .42749 m
.54538 .4313 L
s
.49356 .70627 m
.49741 .71066 L
s
.49963 .69839 m
.49356 .70627 L
s
.49356 .70627 m
.49308 .70244 L
s
.50395 .70658 m
.49356 .70627 L
s
.51869 .69739 m
.49356 .70627 L
s
.04892 .77673 m
.05415 .79554 L
s
.02879 .79173 m
.05415 .79554 L
s
.34962 .59459 m
.35235 .60205 L
s
.49741 .71066 m
.50395 .70658 L
s
.50395 .70658 m
.49963 .69839 L
s
.49963 .69839 m
.49308 .70244 L
s
.14592 .76116 m
.14174 .75832 L
s
.14174 .75832 m
.13655 .74324 L
s
.14174 .75832 m
.12598 .75824 L
s
.69516 .56099 m
.70444 .55269 L
s
.70444 .55269 m
.69627 .5434 L
s
.68698 .55172 m
.69516 .56099 L
s
.02879 .79173 m
.04892 .77673 L
s
.69627 .5434 m
.68698 .55172 L
s
.356 .61 .793 r
.39823 .71727 m .38066 .69787 L .37996 .66626 L p F P
0 0 0 r
s
.69 .09 .12 r
.13655 .74324 m
.1407 .74598 L
s
.13655 .74324 m
.12598 .75824 L
s
.49308 .70244 m
.49741 .71066 L
s
.64261 .38692 m
.64216 .40078 L
s
.64745 .38394 m
.64261 .38692 L
s
.64261 .38692 m
.63587 .3906 L
s
.65371 .39414 m
.64261 .38692 L
s
.65377 .41474 m
.64261 .38692 L
s
.366 .627 .816 r
.36175 .64629 m .37996 .66626 L .38066 .69787 L p F P
0 0 0 r
s
.353 .604 .787 r
.37996 .66626 m .36175 .64629 L .3609 .61527 L p F P
0 0 0 r
s
.69 .09 .12 r
.44123 .56174 m
.44467 .5673 L
s
.44868 .55524 m
.44123 .56174 L
s
.44123 .56174 m
.44171 .55855 L
s
.45163 .56397 m
.44123 .56174 L
s
.46884 .55933 m
.44123 .56174 L
s
.44467 .5673 m
.45163 .56397 L
s
.45163 .56397 m
.44868 .55524 L
s
.59342 .67785 m
.59596 .68497 L
s
.59801 .66752 m
.59342 .67785 L
s
.59342 .67785 m
.5885 .67482 L
s
.60546 .67765 m
.59342 .67785 L
s
.61163 .66964 m
.59342 .67785 L
s
.64216 .40078 m
.65371 .39414 L
s
.63587 .3906 m
.64216 .40078 L
s
.44868 .55524 m
.44171 .55855 L
s
.65371 .39414 m
.64745 .38394 L
s
.1407 .74598 m
.14592 .76116 L
s
.12598 .75824 m
.14592 .76116 L
s
.12598 .75824 m
.1407 .74598 L
s
.44171 .55855 m
.44467 .5673 L
s
.64745 .38394 m
.63587 .3906 L
s
.23897 .72714 m
.23948 .72483 L
s
.23948 .72483 m
.23481 .71247 L
s
.23948 .72483 m
.22436 .72434 L
s
.59596 .68497 m
.60546 .67765 L
s
.60546 .67765 m
.59801 .66752 L
s
.23481 .71247 m
.23428 .71471 L
s
.23481 .71247 m
.22436 .72434 L
s
.59801 .66752 m
.5885 .67482 L
s
.28692 .70158 m
.22436 .72434 L
s
.5885 .67482 m
.59596 .68497 L
s
.53808 .52318 m
.53997 .53286 L
s
.54533 .51575 m
.53808 .52318 L
s
.53808 .52318 m
.53474 .52174 L
s
.55054 .52687 m
.53808 .52318 L
s
.56141 .52894 m
.53808 .52318 L
s
.22436 .72434 m
.23897 .72714 L
s
.22436 .72434 m
.23428 .71471 L
s
.69485 .64897 m
.69698 .65921 L
s
.69781 .63561 m
.69485 .64897 L
s
.69485 .64897 m
.68564 .64678 L
s
.70914 .64802 m
.69485 .64897 L
s
.70796 .64087 m
.69485 .64897 L
s
.366 .627 .816 r
.38066 .69787 m .36198 .67817 L .36175 .64629 L p F P
0 0 0 r
s
.69 .09 .12 r
.23428 .71471 m
.23897 .72714 L
s
.53997 .53286 m
.55054 .52687 L
s
.55054 .52687 m
.54533 .51575 L
s
.53474 .52174 m
.53997 .53286 L
s
.54533 .51575 m
.53474 .52174 L
s
.33375 .69406 m
.3388 .69104 L
s
.3388 .69104 m
.33461 .67966 L
s
.3388 .69104 m
.32396 .69003 L
s
.33461 .67966 m
.32953 .68262 L
s
.33461 .67966 m
.32396 .69003 L
s
.32396 .69003 m
.33375 .69406 L
s
.32396 .69003 m
.32953 .68262 L
s
.36198 .67817 m
.37547 .67397 L
s
.32396 .69003 m
.36198 .67817 L
s
.63654 .48398 m
.63802 .49819 L
s
.64316 .47498 m
.63654 .48398 L
s
.63654 .48398 m
.62926 .48446 L
s
.65188 .48872 m
.63654 .48398 L
s
.65736 .49743 m
.63654 .48398 L
s
.69781 .63561 m
.68564 .64678 L
s
.70914 .64802 m
.69781 .63561 L
s
.69698 .65921 m
.70914 .64802 L
s
.68564 .64678 m
.69698 .65921 L
s
.32953 .68262 m
.33375 .69406 L
s
.42479 .65529 m
.43099 .66212 L
s
.43526 .64458 m
.42479 .65529 L
s
.42479 .65529 m
.42587 .6496 L
s
.44036 .65705 m
.42479 .65529 L
s
.46724 .64536 m
.42479 .65529 L
s
.63802 .49819 m
.65188 .48872 L
s
.65188 .48872 m
.64316 .47498 L
s
.62926 .48446 m
.63802 .49819 L
s
.43099 .66212 m
.44036 .65705 L
s
.44036 .65705 m
.43526 .64458 L
s
.64316 .47498 m
.62926 .48446 L
s
.43526 .64458 m
.42587 .6496 L
s
.42587 .6496 m
.43099 .66212 L
s
.52688 .62011 m
.53106 .63087 L
s
.53652 .60766 m
.52688 .62011 L
s
.52688 .62011 m
.52311 .61598 L
s
.54443 .62251 m
.52688 .62011 L
s
.5624 .6157 m
.52688 .62011 L
s
.53106 .63087 m
.54443 .62251 L
s
.54443 .62251 m
.53652 .60766 L
s
.53652 .60766 m
.52311 .61598 L
s
.63025 .5845 m
.6337 .59971 L
s
.6387 .56945 m
.63025 .5845 L
s
.63025 .5845 m
.62164 .58199 L
s
.65072 .58716 m
.63025 .5845 L
s
.66116 .58491 m
.63025 .5845 L
s
.52311 .61598 m
.53106 .63087 L
s
.6337 .59971 m
.65072 .58716 L
s
.65072 .58716 m
.6387 .56945 L
s
.6387 .56945 m
.62164 .58199 L
s
.62164 .58199 m
.6337 .59971 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[308]:=",
  ImageSize->{400, 434.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3j
l>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40
oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`
iY00n_3V0@3oool00?l0n_3V2P3jl>H00`2`5ah0n_3V0?[`iP230?[`iP40oooo003o0?[`iPT0n_3V
0P2`5aj50?[`iP40oooo003o0?[`iPP0n_3V102`5aj40?[`iP40oooo003o0?[`iPL0n_3V00<0/1LN
0?[`iP2`5ah00P2`5aj40?[`iP40oooo003o0?[`iPH0n_3V00<0/1LN0?[`iP2`5ah00`2`5aj40?[`
iP40oooo003o0?[`iPD0n_3V00<0/1LN0?[`iP3jl>H00P2`5ah20?[`iP030;0G7P3jl>H0n_3V0840
n_3V0@3oool00?l0n_3V103jl>H00`2`5ah0n_3V0?[`iP030;0G7P80n_3V00<0/1LN0?[`iP3jl>H0
P@3jl>H10?ooo`00o`3jl>H30?[`iPL0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP210?[`iP40oooo003o
0?[`iPD0n_3V1`2`5ah00`3jl>H0/1LN0?[`iP210?[`iP40oooo003o0?[`iPP0n_3V1P2`5aj20?[`
iP40oooo003o0?[`iPL0n_3V00<0/1LN0?[`iP3jl>H0QP3jl>H10?ooo`00o`3jl>H70?[`iP030;0G
7P3jl>H0n_3V08H0n_3V0@3oool00?l0n_3V1`3jl>H00`2`5ah0n_3V0?[`iP260?[`iP40oooo003o
0?[`iPL0n_3V00<0/1LN0?[`iP3jl>H0QP3jl>H10?ooo`00o`3jl>H60?[`iP030;0G7P3jl>H0n_3V
08L0n_3V0@3oool00?l0n_3V1P3jl>H00`2`5ah0n_3V0?[`iP270?[`iP40oooo003o0?[`iPH0n_3V
00<0/1LN0?[`iP3jl>H0Q`3jl>H10?ooo`00o`3jl>H60?[`iP030;0G7P3jl>H0n_3V08L0n_3V0@3o
ool00?l0n_3V1@3jl>H00`2`5ah0n_3V0?[`iP280?[`iP40oooo003o0?[`iPD0n_3V00<0/1LN0?[`
iP3jl>H0R03jl>H10?ooo`00o`3jl>H50?[`iP030;0G7P3jl>H0n_3V08P0n_3V0@3oool00?l0n_3V
103jl>H00`2`5ah0n_3V0?[`iP290?[`iP40oooo003o0?[`iP@0n_3V00<0/1LN0?[`iP3jl>H0R@3j
l>H10?ooo`00o`3jl>H40?[`iP030;0G7P3jl>H0n_3V08T0n_3V0@3oool00>X0n_3V00<0/1LN0?[`
iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP290?[`iP40oooo003X0?[`iP<0/1LN5`3jl>H00`2`5ah0
n_3V0?[`iP2:0?[`iP40oooo003W0?[`iP040;0G7P3jl>H0/1LN0;0G7QL0n_3V00<0/1LN0?[`iP3j
l>H0RP3jl>H10?ooo`00i@3jl>H20;0G7P040?[`iP2`5ah0/1LN0;0G7QL0n_3V00<0/1LN0?[`iP3j
l>H0RP3jl>H10?ooo`00i03jl>H20;0G7P80n_3V0P2`5ah00`3jl>H0/1LN0?[`iP0E0?[`iP030;0G
7P3jl>H0n_3V08X0n_3V0@3oool00>D0n_3V1@2`5ah00`3jl>H0/1LN0?[`iP0D0?[`iP030;0G7P3j
l>H0n_3V08/0n_3V0@3oool00>L0n_3V0`2`5ah00`3jl>H0/1LN0?[`iP0D0?[`iP030;0G7P3jl>H0
n_3V08/0n_3V0@3oool00>L0n_3V00<0/1LN0?[`iP2`5ah00P2`5ahE0?[`iP030;0G7P3jl>H0n_3V
08/0n_3V0@3oool00>H0n_3V00<0/1LN0?[`iP3jl>H0603jl>H00`2`5ah0n_3V0?[`iP2;0?[`iP40
oooo003V0?[`iP030;0G7P3jl>H0n_3V01L0n_3V00<0/1LN0?[`iP3jl>H0S03jl>H10?ooo`00iP3j
l>H00`2`5ah0n_3V0?[`iP0G0?[`iP030;0G7P3jl>H0n_3V00@0n_3V00<0/1LN0?[`iP3jl>H02@3j
l>H00`2`5ah0n_3V0?[`iP1i0?[`iP40oooo003U0?[`iP030;0G7P3jl>H0n_3V01P0n_3V00<0/1LN
0?[`iP3jl>H00`3jl>H20;0G7PX0n_3V0P2`5aik0?[`iP40oooo003U0?[`iP030;0G7P3jl>H0n_3V
01P0n_3V00<0/1LN0?[`iP3jl>H00P3jl>H40;0G7PP0n_3V102`5aij0?[`iP40oooo003T0?[`iP03
0;0G7P3jl>H0n_3V01P0n_3V00@0/1LN0?[`iP3jl>H0n_3V1P2`5ah70?[`iP030;0G7P3jl>H0/1LN
0080/1LNNP3jl>H10?ooo`00i03jl>H00`2`5ah0n_3V0?[`iP0H0?[`iP040;0G7P3jl>H0n_3V0;0G
7P80n_3V0`2`5ah00`3jl>H0/1LN0?[`iP040?[`iP030;0G7P3jl>H0/1LN0080/1LN00<0n_3V0;0G
7P3jl>H0N03jl>H10?ooo`00h`3jl>H00`2`5ah0n_3V0?[`iP0K0?[`iP@0/1LN00D0n_3V0;0G7P2`
5ah0n_3V0;0G7P040?[`iP<0/1LN00<0n_3V0;0G7P2`5ah00P2`5aii0?[`iP40oooo003S0?[`iP03
0;0G7P3jl>H0n_3V01d0n_3V1P2`5ah00`3jl>H0/1LN0?[`iP050?[`iPH0/1LNN03jl>H10?ooo`00
hP3jl>H00`2`5ah0n_3V0?[`iP0P0?[`iP030;0G7P3jl>H0/1LN00<0/1LN1`3jl>H00`2`5ah0n_3V
0?[`iP1j0?[`iP40oooo003R0?[`iP030;0G7P3jl>H0n_3V0200n_3V00<0/1LN0?[`iP3jl>H02P3j
l>H00`2`5ah0n_3V0?[`iP1j0?[`iP40oooo003R0?[`iP030;0G7P3jl>H0n_3V0200n_3V00<0/1LN
0?[`iP3jl>H02P3jl>H00`2`5ah0n_3V0?[`iP1j0?[`iP40oooo003Q0?[`iP030;0G7P3jl>H0n_3V
0240n_3V00<0/1LN0?[`iP3jl>H02P3jl>H00`2`5ah0n_3V0?[`iP1j0?[`iP40oooo003Q0?[`iP03
0;0G7P3jl>H0n_3V0240n_3V00<0/1LN0?[`iP3jl>H02P3jl>H00`2`5ah0n_3V0?[`iP1j0?[`iP40
oooo003P0?[`iP030;0G7P3jl>H0n_3V0240n_3V00<0/1LN0?[`iP3jl>H02`3jl>H00`2`5ah0n_3V
0?[`iP1j0?[`iP40oooo003<0?[`iP80/1LN4P3jl>H00`2`5ah0n_3V0?[`iP0Q0?[`iP030;0G7P3j
l>H0n_3V00/0n_3V00<0/1LN0?[`iP3jl>H0NP3jl>H10?ooo`00b@3jl>H50;0G7Q40n_3V00<0/1LN
0?[`iP3jl>H08P3jl>H00`2`5ah0n_3V0?[`iP0:0?[`iP030;0G7P3jl>H0n_3V07/0n_3V0@3oool0
0<L0n_3V1`2`5ahA0?[`iP030;0G7P3jl>H0n_3V0280n_3V00<0/1LN0?[`iP3jl>H02P3jl>H00`2`
5ah0n_3V0?[`iP1k0?[`iP40oooo00380?[`iP030;0G7P3jl>H0/1LN0080/1LN4@3jl>H00`2`5ah0
n_3V0?[`iP0R0?[`iP030;0G7P3jl>H0n_3V00/0n_3V00<0/1LN0?[`iP3jl>H0N`3jl>H10?ooo`00
b03jl>H50;0G7Q40n_3V00<0/1LN0?[`iP3jl>H08P3jl>H00`2`5ah0n_3V0?[`iP0;0?[`iP030;0G
7P3jl>H0n_3V07/0n_3V0@3oool00<P0n_3V1@2`5ahf0?[`iP030;0G7P3jl>H0n_3V00/0n_3V00<0
/1LN0?[`iP3jl>H0N`3jl>H10?ooo`00a`3jl>H00`2`5ah0n_3V0?[`iP030;0G7SH0n_3V00<0/1LN
0?[`iP3jl>H02`3jl>H00`2`5ah0n_3V0?[`iP1k0?[`iP40oooo00360?[`iP030;0G7P3jl>H0n_3V
03T0n_3V00<0/1LN0?[`iP3jl>H0303jl>H00`2`5ah0n_3V0?[`iP1k0?[`iP40oooo00350?[`iP03
0;0G7P3jl>H0n_3V02d0n_3V00<0/1LN0?[`iP3jl>H02P3jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP03
0;0G7P3jl>H0n_3V07/0n_3V0@3oool00<D0n_3V00<0/1LN0?[`iP3jl>H07P3jl>H00`2`5ah0n_3V
0?[`iP0;0?[`iP80/1LN303jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP030;0G7P3jl>H0n_3V07/0n_3V
0@3oool00<@0n_3V00<0/1LN0?[`iP3jl>H07P3jl>H20;0G7P/0n_3V102`5ah<0?[`iP030;0G7P3j
l>H0n_3V00`0n_3V00<0/1LN0?[`iP3jl>H0N`3jl>H10?ooo`00``3jl>H00`2`5ah0n_3V0?[`iP0N
0?[`iP@0/1LN2@3jl>H40;0G7P030?[`iP2`5ah0n_3V00X0n_3V00<0/1LN0?[`iP3jl>H02`3jl>H0
0`2`5ah0n_3V0?[`iP1l0?[`iP40oooo00320?[`iP030;0G7P3jl>H0n_3V01h0n_3V1@2`5ah:0?[`
iPD0/1LN2P3jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP030;0G7P3jl>H0n_3V07`0n_3V0@3oool00<40
n_3V00<0/1LN0?[`iP3jl>H07P3jl>H60;0G7P/0n_3V0`2`5ah;0?[`iP030;0G7P3jl>H0n_3V00`0
n_3V00<0/1LN0?[`iP3jl>H0O03jl>H10?ooo`00`03jl>H00`2`5ah0n_3V0?[`iP0Q0?[`iP<0/1LN
00<0n_3V0;0G7P3jl>H02@3jl>H00`2`5ah0n_3V0?[`iP0;0?[`iP030;0G7P3jl>H0n_3V00`0n_3V
00<0/1LN0?[`iP3jl>H0O03jl>H10?ooo`00_`3jl>H00`2`5ah0n_3V0?[`iP0R0?[`iP030;0G7P3j
l>H0n_3V0080/1LN2P3jl>H00`2`5ah0n_3V0?[`iP0;0?[`iP030;0G7P3jl>H0n_3V00`0n_3V00<0
/1LN0?[`iP3jl>H0O03jl>H10?ooo`00_P3jl>H00`2`5ah0n_3V0?[`iP0R0?[`iP030;0G7P3jl>H0
n_3V00d0n_3V00<0/1LN0?[`iP3jl>H02P3jl>H00`2`5ah0n_3V0?[`iP2<0?[`iP40oooo002m0?[`
iP030;0G7P3jl>H0n_3V02<0n_3V00<0/1LN0?[`iP3jl>H0303jl>H00`2`5ah0n_3V0?[`iP0;0?[`
iP030;0G7P3jl>H0n_3V08`0n_3V0@3oool00><0n_3V00<0/1LN0?[`iP3jl>H0303jl>H00`2`5ah0
n_3V0?[`iP0;0?[`iP030;0G7P3jl>H0n_3V01T0n_3V00<0/1LN0?[`iP3jl>H0L03jl>H10?ooo`00
hP3jl>H00`2`5ah0n_3V0?[`iP0=0?[`iP030;0G7P3jl>H0n_3V01h0n_3V00<0/1LN0?[`iP3jl>H0
1@3jl>H30;0G7W40n_3V0@3oool00>80n_3V00<0/1LN0?[`iP3jl>H0303jl>H00`2`5ah0n_3V0?[`
iP0N0?[`iP<0/1LN1P3jl>H40;0G7W00n_3V0@3oool00>80n_3V00<0/1LN0?[`iP3jl>H0303jl>H0
0`2`5ah0n_3V0?[`iP0M0?[`iP@0/1LN1@3jl>H00`2`5ah0n_3V0;0G7P030;0G7Vl0n_3V0@3oool0
0:/0n_3V0`2`5ahc0?[`iP030;0G7P3jl>H0n_3V00d0n_3V00<0/1LN0?[`iP3jl>H04@3jl>H00`2`
5ah0n_3V0?[`iP090?[`iP<0/1LN00<0n_3V0;0G7P3jl>H00`3jl>H40;0G7P030?[`iP2`5ah0/1LN
06h0n_3V0@3oool00:/0n_3V0P2`5ah0103jl>H0/1LN0;0G7P2`5ah`0?[`iP030;0G7P3jl>H0n_3V
00`0n_3V00<0/1LN0?[`iP3jl>H04@3jl>H20;0G7PX0n_3V102`5ah00`3jl>H0/1LN0?[`iP020?[`
iP80/1LN0P3jl>H30;0G7Vl0n_3V0@3oool00:/0n_3V1@2`5aha0?[`iP030;0G7P3jl>H0n_3V00`0
n_3V00<0/1LN0?[`iP3jl>H0403jl>H40;0G7PP0n_3V202`5ah40?[`iP<0/1LNL@3jl>H10?ooo`00
ZP3jl>H60;0G7S00n_3V00<0/1LN0?[`iP3jl>H03@3jl>H00`2`5ah0n_3V0?[`iP0?0?[`iP030;0G
7P3jl>H0/1LN0080/1LN2`3jl>H00`2`5ah0n_3V0?[`iP080?[`iP030;0G7P3jl>H0n_3V06l0n_3V
0@3oool00:L0n_3V0`2`5ah20?[`iP<0/1LN<@3jl>H00`2`5ah0n_3V0?[`iP0=0?[`iP030;0G7P3j
l>H0n_3V00h0n_3V1P2`5ah;0?[`iP030;0G7P3jl>H0n_3V00P0n_3V00<0/1LN0?[`iP3jl>H0K`3j
l>H10?ooo`00Y03jl>H30;0G7SP0n_3V00<0/1LN0?[`iP3jl>H03@3jl>H00`2`5ah0n_3V0?[`iP0@
0?[`iP<0/1LN00<0n_3V0;0G7P2`5ah02P3jl>H00`2`5ah0n_3V0?[`iP080?[`iP030;0G7P3jl>H0
n_3V06l0n_3V0@3oool00:80n_3V0P2`5ahd0?[`iP030;0G7P3jl>H0n_3V00@0n_3V00<0/1LN0?[`
iP3jl>H03@3jl>H00`2`5ah0n_3V0?[`iP0A0?[`iPD0/1LN2P3jl>H00`2`5ah0n_3V0?[`iP080?[`
iP030;0G7P3jl>H0n_3V06l0n_3V0@3oool00:00n_3V0P2`5ah200000380n_3V0`2`5ah60?[`iP03
0;0G7P3jl>H0n_3V0280n_3V00<0/1LN0?[`iP3jl>H02`3jl>H00`2`5ah0n_3V0?[`iP090?[`iP03
0;0G7P3jl>H0n_3V06h0n_3V0@3oool009h0n_3V0P2`5ah20?[`iP030000001PY=H0000002l0n_3V
1@2`5ah50?[`iP030;0G7P3jl>H0n_3V02<0n_3V00<0/1LN0?[`iP3jl>H02`3jl>H00`2`5ah0n_3V
0?[`iP090?[`iP030;0G7P3jl>H0n_3V06h0n_3V0@3oool00:80n_3V00@00000062TeP1PY=H00000
803jl>H20;0G7Pd0n_3V0P2`5ah00`3jl>H0/1LN0?[`iP040?[`iP030;0G7P3jl>H0n_3V02<0n_3V
00<0/1LN0?[`iP3jl>H02`3jl>H00`2`5ah0n_3V0?[`iP090?[`iP030;0G7P3jl>H0n_3V06h0n_3V
0@3oool00:80n_3V00D00000062TeP1PY=H0H:CF0000000L0?[`iPD0/1LN3@3jl>H30;0G7R`0n_3V
00<0/1LN0?[`iP3jl>H02`3jl>H00`2`5ah0n_3V0?[`iP090?[`iP030;0G7P3jl>H0n_3V06h0n_3V
0@3oool00:80n_3V00<00000062TeP1PY=H00P1PY=H00`000000n_3V0?[`iP0J0?[`iP@0/1LN303j
l>H00`2`5ah0n_3V0?[`iP0]0?[`iP030;0G7P3jl>H0n_3V00/0n_3V00<0/1LN0?[`iP3jl>H02@3j
l>H00`2`5ah0n_3V0?[`iP1^0?[`iP40oooo002S0?[`iP030000001PY=H0H:CF0080H:CF00<00000
0?[`iP3jl>H06P3jl>H30;0G7P/0n_3V00<0/1LN0?[`iP3jl>H0;@3jl>H00`2`5ah0n_3V0?[`iP0<
0?[`iP030;0G7P3jl>H0n_3V00T0n_3V00<0/1LN0?[`iP3jl>H0KP3jl>H10?ooo`00X`3jl>H00`00
0000H:CF062TeP03062TeP030000003jl>H0n_3V01P0n_3V00@0/1LN0?[`iP3jl>H0/1LN2`3jl>H0
0`2`5ah0n_3V0?[`iP0]0?[`iP030;0G7P3jl>H0n_3V00`0n_3V00<0/1LN0?[`iP3jl>H02@3jl>H0
0`2`5ah0n_3V0?[`iP1^0?[`iP40oooo002S0?[`iP030000001PY=H0H:CF00@0H:CF00<000000?[`
iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP030;0G7P3jl>H0n_3V02X0n_3V00D0/1LN0?[`
iP3jl>H0n_3V0;0G7P0>0?[`iP030;0G7P3jl>H0n_3V00X0n_3V00<0/1LN0?[`iP3jl>H0K@3jl>H1
0?ooo`00X`3jl>H00`000000H:CF062TeP04062TeP8000005P3jl>H00`2`5ah0n_3V0?[`iP0<0?[`
iP030;0G7P3jl>H0n_3V02X0n_3V0`2`5ah20?[`iP030;0G7P3jl>H0n_3V00/0n_3V00<0/1LN0?[`
iP3jl>H02`3jl>H00`2`5ah0n_3V0?[`iP1]0?[`iP40oooo002S0?[`iP030000001PY=H0H:CF00@0
H:CF00<00000062Se@0000005@3jl>H00`2`5ah0n_3V0?[`iP0;0?[`iP030;0G7P3jl>H0n_3V02X0
n_3V102`5ah20?[`iP030;0G7P3jl>H0n_3V00/0n_3V00<0/1LN0?[`iP3jl>H02`3jl>H00`2`5ah0
n_3V0?[`iP1]0?[`iP40oooo002S0?[`iP8000001@1PY=H010000000H:?E062Se@00000C0?[`iP03
0;0G7P3jl>H0n_3V00`0n_3V00<0/1LN0?[`iP3jl>H0803jl>H00`2`5ah0n_3V0?[`iP060?[`iP80
/1LN00H0n_3V0;0G7P2`5ah0/1LN0?[`iP2`5ah=0?[`iP030;0G7P3jl>H0n_3V00/0n_3V00<0/1LN
0?[`iP3jl>H0K@3jl>H10?ooo`00X`3jl>H00`000000GYoA00000004062TeP050000001PXmD0H:?E
062Se@0000004@3jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP030;0G7P3jl>H0n_3V01l0n_3V102`5ah9
0?[`iP<0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP0;0?[`iP030;0G7P3jl>H0n_3V07/0n_3V0@3oool0
0:<0n_3V00@0000005jOd@1NWm4000000`1PY=H00`000000H:?E062Se@02062Se@030000003jl>H0
n_3V00d0n_3V00<0/1LN0?[`iP3jl>H0;P3jl>H50;0G7PX0n_3V00D0/1LN0?[`iP3jl>H0n_3V0;0G
7P0=0?[`iP030;0G7P3jl>H0n_3V07/0n_3V0@3oool007l0n_3V102`5ah<0?[`iP<0/1LN4@3jl>H0
10000000GYoA05jOd@000003062TeP030000001PXmD0H:?E00<0H:?E00<000000?[`iP3jl>H0303j
l>H00`2`5ah0n_3V0?[`iP0`0?[`iP@0/1LN2@3jl>H0102`5ah0n_3V0?[`iP2`5ah>0?[`iP030;0G
7P3jl>H0n_3V07/0n_3V0@3oool008<0n_3V1`2`5ah50?[`iP@0/1LN403jl>H01@000000GYoA05jO
d@1NWm4000000080H:CF00<00000062Se@1PXmD0101PXmD00`000000n_3V0?[`iP0:0?[`iP030;0G
7P3jl>H0n_3V0280n_3V00<0/1LN0?[`iP3jl>H0303jl>H00`2`5ah0n_3V0?[`iP0:0?[`iP040;0G
7P3jl>H0n_3V0;0G7X`0n_3V0@3oool008X0n_3V2P2`5ah?0?[`iP030000001NWm40GYoA0080GYoA
00<00000062TeP0000001`1PXmD00`000000n_3V0?[`iP080?[`iP030;0G7P3jl>H0n_3V0240n_3V
0`2`5ah>0?[`iP030;0G7P3jl>H0n_3V00X0n_3V00@0/1LN0?[`iP3jl>H0/1LNS03jl>H10?ooo`00
S`3jl>H00`2`5ah0n_3V0;0G7P030;0G7Ph0n_3V00<0000005jOd@1NWm400`1NWm42000000L0H:?E
0P00000/0?[`iP@0/1LN3@3jl>H00`2`5ah0n_3V0?[`iP0;0?[`iP040;0G7P3jl>H0n_3V0;0G7X`0
n_3V0@3oool008l0n_3V102`5ah@0?[`iP030000001NWm40GYoA00@0GYoA00<00000062Se@1PXmD0
1@1PXmD00`000000Gj7D0000000/0?[`iP@0/1LN303jl>H00`2`5ah0n_3V0?[`iP0;0?[`iP040;0G
7P3jl>H0n_3V0;0G7X`0n_3V0@3oool00:<0n_3V00<0000005jOd@1NWm40101NWm42000000H0H:?E
00@0000005nQe01OXM@000000P3jl>H30;0G7RL0n_3V0`2`5ah<0?[`iP030;0G7P3jl>H0n_3V00/0
n_3V00<0/1LN0?[`iP3jl>H0S@3jl>H10?ooo`00X`3jl>H2000000D0GYoA00<0000005fNc`000000
1@1PXmD01P000000Gj7D05nQe01OXM@000000?[`iPD0/1LN903jl>H00`2`5ah0n_3V0?[`iP0=0?[`
iP030;0G7P3jl>H0n_3V00/0n_3V00<0/1LN0?[`iP3jl>H08`3jl>H30;0G7VL0n_3V0@3oool00:<0
n_3V00<0000005ZHa`000000101NWm4010000000GIk?05fNc`000004062Se@030000001OXM@0Gj7D
0080Gj7D00<000000?[`iP2`5ah00P2`5ahU0?[`iP030;0G7P3jl>H0n_3V00`0n_3V00<0/1LN0?[`
iP3jl>H0303jl>H00`2`5ah0n_3V0?[`iP0M0?[`iP030;0G7P3jl>H0n_3V00<0n_3V1@2`5aiU0?[`
iP40oooo002S0?[`iP040000001JV<L0FYS7000000<0GYoA00D0000005fNc`1MW/l0GIk?00000003
062Se@050000001OXM@0Gj7D0;0G7P1OXM@0102`5ahV0?[`iP030;0G7P3jl>H0n_3V00`0n_3V00<0
/1LN0?[`iP3jl>H0303jl>H00`2`5ah0n_3V0?[`iP0L0?[`iP<0/1LN0`3jl>H30;0G7P030?[`iP2`
5ah0n_3V06D0n_3V0@3oool00:<0n_3V00<0000005ZHa`2`5ah00P2`5ah305jOd@050000001MW/l0
GIk?05fNc`0000000P1PXmD00`000000Gj7D05nQe00405nQe0030000003jl>H0n_3V02@0n_3V00<0
/1LN0?[`iP3jl>H03@3jl>H00`2`5ah0n_3V0?[`iP0[0?[`iP80/1LN00H0n_3V0;0G7P3jl>H0n_3V
0;0G7P3jl>H30;0G7VH0n_3V0@3oool00:<0n_3V00<0000005ZHa`2`5ah0102`5ah00`1NWm400000
05fNc`0305fNc`030000001PXmD0000000L0Gj7D00<000000?[`iP3jl>H08`3jl>H00`2`5ah0n_3V
0?[`iP0=0?[`iP030;0G7P3jl>H0n_3V02X0n_3V00<0/1LN0?[`iP2`5ah00`2`5ah20?[`iP@0/1LN
IP3jl>H10?ooo`00Y03jl>H00`000000FYS70;0G7P020;0G7P030000001NWm40000000D0GIk?0P00
000705nQe0800000903jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP030;0G7P3jl>H0n_3V0240n_3V00<0
/1LN0?[`iP3jl>H01`3jl>H40;0G7PH0n_3V0P2`5aiV0?[`iP40oooo001R0?[`iP030;0G7P3jl>H0
n_3V03h0n_3V1@2`5ah205ZHa`8000001P1MW/l00`000000Gj7D05nQe00505nQe0030000001OWm80
000002<0n_3V00<0/1LN0?[`iP2`5ah0303jl>H00`2`5ah0n_3V0?[`iP0P0?[`iP<0/1LN2`3jl>H0
0`2`5ah0n_3V0?[`iP060?[`iP030;0G7P3jl>H0n_3V06<0n_3V0@3oool006<0n_3V0P2`5ahj0?[`
iP@0/1LN00<0n_3V0000001JV<L01@1JV<L00`000000GIk?05fNc`0405fNc`8000001P1OXM@01000
0000GioB05nOdP00000Q0?[`iP@0/1LN303jl>H00`2`5ah0n_3V0?[`iP0P0?[`iP@0/1LN2P3jl>H0
0`2`5ah0n_3V0?[`iP070?[`iP030;0G7P3jl>H0n_3V0680n_3V0@3oool006D0n_3V0P2`5ahf0?[`
iP80/1LN1@3jl>H00`000000FYS705ZHa`0405ZHa`8000001@1MW/l00`000000GIc=0000000505nQ
e0050000001OWm80GioB05nOdP000000803jl>H00`2`5ah0n_3V0;0G7P020;0G7Rd0n_3V1P2`5ah9
0?[`iP030;0G7P3jl>H0n_3V00L0n_3V00<0/1LN0?[`iP3jl>H0HP3jl>H10?ooo`00I`3jl>H20;0G
7S/0n_3V00<0000005ZHa`1JV<L0101JV<L00`000000FIK50000000405fNc`040000001MW<d0GIc=
000000@0Gj7D00<0000005nOdP1OWm800P1OWm800`000000n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0
n_3V00L0n_3V00<0/1LN0?[`iP2`5ah0<03jl>H30;0G7P/0n_3V00<0/1LN0?[`iP3jl>H01`3jl>H0
0`000000/1LN0?[`iP1R0?[`iP40oooo001Y0?[`iP80/1LN>@3jl>H2000000D0FYS700@0000005VF
a@1IU/D000000`1MW/l010000000GIc=05fLc@1MW<d200000080Gj7D00<0000005nOdP1OWm800`1O
Wm800`000000n_3V0?[`iP0@0?[`iP<0/1LN203jl>H00`2`5ah0n_3V0;0G7P0Q0?[`iP030;0G7P3j
l>H0n_3V00h0n_3V00<0/1LN0?[`iP3jl>H02P3jl>H00`2`5ah0n_3V0?[`iP040?[`iP<0000000<0
<eR10000002`5ah0HP3jl>H10?ooo`00J`3jl>H20;0G7SL0n_3V00<0000005>;]P000000101JV<L0
1@000000FIK505VFa@1IU/D0000000<0GIk?00<0000005fLc@1MW<d00P1MW<d00`000000Gj7D0000
000605nOdP030000003jl>H0n_3V00h0n_3V00@0/1LN0?[`iP2`5ah0/1LN203jl>H00`2`5ah0n_3V
0;0G7P0P0?[`iP<0/1LN3`3jl>H00`2`5ah0n_3V0?[`iP0:0?[`iP040;0G7P3jl>H0n_3V0?[`iP<0
0000100cF8400`000000/1LN0?[`iP1Q0?[`iP40oooo001]0?[`iP80/1LN1P3jl>H00`2`5ah0n_3V
0?[`iP0]0?[`iP030000001CRkH0000000<0FYS700<0000005VFa@1IU/D00P1IU/D010000000GIk?
05fNc`00000505fLc@8000001`1OWm800`000000n_3V0?[`iP0>0?[`iP<0/1LN2P3jl>H00`2`5ah0
n_3V0?[`iP0N0?[`iP@0/1LN3P3jl>H00`2`5ah0n_3V0?[`iP0:0?[`iP040;0G7P00000000000000
00L0<eR100<000000?[`iP2`5ah0H@3jl>H10?ooo`00K`3jl>H20;0G7P<0n_3V00@0/1LN0?[`iP2`
5ah0/1LN;@3jl>H010000000Dh^f05>;]P00000305ZHa`030000001IU/D0FIK50080FIK500<00000
05fNc`0000001P1MW<d00`000000GioB05nOdP0505nOdP<000003P3jl>H00`2`5ah0n_3V0?[`iP09
0?[`iP030;0G7P3jl>H0n_3V01h0n_3V00<0/1LN0?[`iP2`5ah00`2`5ah=0?[`iP030;0G7P3jl>H0
n_3V00P0n_3V0P0000000`2`5ah0<eR103=HP@0803=HP@030000003jl>H0n_3V0640n_3V0@3oool0
0740n_3V0P2`5ah00`3jl>H0/1LN0?[`iP020;0G7Rd0n_3V00D0000005>;]P1CRkH0Dh^f00000002
05ZHa`030000001IU/D0FIK500<0FIK50P00000605fLc@8000001P1OWm80102`5ah0GI_>05fKcP00
000<0?[`iP030;0G7P3jl>H0n_3V00X0n_3V00<0/1LN0?[`iP3jl>H07P3jl>H01P2`5ah0n_3V0;0G
7P2`5ah0n_3V0;0G7Pd0n_3V00<0/1LN0?[`iP3jl>H01@3jl>H30000000403=HP@000000<eR10;0G
7PX0<eR100<000000?[`iP3jl>H0H03jl>H10?ooo`00L`3jl>H20;0G7P040?[`iP2`5ah0/1LN0;0G
7R`0n_3V00<0000005>;]P1CRkH00P1CRkH00`000000FYS70000000605VFa@030000001MW<d0GIc=
00@0GIc=00<0000005^IbP0000000`1OWm830;0G7P<0GI_>00<000000?[`iP3jl>H0203jl>H00`2`
5ah0n_3V0?[`iP0[0?[`iP@0/1LN00<0n_3V0;0G7P3jl>H03@3jl>H00`2`5ah0n_3V0?[`iP020?[`
iP<00000100cF8400`000000<eR10;0G7P0:03=HP@030000003jl>H0n_3V0600n_3V0@3oool007<0
n_3V00H0/1LN0?[`iP2`5ah0/1LN0?[`iP2`5ahI0?[`iP<0/1LN4@3jl>H00`000000Dh^f05>;]P02
05>;]P8000001P1IU/D2000000H0GIc=00@0000005^IbP000000GioB102`5ah405fKcP800000203j
l>H00`2`5ah0n_3V0?[`iP0^0?[`iP<0/1LN0`3jl>H20;0G7PT0n_3V00<0/1LN0?[`iP0000000P00
000703=HP@030000000cF840/1LN00X0<eR100<000000?[`iP3jl>H0H03jl>H10?ooo`00LP3jl>H0
1@2`5ah0n_3V0?[`iP2`5ah0n_3V00<0/1LN6`3jl>H50;0G7P@0n_3V0P2`5ah60?[`iP030000001C
RkH0Dh^f00<0Dh^f00<0000005VFa@1IU/D0101IU/D00`000000F9?20000000505fLc@030000001K
VLX0FiW:008000000`2`5ah00`000000GI_>05fKcP0305fKcP030000003jl>H0n_3V00@0n_3V00<0
/1LN0?[`iP3jl>H0<03jl>H00`2`5ah0n_3V0?[`iP020?[`iP@0/1LN1@3jl>H2000000030;0G7P00
0000<eR100T0<eR100<0000003=HP@2`5ah02P0cF8400`000000n_3V0?[`iP1P0?[`iP40oooo0015
0?[`iP030;0G7P3jl>H0n_3V02X0n_3V202`5ahP0?[`iPL0/1LN1@3jl>H00`000000Dh^f05>;]P03
05>;]P8000001P1IU/D00`000000F9?20000000405fLc@030000001KVLX0FiW:0080FiW:00@0/1LN
05nOdP1OWm800000101MVlh010000000FIC50000000000040?[`iP030;0G7P3jl>H0n_3V02d0n_3V
00@0/1LN0?[`iP3jl>H0/1LN103jl>H30;0G7P80n_3V1000000203=HP@030;0G7P0cF840<eR100T0
<eR100<0000003=HP@0cF8402@0cF84200000680n_3V0@3oool004H0n_3V00<0/1LN0?[`iP3jl>H0
E03jl>H50;0G7P@0n_3V0P00000405>;]P030000001AQ[40000000D0FIK500<0000005RC`P1HTl80
0P00000205fLc@090000001KVLX0FiW:05^IbP2`5ah0FiW:0000001OWm80000000@0GI_>00P00000
05VDa@1IU<D0000005J>`@000000n_3V0;0G7Rl0n_3V0P2`5ah20?[`iP030;0G7P3jl>H0n_3V00<0
n_3V0P2`5ah2000000H0<eR100<0/1LN03=HP@0cF8402@0cF8400`000000<eR103=HP@0603=HP@<0
000000<0<UIn0000003jl>H0H@3jl>H10?ooo`00A`3jl>H20;0G7U@0n_3V0`2`5ah60?[`iP030000
0014LI<0000000@0Dh^f00<000000566/@000000101IU/D00`000000F9?205RC`P0205RC`P030000
001MW<d000000080FiW:00@0/1LN05^IbP1KVLX0FiW:0P00000305fKcP050000001IU<D0FIC505VD
a@0000000P1FS/42000002h0n_3V102`5ah00`3jl>H0/1LN0?[`iP04000000X0<eR100<0/1LN03=H
P@0cF8402@0cF8400`000000<eR103=HP@0203=HP@@00000100bEWh00`000000n_3V0?[`iP1P0?[`
iP40oooo00190?[`iP030;0G7P3jl>H0n_3V0340n_3V0`2`5ahW0?[`iP0300000014LI<0000000<0
Dh^f00<000000566/@1AQ[400P00000205VFa@030000001HTl80F9?200<0F9?200D0000005fLc@00
0000FiW:0;0G7P0405^IbP050000001MVlh0GI_>05fKcP000000101IU<D010000000EXk105J>`@1F
S/42000002d0n_3V0P2`5ah2000000040;0G7P000000=5V1000000`0<eR100<0/1LN03=HP@0cF840
2@0cF8400`000000<eR100000002000000P0<UIn00<000000?[`iP3jl>H0H03jl>H10?ooo`00BP3j
l>H00`2`5ah0n_3V0?[`iP0c0?[`iP@0/1LN103jl>H30;0G7Q`0n_3V00@0000004AaT`14LI<00000
0P1CRkH00`000000DHJa0566/@020566/@030000001IU/D0000000H0F9?20P0000000`2`5ah0FiW:
05^IbP0305^IbP@000001@1IU<D00`000000EXk105J>`@0305J>`@800000:@3jl>H3000000040;0G
7P0dFH40=5V10;0G7P80=5V100<0000003=HP@0cF840100cF8400`2`5ah0<eR103=HP@0303=HP@03
0;0G7P0cF840<eR100P0<eR10`00000;039FOP030000003jl>H0n_3V0600n_3V0@3oool004/0n_3V
0P2`5ahg0?[`iPL0/1LN703jl>H01`000000A76C04AaT`14LI<0000005>;]P0000001@1AQ[400`00
0000FIK50000000605RC`P030000002`5ah0FiW:00@0FiW:00@0000005ZFaP1JU/H000001@1IU<D0
0`000000EXk105J>`@0505J>`@800000703jl>H00`2`5ah0n_3V0?[`iP030?[`iPD000000`0dFH40
102`5ah0=5V10000002`5ah203AIP@030000000cF840<eR100X0<eR100<0000003=HP@0cF8401@0c
F84300000003039FO@000000<UIn00/0<UIn00<000000?[`iP3jl>H0H03jl>H10?ooo`00C@3jl>H0
0`2`5ah0n_3V0?[`iP0h0?[`iP@0/1LN6`3jl>H00`000000A76C04AaT`0204AaT`030000001CRkH0
000000D0DHJa0P00000605RC`P030;0G7P000000FiW:00D0FiW:0P0000000`1HTL80000000000003
05VDa@030000001FS/40EXk100L0EXk11@00000F0?[`iP80/1LN1@00000203QOR@040000000dFH40
=5V103AIP@@0000000D0M^Ko0;0G7P000000=5V10000000<03=HP@030000000cF840<eR10080<eR1
0`000004039FO@030000000bEWh0<UIn00X0<UIn00<000000?[`iP3jl>H0H03jl>H10?ooo`00CP3j
l>H00`2`5ah0n_3V0?[`iP0g0?[`iP<0/1LN7@3jl>H00`000000A76C04AaT`0204AaT`8000001P1A
Q[400`000000F9?205RC`P0405RC`P030000001FS[`0000000D0FiW:0P00000305RA`P8000000P1I
U<D00`000000EXk105J>`@0705J>`@040000001;O:/0Bgb[04]lZaD00000102`5ah603QOR@@00000
1@1fi_l0102`5ah0000003AIP@00000<03=HP@030000000cF8400000008000001`0bEWd00`000000
<UIn039FOP0:039FOP030000003jl>H0n_3V0600n_3V0@3oool004l0n_3V0P2`5aiG0?[`iP030000
0014LI<0A76C00<0A76C00<000000566/@1AQ[40101AQ[42000000D0F9?200<0000005J>_01FS[`0
0P00000305^IbP030000001HTL80F97200@0F9720`00000:05J>`@030000001;O:/0Bgb[00<0Bgb[
00<0000003aTS@0lI8d0300lI8d01@000000>F2903UPR@0iH8T0/1LN00D0>5n91000000807KVo`04
0;0G7P1fi_l00000000000X0<eR11000000:039FO@030000000bEWh0<UIn00X0<UIn00<000000?[`
iP3jl>H0H03jl>H10?ooo`00D@3jl>H00`2`5ah0n_3V0?[`iP0Q0?[`iP030;0G7P3jl>H0n_3V0300
n_3V00<0000003UNN@0000000`14LI<2000000D0DHJa00<0000004n4[P000000101HTl800`000000
EXjl05J>_00205J>_0040000001KVLX00000000000P0F9720P00000905J>`@030000001;O:/0Bgb[
00<0Bgb[00<0000003aTS@0lI8d0300lI8d01@000000>F2903UPR@0iH8T0/1LN0080>5n90`00000<
07KVo`040;0G7P1fi_l0M^Ko000000H0<eR110000002039FO@030000000bEWd0<UIm00T0<UIm00<0
0000039FOP0bEWh02P0bEWh00`000000n_3V0?[`iP020;0G7Uh0n_3V0@3oool00580n_3V00<0/1LN
0?[`iP3jl>H08@3jl>H20;0G7S00n_3V00<0000003UNN@0iGWT00P0000001014LI<0000004IdV000
00040566/@030000001?Q:h0ChB^008000000`1HTl800`000000EXjl05J>_00205J>_0030000001G
T;l0000000P0F97200@000000566]P00000000001`1FS/400`000000Bgb[04]lZ`0304]lZ`030000
000lI8d0?6B=00`0?6B=00@0000003UPR@0iH8T0>F290`00000207CTo`030000001fi_l0M^Ko00X0
M^Ko00H0/1LN07KVo`1fi_l0M^Ko0000000cF844000000H0<UIm00<00000039FO@0bEWd02@0bEWd0
0`000000<UIn039FOP08039FOP<0000000<0n_3V0;0G7P2`5ah0102`5aiK0?[`iP40oooo001C0?[`
iP030;0G7P3jl>H0n_3V0280n_3V0P2`5ah_0?[`iP8000000P0iGWT30000000304IdV0000000DHJa
00<0DHJa00D0000004n4[P1?Q:h0ChB^0000000205RC`P030000001FS[`0EXjl0080000000@0DXRe
00000000000000001`1HTL8010000000DHJf0566]P1AQ[H3000000D0EXk100L0000004]lZ`1;O:/0
Bgb[0000000lI8d0/1LN00d0?6B=1000000607CTo`030000001fi_l0M^Ko00d0M^Ko0P00000:039F
O@030000000bEWd0<UIm00T0<UIm00<00000039FOP0bEWh0100bEWh400000080<5=i00<000000?[`
iP2`5ah0102`5aiL0?[`iP40oooo001D0?[`iP80/1LN903jl>H20;0G7Rh0n_3V0P00000303UNN@80
000000<0AWBH0000001AQ[400P1AQ[400`000000ChB^04n4[P0204n4[P030000001HTl8000000080
00001@1BR;D00`000000F97205RA`P0605RA`P030000001AQ[H0DHJf00<0DHJf0`00000205J>`@05
0000001;O:/0Bgb[04]lZ`0000000`2`5ah903aTS@<000002P1di?l00`000000M^Ko07KVo`0>07KV
o`030000000bEWd0<UIm00P0<UIm00<00000039FO@0bEWd02@0bEWd00`000000<UIn039FOP040000
00@0<5=i0P2`5ah010000000n_3V0;0G7P2`5ah20?[`iP<0/1LNFP3jl>H10?ooo`00EP3jl>H00`2`
5ah0n_3V0?[`iP020?[`iP<0/1LN7P3jl>H20;0G7Rd0n_3V0P00000303UNN@D0000000<0DHJa0000
001?Q:h00P1?Q:h4000000L0DXRe0`00000605RA`P030000001AQ[H0DHJf00H0DHJf0P000000101F
S/40000004]lZ`1;O:/50;0G7PD0?6B=0`00000>07CTo`030000001fi_l0M^Ko00d0M^Ko0P000009
039FO@030000000bEWd0<UIm00P0<UIm10000008031CN@030;0G7P0`DgT0/1LN00D0/1LN0`3jl>H3
0;0G7UL0n_3V0@3oool005L0n_3V00D0/1LN0?[`iP3jl>H0/1LN0?[`iP020;0G7P030?[`iP2`5ah0
n_3V01d0n_3V00<0/1LN0?[`iP3jl>H0:P3jl>H01P0000009Se?000000000000>Eii000000<0?6>1
1P00000304YjX@030000001BR;D0DXRe00D0DXRe00<0000005>8]`1CR;L00P00000405RA`P030000
001AQ[H0DHJf00P0DHJf0`0000000`1;O:/0/1LN0;0G7P020;0G7P80?6B=1000000207;Po`030000
001di?l0M>Co00d0M>Co00<0000007KVo`1fi_l02P1fi_l200000080MNKo00<00000039FO@0bEWd0
1P0bEWd00`000000<UIm039FO@05039FO@<0000000<0<59h0000000`DgT0200`DgT40;0G7P<0n_3V
0P2`5ah60?[`iP80/1LNE@3jl>H10?ooo`00F03jl>H20;0G7P80n_3V00D0/1LN0?[`iP2`5ah0n_3V
0;0G7P0N0?[`iP80/1LN0`3jl>H00`2`5ah0n_3V0?[`iP0I0?[`iP030;0G7P3jl>H0n_3V00T0n_3V
00H0000002HmC`0V?Dl0000003UNN@00000303aSP@8000001P1:NZ43000000H0DXRe00D0000005>8
]`1CR;L0DhRg0000000305RA`P030000001AQ[H0DHJf00X0DHJf00@0B7JS00000000000000000P2`
5ah2000000H0L^3o00<0000007CTo`1di?l03P1di?l00`000000M^Ko07KVo`0607KVo`<000001@1e
i_l00`000000<UIm039FO@05039FO@030000000bEWd0<UIm0080<UIm0`000004031BN0030000000`
DgT0<5=i00L0<5=i0`2`5ah00`000000n_3V0?[`iP0;0?[`iP80/1LND`3jl>H10?ooo`00F@3jl>H3
0;0G7P030?[`iP2`5ah0/1LN0080n_3V0P2`5ahN0?[`iP<0/1LN00<0n_3V0;0G7P3jl>H06@3jl>H3
0;0G7PX0n_3V00<0000002HmC`0V?Dl00P00000503aSP@030000001:NZ40BWZQ00@0BWZQ00<00000
04enZ00000001@1BR;D00`000000DhRg05>8]`0205>8]`8000000P1HTL800`000000DHJf0566]P09
0566]P@0000000<0/1LN07;Po`1bh?l0201bh?l00`000000M>Co07CTo`0=07CTo`030000001fi_l0
M^Ko00<0M^Ko0`00000907GVo`030000000bEWd0<UIm00@0<UIm00<00000039FO@0000000P000007
031BN0030000000`DgT0/1LN00X0<5=i00<0/1LN0?[`iP3jl>H0H03jl>H10?ooo`00F03jl>H01@2`
5ah0n_3V0;0G7P2`5ah0n_3V0080/1LN103jl>H00`2`5ah0n_3V0?[`iP0M0?[`iP<0/1LN5`3jl>H5
0;0G7P`0n_3V00D0000002HmC`0V?Dl09Se?0000000403aSP@8000001@1:NZ4010000000CGjX04en
Z000000405:8]@030000001CR;L0DhRg00@0DhRg0`0000080566]P@000000`1bh?l00`2`5ah0L^3o
07;Po`0907;Po`030000001di?l0M>Co00d0M>Co00<0000007KVo`1fi_l00P00000<07GVo`030000
000bEWd0<UIm0080<UIm1000000:031BN0040000002`5ah0/1LN0;0G7PT0<5=i00<000000;0G7P3j
l>H0H03jl>H10?ooo`00E`3jl>H20;0G7P030?[`iP2`5ah0n_3V00<0/1LN1@3jl>H00`2`5ah0n_3V
0?[`iP0K0?[`iP030;0G7P3jl>H0n_3V0080/1LN503jl>H20;0G7PL0n_3V0P2`5ah90?[`iP800000
0P0V?Dl00`000000?6>103aSP@0203aSP@<000000`1:NZ4010000000CGjX04enZ01=OZP200000080
DXRe00<0000005>8]`1CR;L01P1CR;L2000000<0DHJf1000000306kIo`050000001bh?l0L^3o07;P
o`2`5ah0301bh?l00`000000M>Co07CTo`0;07CTo`@000003`1ei_l400000080<EAi00<00000031B
N00`DWP02@0`DWP00`000000/1LN0;0G7P020;0G7PP0<5=i00<000000;0G7P3jl>H0H03jl>H10?oo
o`00F03jl>H50;0G7P030?[`iP2`5ah0/1LN00D0n_3V0P2`5ahK0?[`iPH0/1LN7P3jl>H20;0G7PP0
n_3V0`0000000`0V?Dl0000003aSP@0203aSP@040000000mI8@0?FB4000000<0BWZQ00<0000004en
Z01=OZP00P1=OZP010000000DXRe05:8]@00000705>8]`D00000201^fOl010000000L^3o07;Po`2`
5ah<07;Po`030000001di?l0M>Co00L0M>Co1000000307CSo`030000001ei_l0MNKo00h0MNKo00<0
0000035DN@0aE7T00P0aE7T00`000000<59h031BN009031BN0040000000`DgT0<5=i0;0G7PL0<5=i
0`0000000`3jl>H0/1LN0?[`iP1O0?[`iP40oooo001I0?[`iP030;0G7P3jl>H0n_3V00@0/1LN1`3j
l>H00`2`5ah0n_3V0?[`iP0n0?[`iP80/1LN00<0n_3V0;0G7P3jl>H01@3jl>H500000080?6>100@0
000003eTQ00mI8@000000P1:NZ400`000000CGjX04enZ00304enZ0<0000000<0DhRg000000000000
1@00000=06kIo`030000001bh?l0/1LN00d0L^3o00@0000007CTo`1di?l0M>Co1@00000807CSo`03
0000001ei_l0MNKo00h0MNKo00D00000035DN@0aE7T0<EAi0000000;031BN0040000000`DgT0<5=i
0;0G7P<0<5=i1000000202e=L0040000003jl>H0n_3V0;0G7Ul0n_3V0@3oool005X0n_3V00<0/1LN
0?[`iP3jl>H02`3jl>H01@2`5ah0n_3V0?[`iP3jl>H0/1LN03d0n_3V0`2`5ah60?[`iP040000000R
AF`0000004R?f0P0000000<0BWZQ04enZ01=OZP01`00000506K9o`030000001^fOl0K]Wo00`0K]Wo
00<0000007;Po`2`5ah03@1bh?l4000000h0M>?o00<0000007GVo`1ei_l03@1ei_l200000080<EAi
00<00000031BN00`DWP02@0`DWP010000000<5=i031CN@2`5ah3000000H0;De`00<000000?[`iP3j
l>H0H03jl>H10?ooo`00F`3jl>H00`2`5ah0n_3V0?[`iP0;0?[`iP<0/1LN00<0n_3V0;0G7P2`5ah0
>`3jl>H40;0G7PH0n_3V0`00000604R?f0D000000P1L^?l2000000T0I/Wo00<0000006kIo`1^fOl0
301^fOl00`000000/1LN07;Po`0907;Po`<000000P1ag_l00`000000M>?o07CSo`0=07CSo`030000
001ei_l0MNKo00T0MNKo1000000207CTo`040000000aE7T000000;0G7PT0<59h100000000`2`5ah0
;De`02e=L00702e=L0030000003jl>H0n_3V0600n_3V0@3oool005`0n_3V0P2`5ah<0?[`iP80/1LN
00<0n_3V0;0G7P2`5ah0A`3jl>H3000000P0B8oH00<0000005bho`1L^?l00P1L^?l2000000P0I/Wo
00<0000006kIo`1^fOl0301^fOl00`2`5ah0L^3o07;Po`0407;Po`@000001P1ag_l00`000000M>?o
07CSo`0=07CSo`030000001ei_l0MNKo00D0MNKo0`00000607CTo`030000000aE7T0/1LN00<0/1LN
100`DWP30000000502e=K`000000;De`02e=L02`5ah02@0]CG000`000000n_3V0?[`iP1P0?[`iP40
oooo001N0?[`iP030;0G7P3jl>H0n_3V00T0n_3V00<0/1LN0?[`iP2`5ah00P2`5ahR0?[`iP80/1LN
903jl>H3000000P0B8oH00<0000005bho`1L^?l00`1L^?l2000000L0I/Wo00<0000006kIo`1^fOl0
301^fOl00`000000L^3o07;Po`03000000/0LMko00<0000007CSo`1dhol03@1dhol00`000000MNKo
07GVo`04000000X0M>Co00@0/1LN0000002`5ah0/1LN0P0`DWP3000000@0;De_00D0000002e=L00]
CG00;De`0;0G7P0802e=L0030000003jl>H0n_3V0600n_3V0@3oool005l0n_3V00<0/1LN0?[`iP3j
l>H01`3jl>H70;0G7R<0n_3V0`2`5ah20?[`iP80/1LN7`3jl>H2000000P0B8oH00<0000005bho`1L
^?l0101L^?l2000000H0I/Wo00<0000006kIo`1^fOl02@1^fOl5000000h0LMko00<0000007CSo`1d
hol03@1dhol3000000l0M>Co0`2`5ah2000000L0;De_00D0000002e=L00]CG00;De`0;0G7P0802e=
L0030000003jl>H0n_3V0600n_3V0@3oool00480n_3V00<0/1LN0?[`iP3jl>H06`3jl>H00`2`5ah0
n_3V0?[`iP090?[`iP@0/1LN9P3jl>H50;0G7Ql0n_3V0`00000704R?f0030000001L^?l0G;So00D0
G;So0P00000506K9o`030000001^fOl0K]Wo0080K]Wo1P00000406S>o`030000001ag_l0LMko00d0
LMko00<0000007CSo`1dhol02@1dhol300000080L^7o00<0000007CTo`1di?l03P1di?l00`2`5ah0
;De_02e=K`0802e=K`050000000]CG00;De`02e=L02`5ah0200]CG000`000000n_3V0?[`iP1P0?[`
iP40oooo00130?[`iP030;0G7P3jl>H0n_3V01/0n_3V00<0/1LN0?[`iP3jl>H0=03jl>H40;0G7Ql0
n_3V1P00000404R?f0030000001L^?l0G;So00H0G;So0P00000306K9o`D000002`1Xc_l00`000000
LMko077No`0=077No`030000001dhol0M>?o00@0M>?o1000000607;Qo`030000001di?l0M>Co00d0
M>Co00<0/1LN02e=K`0]CFl0200]CFl00`000000;De`02e=L00:02e=L0030000003jl>H0n_3V0600
n_3V0@3oool004@0n_3V00<0/1LN0?[`iP3jl>H06`3jl>H00`2`5ah0n_3V0?[`iP0c0?[`iP80/1LN
8P3jl>H2000000<09Dig100000000`18SmP0000005bho`0405bho`L000000P1Ub?l00`000000J<ko
06S>o`0<06S>o`030000001ag_l0LMko00d0LMko00<0000007CSo`1dhol00`00000807;Qo`040;0G
7P1bhOl0L^7o000000h0M>Co00<0/1LN0000000]CFl0200]CFl00`000000;De`02e=L00802e=L0<0
0000HP3jl>H10?ooo`00A@3jl>H00`2`5ah0n_3V0?[`iP0K0?[`iP80/1LN8P3jl>H00`2`5ah0n_3V
0?[`iP0b0?[`iP030;0G7P3jl>H0000000H09Dig1`00000605Zdo`8000000P1Ub?l00`000000J<ko
06S>o`0<06S>o`030000001ag_l0LMko00/0LMko1000000907;Qo`<0/1LN0`1bhOl00`000000M>Co
07CTo`0;07CTo`030;0G7P000000000000P0;De_00<0000002e=L00]CG00100]CG0400000080:TMW
00<000000?[`iP3jl>H0H03jl>H10?ooo`00AP3jl>H00`2`5ah0n_3V0?[`iP0L0?[`iP030;0G7P3j
l>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H02P3jl>H20;0G7S40n_3V0`2`5ah00`3jl>H000000000
000702E>M`030000001J]?l0F[Co00T0F[Co1000000>06S>o`030000001ag_l0LMko00H0LMko1000
000306cEo`030000001bhOl0L^7o00D0L^7o0`2`5ah207;Qo`050;0G7P1bhOl0L^7o07;Qo`000000
201di?l4000000040;0G7P1bhOl0L^7o000000L0;De_00<0000002e=L00]CG001000000602Y7I`03
0000003jl>H0n_3V0600n_3V0@3oool004H0n_3V00<0/1LN0?[`iP3jl>H07@3jl>H00`2`5ah0n_3V
0?[`iP020?[`iP030;0G7P3jl>H0n_3V00h0n_3V0P2`5ah<0?[`iP030;0G7P3jl>H0n_3V02h0n_3V
0P2`5ah40?[`iP8000001P0UCWL00`000000F[Co05Zdo`0;05Zdo`8000003P1Xc_l010000000LMko
077No`1ag_l4000000P0K=Go00<0000007;Qo`1bhOl00`1bhOl20;0G7P0507;Qo`2`5ah0/1LN07;Q
o`2`5ah0101bhOl010000000M>Co07CTo`1di?l4000000@0L^7o00D0/1LN07;Qo`1bhOl0L^7o0000
000502e=K`@000002P0ZAfL00`000000n_3V0?[`iP1P0?[`iP40oooo00170?[`iP030;0G7P3jl>H0
n_3V01d0n_3V00<0/1LN0?[`iP3jl>H00P2`5ahB0?[`iP030;0G7P3jl>H0n_3V00X0n_3V0P2`5ah_
0?[`iP030;0G7P3jl>H0n_3V00@0n_3V0`00000402E>M`8000003@1J]?l2000000/0J<ko1@00000=
06cEo`030000001bhOl0L^7o00<0L^7o00<0/1LN07;Qo`2`5ah0102`5ah307;Qo`@00000201bhOl0
0`2`5ah0L^7o07;Qo`0207;Qo`D0000000<0:dUZ0000000ZAfL02`0ZAfL00`000000n_3V0?[`iP1P
0?[`iP40oooo00180?[`iP030;0G7P3jl>H0n_3V01d0n_3V1@2`5ahB0?[`iP040;0G7P3jl>H0/1LN
0;0G7PX0n_3V00<0/1LN0?[`iP3jl>H0;03jl>H00`2`5ah0n_3V0?[`iP020?[`iP@0/1LN10000003
02E>M`030000001J]?l0F[Co00/0F[Co0`00000406S>o`D000000`1Xcol00`000000K=Go06cEo`0=
06cEo`030000001bhOl0L^7o0080L^7o00@0/1LN07;Qo`2`5ah0/1LN0P1bhOl0102`5ah000000000
0000000206gHo`030000001bhOl0L^7o00L0L^7o00<0/1LN07;Qo`1bhOl00P1bhOl2000000@0:dUZ
00<0000002Y7I`0ZAfL02P0ZAfL00`000000n_3V0?[`iP1P0?[`iP40oooo00190?[`iP030;0G7P3j
l>H0n_3V01`0n_3V0`2`5ah00`3jl>H0/1LN0?[`iP0B0?[`iP<0/1LN2`3jl>H20;0G7P030?[`iP2`
5ah0n_3V02T0n_3V00<0/1LN0?[`iP3jl>H0203jl>H50000000302E>M`000000F[Co00H0F[Co3000
000906S?o`030000001/eOl0K=Go00d0K=Go00<0000007;Qo`1bhOl00P1bhOl50;0G7P030000001]
f?l0KMSo00@0KMSo00<0000007;Qo`1bhOl0301bhOlC000000/0n_3V102`5ah:0?[`iP<0/1LNAP3j
l>H10?ooo`00BP3jl>H00`2`5ah0n_3V0?[`iP0J0?[`iP<0/1LN00<0n_3V0;0G7P2`5ah01P3jl>H0
0`2`5ah0n_3V0?[`iP0:0?[`iP<0/1LN3@3jl>H30;0G7RT0n_3V00<0/1LN0?[`iP3jl>H02P3jl>H0
10000000<FBE035TU@0aI9D8000000L0Ejgo00@0000006;2o`1R`_l0H/;o1000000706S?o`030000
001/eOl0K=Go00d0K=Go00<0000007;Qo`1bhOl00P0000030;0G7PT0KMSo00<0000007;Qo`1bhOl0
301bhOl01@0000009CiK02DnF`0U?U/0000000`09T1M00<000000?[`iP3jl>H0203jl>H50;0G7P@0
n_3V1P2`5ai90?[`iP40oooo001;0?[`iP030;0G7P3jl>H0n_3V01X0n_3V1P2`5ah60?[`iP030;0G
7P3jl>H0n_3V01T0n_3V0`2`5ahg0?[`iP8000000`0aI9D2000000`0Ejgo00<0000006;2o`1R`_l0
101R`_l4000000@0J<oo00<0000006cEo`1/eOl02`1/eOl4000000@0KMSo00<0/1LN06gHo`1]f?l0
1`1]f?l00`000000L^7o07;Qo`0;07;Qo`<000000P0U?U/00`0000009T1M02I0G@0802I0G@<00000
2P3jl>H20;0G7P030?[`iP2`5ah0/1LN00@0/1LNC`3jl>H10?ooo`00C03jl>H00`2`5ah0n_3V0?[`
iP0L0?[`iP<0/1LN1`3jl>H20;0G7QT0n_3V102`5ahh0?[`iP8000000`0aI9D00`000000Ejgo05N]
o`0:05N]o`800000201R`_l40000000306S?o`000000K=Go00D0K=Go1P00000306[Co`030000001]
f?l0KMSo00<0KMSo00<0/1LN06gHo`1]f?l01`1]f?l00`000000L^7o07;Qo`0607;Qo`@000000`1/
eol2000000L09T1M100000000`0D7bd000000?[`iP090?[`iP@0/1LN00<0n_3V0;0G7P3jl>H0DP3j
l>H10?ooo`00C@3jl>H00`2`5ah0n_3V0?[`iP020;0G7RD0n_3V00<0/1LN0?[`iP3jl>H0=`3jl>H2
0;0G7P80n_3V00<0/1LN0?[`iP3jl>H05P3jl>H200000080<FBE00<0000005N]o`1G[Ol02`1G[Ol0
0`000000H/;o06;2o`0906;2o`D0000000<0/1LN0000000000002P1Zdol00`000000KMSo06gHo`02
06gHo`030;0G7P1]f?l0KMSo00P0KMSo00@0000007;Qo`1bhOl0L^7o1000000806cGo`80000000<0
9T1M0000000000000`00000501@O;@030000003jl>H0n_3V00L0n_3V102`5ah20?[`iP030;0G7P3j
l>H0n_3V0540n_3V0@3oool004h0n_3V0`2`5ah00`3jl>H0/1LN0;0G7P0G0?[`iP030;0G7P3jl>H0
n_3V00X0n_3V00<0/1LN0?[`iP3jl>H0=@3jl>H30;0G7P<0n_3V00<0/1LN0?[`iP3jl>H05`3jl>H5
000000`0Ejgo00<0000006;2o`1R`_l0101R`_l4000000@0G[_o0`2`5ah00`1Tb?l0000000000006
000000<0J]?o00D0000006gHo`1]f?l0KMSo0;0G7P0:06gHo`@000003P1/eol00`00000051l]01@O
;@0701@O;@030000003jl>H0n_3V00L0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P030;0G7U<0n_3V0@3o
ool004h0n_3V0P2`5ah0103jl>H0/1LN0;0G7P2`5ahH0?[`iP030;0G7P3jl>H0n_3V00X0n_3V0P2`
5ahc0?[`iP80/1LN1`3jl>H20;0G7QT0n_3V5000000:05jko`80/1LN2P1Tb?l8000000030;0G7P1]
f?l0KMSo00<0KMSo1000000206WBo`030000001/eol0K=Oo00L0K=Oo2000000801@O;@030000003j
l>H0n_3V00L0n_3V202`5aiC0?[`iP40oooo001=0?[`iP070;0G7P3jl>H0/1LN0?[`iP2`5ah0n_3V
0;0G7P0I0?[`iP030;0G7P3jl>H0n_3V00/0n_3V00@0/1LN0?[`iP2`5ah0/1LN=`3jl>H30;0G7Q/0
n_3V1000000;03AZW0030000001N^ol0G[_o00/0G[_o00<0/1LN0000001Tb?l03@1Tb?l010000000
Ilgo06O=o`2`5ahE000000P0HL?o0P00000501@O;@030000003jl>H0n_3V00T0n_3V0`2`5ah00`3j
l>H0/1LN0;0G7P030;0G7U40n_3V0@3oool004`0n_3V0P2`5ah20?[`iP040;0G7P3jl>H0/1LN0;0G
7PP0n_3V00<0/1LN0?[`iP3jl>H03`3jl>H00`2`5ah0n_3V0?[`iP0;0?[`iP<0/1LNF03jl>H30000
00X0=6ZL00<0000005jko`1N^ol02P1N^ol00`2`5ah0G[_o0000000;06C8o`H000003@1Taol00`00
0000HL?o0673o`070673o`@000001018T</20000000401@O;@0000000000000000`0n_3V0P2`5aiG
0?[`iP40oooo001>0?[`iP80/1LN00@0n_3V0;0G7P2`5ah0/1LN2@3jl>H00`2`5ah0n_3V0?[`iP0?
0?[`iP80/1LN2P3jl>H50;0G7UT0n_3V0`00000903AZW08000002P1N^ol0102`5ah0G[_o05jko`00
000406C8o`H00000101I/_l2000000h0I<Oo0P0000030673o`@000002P18T</3000006H0n_3V0@3o
ool00500n_3V102`5ah90?[`iP030;0G7P3jl>H0n_3V0140n_3V00<0/1LN0?[`iP3jl>H0203jl>H4
0;0G7R<0n_3V00<0/1LN0?[`iP3jl>H0=P3jl>H7000000@0=6ZL00<0000005jko`1N^ol01@1N^ol2
000000030;0G7P000000000000D00000301I/_l00`000000I<Oo06C7o`0:06C7o`H000001P18T</6
000000/0n_3V0P2`5aiN0?[`iP40oooo001B0?[`iP80/1LN2P3jl>H00`2`5ah0n_3V0?[`iP0A0?[`
iP030;0G7P3jl>H0n_3V02l0n_3V0P2`5ahk0?[`iPh000000P0iM:H00`2`5ah0>GBV03UdYP0203Ud
YP8000003P1I/_l2000000@0I<Oo1P00000603QbX@H0000000<0/1LN0?[`iP3jl>H01`3jl>H30;0G
7P@0n_3V0P2`5aiN0?[`iP40oooo001F0?[`iP030;0G7P3jl>H0n_3V00H0n_3V00<0/1LN0?[`iP3j
l>H04@3jl>H00`2`5ah0n_3V0?[`iP0`0?[`iP<0/1LN3P3jl>H@000001@0n_3V0P2`5ah30?[`iP80
/1LN103jl>H6000000`0>GBV0P00000805Vbo`X000001`0hLZ45000000<0n_3V102`5ah30?[`iPH0
/1LN203jl>H00`2`5ah0n_3V0?[`iP1L0?[`iP40oooo001G0?[`iP030;0G7P3jl>H0n_3V00H0n_3V
00<0/1LN0?[`iP3jl>H04@3jl>H00`2`5ah0n_3V0?[`iP0R0?[`iP030;0G7P3jl>H0n_3V00/0n_3V
0`2`5ah70?[`iPH0000000<0C8Bn0000001BSl/02`1BSl/00`000000GjGV00000003000000h0n_3V
1`2`5ah00`3jl>H0/1LN0?[`iP080?[`iQL000002@0dK9P6000000T0n_3V202`5ah?0?[`iP030;0G
7P3jl>H0n_3V05/0n_3V0@3oool005P0n_3V00<0/1LN0?[`iP3jl>H01@3jl>H00`2`5ah0n_3V0?[`
iP0B0?[`iP040;0G7P3jl>H0n_3V0;0G7Ql0n_3V0`2`5ah?0?[`iPL000001017O;<010000000C8Bn
04b4_P00000<05:?b`030000001OYNH0GjGV00<0GjGV0`00000;0?[`iPD0/1LN0P3jl>H00`2`5ah0
n_3V0?[`iP0f0?[`iP@0/1LN00<0n_3V0;0G7P3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP1J0?[`iP40
oooo001I0?[`iP030;0G7P3jl>H0n_3V00D0n_3V0P2`5ahC0?[`iP80/1LN00<0n_3V0;0G7P3jl>H0
7P3jl>H00`2`5ah0n_3V0?[`iP0:0?[`iP@0000000<0@W>X00000017O;<01`17O;<01@000000C8Bn
04b4_P1<Q;h0000000d0DXo;00<0000005nUiP1OYNH00`1OYNH00`000000J[Wm00000002000000T0
n_3V0P2`5ah01@3jl>H0/1LN0;0G7P3jl>H0/1LN03X0n_3V102`5ai`0?[`iP40oooo001J0?[`iP03
0;0G7P3jl>H0n_3V00@0n_3V102`5ahB0?[`iP<0/1LN803jl>H00`2`5ah0n_3V0?[`iP050?[`iP@0
00001@12LjP00`000000Agbc04Ml/`0604Ml/`050000001<Q;h0C8Bn04b4_P0000003@1BSl/00`00
0000GjGV05nUiP0205nUiP030000001Z^Od0J[Wm00<0J[Wm0P0000070?[`iP<0/1LN>P3jl>H30;0G
7PX0n_3V00<0/1LN0?[`iP3jl>H0J03jl>H10?ooo`00F`3jl>H00`2`5ah0n_3V0?[`iP030?[`iP04
0;0G7P3jl>H0/1LN0;0G7Q40n_3V00<0/1LN0?[`iP2`5ah00P2`5ahD0?[`iP030;0G7P3jl>H0n_3V
00T0n_3V00@0/1LN0?[`iP3jl>H0n_3V0`000009049cZ00300000017O;<0Agbc00D0Agbc00<00000
04b4_P1<Q;h00P1<Q;h00`000000DXo;05:?b`0;05:?b`030000001OYNH0GjGV0080GjGV00<00000
06Zio@1Z^Od01@1Z^Od3000000L0n_3V00<0/1LN0?[`iP3jl>H0=P3jl>H90;0G7P@0n_3V0`2`5aiY
0?[`iP40oooo001L0?[`iP040;0G7P3jl>H0n_3V0?[`iPD0/1LN4@3jl>H30;0G7P030?[`iP2`5ah0
n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0203jl>H01P000000/1LN000000000000/1LN000000X0@W>X
00<0000004Ml/`17O;<01@17O;<00`000000C8Bn04b4_P0204b4_P030000001BSl/0DXo;00/0DXo;
00<0000005nUiP1OYNH00P1OYNH00`000000J[Wm06Zio@0306Zio@030;0G7P1Z^Od0J[Wm0080J[Wm
0P0000060?[`iP030;0G7P3jl>H0n_3V03H0n_3V0P2`5ah;0?[`iP030;0G7P3jl>H0n_3V06P0n_3V
0@3oool003h0n_3V00<0/1LN0?[`iP3jl>H0703jl>H00`2`5ah0n_3V0?[`iP020?[`iP<0/1LN503j
l>H30;0G7QD0n_3V102`5ah20?[`iP@000000`0oKZ400`2`5ah0?fjQ0000000:049cZ00300000017
O;<0Agbc00@0Agbc00<0000004b4_P1<Q;h00`1<Q;h00`000000DXo;05:?b`0;05:?b`050000001O
YNH0GjGV05nUiP000000101Z^Od40;0G7P@0J[Wm0P0000050?[`iP030;0G7P3jl>H0n_3V04@0n_3V
00<0/1LN0?[`iP3jl>H0:`3jl>H20;0G7SX0n_3V0@3oool003h0n_3V00<0/1LN0?[`iP3jl>H0703j
l>H00`2`5ah0n_3V0?[`iP0b0?[`iP<0/1LN0P00000603m^X@040;0G7P0oKZ40?fjQ000000/0@W>X
00<0000004Ml/`17O;<00`17O;<00`000000C8Bn04b4_P0304b4_P030000001BSl/0DXo;00/0DXo;
00D0000005nUiP1OYNH0GjGV0000000306Zio@80/1LN00<0J[Wm0;0G7P1Z^Od0101Z^Od00`000000
LLCo000000050?[`iP030;0G7P3jl>H0n_3V04<0n_3V00<0/1LN0?[`iP3jl>H0:@3jl>H20;0G7S`0
n_3V0@3oool003l0n_3V00<0/1LN0?[`iP3jl>H0703jl>H00`2`5ah0n_3V0?[`iP0U0?[`iP030;0G
7P3jl>H0n_3V00L0n_3V0P0000030;0G7P030000000oKZ40?fjQ00P0?fjQ00<00000049cZ012LjP0
2@12LjP00`000000Agbc04Ml/`0204Ml/`030000001<Q;h0C8Bn00@0C8Bn00<0000005:?b`1BSl/0
301BSl/010000000GjGV05nUiP00000406Zio@030;0G7P1Z^Od0J[Wm00D0J[Wm00<000000774o`00
00000P00000^0?[`iP<0/1LN603jl>H00`2`5ah0n_3V0?[`iP0W0?[`iP80/1LN?P3jl>H10?ooo`00
?`3jl>H00`2`5ah0n_3V0?[`iP0M0?[`iP030;0G7P3jl>H0n_3V0080/1LN8`3jl>H00`2`5ah0n_3V
0?[`iP020?[`iP@000001@0mJi`00`000000?fjQ03m^X@0803m^X@0300000012LjP0@W>X00T0@W>X
00<0000004Ml/`17O;<00P17O;<00`000000C8Bn04b4_P0404b4_P030000001BSl/0DXo;00`0DXo;
00@0000005nUiP1OYNH00000101Z^Od00`2`5ah0J[Wm06Zio@0506Zio@030000001aa?l000000080
LLGo0P00000S0?[`iP030;0G7P3jl>H0n_3V0080n_3V102`5ah50?[`iP80/1LN>`3jl>H30;0G7T00
n_3V0@3oool00400n_3V00<0/1LN0?[`iP3jl>H07@3jl>H40;0G7R@0n_3V0P2`5ah2000000T0?F^L
00<0000003m^X@0oKZ40200oKZ400`000000@W>X049cZ009049cZ00500000017O;<0Agbc04Ml/`00
0000101<Q;hC0000000305nUiP000000J[Wm00@0J[Wm00<0/1LN06Zio@1Z^Od0101Z^Od01@000000
LLCo0774o`1aa?l0000000<0LLGo0P00000P0?[`iPH0/1LN203jl>H30;0G7P@0n_3V00<0/1LN0?[`
iP3jl>H09`3jl>H30;0G7PP0n_3V0P2`5ai30?[`iP40oooo00100?[`iP030;0G7P3jl>H0n_3V01d0
n_3V0P2`5ah00`3jl>H0/1LN0?[`iP0H0?[`iP030;0G7P3jl>H0n_3V00H0n_3V0`0000000`0lJ9T0
/1LN03e[W00903e[W0030000000oKZ40?fjQ00P0?fjQ00<00000049cZ012LjP02012LjP:000000<0
Bh>m00<0000005RIe`1HVML0301HVML4000000/0J[Wm00D000000774o`1aa?l0LLCo000000050775
o`030000003jl>H0n_3V01`0n_3V102`5ah=0?[`iP030;0G7P3jl>H0n_3V00@0/1LN:03jl>H00`2`
5ah0n_3V0?[`iP030;0G7P<0n_3V0P2`5ai50?[`iP40oooo00110?[`iP030;0G7P3jl>H0n_3V01/0
n_3V0P2`5ah0103jl>H0/1LN0;0G7P2`5ahD0?[`iP030;0G7P3jl>H0n_3V0080n_3V0P2`5ah20?[`
iP@00000100lJ9T010000000/1LN03e[W02`5ah703e[W0030000000oKZ40?fjQ00P0?fjQ00<00000
049cZ012LjP01012LjP40000000504Ei/0000000B7jg04Qn]`000000201;Pkd00`000000F9WG05RI
e`0<05RIe`040000001QZ>/0000006Ren@<00000201Z^Od01@000000LLCo0774o`1aa?l0000000D0
LLGo0P00000N0?[`iP<0/1LN3P3jl>H40;0G7P030?[`iP2`5ah0/1LN02H0n_3V0P2`5ah20?[`iP<0
/1LN00<0n_3V0;0G7P2`5ah0A`3jl>H10?ooo`00@@3jl>H00`2`5ah0n_3V0?[`iP0M0?[`iP@0/1LN
503jl>H00`2`5ah0n_3V0?[`iP040?[`iP030;0G7P000000?6RI00L0?6RI00@0000003e[W02`5ah0
/1LN1`0mJi`00`000000?fjQ03m^X@0803m^X@0300000012LjP0@W>X00@000001@15NK0010000000
B7jg04Qn]`00000804^3_@030000001HVML0F9WG00D0F9WG0`2`5ah405RIe`030000001QZ>/00000
00@0J;Gi1000000406Zio@050000001aa?l0LLCo0774o`0000001@1aaOl00`000000LlSo0000000`
0?[`iP@0/1LN9`3jl>H20;0G7P030?[`iP2`5ah0n_3V00<0/1LN103jl>H20;0G7T<0n_3V0@3oool0
0480n_3V00<0/1LN0?[`iP3jl>H07P3jl>H20;0G7Q@0n_3V00<0/1LN0?[`iP3jl>H0103jl>H00`00
0000?6RI03aXV@0703aXV@030000002`5ah0/1LN0080/1LN1P0mJi`00`000000?fjQ03m^X@0703m^
X@@000002@15NK000`000000B7jg0000000904^3_@030000001HVML0F9WG00d0F9WG00<0000006Re
n@1X]OT01`1X]OT30000000306Zio@000000LLCo00<0LLCo00<000000775o`1aaOl00P1aaOl00`00
0000LlSo07?8o`02000001D0n_3V00<0/1LN0?[`iP3jl>H05P3jl>H30;0G7RP0n_3V00<0/1LN0?[`
iP2`5ah00P2`5ah00`3jl>H0/1LN0?[`iP020?[`iP80/1LNA@3jl>H10?ooo`00@P3jl>H00`2`5ah0
n_3V0?[`iP0/0?[`iP030;0G7P3jl>H0n_3V00D0n_3V00<0/1LN0?[`iP3jl>H0103jl>H00`000000
?6RI03aXV@0703aXV@030000000mJi`0?F^L00P0?F^L00<0000003m^X@0oKZ400`0oKZ4400000003
045bYP000000AGV`00X0AGV`00<0000004Qn]`0000002@1;Pkd00`000000F9WG05RIe`0=05RIe`03
0000001X]OT0J;Gi00X0J;Gi0P0000040774o`030000001aaOl0LLGo0080LLGo00<0000007?8o`1c
b?l00P1cb?l00`000000n_3V0?[`iP0A0?[`iPL0/1LN503jl>H20;0G7RL0n_3V102`5ah40?[`iP<0
/1LNA`3jl>H10?ooo`00@P3jl>H00`2`5ah0n_3V0?[`iP0]0?[`iP030;0G7P3jl>H0n_3V00<0n_3V
0`2`5ah50?[`iP030000000lJ9T0?6RI00L0?6RI00<0000003e[W00mJi`0200mJi`00`000000?fjQ
00000003000000D0@G:V00<0000004Ei/015NK002@15NK02000000H0Bh>m00<0/1LN04^3_@2`5ah0
0P2`5ah00`000000F9WG05RIe`0<05RIe`030000001X]OT0J;Gi00/0J;Gi0`0000020774o`050000
001aaOl0LLGo0775o`0000001P1cb?l00`000000n_3V0?[`iP0A0?[`iP80/1LN1P3jl>H00`2`5ah0
n_3V0?[`iP0A0?[`iP030;0G7P3jl>H0n_3V01d0n_3V0P2`5ah50?[`iPT0/1LNB@3jl>H10?ooo`00
@`3jl>H00`2`5ah0n_3V0?[`iP0/0?[`iP030;0G7P3jl>H0n_3V00<0n_3V0P2`5ah60?[`iP030000
000lJ9T0?6RI00L0?6RI00<0000003e[W00mJi`01`0mJi`3000000T0@G:V00<0000004Ei/015NK00
2@15NK02000000L0Bh>m102`5ah00`000000F9WG05RIe`0<05RIe`030000001X]OT0J;Gi00/0J;Gi
00@0000007?8o`1cb?l000000P1aa?l30775o`030000001cb?l0LlSo00D0LlSo00<000000?[`iP3j
l>H01@3jl>H20;0G7Q00n_3V0`2`5ahB0?[`iP030;0G7P3jl>H0n_3V01/0n_3V0P2`5ah80?[`iPP0
/1LNB@3jl>H10?ooo`00@`3jl>H00`2`5ah0n_3V0;0G7P0S0?[`iP030;0G7P3jl>H0n_3V00L0n_3V
00<0/1LN0?[`iP3jl>H00`3jl>H00`2`5ah0n_3V0?[`iP030?[`iP030000000lJ9T0?6RI00P0?6RI
00<0000003e[W00mJi`00`0mJi`40000000303m^X@000000@G:V00T0@G:V00<0000004Ei/015NK00
2@15NK000`000000Bh>m04^3_@0604^3_@D0/1LN3P1HVML00`000000J;Gi06Ren@0:06Ren@030000
001cb?l0LlSo0080LlSo0`0000020775o`030000001cb?l0LlSo00D0LlSo0P0000020?[`iP@0/1LN
4@3jl>H00`2`5ah0n_3V0;0G7P0^0?[`iP<0/1LN2P3jl>H40;0G7P030?[`iP2`5ah0n_3V04X0n_3V
0@3oool004@0n_3V102`5ahR0?[`iP030;0G7P3jl>H0n_3V00H0n_3V00<0/1LN0?[`iP3jl>H02@3j
l>H00`000000?6RI03aXV@0803aXV@030000000mJi`0000000<000001@0oKZ400`000000@G:V045b
YP08045bYP0300000015NK00AGV`00P0AGV`0P00000904^3_@80/1LN00@0Bh>m0000002`5ah0/1LN
2`1HVML2000000`0J;Gi00<0000007?8o`1cb?l0101cb?l010000000LLGo0775o`00000707?8o`04
0000001caol0/1LN0;0G7Q@0n_3V00@0/1LN0?[`iP2`5ah0/1LN:`3jl>H30;0G7Pd0n_3V0`2`5ah2
0?[`iP030;0G7P3jl>H0n_3V04T0n_3V0@3oool00480n_3V102`5ah20?[`iP030;0G7P3jl>H0n_3V
0200n_3V00<0/1LN0?[`iP3jl>H01P3jl>H00`2`5ah0n_3V0?[`iP080?[`iP030000000lJ9T0?6RI
00L0?6RI0`00000903m^X@0300000011LZH0@G:V00T0@G:V00<0000004Ei/015NK001`15NK020000
00`0Bh>m00<0000005RIe`1HVML02`1HVML2000000`0J;Gi00<0000007?8o`1cb?l0101cb?l40000
00L0LlSo00<0000007?7o`1caol00P00000A0?[`iP80/1LN0`3jl>H00`2`5ah0n_3V0?[`iP0O0?[`
iP<0/1LN1@3jl>H20;0G7Q<0n_3V0`2`5ai;0?[`iP40oooo00110?[`iP80/1LN0P3jl>H30;0G7R@0
n_3V00<0/1LN0?[`iP3jl>H01P3jl>H30;0G7PL0n_3V00<0000003aXV@0lJ9T00`0lJ9T400000003
03e[W@000000?fjQ00T0?fjQ00<00000045bYP11LZH02@11LZH00`000000AGV`04Ei/00604Ei/004
00000019PKX000000;0G7PD0Bh>m3@00000605RIe`030000001RZnl0000000`0J;Gi00<0000007?8
o`1cb?l0101cb?l010000000LlSo07?8o`00000707?8o`030000001caol0LlOo0080LlOo00D00000
0?[`iP3jl>H0n_3V0;0G7P0;0?[`iP<0/1LN0`3jl>H00`2`5ah0n_3V0?[`iP0N0?[`iP@0/1LN0P3j
l>H30;0G7Q00n_3V00D0/1LN0?[`iP3jl>H0n_3V0;0G7P1>0?[`iP40oooo00120?[`iPH0/1LN9@3j
l>H00`2`5ah0n_3V0?[`iP040?[`iP<0/1LN203jl>H00`000000?6RI00000003000000D0?F^M00<0
000003m^X@0oKZ40200oKZ400`000000@G:V045bYP09045bYP0300000015NK00AGV`00H0AGV`0P00
00030;0G7P@000001P1?RlP00`000000FYkO05ZNg`0405ZNg`X000002`1X]OT00`000000LlSo07?8
o`0507?8o`040000001cb?l00000000000D0LlSo00<0000007?7o`1caol0101caol00`000000n_3V
0;0G7P020;0G7PT0n_3V2@2`5ahO0?[`iP80/1LN00@0n_3V0;0G7P2`5ah0/1LN4P3jl>H50;0G7Tl0
n_3V0@3oool004@0n_3V0`2`5ahB0?[`iP030;0G7P3jl>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H0
103jl>H20;0G7PP0n_3V0P00000903e[W@030000000oKZ40?fjQ00P0?fjQ00<00000045bYP11LZH0
2@11LZH00`000000AGV`04Ei/00204Ei/0D0000000<0Bh>n0000002`5ah02`1?RlP00`000000FYkO
05ZNg`0:05ZNg`040000001T/?H0000006Zio`<00000201X]OT00`000000LlSo07?8o`0507?8o`05
0000001cb?l0000007C9o`000000101cb?l00`000000LlOo07?7o`0507?7o`030000003jl>H0n_3V
00/0n_3V0P2`5ah20?[`iP030;0G7P3jl>H0n_3V0080/1LN7@3jl>H40;0G7P030?[`iP2`5ah0n_3V
0080n_3V0P2`5ah>0?[`iP<0/1LND@3jl>H10?ooo`00AP3jl>H00`2`5ah0n_3V0?[`iP0@0?[`iP03
0;0G7P3jl>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H03P3jl>H00`000000?F^M03e[W@0803e[W@03
0000000oKZ40?fjQ00P0?fjQ00<00000045bYP11LZH02011LZH2000000040;0G7P00000000000000
0080B7ff00D0000004^3_P1;Pkh0Bh>n0000000=04n;b0030000001JW]l0FYkO00P0FYkO00@00000
06B`mP1T/?H00000101Z^Ol3000000@0J;Gi00<0000007?8o`1cb?l01P1cb?l2000000<0M<Wo0P00
000207?8o`030000001caol0LlOo00D0LlOo0P0000000`2`5ah0n_3V0?[`iP090?[`iP80/1LN0`3j
l>H30;0G7Qh0n_3V102`5ah20?[`iP<0/1LN4@3jl>H20;0G7U40n_3V0@3oool005T0n_3V00<0/1LN
0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP020;0G7P<00000203jl>H00`000000?F^M03e[W@08
03e[W@030000000oKZ40?fjQ00P0?fjQ00<00000045bYP11LZH01011LZH40000000304Ei/0000000
B7ff0080/1LN0`18OKH01@000000Bh>n04^3_P1;Pkh0000000d0Ch_800<0000005ZNg`1JW]l0201J
W]l01@000000I;3f06B`mP1T/?H0000000H0J[Wo0`0000000`1X]OT0000007?8o`0707?8o`030000
002`5ah0M<Wo0080/1LN0P1dbOl00`000000LlSo0000000707?7o`030000002`5ah0/1LN00`0n_3V
0P2`5ah20?[`iP030;0G7P3jl>H0/1LN01D0n_3V0P2`5ah70?[`iPL0/1LNIP3jl>H10?ooo`00D`3j
l>H00`2`5ah0n_3V0?[`iP030?[`iP030;0G7P3jl>H0n_3V0180n_3V1P0000000`1N]ol0000004fF
j00600000080n_3V00<0000003e[W@0mJid0200mJid00`000000?fjQ03m^X@0803m^X@0300000011
LZH0/1LN00@000001@15NK000`000000B7ff04Qm]P020;0G7P0304Qm]P000000Bh>n00<0Bh>n00<0
000004n;b01?RlP02`1?RlP00`000000FYkO05ZNg`0705ZNg`030000001T/?H0I;3f0080I;3f00<0
000006Zio`1Z^Ol01`1Z^Ol2000000T0LlSo0P2`5ah507C9o`8000001`1caol40;0G7P/0n_3V102`
5ah30?[`iP80/1LN403jl>H30;0G7PT0n_3V1@2`5aiX0?[`iP40oooo001D0?[`iP030;0G7P3jl>H0
n_3V0080n_3V00<0/1LN0?[`iP3jl>H02P3jl>H8000000@0ILGo00D0000005jgo`1N]ol0G[Oo0000
000604fFj0@000002@0mJid00`000000?fjQ03m^X@0703m^X@@0000000<0/1LN04Ei/015NK001P15
NK000`000000B7ff04Qm]P0204Qm]P030000001;Pkh0Bh>n00<0Bh>n00<0000004n;b01?RlP02`1?
RlP00`000000FYkO05ZNg`0705ZNg`030000001T/?H0I;3f0080I;3f00<0000006Zio`1Z^Ol0201Z
^Ol3000000L0LlSo00<0000007C9o`1dbOl01@1dbOl00`000000LlOo07?7o`0507?7o`<0/1LN00<0
00000?[`iP3jl>H02P3jl>H00`2`5ah0n_3V0?[`iP050?[`iP030;0G7P3jl>H0n_3V00/0n_3V0P2`
5ah;0?[`iP@0/1LNJP3jl>H10?ooo`00E03jl>H00`2`5ah0n_3V0?[`iP020?[`iP030;0G7P3jl>H0
n_3V00@0n_3V1P00000306cBo`030000001UaOl0ILGo00H0ILGo00D0000005jgo`1N]ol0G[Oo0000
000:04fFj08000001`0mJid00`000000?fjQ03m^X@0303m^X@@0000000<0@G:W00000015NK000P15
NK000`2`5ah0AGV`04Ei/00504Ei/00500000018OKH0B7ff04Qm]P0000001`1;Pkh00`000000Ch_8
04n;b00:04n;b0030000001JW]l0FYkO00H0FYkO00<0000006B`mP1T/?H00`1T/?H00`000000J[Wo
06Zio`0706Zio`040000001bb?l0L/So07;8o`8000001@1cb?l00`000000M<Wo07C9o`0507C9o`80
00001@1caol01P000000L/Go0;0G7P1baOl0/1LN000001h0n_3V0`2`5ah=0?[`iP@0/1LNJP3jl>H1
0?ooo`00E@3jl>H01@2`5ah0n_3V0?[`iP3jl>H0/1LN0080n_3V1000000:06cBo`030000001UaOl0
ILGo00H0ILGo00D0000005jgo`1N]ol0G[Oo0000000904fFj0040000000TBG@00000000000D0?F^M
00<0000003m^X@0000000`000005045bY`0300000015NK00AGV`0080AGV`0`2`5ah404Ei/0050000
0018OKH0B7ff04Qm]P0000001`1;Pkh00`000000Ch_804n;b00:04n;b0030000001JW]l0FYkO00H0
FYkO00<0000006B`mP1T/?H0101T/?H00`000000J[Wo06Zio`0606Zio`030000001bb?l0L/So00<0
L/So0P00000207?8o`80000000<0M<Wo0;0G7P2`5ah0101dbOl00`000000ML_o0000000407?7o`03
0000001baOl0L/Go0080L/Go00<0/1LN0000003jl>H05@3jl>H0102`5ah0n_3V0?[`iP3jl>H30;0G
7R<0n_3V00<0/1LN0?[`iP3jl>H0F03jl>H10?ooo`00E@3jl>H01@2`5ah0n_3V0?[`iP000000/1LN
008000000P1`f_l00`000000K=;o06cBo`0:06cBo`030000001UaOl0ILGo00D0ILGo00<0000005jg
o`1N]ol00P1N]ol00`000000CIKX04fFj00704fFj0040000000TBG@094Ud000000<0?F^M0`000009
045bY`0300000015NK00AGV`0080AGV`0`2`5ah404Ei/00400000018OKH0B7ff000000P0Bh>n00<0
000004n;b01?RlP02`1?RlP00`000000FYkO05ZNg`0405ZNg`030000001T/?H0I;3f00D0I;3f00<0
000006Zio`1Z^Ol01P1Z^Ol00`000000L/So07;8o`0507;8o`@0000000<0M<Wo0;0G7P2`5ah0101d
bOl00`000000ML_o07G;o`0200000080LlOo00<0000007;5o`1baOl0101baOl00`000000n_3V0?[`
iP0B0?[`iP80/1LN00<0n_3V0;0G7P2`5ah09@3jl>H30;0G7UT0n_3V0@3oool005@0n_3V0`000003
0;0G7PD0L=[o00<0000006cBo`1/d_l02P1/d_l00`000000ILGo06G5o`0406G5o`030000001N]ol0
G[Oo00<0G[Oo00<0000004fFj01=U^P01`1=U^P00`00000094Ud02A9M0030000000303m_X`000000
@G:W00T0@G:W00@0000004Ei/02`5ah0/1LN0P15NK020;0G7P@0AGV`00<0000004Qm]P0000002@1;
Pkh00`000000Ch_804n;b00;04n;b0030000001JW]l0FYkO00@0FYkO00<0000006B`mP1T/?H01@1T
/?H00`000000J[Wo06Zio`0506Zio`030000001bb?l0L/So00P0L/So00D0000007C:o`000000M<Wo
0;0G7P0407C9o`030000001ebol0ML_o0080ML_o00<0000007?7o`0000001P1baOl200000180n_3V
102`5ahD0?[`iP030;0G7P3jl>H0n_3V0140n_3V00<0/1LN0?[`iP3jl>H0803jl>H00`2`5ah0n_3V
0?[`iP0e0?[`iP40oooo001@0?[`iP@000000`1`f_l0102`5ah0L=[o0;0G7P2`5ah5073Jo`030000
001/d_l0K=;o00T0K=;o00<0000006G5o`1UaOl0101UaOl00`000000G[Oo05jgo`0405jgo`030000
001=U^P0CIKX00L0CIKX00<0000002A9M00000000`0oKj<00`000000@G:W045bY`06045bY`@0/1LN
2P15NK02000000X0Bh>n00<0000004n;b01?RlP01@1?RlP9000000<0FYkO00<0000006B`mP1T/?H0
1`1T/?H606Zio`030;0G7P000000L/So00T0L/So0`00000507C9o`030000001ebol0ML_o00@0ML_o
0P00000607;5o`030000001a`ol000000100n_3V1@2`5ah@0?[`iP@0/1LN=P3jl>H00`2`5ah0n_3V
0?[`iP0f0?[`iP40oooo001<0?[`iP@000000P1bg_l00`000000L=[o073Jo`02073Jo`@0/1LN1P1`
f_l00`000000K=;o06cBo`0906cBo`030000001UaOl0ILGo00@0ILGo00<0000005jgo`1N]ol00`1N
]ol00`000000CIKX04fFj00704fFj0040000000TBG@094Ud00000080?fnS00@00000045bY`11LZL0
/1LN1011LZL30;0G7P03045bY`000000AGV`00T0AGV`0P00000804^3_PX000001P1HV]`00`000000
GZGZ05jUjP08000000D0I;3f00<0000006Zio`1Z^Ol00P1Z^Ol30;0G7PX0L/So00<0000007K>o`00
00001@1dbOl00`000000ML_o07G;o`0507G;o`030000001baOl0L/Go00@0L/Go00@000000773o`1a
`ol000004P3jl>H50;0G7Pd0n_3V0P2`5ahf0?[`iP80/1LN>@3jl>H10?ooo`00>`3jl>H00`2`5ah0
n_3V0?[`iP0:0?[`iP@000001`1bg_l010000000L=[o073Jo`1`f_l40;0G7PH0L=[o00<0000006cB
o`1/d_l02P1/d_l00`000000ILGo06G5o`0306G5o`030000001N]ol0G[Oo00@0G[Oo00<0000004fF
j01=U^P01`1=U^P01P00000094Ud000000000000?fnS00000080@G:W00<0/1LN045bY`11LZL00`11
LZL0102`5ah0@G:W045bY`00000:04Ei/0040000001;Pkh0Bh>n04^3_PH000000P1>RLH00`000000
F9[L05RJg00;05RJg0030000001NYNX0GZGZ00<0GZGZ00<0000006Jdn`1V]?/00P1V]?/7000000@0
J[Wo00<0/1LN0000001bb?l01@1bb?l0102`5ah0L/So07;8o`00000307K>o`8000000`1dbOl00`00
0000ML_o07G;o`0507G;o`8000001@1baOl01@000000LL?o0773o`1a`ol0000000D0n_3V00<0/1LN
0?[`iP3jl>H02@3jl>H30;0G7TH0n_3V00<0/1LN0?[`iP3jl>H0>@3jl>H10?ooo`00>`3jl>H00`2`
5ah0n_3V0?[`iP070?[`iP<00000301bg_l010000000L=[o073Jo`1`f_l20;0G7PP0L=[o00<00000
06cBo`1/d_l02P1/d_l010000000ILGo06G5o`1UaOl;000000P0CIKX00D0000002A9M0000000?fnS
00000002045bY`030;0G7P11LZL0@G:W00H0@G:W00<0000004Ei/015NK001P15NK06000000P0CXW6
00<0000005RJg01HV]`0301HV]`01@000000GZGZ05jUjP1NYNX0000000/0I[Ck00H0KL3o00000000
0000000006Zio`00000507;8o`<0/1LN0P1bb?l01`000000M/ko07K>o`1fc_l0000007K=o`000000
0P1dbOl00`000000ML_o07G;o`0507G;o`030000001dbOl0000000<0L/Go00<000000773o`1a`ol0
0`1a`ol00`000000n_3V0?[`iP020;0G7PP0n_3V102`5ai80?[`iP030;0G7P3jl>H0n_3V03X0n_3V
0@3oool003/0n_3V00<0/1LN0?[`iP3jl>H0103jl>H300000080M>7o00<0000007;No`1bg_l02`1b
g_l00`000000L=[o073Jo`0;073Jo`030000001/d_l0K=;o00P0K=;o1@0000000`1Ua?l00000066m
o`07066mo`D000001@1=U^P400000080@G:W0P2`5ah7045bY`0300000015NK00AGV`00<0AGV`1000
00000`1<QL80000004j9aP0:04j9aP030000001HV]`0F9[L00`0F9[L00D0000005jUjP1NYNX0GZGZ
0000000;06Jdn`@0KL3o0P00000307;8o`<0/1LN0P1bb?l00`2`5ah0L/So0000000307K>o`030000
001fcOl0M/go00<000001`1ebol010000000M<Wo07C9o`00000207;5o`030000001a`ol0LL?o00@0
LL?o0P2`5ah80?[`iP<0/1LN803jl>H00`2`5ah0n_3V0?[`iP0W0?[`iP030;0G7P3jl>H0n_3V03/0
n_3V0@3oool003X0n_3V00<0/1LN0?[`iP3jl>H00P3jl>H3000000H0M>7o00<0000007;No`1bg_l0
2P1bg_l00`000000L=[o073Jo`0<073Jo`040000001/d_l0K=;o06cBo`H000000`1Yc?l010000000
ILCo06G4o`000008066mo`0300000011O/D0@Gk50080@Gk5100000000`1=U^P0000002A9M0020000
0080@G:W00<0/1LN045bY`11LZL01P11LZL00`000000AGV`0000000300000080B7jh00@0000004b5
`P1<QL800000301>RLH00`000000F9[L05RJg00;05RJg0040000001NYNX0GZGZ000000`0I[Ck00<0
000006g0o`1]`?l00P1]`?l30000000307;8o`2`5ah0/1LN0080/1LN00@0L/So0;0G7P1bb?l00000
101fc_l01@000000M/go07K=o`1fcOl0000000L0ML_o00L0000007C9o`1dbOl0M<Wo0000001baOl0
000000H0LL?o00<000000?[`iP3jl>H0203jl>H30;0G7Qh0n_3V0`2`5ahV0?[`iP80/1LN?P3jl>H1
0?ooo`00>P3jl>H00`2`5ah0n_3V00000002000000X0M>7o00<0000007;No`1bg_l02P1bg_l00`00
0000L=[o073Jo`0;073Jo`@000002P1Yc?l00`000000ILCo00000009066mo`0300000011O/D0@Gk5
00D0@Gk51@000009045bY`@000001@18O[P01@000000C8G204b5`P1<QL80000000`0CXW600<00000
05RJg01HV]`02`1HV]`010000000GZGZ05jUjP00000<06Jdn`050000001]`?l0KL3o06g0o`000000
0`1bbOl2000000030;0G7P1bb?l0/1LN00D0/1LN0`1fc_l010000000M/go07K=o`1fcOl2000000D0
ML_o00<0000007C9o`1dbOl00`1dbOl2000000H0LL?o00<000000?[`iP3jl>H0:@3jl>H40;0G7Qh0
n_3V0`2`5ah30?[`iP030;0G7P3jl>H0n_3V03h0n_3V0@3oool003X0n_3V00<0/1LN0000001dhOl0
3@1dhOl00`000000L]ko07;No`0:07;No`030000001`f_l0L=[o00H0L=[o1000000206oGo`030000
001Yc?l0JLco00X0JLco00<0000006G4o`0000002@1Q_Ol00`000000@Gk5045na@07045na@<00000
0P11LZL600000080AW^d00<0000004Qn^018O[P00`18O[P00`000000C8G204b5`P0204b5`P030000
001>RLH0CXW600X0CXW600<0000005RJg01HV]`02`1HV]`00`000000GZGZ0000000<06Jdn`80/1LN
0`1]`?l00`000000L/Wo07;9o`0307;9o`040;0G7P000000L/So07;8o`80/1LN0P1fc_l30;0G7P07
0000001fcOl0M/go07K=o`000000Mloo0000000407G;o`030000001dbOl0M<Wo00@0M<Wo00<00000
0773o`1a`ol0101a`ol00`000000n_3V0?[`iP0Y0?[`iP<0/1LN7`3jl>H00`2`5ah0n_3V0?[`iP03
0;0G7T40n_3V0@3oool003X0n_3V00<0/1LN0000001dhOl03@1dhOl00`000000L]ko07;No`0;07;N
o`040000001`f_l0L=[o073Jo`@000001`1_eol00`000000JLco06W<o`0:06W<o`8000002@1Q_Ol0
0`000000@Gk5045na@07045na@D000002016Nk@00`000000B7jh04Qn^00204Qn^0030000001<QL80
C8G200<0C8G200<0000004j9aP1>RLH02P1>RLH00`000000F9[L05RJg00<05RJg0800000301V]?/3
0;0G7P0306g0o`000000L/Wo00H0L/Wo00D0/1LN0000002`5ah0/1LN0000000607K>o`040000001f
cOl0M/go00000080Mloo0P00000207G;o`030000001dbOl0M<Wo00@0M<Wo0P0000050773o`030000
003jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP0N0?[`iP80/1LN
0P3jl>H20;0G7T40n_3V0@3oool003X0n_3V00<0/1LN0?[`iP0000003P1dhOl00`000000L]ko07;N
o`0:07;No`@000002`1_eol00`000000JLco06W<o`0;06W<o`030000001Q_Ol0HKgo00P0HKgo00<0
0000045na@11O/D01`11O/D3000000T0AW^d00<0000004Qn^018O[P00P18O[P00`000000C8G204b5
`P0304b5`P030000001>RLH0CXW600X0CXW600<0000005RJg01HV]`0301HV]`010000000I[Ck06Jd
n`2`5ah;06Jdn`@0/1LN1`1bbOl20;0G7P0307;9o`000000000000H0M/ko00@0000007K=o`1fcOl0
0000101gcol00`000000ML_o0000000607C9o`030000001caol0000000<0LL?o00<000000?[`iP3j
l>H0103jl>H00`2`5ah0n_3V0?[`iP0>0?[`iP<0/1LN9@3jl>H00`2`5ah0n_3V0?[`iP0<0?[`iPH0
/1LN@@3jl>H10?ooo`00>P3jl>H0102`5ah0n_3V0?[`iP00000>07CQo`030000001bg_l0L]ko00D0
L]ko10000002077Lo`030000001_eol0KmOo00/0KmOo00<0000006W<o`1Yc?l02P1Yc?l200000003
0;0G7P1Q_Ol0HKgo00L0HKgo00<00000045na@11O/D01`11O/D00`000000<55U0000000804Ik]005
00000018O[P0B7jh04Qn^00000001`1<QL800`000000CXW604j9aP0904j9aP030000001HV]`0F9[L
00`0F9[L00<0000006Jdn`2`5ah00P2`5ah:06Jdn`030000001]`?l0000000`0L/Wo0P00000507K>
o`030000001fcOl0000000H0Mloo0P00000207C9o`80/1LN0P1dbOl010000000LlOo07?7o`000002
0773o`030000003jl>H0n_3V0080n_3V0P2`5ahB0?[`iP030;0G7P3jl>H0n_3V0280n_3V0P2`5ah?
0?[`iP<0/1LN00@0n_3V0;0G7P3jl>H0/1LN@03jl>H10?ooo`00>P3jl>H01@2`5ah0n_3V0?[`iP3j
l>H0000000h0M>7o00<0000007;No`1bg_l010000007077Lo`030000001_eol0KmOo00/0KmOo00<0
000006W<o`1Yc?l02@1Yc?l00`000000/1LN066mo`0:066mo`0300000011O/D0@Gk500H0@Gk50P00
00000`0`DFD0000004Ik]00604Ik]00400000018O[P0B7jh000000P0C8G200<0000004j9aP1>RLH0
2P1>RLH01@000000F9[L05RJg01HV]`0/1LN00P0F9[L0P00000206Jdn`030;0G7P1V]?/0I[Ck00X0
I[Ck0P00000;07;9o`030000001hdol0N=?o00800000101fc_l2000000D0Mloo00<0/1LN07O?o`00
00000P2`5ah407C9o`070000001caol0LlOo07?7o`000000LL?o000000030?[`iP80/1LN=`3jl>H0
0`2`5ah0n_3V0?[`iP0?0?[`iP@0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP0n0?[`iP40oooo000j0?[`
iP030;0G7P3jl>H0n_3V0080n_3V00<0000007CQo`1dhOl02`1dhOl3000000`0LMco00<0000006oG
o`1_eol02`1_eol00`000000JLco06W<o`0806W<o`030;0G7P1Ta?l0000000X0HKgo00<00000045n
a@11O/D01P11O/D010000000>fF1031AI@00000704Ik]00300000018O[P0000000T0C8G200<00000
04j9aP1>RLH02P1>RLH00`000000F9[L05RJg00205RJg0030;0G7P1HV]`0F9[L00@0F9[L00<00000
062[lP0000003`1V]?/00`000000L/Wo07;9o`0:07;9o`030000001hdol0N=?o0080N=?o00@00000
07K>o`1fc_l0M/ko0P00000407O?o`@0/1LN00<0000007C9o`1dbOl00`1dbOl00`000000LlOo07?7
o`0207?7o`800000>P3jl>H20;0G7Q@0n_3V1@2`5ai00?[`iP40oooo000j0?[`iP030;0G7P3jl>H0
n_3V00<0n_3V00<0000007CQo`1dhOl01P1dhOl400000080Lmoo00<00000077Lo`1ag?l02`1ag?l0
0`000000KmOo06oGo`0:06oGo`030000001Yc?l0JLco00H0JLco00<000000;0G7P0000003`000007
045na@80000000<0<55U00000016Nk@01@16Nk@2000000X0C8G200<0000004j9aP1>RLH01`1>RLHD
000000d0I[Ck00<0000007;9o`1bbOl02P1bbOl00`000000N=?o07SCo`0307SCo`050000001fc_l0
M/ko07K>o`000000101gcol30;0G7P030000001fc_l0000000@0M<Wo00<0000007?7o`1caol00`1c
aol00`000000n_3V0?[`iP0I0?[`iP030;0G7P3jl>H0n_3V01/0n_3V00<0/1LN0?[`iP3jl>H04@3j
l>H40;0G7T@0n_3V0@3oool003L0n_3V0`2`5ah70?[`iP040000001dhOl0M>7o07CQo`@000001`1c
gol00`000000LMco077Lo`0;077Lo`030000001_eol0KmOo00X0KmOo00@0000006W<o`1Yc?l0JLco
0`0000020;0G7P0306S;o`000000ILCo0080ILCo00<0000005^ao`1K/Ol0201K/Ol5000000<0@Gk5
00D0000003]UP@0`DFD0<55U0000000504Ik]0030000001<QL80C8G200T0C8G200@0000004j9aP1>
RLH0CXW61P00000305RMh@030000001MYN`0GJG/00L0GJG/00D0000006BcoP1T/oh0I;?n00000002
06Zlo`D00000201V]?/00`000000L/Wo07;9o`0:07;9o`030000001hdol0N=?o00@0N=?o0P000000
0`1fc_l0000007O?o`0607O?o`030000001fc_l0M/ko008000000P1dbOl00`000000LlOo07?7o`03
07?7o`030000003jl>H0n_3V01P0n_3V0`2`5ahE0?[`iP030;0G7P3jl>H0n_3V0080n_3V0P2`5ahD
0?[`iP040;0G7P3jl>H0/1LN0;0G7T@0n_3V0@3oool003L0n_3V00<0/1LN0?[`iP2`5ah00`2`5ah5
0?[`iP<00000301cgol00`000000LMco077Lo`0;077Lo`030000001_eol0KmOo00P0KmOo1@000003
0;0G7P<0J<_o00D0000006G4o`1Ua?l0ILCo0000000:05^ao`0300000013PL/0@h7;0080@h7;1000
0000100kIH400000031AI@00000404Ik]08000002@1<QL86000000T0F9gQ00<0000005fUk01MYN`0
1P1MYN`00`000000I;?n06BcoP0306BcoP030000001Z_?l0J[co00@0J[co1@00000206Jdn`030000
001_aOl0000000X0L/Wo00<0000007SCo`1hdol01`1hdol2000000L0Mloo00<0000007K>o`1fc_l0
0P1fc_l00`000000M<Wo0000000507?7o`030000003jl>H0n_3V01L0n_3V0P2`5ah20?[`iP030;0G
7P3jl>H0n_3V0180n_3V1@2`5ahG0?[`iP80/1LN00<0n_3V0;0G7P3jl>H0@P3jl>H10?ooo`00=P3j
l>H01@2`5ah0n_3V0;0G7P2`5ah0n_3V0080/1LN1P3jl>H00`000000Lmoo07?Oo`0;07?Oo`030000
001ag?l0LMco00`0LMco00@0000006oGo`1_eol0KmOo1P00000306_@o`040000001Xbol0/1LN0;0G
7P<0J<_o00<0000006G4o`1Ua?l00`1Ua?l00`000000Fk7o05^ao`0805^ao`0300000013PL/0@h7;
00@0@h7;00H0000003]UP@0kIH400000031AI@00000204Ik]0030000001:Pkl0000000<0C8G21P00
0002052>c`030000001HWN40F9gQ00/0F9gQ00<0000005fUk01MYN`01@1MYN`00`000000I;?n06Bc
oP0306BcoP030000001Z_?l0J[co00T0J[co1@00000:07;9o`030000001hdol0N=?o00L0N=?o0P00
000607O?o`030000001fc_l0M/ko00@0M/ko0P00000507?7o`030000003jl>H0n_3V01H0n_3V1@2`
5ah00`3jl>H0/1LN0?[`iP0A0?[`iP@0/1LN6@3jl>H40;0G7T<0n_3V0@3oool003H0n_3V102`5ah0
0`3jl>H0/1LN0?[`iP070?[`iP030000001cgol0Lmoo00/0Lmoo00<00000077Lo`1ag?l02`1ag?l4
000000X0Jm3o00@000000;0G7P2`5ah0/1LN0P1Xbol00`000000ILCo06G4o`0406G4o`030000001K
/Ol0Fk7o00P0Fk7o00<0000004>1b`13PL/01013PL/010000000>fF10000000`DFD30000000304Z3
_`000000000000<00000201@S/l00`000000F9gQ05RMh@0;05RMh@030000001MYN`0GJG/00@0GJG/
00<0000006BcoP1T/oh0101T/oh00`000000J[co06Zlo`0:06Zlo`030000001bc?l0L/co00<00000
201bbOl00`000000N=?o07SCo`0707SCo`040000001ieOl00000000000@0Mloo00<0000007K>o`1f
c_l01@1fc_l00`000000LlOo07?7o`0307?7o`030000003jl>H0n_3V00L0n_3V00<0/1LN0?[`iP3j
l>H03@3jl>H70;0G7Q40n_3V0`2`5ah00`3jl>H0/1LN0?[`iP0B0?[`iP030;0G7P3jl>H0n_3V04T0
n_3V0@3oool003L0n_3V1@2`5ah90?[`iP030000001cgol0Lmoo00/0Lmoo00<00000077Lo`1ag?l0
1P1ag?l400000080KmSo00<0000006_@o`1[d?l02P1[d?l00`000000J<_o06S;o`0206S;o`030000
001Ua?l0ILCo00@0ILCo00<0000005^ao`1K/Ol02@1K/Ol00`000000@h7;04>1b`0304>1b`050000
000kIH40>fF10000000`DFD00`0000000`1?Rl/00000052>c`0;052>c`030000001HWN40F9gQ00X0
F9gQ00@0000005fUk02`5ah0/1LN0P1MYN`00`000000I;?n06BcoP0606BcoP030000001Z_?l0J[co
00T0J[co00<0000007;<o`1bc?l00P1bc?l0101ed?l0000000000000000507;9o`030000001hdol0
N=?o00H0N=?o00H0000007WEo`1ieOl0000007WCo`00000307O?o`030000001fc_l0M/ko00<0M/ko
00@0/1LN07K>o`0000000000101caol00`000000n_3V0?[`iP060?[`iP<0/1LN3P3jl>H20;0G7P80
n_3V0P2`5ah20?[`iP030;0G7P3jl>H0n_3V00d0n_3V1@2`5ahC0?[`iP030;0G7P3jl>H0n_3V04T0
n_3V0@3oool003P0n_3V0`2`5ah;0?[`iP030000001cgol0Lmoo00/0Lmoo00@00000077Lo`1ag?l0
LMco1000000706oHo`030000001[d?l0Jm3o00T0Jm3o00<0000006S;o`1Xbol00P1Xbol00`000000
ILCo06G4o`0506G4o`030000001K/Ol0Fk7o00P0Fk7o00<0000004>1b`13PL/00`13PL/200000080
>fF10`00000204n;b`030000001@S/l0D8k?00X0D8k?00<0000005RMh@1HWN402P1HWN440;0G7P03
05fUk0000000/1LN00D0/1LN0`1T/oh00`000000J[co06Zlo`0806Zlo`030000001bc?l0L/co00<0
L/co00@0000007G@o`1ed?l0MM3o0`0000000`1bbOl0000007SCo`0607SCo`030;0G7P1hdol0/1LN
0080NMGo00@0000007WCo`1idol000000P1gcol00`000000M/ko07K>o`0207K>o`<0/1LN00<00000
07G<o`0000000`1caol00`000000n_3V0?[`iP070?[`iP030;0G7P3jl>H0n_3V00h0n_3V102`5ah0
0`3jl>H0/1LN0;0G7P0B0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H0B@3jl>H1
0?ooo`00>@3jl>H00`2`5ah0n_3V0?[`iP0;0?[`iP030000001cgol0Lmoo00X0Lmoo1000000;06oH
o`030000001[d?l0Jm3o00X0Jm3o00D0000006S;o`1Xbol0J<_o0000000806G4o`030000001K/Ol0
Fk7o00P0Fk7o00<0000004>1b`13PL/00P13PL/010000000Bh2V0000000kIH4300000080Ch_;00<0
0000052>c`1@S/l0201@S/l00`2`5ah0D8k?0000000505RMh@030;0G7P1HWN40/1LN0080/1LN0P1H
WN460;0G7PT0I;?n00<0000006Zlo`1Z_?l01`1Z_?l00`000000L/co07;<o`0407;<o`030000001e
d?l0MM3o00@0MM3o0P00000707SCo`80/1LN00D0000007WEo`1ieOl0NMGo0000000207WCo`<00000
1@1fc_l00`2`5ah0M/ko0000000207G<o`040000001caol0LlOo000001/0n_3V00@0/1LN0?[`iP2`
5ah0/1LN4`3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V04T0n_3V0@3oool004P0
n_3V00<0000007?Oo`1cgol01@1cgol400000080L]co00<0000006oHo`1_f?l02`1_f?l00`000000
Jm3o06_@o`0:06_@o`030000001Xbol0000000X0ILCo00<0000005^ao`1K/Ol0201K/Ol01`000000
@h7;04>1b`13PL/0000004^0YP0000000P0kIH401P000000<UM/0000001?Rl/0/1LN000000P0D8k?
00@0/1LN052>c`1@S/l00000101HWN430;0G7PD0F9gQ00<0/1LN05fUk02`5ah00P2`5ah;06BcoP03
0000001Z_?l0J[co00H0J[co00<0000007;<o`1bc?l0101bc?l00`000000MM3o07G@o`0407G@o`04
0000001ifOl00000000000L0N=?o00D0000007WEo`1ieOl0NMGo0000000407WCo`030000001fc_l0
M/ko00D0M/ko00L0000007G<o`1ec?l0MLco0000001caol0000001/0n_3V0P2`5ahD0?[`iP030;0G
7P3jl>H0n_3V01D0n_3V0P2`5ai:0?[`iP40oooo00190?[`iP030000001cgol0Lmoo00@000001P1b
g?l00`2`5ah0000006oHo`0<06oHo`030000001[d?l0Jm3o00X0Jm3o0P00000:06G4o`030000001K
/Ol0Fk7o00T0Fk7o00P0000004>1b`13PL/0@h7;0000001;P:H0000003]UP@<000000P1?Rl/20;0G
7PL0D8k?0P2`5ah2052>c`030000001HWN40F9gQ0080F9gQ00<0/1LN05RMh@1HWN401@1HWN430;0G
7P`0I;?n00<0000006Zlo`1Z_?l01@1Z_?l00`000000L/co07;<o`0607;<o`030000001ed?l0MM3o
00<0MM3o00D0000007WIo`1ifOl0NMWo0000000607SCo`050000001ieOl0NMGo07WEo`000000101i
dol2000000D0M/ko00<0000007G<o`1ec?l00`1ec?l2000001H0n_3V0P2`5ah00`3jl>H0/1LN0;0G
7P0C0?[`iP<0/1LN5`3jl>H20;0G7T/0n_3V0@3oool004X0n_3V0P00000907;Lo`040;0G7P1bg?l0
L]co000000d0KmSo00<0000006_@o`1[d?l02P1[d?l00`000000ILCo06G4o`0406G4o`/000001@1K
/Ol01@000000@h7;04>1b`13PL/000000080Bh2V00H0000003]UP@000000<UM/0000001?Rl/20;0G
7P/0D8k?00<0000005RMh@1HWN402P1HWN400`2`5ah0000006BcoP0<06BcoP030000001Z_?l0J[co
00@0J[co00<0000007;<o`1bc?l01`1bc?l00`000000MM3o07G@o`0207G@o`030000001ifOl0NMWo
00<0NMWo0P00000407SCo`030000001ieOl0NMGo0080NMGo00@0000007WCo`1idol000000P1je_l0
0`000000M/ko07K>o`0207K>o`030000001ec?l0MLco00@0MLco00<000000?[`iP3jl>H00P3jl>H0
0`2`5ah0n_3V0?[`iP0>0?[`iP@0/1LN5@3jl>H40;0G7QL0n_3V00<0/1LN0?[`iP3jl>H0B@3jl>H1
0?ooo`00B`3jl>H00`000000L]co07;Lo`0607;Lo`030;0G7P1bg?l0L]co0080L]co00<0000006oH
o`1_f?l02P1_f?l00`000000Jm3o06_@o`0706_@o`X000001P1R_?l00`000000D9_`052Kl002052K
l0X000000`1;P:H200000004039GK0000000Ch_;000000`0D8k?00<0000005RMh@1HWN402P1HWN40
0`000000I;?n06BcoP0=06BcoP030000001Z_?l0J[co00<0J[co00<0000007;<o`1bc?l01`1bc?l0
0`000000MM3o07G@o`0207G@o`030000001ifOl0NMWo00D0NMWo00@0000007SCo`1hdol000001@1i
eOl010000000NM?o07WCo`00000307[Fo`8000000P1fc_l00`000000MLco07G<o`0407G<o`070000
003jl>H0n_3V0?[`iP2`5ah0n_3V0;0G7P0?0?[`iP@0/1LN5@3jl>H20;0G7VD0n_3V0@3oool004`0
n_3V00D0000007;Lo`1bg?l0L]co0;0G7P0207;Lo`030;0G7P1bg?l0L]co00@0L]co00<0000006oH
o`1_f?l02P1_f?l010000000Jm3o06_@o`1[d?l500000080J/go00@0000006K5o`1VaOl000002P1R
_?l00`000000D9_`052Kl009052Kl00300000014Q<l0000000<0Bh2V0`0000000`0bEf`000000000
000<052>c`030000001HWN40F9gQ00T0F9gQ0P00000?06BcoP030000001Z_?l0J[co0080J[co00<0
000007;<o`1bc?l0201bc?l01@000000MM3o07G@o`1ed?l0000000T0NMWo0`00000607WEo`030000
001idol0000000D0N]Ko00<0000007K>o`0000001P1ec?l00`000000n_3V0?[`iP020;0G7P030?[`
iP2`5ah0n_3V0100n_3V0P2`5ail0?[`iP40oooo001=0?[`iP030000001bg?l0L]co0080L]co00<0
/1LN07;Lo`1bg?l01P1bg?l00`000000KmSo06oHo`0806oHo`D000001P1ZcOl01@000000I/Go06K5
o`1VaOl0000000/0H[co00<00000052Kl01@Vo00201@Vo000`000000A8C?0000000404^0YP800000
00<0<UM/0000000000003@1@S/l00`000000F9gQ05RMh@0805RMh@030000001Q[_T0000000h0I;?n
00D0000006Zlo`1Z_?l0J[co0000000<07;<o`040000001ed?l0MM3o000000/0NMWo00<0000007WE
o`1ieOl0101ieOl00`000000NM?o0000000607[Fo`8000001P1ec?l010000000/1LN0;0G7P2`5ah3
0?[`iP030;0G7P3jl>H0n_3V05L0n_3V00<0/1LN0?[`iP3jl>H0<P3jl>H10?ooo`00CP3jl>H01000
0000L]co07;Lo`2`5ah:07;Lo`040000001_f?l0KmSo06oHo`H000000`1/dOl00`000000J/go06[=
o`0506[=o`030000001VaOl0I/Go0080I/Go00<0000006:lo`1R_?l02@1R_?l00`000000D9_`052K
l008052Kl08000001@1;P:H200000003039GK0000000000000T0D8k?6000000806BcoP040000001Z
_?l0J[co000000`0L/co00<0000007G@o`000000301ifOl3000000D0NMGo00<0000007[Fo`1je_l0
0`1je_l0102`5ah0N]Ko07[Fo`00000607G<o`050;0G7P3jl>H0n_3V0;0G7P3jl>H00`2`5ah>0?[`
iP030;0G7P3jl>H0n_3V00l0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP0P0?[`
iP030;0G7P3jl>H0n_3V03<0n_3V0@3oool004l0n_3V00<0000007;Lo`2`5ah02P1bg?l4000000X0
K=7o00<0000006[=o`1ZcOl00`1ZcOl00`000000I/Go06K5o`0406K5o`030000001R_?l0H[co00T0
H[co00<00000052Kl01@Vo001`1@Vo000`000000A8C?0000000404^0YP80000000<0<UM/00000000
00000`1@S/l6000000<0G:K`00<0000005nZm@1OZ_D01P1OZ_D01@000000JKko06Vno`1Y__l00000
00L0Jl7o2@0000000`2`5ah000000000000;07;<o`040;0G7P000000MM3o000000/0NMWo00D00000
07cLo`1lg?l0O=co0000000407WEo`040000001je_l0N]Ko07[Fo`80/1LN00<0N]Ko0;0G7P1je_l0
0P00000407G<o`H0/1LN0`3jl>H00`2`5ah0n_3V0?[`iP0:0?[`iP030;0G7P3jl>H0n_3V0100n_3V
00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0O0?[`iP030;0G7P3jl>H0n_3V03<0n_3V
0@3oool004h0n_3V0`2`5ah707;Lo`@000000P1_e_l00`000000K=7o06cAo`0:06cAo`030000001Z
cOl0J/go0080J/go00<0000006K5o`1VaOl0101VaOl00`000000H[co06:lo`0906:lo`030000001@
Vo00D9_`00P0D9_`0P00000404^0YP<0000000<0<UM/0000000000000P00000:05bVl0030000001O
Z_D0Gj[e00@0Gj[e00<0000006Vno`1Y__l00`1Y__l00`000000Jl7o06_1o`0<06_1o`040000002`
5ah0/1LN07KDo`@000001P1bc?l30;0G7P030000001ifOl0NMWo00T0NMWo0`2`5ah307cLo`800000
0P1ieOl00`000000N]Ko07[Fo`080;0G7P040000001ec?l0MLco07G<o`T0/1LN00<0n_3V0;0G7P3j
l>H0203jl>H20;0G7Q<0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0N0?[`iP03
0;0G7P3jl>H0n_3V03@0n_3V0@3oool004`0n_3V1P2`5ah207;Lo`@000001`1_e_l00`000000K=7o
06cAo`0906cAo`050000001ZcOl0J/go06[=o`000000201VaOl00`000000H[co06:lo`0906:lo`03
0000001@Vo00D9_`00P0D9_`00<0000004^0YP1;P:H00`1;P:H200000003039GK0000000G:K`00`0
G:K`00<0000005nZm@1OZ_D00`1OZ_D00`000000JKko06Vno`0406Vno`030000001[`Ol0Jl7o00`0
Jl7o00<0000007KDo`1fe?l01@1fe?l3000000@0L/co00<0/1LN07;<o`0000002`1ifOl00`000000
/1LN07cLo`0507cLo`@000000P1je_l20;0G7P0307[Fo`2`5ah0/1LN00<0NM?o00P0000007G<o`1e
c?l000000;0G7P3jl>H0/1LN0?[`iP/0/1LN0`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP80/1LN5@3j
l>H30;0G7PD0n_3V0`00000E0?[`iP030;0G7P3jl>H0n_3V03@0n_3V0@3oool004`0n_3V1@2`5ah0
0`3jl>H000000000000<06oFo`030000001/dOl0K=7o00T0K=7o00@0000006[=o`1ZcOl000002@1V
aOl00`000000H[co06:lo`0906:lo`030000001@Vo00D9_`00@0D9_`00<0/1LN052Kl01@Vo000P00
000404^0YP050000002`5ah0/1LN039GK0000000301LY_0010000000Gj[e05nZm@1OZ_D2000000L0
JKko00<0000006_1o`1[`Ol02`1[`Ol00`000000Lm7o07KDo`0907KDo`@0000000@0L/co0000001h
eol000002P1ifOl00`000000O=co07cLo`0707cLo`8000000P1je_l40;0G7P030000001idol0NM?o
0080NM?o00H0000007G<o`000000/1LN0?[`iP2`5ah50?[`iP<0/1LN1P3jl>H30;0G7Q@0n_3V0P2`
5ahE0?[`iP80/1LN103jl>H00`0000001PdB0000000205J/jP<000004@3jl>H00`2`5ah0n_3V0?[`
iP0e0?[`iP40oooo000g0?[`iP030;0G7P3jl>H0n_3V0180n_3V1@2`5ah20?[`iP030000001_e_l0
KmKo00/0KmKo00<0000006cAo`1/dOl02@1/dOl2000000/0I/Go00<0000006:lo`1R_?l02@1R_?l0
10000000D9_`052Kl01@Vo020;0G7P<0D9_`00<0000005BA_00000000P1;P:H20;0G7P04045_SP00
0000<UM/000000`0G:K`00@0000005nZm@1OZ_D000002P1Y__l00`000000Jl7o06_1o`0906_1o`04
0000001cdOl0Lm7o000000d0M]Co1000000907WIo`030000001lg?l0O=co00P0O=co0`00000207[F
o`040;0G7P1je_l0N]Ko000000D0NM?o0P0000000`3jl>H0/1LN0;0G7P050?[`iP80/1LN>@3jl>H0
100000001PdB00000000000305J/jP80000000<0LnGo0000003jl>H03`3jl>H00`2`5ah0n_3V0?[`
iP0e0?[`iP40oooo000f0?[`iP030;0G7P3jl>H0n_3V01<0n_3V102`5ah40?[`iP030000001_e_l0
KmKo00X0KmKo00<0000006cAo`1/dOl02P1/dOl00`000000I/Go06K5o`0906K5o`030000001R_?l0
H[co00T0H[co00@000000;0G7P1@Vo00/1LN0P1@Vo001@2`5ah0D9_`052Kl0000000E96l00<0/1LN
00L0Bh2V00000011Khh0@Fn>0000000bEf`0000000`0G:K`0P00000;06Vno`030000001[`Ol0Jl7o
00P0Jl7o00D0000007?Ao`1cdOl0Lm7o0000000=07KDo`030000001jgol0N]oo00800000201ifOl0
0`000000O=co07cLo`0707cLo`040000001mgOl0OMgo000000D0N]Ko00<0000007WCo`1idol0101i
dol01@000000n_3V0;0G7P3jl>H0/1LN00<0n_3V00<0/1LN0?[`iP3jl>H0=`3jl>H01`0000001PdB
0000000000003aTT0000001F[>X00P0000001@1ciOl000000000001il?l0000000h0n_3V00<0/1LN
0?[`iP3jl>H0=P3jl>H10?ooo`00=@3jl>H00`2`5ah0n_3V0?[`iP0M0?[`iP030000001_e_l0KmKo
00X0KmKo00<0000006cAo`1/dOl0201/dOl00`000000JL[o0000000606K5oa0000000`2`5ah20000
0080/1LN00H0D9_`0;0G7P2`5ah0/1LN05BA_000000204^0YP0300000011Khh0@Fn>00<00000301L
Y_000`000000JKko06Vno`0:06Vno`030000001[`Ol0Jl7o00L0Jl7o00<0000007?Ao`1cdOl00`1c
dOl00`000000M]Co07KDo`0907KDo`030000001jgol0N]oo0080N]oo0`00000507WIo`030000001l
g?l0O=co00P0O=co00D0000007gMo`1mgOl0OMgo0000000407[Fo`030000001idol0NM?o00@0NM?o
00<000000?[`iP3jl>H00P2`5ah20?[`iP030;0G7P3jl>H0n_3V03H0n_3V00@0000000H=4P000000
00000P0?6B@300000080LnGo00<0000007W`o`1il?l00P1il?l2000000`0n_3V00<0/1LN0?[`iP3j
l>H0=P3jl>H10?ooo`00=@3jl>H00`2`5ah0n_3V0?[`iP0N0?[`iP030000001_e_l0KmKo00X0KmKo
00<0000006cAo`1/dOl01P1/dOl00`000000JL[o00000007000000H0H[[o00<0000005JVo@1FY_d0
1`1FY_d30;0G7P0304nHjP2`5ah0/1LN0080/1LN0P00000305BA_0030000001;P:H0000000<0@Fn>
00<0=emh0000000000002@1LY_03000000d0JKko00<0000006_1o`1[`Ol01@1[`Ol00`000000Lm7o
07?Ao`0407?Ao`030000001fe?l0M]Co00P0M]Co00<0000007[Oo`1jgol0101jgol010000000O=ko
00000000000307WIo`030000001lg?l0O=co00P0O=co00<0000007gMo`1mgOl00P1mgOl010000000
N]Ko07[Fo`00000707WCo`030000003jl>H0n_3V00@0/1LN=`3jl>H4000000@03aTT00D0000007?U
o`1ciOl0LnGo0000000707W`o`030000003jl>H0n_3V00P0n_3V0P2`5ahh0?[`iP40oooo000d0?[`
iP030;0G7P3jl>H0n_3V01l0n_3V00<0000006oFo`1_e_l02`1_e_l00`000000K=7o06cAo`0206cA
o`D000000`1U`_l00`000000H[[o06:jo`0806:jo`030000001FY_d0EZKm00T0EZKm00<0000004nH
jP2`5ah00`2`5ah00`1?V>X0000005BA_00305BA_0030000001;P:H000000080@Fn>0`00000805bV
l0050000001V^Ol0I[Wo06Jio`000000301Y__l00`000000Jl7o06_1o`0406_1o`030000001cdOl0
Lm7o00H0Lm7o00<0000007KDo`1fe?l01`1fe?l00`000000N]oo07[Oo`0407[Oo`040000001lg_l0
O=ko07cNo`<000002P1lg?l00`000000OMgo07gMo`0307gMo`@000001P1idol00`000000n_3V0?[`
iP020?[`iP030;0G7P3jl>H0n_3V03D0n_3V0`00000700lI90040000001ciOl00000000000D0NO3o
0P00000207kho`030000003jl>H0n_3V0080n_3V00<0/1LN0?[`iP2`5ah0102`5ahh0?[`iP40oooo
000c0?[`iP030;0G7P3jl>H0n_3V0240n_3V00<0000006oFo`1_e_l02P1_e_l50000000306[=o`00
0000IL;o00D0IL;o00<0000006:jo`1R^_l02@1R^_l00`000000EZKm05JVo@0805JVo@030000001?
V>X0CiSZ00@0CiSZ0P00000405BA_08000000P11Khh4000000D0G:K`0P00000406Jio`030000001Y
__l0JKko00/0JKko00<0000006_1o`1[`Ol00P1[`Ol00`000000Lm7o07?Ao`0707?Ao`030000001f
e?l0M]Co00H0M]Co00<0000007[Oo`1jgol01P1jgol00`000000O=ko07cNo`0207cNo`030000001l
g?l0O=co00P0O=co00<0000007gMo`1mgOl00`1mgOl00`000000/1LN07_Io`020;0G7PD0NM?o00<0
00000?[`iP3jl>H01`3jl>H00`2`5ah0n_3V0?[`iP0^0?[`iP<000002@0?6B@2000000D0NO3o0P00
000507kho`080000003jl>H0n_3V0?[`iP2`5ah0n_3V0;0G7P3jl>H30;0G7SP0n_3V0@3oool00380
n_3V00<0/1LN0?[`iP3jl>H08`3jl>H00`000000KmKo06oFo`0506oFo`@0000000<0K<oo0000001Z
cOl00P1ZcOl00`000000IL;o06G2o`0606G2o`030000001R^_l0H[[o00P0H[[o00<0000005JVo@1F
Y_d02@1FY_d00`000000CiSZ04nHjP0304nHjP8000001@1DTK`01`000000@Fn>045_SP11Khh00000
03IMM@0000000`1LY_02000000H0I[Wo00<0000006Vno`1Y__l01`1Y__l01@2`5ah0JKko06Vno`1Y
__l0000000<0Jl7o00<0000007?Ao`1cdOl0201cdOl00`000000M]Co07KDo`0507KDo`030000001j
gol0N]oo00L0N]oo00H0000007cNo`1lg_l0O=ko00000020iol2000000L0O=co00<0000007gMo`1m
gOl0101mgOl30;0G7P8000001@1idol00`000000n_3V0?[`iP070?[`iP030;0G7P3jl>H0n_3V0100
n_3V00<0/1LN0?[`iP3jl>H06P3jl>H00`00000031@L0000000900lI908000000`1il?l3000000P0
O_So00D000000?[`iP3jl>H0/1LN0?[`iP030;0G7P80n_3V00<0/1LN0?[`iP3jl>H0=@3jl>H10?oo
o`00<P3jl>H00`2`5ah0n_3V0?[`iP0T0?[`iP030000001_e_l0KmKo00@000001P1/col010000000
J/go06[=o`00000906G2o`030000001R^_l0H[[o00P0H[[o00<0000005JVo@1FY_d0201FY_d00`00
0000CiSZ04nHjP0204nHjP0300000015Pl`0000000D0E96l0P000002045_SP060000000fGGD00000
0000001LY_0000002@1V^Ol00`000000JKko06Vno`0506Vno`<0/1LN0P1Y__l010000000Jl7o06_1
o`00000<07?Ao`030000001fe?l0M]Co00<0M]Co00<0000007[Oo`1jgol01`1jgol00`2`5ah0N]oo
0000000207cNo`0400000020iol0P>Oo083Wo`8000001@1lg?l00`000000OMgo07gMo`0507gMo`80
00000P1lfol00`000000NM?o07WCo`0207WCo`030000003jl>H0n_3V00L0n_3V0P2`5ahB0?[`iP03
0;0G7P3jl>H0n_3V0140n_3V0P2`5ah40?[`iP80000000<031@L0000000?6B@0200?6B@200000080
NO3o0P00000<07kho`030000003jl>H0/1LN0080n_3V1@2`5ahg0?[`iP40oooo000a0?[`iP030;0G
7P3jl>H0n_3V02H0n_3V0P00000:06c?o`030000001ZcOl0000000X0IL;o00<0000006:jo`1R^_l0
201R^_l00`000000EZKm05JVo@0905JVo@070000001?V>X0CiSZ04nHjP000000AH?<0000000505BA
_08000000P11Khh20000000303IMM@000000000000X0I[Wo00<0000006Vno`1Y__l01P1Y__l00`2`
5ah0JKko06Vno`0206Vno`8000001@1cdOl30;0G7PD0Lm7o00H0000007KDo`1fe?l0M]Co0;0G7P00
000807[Oo`<0/1LN00@0N]oo0000001lg_l000001P20iol2000000<0O=co00<0000007gMo`1mgOl0
1P1mgOl01@000000O=_o07cKo`1lfol0000000<0NM?o00<000000?[`iP3jl>H06`3jl>H20;0G7Q80
n_3V102`5ah2000000<031@L00<0000000lI900?6B@01@0?6B@20000000401leD000000000000000
00l0O_So00@000000?[`iP2`5ah0n_3V0`2`5ahi0?[`iP40oooo000`0?[`iP030;0G7P3jl>H0n_3V
02P0n_3V00<0000006c?o`1/col02@1/col00`000000IL;o06G2o`0206G2o`030;0G7P1U`_l0IL;o
00D0IL;o00<0000006:jo`1R^_l0201R^_l00`000000EZKm05JVo@0805JVo@040000001?V>X0CiSZ
00000080AH?<00<0000005BA_01DTK`00`1DTK`00`000000D8Vb00000002045_SP040000000fGGD0
=Uee000000X0I[Wo00<0000006Vno`1Y__l02`1Y__l00`000000Lm7o07?Ao`0407?Ao`030;0G7P1c
dOl0Lm7o00H0Lm7o00D000000;0G7P2`5ah0/1LN07[Oo`040;0G7P80N]oo0`2`5ah207[Oo`040;0G
7P1jgol00000000000P0P>Oo0`00000907gMo`030000001lfol0O=_o0080O=_o00<0000007WCo`00
00007P3jl>H20;0G7Q40n_3V00@0/1LN0?[`iP2`5ah0n_3V0P2`5ah400`D70030000000?6B@03aTT
00<03aTT0P00000301leD0030000001mmol0000000`0O_So0P00000207kgo`030000002`5ah0n_3V
03`0n_3V0@3oool002l0n_3V00<0/1LN0?[`iP3jl>H0:@3jl>H00`000000K<oo06c?o`0806c?o`03
0000001Wa_l000000080IL;o00<0/1LN06G2o`1U`_l01P1U`_l00`2`5ah0H[[o06:jo`0906:jo`03
0000001FY_d0EZKm00P0EZKm00<0000004nHjP0000000P15Pl`00`000000E96l05BA_00305BA_005
0000001@RK80D8Vb00000011Khh00P0000000`0fGGD0000006Jio`0:06Jio`030000001Y__l0JKko
00T0JKko00<00000073>o`0000003P1cdOl00`000000/1LN0;0G7P020;0G7P@0N]oo0P2`5ah207[O
o`060;0G7P1jgol0N]oo0;0G7P1jgol000000`20iol40;0G7P@0P>Oo00<0000007gMo`1mgOl01`1m
gOl2000000@0O=_o0P00000`0?[`iPH0/1LN1@0<51`00`0000003aTT00lI9003000000<07cE@00<0
000002DoGP0000000P1mmol00`000000O_So07kho`0707kho`8000001@1nmol00`2`5ah0n_3V0?[`
iP0k0?[`iP40oooo000/0?[`iP80/1LN00<0n_3V0;0G7P3jl>H0:`3jl>H00`000000K<oo06c?o`06
06c?o`060000001Wa_l0IlKo0000001U`_l0/1LN1`1U`_l20;0G7P0306G2o`000000H[[o00T0H[[o
00<0000005JVo@1FY_d0201FY_d2000000<0AH?<0P00000405BA_0040000001@RK80D8Vb0529/P<0
00000P0fGGD00`000000I[Wo06Jio`0206Jioa<0000000<0L<ko0000001cdOl03P1cdOl00`000000
/1LN0;0G7P0507[Oo`80/1LN00@0N]oo0;0G7P1jgol0N]oo1`2`5ah7083Wo`0300000022k?l00000
00L0OMgo00<0000007kPo`0000001@1lfol00`000000n_3V0?[`iP0_0?[`iP@0/1LN1@0<51`01000
00003aTT00000000000501leD0040000000U?eh09CmN000000<0OOOo00<0000007kho`1nn?l00`1n
n?l3000000L0O_Oo00<0/1LN0?[`iP3jl>H0>`3jl>H10?ooo`00:P3jl>H30;0G7P030?[`iP2`5ah0
n_3V02`0n_3V00<0000006c?o`1/col01@1/col00`000000IlKo06O6o`0206O6o`030;0G7P1U`_l0
IL;o00@0IL;o0P2`5ah406G2o`030000001R^_l0H[[o00P0H[[o00<0000005JVo@1FY_d0201FY_d0
1`000000AH?<04F3c015Pl`0000005ZJb@0000000`1DTK`02@000000D8Vb0529/P1@RK800000045_
SP0mJXL0000003IMM@05000000H0K<Oo00<0000006k;o`1^bol01`1^bol00`000000LmCo07?Do`06
000000/0Lm7o00<0000007[Oo`1jgol01P1jgol50;0G7P0507[Oo`000000/1LN07kVo`0000002@20
iol00`000000P^co08;/o`02000000D0OMgo00@0000007kPo`1nh?l00000101lfol00`000000n_3V
0?[`iP0T0?[`iP030;0G7P3jl>H0n_3V00H0n_3V00D0000000H=4P00000031@L0;0G7P0600`D7080
00001@0O=E02000000<09CmN00<0000007ggo`1mmol00P1mmol00`000000O_So07kho`02000000T0
O_Oo102`5ahk0?[`iP40oooo000Z0?[`iPD0/1LN;P3jl>H00`000000K<oo06c?o`0206c?o`800000
0`1Wa_l20;0G7P0306O6o`000000IL;o0080IL;o0P2`5ah606G2o`030000001R^_l0H[[o00P0H[[o
00<0000005JVo@1FY_d01`1FY_d00`000000CI?R0000000204F3c0040000001JV/T0FY[9000000<0
E96l00@000000529/P1@RK80D8Vb0`0000000`0fGGD000000000000:06c7o`030000001^bol0K/_o
00@0K/_o0P00000607?Do`030000001ffOl0M]Wo00H00000101cdOl00`000000N=co0000000707[O
o`80/1LN0`1jgol40;0G7P0307kVo`000000P>Oo00H0P>Oo00<0000008;/o`22k?l00`22k?l00`00
0000OMgo07gMo`0207gMo`040000001nh?l0O^3o000000@0O=_o00<000000?[`iP3jl>H08`3jl>H0
0`2`5ah0n_3V0?[`iP060?[`iP<000001`0<51`3000000D07cE@00<0000002DoGP0U?eh00P0U?eh0
0`000000OOOo07ggo`0407ggo`8000002P1nmol40;0G7P030000003jl>H0n_3V03T0n_3V0@3oool0
02X0n_3V0`2`5ah20?[`iP030;0G7P3jl>H0n_3V02`0n_3V00@0000006c?o`1/col000000`1Wa_l2
0;0G7P@0IlKo00<000000;0G7P2`5ah01`1U`_lG0000000504fChP000000AH?<04F3c00000000P1J
V/T01@000000E96l05BA_01DTK`0000000@0D8Vb00D0000003eZQ`000000=Uee0000000:06c7o`03
0000001^bol0K/_o00<0K/_o00<0000007?Do`1ce?l01P1ce?l00`000000M]Wo07KIo`0607KIo`D0
000000<0N=co0000001jgol01`1jgol01@2`5ah0N]oo07[Oo`1jgol000000080/1LN0P1ni_l00`00
0000P>Oo083Wo`04083Wo`030;0G7P000000P^co00D0P^co00D0000007gMo`1mgOl0OMgo00000003
07kPo`050000001lfol0O=_o07cKo`000000903jl>H00`2`5ah0n_3V0?[`iP060?[`iP80000000<0
2Q4H0000000<51`0100<51`2000000808CQD00<0000001leD00O=E000P0O=E000`0000009CmN02Do
GP0302DoGP040000001mmol0OOOo07ggo`8000000P20n_l00`000000O_Oo07kgo`0907kgo`<0/1LN
0P00000j0?[`iP40oooo000Z0?[`iPL0/1LN;@3jl>H00`000000K<oo0000000306O6o`@0/1LN0P1W
a_l20;0G7P<0IL;o1P00000205VYoP030000001HY_X0F:Kj00P0F:Kj00<0000005:LkP1BW>h0101B
W>h00`000000AH;904F2b@05000000<0FY[900@0000005BA_01DTK`00000101@RK830000000303IM
M@000000K<Oo00X0K<Oo00D0000006k;o`1^bol0K/_o0000000:07?Do`030000001ffOl0M]Wo00L0
M]Wo00<0000007[So`1jhol01000000607[Oo`80/1LN00<0N]oo0;0G7P2`5ah01@1ni_l00`000000
P>Oo083Wo`02083Wo`<0/1LN1`22k?l3000000D0O^3o00<0000007cKo`000000903jl>H00`2`5ah0
n_3V0?[`iP050?[`iP8000000P0:4AP00`00000031@L00`D700200`D708000000`0Q>5@010000000
7cE@01leD00O=E02000000H09CmN00@0000007ggo`00000000001@20n_l00`2`5ah0O_Oo07kgo`08
07kgo`030000002`5ah000000080OOGo00<000000?[`iP3jl>H0=`3jl>H10?ooo`00:P3jl>H50;0G
7S00n_3V00<0000006O6o`1Wa_l00P1Wa_l60;0G7PD000002@1IZOh00`000000F:Kj05RVnP0805RV
nP030000001BW>h0DYc^0080DYc^00<0000004F2b@15P/T00`15P/T00`000000@GZn0000000405ZJ
b@030000001DTK`0000000@0D8Vb0P000000100mJXL0000000000000000:06c7o`040000001^bol0
0000000000/0LmCo00<0000007KIo`1ffOl01P1ffOl00`000000N^?o07[So`0407[So`@00000101j
gol20;0G7PL0O^Ko00<00000083Wo`20iol00`20iol00`2`5ah0P^co08;/o`0808;/o`030000001n
h?l0O^3o0080O^3o00@0/1LN0000001lfol000008@3jl>H30;0G7PL0n_3V0P00000300XA60030000
000<51`031@L008000001@0Q>5@0100000007cE@01leD000000802DoGP8000002020n_l00`2`5ah0
O_Oo07kgo`0407kgo`<000001P1mmOl00`000000n_3V0?[`iP0f0?[`iP40oooo000Z0?[`iP80/1LN
=03jl>H01@000000IlKo06O6o`1Wa_l0000000<0/1LN0P00000305ndo`/0FJWn00<0000005RVnP1H
Y_X0201HY_X01@000000DYc^05:LkP1BW>h0000000L0AH;90P00000505ZJb@800000101@RK800`00
0000@W:B0000000200000003035EJ01/aol0K<Oo00T0K<Oo00<0000007?Do`1ce?l0301ce?l00`00
0000M]Wo07KIo`0407KIo`030000001jhol0N^?o00D0N^?o00@0000007cTo`1li?l0O>Co0`000002
07[Oo`030000001ni_l0O^Ko00H0O^Ko00D00000083Wo`20iol0P>Oo0000000:08;/o`0400000022
jOl0000000000080O^3o0P2`5ah200000240n_3V0P2`5ah60?[`iP800000100:4AP01000000031@L
000000000007024hE0<00000200U?eh2000000T0P?[o00@0/1LN0000001nmol0O_Oo0`00000907ge
o`030000003jl>H0n_3V03H0n_3V0@3oool00640n_3V0`0000050;0G7P@0GkCo00<0000005VYoP1I
ZOh02@1IZOh00`000000F:Kj05RVnP0805RVnP040000001BW>h0DYc^000000L0AH;90P00000605ZJ
b@030000001@RK80D8Vb0080D8Vb00<00000049bTP12LY800P0000000`0aEFP0K<Oo06c7o`0706c7
o`80000000<0M=So0000001ce?l0301ce?l00`000000M]Wo07KIo`0207KIo`8000002@1jhol00`00
0000O>Co07cTo`0307cTo`<00000201ni_l01@000000P>Oo083Wo`20iol0000000X0P^co00D00000
08;Yo`22jOl0P^Wo0000000207kPo`030;0G7P000000000000h0n_3V0P2`5ah@0?[`iP@0/1LN103j
l>H2000000@02Q4H0`000009024hE0030000000U?eh09CmN00H09CmN0P0000000`0XAFL00000083j
o`09083jo`030;0G7P000000000000d0OOGo00<000000?[`iP3jl>H0=@3jl>H10?ooo`00HP3jl>H0
10000000GkCo05ndo`1O]?l30;0G7PD0GkCo00<0000005VYoP1IZOh0201IZOh00`000000F:Kj05RV
nP0805RVnP030000001BW>h0000000P0AH;90P00000605ZJb@8000000`1@RK801`000000@W:B049b
TP12LY800000035EJ00000001P1/aol2000000<0M=So00<0000007?Do`1ce?l0301ce?l010000000
M]Wo07KIo`00000;07[So`030000001li?l0O>Co00<0O>Co00<00000083]o`20kOl00P00000707kV
o`0300000020iol0000000X0P^co00<0000008;Yo`22jOl00`22jOl01@000000O^3o07kPo`1nh?l0
000000d0n_3V0`2`5ah?0?[`iP<0/1LN103jl>H2000000@02Q4H0P0000000`0F93T00000024hE008
024hE08000001P0U?eh2000000<0:4EW00<00000083jo`20n_l01P20n_l20000000307oho`2`5ah0
000000h0OOGo00<000000?[`iP3jl>H0=03jl>H10?ooo`00C@3jl>H00`2`5ah0n_3V0?[`iP0B0?[`
iP030000001O]?l0GkCo00T0GkCo00<0000005VYoP1IZOh02@1IZOh00`000000F:Kj05RVnP0805RV
nP0300000015P/T0AH;900P0AH;900<0000005ZJb@1JV/T0101JV/T2000000<0D8Vb00@00000049b
TP12LY80@W:B0P0000000`0aEFP0K<Oo06c7o`0206c7o`80000000@0M=So0;0G7P2`5ah0/1LN0P1d
f?l00`000000LmCo07?Do`0;07?Do`030000001ffOl0000000d0N^?o00<0000007cTo`1li?l00P00
0005083]o`8000001@1ni_l00`000000P>Oo0000000:08;/o`0300000022jOl0P^Wo00@0P^Wo0`00
000>0?[`iP@0/1LN303jl>H20;0G7P070?[`iP2`5ah0n_3V0;0G7P3jl>H0/1LN0000000400XA6080
00000`0F93T00`0000008CQD024hE006024hE0030000000T?E`0000000<09CmN0`00000502Q5I`03
00000020n_l0P?[o00@0P?[o0P00000307oho`030;0G7P1on?l0000000d0OOGo0P00000e0?[`iP40
oooo001<0?[`iP030;0G7P3jl>H0n_3V00@0n_3V00<0/1LN0?[`iP3jl>H03@3jl>H00`000000GkCo
05ndo`0905ndo`030000001IZOh0FJWn00P0FJWn00<0000005RVnP1HY_X01`1HY_X2000000X0AH;9
00<0000005ZJb@1JV/T0101JV/T00`000000EiC1000000030529/P0700000012LY80@W:B049bTP00
0000<EEX06c7o`060;0G7P<0M=So00<0/1LN07CHo`0000003P1ce?l00`000000N^?o07[So`0<07[S
o`030000001li?l0000000T0P>go0P00000407kVo`0300000022k?l0P^co00P0P^co00<0000008;Y
o`22jOl01`22jOl00`000000n_3V0?[`iP080?[`iP80/1LN0P3jl>H30;0G7P`0n_3V00@0/1LN0?[`
iP3jl>H0/1LN0P3jl>H20;0G7P8000000P0:4AP2000000D05R@i00<00000024hE00Q>5@01@0Q>5@0
1@00000093eL02@mG00000009CmN00800000200XAFL010000000P?[o083jo`20n_l3000000H0OoSo
0`2`5ah907geo`<000000P1mlol010000000n_3V0?[`iP2`5aha0?[`iP40oooo001;0?[`iP030;0G
7P3jl>H0n_3V00<0n_3V0P2`5ah@0?[`iP030000001O]?l0GkCo00T0GkCo00<0000005VYoP1IZOh0
2@1IZOh00`000000F:Kj05RVnP0405RVnP8000000P1<S]T00`000000AH;904F2b@0704F2b@030000
001JV/T0FY[900@0FY[900@0000005ND`@1GU<4000000P1@RK800`000000@W:B049bTP02049bTP04
035EJ02`5ah0/1LN0;0G7PD0M=So0`2`5ah207CHo`030000001ce?l0LmCo00D0LmCo0`2`5ah01@1c
e?l000000000001ih_l0000000h0N^?o00<00000083]o`20kOl02P20kOl20000000307kVo`000000
000000T0P^co00<0000008;Yo`22jOl01`22jOl00`000000n_3V0?[`iP050?[`iP@0/1LN1@3jl>H0
0`2`5ah0n_3V0?[`iP0:0?[`iP80/1LN0P3jl>H30;0G7P040?[`iP2`5ah0000000XA608000001`0F
93T00`0000008CQD024hE003024hE08000000P0T?E`3000000X0:4EW00@00000083jo`0000000000
2@1on?l30;0G7PH0OOGo0`00000607gco`030000003jl>H0/1LN0340n_3V0@3oool004X0n_3V00<0
/1LN0?[`iP3jl>H00P3jl>H20;0G7Q<0n_3V00<0000005ndo`1O]?l02@1O]?l00`000000FJWn05VY
oP0805VYoP030000001HY_X0F:Kj00<0F:Kj00<0000004b>f@1<S]T00P1<S]T00`000000AH;904F2
b@0704F2b@8000001@1JV/T01`000000EiC105ND`@1GU<4000000529/P0000001012LY8010000000
<EEX0;0G7P2`5ah307CHo`<0/1LN0P1df?l0102`5ah0M=So07CHo`00000207?Do`@0/1LN0P1ce?l2
000000<0NN;o00@0000007[So`1jhol0N^?o0P2`5ah807[So`030000001mj?l0000000d0P>go0P00
00000`21k?l0000008;/o`0708;/o`0300000022jOl0P^Wo00L0P^Wo00<000000?[`iP3jl>H0103j
l>H20;0G7Q@0n_3V00<0/1LN0?[`iP2`5ah0202`5ah00`0000005R@i01HT>@0601HT>@030000000Q
>5@08CQD00<08CQD00<0000002@mG00T?E`00P0000000`0V@f<0000002Q5I`0:02Q5I`8000002`1o
n?l30;0G7P030000001mmOl0OOGo00<000002@1mlol00`000000n_3V0;0G7P0a0?[`iP40oooo0019
0?[`iP030;0G7P3jl>H0n_3V0080n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`000000GkCo05ndo`09
05ndo`030000001IZOh0FJWn00T0FJWn00D0000005RVnP1HY_X0F:Kj0000000604b>f@0300000015
P/T0AH;900H0AH;900<0000005fPd0000000101JV/T01`000000EiC105ND`@1GU<4000000529/P00
00001012LY800`000000<EEX07CHo`0407CHo`030;0G7P1df?l0/1LN0080M=So00<0/1LN07CHo`2`
5ah00`2`5ah407?Do`8000001P1ih_l01@000000N^?o07[So`1jhol0/1LN00H0N^?o0P00000207gX
o`0300000020kOl0P>go00/0P>go00@0000008?bo`00000000001`22k?l00`000000P^Wo08;Yo`07
08;Yo`030000003jl>H0n_3V01/0n_3V00H0/1LN0?[`iP3jl>H0/1LN0?[`iP2`5ah3000000030;0G
7P0000005R@i00P05R@i00<00000024hE00Q>5@00P0Q>5@4000000<09T=S00<0000002Q5I`0XAFL0
2@0XAFL2000000`0OoSo0P2`5ah3000000d0OO?o00<000000?[`iP2`5ah0<03jl>H10?ooo`00B03j
l>H0102`5ah0n_3V0?[`iP3jl>H20;0G7QL0n_3V00<0000005ndo`1O]?l02@1O]?l00`000000FJWn
05VYoP0805VYoP040000001HY_X00000000000L0C8kI00<0000004F2b@15P/T01P15P/T010000000
GJ3@05fPd000000305ZJb@030000001GU<40EiC10080EiC10P000004049bTP<00000101df?l20;0G
7P0307CHo`2`5ah0/1LN0080/1LN0P1df?l010000000LmCo07?Do`1ce?l2000000T0NN;o00<00000
07[So`1jhol01P1jhol00`000000ONSo07gXo`0307gXo`0300000020kOl0P>go00P0P>go0P000004
08?bo`0300000022k?l0P^co00@0P^co00<0000008;Yo`22jOl01`22jOl00`000000n_3V0?[`iP0K
0?[`iP040;0G7P3jl>H0n_3V0?[`iP80/1LN00D01`dB0000002`5ah041/Y0000000901HT>@040000
000Q>5@08CQD024hE08000001P0V@f<00`000000:4EW02Q5I`0902Q5I`0300000021o?l0000000/0
OoSo0P00000207kfo`030000001mlol0OO?o00`0OO?o00<000000;0G7P3jl>H0;`3jl>H10?ooo`00
A03jl>H40;0G7P80n_3V0P2`5ahJ0?[`iP030000001O]?l0GkCo00P0GkCo00<0000005VYoP1IZOh0
2@1IZOh00`000000C8kI04b>f@0704b>f@0300000015P/T0AH;900H0AH;900@0000005fPd01MX=00
00000`1JV/T00`000000EiC105ND`@0305ND`@0300000012LY80@W:B0080@W:B0P0000000`0aEFP0
M=So07CHo`0207CHo`L0/1LN0P1df?l010000000LmCo00000000000;07WRo`030000001jhol0N^?o
00D0N^?o00<0000007gXo`1mj?l01@1mj?l00`2`5ah0P>go083]o`06083]o`0300000023l_l0Po;o
00D0Po;o0P00000308;/o`0300000022jOl0P^Wo00L0P^Wo00<000000?[`iP3jl>H0703jl>H20;0G
7P80n_3V00H000000;0G7P2`5ah0/1LN010K:@00000:01HT>@040000000Q>5@00000000000P09T=S
00<0000002Q5I`0XAFL02@0XAFL00`000000POco0000000907oho`8000001@1nm_l00`000000OO?o
07gco`0;07gco`030000002`5ah0n_3V02l0n_3V0@3oool004@0n_3V0`2`5ah20?[`iP030;0G7P3j
l>H0n_3V01X0n_3V00<0000005ndo`1O]?l02@1O]?l00`000000FJWn05VYoP0705VYoP8000002P1<
S]T00`000000AH;904F2b@0504F2b@050000001MX=00GJ3@05fPd00000000P1JV/T00`000000EiC1
05ND`@0305ND`@8000000`12LY84000000@0M=So0P2`5ah00`1df?l0/1LN0;0G7P0407CHo`030000
001ih_l0NN;o00`0NN;o00<0000007[So`1jhol00`1jhol00`000000ONSo07gXo`0507gXo`<0/1LN
1P20kOl00`000000Po;o08?bo`0708?bo`<0000000<0P^co00000022jOl02022jOl00`000000n_3V
0?[`iP0L0?[`iP030;0G7P3jl>H0n_3V0080000000D041/Y0;0G7P0@6bT041/Y0000000901HT>@@0
00002@0V@f<00`000000:4EW02Q5I`0602Q5I`040;0G7P0XAFL0:4EW00000080POco00<0000007oh
o`1on?l00`1on?l3000000L0O_Ko00<0000007gco`1mlol0201mlol3000000030?[`iP2`5ah0n_3V
02l0n_3V0@3oool00440n_3V00<0/1LN0?[`iP3jl>H00P2`5ah00`3jl>H0/1LN0;0G7P0N0?[`iP03
0000001O]?l0GkCo00P0GkCo00<0000005VYoP1IZOh01@1IZOh200000080D9CP00<000000;0G7P2`
5ah01`1<S]T00`000000AH;904F2b@0504F2b@030000001MX=00GJ3@0080GJ3@00<0000005ZJb@00
00001@1GU<42000000@0@W:B0`00000507CHo`80/1LN101df?l20000000307WTo`000000NN;o00d0
NN;o00<0000007[So`1jhol00P00000907gXo`030;0G7P000000P>go00@0P>go00<0000008?bo`23
l_l02023l_l010000000Pnoo08?_o`00000908;Yo`030000003jl>H0n_3V01l0n_3V00<00000010K
:@0@6bT0100@6bT00`0000005R@i01HT>@0501HT>@@000002`0V@f<00`000000:4EW02Q5I`0702Q5
I`030;0G7P000000000000<0POco00<0000007oho`1on?l00P00000;07kfo`030000001mlol0OO?o
00@0OO?o0`0000040?[`iP030;0G7P3jl>H0n_3V02h0n_3V0@3oool00440n_3V1`2`5ahO0?[`iP03
0000001O]?l0GkCo00@0GkCo3P0000030;0G7PD000001@1<S]T00`000000AH;904F2b@0404F2b@03
0000001MX=00GJ3@00<0GJ3@0P00000505ND`@030000001ARkD0000000<0@W:B00@0?Vf;00000000
00000000201df?l2000000<0NNCo00<0000007WRo`1ih_l0301ih_l00`000000N^?o0000000=07gX
o`0300000020kOl0P>go008000002023l_l20;0G7P80Po;o0P0000000`25lol000000000000708;Y
o`030000003jl>H0n_3V01h0n_3V00<00000010K:@0@6bT01@0@6bT00`0000005R@i01HT>@0301HT
>@8000000P0R>eT00`0000009T=S02I3H`0:02I3H`030000000XAFL0:4EW00D0:4EW0P0000000`2`
5ah0;4ea00000003087lo`<000003P1nm_l00`000000OO?o07gco`03000000L0n_3V00<0/1LN0?[`
iP3jl>H0;P3jl>H10?ooo`00@03jl>H00`2`5ah0n_3V0;0G7P020;0G7R<0n_3V1P00000505>Kj004
0000001AUn@0DIOT056Gi08000000P14OKh30;0G7P0300000016P/D0AX;500<0AX;51@0000020;0G
7PD0AH;900<0000005fPd01MX=00101MX=000`000000EiC105ND`@0305ND`@040000001ARkD0DH^e
00000080@W:B100000000`2`5ah0M=So07CHo`0307CHo`8000001P1ii?l00`000000NN;o07WRo`0<
07WRo`030000001mj?l0ONSo00`0ONSo00<00000083]o`0000002@23l_l30;0G7P<0Po;o00D00000
08Gco`25lol0QO?o0000000508;Yo`030000003jl>H0n_3V01h0n_3V00<00000010K:@0@6bT01@0@
6bT0100000005R@i01HT>@0F93T3000000<08S]I0P00000<02I3H`030000000XAFL0:4EW0080:4EW
0`00000302a=L@030;0G7P0000000000008000000P20nOl00`000000O_Ko07kfo`0<07kfo`<00000
2P3jl>H00`2`5ah0n_3V0?[`iP0^0?[`iP40oooo00100?[`iPD0/1LN8`3jl>H00`000000Di_X05>K
j00905>Kj0<000001`14OKh00`000000AX;504J2a@0604J2a@80/1LN00<00000045i^@0000000`00
00000`15P/T0000005fPd00505fPd0800000101GU<401P000000DH^e056;]@1ARkD00000049bTP80
000000<0=Uif0000002`5ah00`1df?l2000000T0NNCo00<0000007WRo`1ih_l02@1ih_l200000003
07cZo`000000ONSo00d0ONSo00<0000008?bo`23l_l02023l_l20;0G7P<0Po;o00<0000008;ao`00
00000`25lol200000080P^Wo00@0/1LN0000003jl>H0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP0H0?[`
iP030000000@6bT041/Y00H041/Y00@0000001HT>@00000000001@0R>eT00`0000009D5P0000000<
02I3H`030000000XAFL00000008000001`0/CG400`2`5ah0P?Wo0;0G7P04083io`030000001nm_l0
O_Ko00P0O_Ko0`00000=0?[`iP030;0G7P3jl>H0n_3V02h0n_3V0@3oool003<0n_3V00<0/1LN0?[`
iP3jl>H02@3jl>H30;0G7P030?[`iP2`5ah0/1LN02@0n_3V00<0000005>Kj01CVnP0201CVnP00`00
0000A7fn04Am_P0804Am_P0300000016P/D0AX;500<0AX;50P2`5ah304J2a@0300000011NKT0@GVi
0080@GVi0P00000605fPd0030000001KW</0000000<0EiC100H00000056;]@1ARkD0DH^e00000012
LY820000000403INMP000000000007CHo`8000002`1ii?l00`000000NN;o07WRo`0707WRo`800000
0`1lj_l00`000000ONSo07gXo`0:07gXo`80000000<0Onoo00000023l_l02`23l_l200000080P_7o
00<0000008Gco`25lol00`25lol00`000000/1LN000000050;0G7QX0n_3V0P000008010K:@800000
1P0R>eT0100000009D5P02E1H000000;02I3H`<000002P0/CG400`000000/1LN0;0G7P020;0G7P<0
P?Wo00<0000007kfo`1nm_l0101nm_l300000100n_3V00<0/1LN0?[`iP3jl>H0;P3jl>H10?ooo`00
<@3jl>H20;0G7P`0n_3V1`2`5ahS0?[`iP030000001CVnP0Di_X00H0Di_X0`00000:04Am_P030000
002`5ah0/1LN00<0/1LN1@16P/D00`000000@GVi045i^@03045i^@040000001MX=00GJ3@05fPd080
/1LN00D0GJ3@0000001KW</0Fic;0000000305ND`@040000001ARkD0DH^e056;]@80000000D0?Vf;
000000000000MMco0000000>07WTo`030000001ih_l0NN;o00@0NN;o0P00000607cZo`030000001m
j?l0ONSo00P0ONSo00D0000007o_o`1okol0Onoo0000000;08?bo`0300000022lOl0P_7o00<0P_7o
00@0000008Gco`25lol0QO?o0`2`5ah010000000/1LN0;0G7P2`5ahK0?[`iP8000001`0@6bT30000
00H08S]I00D0000002E1H00U@F009D5P0000000902I3H`80000000<0:TU/0000000/CG402P0/CG40
0`000000/1LN0;0G7P020;0G7P@0P?Wo00<0000007kfo`1nm_l00`0000080?[`iP030;0G7P3jl>H0
n_3V00P0n_3V0P2`5ah_0?[`iP40oooo000`0?[`iP030;0G7P3jl>H0n_3V03H0n_3V00<0000005>K
j01CVnP0101CVnP200000080A7^j00<0000004Am_P14OKh02014OKh30;0G7PP0AX;500<00000045i
^@11NKT00P11NKT20000000305fPd02`5ah0/1LN00<0GJ3@00@0000005^Lb`1KW</000000`1GU<40
0`000000DH^e056;]@02056;]@070000000nKH/0000003INMP000000N>;o0000000>07WTo`040000
001ih_l0NN;o07WRo`800000201lj_l00`000000ONSo07gXo`0607gXo`8000001@1okol00`000000
Po;o08?bo`0708?bo`0300000022lOl0P_7o00@0P_7o00L0000008Gco`25lol0/1LN08Gco`2`5ah0
000000<0/1LN6`3jl>H3000000D041/Y0P00000201X/A0030000000R>eT08S]I00<08S]I00<00000
02E1H00U@F000P0U@F000`0000009T=S02I3H`0402I3H`<000000`0ZBF`00`000000;4ea02a=L@0:
02a=L@<0/1LN1@20nOl3000000`0n_3V00<0/1LN0?[`iP3jl>H01P3jl>H50;0G7Rd0n_3V0@3oool0
02h0n_3V0P2`5ahi0?[`iP030000001CVnP0Di_X0080Di_X0P00000504Ak^P0300000014OKh0A7fn
00H0A7fn102`5ah304J2a@030;0G7P16P/D0AX;50080AX;500<00000045i^@11NKT00P0000030;0G
7PD0GJ3@00D0000005^Lb`1KW</0Fic;0000000205ND`@030000001ARkD0DH^e0080DH^e0`000000
0`0fGWH0000000000005000000<0NNCo00<0/1LN07WTo`1ii?l0101ii?l010000000NN;o00000000
000;07cZo`030000001mj?l0ONSo00<0ONSo0P00000807o_o`0300000023l_l0Po;o00D0Po;o00<0
000008;ao`22lOl01P22lOl00`000000QO?o08Gco`070;0G7Q00n_3V00<0/1LN0?[`iP3jl>H01P3j
l>H20000000300/D7`00000041/Y008041/Y0P00000401X/A0030000000R>eT08S]I00808S]I00<0
000002E1H00U@F000`0U@F00100000009T=S02I3H`0V@f<3000000H0:TU/00<0000002a=L@0/CG40
2P0/CG400`000000/1LN0;0G7P03083io`8000003`3jl>H00`2`5ah0n_3V0?[`iP050?[`iPD0/1LN
;P3jl>H10?ooo`00;@3jl>H00`2`5ah0n_3V0?[`iP0j0?[`iP040000001CVnP00000000000L0A7^j
00<0000004Am_P14OKh02014OKh010000000AX;504J2a@16P/D20;0G7PD0AX;500@000000;0G7P2`
5ah0/1LN0P0gI9/00`000000GJ3@05fPd00305fPd0030000001KW</0Fic;0080Fic;00<0000005ND
`@000000101ARkD20000000303i]R`000000000000<0NNCo00<0000007[Wo`1jiol0100000000`2`
5ah0000007WTo`0407WTo`030000001lj_l0O>[o00`0O>[o00D0000007gXo`1mj?l0ONSo0000000;
07o_o`0300000023l_l0Po;o00<0Po;o00<0000008;ao`22lOl02022lOl010000000QO?o0;0G7P2`
5ah30?[`iP030;0G7P3jl>H0n_3V0100n_3V0`2`5ah40?[`iP8000000P0;51l01000000041/Y0000
0000000601X/A0030000000R>eT08S]I00808S]I00<0000002E1H00U@F000`0U@F00100000009T=S
00000000000902Y9K0030000000/CG40;4ea00X0;4ea00@00000083io`20nOl0P?Wo0P00000B0?[`
iP030;0G7P3jl>H0n_3V00D0n_3V102`5ah^0?[`iP40oooo000[0?[`iP80/1LN?@3jl>H2000000T0
A7^j00<0000004Am_P14OKh02014OKh010000000AX;504J2a@2`5ah204J2a@030;0G7P16P/D0AX;5
00<0/1LN1P0gI9/00`000000GJ3@05fPd00205fPd0030000001KW</0Fic;00<0Fic;0P000004056;
]@0300000010L8l00000008000000`1ii?l00`000000N^Oo07[Wo`0607[Wo`P00000301lj_l01000
0000ONSo00000000000807o_o`050;0G7P1okol0Onoo07o_o`0000000`23l_l2000000/0P_7o00<0
000008Gco`000000102`5ahE0?[`iP80/1LN0P3jl>H2000000802a@O0`00000701X/A0030000000R
>eT08S]I00808S]I00<0000002E1H00U@F000`0U@F03000000/0:TU/00<0000002a=L@0/CG402P0/
CG4010000000/1LN00000000000D0?[`iP030;0G7P3jl>H0n_3V00H0n_3V0P2`5ah_0?[`iP40oooo
000Z0?[`iP030;0G7P3jl>H0n_3V03@0n_3V0P2`5ah70?[`iP0300000014NkX0A7^j00P0A7^j00<0
000004Am_P14OKh02014OKh010000000AX;50;0G7P2`5ah204J2a@<0/1LN0`00000703MTV`050000
001MX=00GJ3@05fPd00000001P1KW</00`000000DH^e056;]@02056;]@0300000010L8l0@72?00<0
00000`1ii?l00`000000N^Oo07[Wo`0507[Wo`800000101kj_l00`000000O>_o00000003000000T0
O>[o00<0000007o_o`1okol01`1okol20;0G7P@0Onoo00<0000008?bo`0000003P22lOl010000000
n_3V0?[`iP2`5ahJ0?[`iP03000000063A80000000802a@O00<0000001X/A00J;4@01@0J;4@00`2`
5ah06Ra400000003028kF@040000000U@F009D5P02E1H0<0000000<09dAU0000000ZBF`02`0ZBF`0
0`000000;4ea02a=L@0:02a=L@030000002`5ah0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H01P3jl>H0
0`2`5ah0n_3V0?[`iP0]0?[`iP40oooo000X0?[`iP80/1LN<P3jl>H50;0G7PT0n_3V00<0000004Ak
^P14NkX02014NkX00`000000A7fn04Am_P0804Am_P0300000016P/D0/1LN00<0/1LN00<0AX;50;0G
7P0000000P0iIid00`000000=fBK03MTV`0503MTV`050000001MX=00GJ3@05fPd00000001P1KW</2
000000<0DH^e00<00000041`S`10L8l00P0000000`0`DfD0NNCo07WTo`0207WTo`030000001jiol0
N^Oo0080N^Oo0P00000707_Zo`030000001ljol0O>_o0080/1LN1@00000307cZo`030000001nk_l0
000000T0Onoo00<0/1LN07o_o`1okol00`1okol00`000000P_7o08;ao`0<08;ao`030000003jl>H0
n_3V01/0n_3V00@0000000H=4P0000002a@O0`00000801X/A0050;0G7P0000008S]I028kF@000000
0P0U@F02000000@09dAU00<0000002Y9K00ZBF`02P0ZBF`00`000000;4ea02a=L@0902a=L@800000
0`2`5ahE0?[`iP030;0G7P3jl>H0n_3V03H0n_3V0@3oool002L0n_3V00<0/1LN0?[`iP3jl>H0<@3j
l>H40;0G7P`0n_3V00<0000004Ak^P14NkX02014NkX00`000000A7fn04Am_P0804Am_PL0/1LN0`0i
Iid00`000000=fBK03MTV`0603MTV`040000001MX=00GJ3@000000H0Fic;0P000003056;]@040000
0010L8l0@72?041`S`800000101ii?l00`000000N^Oo07[Wo`02000000T0Nn[o0`2`5ah707c[o`D0
000000<0O^ko0000001okol01`1okol0102`5ah0Onoo07o_o`1okol200000003087bo`000000P_7o
00/0P_7o00<000000?[`iP3jl>H0703jl>H20000000500/D7`0000003aXZ00lJ:P0000002@0J;4@3
0;0G7P<000001P0WA6D00`000000:TU/02Y9K00:02Y9K0030000000/CG40;4ea00L0;4ea0P000000
100^DGL000000;0G7P2`5ahG0?[`iP030;0G7P3jl>H0n_3V03D0n_3V0@3oool001d0n_3V0P2`5ah6
0?[`iP80/1LN=03jl>H30;0G7PX0n_3V0P2`5ah00`3jl>H0000004Ak^P0904Ak^P0300000014OKh0
A7fn00P0A7fn00<0000004J2a@2`5ah00`2`5ah503UWW@030000000gI9/0=fBK00H0=fBK00<00000
05fPd00000001P1KW</00`000000EYC100000003056;]@0300000010L8l0@72?00<000000`1ii?l3
000000`0Nn[o00<0/1LN07c[o`1ljol01P1ljol2000000<0O^ko1000000607o_o`040;0G7P1okol0
Onoo000000<0PO;o00<0000008;ao`22lOl02@22lOl00`000000n_3V0?[`iP0L0?[`iP80000000<0
2a@O0000000?6RX00P0?6RX00`0000006Ra401X/A00701X/A0040000002`5ah0/1LN0;0G7PP09dAU
00<0000002Y9K00ZBF`01@0ZBF`00`2`5ah0:TU/02Y9K00202Y9K0030000000/CG40;4ea00@0;4ea
0`00000302iAM`030000002`5ah0/1LN01P0n_3V00<0/1LN0?[`iP3jl>H0=03jl>H10?ooo`007@3j
l>H00`2`5ah0n_3V0;0G7P020;0G7P80n_3V00<0/1LN0?[`iP3jl>H0?`3jl>H20;0G7P<0n_3V00<0
000004Ak^P14NkX02014NkX00`000000A7fn04Am_P0804Am_P8000002@0iIid00`000000=fBK03MT
V`0703MTV`8000001P1KW</010000000EYC105JD`@000002056;]@0300000010L8l0@72?00<00000
00<0NNCo0000000000000P1kjOl00`000000Nn[o07_Zo`0;07_Zo`030000001ljol0O>_o00<0O>_o
0P00000807k^o`<000001P1okol00`000000PO;o087bo`03087bo`0300000022lOl0P_7o00L0P_7o
00<000000?[`iP3jl>H07@3jl>H3000000@03aXZ00<0000001X/A00J;4@01P0J;4@00`000000/1LN
0;0G7P020;0G7PP09dAU00<0000002Y9K00ZBF`01@0ZBF`00`2`5ah0:TU/02Y9K00202Y9K0040000
000/CG40;4ea02a=L@<000001P0^DGL00`000000/1LN0?[`iP0H0?[`iP030;0G7P3jl>H0n_3V03@0
n_3V0@3oool001`0n_3V00@0/1LN0?[`iP2`5ah0n_3V102`5ai00?[`iP80/1LN1@3jl>H00`000000
A7^j04Ak^P0804Ak^P0300000014OKh0A7fn00H0A7fn0`00000:03UWW@030000000gI9/0=fBK00L0
=fBK0P00000605^Lb`070000001FU<40EYC105JD`@000000DH^e00000002041`S`80000000<0<5=U
0000001kjOl0101kjOl00`000000Nn[o07_Zo`0407_Zo`030;0G7P1kj_l0Nn[o00@0Nn[o00<00000
07c[o`1ljol00P00000407k^o`030;0G7P1nk_l0O^ko00<0O^ko0P2`5ah00`1ol?l0000000000002
07o_o`8000001`21l_l00`000000P_7o08;ao`0408;ao`030;0G7P000000n_3V01h0n_3V0P000005
00lJ:P030000000J;4@06Ra400D06Ra40P000000100R>eT000000;0G7P2`5ah902M4I@030000000Z
BF`0:TU/00H0:TU/0P2`5ah202Y9K0040000000/CG400000000000T0;U5g00<000000?[`iP3jl>H0
6@3jl>H00`2`5ah0n_3V0;0G7P0c0?[`iP40oooo000L0?[`iP050;0G7P3jl>H0/1LN0;0G7P3jl>H0
0P2`5ahi0?[`iP<0/1LN0P3jl>H30;0G7PL0n_3V00<0000004Ak^P14NkX00`14NkX20;0G7P<0A7^j
00<0000004Am_P14OKh01014OKh200000080?6bT00<0000003UWW@0iIid0200iIid00`000000=fBK
03MTV`0803MTV`8000001@1KW</01`000000EYC105JD`@1FU<400000056;]@0000000`10L8l20000
00L0NnWo00<0000007_Zo`1kj_l00P1kj_l30;0G7PD0Nn[o0`00000407k^o`80/1LN00<0O^ko0;0G
7P1nk_l00`2`5ah00`1nk_l0000007o`o`0207o`o`<000002@21l_l010000000P_7o08;ao`22lOl3
0;0G7Ql0n_3V0P00000600lJ:P030000000J;4@06Ra400<06Ra40P000002028kF@8000002`0WA6D0
0`000000:TU/02Y9K00602Y9K0<0/1LN0`00000;02iAM`030000003jl>H0n_3V01T0n_3V0`2`5ahc
0?[`iP40oooo000L0?[`iP030;0G7P3jl>H0/1LN0080/1LN00<0n_3V0;0G7P3jl>H0>03jl>H50;0G
7P/0n_3V00<0000004Ak^P2`5ah00P2`5ah604Ak^P0400000014OKh0A7fn04Am_P800000100lK:@0
0`000000>FNM03UWW@0803UWW@030000000gI9/0=fBK00P0=fBK00<0000002iCPP000000101KW</0
0`000000EYC105JD`@0205JD`@8000000`10L8l3000000H0NnWo00<0000007_Zo`1kj_l00`1kj_l0
102`5ah0Nn[o07_Zo`1kj_l300000080O>co00@0000007k^o`1nk_l0O^ko1P2`5ah407k^o`030000
001ol?l0Oo3o008000000P20l_l2000000L0PO;o00D0000008;ao`22lOl0P_7o0000000Q0?[`iP03
0000000?6RX03aXZ00D03aXZ00@0000001X/A00J;4@06Ra40P000004028kF@8000002`0WA6D00`00
0000:TU/02Y9K00502Y9K0<0/1LN00<000000;0G7P2`5ah0300^DGL00`000000n_3V0?[`iP0H0?[`
iP@0/1LN<`3jl>H10?ooo`00703jl>H40;0G7P<0n_3V00<0/1LN0?[`iP3jl>H0=@3jl>H50;0G7P`0
n_3V0P2`5ah904Ak^P0400000014OKh00000000000L0?6bT00<0000003UWW@0iIid01`0iIid00`00
0000=fBK03MTV`0603MTV`<000000P0^Dh801@000000Fic;05^Lb`1KW</0000000D0EYC100@00000
041`S`10L8l0@72?0`00000707_Yo`030000001kj_l0Nn[o0080Nn[o00@0/1LN07_Zo`0000000000
1P1lk?l00`000000O^ko07k^o`060;0G7PD0O^ko0P000006083bo`<000001@21l_l00`000000P_7o
0000000Q0?[`iP8000001`0?6RX0100000006Ra4000000000005028kF@030000000V@V80000000/0
9dAU00<0000002Y9K00ZBF`00P0ZBF`2000000040;0G7P000000/1LN0;0G7P80;Dic00<000000;0G
7P0^DGL02P0^DGL00`000000n_3V0?[`iP080?[`iP030;0G7P3jl>H0n_3V00h0n_3V0`2`5ahc0?[`
iP40oooo000K0?[`iPT0/1LN=`3jl>H50;0G7PT0n_3V0`2`5ah00`000000A7^j04Ak^P0804Ak^P80
00002@0lK:@00`000000>FNM03UWW@0703UWW@030000000gI9/0=fBK00@0=fBK0P000002039KR`05
0000000^Dh80;U>202iCPP0000000P1KW</00`000000EYC105JD`@0305JD`@8000000P10L8l00`00
0000<eU]0000000807_Yo`060000001kj_l0Nn[o0000002`5ah000002@1lk?l01@000000O^ko07k^
o`2`5ah0O^ko0080/1LN101nk_l20000000307k_o`000000P?;o00P0P?;o0P000003087bo`800000
8@3jl>H2000000P03aXZ0P000006028kF@040000000V@V809T9R000000/09dAU00<0000002Y9K000
00000P0000000`0]CW<0/1LN0;0G7P0202e>L`040;0G7P0]CW<0/1LN0;0G7P`0;U5g00<000000?[`
iP3jl>H02@3jl>H00`2`5ah0n_3V0?[`iP0?0?[`iP030;0G7P3jl>H0n_3V0340n_3V0@3oool001/0
n_3V1@2`5ai60?[`iP<0/1LN0`3jl>H00`000000A7^j04Ak^P0604Ak^P030000000nKjP0000000X0
?6bT00<0000003UWW@0iIid0200iIid00`000000=fBK03MTV`0203MTV`030000000bFh/0<U^;0080
<U^;00<0000002iCPP0^Dh800P0^Dh800`000000Fic;0000000505JD`@8000000P10L8l3000000P0
NnWo0`0000000`1lk?l0/1LN07c/o`0907c/o`050000001nk_l0O^ko07k^o`2`5ah0101nk_l20000
00@0O^oo00<00000083bo`20l_l02020l_l3000001@0n_3V00<0/1LN0?[`iP3jl>H02P3jl>H0102`
5ah0n_3V00000000000600lJ:P<000001`0R>eT0100000009T9R02I2HP00000:02M4I@<000001@0]
CW<60;0G7P030000000^DGL0;U5g00X0;U5g00<000000?[`iP3jl>H02P3jl>H00`2`5ah0n_3V0?[`
iP120?[`iP40oooo001M0?[`iP030;0G7P3jl>H0n_3V00<0n_3V0`2`5ah60?[`iP0300000014NkX0
A7^j00@0A7^j0P00000203i_Z0030000000lK:@0?6bT00P0?6bT00<0000003UWW@0iIid0200iIid0
0`000000=fBK03MTV`02000000D0<U^;00@000000;0G7P2`5ah0;U>20P2`5ah2000000D0EYC100@0
000004j7[`000000@72?0P0000000`0cFFd0000007_Yo`0407_Yo`8000000P1kk?l00`000000O>co
0;0G7P0;07c/o`030000001nk_l0O^ko00<0O^ko0P00000707k_o`0300000020l_l0P?;o00H0P?;o
0P00000G0?[`iP80/1LN2@3jl>H20;0G7P<000001@0?6RX01000000062M001PW@0000006028kF@05
0000000V@V809T9R02I2HP000000200WA6D20000000302Y9K@000000;Dic00H0;Dic102`5ah00`0]
CW<0000002iAM`0;02iAM`030000003jl>H0n_3V00/0n_3V00<0/1LN0?[`iP3jl>H0@@3jl>H10?oo
o`00G03jl>H20;0G7P80n_3V0`2`5ah:0?[`iP0400000014NkX0A7^j04Ak^P8000001@0nKjP00`00
0000?6bT03a/Y00703a/Y0030000000iIid0>FNM00P0>FNM0`000007039KR`@0/1LN0`0^Dh800`00
0000EYC105JD`@0305JD`@040000001>Qjl00000041`S`80000000@0<eU]0000001kjOl0NnWo0`00
000507_/o`030000002`5ah0O>co00/0O>co0P2`5ah00`1nk_l000000000000907k_o`0300000020
l_l0P?;o00D0P?;o00<000000?[`iP3jl>H05`3jl>H20;0G7PX0n_3V00@0/1LN0000000;52000000
100?6RX01@00000062M001PW@00H9d00000000D08S]I00<0000002I2HP0V@V800P0V@V800`000000
9dAU02M4I@0402M4I@8000000`0ZBFd00`000000;Dic02e>L`0702e>L`040;0G7P0]CW<0;Dic0000
00`0;U5g00<000000?[`iP3jl>H0303jl>H00`2`5ah0n_3V0?[`iP0A0?[`iP030;0G7P3jl>H0n_3V
02`0n_3V0@3oool004T0n_3V0P2`5ah@0?[`iP030;0G7P3jl>H0n_3V0080/1LN3@3jl>H010000000
A7^j00000000000703i_Z0030000000lK:@0?6bT00L0?6bT00<0000003UWW@0iIid0200iIid00`00
0000<U^;039KR`07039KR`030000002`5ah0/1LN00D0;U>200<0000005JD`@1FU<400P1FU<401`00
0000CXN_04j7[`000000@72?0000000cFFd00`00000907_/o`030000001lk?l0O>co00X0O>co00<0
/1LN000000000000301nkol00`000000P?;o083bo`02083bo`8000002@3jl>H00`2`5ah0n_3V0?[`
iP0J0?[`iP<000000`0?6RX2000000@062M000<00000028kF@0R>eT00P0R>eT00`0000009T9R02I2
HP0302I2HP040000000WA6D09dAU02M4I@<000001@0ZBFd00`000000;Dic02e>L`0:02e>L`030000
000^DGL0;U5g00T0;U5g0P00000?0?[`iP030;0G7P3jl>H0n_3V0140n_3V00<0/1LN0?[`iP3jl>H0
:`3jl>H10?ooo`00A`3jl>H20;0G7Q40n_3V1@2`5ah>0?[`iP8000002@0nKjP00`000000?6bT03a/
Y00703a/Y0030000000iIid0>FNM00H0>FNM0`000009039KR`030000000^Dh80;U>200H0;U>200D0
000005JD`@1FU<40EYC10000000304j7[`@000002`1kk?l00`000000O>co07c/o`0707c/o`800000
00@0/1LN07c^o`1lk_l000003@1nkol010000000P?;o00000000000:0?[`iP<0/1LN6P3jl>H20000
000600/D800000003aXZ00lJ:P000000/1LN1@0H9d000`0000008S]I028kF@02028kF@030000000V
@V809T9R00<09T9R00@0000002M4I@0000000000200ZBFd00`000000;Dic02e>L`0:02e>L`030000
000^DGL0;U5g00H0;U5g0`0000000`0`Dg/000000?[`iP0>0?[`iP030;0G7P3jl>H0n_3V0140n_3V
00<0/1LN0?[`iP3jl>H0:`3jl>H10?ooo`00A@3jl>H20;0G7Q80n_3V1`2`5ah=0?[`iP030000000n
KjP0?VnX00P0?VnX00<0000003a/Y00lK:@0200lK:@00`000000>FNM03UWW@0303UWW@8000000P0g
HiH00`000000<U^;039KR`08039KR`030000000^Dh80;U>200H0;U>200D0000005JD`@1FU<40EYC1
0000000204j7[`8000000P2`5ah<07_/o`030000001lk?l0O>co00@0O>co0P00000207c^o`050;0G
7P1lk_l0O>ko07c^o`000000301nkol2000000`0n_3V0`2`5ahJ0?[`iP80000000H02a@P00000000
0000000001PW@02`5ah401PW@0030000000R>eT08S]I00808S]I00<0000002I2HP0V@V800`0V@V83
000000X0:TU]00<0000002e>L`0]CW<02P0]CW<00`000000;U5g02iAM`0202iAM`@00000100`Dg/0
0`000000n_3V0?[`iP0>0?[`iP030;0G7P3jl>H0n_3V0140n_3V00<0/1LN0?[`iP3jl>H0:P3jl>H1
0?ooo`00>P3jl>H20;0G7PL0n_3V0P2`5ahG0?[`iP@0/1LN3P3jl>H3000000P0?VnX00<0000003a/
Y00lK:@01`0lK:@010000000>FNM03UWW@0iIid2000000@0=f>F00<00000039KR`0bFh/0200bFh/0
0`000000;U>202iCPP0402iCPP<000000`1FU<400`000000CXN_04j7[`020;0G7P030000000cFFd0
000000`0Nnco00<0000007c/o`1lk?l00`00000807c^o`030000001nkol0O^oo00L0O^oo0`00000?
0?[`iP030;0G7P3jl>H0n_3V01P0n_3V0P00000200/D80030000000H9d0062M000<0/1LN0`0H9d00
1@0000008S]I028kF@0R>eT0000000<09T9R0`0000000`0V@f@0000002Y9K@0:02Y9K@030000000]
CW<0;Dic00X0;Dic00<0000002iAM`0000000P000008031CN`030000003jl>H0n_3V00l0n_3V00<0
/1LN0?[`iP2`5ah0403jl>H00`2`5ah0n_3V0?[`iP0Z0?[`iP40oooo000j0?[`iP040;0G7P3jl>H0
/1LN0;0G7P80n_3V0`2`5ah<0?[`iP80/1LN7@3jl>H00`000000?6^P03a[X00600000080?VnX00<0
000003a/Y00lK:@01`0lK:@010000000>FNM00000000000603MSUP030000000bFh/0<U^;00P0<U^;
00<0000002iCPP0^Dh800`0^Dh800`000000/1LN0;0G7P0200000080EYC10`2`5ah00`1>Qjl00000
00000003000000/0Nnco0`00000<07c^o`030000001nkol0O^oo00@0O^oo0P00000B0?[`iP030;0G
7P3jl>H0n_3V01P0n_3V0P0000001P0;520000000000000H9d00/1LN01PW@080/1LN0`0H9d001000
00008S]I028kF@0R>eT4000000@09T=T00<0000002Y9K@0ZBFd02@0ZBFd00`000000;Dic02e>L`09
02e>L`<000002`0`Dg/00`000000n_3V0?[`iP0@0?[`iP@0/1LN3`3jl>H00`2`5ah0n_3V0?[`iP0Y
0?[`iP40oooo000i0?[`iP80/1LN00<0n_3V0;0G7P2`5ah00P2`5ah=0?[`iP80/1LN7`3jl>H00`00
0000?6^P03a[X00603a[X0@00000200lK:@2000000P0=f>F00<00000039KR`0bFh/0200bFh/01000
0000;U>202iCPP0^Dh82000000L0/1LN00H0000004j7[`1>Qjl0CXN_00000010L903000000T0Nnco
0P00000207c]o`030000001lk_l0O>ko00/0O>ko00<0000007k_o`1nkol00`00000D0?[`iP030;0G
7P3jl>H0n_3V01L0n_3V10000000200@72h000000;0G7P2`5ah062M00;0G7P0H9d00/1LN0P0H9d00
0`0000008S]I028kF@02000000L09T=T00<0000002Y9K@0ZBFd02@0ZBFd00`000000;Dic02e>L`07
02e>L`80000000<0;U5h0000000`Dg/02`0`Dg/00`000000n_3V0?[`iP0?0?[`iP030;0G7P3jl>H0
/1LN0080/1LN3`3jl>H00`2`5ah0n_3V0?[`iP0Y0?[`iP40oooo000i0?[`iPD0/1LN303jl>H30;0G
7R40n_3V00<0000003a[X00lJj00200lJj000`000000>VRM00000002000000<0?6bT0`00000903MS
UP030000000bFh/0<U^;00P0<U^;00D0000002iCPP0^Dh80000002a?NP050;0G7P040000000U@fX0
0000000000<0CXN_00H00000041`T0000000000007_[o`00000507_/o`<000001@1lkOl00`000000
O>ko07c^o`0707c^o`<0/1LN0`0000050?[`iP030;0G7P3jl>H0n_3V00l0n_3V00<0/1LN0?[`iP3j
l>H05`3jl>H20000008041`^00<0000001PW@00H9d00102`5ah301PW@0<000002@0V@f@00`000000
:TU]02Y9K@0902Y9K@030000000]CW<0;Dic00@0;Dic0`00000302iAN0030000000`Dg/0<5=k00X0
<5=k00<000000?[`iP3jl>H0403jl>H40;0G7Q00n_3V00<0/1LN0?[`iP3jl>H0:03jl>H10?ooo`00
>03jl>H40;0G7P030?[`iP2`5ah0n_3V00T0n_3V0P2`5ahT0?[`iP030000000lJj00?6^P00D0?6^P
00@0/1LN03a[X00lJj000000100jJ9d400000080>FJJ00<0000003MSUP0gHiH01`0gHiH00`000000
<U^;039KR`07039KR`<00000100/CgX30;0G7P040000000U@fX09D=Z000000<0CXN_00@00000041`
T000000000000P1kjol00`000000Nnco07_/o`02000000T0O>go00<0000007c^o`1lk_l01`1lk_l2
000000L0n_3V0`2`5ahY0?[`iP<000000P0@72h00`00000062M001PW@00201PW@0030;0G7P0H9d00
62M0008062M000<0000002@nGP0000002@0V@f@00`000000:TU]02Y9K@0902Y9K@040000000]CW<0
;Dic02e>L`<000001P0^DGP00`000000<5=k031CN`0;031CN`030000003jl>H0n_3V0140n_3V0P2`
5ahA0?[`iP030;0G7P3jl>H0n_3V02L0n_3V0@3oool003P0n_3V1P2`5ah70?[`iP<0/1LN9P3jl>H0
0`000000?6^P03a[X00403a[X0<0/1LN00<0?6^P0000002`5ah0102`5ah303MRT`<000002@0gHiH0
0`000000<U^;039KR`07039KR`030000000/CgX0;4mj00L0;4mj00D0000002E3JP0U@fX09D=Z0000
000204j7[`0400000010L900@72@00000080Nn_o0`00000<07c]o`030000001lk_l0O>ko00<0O>ko
0`0000000`2`5ah0n_3V0?[`iP070?[`iP030;0G7P3jl>H0n_3V0240n_3V0P2`5ah50?[`iP800000
0`0@72h00`00000062M001PW@00501PW@0@000002P0V@f@00`000000:TU]02Y9K@0902Y9K@040000
000]CW<00000000000T0;U5h00<00000031CN`0`Dg/02`0`Dg/00`000000n_3V0;0G7P0T0?[`iP03
0;0G7P3jl>H0n_3V02L0n_3V0@3oool003/0n_3V0`2`5ah50?[`iP80/1LN:P3jl>H00`000000?6^P
03a[X00303a[X0D0/1LN00<0000003MRT`0gHY<01`0gHY<3000000L0=f>F00<00000039KR`0bFh/0
1@0bFh/3000000T0;4mj00D0000002E3JP0U@fX09D=Z0000000204j7[`0300000010L900@72@00<0
00000P1kk?l00`000000O>go07c]o`0;07c]o`030000001lk_l0O>ko008000000`3jl>H00`2`5ah0
n_3V0?[`iP0[0?[`iP80/1LN103jl>H3000000<041`^00<0000001PW@00H9d000`0H9d0200000080
83ME0P00000:02I3I0030000000ZBFd0:TU]00P0:TU]0`00000;02iAN0030000000`Dg/0<5=k00T0
<5=k00<0/1LN031CN`0000000P3jl>H00`2`5ah0n_3V0?[`iP0R0?[`iP030;0G7P3jl>H0n_3V02H0
n_3V0@3oool003H0n_3V00<0/1LN0?[`iP3jl>H01`3jl>H30;0G7R`0n_3V00<0000003a[X00lJj00
100lJj020;0G7P8000002P0gHY<010000000=f:C03MRT`00000603MSUP030000000bFh/0<U^;00<0
<U^;0P00000203=LR`030000000/CgX0;4mj00L0;4mj00<0000002E3JP0U@fX00P0U@fX01@000000
CXN_04j7[`000000@72@00800000101kk?l00`000000O>go07c]o`0:07c]o`<000001@3jl>H00`2`
5ah0n_3V0?[`iP0X0?[`iP<0/1LN1P3jl>H00`0000001PdB00000003010L;P040000000H9d0062M0
01PW@0800000100P=eD00`0000009T=T02I3I00902I3I0030000000ZBFd0:TU]00D0:TU]0`000000
0`0/CW<0000002iAN00;02iAN0030000000`Dg/0<5=k00X0<5=k00D0/1LN0000003jl>H0n_3V0;0G
7P0T0?[`iP030;0G7P3jl>H0n_3V02H0n_3V0@3oool003D0n_3V102`5ah50?[`iP80/1LN;`3jl>H0
0`000000?6^P03a[X00303a[X08000000P0gHY800`000000=f:C03MRT`0803MRT`040000000gHY<0
=f:C03MRT`800000100gHiH010000000<U^;039KR`0bFh/2000000@0<eb;00<0000002a?NP0/CgX0
1`0/CgX00`0000009D=Z02E3JP0202E3JP050000001>Qjl0CXN_00000010L9000P00000507_/o`03
0000001lkOl0O>go00L0O>go0P0000080?[`iP030;0G7P3jl>H0n_3V01P0n_3V00<0/1LN0?[`iP3j
l>H05@3jl>H3000000<041`^00<0000001PW@00H9d000P000006020gE@030000000V@f@09T=T00T0
9T=T00<0000002Y9K@0ZBFd00P0ZBFd3000000@0;4ic00<0000002iAN00^DGP02`0^DGP00`000000
<5=k031CN`09031CN`030;0G7P000000n_3V0080n_3V00<0/1LN0?[`iP3jl>H08P3jl>H00`2`5ah0
n_3V0?[`iP0U0?[`iP40oooo000e0?[`iP040;0G7P3jl>H0/1LN0;0G7P80n_3V0`2`5aha0?[`iP04
0000000lJj00?6^P03a[X0800000100gHY800`000000=f:C03MRT`0803MRT`030000000gHY<0=f:C
00<0=f:C00H0000003MSUP0gHiH0=f>F0000000bFh/2000000H0<eb;00<0000002a?NP0/CgX01`0/
CgX02P0000009D=Z02E3JP0U@fX00000020jG@000000CXN_00000010L902000000H0Nnco00<00000
07c]o`1lkOl00`1lkOl3000000X0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0;0G7P0H
0?[`iP03000000063A80000000<041`^0`000008020gE@030000000V@f@09T=T00T09T=T00<00000
02Y9K@0000000P00000702a>L`030000000^DGP0;U5h00/0;U5h00<00000031CN`0`Dg/02@0`Dg/0
0`000000/1LN0?[`iP030?[`iP030;0G7P3jl>H0n_3V0280n_3V00<0/1LN0?[`iP3jl>H0903jl>H1
0?ooo`00=03jl>H01@2`5ah0n_3V0;0G7P2`5ah0n_3V0080/1LN=03jl>H010000000?6^P00000000
000603MRTP030000000gHY<0=f:C00P0=f:C00<0000003MRT`2`5ah00P2`5ah203MRT`80000000<0
=f>F000000000000200cG8/00`000000;4mj02a?NP0802a?NP040000000U@fX09D=Z0000008083YM
0P0000001@10L90000000000001kk?l0/1LN00D0Nnco00<0000007c]o`1lkOl00P00000=0?[`iP03
0;0G7P3jl>H0n_3V00/0n_3V0`2`5ah60?[`iP<0/1LN6@3jl>H2000000@041`^00<00000020gE@0P
=eD01`0P=eD2000000X09T=T0`00000:02a>L`030000000^DGP0;U5h00/0;U5h00<00000031CN`0`
Dg/01P0`Dg/300000080n_3V00<0/1LN0?[`iP3jl>H00P3jl>H00`2`5ah0n_3V0?[`iP0?0?[`iP03
0;0G7P3jl>H0n_3V00l0n_3V00<0/1LN0?[`iP2`5ah0903jl>H10?ooo`00;P3jl>H20;0G7P<0n_3V
1`2`5ahe0?[`iP800000200gHY800`2`5ah0=f:C03MRT`0603MRT`@0/1LN1P0gHY<3000000T0<eb;
00<0000002a?NP0/CgX0200/CgX00`0000009D=Z00000003020jG@8000000P10L90010000000Nnco
0;0G7P2`5ah407_/o`<000003`3jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP80/1LN1P3jl>H40;0G7QP0
n_3V0P000003010L;P8000002@0P=eD2000000P09T=T0P0000000`0YAf/0000002a>L`0:02a>L`03
0000000^DGP0;U5h00/0;U5h00<00000031CN`0`Dg/00P0`Dg/4000000H0n_3V00D0/1LN0?[`iP3j
l>H0n_3V0;0G7P0B0?[`iP030;0G7P3jl>H0n_3V00h0n_3V1@2`5ahR0?[`iP40oooo000/0?[`iP80
/1LN1@3jl>H30;0G7P80n_3V0P2`5ahJ0?[`iP030;0G7P3jl>H0n_3V01P0n_3V00<0000003MRTP0g
HY801P0gHY830;0G7P<0=f:C102`5ah203MRT`030000000gHY<0=f:C00<0=f:C0P00000203ALRP80
00002@0cG8/00`000000;4mj02a?NP0702a?NP8000001@0P>Ud00`000000@72@041`T00200000080
/1LN00@0Nnco00000000000000008@3jl>H00`2`5ah0n_3V0?[`iP060?[`iP80/1LN603jl>H00`00
00001PdB00000002010L;P030000000<5R@0000000P083ME00<0000002E1HP0000001P0V@f@20000
00<0:DM[00<0000002a>L`0/CW<02@0/CW<00`000000;U5h02iAN00;02iAN0030000000`Dg/00000
008000002`3jl>H01@2`5ah0n_3V0;0G7P3jl>H0/1LN0180n_3V00<0/1LN0?[`iP3jl>H02`3jl>H2
0;0G7P030?[`iP2`5ah0/1LN0080/1LN8P3jl>H10?ooo`00:P3jl>H20;0G7PH0n_3V1`2`5ah00`3j
l>H0/1LN0?[`iP0H0?[`iP<0/1LN603jl>H00`000000=f:B03MRTP0603MRTPH0/1LN1P0gHY<01000
0000=f:C03MRT`0gHY<2000000D0=5b:0P00000803=LR`030000000/CgX0;4mj00L0;4mj00<00000
020jG@0P>Ud01@0P>Ud01`000000@72@000000000000Nnco0000002`5ah01P3jl>H00`2`5ah0n_3V
0?[`iP0J0?[`iP030;0G7P3jl>H0n_3V0240n_3V0P000002010L;P040000000<5R@031HT000000P0
83ME00<0000002E1HP0000000`0V@f@3000000D0:DM[00<0000002a>L`0/CW<02@0/CW<00`000000
;U5h02iAN00:02iAN0<000003P3jl>H60;0G7Q80n_3V00<0/1LN0?[`iP3jl>H02`3jl>H50;0G7R<0
n_3V0@3oool002L0n_3V0`2`5ah<0?[`iPD0/1LN603jl>H20;0G7P030?[`iP2`5ah0/1LN0080n_3V
1P2`5ah?0?[`iP030000000gHY80=f:B00D0=f:B1@2`5ah803MRT`040000000gHY<00000000000L0
=5b:00<0000003=LRP0000001`0cG8/00`000000;4mj02a?NP0502a?NP<000001`0P>Ud00`000000
@72@00000002000000L0n_3V0P2`5ahL0?[`iP030;0G7P3jl>H0n_3V0240n_3V0P0000000`0@72h0
000000`F900200`F90030000000P=eD083ME00D083ME00D0000002E1HP0U@F80000002I3I0020000
00P0:DM[00<0000002a>L`0/CW<02@0/CW<00`000000;U5h02iAN00702iAN0<000004@3jl>H20;0G
7P030?[`iP2`5ah0n_3V00@0/1LN403jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP<0/1LN8`3jl>H10?oo
o`009@3jl>H20;0G7R`0n_3V1`2`5ahE0?[`iP030000000gHY80=f:B00L0=f:B0`2`5ah703MRT`<0
00002@0dG8X010000000<eb:03=LRP00000603=LR`030000000/CgX0;4mj00<0;4mj0P00000202mE
P@030000000P>Ud083YM00H083YM00<00000041`T00000001`3jl>H40;0G7QX0n_3V00<0/1LN0?[`
iP3jl>H08P3jl>H3000000@031HT00<00000020gE@0P=eD01@0P=eD00`0000009D5R02E1HP020000
00X0:DM[00<0000002a>L`0/CW<02@0/CW<00`000000;U5h02iAN00502iAN0800000503jl>H00`2`
5ah0n_3V0;0G7P060;0G7Q40n_3V00<0/1LN0?[`iP3jl>H03@3jl>H00`2`5ah0n_3V0?[`iP0Q0?[`
iP40oooo000R0?[`iP<0/1LN;`3jl>H30;0G7QP0n_3V00<0000003MRTP0gHY80200gHY800`000000
=f:C03MRT`0403MRT`80000000<0=Ef<0000000dG8X02@0dG8X01@000000<eb:03=LRP0cG8X00000
00D0<eb;00@0000002a?NP0/CgX0;4mj0P00000402mEP@030000000P>Ud083YM00H083YM0`000008
0?[`iP<0/1LN?P3jl>H3000000D031HT00<00000020gE@0P=eD0100P=eD00`0000009D5R00000002
000000/0:DM[00<0000002a>L`0/CW<02@0/CW<00`000000;U5h02iAN00202iAN0<000005@3jl>H3
0;0G7P030?[`iP2`5ah0/1LN00@0/1LN4P3jl>H00`2`5ah0n_3V0?[`iP0`0?[`iP40oooo000P0?[`
iP80/1LN<`3jl>H20;0G7QP0n_3V00<0000003MRTP0gHY80200gHY8010000000=f:C03MRT`0gHY<3
000000<0=Ef<00<0000003ALRP0dG8X0200dG8X00`000000<eb:03=LRP0203=LRP030000000cG8/0
<eb;0080<eb;00@0000002a?NP00000000001P0_EH400`00000083YM020jG@06020jG@<00000203j
l>H00`2`5ah0n_3V0?[`iP0n0?[`iP8000001P0<5R@00`00000083ME020gE@04020gE@8000000P0V
@fD00`000000:DM[02U7J`0902U7J`030;0G7P0/CW<0;4ic00T0;4ic00<0000002iAN00000000P00
000I0?[`iPD0/1LN00@0n_3V0;0G7P2`5ah0/1LN4`3jl>H00`2`5ah0n_3V0?[`iP0_0?[`iP40oooo
000N0?[`iP80/1LNC`3jl>H00`000000=f:B03MRTP0803MRTP040000000gHY<00000000000H0=Ef<
00<0000003ALRP0dG8X0200dG8X00`000000<eb:03=LRP0303=LRP040000000cG8/0<eb;03=LR`80
0000200_EH400`00000083YM020jG@06020jG@@000001`3jl>H00`2`5ah0n_3V0?[`iP040?[`iP80
/1LN>03jl>H2000000H031HT00<00000020gE@0P=eD00P0P=eD3000000<09T=U00<0000002U7J`0Y
Af/02@0YAf/00`000000/1LN02a>L`0802a>L`<000000`2`5ahK0?[`iP80/1LN6@3jl>H00`2`5ah0
n_3V0?[`iP0^0?[`iP40oooo000@0?[`iP80/1LN2@3jl>H30;0G7U40n_3V00<0000003MRTP0gHY80
1`0gHY83000000P0=Ef<00<0000003ALRP0dG8X0200dG8X00`000000<eb:03=LRP0403=LRP040000
000cG8/00000000000T0;eF100<00000020jG@0P>Ud01@0P>Ud5000000L0n_3V00<0/1LN0?[`iP2`
5ah0102`5ahX0?[`iP80/1LN403jl>H2000000H031HT00<00000020gE@0P=eD00P0000000`0R>eX0
000002I3I@0302I3I@030000000YAf/0:DM[00T0:DM[00<0000002a>L`2`5ah01@0/CW<3000000<0
n_3V102`5ah;0?[`iP030;0G7P3jl>H0n_3V02P0n_3V00<0/1LN0?[`iP3jl>H0;@3jl>H10?ooo`00
3`3jl>H20;0G7P030?[`iP2`5ah0/1LN00D0n_3V0P2`5ai:0?[`iP<0/1LN1`3jl>H00`000000=f:B
03MRTP0403MRTP<0000000<0=Uj=0000000eGH`0200eGH`00`000000=5b:03ALRP0803ALRP030000
000cG8X0<eb:00@0<eb:0P0000000`0aF8D0000002mEP@0902mEP@030000000P>Ud083YM00<083YM
00@00000020jG00000004R8l0P0000070?[`iP@0/1LN:03jl>H40;0G7Q00n_3V0P00000700`F90<0
00000`0R>eX00`0000009T=U02I3I@0202I3I@030000000YAf/0:DM[00T0:DM[00H0000002a>L`0/
CW<0/1LN02a>L`2`5ah2000001H0n_3V00<0/1LN0?[`iP3jl>H0:03jl>H00`2`5ah0n_3V0?[`iP0/
0?[`iP40oooo000?0?[`iP030;0G7P3jl>H0/1LN0080/1LN0P3jl>H30;0G7S/0n_3V00<0/1LN0?[`
iP3jl>H02P3jl>H40;0G7PX0n_3V00<0000003MRTP0gHY800P0gHY82000000@0=Uj=00<0000003EM
S00eGH`01`0eGH`00`000000=5b:03ALRP0803ALRP030000000cG8X0<eb:0080<eb:0P000002035G
Q08000002P0_EH400`00000083YM020jG@02020jG@050000000P>U`083YL0000000B8S`00P000007
0?[`iP030;0G7P3jl>H0n_3V03d0n_3V0P00000700`F90030000000R>eX08S]J00808S]J00<00000
02I3I@0V@fD00P0V@fD00`000000:DM[02U7J`0:02U7J`070000000/CW<000000000002`5ah0n_3V
0;0G7P0H0?[`iP80/1LN:@3jl>H00`2`5ah0n_3V0?[`iP020;0G7RT0n_3V0@3oool000h0n_3V00D0
/1LN0?[`iP2`5ah0/1LN0?[`iP030;0G7Sd0n_3V102`5ah60?[`iP@0/1LN3P3jl>H00`000000=f:B
00000002000000H0=Uj=00<0000003EMS00eGH`01`0eGH`00`000000=5b:03ALRP0803ALRP030000
000cG8X0000000800000100aEh@00`000000<ER50000000902mEP@050000000P>Ud083YM020jG@00
00000`0P>U`0100000004R8l0000000000060?[`iP030;0G7P3jl>H0n_3V03h0n_3V0P00000600`F
90800000100R>eX00`0000009T=U02I3I@0202I3I@030000000YAf/0:DM[00T0:DM[0`0000020?[`
iP@0/1LN6@3jl>H00`2`5ah0n_3V0?[`iP0W0?[`iP@0/1LN:@3jl>H10?ooo`003@3jl>H0102`5ah0
n_3V0;0G7P3jl>H40;0G7Sd0n_3V00<0/1LN0?[`iP2`5ah00P2`5ah00`3jl>H0/1LN0;0G7P030;0G
7Q80n_3V0P00000903INS@030000000eGH`0=Ef<00L0=Ef<00<0000003ALRP0dG8X01`0dG8X30000
00P0<EN40P00000902mEP@040000000P>Ud083YM000000@083YL00@00000018R?000000000001P3j
l>H00`2`5ah0n_3V0?[`iP0_0?[`iP030;0G7P3jl>H0n_3V00`0n_3V0P00000400`F9080000000<0
52<i0000000R>eX00P0R>eX00`0000009T=U02I3I@0302I3I@030000000YAf/0:DM[00L0:DM[0P00
00040?[`iPD0/1LN6P3jl>H00`2`5ah0n_3V0?[`iP0V0?[`iP80/1LN00<0n_3V0;0G7P3jl>H0:03j
l>H10?ooo`00303jl>H00`2`5ah0n_3V0;0G7P030;0G7P80n_3V00<0/1LN0?[`iP3jl>H0>`3jl>H6
0;0G7Q@0n_3V0P2`5ah00`3jl>H0000003INS@0903INS@030000000eGH`0=Ef<00L0=Ef<00<00000
03ALRP0dG8X0100dG8X30000000303=JQ`000000<EN400T0<EN400<0000002mEP@0_EH401`0_EH40
0`00000083YM00000005020jG0040000000B8S`00000000000H0n_3V00<0/1LN0?[`iP3jl>H0303j
l>H00`2`5ah0n_3V0?[`iP020?[`iP030;0G7P3jl>H0n_3V01T0n_3V0`2`5ah=0?[`iP<000000`0<
5R@01@00000052<i01@S>@0D8cT0000000<08S]J00<0000002I3I@0V@fD00`0V@fD00`000000:DM[
02U7J`0402U7J`<000001`3jl>H30;0G7Q`0n_3V0P2`5ahU0?[`iP80/1LN00@0n_3V0;0G7P2`5ah0
/1LN:03jl>H10?ooo`00303jl>H30;0G7P<0n_3V00<0/1LN0?[`iP2`5ah0?03jl>H40;0G7P030?[`
iP2`5ah0n_3V01@0n_3V102`5ah:03INS@030000000eGH`0=Ef<00L0=Ef<00<0000003ALRP0dG8X0
0P0dG8X2000000@0<eZ700<00000035GQ00aEh@0200aEh@00`000000;eF102mEP@0702mEP@800000
1P0P>U`0100000004R8l00000000000D0?[`iP80/1LN0`3jl>H20;0G7Q`0n_3V0P2`5ah=0?[`iP80
00000`0<5R@00`00000052<i01@S>@0201@S>@050000000R>eX08S]J028kFP0000001@0V@fD01000
0000:DM[02U7J`0YAf/3000002/0n_3V00<0/1LN0?[`iP3jl>H0303jl>H00`2`5ah0n_3V0?[`iP0C
0?[`iPH0/1LN:03jl>H10?ooo`002`3jl>H80;0G7P030?[`iP2`5ah0n_3V03d0n_3V0P2`5ah00`3j
l>H0/1LN0?[`iP0D0?[`iP<0/1LN00<0000003INS@0fGXd0200fGXd00`000000=Ef<03EMS00703EM
S0030000000dG8X00000008000001P0cFXL00`000000<EN4035GQ008035GQ0800000200_EH400`00
000083YL020jG006020jG0804R8l00<000000?[`iP3jl>H04P3jl>H20;0G7P<0n_3V0P2`5ahK0?[`
iP030;0G7P3jl>H0n_3V00/0n_3V00D0/1LN0?[`iP000000000000`F9002000000D052<i00@00000
028kFP0R>eX000001P0V@fD010000000:DM[00000000000_0?[`iP040;0G7P3jl>H0/1LN0;0G7P/0
n_3V00<0/1LN0?[`iP3jl>H05@3jl>H30;0G7RP0n_3V0@3oool000h0n_3V202`5aho0?[`iP80/1LN
5P3jl>H00`2`5ah0n_3V0;0G7P0:03INS@030000000eGH`0=Ef<00H0=Ef<0`00000903=JQ`030000
000aEh@0<EN40080<EN40P2`5ah4035GQ08000001P0_EH43000000P083YL0P0B8S`00`000000n_3V
0?[`iP0B0?[`iP040;0G7P3jl>H0n_3V0?[`iP@0/1LN6P3jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP04
0;0G7P0kKHT00000000000H052<i00D00000028kFP0R>eX08S]J0000000502I3I@<0000000<0N=Go
0000003jl>H0;`3jl>H30;0G7P`0n_3V00<0/1LN0?[`iP3jl>H0503jl>H00`2`5ah0n_3V0?[`iP0X
0?[`iP40oooo000C0?[`iP<0/1LNF@3jl>H00`000000=Uj=03INS@0803INS@030000000eGH`0=Ef<
00@0=Ef<0P0000000`0dG8T0000003=JQ`0903=JQ`030000000aEh@0<EN400`0/1LN0P0_EH420000
0080;E1k00<00000020jG00P>U`01P0P>U`2018R?0030000003jl>H0n_3V0140n_3V00<0/1LN0?[`
iP3jl>H00`3jl>H30;0G7QT0n_3V00<0/1LN0?[`iP3jl>H03@3jl>H20;0G7P030000000D8cT052<i
00D052<i00@00000028kFP0R>eX00000100V@fD2000000<0N=Go00<000000?[`iP3jl>H0103jl>H2
0;0G7RT0n_3V102`5ah<0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H09`3jl>H1
0?ooo`00A@3jl>H20;0G7RP0n_3V00<0000003INS@0fGXd0200fGXd010000000=Ef<03EMS00eGH`3
000000<0=5b900<0000003=JQ`0cFXL0200cFXL010000000<EN4035GQ00aEh@30;0G7P@0<EN400@0
0000031FPP000000;eF10P00000402e@N`030000000P>U`083YL00H083YL00<04R8l0000003jl>H0
4`3jl>H00`2`5ah0n_3V0?[`iP030?[`iP030;0G7P3jl>H0n_3V01T0n_3V00<0/1LN0?[`iP3jl>H0
3@3jl>H30;0G7PL052<i00@00000028kFP0R>eX000000P0V@fD4000000<0N=Go00<000000?[`iP3j
l>H01P3jl>H30;0G7RP0n_3V0P2`5ah=0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3j
l>H09P3jl>H10?ooo`00@@3jl>H40;0G7RX0n_3V00@0000003INS@0fGXd0/1LN1`0fGXd010000000
=Ef<00000000000603ALR@030000000cFXL0<eZ700P0<eZ700<00000035GQ00aEh@00`0aEh@00`2`
5ah0<EN4035GQ002035GQ0040000000`EX800000000000H0;E1k00<00000020jG00P>U`01P0P>U`0
0`0B8S`000000;0G7P0I0?[`iP030;0G7P3jl>H0n_3V01P0n_3V00<0/1LN0?[`iP3jl>H03P3jl>H0
0`000000/1LN0;0G7P0701@S>@040000000R>eX0000002I3I@8000000P1bb_l2000000<0N=Go00<0
00000?[`iP3jl>H02@3jl>H20;0G7P80n_3V00<0/1LN0?[`iP3jl>H0<@3jl>H00`2`5ah0n_3V0?[`
iP0D0?[`iP030;0G7P3jl>H0n_3V02D0n_3V0@3oool002l0n_3V0P2`5ah<0?[`iP@0/1LN;P3jl>H0
0`000000=Uj=03INS@0703INS@<00000200dG8T00`000000<eZ703=JQ`0803=JQ`030000000aEh@0
<EN400L0<EN40`00000202iCOP030000000]D7/0;E1k00<0;E1k00<00000020jG00P>U`01P0P>U`0
0`000000/1LN0;0G7P0I0?[`iP030;0G7P3jl>H0n_3V01P0n_3V00<0/1LN0?[`iP3jl>H03P3jl>H3
000000L052<i00@00000028kFP00000000000`1bb_l010000000Ll_o07?;o`00000207SEo`030000
003jl>H0n_3V00/0n_3V102`5ahc0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0
903jl>H10?ooo`00;P3jl>H20;0G7P030?[`iP2`5ah0/1LN00H0n_3V102`5ahb0?[`iP030000000f
GXd0=Uj=00@0=Uj=0`0000000`0eGHX0000003ALR@0803ALR@030000000cFXL0<eZ700P0<eZ700<0
0000035GQ00aEh@01@0aEh@200000003031FP@000000;U=n0080;U=n00<0000002e@N`0]D7/00`0]
D7/00`00000083YL020jG006020jG0030000003jl>H0n_3V01P0n_3V00<0/1LN0?[`iP3jl>H0:P3j
l>H00`00000031HT0000000701@S>@<00000101bb_l010000000Ll_o07?;o`00000207SEo`030000
003jl>H0n_3V00`0n_3V102`5ahc0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0
8`3jl>H10?ooo`00;@3jl>H00`2`5ah0n_3V0;0G7P030;0G7P80n_3V102`5ahf0?[`iP030000000f
GXd0=Uj=0080=Uj=0P00000403EMRP030000000dG8T0=5b900L0=5b900<0000003=JQ`0cFXL0200c
FXL00`000000<EN4035GQ003035GQ08000000`0`EX400`000000;U=n02iCOP0202iCOP030000000]
D7/0;E1k00<0;E1k00<00000020jG00P>U`0100P>U`00`000000n_3V0?[`iP0I0?[`iP030;0G7P3j
l>H0n_3V02X0n_3V00<0000000`F900000001P0D8cT010000000K;og00000000000407;:o`040000
001cbol0Ll_o07?;o`800000A`3jl>H20;0G7QD0n_3V00<0/1LN0?[`iP3jl>H08P3jl>H10?ooo`00
;@3jl>H30;0G7P030?[`iP2`5ah0/1LN0080/1LN>P3jl>H00`000000/1LN00000002000000H0=Ef:
00<0000003ALR@0dG8T01`0dG8T00`000000<eZ703=JQ`0803=JQ`040000000aEh@0<EN4035GQ080
00001@0`EX400`000000;U=n02iCOP0202iCOP030000000]D7/0;E1k00<0;E1k00<00000020jG00P
>U`00`0P>U`00`000000/1LN0?[`iP0J0?[`iP030;0G7P3jl>H0n_3V02X0n_3V0P00000501@S>@80
00000`1/_oL00`000000L/[o07;:o`0207;:o`040000001cbol0Ll_o07?;o`8000006`3jl>H00`2`
5ah0n_3V0?[`iP0[0?[`iP030;0G7P3jl>H0n_3V0080/1LN4@3jl>H00`2`5ah0n_3V0?[`iP0Q0?[`
iP40oooo000/0?[`iPD0/1LN00<0n_3V0;0G7P3jl>H0>`3jl>H30;0G7PP0=Ef:00<0000003ALR@0d
G8T01`0dG8T00`000000<eZ703=JQ`0803=JQ`040000000aEh@00000000000L0<5J100<0000002iC
OP0^Dgh00`0^Dgh00`000000;E1k02e@N`0202e@N`030000000P>U`083YL008083YL00<000000?[`
iP2`5ah06`3jl>H00`2`5ah0n_3V0?[`iP060?[`iP030;0G7P3jl>H0n_3V0200n_3V0`00000401@S
>@800000101/_oL2000000<0L/[o00<0000007?;o`1cbol00P1cbol00`000000n_3V0?[`iP0J0?[`
iP80/1LN603jl>H00`2`5ah0n_3V0?[`iP0A0?[`iP<0/1LN00<0n_3V0;0G7P2`5ah0403jl>H00`2`
5ah0n_3V0?[`iP0P0?[`iP40oooo000[0?[`iPD0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP0i0?[`iPD0
/1LN1`0eGHX00`000000=5b903ALR@0703ALR@030000000cFXL0<eZ700L0<eZ70`000009031FP@03
0000000^Dgh0;U=n00@0;U=n00D0000002e@N`0]D7/0;E1k00000002020jG08000000P3jl>H00`2`
5ah0n_3V0?[`iP0I0?[`iP030;0G7P3jl>H0n_3V00D0n_3V0`2`5ahQ0?[`iP030000000<5R@00000
00<052<i00<0000006BbiP000000101/_oL2000000<0L/[o00<0000007?;o`1cbol00P1cbol00`00
0000n_3V0?[`iP0L0?[`iP030;0G7P3jl>H0n_3V01H0n_3V0P2`5ahA0?[`iP80/1LN00@0n_3V0;0G
7P2`5ah0/1LN4@3jl>H00`2`5ah0n_3V0?[`iP0O0?[`iP40oooo000]0?[`iPH0/1LN>P3jl>H@0;0G
7PL0=5b900<0000003=JQ`0cFXL0100cFXL300000003039IQ@000000<5J100T0<5J100<0000002iC
OP0^Dgh0100^Dgh01`000000;E1k02e@N`0]D7/00000020jG0000000103jl>H00`2`5ah0n_3V0?[`
iP0H0?[`iP030;0G7P3jl>H0n_3V00L0n_3V00<0/1LN0?[`iP3jl>H01@3jl>H20;0G7QP0n_3V00D0
/1LN0000000<5R@0000001@S>@030000000306BbiP000000K;og00<0K;og00D0000006g0n@000000
L/[o0000000507?;o`030000003jl>H0n_3V01d0n_3V0P2`5ahH0?[`iP030;0G7P3jl>H0n_3V00h0
n_3V00H0/1LN0?[`iP2`5ah0/1LN0?[`iP2`5ahB0?[`iP030;0G7P3jl>H0n_3V01h0n_3V0@3oool0
0340n_3V0P2`5ahk0?[`iP80/1LN00<0=Ef:0;0G7P0eGHX01`0eGHX00`000000=5b903ALR@0703AL
R@030000000cFXL0<eZ70080<eZ70P000004039IQ@030000000`EX40<5J100P0<5J100<0000002iC
OP0^Dgh01@0^Dgh00`000000;E1k02e@N`02000000D0n_3V00<0/1LN0?[`iP3jl>H0603jl>H00`2`
5ah0n_3V0?[`iP0=0?[`iP@0/1LN6@3jl>H01000000031HT00000000000306>`i0800000101/_oL0
0`000000KL3i06g0n@02000000D0Ll_o00<000000?[`iP3jl>H07`3jl>H00`2`5ah0n_3V0?[`iP0F
0?[`iP030;0G7P3jl>H0n_3V00`0n_3V0P2`5ah20?[`iP<0/1LN4P3jl>H00`2`5ah0n_3V0?[`iP0N
0?[`iP40oooo001_0?[`iP030000002`5ah0/1LN00P0=Ef:00<0000003ALR@0dG8T01`0dG8T00`00
0000<eZ700000002000000H0<UV500<00000031FP@0`EX40200`EX400`000000;U=n02iCOP0502iC
OP040000000]D7/0;E1k000000H0n_3V00<0/1LN0?[`iP3jl>H0603jl>H00`2`5ah0n_3V0?[`iP0>
0?[`iP<0/1LN6@3jl>H01000000031HT00000000000306>`i0800000101/_oL00`000000KL3i06g0
n@02000000D0Ll_o00<000000?[`iP3jl>H0803jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP80/1LN3P3j
l>H50;0G7Q<0n_3V00<0/1LN0?[`iP3jl>H07@3jl>H10?ooo`00K`3jl>H00`000000=Ef:03EMRP08
03EMRP030000000dG8T0=5b900H0=5b90`000009039IQ@030000000`EX40<5J100P0<5J100<00000
02iCOP0^Dgh01@0^Dgh3000000L0n_3V00<0/1LN0?[`iP3jl>H02P3jl>H00`2`5ah0n_3V0?[`iP0L
0?[`iP80/1LN6P3jl>H0100<5R@0000005BHa000000406>`i0050000001/_oL0K;og06bom`000000
101]`?T00`000000Ll_o07?;o`0307?;o`030000003jl>H0n_3V0240n_3V0P2`5ah00`3jl>H0/1LN
0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V00h0n_3V0P2`5ahD0?[`iP030;0G7P3jl>H0n_3V01`0n_3V
0@3oool006l0n_3V00<0000003EMRP0eGHX0200eGHX00`000000=5b903ALR@0403ALR@80000000<0
=5^80000000bFHD02@0bFHD00`000000<5J1031FP@08031FP@030000000^Dgh0;U=n00<0;U=n0P00
00090?[`iP030;0G7P3jl>H0/1LN00T0n_3V102`5ahL0?[`iP030;0G7P3jl>H0n_3V01T0n_3V1@00
000406>`i08000000P1/_oL00`000000KL3i06g0n@0206g0n@8000000`1cbol00`000000n_3V0?[`
iP0T0?[`iP030;0G7P3jl>H0/1LN01H0n_3V00<0/1LN0?[`iP3jl>H0903jl>H00`2`5ah0n_3V0?[`
iP020?[`iP030;0G7P3jl>H0n_3V01H0n_3V0@3oool004`0n_3V00<0/1LN0?[`iP3jl>H07`3jl>H0
0`000000=Ef:03EMRP0903EMRP040000000dG8T0=5b903ALR@<000000`0dFhP00`000000<UV5039I
Q@08039IQ@030000000`EX40<5J100P0<5J100@0000002iCOP0^Dgh0;U=n0P00000;0?[`iP040;0G
7P3jl>H0/1LN0;0G7PL0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P0K0?[`iP030;0G7P3jl>H0n_3V01X0
n_3V0P0000000`1;R:l000000000000406>`i08000000P1/_oL00`000000KL3i06g0n@0206g0n@03
0000001]_oP000000080Ll_o00<000000?[`iP3jl>H0903jl>H30;0G7QL0n_3V0P2`5ah=0?[`iP03
0;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H00P2`5ahH0?[`iP40oooo001;0?[`iP@0/1LN
7`3jl>H00`000000=Ef:03EMRP0903EMRP040000000dG8T00000000000H0=5^800<00000039IQ@0b
FHD0200bFHD00`000000<5J1031FP@08031FP@040000000^Dgh00000000000d0n_3V00@0/1LN0?[`
iP2`5ah0/1LN2@3jl>H40;0G7QT0n_3V00<0/1LN0?[`iP3jl>H06`3jl>H20000000304^8[`000000
000000<0Hk3T00H0000006VhkP1Y^>h0000006bom`00000406g0n@80/1LN00@0000007?;o`1cbol0
00009@3jl>H50;0G7QP0n_3V00<0/1LN0?[`iP3jl>H02`3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP80
/1LN0P3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP40oooo001:0?[`iP80/1LN00@0n_3V0;0G7P2`5ah0
/1LN7P3jl>H00`000000=Ef:03EMRP0803EMRP<00000200dFhP00`000000<UV5039IQ@08039IQ@03
0000000`EX40<5J100L0<5J10`00000?0?[`iP050;0G7P3jl>H0n_3V0?[`iP2`5ah0203jl>H00`2`
5ah0n_3V0?[`iP0J0?[`iP030;0G7P3jl>H0n_3V01/0n_3V0P0000000`1;R:l000000000000306>`
i0040000001Y^>h0JKS^06VhkP800000101]`?T01P000000KKoh0;0G7P2`5ah0Ll_o000001L0n_3V
0P2`5ahZ0?[`iP80/1LN00<0n_3V0;0G7P2`5ah02@3jl>H20;0G7Q@0n_3V0`2`5ah20?[`iP030;0G
7P3jl>H0n_3V01D0n_3V0@3oool004T0n_3V2P2`5ahK0?[`iP030000000eGHX0=Ef:00D0=Ef:0`00
00000`0dG8T0000003AKR00803AKR0030000000bFHD0<UV500P0<UV500<00000031FP@0`EX401@0`
EX42000000<0/1LN3`3jl>H00`2`5ah0n_3V0?[`iP020?[`iP030;0G7P3jl>H0n_3V00D0n_3V00<0
/1LN0?[`iP3jl>H06@3jl>H00`2`5ah0n_3V0?[`iP0L0?[`iP050000001;R:l0000005BG`P000000
0`1S/>@010000000JKS^06VhkP1Y^>h2000000@0KL3i00@0000006fon01]_oP0KKoh0`2`5ah00`3j
l>H0/1LN0?[`iP0E0?[`iP@0/1LN:03jl>H30;0G7P/0n_3V00<0/1LN0?[`iP3jl>H0403jl>H20;0G
7P80n_3V00<0/1LN0?[`iP2`5ah05`3jl>H10?ooo`00BP3jl>H20;0G7P80n_3V00<0/1LN0?[`iP3j
l>H00P3jl>H:0;0G7Q40n_3V00<0000003EMRP0eGHX00P0eGHX3000000@0=5b900<0000003AKR00d
FhP01`0dFhP00`000000<UV5039IQ@08039IQ@030000000`EX40<5J100<0<5J10P0000000`2`5ah0
n_3V0;0G7P030;0G7Ph0n_3V00<0/1LN0?[`iP3jl>H02P3jl>H00`2`5ah0n_3V0?[`iP0h0?[`iP05
0000001;R:l0000005BG`P0000000`1S/>@00`000000JKS^06VhkP0206VhkP050000001]`?T0KL3i
06g0n@0000001@1]_oP00`000000n_3V0;0G7P020;0G7QT0n_3V102`5ah0103jl>H0/1LN0;0G7P2`
5ahO0?[`iP030;0G7P3jl>H0/1LN0080/1LN2`3jl>H00`2`5ah0n_3V0?[`iP0A0?[`iP80/1LN00<0
n_3V0;0G7P2`5ah05`3jl>H10?ooo`00C03jl>H30;0G7Ql0n_3V00<0000003EMRP0000000P000007
03ALR@030000000dFhP0=5^800L0=5^800<00000039IQ@0bFHD00P0bFHD20;0G7P@0<UV500@00000
031FP@0`EX40<5J10P0000030?[`iP<0/1LN703jl>H00`2`5ah0n_3V0?[`iP0i0?[`iP040000001;
R:l0000005BG`P8000000P1S/>@00`000000JKS^06VhkP0206VhkP8000000P1]`?T00`000000KKoh
06fon00306fon0030000003jl>H0/1LN00<0/1LN703jl>H50;0G7Qd0n_3V1P2`5ah<0?[`iP030;0G
7P3jl>H0n_3V0180n_3V102`5ahF0?[`iP40oooo001>0?[`iP030;0G7P3jl>H0n_3V01d0n_3V0P00
000:03ALR@030000000dFhP0=5^800L0=5^800@00000039IQ@0bFHD0<UV51@2`5ah2039IQ@040000
000`EX400000000000L0n_3V00<0/1LN0?[`iP3jl>H06P3jl>H00`2`5ah0n_3V0?[`iP0i0?[`iP80
00000P1DUl8200000080Hk3T00<0000006VhkP1Y^>h00P1Y^>h200000080KL3i00<0000006fon01]
_oP00`1]_oP010000000n_3V0;0G7P2`5ahO0?[`iP80/1LN00<0n_3V0;0G7P2`5ah07`3jl>H40;0G
7P`0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H20;0G7QH0n_3V0@3oool006h0n_3V00<0000003ALR@0d
G8T02@0dG8T00`000000=5^803AKR00703AKR0060000000bFHD0<UV5039IQ@2`5ah0<UV50P2`5ah2
039IQ@<000002@3jl>H00`2`5ah0n_3V0?[`iP0J0?[`iP030;0G7P3jl>H0n_3V03<0n_3V0P2`5ah4
0?[`iP8000000P1DUl8010000000HjoR00000000000506VhkP050000001Z^O00000006g0n@000000
1@1]_oP00`000000/1LN0;0G7P030;0G7Qd0n_3V0`2`5ahb0?[`iP80/1LN:`3jl>H10?ooo`00KP3j
l>H00`000000=5b903ALR@0803ALR@030000000dFhP0=5^800P0=5^800<00000039IQ@0bFHD00P0b
FHD20;0G7P030000002`5ah0000000`0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`
iP050?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H05`3jl>H00`2`5ah0n_3V0?[`
iP040;0G7P@0n_3V0P00000205BG`P040000001S[n800000000000D0JKS^00<0000006Zil01Z^O00
0P00000506fon0D0/1LNE@3jl>H00`2`5ah0n_3V0?[`iP0X0?[`iP40oooo001^0?[`iP030000000d
G8T0=5b900P0=5b900<0000003AKR00dFhP0200dFhP00`000000<UV5039IQ@02039IQ@8000000P3j
l>H00`2`5ah0n_3V0?[`iP0:0?[`iP030;0G7P3jl>H0n_3V0140n_3V0P2`5ah60?[`iP030;0G7P3j
l>H0n_3V01<0n_3V0`2`5ahH0?[`iPL0/1LN1@3jl>H01@000000E9O205BG`P1DUl8000000080HjoR
00<0000006VhkP1Y^>h00`1Y^>h00`000000J[W`06Zil002000000<0KKoh00D0/1LN06fon0000000
n_3V0;0G7P0Z0?[`iP030;0G7P3jl>H0n_3V02/0n_3V00<0/1LN0?[`iP3jl>H09`3jl>H10?ooo`00
I`3jl>H20;0G7PD0n_3V00<0000003ALR@0dG8T0200dG8T00`000000=5^803AKR00803AKR0030000
000bFHD00000008000001@3jl>H00`2`5ah0n_3V0?[`iP080?[`iP030;0G7P3jl>H0n_3V0140n_3V
102`5ah50?[`iP030;0G7P3jl>H0n_3V0180n_3V102`5ahD0?[`iP@0/1LN00@0n_3V0;0G7P2`5ah0
n_3V0`2`5ah50?[`iP040000001DUl80E9O2000000<0HjoR00<0000006VhkP1Y^>h00P1Y^>h00`00
0000J[W`06Zil00206Zil0030000001]_oP0KKoh0080KKoh00<000000?[`iP3jl>H0;03jl>H20;0G
7R`0n_3V00<0/1LN0?[`iP3jl>H09P3jl>H10?ooo`00I@3jl>H30;0G7P030?[`iP2`5ah0n_3V00<0
n_3V00<0000003ALR@0dG8T0200dG8T00`000000=5^803AKR00703AKR0<000002@3jl>H00`2`5ah0
n_3V0?[`iP070?[`iP030;0G7P3jl>H0n_3V0100n_3V0`2`5ah00`3jl>H0/1LN0?[`iP040?[`iP03
0;0G7P3jl>H0n_3V0140n_3V102`5ah00`3jl>H0/1LN0?[`iP0I0?[`iP030;0G7P3jl>H0/1LN00H0
n_3V00@0000005BG`P1DUl8000000`1S[n82000000<0JKS^00<0000006Zil01Z^O000P1Z^O020000
00<0KKoh00<000000?[`iP3jl>H0;P3jl>H20;0G7R/0n_3V00<0/1LN0?[`iP3jl>H09@3jl>H10?oo
o`00I@3jl>H20;0G7P040?[`iP2`5ah0/1LN0;0G7P<0n_3V00<0000003ALR@0dG8T0200dG8T00`00
0000=5^803AKR00303AKR0@000003@3jl>H00`2`5ah0n_3V0?[`iP060?[`iP030;0G7P3jl>H0n_3V
00l0n_3V102`5ah00`3jl>H0/1LN0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V00@0n_3V102`5ahI0?[`
iP030;0G7P3jl>H0n_3V00P0n_3V00<0000005BG`P0000000`1S[n800`000000IkCY0000000206Vh
kP030000001Z^O00J[W`0080J[W`00<0000006Zil@0000000P1]_oP00`000000n_3V0?[`iP0`0?[`
iP80/1LN:P3jl>H20;0G7P<0n_3V00<0/1LN0?[`iP3jl>H07`3jl>H10?ooo`00I@3jl>H50;0G7P@0
n_3V00<0000003ALR@0dG8T0200dG8T00`000000=5^800000003000001X0n_3V00<0/1LN0?[`iP3j
l>H03P3jl>H20;0G7P80n_3V0P2`5ah00`3jl>H0/1LN0?[`iP0A0?[`iP80/1LN1P3jl>H00`2`5ah0
n_3V0?[`iP0J0?[`iP030;0G7P3jl>H0n_3V00P0n_3V00<0000005BG`P0000000`1S[n800`000000
IkCY0000000206VhkP030000001Z^O00J[W`0080J[W`00<0000006Zil@0000000P1]_oP00`000000
n_3V0?[`iP0b0?[`iP030;0G7P3jl>H0n_3V02T0n_3V00@0/1LN0?[`iP2`5ah0n_3V0P2`5ahO0?[`
iP40oooo001U0?[`iP80/1LN00<0n_3V0;0G7P2`5ah0103jl>H00`000000=5b903ALR@0703ALR@<0
00007P3jl>H00`2`5ah0n_3V0?[`iP0@0?[`iPH0/1LN4P3jl>H30;0G7P@0n_3V00<0/1LN0?[`iP3j
l>H06P3jl>H00`2`5ah0n_3V0?[`iP0:0?[`iP8000000`1S[n801P000000IkCY06Ndj@000000JKS^
000000@0J[W`00H0000006Zil@1Z^O40000006fon000000e0?[`iP80/1LN:P3jl>H20;0G7P030?[`
iP2`5ah0/1LN01l0n_3V0@3oool006H0n_3V0`2`5ah00`3jl>H0/1LN0?[`iP020?[`iP030000000d
G8T0=5b900@0=5b90`00000Q0?[`iP030;0G7P3jl>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H04`3j
l>H20;0G7PD0n_3V00<0/1LN0?[`iP3jl>H06@3jl>H00`2`5ah0n_3V0?[`iP0;0?[`iP8000000`1S
[n8010000000IkCY06Ndj@1W]>T2000000@0J[W`00@0000006Zil@1Z^O40J[Wa0P00000g0?[`iP80
/1LN:03jl>H30;0G7P030?[`iP2`5ah0/1LN01h0n_3V0@3oool006L0n_3V00@0/1LN0?[`iP3jl>H0
n_3V0P2`5ah00`3jl>H0000003ALR@0303ALR@800000903jl>H00`2`5ah0n_3V0?[`iP060?[`iP80
/1LN2@3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V00<0n_3V00<0/1LN0?[`iP3j
l>H06@3jl>H00`2`5ah0n_3V0?[`iP0=0?[`iP050000001S[n80HjoR06>_hP000000101W]>T00`00
0000J[W`06Zil00206Zil0030000001Z^O40J[Wa0080J[Wa00<000000?[`iP3jl>H0=`3jl>H01@2`
5ah0n_3V0?[`iP3jl>H0/1LN01l0n_3V00P0/1LN0?[`iP3jl>H0n_3V0;0G7P3jl>H0/1LN0?[`iP80
/1LN7P3jl>H10?ooo`00K@3jl>H00`2`5ah0000003ALR@03000002H0n_3V00<0/1LN0?[`iP3jl>H0
1@3jl>H40;0G7PP0n_3V00<0/1LN0?[`iP3jl>H0503jl>H00`2`5ah0n_3V0?[`iP030?[`iP030;0G
7P3jl>H0n_3V01P0n_3V00<0/1LN0?[`iP3jl>H03`3jl>H010000000HjoR06>_hP00000406Ndj@80
00000`1Z^O000`000000J[Wa06Zil@0206Zil@030000003jl>H0n_3V03P0n_3V0`2`5ah00`3jl>H0
/1LN0?[`iP0N0?[`iP030;0G7P3jl>H0/1LN0080/1LN00@0n_3V0;0G7P2`5ah0/1LN7P3jl>H10?oo
o`00KP3jl>H00`2`5ah000000?[`iP0X0?[`iP030;0G7P3jl>H0n_3V00@0n_3V00<0/1LN0?[`iP2`
5ah00P3jl>H00`2`5ah0n_3V0?[`iP050?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3j
l>H0103jl>H00`2`5ah0n_3V0?[`iP0G0?[`iP030;0G7P3jl>H0n_3V0100n_3V00@0000006>_hP1S
[n800000101W]>T00`000000J;K[0000000206Zil0030000001Z^O40J[Wa0080J[Wa00<000000?[`
iP3jl>H02@3jl>H20;0G7Rl0n_3V102`5ahO0?[`iPT0/1LN7@3jl>H10?ooo`00K`3jl>H20;0G7Pl0
n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP050?[`iP@0/1LN203jl>H00`2`5ah0
n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V00<0n_3V00<0/1LN0?[`iP3jl>H0;03jl>H00`000000
HjoR0000000406Ndj@030000001X]^/000000080J[W`00<0000006Zil@1Z^O400P1Z^O400`000000
n_3V0?[`iP0;0?[`iP@0/1LN1`3jl>H00`2`5ah0n_3V0?[`iP0P0?[`iP80/1LN00<0n_3V0;0G7P2`
5ah08@3jl>H00`2`5ah0n_3V0?[`iP040;0G7Qd0n_3V0@3oool00740n_3V00<0/1LN0?[`iP3jl>H0
2`3jl>H30;0G7R00n_3V00<0/1LN0?[`iP3jl>H0203jl>H00`2`5ah0n_3V0?[`iP0I0?[`iP030;0G
7P3jl>H0n_3V02d0n_3V0P00000406Ndj@060000001X]^/0J;K[0000001Z^O000000101Z^O400`00
0000n_3V0?[`iP0?0?[`iP@0/1LN0`3jl>H20;0G7R40n_3V1P2`5ahQ0?[`iP030;0G7P3jl>H0n_3V
0200n_3V0@3oool007l0n_3V1@2`5ahN0?[`iP030;0G7P3jl>H0n_3V00L0n_3V00<0/1LN0?[`iP3j
l>H06@3jl>H00`2`5ah0n_3V0?[`iP0^0?[`iP800000101W]>T010000000J;K[06Rfj`1X]^/20000
00@0J[Wa00<000000?[`iP3jl>H04`3jl>H60;0G7TP0n_3V0P2`5ahP0?[`iP40oooo001n0?[`iP@0
/1LN0P3jl>H00`2`5ah0n_3V0?[`iP0L0?[`iP030;0G7P3jl>H0n_3V00H0n_3V00<0/1LN0?[`iP3j
l>H06@3jl>H00`2`5ah0n_3V0?[`iP0_0?[`iP050000001W]>T0IkCY06Ndj@2`5ah01@1X]^/00`00
0000J[Wa06Zil@0206Zil@030000003jl>H0n_3V01D0n_3V1@2`5ai90?[`iP030;0G7P3jl>H0n_3V
01d0n_3V0@3oool007h0n_3V00H0/1LN0?[`iP2`5ah0/1LN0?[`iP2`5ahO0?[`iP030;0G7P3jl>H0
n_3V00H0n_3V00<0/1LN0?[`iP3jl>H0603jl>H00`2`5ah0n_3V0?[`iP0a0?[`iP030000001W]>T0
/1LN00<0/1LN0`1X]^/2000000<0J[Wa00<000000?[`iP3jl>H05@3jl>H30;0G7T`0n_3V00<0/1LN
0?[`iP3jl>H0703jl>H10?ooo`00O`3jl>H40;0G7R00n_3V00<0/1LN0?[`iP3jl>H01P3jl>H00`2`
5ah0n_3V0?[`iP0H0?[`iP030;0G7P3jl>H0n_3V0140n_3V0`2`5ahL0?[`iP@0/1LN00<000000;0G
7P1X]^/00`1X]^/00`000000J;K/0000000206Zil@030000003jl>H0n_3V06D0n_3V0P2`5ahL0?[`
iP40oooo00200?[`iP030;0G7P3jl>H0/1LN0200n_3V00<0/1LN0?[`iP3jl>H01P3jl>H00`2`5ah0
n_3V0?[`iP0;0?[`iP030;0G7P3jl>H0n_3V00T0n_3V00<0/1LN0?[`iP3jl>H0403jl>H50;0G7QP0
n_3V102`5ah20?[`iP030000001W]>T0/1LN00D0J;K[00<0000006Rfk00000000P1Z^O400`000000
n_3V0?[`iP0i0?[`iP030;0G7P3jl>H0n_3V02/0n_3V00<0/1LN0?[`iP3jl>H06@3jl>H10?ooo`00
PP3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V00L0n_3V00<0/1LN0?[`iP3jl>H0
1@3jl>H00`2`5ah0n_3V0?[`iP0;0?[`iP80/1LN2`3jl>H00`2`5ah0n_3V0?[`iP0A0?[`iP@0/1LN
5P3jl>H20;0G7PL0n_3V0P00000506Rfj`060000001X]^`0J;K/0000001Z^O400000?03jl>H20;0G
7R`0n_3V00<0/1LN0?[`iP3jl>H0603jl>H10?ooo`00PP3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP<0
/1LN203jl>H00`2`5ah0n_3V0?[`iP050?[`iP030;0G7P3jl>H0n_3V00T0n_3V1@2`5ahN0?[`iP@0
/1LN7`3jl>H2000000D0J;K[00@0000006Rfk01X]^`0J;K/0P00000n0?[`iP80/1LN:`3jl>H00`2`
5ah0n_3V0?[`iP0G0?[`iP40oooo00230?[`iP030;0G7P3jl>H0n_3V0140n_3V102`5ah@0?[`iP03
0;0G7P3jl>H0n_3V00P0n_3V0P2`5ah0103jl>H0/1LN0;0G7P2`5ahM0?[`iP040;0G7P3jl>H0n_3V
0;0G7R40n_3V00<0000006Rfj`1X]^/00P1X]^/00`000000J;K/06Rfk00306Rfk0030000003jl>H0
n_3V03h0n_3V0P2`5ahZ0?[`iP80/1LN5`3jl>H10?ooo`00P`3jl>H00`2`5ah0n_3V0?[`iP0@0?[`
iP060;0G7P3jl>H0/1LN0;0G7P3jl>H0/1LN3`3jl>H00`2`5ah0n_3V0?[`iP090?[`iP060;0G7P3j
l>H0/1LN0;0G7P3jl>H0/1LN6`3jl>H00`2`5ah0n_3V0?[`iP0T0?[`iP050000001X]^/0J;K[06Rf
j`0000001@1X]^`00`000000n_3V0?[`iP100?[`iP80/1LN:P3jl>H00`2`5ah0n_3V0?[`iP0D0?[`
iP40oooo00230?[`iP030;0G7P3jl>H0n_3V00l0n_3V1`2`5ah?0?[`iP030;0G7P3jl>H0n_3V00X0
n_3V102`5ahL0?[`iP030;0G7P3jl>H0n_3V02D0n_3V00@0000006Rfj`1X]^/000001@1X]^`00`00
0000n_3V0?[`iP120?[`iP80/1LN:@3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP40oooo00240?[`iP03
0;0G7P3jl>H0n_3V00d0n_3V0P2`5ah20?[`iP80/1LN00<0n_3V0;0G7P2`5ah03@3jl>H00`2`5ah0
n_3V0?[`iP0;0?[`iP030;0G7P3jl>H0/1LN01`0n_3V00<0/1LN0?[`iP3jl>H09P3jl>H010000000
J;K[06Rfj`00000506Rfk0030000003jl>H0n_3V04@0n_3V0P2`5ahX0?[`iP80/1LN1@3jl>H00`2`
5ah0n_3V0?[`iP0;0?[`iP40oooo00240?[`iP030;0G7P3jl>H0n_3V00h0n_3V0P2`5ah00`3jl>H0
/1LN0?[`iP020;0G7Ph0n_3V00<0/1LN0?[`iP3jl>H02`3jl>H00`2`5ah0n_3V0?[`iP0K0?[`iP03
0;0G7P3jl>H0n_3V02P0n_3V00<0000006Rfj`0000001@1X]^`00`000000n_3V0?[`iP160?[`iP80
/1LN1`3jl>H00`2`5ah0n_3V0?[`iP0N0?[`iP040;0G7P3jl>H0n_3V0?[`iP80/1LN3@3jl>H10?oo
o`00Q03jl>H00`2`5ah0n_3V0?[`iP0@0?[`iP<0/1LN403jl>H00`2`5ah0n_3V0?[`iP030?[`iP03
0;0G7P3jl>H0n_3V00D0n_3V00<0/1LN0?[`iP3jl>H06P3jl>H00`2`5ah0n_3V0?[`iP0Z0?[`iP80
00001@1X]^`00`000000n_3V0?[`iP0H0?[`iP<0/1LN;@3jl>H20;0G7PD0n_3V0P2`5ahP0?[`iP06
0;0G7P3jl>H0n_3V0;0G7P3jl>H0/1LN303jl>H10?ooo`00Q@3jl>H00`2`5ah0n_3V0?[`iP0@0?[`
iP030;0G7P3jl>H0n_3V01@0n_3V0P2`5ah60?[`iP030;0G7P3jl>H0n_3V01L0n_3V00@0/1LN0?[`
iP3jl>H0/1LN;P3jl>H00`000000J;K/06Rfk00306Rfk0030000003jl>H0n_3V01/0n_3V1P2`5ah9
0?[`iP030;0G7P3jl>H0n_3V01d0n_3V0P2`5ah20?[`iP<0/1LN8@3jl>H30;0G7P030?[`iP2`5ah0
n_3V00/0n_3V0@3oool008D0n_3V00<0/1LN0?[`iP3jl>H0403jl>H00`2`5ah0n_3V0?[`iP0C0?[`
iP@0/1LN1@3jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP80/1LN803jl>H20;0G7Q00n_3V00<0000006Rf
k01X]^`00P1X]^`00`000000n_3V0?[`iP060?[`iP80/1LN6@3jl>H50;0G7P<0n_3V0`2`5ahP0?[`
iP<0/1LN00<0n_3V0;0G7P2`5ah0803jl>H30;0G7P80n_3V00<0/1LN0?[`iP3jl>H02@3jl>H10?oo
o`00V03jl>H00`2`5ah0n_3V0?[`iP0B0?[`iPD0/1LN1@3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iPD0
/1LN7@3jl>H40;0G7Q40n_3V00D0000006Rfk01X]^`0J;K/000000070?[`iPH0/1LN6`3jl>H80;0G
7R00n_3V0P2`5ah00`3jl>H0/1LN0;0G7P0O0?[`iP060;0G7P3jl>H0n_3V0;0G7P3jl>H0/1LN2`3j
l>H10?ooo`00V03jl>H00`2`5ah0n_3V0?[`iP0A0?[`iP030;0G7P3jl>H0/1LN0080/1LN00<0n_3V
0;0G7P3jl>H00P3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP<0/1LN00<0n_3V0;0G7P2`5ah06`3jl>H2
0;0G7P040?[`iP2`5ah0/1LN0;0G7Q80n_3V00@0000006Rfk01X]^`000001`3jl>H50;0G7Ql0n_3V
0P2`5ah0103jl>H0/1LN0;0G7P2`5ahN0?[`iP030;0G7P3jl>H0n_3V00<0/1LN7P3jl>H20;0G7P<0
n_3V0`2`5ah:0?[`iP40oooo002H0?[`iP030;0G7P3jl>H0n_3V0100n_3V0`2`5ah01@3jl>H0/1LN
0;0G7P3jl>H0/1LN00<0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H20;0G7P050?[`iP2`5ah0/1LN0?[`
iP2`5ah0703jl>H20;0G7P030?[`iP2`5ah0/1LN01<0n_3V00<0000006Rfk0000000103jl>H50;0G
7P030?[`iP2`5ah0n_3V01l0n_3V102`5ahP0?[`iPL0/1LN7@3jl>H60;0G7P030?[`iP2`5ah0n_3V
00T0n_3V0@3oool009P0n_3V00<0/1LN0?[`iP3jl>H03`3jl>H20;0G7P<0n_3V00<0/1LN0?[`iP2`
5ah00P2`5ah20?[`iP030;0G7P3jl>H0n_3V01@0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P020;0G7Q/0
n_3V0`2`5ah00`3jl>H0/1LN0?[`iP0C0?[`iP80000000@0n_3V0;0G7P2`5ah0/1LN103jl>H30;0G
7R00n_3V0P2`5ahQ0?[`iP@0/1LN9@3jl>H50;0G7PT0n_3V0@3oool009P0n_3V00<0/1LN0?[`iP3j
l>H0403jl>H20;0G7P030?[`iP2`5ah0/1LN00<0n_3V00@0/1LN0?[`iP3jl>H0/1LN5`3jl>H30;0G
7P030?[`iP2`5ah0/1LN01X0n_3V00<0/1LN0?[`iP3jl>H00P2`5ahD0?[`iP@0/1LN203jl>H00`2`
5ah0n_3V0?[`iP1i0?[`iP40oooo002H0?[`iP030;0G7P3jl>H0n_3V0180n_3V0`2`5ah00`3jl>H0
/1LN0;0G7P020?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H00P2`5ahK0?[`iP03
0;0G7P3jl>H0n_3V01@0n_3V0`2`5aj80?[`iP40oooo002H0?[`iP030;0G7P3jl>H0n_3V01<0n_3V
0`2`5ah40?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H0703jl>H00`2`5ah0n_3V
0?[`iP2P0?[`iP40oooo002H0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H06`3j
l>H00`2`5ah0n_3V0?[`iP0L0?[`iP030;0G7P3jl>H0n_3V0:40n_3V0@3oool009L0n_3V00<0/1LN
0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0L0?[`iP030;0G7P3jl>H0n_3V01/0n_3V00<0/1LN
0?[`iP3jl>H0XP3jl>H10?ooo`00U`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V
01/0n_3V00<0/1LN0?[`iP3jl>H06`3jl>H00`2`5ah0n_3V0?[`iP2S0?[`iP40oooo002G0?[`iP03
0;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H06`3jl>H00`2`5ah0n_3V0?[`iP0J0?[`iP03
0;0G7P3jl>H0n_3V0:@0n_3V0@3oool009L0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V
0?[`iP0J0?[`iP030;0G7P3jl>H0n_3V01X0n_3V00<0/1LN0?[`iP3jl>H0Y@3jl>H10?ooo`00U`3j
l>H00`2`5ah0n_3V0?[`iP0B0?[`iP030;0G7P3jl>H0n_3V01/0n_3V00<0/1LN0?[`iP3jl>H06@3j
l>H00`2`5ah0n_3V0?[`iP2V0?[`iP40oooo002G0?[`iP030;0G7P3jl>H0n_3V0180n_3V00<0/1LN
0?[`iP3jl>H06P3jl>H00`2`5ah0n_3V0?[`iP0I0?[`iP030;0G7P3jl>H0n_3V0:L0n_3V0@3oool0
09L0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP0J0?[`iP030;0G7P3jl>H0n_3V
0<<0n_3V0@3oool00:`0n_3V00<0/1LN0?[`iP3jl>H06@3jl>H00`2`5ah0n_3V0?[`iP340?[`iP40
oooo002/0?[`iP030;0G7P3jl>H0n_3V01T0n_3V00<0/1LN0?[`iP3jl>H0a03jl>H10?ooo`00Z`3j
l>H00`2`5ah0n_3V0?[`iP0I0?[`iP030;0G7P3jl>H0n_3V0<D0n_3V0@3oool00:/0n_3V00<0/1LN
0?[`iP3jl>H06@3jl>H00`2`5ah0n_3V0?[`iP350?[`iP40oooo002[0?[`iP030;0G7P3jl>H0n_3V
01P0n_3V00<0/1LN0?[`iP3jl>H0aP3jl>H10?ooo`00Z`3jl>H00`2`5ah0n_3V0?[`iP0H0?[`iP03
0;0G7P3jl>H0n_3V0<H0n_3V0@3oool00:X0n_3V00<0/1LN0?[`iP3jl>H0hP3jl>H10?ooo`00ZP3j
l>H00`2`5ah0n_3V0?[`iP3R0?[`iP40oooo002Z0?[`iP030;0G7P3jl>H0n_3V0>80n_3V0@3oool0
0:X0n_3V00<0/1LN0?[`iP3jl>H0hP3jl>H10?ooo`00Z@3jl>H00`2`5ah0n_3V0?[`iP3S0?[`iP40
oooo002Y0?[`iP030;0G7P3jl>H0n_3V0><0n_3V0@3oool00:T0n_3V00<0/1LN0?[`iP3jl>H0h`3j
l>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00
o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`
iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o
0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V
0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0
n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H1
0?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3j
l>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40
oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`
iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3o
ool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.25, 0}} -> {0.0486967, -7.73692*^-05, \
0.00214909, 0.00214909}}]
}, Open  ]],

Cell[BoxData[
    \(Clear[contour]\)], "Input",
  CellLabel->"In[4]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->{},
WindowSize->{494, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 66, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1845, 56, 481, 16, 68, "Usage",
      CellTags->"Function?"],
    Cell[2329, 74, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 354485, 16294}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 66, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1845, 56, 481, 16, 68, "Usage",
  CellTags->"Function?"],
Cell[2329, 74, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2426, 79, 183, 3, 58, "MathCaption"],
Cell[2612, 84, 159, 6, 41, "MathCaption"],
Cell[2774, 92, 406, 14, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3205, 110, 33, 0, 39, "ExampleSection"],
Cell[3241, 112, 97, 2, 29, "Input"],
Cell[3341, 116, 344, 6, 76, "Text"],

Cell[CellGroupData[{
Cell[3710, 126, 227, 5, 49, "Input"],
Cell[3940, 133, 394, 6, 50, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4371, 144, 549, 9, 189, "Input"],
Cell[4923, 155, 348797, 16113, 441, 205721, 14342, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[353735, 16271, 71, 2, 29, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

