(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    621964,      21547]*)
(*NotebookOutlinePosition[    622864,      21579]*)
(*  CellTagsIndexPosition[    622786,      21573]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawGraphics3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["DrawGraphics3D",
          "MR"], 
        StyleBox["[",
          "MR"], \(plot[args]\), 
        StyleBox["]",
          "MR"]}]]],
  " will extract the primitive graphics from any plot that produces or can be \
converted to Graphics3D."
}], "Usage",
  CellTags->"Function?"],

Cell["Normal display is suppressed.", "MathCaption"],

Cell["\<\
DrawGraphics3D will handle routines produced by packages which were not \
anticipated by the author of DrawingCube, or for which there is no explicit \
Draw routine..\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawWithOptions3D",
    ButtonData:>{"DrawWithOptions3D"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[{
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<Graphics`Graphics3D`\>"]\)}], "Input",
  CellLabel->"In[224]:="],

Cell["\<\
The Graphics`Graphics3D`  routines are not directly covered by DrawGraphics. \
However you can still use them. This uses the BarChart3D example.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{BarChart3D[{{1, 2, 3}, {4, 5, 6}}] // 
            DrawGraphics3D}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            1}, \[IndentingNewLine]Axes \[Rule] True];\)\)], "Input",
  CellLabel->"In[226]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 5.12828e-017 1.16608 [
[.09072 .22988 -17.7473 -9 ]
[.09072 .22988 .25272 0 ]
[.21906 .17566 -5.65366 -9 ]
[.21906 .17566 .34634 0 ]
[.3545 .11847 -16.1747 -9 ]
[.3545 .11847 1.82534 0 ]
[.49765 .05807 -5.12945 -9 ]
[.49765 .05807 .87055 0 ]
[.64919 -0.00583 -14.602 -9 ]
[.64919 -0.00583 3.39797 0 ]
[.00955 .82643 -3.46362 0 ]
[.00955 .82643 2.53638 9 ]
[.1357 .91488 -3.34141 0 ]
[.1357 .91488 2.65859 9 ]
[.2472 .99305 -3.23852 0 ]
[.2472 .99305 2.76148 9 ]
[.34647 1.06263 -3.15071 0 ]
[.34647 1.06263 2.84929 9 ]
[.07325 .26228 -6 -2.6177 ]
[.07325 .26228 0 6.3823 ]
[.04822 .41894 -6 -2.75702 ]
[.04822 .41894 0 6.24298 ]
[.0202 .59437 -6 -2.91482 ]
[.0202 .59437 0 6.08518 ]
[-0.01139 .79218 -6 -3.09501 ]
[-0.01139 .79218 0 5.90499 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0.5)] .09072 .22988 .97192 1 Mshowa
.22871 .18658 m
.23354 .19204 L
s
[(1)] .21906 .17566 .88455 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(1.5)] .3545 .11847 .79718 1 Mshowa
.50609 .06995 m
.51031 .07589 L
s
[(2)] .49765 .05807 .70982 1 Mshowa
.65689 .00654 m
.66074 .01273 L
s
[(2.5)] .64919 -0.00583 .62245 1 Mshowa
.125 Mabswid
.12591 .22981 m
.12892 .23297 L
s
.1512 .21917 m
.15419 .22236 L
s
.17676 .20842 m
.17972 .21164 L
s
.2026 .19756 m
.20553 .20081 L
s
.25511 .17548 m
.25797 .17879 L
s
.28179 .16426 m
.28462 .1676 L
s
.30875 .15292 m
.31155 .15628 L
s
.33602 .14146 m
.33878 .14485 L
s
.39145 .11815 m
.39414 .1216 L
s
.41963 .1063 m
.42229 .10978 L
s
.44813 .09432 m
.45074 .09783 L
s
.47695 .0822 m
.47952 .08574 L
s
.53556 .05756 m
.53805 .06115 L
s
.56537 .04502 m
.56782 .04865 L
s
.59553 .03235 m
.59793 .036 L
s
.62603 .01952 m
.62839 .0232 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.13735 .90039 m
.13817 .89315 L
s
[(1)] .1357 .91488 .1138 -1 Mshowa
.24836 .97852 m
.24893 .97125 L
s
[(2)] .2472 .99305 .07951 -1 Mshowa
.3472 1.04807 m
.34757 1.0408 L
s
[(3)] .34647 1.06263 .05024 -1 Mshowa
.125 Mabswid
.03819 .83061 m
.03882 .82629 L
s
.06393 .84873 m
.06453 .8444 L
s
.08902 .86639 m
.08958 .86205 L
s
.11348 .8836 m
.11401 .87926 L
s
.16063 .91678 m
.16109 .91243 L
s
.18335 .93277 m
.18378 .92842 L
s
.20553 .94838 m
.20594 .94403 L
s
.2272 .96362 m
.22757 .95927 L
s
.26903 .99307 m
.26935 .9887 L
s
.28924 1.00729 m
.28953 1.00292 L
s
.30899 1.02119 m
.30926 1.01682 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.36568 1.06108 m
.36588 1.05671 L
s
.38377 1.07381 m
.38394 1.06944 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.0867 .25665 m
.09342 .25384 L
s
[(0)] .07325 .26228 1 -0.41829 Mshowa
.06181 .41367 m
.06861 .41104 L
s
[(2)] .04822 .41894 1 -0.38733 Mshowa
.03395 .58953 m
.04082 .58711 L
s
[(4)] .0202 .59437 1 -0.35226 Mshowa
.00252 .78784 m
.00948 .78567 L
s
[(6)] -0.01139 .79218 1 -0.31222 Mshowa
.125 Mabswid
.08073 .29431 m
.08477 .29265 L
s
.0746 .333 m
.07865 .33137 L
s
.0683 .37277 m
.07236 .37117 L
s
.05515 .45574 m
.05924 .45419 L
s
.04829 .49904 m
.05239 .49752 L
s
.04122 .54362 m
.04533 .54213 L
s
.02645 .63684 m
.03058 .63543 L
s
.01872 .68562 m
.02287 .68424 L
s
.01075 .73593 m
.01491 .73458 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.672 .728 .891 r
.65504 .5055 m .42216 .58164 L .34338 .50111 L p F P
0 g
s
.573 .367 .563 r
.66477 .73412 m .65504 .5055 L .42216 .58164 L p F P
0 g
s
.573 .367 .563 r
.42216 .58164 m .41465 .80504 L .66477 .73412 L p F P
0 g
s
.938 .685 .528 r
.34338 .50111 m .42216 .58164 L .41465 .80504 L p F P
0 g
s
.672 .728 .891 r
.91022 .42206 m .65504 .5055 L .58428 .41724 L p F P
0 g
s
.573 .367 .563 r
.97657 .93008 m .91022 .42206 L .65504 .5055 L p F P
0 g
s
.573 .367 .563 r
.65504 .5055 m .6761 1.00015 L .97657 .93008 L p F P
0 g
s
.672 .728 .891 r
.34338 .50111 m .58428 .41724 L .65504 .5055 L p F P
0 g
s
.938 .685 .528 r
.41465 .80504 m .32951 .73002 L .34338 .50111 L p F P
0 g
s
.656 .751 .92 r
.66477 .73412 m .41465 .80504 L .32951 .73002 L p F P
0 g
s
.656 .751 .92 r
.32951 .73002 m .5889 .65133 L .66477 .73412 L p F P
0 g
s
.966 .687 .452 r
.58428 .41724 m .65504 .5055 L .6761 1.00015 L p F P
0 g
s
.966 .687 .452 r
.58428 .41724 m .65504 .5055 L .66477 .73412 L p F P
0 g
s
.558 .344 .546 r
.5889 .65133 m .58428 .41724 L .34338 .50111 L p F P
0 g
s
.558 .344 .546 r
.34338 .50111 m .32951 .73002 L .5889 .65133 L p F P
0 g
s
.672 .728 .891 r
.58428 .41724 m .34338 .50111 L .25661 .4124 L p F P
0 g
s
.558 .344 .546 r
.58728 .56926 m .58428 .41724 L .34338 .50111 L p F P
0 g
s
.558 .344 .546 r
.34338 .50111 m .33436 .64995 L .58728 .56926 L p F P
0 g
s
.938 .685 .528 r
.25661 .4124 m .34338 .50111 L .33436 .64995 L p F P
0 g
s
.672 .728 .891 r
.58428 .41724 m .84947 .32491 L .91022 .42206 L p F P
0 g
s
.973 .663 .31 r
.84947 .32491 m .91022 .42206 L .97657 .93008 L p F P
0 g
s
.558 .344 .546 r
.90883 .84708 m .84947 .32491 L .58428 .41724 L p F P
0 g
s
.966 .687 .452 r
.6761 1.00015 m .59432 .926 L .58428 .41724 L p F P
0 g
s
.966 .687 .452 r
.66477 .73412 m .5889 .65133 L .58428 .41724 L p F P
0 g
s
.558 .344 .546 r
.58428 .41724 m .59432 .926 L .90883 .84708 L p F P
0 g
s
.672 .728 .891 r
.84947 .32491 m .58428 .41724 L .50596 .31957 L p F P
0 g
s
.558 .344 .546 r
.89747 .74713 m .84947 .32491 L .58428 .41724 L p F P
0 g
s
.558 .344 .546 r
.58428 .41724 m .59241 .8293 L .89747 .74713 L p F P
0 g
s
.672 .728 .891 r
.25661 .4124 m .50596 .31957 L .58428 .41724 L p F P
0 g
s
.938 .685 .528 r
.33436 .64995 m .2426 .56459 L .25661 .4124 L p F P
0 g
s
.662 .743 .91 r
.58728 .56926 m .33436 .64995 L .2426 .56459 L p F P
0 g
s
.662 .743 .91 r
.2426 .56459 m .50485 .4748 L .58728 .56926 L p F P
0 g
s
.966 .687 .452 r
.50596 .31957 m .58428 .41724 L .59241 .8293 L p F P
0 g
s
.966 .687 .452 r
.50596 .31957 m .58428 .41724 L .58728 .56926 L p F P
0 g
s
.539 .317 .526 r
.50485 .4748 m .50596 .31957 L .25661 .4124 L p F P
0 g
s
.539 .317 .526 r
.25661 .4124 m .2426 .56459 L .50485 .4748 L p F P
0 g
s
.672 .728 .891 r
.50596 .31957 m .25661 .4124 L .16055 .31419 L p F P
0 g
s
.539 .317 .526 r
.50542 .39511 m .50596 .31957 L .25661 .4124 L p F P
0 g
s
.539 .317 .526 r
.25661 .4124 m .24978 .48657 L .50542 .39511 L p F P
0 g
s
.938 .685 .528 r
.16055 .31419 m .25661 .4124 L .24978 .48657 L p F P
0 g
s
.938 .685 .528 r
.24978 .48657 m .15078 .38981 L .16055 .31419 L p F P
0 g
s
.668 .735 .9 r
.50542 .39511 m .24978 .48657 L .15078 .38981 L p F P
0 g
s
.973 .663 .31 r
.97657 .93008 m .90883 .84708 L .84947 .32491 L p F P
0 g
s
.672 .728 .891 r
.50596 .31957 m .78189 .21685 L .84947 .32491 L p F P
0 g
s
.973 .663 .31 r
.78189 .21685 m .84947 .32491 L .89747 .74713 L p F P
0 g
s
.966 .687 .452 r
.58728 .56926 m .50485 .4748 L .50596 .31957 L p F P
0 g
s
.539 .317 .526 r
.82232 .64945 m .78189 .21685 L .50596 .31957 L p F P
0 g
s
.966 .687 .452 r
.59241 .8293 m .50293 .74234 L .50596 .31957 L p F P
0 g
s
.539 .317 .526 r
.50596 .31957 m .50293 .74234 L .82232 .64945 L p F P
0 g
s
.672 .728 .891 r
.78189 .21685 m .50596 .31957 L .41883 .21088 L p F P
0 g
s
.539 .317 .526 r
.81324 .55231 m .78189 .21685 L .50596 .31957 L p F P
0 g
s
.539 .317 .526 r
.50596 .31957 m .50361 .64799 L .81324 .55231 L p F P
0 g
s
.672 .728 .891 r
.16055 .31419 m .41883 .21088 L .50596 .31957 L p F P
0 g
s
.668 .735 .9 r
.15078 .38981 m .4158 .28775 L .50542 .39511 L p F P
0 g
s
.966 .687 .452 r
.41883 .21088 m .50596 .31957 L .50361 .64799 L p F P
0 g
s
.966 .687 .452 r
.41883 .21088 m .50596 .31957 L .50542 .39511 L p F P
0 g
s
.514 .282 .5 r
.4158 .28775 m .41883 .21088 L .16055 .31419 L p F P
0 g
s
.514 .282 .5 r
.16055 .31419 m .15078 .38981 L .4158 .28775 L p F P
0 g
s
.966 .687 .452 r
.50542 .39511 m .4158 .28775 L .41883 .21088 L p F P
0 g
s
.625 .78 .956 r
.97657 .93008 m .6761 1.00015 L .59432 .926 L p F P
0 g
s
.973 .663 .31 r
.89747 .74713 m .82232 .64945 L .78189 .21685 L p F P
0 g
s
.672 .728 .891 r
.41883 .21088 m .70626 .09591 L .78189 .21685 L p F P
0 g
s
.973 .663 .31 r
.70626 .09591 m .78189 .21685 L .81324 .55231 L p F P
0 g
s
.514 .282 .5 r
.72983 .43813 m .70626 .09591 L .41883 .21088 L p F P
0 g
s
.966 .687 .452 r
.50361 .64799 m .40559 .54672 L .41883 .21088 L p F P
0 g
s
.514 .282 .5 r
.41883 .21088 m .40559 .54672 L .72983 .43813 L p F P
0 g
s
.638 .77 .943 r
.89747 .74713 m .59241 .8293 L .50293 .74234 L p F P
0 g
s
.625 .78 .956 r
.59432 .926 m .90883 .84708 L .97657 .93008 L p F P
0 g
s
.648 .761 .931 r
.81324 .55231 m .50361 .64799 L .40559 .54672 L p F P
0 g
s
.973 .663 .31 r
.81324 .55231 m .72983 .43813 L .70626 .09591 L p F P
0 g
s
.638 .77 .943 r
.50293 .74234 m .82232 .64945 L .89747 .74713 L p F P
0 g
s
.648 .761 .931 r
.40559 .54672 m .72983 .43813 L .81324 .55231 L p F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0.5)] .09072 .22988 .97192 1 Mshowa
.22871 .18658 m
.23354 .19204 L
s
[(1)] .21906 .17566 .88455 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(1.5)] .3545 .11847 .79718 1 Mshowa
.50609 .06995 m
.51031 .07589 L
s
[(2)] .49765 .05807 .70982 1 Mshowa
.65689 .00654 m
.66074 .01273 L
s
[(2.5)] .64919 -0.00583 .62245 1 Mshowa
.125 Mabswid
.12591 .22981 m
.12892 .23297 L
s
.1512 .21917 m
.15419 .22236 L
s
.17676 .20842 m
.17972 .21164 L
s
.2026 .19756 m
.20553 .20081 L
s
.25511 .17548 m
.25797 .17879 L
s
.28179 .16426 m
.28462 .1676 L
s
.30875 .15292 m
.31155 .15628 L
s
.33602 .14146 m
.33878 .14485 L
s
.39145 .11815 m
.39414 .1216 L
s
.41963 .1063 m
.42229 .10978 L
s
.44813 .09432 m
.45074 .09783 L
s
.47695 .0822 m
.47952 .08574 L
s
.53556 .05756 m
.53805 .06115 L
s
.56537 .04502 m
.56782 .04865 L
s
.59553 .03235 m
.59793 .036 L
s
.62603 .01952 m
.62839 .0232 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.13735 .90039 m
.13817 .89315 L
s
[(1)] .1357 .91488 .1138 -1 Mshowa
.24836 .97852 m
.24893 .97125 L
s
[(2)] .2472 .99305 .07951 -1 Mshowa
.3472 1.04807 m
.34757 1.0408 L
s
[(3)] .34647 1.06263 .05024 -1 Mshowa
.125 Mabswid
.03819 .83061 m
.03882 .82629 L
s
.06393 .84873 m
.06453 .8444 L
s
.08902 .86639 m
.08958 .86205 L
s
.11348 .8836 m
.11401 .87926 L
s
.16063 .91678 m
.16109 .91243 L
s
.18335 .93277 m
.18378 .92842 L
s
.20553 .94838 m
.20594 .94403 L
s
.2272 .96362 m
.22757 .95927 L
s
.26903 .99307 m
.26935 .9887 L
s
.28924 1.00729 m
.28953 1.00292 L
s
.30899 1.02119 m
.30926 1.01682 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.36568 1.06108 m
.36588 1.05671 L
s
.38377 1.07381 m
.38394 1.06944 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[226]:=",
  ImageSize->{265.313, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004900017b000`400?l00000o`00003oo`3oool:
0?ooo`00X03oool4000000<0oooo0P0000040?ooo`800000FP3oool00:00oooo00<000000?ooo`3o
ool02@3oool010000000oooo0?ooo`00001I0?ooo`00X@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo05L0oooo002R0?ooo`030000003oool0oooo00P0oooo0P00001J0?ooo`00X03o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo05T0oooo002Q0?ooo`8000002P3o
ool3000005T0oooo003o0?ooo`X0oooo003o0?ooo`X0oooo003o0?ooo`X0oooo002b0?ooo`800000
E@3oool00;00oooo0P0000000`3oool000000000001D0?ooo`00[P3oool300000080oooo0P00001D
0?ooo`00Z`3oool3000000<0oooo00D000000?ooo`000000oooo0000001C0?ooo`00Z@3oool20000
00P0oooo00<000000?ooo`000000D`3oool00:L0oooo0P00000:0?ooo`040000003oool0oooo0000
0580oooo002T0?ooo`<0000000<0oooo0000003oool02@3oool01@000000oooo0?ooo`3oool00000
0540oooo00230?ooo`@000006`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000001A0?oo
o`00P`3oool00`000000oooo0?ooo`0I0?ooo`<000004@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo04h0oooo00240?ooo`030000003oool0oooo01H0oooo0P0000020?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`00Q@3o
ool00`000000oooo0?ooo`0C0?ooo`8000005`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo04d0oooo00230?ooo`040000003oool0oooo00000140oooo0`00000I0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0C03oool008@0oooo0P00000@0?ooo`80000000<0oooo
0000003oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04`0oooo002D0?oo
o`8000007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04/0oooo002A0?ooo`<0
0000803oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04X0oooo002?0?ooo`@00000
8@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04X0oooo002=0?ooo`8000009@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04T0oooo002:0?ooo`<000009`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo04P0oooo00280?ooo`<00000:@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo04P0oooo00260?ooo`8000000`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A`3oool008<0oooo
0`00000^0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A`3oool00840oooo0P00
000a0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0AP3oool005@0oooo1@000002
0?ooo`800000103oool2000001`0oooo0P0000020?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`150?ooo`00EP3oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000001P0oooo0`00000e0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0A@3oool005H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?oo
o`800000>03oool00`000000oooo0?ooo`040?ooo`8000001@3oool00`000000oooo0?ooo`140?oo
o`00EP3oool00`000000oooo0?ooo`080?ooo`800000503oool300000080oooo00<000000?ooo`3o
ool0=P3oool010000000oooo0?ooo`3oool20000000308=8O`000000000000D0oooo00<000000?oo
o`3oool0@`3oool005H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`80
0000?P3oool4000000<0PdQo0P0000050?ooo`030000003oool0oooo04<0oooo001E0?ooo`800000
2P3oool3000000l0oooo0P00000o0?ooo`8000001P23B7l00`000000nJU?000000050?ooo`030000
003oool0oooo0480oooo001`0?ooo`<000000P3oool00`000000oooo0?ooo`0i0?ooo`<0000000<0
PdQo00000023B7l01@23B7l00`000000nJU?000000050?ooo`030000003oool0oooo0480oooo001^
0?ooo`800000?`3oool2000000@0PdQo00<0000008=8O`23B7l01023B7l010000000nJU?0?VYC`00
00050?ooo`030000003oool0oooo0440oooo001/0?ooo`800000?P3oool3000000H0PdQo00<00000
08=8O`23B7l01023B7l01@000000nJU?0?VYC`3iZDl0000000D0oooo00<000000?ooo`3oool0@03o
ool006T0oooo0`0000000`3oool000000?ooo`0k0?ooo`8000002@23B7l00`000000PdQo08=8O`04
08=8O`050000003iZDl0nJU?0?VYC`0000001@3oool00`000000oooo0?ooo`100?ooo`00I`3oool2
000003h0oooo0`00000;08=8O`0300000023B7l0PdQo00D0PdQo00D000000?VYC`3iZDl0nJU?0000
00050?ooo`030000003oool0oooo03l0oooo001U0?ooo`800000?P3oool2000000h0PdQo00<00000
08=8O`23B7l01@23B7l00`000000nJU?0?VYC`020?VYC`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0?P3oool00680oooo0`0000020?ooo`030000003oool0oooo03P0oooo0`00000@08=8
O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl00P3iZDl00`000000oooo0?ooo`030?oo
o`030000003oool0oooo03h0oooo001P0?ooo`800000?P3oool2000001<0PdQo00<0000008=8O`23
B7l01@23B7l00`000000nJU?0?VYC`030?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0?@3oool003d0oooo1@00000L0?ooo`<00000?03oool3000001D0PdQo00<0000008=8O`23B7l0
1@23B7l00`000000nJU?0?VYC`030?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
?@3oool003l0oooo00<000000?ooo`3oool06@3oool3000003d0oooo0P00000H08=8O`0300000023
B7l0PdQo00D0PdQo00<000000?VYC`3iZDl0103iZDl00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03`0oooo000o0?ooo`030000003oool0oooo01L0oooo0P00000n0?ooo`8000006P23B7l0
0`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00D0nJU?00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0k0?ooo`00?`3oool00`000000oooo0?ooo`0D0?ooo`@00000?03oool30000
01`0PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`050?VYC`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0>`3oool003l0oooo00<000000?ooo`3oool04P3oool2000003h0
oooo0P00000O08=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl01P3iZDl00`000000
oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo000n0?ooo`8000004@3oool3000003d0oooo
0`00000R08=8O`0300000023B7l0PdQo00@0PdQo00<000000?VYC`3iZDl01P3iZDl00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03T0oooo001?0?ooo`@00000?03oool2000002D0PdQo00<0
000008=8O`23B7l01023B7l00`000000nJU?0?VYC`070?VYC`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0>@3oool004d0oooo0P00000m0?ooo`<000009`23B7l00`000000PdQo08=8O`04
08=8O`030000003iZDl0nJU?00P0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0h
0?ooo`00BP3oool3000003d0oooo0P00000Z08=8O`0300000023B7l0PdQo00@0PdQo00<000000?VY
C`3iZDl0203iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo03P0oooo00180?ooo`@0
0000>`3oool3000002`0PdQo00<0000008=8O`23B7l01023B7l00`000000nJU?0?VYC`090?VYC`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0=`3oool004H0oooo0P00000m0?ooo`800000
;`23B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00P0nJU?00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0f0?ooo`00A03oool2000003`0oooo0`00000a08=8O`0300000023
B7l0PdQo00D0PdQo00<000000?VYC`3iZDl02@3iZDl00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03H0oooo00110?ooo`<0000000<0oooo0000003oool0>@3oool2000003@0PdQo00<00000
08=8O`23B7l01@23B7l00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0=@3oool003l0oooo0P00000l0?ooo`<00000=P23B7l00`000000PdQo08=8O`0508=8
O`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0d0?oo
o`004@3oool2000000@0oooo0P0000040?ooo`8000007P3oool2000003`0oooo0P00000i08=8O`03
00000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl02`3iZDl00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo03@0oooo000@0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000006P3oool3000000030?ooo`000000oooo03P0oooo0`00000k08=8O`0300000023B7l0PdQo
00D0PdQo00<000000?VYC`3iZDl0303iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo
03<0oooo000@0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool05@3oool30000
03`0oooo0P00000n08=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl0303iZDl00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo000@0?ooo`040000003oool0oooo0000
00T0oooo0P00000G0?ooo`800000>`3oool300000400PdQo00<0000008=8O`23B7l01@23B7l00`00
0000nJU?0?VYC`0=0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<P3oool00100
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0C0?ooo`<00000>`3oool20000
000308=8O`000000PdQo0400PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0=0?VY
C`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<@3oool00140oooo0P00000:0?ooo`<0
0000403oool3000003/0oooo0`00000308=8O`0300000023B7l0PdQo03l0PdQo00<0000008=8O`23
B7l01@23B7l00`000000nJU?0?VYC`0>0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0<@3oool002h0oooo1000000j0?ooo`8000001P23B7l00`000000PdQo08=8O`0o08=8O`030000
0023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl2000000D0oooo00<000000?ooo`3oool0
<03oool002`0oooo0P00000k0?ooo`<000002023B7l00`000000PdQo08=8O`0o08=8O`0300000023
B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl2000000H0oooo00<000000?ooo`3oool0;`3o
ool002X0oooo0P00000k0?ooo`8000002`23B7l00`000000PdQo08=8O`1008=8O`0300000023B7l0
PdQo00@0PdQo00<000000?VYC`3iZDl03P3iZDl00`000000nJU?000000050?ooo`030000003oool0
oooo02l0oooo000W0?ooo`<0000000<0oooo0000003oool0=`3oool3000000d0PdQo00<0000008=8
O`23B7l0@023B7l00`000000PdQo08=8O`0408=8O`030000003iZDl0nJU?00h0nJU?00@000000?VY
C`3iZDl000001@3oool00`000000oooo0?ooo`0^0?ooo`009@3oool2000003/0oooo0P00000@08=8
O`0300000023B7l0PdQo0400PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0=0?VY
C`040000003iZDl0nJU?000000D0oooo00<000000?ooo`3oool0;P3oool002<0oooo0P00000j0?oo
o`<000004P23B7l00`000000PdQo08=8O`1008=8O`0300000023B7l0PdQo00D0PdQo00<000000?VY
C`3iZDl03P3iZDl010000000nJU?0?VYC`0000050?ooo`030000003oool0oooo02d0oooo000Q0?oo
o`8000000P3oool00`000000oooo0?ooo`0e0?ooo`8000005@23B7l00`000000PdQo08=8O`1008=8
O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl010000000nJU?0?VYC`000006
0?ooo`030000003oool0oooo02`0oooo000Q0?ooo`800000=`3oool3000001H0PdQo0P00001208=8
O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl01@000000nJU?0?VYC`3iZDl0
000000D0oooo00<000000?ooo`3oool0;03oool00240oooo0`00000d0?ooo`8000006@23B7l00`00
0000PdQo08=8O`1108=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl00`00
0000nJU?0?VYC`020?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:`3oool00200
oooo0P0000020?ooo`030000003oool0oooo02h0oooo0`00000K08=8O`0300000023B7l0PdQo0440
PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0>0?VYC`030000003iZDl0nJU?0080
nJU?00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Z0?ooo`00803oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02/0oooo0P00000N08=8O`0300000023B7l0PdQo0440PdQo
00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0>0?VYC`030000003iZDl0nJU?00<0nJU?
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?ooo`006@3oool2000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`<000008023B7l00`000000PdQo08=8
O`1108=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl00`000000nJU?0?VY
C`040?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:@3oool001P0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0oooo0P00
000S08=8O`0300000023B7l0PdQo0440PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VY
C`0>0?VYC`030000003iZDl0nJU?00@0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0Y0?ooo`00603oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0803oool3000002D0PdQo00<0000008=8O`23B7l0@@23B7l00`000000PdQo08=8
O`0508=8O`030000003iZDl0nJU?00h0nJU?00<000000?VYC`3iZDl01@3iZDl00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02P0oooo000H0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0M0?ooo`800000:023B7l00`000000PdQo08=8
O`1108=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl00`000000nJU?0?VY
C`050?VYC`030000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool001P0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo0`00
000Z08=8O`0300000023B7l0PdQo0440PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VY
C`0?0?VYC`030000003iZDl0nJU?00D0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0W0?ooo`006@3oool2000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F
0?ooo`800000;023B7l2000004<0PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0?
0?VYC`030000003iZDl0nJU?00H0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0V
0?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0180oooo0`00000/08=8
O`80000000<0ZkcV00000023B7l0@P23B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?
00l0nJU?00<000000?VYC`3iZDl01P3iZDl00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02D0oooo000O0?ooo`800000303oool00`000000oooo0?ooo`0?0?ooo`800000;023B7l3000000<0
ZkcV00<0000008=8O`23B7l0@P23B7l00`000000PdQo08=8O`0408=8O`030000003iZDl0nJU?00l0
nJU?00<000000?VYC`3iZDl01`3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo02D0
oooo000O0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool3000002/0PdQo
0`0000060:^liP0300000023B7l0PdQo0480PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?
0?VYC`0>0?VYC`030000003iZDl0nJU?00P0nJU?00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0T0?ooo`007`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo0P00
000/08=8O`8000002@2[_>H00`000000PdQo08=8O`1208=8O`0300000023B7l0PdQo00D0PdQo00<0
00000?VYC`3iZDl03P3iZDl00`000000nJU?0?VYC`080?VYC`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0903oool001l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`<00000:`23B7l3000000/0ZkcV00<0000008=8O`23B7l0@P23B7l00`000000PdQo08=8O`05
08=8O`030000003iZDl0nJU?00h0nJU?00<000000?VYC`3iZDl02@3iZDl00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02<0oooo000N0?ooo`030000003oool0oooo0100oooo00@000000?oo
o`3oool0oooo0P00000/08=8O`8000003P2[_>H00`000000PdQo08=8O`1208=8O`0300000023B7l0
PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl00`000000nJU?0?VYC`090?VYC`030000003oool0
oooo00@0oooo00<000000?ooo`3oool08P3oool001h0oooo00<000000?ooo`3oool04@3oool20000
02`0PdQo0`00000@0:^liP0300000023B7l0PdQo0480PdQo00<0000008=8O`23B7l01@23B7l00`00
0000nJU?0?VYC`0>0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0R0?ooo`007P3oool00`000000oooo0?ooo`0B0?ooo`0300000023B7l0PdQo02P0
PdQo0P00000C0:^liP0300000023B7l0PdQo0480PdQo00<0000008=8O`23B7l01@23B7l00`000000
nJU?0?VYC`0>0?VYC`030000003iZDl0nJU?00/0nJU?00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0Q0?ooo`007P3oool00`000000oooo0?ooo`0B0?ooo`0300000023B7l0PdQo02D0PdQo
0`00000E0:^liP0300000023B7l0PdQo0480PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?
0?VYC`0>0?VYC`030000003iZDl0nJU?00/0nJU?00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0P0?ooo`007P3oool00`000000oooo0?ooo`0B0?ooo`0300000023B7l0PdQo0280PdQo0`00
000H0:^liP0300000023B7l0PdQo0480PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VY
C`0?0?VYC`030000003iZDl0nJU?00/0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0P0?ooo`007P3oool00`000000oooo0?ooo`0A0?ooo`0300000023B7l0PdQo0240PdQo0P00000K
0:^liP0300000023B7l0PdQo0480PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0?
0?VYC`030000003iZDl0nJU?00/0nJU?0P0000050?ooo`030000003oool0oooo01l0oooo000M0?oo
o`030000003oool0oooo0180oooo00<0000008=8O`23B7l07P23B7l3000001d0ZkcV00<0000008=8
O`23B7l0@P23B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00l0nJU?00<000000?VY
C`3iZDl02`3iZDl2000000D0oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3o
ool04P3oool00`000000PdQo08=8O`0L08=8O`8000007`2[_>H00`000000PdQo08=8O`1308=8O`03
00000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0;0?VYC`03
0000003iZDl0000000D0oooo00<000000?ooo`3oool07P3oool001d0oooo00<000000?ooo`3oool0
4P3oool00`000000PdQo08=8O`0I08=8O`<000008@2[_>H00`000000PdQo08=8O`1308=8O`030000
0023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0;0?VYC`030000
003iZDl0000000H0oooo00<000000?ooo`3oool07@3oool001d0oooo00<000000?ooo`3oool04P3o
ool00`000000PdQo08=8O`0G08=8O`800000902[_>H00`000000PdQo08=8O`1308=8O`0300000023
B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003i
ZDl0000000D0oooo00<000000?ooo`3oool07@3oool001d0oooo00<000000?ooo`3oool04P3oool0
0`000000PdQo08=8O`0D08=8O`<000009P2[_>H00`000000PdQo08=8O`1308=8O`0300000023B7l0
PdQo00D0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0<0?VYC`040000003iZDl0
nJU?000000D0oooo00<000000?ooo`3oool0703oool001d0oooo00<000000?ooo`3oool04@3oool0
0`000000PdQo08=8O`0B08=8O`<00000:@2[_>H00`000000PdQo08=8O`1308=8O`0300000023B7l0
PdQo00H0PdQo00<000000?VYC`3iZDl03P3iZDl00`000000nJU?0?VYC`0<0?VYC`040000003iZDl0
nJU?000000H0oooo00<000000?ooo`3oool06`3oool001`0oooo00<000000?ooo`3oool04P3oool0
0`000000PdQo08=8O`0@08=8O`800000;02[_>H00`000000PdQo08=8O`1408=8O`0300000023B7l0
PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl00`000000nJU?0?VYC`0<0?VYC`050000003iZDl0
nJU?0?VYC`0000001@3oool00`000000oooo0?ooo`0K0?ooo`00703oool00`000000oooo0?ooo`0B
0?ooo`0300000023B7l0PdQo00d0PdQo0`00000^0:^liP0300000023B7l0PdQo04@0PdQo00<00000
08=8O`23B7l01@23B7l00`000000nJU?0?VYC`0>0?VYC`030000003iZDl0nJU?00`0nJU?00<00000
0?VYC`3iZDl00P3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo000L0?oo
o`030000003oool0oooo0180oooo00<0000008=8O`23B7l02`23B7l200000340ZkcV00<0000008=8
O`23B7l0A023B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00l0nJU?00<000000?VY
C`3iZDl02`3iZDl00`000000nJU?0?VYC`020?VYC`030000003oool0oooo00<0oooo00<000000?oo
o`3oool06P3oool001`0oooo00<000000?ooo`3oool04P3oool00`000000PdQo08=8O`0808=8O`<0
0000<`2[_>H00`000000PdQo08=8O`1408=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3i
ZDl03`3iZDl00`000000nJU?0?VYC`0;0?VYC`030000003iZDl0nJU?00<0nJU?00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0I0?ooo`006`3oool2000001@0oooo00<0000008=8O`23B7l0
1P23B7l2000003H0ZkcV00<0000008=8O`23B7l0A023B7l00`000000PdQo08=8O`0508=8O`030000
003iZDl0nJU?00l0nJU?00<000000?VYC`3iZDl02`3iZDl00`000000nJU?0?VYC`030?VYC`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0603oool001`0oooo00<000000?ooo`3oool04@3o
ool00`000000PdQo08=8O`0408=8O`<00000>02[_>H00`000000PdQo08=8O`1408=8O`0300000023
B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0;0?VYC`030000003i
ZDl0nJU?00@0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`006`3oool0
0`000000oooo0?ooo`0B0?ooo`0400000023B7l0PdQo08=8O`<00000>`2[_>H00`000000PdQo08=8
O`1408=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VY
C`0<0?VYC`030000003iZDl0nJU?00@0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0G0?ooo`006`3oool00`000000oooo0?ooo`0B0?ooo`0400000023B7l00000000003h0ZkcV00<0
000008=8O`23B7l0A023B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00l0nJU?00<0
00000?VYC`3iZDl0303iZDl00`000000nJU?0?VYC`040?VYC`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool04P3oool200000400ZkcV00<00000
08=8O`23B7l0A023B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00l0nJU?00<00000
0?VYC`3iZDl0303iZDl00`000000nJU?0?VYC`050?VYC`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool04`3oool00`000000ZkcV0:^liP0n0:^l
iP0300000023B7l0PdQo04@0PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0?0?VY
C`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl01P3iZDl00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01D0oooo000K0?ooo`030000003oool0oooo01@0oooo00<000000:^liP2[
_>H0?@2[_>H00`000000PdQo08=8O`1408=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3i
ZDl03`3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00H0nJU?00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0E0?ooo`006`3oool00`000000oooo0?ooo`0E0?ooo`030000
002[_>H0ZkcV03`0ZkcV00<0000008=8O`23B7l0A023B7l00`000000PdQo08=8O`0508=8O`030000
003iZDl0nJU?00l0nJU?00<000000?VYC`3iZDl0303iZDl00`000000nJU?0?VYC`070?VYC`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001X0oooo00<000000?ooo`3oool05`3o
ool00`000000ZkcV0:^liP0k0:^liP0300000023B7l0PdQo04@0PdQo00<0000008=8O`23B7l01@23
B7l00`000000nJU?0?VYC`0?0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl01`3i
ZDl00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo000J0?ooo`030000003oool0
000001P0oooo00<000000:^liP2[_>H0>P2[_>H00`000000PdQo08=8O`1408=8O`0300000023B7l0
PdQo00H0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0;0?VYC`030000003iZDl0
nJU?00P0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`006P3oool20000
01X0oooo00<000000:^liP2[_>H0>@2[_>H00`000000PdQo08=8O`1408=8O`0300000023B7l0PdQo
00H0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0;0?VYC`8000002P3iZDl00`00
0000oooo0?ooo`020?ooo`800000503oool001X0oooo00<000000?ooo`3oool06P3oool00`000000
ZkcV0:^liP0h0:^liP0300000023B7l0PdQo04@0PdQo00<0000008=8O`23B7l01P23B7l00`000000
nJU?0?VYC`0?0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl0203iZDl00`000000
oooo00000002000000030?ooo`000000oooo01<0oooo000A0?ooo`@000001@3oool00`000000oooo
0?ooo`0K0?ooo`030000002[_>H0ZkcV03L0ZkcV00<0000008=8O`23B7l0A023B7l00`000000PdQo
08=8O`0608=8O`030000003iZDl0nJU?00l0nJU?00<000000?VYC`3iZDl0303iZDl00`000000nJU?
0?VYC`090?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00140oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`030000002[_>H0ZkcV03D0ZkcV00<0
000008=8O`23B7l0AP23B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00l0nJU?00<0
00000?VYC`3iZDl0303iZDl00`000000nJU?0?VYC`090?VYC`030000003oool0oooo0080oooo00<0
00000?ooo`3oool04P3oool00180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N
0?ooo`030000002[_>H0ZkcV03<0ZkcV0P00001808=8O`0300000023B7l0PdQo00D0PdQo00<00000
0?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00T0nJU?00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01l0oooo00<000000:^liP2[_>H0<02[_>H20000000308UAQP000000PdQo
04L0PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0?0?VYC`030000003iZDl0nJU?
00`0nJU?00<000000?VYC`3iZDl02@3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0140oooo000A0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0803oool00`00
0000ZkcV0:^liP0/0:^liP<000000`29DHH00`000000PdQo08=8O`1608=8O`0300000023B7l0PdQo
00@0PdQo0P00000A0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl02P3iZDl00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo000B0?ooo`8000001@3oool00`000000
oooo0?ooo`0Q0?ooo`030000002[_>H0ZkcV02P0ZkcV0`00000608UAQP0300000023B7l0PdQo04H0
PdQo00@0000008=8O`23B7l0PdQo0`0000020:G2kP030000003iZDl0nJU?00h0nJU?00<000000?VY
C`3iZDl0303iZDl00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo0080oooo00<000000?oo
o`3oool04@3oool001T0oooo00<000000?ooo`3oool08P3oool00`000000ZkcV0:^liP0U0:^liP80
00002@29DHH00`000000PdQo08=8O`1608=8O`@000001@2U`^h00`000000nJU?0?VYC`0>0?VYC`03
0000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0140oooo000I0?ooo`030000003oool0oooo02<0oooo00<000000:^liP2[_>H0
8@2[_>H3000000/0RE6600<0000008=8O`23B7l0A023B7l3000000T0YL;^00<000000?VYC`3iZDl0
3P3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00T0nJU?00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0A0?ooo`00603oool2000002H0oooo00<000000:^liP2[_>H07@2[
_>H3000000h0RE6600<0000008=8O`23B7l0@@23B7l300000080YL;^00<000000:G2kP2U`^h0202U
`^h00`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl02@3i
ZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo000H0?ooo`030000003oool0
oooo02H0oooo00<000000:^liP2[_>H06P2[_>H200000140RE6600<0000008=8O`23B7l0?P23B7l3
000000D0YL;^00<000000:G2kP2U`^h02@2U`^h00`000000nJU?0?VYC`0<0?VYC`030000003iZDl0
nJU?00`0nJU?00<000000?VYC`3iZDl02@3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0140oooo000H0?ooo`030000003oool0oooo02L0oooo00<000000:^liP2[_>H05P2[_>H30000
01<0RE6600<0000008=8O`23B7l0>`23B7l3000000P0YL;^00<000000:G2kP2U`^h02@2U`^h00`00
0000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl02@3iZDl00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000H0?ooo`030000003oool0oooo02P0
oooo00<000000:^liP2[_>H04P2[_>H3000001H0RE6600<0000008=8O`23B7l0>@23B7l2000000/0
YL;^00<000000:G2kP2U`^h02P2U`^h00`000000nJU?0?VYC`0;0?VYC`030000003iZDl0nJU?00`0
nJU?00<000000?VYC`3iZDl02@3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100
oooo000H0?ooo`030000003oool0oooo02T0oooo00<000000:^liP2[_>H03`2[_>H2000001T0RE66
00<0000008=8O`23B7l0=P23B7l3000000d0YL;^00<000000:G2kP2U`^h02`2U`^h00`000000nJU?
0?VYC`0:0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo000H0?ooo`030000003oool0oooo02X0oooo00<0
00000:^liP2[_>H02`2[_>H3000001/0RE6600<0000008=8O`23B7l0<`23B7l300000100YL;^00<0
00000:G2kP2U`^h0302U`^h00`000000nJU?0?VYC`090?VYC`030000003iZDl0nJU?00`0nJU?00<0
00000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo000G
0?ooo`030000003oool0oooo02`0oooo00<000000:^liP2[_>H01`2[_>H3000001h0RE6600<00000
08=8O`23B7l0<023B7l3000001<0YL;^00<000000:G2kP2U`^h0302U`^h00`000000nJU?0?VYC`09
0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo000G0?ooo`030000003oool0oooo02d0oooo00<000000:^l
iP2[_>H0102[_>H200000240RE6600<0000008=8O`23B7l0;@23B7l3000001H0YL;^00<000000:G2
kP2U`^h03@2U`^h00`000000nJU?0?VYC`080?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VY
C`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo000G0?ooo`03
0000003oool0oooo02h0oooo00<000000:^liP2[_>H00`00000S08UAQP0300000023B7l0PdQo02X0
PdQo0`00000I0:G2kP030000002U`^h0YL;^00h0YL;^00<000000?VYC`3iZDl01`3iZDl00`000000
nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00T0nJU?00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`005`3oool00`000000oooo0?ooo`0_0?ooo`8000009P29DHH00`000000PdQo
08=8O`0W08=8O`<000007@2U`^h00`000000YL;^0:G2kP0=0:G2kP030000003iZDl0nJU?00L0nJU?
00<000000?VYC`3iZDl03@3iZDl00`000000nJU?0?VYC`090?VYC`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03`3oool001L0oooo00<000000?ooo`3oool0;`3oool00`000000RE6608UA
QP0U08UAQP0300000023B7l0PdQo02@0PdQo0`00000P0:G2kP030000002U`^h0YL;^00h0YL;^00<0
00000?VYC`3iZDl01`3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00T0nJU?00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`005`3oool00`000000oooo0?ooo`0_
0?ooo`0300000029DHH0RE6602D0RE6600<0000008=8O`23B7l08@23B7l3000002<0YL;^00<00000
0:G2kP2U`^h03`2U`^h00`000000nJU?0?VYC`060?VYC`030000003iZDl0nJU?00`0nJU?00<00000
0?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo000F0?oo
o`030000003oool0oooo0300oooo00<0000008UAQP29DHH09@29DHH00`000000PdQo08=8O`0N08=8
O`<000009P2U`^h00`000000YL;^0:G2kP0@0:G2kP030000003iZDl0nJU?00D0nJU?00<000000?VY
C`3iZDl0303iZDl00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo0080oooo00<000000?oo
o`3oool03`3oool001H0oooo00<000000?ooo`3oool0<03oool00`000000RE6608UAQP0U08UAQP03
00000023B7l0PdQo01/0PdQo0`00000Y0:G2kP030000002U`^h0YL;^0100YL;^00<000000?VYC`3i
ZDl01@3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`005P3oool00`000000oooo0?ooo`0_0?ooo`030000
0029DHH0RE6602D0RE6600<0000008=8O`23B7l06@23B7l3000002`0YL;^00<000000:G2kP2U`^h0
4@2U`^h00`000000nJU?0?VYC`040?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl0
2P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo000F0?ooo`030000003o
ool0oooo02l0oooo00<0000008UAQP29DHH08P29DHH4000001P0PdQo0`00000_0:G2kP030000002U
`^h0YL;^0180YL;^00<000000?VYC`3iZDl00`3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003i
ZDl0nJU?00X0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`005P3oool0
0`000000oooo0?ooo`0_0?ooo`0300000029DHH0RE6601l0RE660`0000030:Vnj00300000023B7l0
PdQo01<0PdQo0`00000b0:G2kP030000002U`^h0YL;^0180YL;^00<000000?VYC`3iZDl00`3iZDl0
0`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0?0?ooo`005P3oool00`000000oooo0?ooo`0_0?ooo`0300000029DHH0RE66
01`0RE660`0000060:Vnj00300000023B7l0PdQo0140PdQo0P00000e0:G2kP030000002U`^h0YL;^
01<0YL;^00<000000?VYC`3iZDl00P3iZDl00`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?
00T0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`005@3oool00`000000
oooo0?ooo`0`0?ooo`0300000029DHH0RE6601T0RE660`0000090:Vnj00300000023B7l0PdQo00h0
PdQo0`00000g0:G2kP030000002U`^h0YL;^01@0YL;^00D000000?VYC`3iZDl0nJU?0000000?0?VY
C`030000003iZDl0nJU?00T0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?oo
o`005@3oool00`000000oooo0?ooo`0`0?ooo`0300000029DHH0RE6601H0RE660`00000<0:Vnj003
00000023B7l0PdQo00/0PdQo0`00000j0:G2kP030000002U`^h0YL;^01D0YL;^00@000000?VYC`3i
ZDl000003`3iZDl00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo0080oooo00<000000?oo
o`3oool03P3oool001D0oooo00<000000?ooo`3oool0<03oool00`000000RE6608UAQP0C08UAQP<0
00003`2Y_^P00`000000PdQo08=8O`0808=8O`<00000?@2U`^h00`000000YL;^0:G2kP0E0:G2kP05
0000003iZDl0nJU?0?VYC`0000003P3iZDl00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo
0080oooo00<000000?ooo`3oool03P3oool001D0oooo00<000000?ooo`3oool0<03oool00`000000
RE6608UAQP0@08UAQP<000004P2Y_^P00`000000PdQo08=8O`0508=8O`<00000@02U`^h00`000000
YL;^0:G2kP0F0:G2kP040000003iZDl0nJU?000000h0nJU?00<000000?VYC`3iZDl02P3iZDl00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo000E0?ooo`800000<@3oool00`000000
RE6608UAQP0=08UAQP<000005@2Y_^P00`000000PdQo08=8O`0208=8O`<00000@`2U`^h00`000000
YL;^0:G2kP0G0:G2kP030000003iZDl0000000h0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo000E0?ooo`030000003oool0oooo0300oooo
00<0000008UAQP29DHH02P29DHH3000001P0ZKkX00<0000008=8O`0000000P0000160:G2kP030000
002U`^h0YL;^01P0YL;^0P00000>0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`005@3oool00`000000oooo0?ooo`0_0?ooo`0300000029
DHH0RE6600P0RE660`00000K0:Vnj0800000B@2U`^h00`000000YL;^0:G2kP0H0:G2kP8000003P3i
ZDl00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3o
ool001@0oooo00<000000?ooo`3oool0<03oool00`000000RE6608UAQP0508UAQP<000007`2Y_^P0
0`000000YL;^0:G2kP180:G2kP030000002U`^h0YL;^01L0YL;^0P00000>0?VYC`8000002`3iZDl0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo000D0?ooo`030000003oool0oooo
0300oooo00<0000008UAQP29DHH00P29DHH3000002<0ZKkX00<000000:G2kP2U`^h0A`2U`^h00`00
0000YL;^0:G2kP0D0:G2kP<0000000<0RE660000003iZDl03P3iZDl00`000000nJU?0?VYC`0:0?VY
C`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool001@0oooo00<000000?ooo`3o
ool0<03oool00`000000RE6600000002000002L0ZKkX00<000000:G2kP2U`^h0AP2U`^h00`000000
YL;^0:G2kP0@0:G2kP@000001029DHH00`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00X0
nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`00503oool00`000000oooo
0?ooo`0`0?ooo`800000:`2Y_^P00`000000YL;^0:G2kP150:G2kP030000002U`^h0YL;^00d0YL;^
0`00000808UAQP030000003iZDl0nJU?00d0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00d0oooo000D0?ooo`030000003oool0oooo0340oooo00<0
00000:Vnj02Y_^P0:P2Y_^P00`000000YL;^0:G2kP140:G2kP030000002U`^h0YL;^00X0YL;^0`00
000;08UAQP030000003iZDl0nJU?00d0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00d0oooo000D0?ooo`030000003oool0oooo0380oooo00<00000
0:Vnj02Y_^P0:P2Y_^P00`000000YL;^0:G2kP130:G2kP030000002U`^h0YL;^00L0YL;^0`00000>
08UAQP030000003iZDl0nJU?00d0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00d0oooo000C0?ooo`030000003oool0oooo03@0oooo00<000000:Vn
j02Y_^P0:P2Y_^P00`000000YL;^0:G2kP120:G2kP030000002U`^h0YL;^00<0YL;^1000000A08UA
QP030000003iZDl0nJU?00d0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo000C0?ooo`030000003oool0oooo03D0oooo00<000000:Vnj02Y
_^P0:P2Y_^P00`000000YL;^0:G2kP110:G2kP030000002U`^h0YL;^00<000005@29DHH00`000000
nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0<0?ooo`004`3oool00`000000oooo0?ooo`0f0?ooo`030000002Y_^P0ZKkX02X0ZKkX
00<000000:G2kP2U`^h0?`2U`^h4000001T0RE6600<000000?VYC`3iZDl0303iZDl00`000000nJU?
0?VYC`0:0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool001<0oooo0`00
000g0?ooo`030000002Y_^P0ZKkX02X0ZKkX00<000000:G2kP2U`^h0>`2U`^h40000000308UAQP00
0000RE6601T0RE6600<000000?VYC`3iZDl0303iZDl2000000`0nJU?00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0<0?ooo`004`3oool00`000000oooo0?ooo`0h0?ooo`030000002Y_^P0
ZKkX02X0ZKkX00<000000:G2kP2U`^h0=P2U`^h5000000D0RE6600<0000008UAQP29DHH05`29DHH0
0`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0<0?ooo`00303oool3000000@0oooo00<000000?ooo`3oool0>@3oool00`00
0000ZKkX0:Vnj00Z0:Vnj0030000002U`^h0YL;^0380YL;^1000000908UAQP0300000029DHH0RE66
01L0RE6600<000000?VYC`3iZDl03@3iZDl00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0k0?ooo`030000002Y_^P0ZKkX02X0ZKkX00<000000:G2kP2U`^h0;P2U`^h4000000d0
RE6600<0000008UAQP29DHH05P29DHH00`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00X0
nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`002P3oool5000000<0oooo
00<000000?ooo`3oool0?03oool00`000000ZKkX0:Vnj00Z0:Vnj0030000002U`^h0YL;^02X0YL;^
1000000A08UAQP0300000029DHH0RE6601D0RE6600<000000?VYC`3iZDl03@3iZDl00`000000nJU?
0?VYC`0:0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool000X0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0m0?ooo`800000:`2Y_^P00`000000YL;^
0:G2kP0U0:G2kPD000005@29DHH00`000000RE6608UAQP0D08UAQP030000003iZDl0nJU?00d0nJU?
00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo
000;0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0?`3oool00`000000ZKkX0:Vn
j00T0:Vnj0@0000000<0SUR;0000002U`^h08P2U`^h4000001X0RE6600<0000008UAQP29DHH04`29
DHH00`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0;0?ooo`00303oool2000000@0oooo00<000000?ooo`3oool0@03oool0
0`000000ZKkX0:Vnj00P0:Vnj0<000001P2>F8/00`000000YL;^0:G2kP0M0:G2kP@000007@29DHH0
0`000000RE6608UAQP0C08UAQP030000003iZDl0nJU?00d0nJU?00<000000?VYC`3iZDl02`3iZDl0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo000B0?ooo`030000003oool0oooo
0440oooo00<000000:Vnj02Y_^P0702Y_^P3000000X0SUR;00<000000:G2kP2U`^h06@2U`^h40000
0240RE6600<0000008UAQP29DHH04P29DHH00`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?
00/0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`004@3oool00`000000
oooo0?ooo`130?ooo`030000002Y_^P0ZKkX01P0ZKkX0`00000>08iHR`030000002U`^h0YL;^01D0
YL;^1000000U08UAQP0300000029DHH0RE660140RE6600<000000?VYC`3iZDl03@3iZDl2000000`0
nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`004@3oool00`000000oooo
0?ooo`140?ooo`030000002Y_^P0ZKkX01@0ZKkX0`00000B08iHR`030000002U`^h0YL;^0100YL;^
1000000Z08UAQP0300000029DHH0RE660140RE6600<000000?VYC`3iZDl03@3iZDl00`000000nJU?
0?VYC`0:0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00140oooo00<0
00000?ooo`3oool0A@3oool00`000000ZKkX0:Vnj00@0:Vnj0<000005P2>F8/00`000000YL;^0:G2
kP0<0:G2kP@00000;P29DHH00`000000RE6608UAQP0@08UAQP030000003iZDl0nJU?00d0nJU?00<0
00000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo000A
0?ooo`800000A`3oool00`000000ZKkX0:Vnj00<0:Vnj0<000006P2>F8/00`000000YL;^0:G2kP08
0:G2kP@00000<@29DHH00`000000RE6608UAQP0@08UAQP030000003iZDl0nJU?00d0nJU?00<00000
0?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo000A0?oo
o`030000003oool0oooo04L0oooo00<000000:Vnj02Y_^P0202Y_^P3000001h0SUR;00<000000:G2
kP2U`^h0102U`^h4000003D0RE6600<0000008UAQP29DHH03`29DHH00`000000nJU?0?VYC`0=0?VY
C`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?oo
o`004@3oool00`000000oooo0?ooo`180?ooo`030000002Y_^P0ZKkX00@0ZKkX0`00000R08iHR`03
0000002U`^h0000000<00000>P29DHH00`000000RE6608UAQP0>08UAQP030000003iZDl0nJU?00d0
nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0
oooo000@0?ooo`030000003oool0oooo04X0oooo00<000000:Vnj02Y_^P00`00000T08iHR`@00000
?P29DHH00`000000RE6608UAQP0<08UAQP8000003`3iZDl00`000000nJU?0?VYC`0;0?VYC`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00100oooo00<000000?ooo`3oool0B`3o
ool2000002@0SUR;0`00000208iHR`0300000029DHH0RE6603h0RE6600<0000008UAQP29DHH02029
DHH300000080XlGa00<000000?VYC`3iZDl0303iZDl00`000000nJU?0?VYC`0;0?VYC`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02P3oool00100oooo00<000000?ooo`3oool0B`3oool0
0`000000SUR;08iHR`0P08iHR`<000001@2>F8/00`000000RE6608UAQP0n08UAQP0300000029DHH0
RE6600@0RE66100000060:?5l@030000003iZDl0nJU?00/0nJU?0P00000<0?VYC`030000003oool0
oooo0080oooo00<000000?ooo`3oool02P3oool00100oooo00<000000?ooo`3oool0B`3oool00`00
0000SUR;08iHR`0L08iHR`@00000202>F8/00`000000RE6608UAQP0o08UAQP0300000029DHH0RE66
00<000002P2SaO400`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`00403oool00`000000oooo0?ooo`1;0?ooo`03
0000002>F8/0SUR;01T0SUR;0`00000<08iHR`0300000029DHH0RE6603l0RE660`00000>0:?5l@03
0000003iZDl0nJU?00/0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo000@0?ooo`030000003oool0oooo04/0oooo00<0000008iHR`2>F8/0
5P2>F8/3000000l0SUR;00<0000008UAQP29DHH0>`29DHH400000080XlGa00<000000:?5l@2SaO40
3@2SaO400`000000nJU?0?VYC`0:0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`090?ooo`003`3oool00`000000oooo0?ooo`1<0?ooo`030000002>
F8/0SUR;01<0SUR;0`00000B08iHR`0300000029DHH0RE6603P0RE660`0000070:?5l@030000002S
aO40XlGa00d0XlGa00<000000?VYC`3iZDl02@3iZDl00`000000nJU?0?VYC`0:0?VYC`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool000l0oooo00<000000?ooo`3oool0C03oool0
0`000000SUR;08iHR`0?08iHR`@000005@2>F8/00`000000RE6608UAQP0e08UAQP<000002P2SaO40
0`000000XlGa0:?5l@0=0:?5l@030000003iZDl0nJU?00T0nJU?00<000000?VYC`3iZDl02P3iZDl0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo000?0?ooo`030000003oool0oooo
04`0oooo00<0000008iHR`2>F8/0302>F8/3000001H0SUR;1000000c08UAQP@000003P2SaO400`00
0000XlGa0:?5l@0=0:?5l@030000003iZDl0nJU?00P0nJU?00<000000?VYC`3iZDl02`3iZDl00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo000?0?ooo`800000C@3oool00`000000
SUR;08iHR`0908iHR`<000005P2>F8/3000000<0Yl3[00<0000008UAQP29DHH0;P29DHH3000001<0
XlGa00<000000:?5l@2SaO403@2SaO400`000000nJU?0?VYC`070?VYC`030000003iZDl0nJU?00/0
nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`003`3oool00`000000oooo
0?ooo`1<0?ooo`030000002>F8/0SUR;00H0SUR;0`00000F08iHR`<000001P2W`>/00`000000RE66
08UAQP0[08UAQP<000005`2SaO400`000000XlGa0:?5l@0=0:?5l@030000003iZDl0nJU?00H0nJU?
00<000000?VYC`3iZDl02`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
000?0?ooo`030000003oool0oooo04`0oooo00<0000008iHR`2>F8/00`2>F8/3000001D0SUR;1000
00090:O0j`0300000029DHH0RE6602L0RE661000000K0:?5l@030000002SaO40XlGa00`0XlGa00<0
00000?VYC`3iZDl01P3iZDl2000000`0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`090?ooo`003P3oool00`000000oooo0?ooo`1=0?ooo`030000002>F8/0000000<000005@2>F8/3
000000d0Yl3[00<0000008UAQP29DHH09029DHH300000200XlGa00<000000:?5l@2SaO40302SaO40
0`000000nJU?0?VYC`060?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`003P3oool00`000000oooo0?ooo`1<0?ooo`<000005P2>F8/30000
0100Yl3[00<0000008UAQP29DHH08@29DHH3000002<0XlGa00<000000:?5l@2SaO403@2SaO400`00
0000nJU?0?VYC`050?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`080?ooo`003P3oool00`000000oooo0?ooo`190?ooo`@000005@2>F8/3000001<0
Yl3[00<0000008UAQP29DHH07@29DHH4000002L0XlGa00<000000:?5l@2SaO403@2SaO400`000000
nJU?0?VYC`040?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`003P3oool00`000000oooo0?ooo`160?ooo`<000000`3oool00`000000SUR;
08iHR`0?08iHR`@000005P2W`>/00`000000RE6608UAQP0J08UAQP<00000;02SaO400`000000XlGa
0:?5l@0<0:?5l@030000003iZDl0nJU?00@0nJU?00<000000?VYC`3iZDl02`3iZDl00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo000>0?ooo`030000003oool0oooo0480oooo1000
00060?ooo`030000002>F8/0SUR;00`0SUR;0`00000J0:O0j`0300000029DHH0RE6601L0RE660`00
000`0:?5l@030000002SaO40XlGa00`0XlGa00<000000?VYC`3iZDl00`3iZDl00`000000nJU?0?VY
C`0;0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool000h0oooo00<00000
0?ooo`3oool0?`3oool3000000X0oooo00<0000008iHR`2>F8/02@2>F8/3000001d0Yl3[00<00000
08UAQP29DHH04`29DHH4000003@0XlGa00<000000:?5l@2SaO40302SaO400`000000nJU?0?VYC`02
0?VYC`030000003iZDl0nJU?00/0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`003@3oool00`000000oooo0?ooo`0m0?ooo`<000003@3oool00`000000SUR;08iHR`0608iH
R`<00000802W`>/00`000000RE6608UAQP0@08UAQP<00000>02SaO400`000000XlGa0:?5l@0=0:?5
l@050000003iZDl0nJU?0?VYC`0000003@3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo000=0?ooo`030000003oool0oooo03X0oooo0`00000@0?ooo`030000002>F8/0SUR;
0080SUR;1000000S0:O0j`0300000029DHH0RE6600d0RE660`00000l0:?5l@030000002SaO40XlGa
00`0XlGa00D000000?VYC`3iZDl0nJU?0000000=0?VYC`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0203oool000d0oooo00<000000?ooo`3oool0=P3oool4000001<0oooo00<0000008iH
R`0000000P00000W0:O0j`0300000029DHH0RE6600T0RE66100000100:?5l@030000002SaO40XlGa
00`0XlGa00<000000?VYC`3iZDl00P00000<0?VYC`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool000d0oooo00<000000?ooo`3oool0<`3oool3000001L0oooo0P00000Z0:O0j`03
00000029DHH0RE6600H0RE660`0000150:?5l@030000002SaO40XlGa00`0XlGa00@000000?VYC`3i
ZDl00000303iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo000=0?ooo`80
0000<@3oool3000001/0oooo00<000000:O0j`2W`>/0:02W`>/00`000000RE6608UAQP0308UAQP<0
0000B@2SaO400`000000XlGa0:?5l@0<0:?5l@030000003iZDl0000000`0nJU?00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`003@3oool00`000000oooo0?ooo`0]0?ooo`<00000
7`3oool00`000000Yl3[0:O0j`0W0:O0j`0300000029DHH0000000<00000C02SaO400`000000XlGa
0:?5l@0<0:?5l@030000003iZDl0000000d0nJU?00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`00303oool00`000000oooo0?ooo`0Z0?ooo`@000008`3oool2000002L0Yl3[0P00
001A0:?5l@030000002SaO40XlGa00`0XlGa0P00000=0?VYC`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool09`3oool3000002T0oooo00<00000
0:O0j`2W`>/09@2W`>/00`000000XlGa0:?5l@1@0:?5l@030000002SaO40XlGa00/0XlGa0P00000=
0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool000`0oooo00<000000?oo
o`3oool0903oool3000002d0oooo00<000000:O0j`2W`>/09@2W`>/00`000000XlGa0:?5l@1@0:?5
l@030000002SaO40XlGa00H0XlGa100000000`2>F8/000000?VYC`0<0?VYC`030000003oool0oooo
0080oooo00<000000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool08@3oool300000340
oooo00<000000:O0j`2W`>/09@2W`>/00`000000XlGa0:?5l@1@0:?5l@040000002SaO40XlGa0:?5
l@@000001@2>F8/00`000000nJU?0?VYC`0;0?VYC`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool000`0oooo00<000000?ooo`3oool07@3oool4000003D0oooo00<000000:O0j`2W
`>/09@2W`>/00`000000XlGa0:?5l@1?0:?5l@@000002@2>F8/00`000000nJU?0?VYC`0;0?VYC`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool000`0oooo00<000000?ooo`3oool0
6P3oool3000003X0oooo00<000000:O0j`2W`>/09@2W`>/00`000000XlGa0:?5l@1;0:?5l@D00000
302>F8/00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool000/0oooo00<000000?ooo`3oool0603oool3000003h0oooo00<000000:O0j`2W`>/09@2W
`>/00`000000XlGa0:?5l@160:?5l@@000001@2>F8/00`000000SUR;08iHR`0908iHR`030000003i
ZDl0nJU?00/0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`002`3oool0
0`000000oooo0?ooo`0E0?ooo`<00000@P3oool2000002H0Yl3[00<000000:?5l@2SaO40@P2SaO43
000000X0SUR;00<0000008iHR`2>F8/0202>F8/00`000000nJU?0?VYC`0;0?VYC`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool000/0oooo00<000000?ooo`3oool04P3oool30000
04L0oooo00<000000:O0j`2W`>/08@2W`>/4000003l0XlGa1000000>08iHR`030000002>F8/0SUR;
00L0SUR;00<000000?VYC`3iZDl02`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo000;0?ooo`030000003oool0oooo00h0oooo1000001;0?ooo`030000002W`>/0Yl3[01`0
Yl3[100000040?ooo`030000002SaO40XlGa03P0XlGa1000000B08iHR`030000002>F8/0SUR;00L0
SUR;00<000000?VYC`3iZDl02`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo000;0?ooo`030000003oool0oooo00/0oooo0`00001@0?ooo`030000002W`>/0Yl3[01P0Yl3[
0`0000090?ooo`030000002SaO40XlGa03@0XlGa0`00000G08iHR`030000002>F8/0SUR;00H0SUR;
00<000000?VYC`3iZDl02`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
000;0?ooo`<00000203oool3000005@0oooo00<000000:O0j`2W`>/04`2W`>/4000000d0oooo00<0
00000:?5l@2SaO40;`2SaO44000001/0SUR;00<0000008iHR`2>F8/01@2>F8/00`000000nJU?0?VY
C`0;0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00080oooo0`000005
0?ooo`030000003oool0oooo00H0oooo0`00001H0?ooo`030000002W`>/0Yl3[00l0Yl3[0`00000B
0?ooo`030000002SaO40XlGa02X0XlGa1000000P08iHR`030000002>F8/0SUR;00@0SUR;00<00000
0?VYC`3iZDl02`3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool4000005`0oooo0P00000;
0:O0j`@000005P3oool00`000000XlGa0:?5l@0V0:?5l@<000009@2>F8/00`000000SUR;08iHR`04
08iHR`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0000000800000HP3oool0
0`000000Yl3[0:O0j`050:O0j`<000006`3oool00`000000XlGa0:?5l@0Q0:?5l@@00000:02>F8/0
0`000000SUR;08iHR`0408iHR`030000003iZDl0nJU?00/0nJU?00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`000P3oool3000000D0oooo0P00001U0?ooo`8000000P2W`>/40000
01l0oooo00<000000:?5l@2SaO40702SaO44000002d0SUR;00<0000008iHR`2>F8/00`2>F8/00`00
0000nJU?0?VYC`0;0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool000<0
oooo00<000000?ooo`3oool01@3oool3000006<0oooo00@000000?ooo`0000000000903oool00`00
0000XlGa0:?5l@0H0:?5l@<00000<P2>F8/00`000000SUR;08iHR`0208iHR`030000003iZDl0nJU?
00/0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`000`3oool3000000L0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0V0?ooo`030000002SaO40XlGa01<0
XlGa1000000f08iHR`050000002>F8/0SUR;08iHR`0000003@3iZDl00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo000>0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool09`3oool00`000000XlGa0:?5l@0>0:?5l@@00000>`2>F8/010000000SUR;08iHR`00000=0?VY
C`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool000l0oooo0P00001P0?ooo`03
0000003oool0oooo02P0oooo00<000000:?5l@2SaO402P2SaO43000003l0SUR;00@0000008iHR`2>
F8/000003@3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo000A0?ooo`03
0000003oool0oooo05d0oooo00<000000?ooo`3oool0:@3oool00`000000XlGa0:?5l@050:?5l@@0
0000@`2>F8/00`000000SUR;0000000=0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00180oooo0`00001L0?ooo`030000003oool0oooo02X0oooo00<000000:?5l@2SaO40
1000001808iHR`8000003P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
000D0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0:`3oool2000004d0SUR;0P00
000=0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool001D0oooo0P00001J
0?ooo`030000003oool0oooo02/0oooo00<0000008iHR`2>F8/0C@2>F8/00`000000nJU?0?VYC`0;
0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool001L0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0[0?ooo`030000002>F8/0SUR;04d0SUR;00<000000?VY
C`3iZDl02`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo000;0?ooo`80
00002`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo02`0oooo00<0000008iHR`2>
F8/0C02>F8/2000000`0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`00
2P3oool010000000oooo0?ooo`00000;0?ooo`800000EP3oool00`000000oooo0?ooo`0/0?ooo`03
0000002>F8/0SUR;04/0SUR;0P0000000`3iZDl000000?VYC`0:0?VYC`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool000X0oooo00@000000?ooo`3oool00000303oool2000005D0
oooo00<000000?ooo`3oool0;03oool00`000000SUR;08iHR`1708iHR`@000000P2Oao@00`000000
nJU?0000000:0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool000X0oooo
00@000000?ooo`3oool000003P3oool2000005<0oooo00<000000?ooo`3oool0;03oool00`000000
SUR;08iHR`1308iHR`@000001`2Oao@00`000000nJU?000000090?VYC`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool000X0oooo00@000000?ooo`3oool00000403oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo02`0oooo00<0000008iHR`2>F8/0?`2>F8/4000000/0
WlOd00<000000?VYC`0000002P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo000;0?ooo`8000004P3oool3000004l0oooo00<000000?ooo`3oool0;03oool00`000000SUR;
08iHR`0k08iHR`@00000402Oao@00`000000nJU?000000090?VYC`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0/0?ooo`030000002>F8/0SUR;03L0SUR;1000000E09o7m0030000003iZDl0000000P0nJU?00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo02`0oooo00<0000008iHR`2>F8/0<`2>F8/4000001X0WlOd00<00000
0?VYC`0000001`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo000S0?oo
o`800000C03oool00`000000oooo0?ooo`0/0?ooo`030000002>F8/0SUR;02l0SUR;1000000O09o7
m0030000003iZDl0000000H0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`009@3oool00`000000oooo000000190?ooo`030000003oool0oooo02`0oooo00<0000008iHR`2>
F8/0:`2>F8/4000002<0WlOd00@000000?VYC`3iZDl000001@3iZDl00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo000V0?ooo`800000B@3oool00`000000oooo0?ooo`0/0?ooo`03
0000002>F8/0SUR;02L0SUR;1000000X09o7m0030000003iZDl0000000D0nJU?00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`00:03oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo02`0oooo00<0000008iHR`2>F8/08`2>F8/4000002d0WlOd00<000000?VYC`000000
1@3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo000Y0?ooo`800000AP3o
ool00`000000oooo0?ooo`0/0?ooo`030000002>F8/0SUR;01l0SUR;1000000b09o7m0030000003i
ZDl0000000@0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`00:`3oool0
0`000000oooo000000130?ooo`030000003oool0oooo02`0oooo00<0000008iHR`2>F8/06`2>F8/4
000003L0WlOd00<000000?VYC`0000000`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo000/0?ooo`800000@P3oool00`000000oooo0?ooo`0]0?ooo`030000002>F8/0SUR;
01L0SUR;1000000l09o7m0030000003iZDl000000080nJU?00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`00;@3oool200000440oooo00<000000?ooo`3oool0;@3oool00`000000
SUR;08iHR`0C08iHR`@00000@02Oao@00`000000nJU?000000020?VYC`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool002l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0]0?ooo`030000002>F8/0SUR;00l0SUR;1000001509o7m0050000003iZDl000000?VYC`00
00001@3oool00`000000oooo0?ooo`010?ooo`00<03oool2000003h0oooo00<000000?ooo`3oool0
;@3oool00`000000SUR;08iHR`0;08iHR`@00000BP2Oao@010000000nJU?0000000000050?ooo`03
0000003oool0oooo0040oooo000b0?ooo`800000?03oool00`000000oooo0?ooo`0]0?ooo`030000
002>F8/0SUR;00L0SUR;1000001?09o7m0030000003iZDl0000000D0oooo00<000000?ooo`3oool0
0@3oool003<0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0]0?ooo`030000002>
F8/0SUR;00<0SUR;1000001D09o7m0030000003iZDl0000000@0oooo00<000000?ooo`3oool00@3o
ool003@0oooo0P00000j0?ooo`030000003oool0oooo02d0oooo00<0000008iHR`0000000`00001H
09o7m0030000003iZDl0000000@0oooo00<000000?ooo`3oool00@3oool003H0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0]0?ooo`800000G@2Oao@3000000<0oooo00<000000?oo
o`3oool00@3oool002X0oooo1@0000080?ooo`800000=`3oool00`000000oooo0?ooo`0^0?ooo`03
0000002Oao@0WlOd05X0WlOd0`0000001@3oool000000?ooo`3oool0000000<0oooo000/0?ooo`03
0000003oool0oooo00T0oooo0P00000f0?ooo`030000003oool0oooo02l0oooo00<0000009o7m02O
ao@0E@2Oao@4000000D0oooo00<000000?ooo`0000000`3oool002`0oooo00<000000?ooo`3oool0
2`3oool2000003@0oooo00<000000?ooo`3oool0<03oool00`000000WlOd09o7m01@09o7m0@00000
2P3oool00`000000oooo000000020?ooo`00;03oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0<@3oool00`000000WlOd09o7m01;09o7m0@000003P3o
ool00`000000oooo000000020?ooo`00;03oool00`000000oooo0?ooo`0>0?ooo`800000<@3oool0
0`000000oooo0?ooo`0b0?ooo`030000002Oao@0WlOd04H0WlOd1000000C0?ooo`8000000P3oool0
02/0oooo0P00000A0?ooo`800000<03oool00`000000oooo0?ooo`0c0?ooo`030000002Oao@0WlOd
0400WlOd1@00000F0?ooo`<000000P3oool00400oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0d0?ooo`030000002Oao@0WlOd03/0WlOd1000000G0?ooo`@000001@3oool00440oooo
0P0000000`3oool000000?ooo`0Z0?ooo`030000003oool0oooo03D0oooo00<0000009o7m02Oao@0
=P2Oao@4000001H0oooo1@0000090?ooo`00@`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo03H0oooo00<0000009o7m02Oao@0<@2Oao@4000001H0oooo1000000>0?ooo`00@`3oool3
000002X0oooo00<000000?ooo`3oool0=`3oool2000002`0WlOd1@00000F0?ooo`@000004P3oool0
04H0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`0i0?ooo`030000002Oao@0
WlOd02D0WlOd1000000F0?ooo`D000005P3oool004L0oooo00<000000?ooo`0000009P3oool00`00
0000oooo0?ooo`0j0?ooo`030000002Oao@0WlOd0200WlOd1000000F0?ooo`@000006`3oool004P0
oooo0P00000V0?ooo`030000003oool0oooo03/0oooo00<0000009o7m02Oao@06`2Oao@4000001D0
oooo1@00000O0?ooo`00BP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03`0oooo
00<0000009o7m02Oao@05P2Oao@4000001D0oooo1000000T0?ooo`00B`3oool2000002<0oooo00<0
00000?ooo`3oool0?@3oool00`000000WlOd09o7m00@09o7m0D00000503oool5000002P0oooo001=
0?ooo`8000008@3oool00`000000oooo0?ooo`0n0?ooo`030000002Oao@0WlOd00/0WlOd1000000E
0?ooo`@00000;@3oool004h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0o0?oo
o`030000002Oao@0WlOd00H0WlOd1000000D0?ooo`D00000<@3oool004l0oooo0P00000O0?ooo`03
0000003oool0oooo0400oooo00@0000009o7m02Oao@0WlOd1000000D0?ooo`@00000=P3oool00540
oooo00<000000?ooo`000000703oool00`000000oooo0?ooo`110?ooo`<00000503oool4000003X0
oooo001B0?ooo`800000703oool00`000000oooo0?ooo`1C0?ooo`D00000?P3oool004H0oooo1000
00090?ooo`8000006`3oool00`000000oooo0?ooo`1?0?ooo`@00000@`3oool004H0oooo00<00000
0?ooo`3oool0303oool2000001T0oooo00<000000?ooo`3oool0BP3oool5000004L0oooo00170?oo
o`030000003oool0oooo00d0oooo0P00000G0?ooo`030000003oool0oooo04H0oooo1000001<0?oo
o`00B03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0@@3oool500000500oooo00160?ooo`040000003oool0oooo000000l0oooo0P00000D0?ooo`03
0000003oool0oooo03h0oooo1000001E0?ooo`00A`3oool200000180oooo00<000000?ooo`000000
4@3oool00`000000oooo0?ooo`0i0?ooo`D00000F@3oool005`0oooo0P00000A0?ooo`030000003o
ool0oooo03D0oooo1000001N0?ooo`00GP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0340oooo1000001R0?ooo`00G`3oool2000000030?ooo`000000oooo00/0oooo00<000000?oo
o`3oool0;03oool5000006H0oooo001Q0?ooo`800000303oool00`000000oooo0?ooo`0X0?ooo`@0
0000J`3oool00680oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0S0?ooo`D00000
K`3oool006<0oooo0P00000:0?ooo`030000003oool0oooo01l0oooo1000001d0?ooo`00I@3oool2
000000P0oooo00<000000?ooo`3oool06P3oool5000007P0oooo001V0?ooo`8000001`3oool00`00
0000oooo0?ooo`0F0?ooo`@00000O@3oool006P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0A0?ooo`D00000P@3oool006T0oooo0`0000030?ooo`030000003oool0oooo00d0oooo
100000260?ooo`00J`3oool01@000000oooo0?ooo`3oool0000000/0oooo1000002:0?ooo`00H03o
ool2000000X0oooo00@000000?ooo`3oool000001P3oool5000008h0oooo001O0?ooo`040000003o
ool0oooo000000X0oooo0`0000020?ooo`@00000T`3oool00640oooo00<000000?ooo`3oool02`3o
ool3000009L0oooo001R0?ooo`030000003oool0oooo0:@0oooo001O0?ooo`040000003oool0oooo
00000:H0oooo001P0?ooo`800000Y`3oool00001\
\>"],
  ImageRangeCache->{{{0, 264.313}, {286.938, 0}} -> {0.0120589, -0.035668, \
0.00340708, 0.00340708}}]
}, Open  ]],

Cell["This uses the ShadowPlot3D example.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{ShadowPlot3D[
              E\^\(-\((x\^2 + y\^2)\)\), {x, \(-2\), 2}, {y, \(-2\), 2}, 
              ShadowPosition \[Rule] 1, PlotPoints \[Rule] 25] // 
            DrawGraphics3D}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            1}, \[IndentingNewLine]Lighting \[Rule] False];\)\)], "Input",
  CellLabel->"In[227]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.46964e-016 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
1 .002 0 r
.41156 .57099 m .42216 .58173 L .44003 .57597 L p F P
0 0 0 r
s
1 .005 0 r
.42952 .56522 m .44003 .57597 L .45803 .57021 L p F P
0 0 0 r
s
1 .002 0 r
.44003 .57597 m .42952 .56522 L .41156 .57099 L p F P
0 0 0 r
s
1 .005 0 r
.40083 .56016 m .41156 .57099 L .42952 .56522 L p F P
0 0 0 r
s
1 .011 0 r
.4476 .5595 m .45803 .57021 L .47616 .56449 L p F P
0 0 0 r
s
1 .005 0 r
.45803 .57021 m .4476 .5595 L .42952 .56522 L p F P
0 0 0 r
s
1 .011 0 r
.41886 .55442 m .42952 .56522 L .4476 .5595 L p F P
0 0 0 r
s
1 .005 0 r
.42952 .56522 m .41886 .55442 L .40083 .56016 L p F P
0 0 0 r
s
1 .018 0 r
.46581 .55388 m .47616 .56449 L .49442 .55882 L p F P
0 0 0 r
s
1 .011 0 r
.47616 .56449 m .46581 .55388 L .4476 .5595 L p F P
0 0 0 r
s
1 .011 0 r
.38995 .54926 m .40083 .56016 L .41886 .55442 L p F P
0 0 0 r
s
1 .02 0 r
.43702 .54881 m .4476 .5595 L .46581 .55388 L p F P
0 0 0 r
s
1 .011 0 r
.4476 .5595 m .43702 .54881 L .41886 .55442 L p F P
0 0 0 r
s
1 .029 0 r
.48415 .54839 m .49442 .55882 L .51282 .55323 L p F P
0 0 0 r
s
1 .018 0 r
.49442 .55882 m .48415 .54839 L .46581 .55388 L p F P
0 0 0 r
s
1 .02 0 r
.40806 .54362 m .41886 .55442 L .43702 .54881 L p F P
0 0 0 r
s
1 .011 0 r
.41886 .55442 m .40806 .54362 L .38995 .54926 L p F P
0 0 0 r
s
1 .034 0 r
.4553 .5434 m .46581 .55388 L .48415 .54839 L p F P
0 0 0 r
s
1 .02 0 r
.46581 .55388 m .4553 .5434 L .43702 .54881 L p F P
0 0 0 r
s
1 .044 0 r
.50263 .54307 m .51282 .55323 L .53135 .5477 L p F P
0 0 0 r
s
1 .029 0 r
.51282 .55323 m .50263 .54307 L .48415 .54839 L p F P
0 0 0 r
s
1 .018 0 r
.37892 .5383 m .38995 .54926 L .40806 .54362 L p F P
0 0 0 r
s
1 .036 0 r
.42629 .53822 m .43702 .54881 L .4553 .5434 L p F P
0 0 0 r
s
1 .02 0 r
.43702 .54881 m .42629 .53822 L .40806 .54362 L p F P
0 0 0 r
s
1 .054 0 r
.47373 .53826 m .48415 .54839 L .50263 .54307 L p F P
0 0 0 r
s
1 .034 0 r
.48415 .54839 m .47373 .53826 L .4553 .5434 L p F P
0 0 0 r
s
1 .061 0 r
.52125 .53792 m .53135 .5477 L .55002 .54224 L p F P
0 0 0 r
s
1 .044 0 r
.53135 .5477 m .52125 .53792 L .50263 .54307 L p F P
0 0 0 r
s
1 .034 0 r
.3971 .53284 m .40806 .54362 L .42629 .53822 L p F P
0 0 0 r
s
1 .018 0 r
.40806 .54362 m .3971 .53284 L .37892 .5383 L p F P
0 0 0 r
s
1 .06 0 r
.44465 .53318 m .4553 .5434 L .47373 .53826 L p F P
0 0 0 r
s
1 .036 0 r
.4553 .5434 m .44465 .53318 L .42629 .53822 L p F P
0 0 0 r
s
1 .08 0 r
.49229 .53344 m .50263 .54307 L .52125 .53792 L p F P
0 0 0 r
s
1 .054 0 r
.50263 .54307 m .49229 .53344 L .47373 .53826 L p F P
0 0 0 r
s
1 .082 0 r
.54002 .53293 m .55002 .54224 L .56883 .53681 L p F P
0 0 0 r
s
1 .061 0 r
.55002 .54224 m .54002 .53293 L .52125 .53792 L p F P
0 0 0 r
s
1 .029 0 r
.36774 .52731 m .37892 .5383 L .3971 .53284 L p F P
0 0 0 r
s
1 .06 0 r
.41539 .52779 m .42629 .53822 L .44465 .53318 L p F P
0 0 0 r
s
1 .034 0 r
.42629 .53822 m .41539 .52779 L .3971 .53284 L p F P
0 0 0 r
s
1 .093 0 r
.46314 .52862 m .47373 .53826 L .49229 .53344 L p F P
0 0 0 r
s
1 .06 0 r
.47373 .53826 m .46314 .52862 L .44465 .53318 L p F P
0 0 0 r
s
1 .111 0 r
.511 .52897 m .52125 .53792 L .54002 .53293 L p F P
0 0 0 r
s
1 .08 0 r
.52125 .53792 m .511 .52897 L .49229 .53344 L p F P
0 0 0 r
s
1 .103 0 r
.55893 .52801 m .56883 .53681 L .58779 .53134 L p F P
0 0 0 r
s
1 .082 0 r
.56883 .53681 m .55893 .52801 L .54002 .53293 L p F P
0 0 0 r
s
1 .054 0 r
.38598 .52213 m .3971 .53284 L .41539 .52779 L p F P
0 0 0 r
s
1 .029 0 r
.3971 .53284 m .38598 .52213 L .36774 .52731 L p F P
0 0 0 r
s
1 .098 0 r
.43382 .52334 m .44465 .53318 L .46314 .52862 L p F P
0 0 0 r
s
1 .06 0 r
.44465 .53318 m .43382 .52334 L .41539 .52779 L p F P
0 0 0 r
s
1 .137 0 r
.48178 .52464 m .49229 .53344 L .511 .52897 L p F P
0 0 0 r
s
1 .093 0 r
.49229 .53344 m .48178 .52464 L .46314 .52862 L p F P
0 0 0 r
s
1 .148 0 r
.52987 .5248 m .54002 .53293 L .55893 .52801 L p F P
0 0 0 r
s
1 .111 0 r
.54002 .53293 m .52987 .5248 L .511 .52897 L p F P
0 0 0 r
s
1 .044 0 r
.3564 .51629 m .36774 .52731 L .38598 .52213 L p F P
0 0 0 r
s
1 .123 0 r
.57801 .52307 m .58779 .53134 L .60689 .52575 L p F P
0 0 0 r
s
1 .103 0 r
.58779 .53134 m .57801 .52307 L .55893 .52801 L p F P
0 0 0 r
s
1 .093 0 r
.40434 .51758 m .41539 .52779 L .43382 .52334 L p F P
0 0 0 r
s
1 .054 0 r
.41539 .52779 m .40434 .51758 L .38598 .52213 L p F P
0 0 0 r
s
1 .152 0 r
.45238 .51968 m .46314 .52862 L .48178 .52464 L p F P
0 0 0 r
s
1 .098 0 r
.46314 .52862 m .45238 .51968 L .43382 .52334 L p F P
0 0 0 r
s
1 .191 0 r
.50058 .52127 m .511 .52897 L .52987 .5248 L p F P
0 0 0 r
s
1 .137 0 r
.511 .52897 m .50058 .52127 L .48178 .52464 L p F P
0 0 0 r
s
1 .186 0 r
.5489 .52081 m .55893 .52801 L .57801 .52307 L p F P
0 0 0 r
s
1 .148 0 r
.55893 .52801 m .5489 .52081 L .52987 .5248 L p F P
0 0 0 r
s
1 .14 0 r
.59724 .51795 m .60689 .52575 L .62614 .51996 L p F P
0 0 0 r
s
1 .123 0 r
.60689 .52575 m .59724 .51795 L .57801 .52307 L p F P
0 0 0 r
s
1 .08 0 r
.37469 .51148 m .38598 .52213 L .40434 .51758 L p F P
0 0 0 r
s
1 .044 0 r
.38598 .52213 m .37469 .51148 L .3564 .51629 L p F P
0 0 0 r
s
1 .152 0 r
.42281 .51397 m .43382 .52334 L .45238 .51968 L p F P
0 0 0 r
s
1 .093 0 r
.43382 .52334 m .42281 .51397 L .40434 .51758 L p F P
0 0 0 r
s
1 .223 0 r
.47109 .51697 m .48178 .52464 L .50058 .52127 L p F P
0 0 0 r
s
1 .152 0 r
.48178 .52464 m .47109 .51697 L .45238 .51968 L p F P
0 0 0 r
s
1 .061 0 r
.34489 .50522 m .3564 .51629 L .37469 .51148 L p F P
0 0 0 r
s
1 .253 0 r
.51955 .51844 m .52987 .5248 L .5489 .52081 L p F P
0 0 0 r
s
1 .191 0 r
.52987 .5248 m .51955 .51844 L .50058 .52127 L p F P
0 0 0 r
s
1 .152 0 r
.61661 .5125 m .62614 .51996 L .64552 .5139 L p F P
0 0 0 r
s
1 .14 0 r
.62614 .51996 m .61661 .5125 L .59724 .51795 L p F P
0 0 0 r
s
1 .222 0 r
.5681 .5168 m .57801 .52307 L .59724 .51795 L p F P
0 0 0 r
s
1 .186 0 r
.57801 .52307 m .5681 .5168 L .5489 .52081 L p F P
0 0 0 r
s
1 .137 0 r
.3931 .50762 m .40434 .51758 L .42281 .51397 L p F P
0 0 0 r
s
1 .08 0 r
.40434 .51758 m .3931 .50762 L .37469 .51148 L p F P
0 0 0 r
s
1 .234 0 r
.44143 .51158 m .45238 .51968 L .47109 .51697 L p F P
0 0 0 r
s
1 .152 0 r
.45238 .51968 m .44143 .51158 L .42281 .51397 L p F P
0 0 0 r
s
1 .111 0 r
.36324 .50088 m .37469 .51148 L .3931 .50762 L p F P
0 0 0 r
s
1 .061 0 r
.37469 .51148 m .36324 .50088 L .34489 .50522 L p F P
0 0 0 r
s
1 .31 0 r
.48997 .51525 m .50058 .52127 L .51955 .51844 L p F P
0 0 0 r
s
1 .223 0 r
.50058 .52127 m .48997 .51525 L .47109 .51697 L p F P
0 0 0 r
s
1 .156 0 r
.63612 .50659 m .64552 .5139 L .66504 .50754 L p F P
0 0 0 r
s
1 .152 0 r
.64552 .5139 m .63612 .50659 L .61661 .5125 L p F P
0 0 0 r
s
1 .253 0 r
.58747 .51251 m .59724 .51795 L .61661 .5125 L p F P
0 0 0 r
s
1 .222 0 r
.59724 .51795 m .58747 .51251 L .5681 .5168 L p F P
0 0 0 r
s
1 .318 0 r
.53871 .51594 m .5489 .52081 L .5681 .5168 L p F P
0 0 0 r
s
1 .253 0 r
.5489 .52081 m .53871 .51594 L .51955 .51844 L p F P
0 0 0 r
s
1 .223 0 r
.41162 .5051 m .42281 .51397 L .44143 .51158 L p F P
0 0 0 r
s
1 .137 0 r
.42281 .51397 m .41162 .5051 L .3931 .50762 L p F P
0 0 0 r
s
1 .082 0 r
.33322 .49406 m .34489 .50522 L .36324 .50088 L p F P
0 0 0 r
s
1 .343 0 r
.46019 .51065 m .47109 .51697 L .48997 .51525 L p F P
0 0 0 r
s
1 .234 0 r
.47109 .51697 m .46019 .51065 L .44143 .51158 L p F P
0 0 0 r
s
1 .152 0 r
.65577 .50015 m .66504 .50754 L .68468 .50087 L p F P
0 0 0 r
s
1 .156 0 r
.66504 .50754 m .65577 .50015 L .63612 .50659 L p F P
0 0 0 r
s
1 .191 0 r
.38168 .49784 m .3931 .50762 L .41162 .5051 L p F P
0 0 0 r
s
1 .111 0 r
.3931 .50762 m .38168 .49784 L .36324 .50088 L p F P
0 0 0 r
s
1 .273 0 r
.607 .50767 m .61661 .5125 L .63612 .50659 L p F P
0 0 0 r
s
1 .253 0 r
.61661 .5125 m .607 .50767 L .58747 .51251 L p F P
0 0 0 r
s
1 .41 0 r
.50905 .51443 m .51955 .51844 L .53871 .51594 L p F P
0 0 0 r
s
1 .31 0 r
.51955 .51844 m .50905 .51443 L .48997 .51525 L p F P
0 0 0 r
s
1 .38 0 r
.55806 .51344 m .5681 .5168 L .58747 .51251 L p F P
0 0 0 r
s
1 .318 0 r
.5681 .5168 m .55806 .51344 L .53871 .51594 L p F P
0 0 0 r
s
1 .343 0 r
.43027 .50438 m .44143 .51158 L .46019 .51065 L p F P
0 0 0 r
s
1 .223 0 r
.44143 .51158 m .43027 .50438 L .41162 .5051 L p F P
0 0 0 r
s
1 .148 0 r
.35161 .49025 m .36324 .50088 L .38168 .49784 L p F P
0 0 0 r
s
1 .082 0 r
.36324 .50088 m .35161 .49025 L .33322 .49406 L p F P
0 0 0 r
s
1 .14 0 r
.67553 .49317 m .68468 .50087 L .70446 .49393 L p F P
0 0 0 r
s
1 .152 0 r
.68468 .50087 m .67553 .49317 L .65577 .50015 L p F P
0 0 0 r
s
1 .28 0 r
.62667 .50206 m .63612 .50659 L .65577 .50015 L p F P
0 0 0 r
s
1 .273 0 r
.63612 .50659 m .62667 .50206 L .607 .50767 L p F P
0 0 0 r
s
1 .477 0 r
.47915 .51126 m .48997 .51525 L .50905 .51443 L p F P
0 0 0 r
s
1 .343 0 r
.48997 .51525 m .47915 .51126 L .46019 .51065 L p F P
0 0 0 r
s
1 .31 0 r
.40022 .49667 m .41162 .5051 L .43027 .50438 L p F P
0 0 0 r
s
1 .191 0 r
.41162 .5051 m .40022 .49667 L .38168 .49784 L p F P
0 0 0 r
s
1 .431 0 r
.5776 .51051 m .58747 .51251 L .607 .50767 L p F P
0 0 0 r
s
1 .431 0 r
.59731 .50669 m .5776 .51051 L p .58337 .50995 L F P
0 0 0 r
s
1 .431 0 r
.607 .50767 m .59731 .50669 L p .58337 .50995 L F P
0 0 0 r
s
1 .465 0 r
.61716 .5016 m .59731 .50669 L p .60359 .5057 L F P
0 0 0 r
s
1 .465 0 r
.62667 .50206 m .61716 .5016 L p .60359 .5057 L F P
0 0 0 r
s
1 .477 0 r
.63713 .495 m .61716 .5016 L p .62343 .5003 L F P
0 0 0 r
s
1 .477 0 r
.64646 .49554 m .63713 .495 L p .62343 .5003 L F P
0 0 0 r
s
1 .465 0 r
.65719 .48691 m .63713 .495 L p .64287 .49365 L F P
0 0 0 r
s
1 .465 0 r
.66636 .48811 m .65719 .48691 L p .64287 .49365 L F P
0 0 0 r
s
1 .698 0 r
.65719 .48691 m .67732 .47752 L p .67165 .4801 L F P
0 0 0 r
s
1 .753 0 r
.63713 .495 m .65719 .48691 L p .65098 .48965 L F P
0 0 0 r
s
1 .477 0 r
.61716 .5016 m .62667 .50206 L .64646 .49554 L p F P
0 0 0 r
s
1 .465 0 r
.63713 .495 m .64646 .49554 L .66636 .48811 L p F P
0 0 0 r
s
1 .753 0 r
.62778 .4999 m .63713 .495 L p .65098 .48965 L F P
0 0 0 r
s
1 .698 0 r
.64803 .49085 m .65719 .48691 L p .67165 .4801 L F P
0 0 0 r
s
1 .773 0 r
.61716 .5016 m .63713 .495 L p .63089 .49744 L F P
0 0 0 r
s
1 .465 0 r
.59731 .50669 m .607 .50767 L .62667 .50206 L p F P
0 0 0 r
s
1 .773 0 r
.60759 .50655 m .61716 .5016 L p .63089 .49744 L F P
0 0 0 r
s
1 .753 0 r
.59731 .50669 m .61716 .5016 L p .61141 .50339 L F P
0 0 0 r
s
1 .753 0 r
.58751 .51083 m .59731 .50669 L p .61141 .50339 L F P
0 0 0 r
s
1 .698 0 r
.5776 .51051 m .59731 .50669 L p .59265 .50769 L F P
0 0 0 r
s
1 .38 0 r
.58747 .51251 m .5776 .51051 L p .56272 .51329 L F P
0 0 0 r
s
1 .698 0 r
.56758 .51309 m .5776 .51051 L p .59265 .50769 L F P
0 0 0 r
s
1 .38 0 r
.5776 .51051 m .55806 .51344 L p .56272 .51329 L F P
0 0 0 r
s
1 .103 0 r
.32138 .48275 m .33322 .49406 L .35161 .49025 L p F P
0 0 0 r
s
1 .515 0 r
.53871 .51594 m .55806 .51344 L p .53544 .514 L F P
0 0 0 r
s
1 .515 0 r
.52834 .51418 m .52988 .51444 L p .53544 .514 L F P
0 0 0 r
s
1 .515 0 r
.52988 .51444 m .53871 .51594 L p .53544 .514 L F P
0 0 0 r
s
1 .515 0 r
.55806 .51344 m .54785 .51397 L .52834 .51418 L p F P
0 0 0 r
s
1 .615 0 r
.54785 .51397 m .55806 .51344 L .5776 .51051 L p F P
0 0 0 r
s
1 .615 0 r
.56758 .51309 m .54785 .51397 L p .57315 .51103 L F P
0 0 0 r
s
1 .615 0 r
.5776 .51051 m .57667 .51075 L p .57315 .51103 L F P
0 0 0 r
s
1 .615 0 r
.57667 .51075 m .56758 .51309 L p .57315 .51103 L F P
0 0 0 r
s
1 .41 0 r
.53871 .51594 m .52834 .51418 L .50905 .51443 L p F P
0 0 0 r
s
1 .123 0 r
.69542 .48572 m .70446 .49393 L .72436 .48678 L p F P
0 0 0 r
s
1 .14 0 r
.70446 .49393 m .69542 .48572 L .67553 .49317 L p F P
0 0 0 r
s
1 .253 0 r
.37008 .48814 m .38168 .49784 L .40022 .49667 L p F P
0 0 0 r
s
1 .148 0 r
.38168 .49784 m .37008 .48814 L .35161 .49025 L p F P
0 0 0 r
s
1 .502 0 r
.44907 .50578 m .46019 .51065 L .47915 .51126 L p F P
0 0 0 r
s
1 .343 0 r
.46019 .51065 m .44907 .50578 L .43027 .50438 L p F P
0 0 0 r
s
1 .273 0 r
.64646 .49554 m .65577 .50015 L .67553 .49317 L p F P
0 0 0 r
s
1 .28 0 r
.65577 .50015 m .64646 .49554 L .62667 .50206 L p F P
0 0 0 r
s
1 .631 0 r
.49832 .51327 m .50905 .51443 L .52834 .51418 L p F P
0 0 0 r
s
1 .477 0 r
.50905 .51443 m .49832 .51327 L .47915 .51126 L p F P
0 0 0 r
s
1 .186 0 r
.3398 .47947 m .35161 .49025 L .37008 .48814 L p F P
0 0 0 r
s
1 .103 0 r
.35161 .49025 m .3398 .47947 L .32138 .48275 L p F P
0 0 0 r
s
1 .103 0 r
.71542 .47794 m .72436 .48678 L .7444 .47951 L p F P
0 0 0 r
s
1 .123 0 r
.72436 .48678 m .71542 .47794 L .69542 .48572 L p F P
0 0 0 r
s
1 .477 0 r
.41888 .49796 m .43027 .50438 L .44907 .50578 L p F P
0 0 0 r
s
1 .31 0 r
.43027 .50438 m .41888 .49796 L .40022 .49667 L p F P
0 0 0 r
s
1 .253 0 r
.66636 .48811 m .67553 .49317 L .69542 .48572 L p F P
0 0 0 r
s
1 .273 0 r
.67553 .49317 m .66636 .48811 L .64646 .49554 L p F P
0 0 0 r
s
1 .123 0 r
.30937 .4712 m .32138 .48275 L .3398 .47947 L p F P
0 0 0 r
s
1 .41 0 r
.38863 .48847 m .40022 .49667 L .41888 .49796 L p F P
0 0 0 r
s
1 .253 0 r
.40022 .49667 m .38863 .48847 L .37008 .48814 L p F P
0 0 0 r
s
1 .082 0 r
.73554 .46997 m .7444 .47951 L .76458 .47219 L p F P
0 0 0 r
s
1 .103 0 r
.7444 .47951 m .73554 .46997 L .71542 .47794 L p F P
0 0 0 r
s
1 .502 0 r
.47915 .51126 m .46807 .50945 L .44907 .50578 L p F P
0 0 0 r
s
1 .698 0 r
.46807 .50945 m .47915 .51126 L .49832 .51327 L p F P
0 0 0 r
s
1 .222 0 r
.68636 .47989 m .69542 .48572 L .71542 .47794 L p F P
0 0 0 r
s
1 .253 0 r
.69542 .48572 m .68636 .47989 L .66636 .48811 L p F P
0 0 0 r
s
1 .318 0 r
.35829 .4783 m .37008 .48814 L .38863 .48847 L p F P
0 0 0 r
s
1 .186 0 r
.37008 .48814 m .35829 .4783 L .3398 .47947 L p F P
0 0 0 r
s
1 .793 0 r
.51774 .51619 m .52834 .51418 L .54785 .51397 L p F P
0 0 0 r
s
1 .631 0 r
.52834 .51418 m .51774 .51619 L .49832 .51327 L p F P
0 0 0 r
s
1 .698 0 r
.43769 .50221 m .44907 .50578 L .46807 .50945 L p F P
0 0 0 r
s
1 .477 0 r
.44907 .50578 m .43769 .50221 L .41888 .49796 L p F P
0 0 0 r
s
1 .061 0 r
.7558 .46195 m .76458 .47219 L .78491 .46488 L p F P
0 0 0 r
s
1 .082 0 r
.76458 .47219 m .7558 .46195 L .73554 .46997 L p F P
0 0 0 r
s
1 .222 0 r
.32784 .46839 m .3398 .47947 L .35829 .4783 L p F P
0 0 0 r
s
1 .123 0 r
.3398 .47947 m .32784 .46839 L .30937 .4712 L p F P
0 0 0 r
s
1 .186 0 r
.70646 .47111 m .71542 .47794 L .73554 .46997 L p F P
0 0 0 r
s
1 .222 0 r
.71542 .47794 m .70646 .47111 L .68636 .47989 L p F P
0 0 0 r
s
1 .631 0 r
.40727 .49202 m .41888 .49796 L .43769 .50221 L p F P
0 0 0 r
s
1 .41 0 r
.41888 .49796 m .40727 .49202 L .38863 .48847 L p F P
0 0 0 r
s
1 .14 0 r
.29721 .45933 m .30937 .4712 L .32784 .46839 L p F P
0 0 0 r
s
1 .698 0 r
.59731 .50669 m .58751 .51083 L .56758 .51309 L p F P
0 0 0 r
s
1 .923 0 r
.48732 .51518 m .49832 .51327 L .51774 .51619 L p F P
0 0 0 r
s
1 .698 0 r
.49832 .51327 m .48732 .51518 L .46807 .50945 L p F P
0 0 0 r
s
1 .431 0 r
.65719 .48691 m .66636 .48811 L .68636 .47989 L p F P
0 0 0 r
s
1 .044 0 r
.77621 .454 m .78491 .46488 L .80539 .45763 L p F P
0 0 0 r
s
1 .061 0 r
.78491 .46488 m .77621 .454 L .7558 .46195 L p F P
0 0 0 r
s
1 .515 0 r
.37683 .48015 m .38863 .48847 L .40727 .49202 L p F P
0 0 0 r
s
1 .318 0 r
.38863 .48847 m .37683 .48015 L .35829 .4783 L p F P
0 0 0 r
s
1 .148 0 r
.72667 .46203 m .73554 .46997 L .7558 .46195 L p F P
0 0 0 r
s
1 .186 0 r
.73554 .46997 m .72667 .46203 L .70646 .47111 L p F P
0 0 0 r
s
1 .946 0 r
.53742 .51921 m .54785 .51397 L .56758 .51309 L p F P
0 0 0 r
s
1 .793 0 r
.54785 .51397 m .53742 .51921 L .51774 .51619 L p F P
0 0 0 r
s
1 .38 0 r
.34634 .46806 m .35829 .4783 L .37683 .48015 L p F P
0 0 0 r
s
1 .222 0 r
.35829 .4783 m .34634 .46806 L .32784 .46839 L p F P
0 0 0 r
s
1 .38 0 r
.67732 .47752 m .68636 .47989 L .70646 .47111 L p F P
0 0 0 r
s
1 .431 0 r
.68636 .47989 m .67732 .47752 L .65719 .48691 L p F P
0 0 0 r
s
1 .971 0 r
.45671 .50961 m .46807 .50945 L .48732 .51518 L p F P
0 0 0 r
s
1 .698 0 r
.46807 .50945 m .45671 .50961 L .43769 .50221 L p F P
0 0 0 r
s
1 .753 0 r
.61716 .5016 m .60759 .50655 L .58751 .51083 L p F P
0 0 0 r
s
1 .029 0 r
.79677 .44619 m .80539 .45763 L .82603 .45045 L p F P
0 0 0 r
s
1 .044 0 r
.80539 .45763 m .79677 .44619 L .77621 .454 L p F P
0 0 0 r
s
1 .253 0 r
.31571 .45685 m .32784 .46839 L .34634 .46806 L p F P
0 0 0 r
s
1 .14 0 r
.32784 .46839 m .31571 .45685 L .29721 .45933 L p F P
0 0 0 r
s
1 .111 0 r
.74699 .45291 m .7558 .46195 L .77621 .454 L p F P
0 0 0 r
s
1 .148 0 r
.7558 .46195 m .74699 .45291 L .72667 .46203 L p F P
0 0 0 r
s
1 .152 0 r
.28489 .44706 m .29721 .45933 L .31571 .45685 L p F P
0 0 0 r
s
1 .923 0 r
.42606 .49945 m .43769 .50221 L .45671 .50961 L p F P
0 0 0 r
s
1 .631 0 r
.43769 .50221 m .42606 .49945 L .40727 .49202 L p F P
0 0 0 r
s
1 .318 0 r
.69752 .46721 m .70646 .47111 L .72667 .46203 L p F P
0 0 0 r
s
1 .38 0 r
.70646 .47111 m .69752 .46721 L .67732 .47752 L p F P
0 0 0 r
s
.926 1 0 r
.55738 .52127 m .56758 .51309 L .58751 .51083 L p F P
0 0 0 r
s
1 .946 0 r
.56758 .51309 m .55738 .52127 L .53742 .51921 L p F P
0 0 0 r
s
.841 1 0 r
.50686 .52229 m .51774 .51619 L .53742 .51921 L p F P
0 0 0 r
s
1 .923 0 r
.51774 .51619 m .50686 .52229 L .48732 .51518 L p F P
0 0 0 r
s
1 .018 0 r
.81749 .43855 m .82603 .45045 L .84683 .44333 L p F P
0 0 0 r
s
1 .029 0 r
.82603 .45045 m .81749 .43855 L .79677 .44619 L p F P
0 0 0 r
s
1 .773 0 r
.63713 .495 m .62778 .4999 L .60759 .50655 L p F P
0 0 0 r
s
1 .08 0 r
.76746 .44395 m .77621 .454 L .79677 .44619 L p F P
0 0 0 r
s
1 .111 0 r
.77621 .454 m .76746 .44395 L .74699 .45291 L p F P
0 0 0 r
s
1 .793 0 r
.39545 .48601 m .40727 .49202 L .42606 .49945 L p F P
0 0 0 r
s
1 .515 0 r
.39545 .48601 m .37683 .48015 L p .40354 .49057 L F P
0 0 0 r
s
1 .615 0 r
.36487 .47129 m .37683 .48015 L .39545 .48601 L p F P
0 0 0 r
s
1 .615 0 r
.38344 .47923 m .36487 .47129 L p .38929 .48305 L F P
0 0 0 r
s
1 .615 0 r
.39545 .48601 m .38344 .47923 L p .38929 .48305 L F P
0 0 0 r
s
1 .698 0 r
.35276 .46141 m .36487 .47129 L .38344 .47923 L p F P
0 0 0 r
s
1 .698 0 r
.37129 .47093 m .35276 .46141 L p .37588 .47484 L F P
0 0 0 r
s
1 .698 0 r
.38344 .47923 m .37129 .47093 L p .37588 .47484 L F P
0 0 0 r
s
1 .753 0 r
.34052 .45011 m .35276 .46141 L .37129 .47093 L p F P
0 0 0 r
s
1 .753 0 r
.35904 .46047 m .34052 .45011 L p .36306 .46536 L F P
0 0 0 r
s
1 .753 0 r
.37129 .47093 m .35904 .46047 L p .36306 .46536 L F P
0 0 0 r
s
.841 1 0 r
.37129 .47093 m .38989 .48685 L p .36662 .46696 L F P
0 0 0 r
s
.841 1 0 r
.35904 .46047 m .37129 .47093 L p .36662 .46696 L F P
0 0 0 r
s
.841 1 0 r
.37759 .47762 m .35904 .46047 L p .37924 .47774 L F P
0 0 0 r
s
.841 1 0 r
.38989 .48685 m .37759 .47762 L p .37924 .47774 L F P
0 0 0 r
s
.262 1 0 r
.37759 .47762 m .39629 .5022 L p .37591 .47749 L F P
0 0 0 r
s
.811 1 0 r
.35904 .46047 m .37759 .47762 L p .35494 .4555 L F P
0 0 0 r
s
.811 1 0 r
.36527 .46459 m .34673 .44748 L p .36692 .4672 L F P
0 0 0 r
s
.811 1 0 r
.37759 .47762 m .36527 .46459 L p .36692 .4672 L F P
0 0 0 r
s
.262 1 0 r
.36527 .46459 m .37759 .47762 L p .37591 .47749 L F P
0 0 0 r
s
.262 1 0 r
.38393 .48917 m .36527 .46459 L p .38194 .4848 L F P
0 0 0 r
s
.262 1 0 r
.39629 .5022 m .38393 .48917 L p .38194 .4848 L F P
0 0 0 r
s
0 1 .354 r
.38393 .48917 m .40289 .52085 L p .38596 .49363 L F P
0 0 0 r
s
.306 1 0 r
.36527 .46459 m .38393 .48917 L p .36358 .46194 L F P
0 0 0 r
s
.926 1 0 r
.37129 .47093 m .38344 .47923 L p .37749 .47535 L F P
0 0 0 r
s
.926 1 0 r
.40212 .49288 m .38989 .48685 L .37129 .47093 L p F P
0 0 0 r
s
.306 1 0 r
.37166 .47062 m .35298 .44774 L p .37043 .4711 L F P
0 0 0 r
s
.306 1 0 r
.38393 .48917 m .37166 .47062 L p .37043 .4711 L F P
0 0 0 r
s
0 1 .354 r
.37166 .47062 m .38393 .48917 L p .38596 .49363 L F P
0 0 0 r
s
0 1 .414 r
.38393 .48917 m .39629 .5022 L .41532 .53387 L p F P
0 0 0 r
s
0 1 .414 r
.40289 .52085 m .38393 .48917 L p .39495 .50486 L F P
0 0 0 r
s
0 1 .414 r
.41532 .53387 m .40289 .52085 L p .39495 .50486 L F P
0 0 0 r
s
0 .891 1 r
.40289 .52085 m .42237 .55781 L p .41105 .53729 L F P
0 0 0 r
s
0 1 .354 r
.3906 .50021 m .37166 .47062 L p .38339 .48949 L F P
0 0 0 r
s
0 1 .354 r
.40289 .52085 m .3906 .50021 L p .38339 .48949 L F P
0 0 0 r
s
0 .891 1 r
.3906 .50021 m .40289 .52085 L p .41105 .53729 L F P
0 0 0 r
s
0 .811 1 r
.40289 .52085 m .41532 .53387 L .43487 .57078 L p F P
0 0 0 r
s
0 .811 1 r
.43487 .57078 m .42237 .55781 L .40289 .52085 L p F P
0 0 0 r
s
0 1 .882 r
.3906 .50021 m .41004 .53475 L p .398 .5112 L F P
0 0 0 r
s
.926 1 0 r
.38344 .47923 m .40212 .49288 L p .37749 .47535 L F P
0 0 0 r
s
.306 1 0 r
.37759 .47762 m .38989 .48685 L .40868 .50977 L p F P
0 0 0 r
s
.306 1 0 r
.40868 .50977 m .39629 .5022 L .37759 .47762 L p F P
0 0 0 r
s
0 1 .882 r
.3785 .47306 m .3906 .50021 L p .398 .5112 L F P
0 0 0 r
s
0 1 .182 r
.37166 .47062 m .3906 .50021 L p .37291 .47013 L F P
0 0 0 r
s
0 1 .182 r
.3595 .44734 m .37166 .47062 L p .37291 .47013 L F P
0 0 0 r
s
.306 1 0 r
.35298 .44774 m .36527 .46459 L p .36358 .46194 L F P
0 0 0 r
s
.811 1 0 r
.34673 .44748 m .35904 .46047 L p .35494 .4555 L F P
0 0 0 r
s
1 .946 0 r
.39545 .48601 m .41419 .4967 L p .38722 .48137 L F P
0 0 0 r
s
1 .946 0 r
.38344 .47923 m .39545 .48601 L p .38722 .48137 L F P
0 0 0 r
s
1 .515 0 r
.40727 .49202 m .39545 .48601 L p .40354 .49057 L F P
0 0 0 r
s
1 .38 0 r
.37683 .48015 m .36487 .47129 L .34634 .46806 L p F P
0 0 0 r
s
1 .253 0 r
.71779 .45644 m .72667 .46203 L .74699 .45291 L p F P
0 0 0 r
s
1 .318 0 r
.72667 .46203 m .71779 .45644 L .69752 .46721 L p F P
0 0 0 r
s
1 .431 0 r
.33423 .45714 m .34634 .46806 L .36487 .47129 L p F P
0 0 0 r
s
1 .253 0 r
.34634 .46806 m .33423 .45714 L .31571 .45685 L p F P
0 0 0 r
s
1 .698 0 r
.66831 .47975 m .64803 .49085 L p .65398 .48814 L F P
0 0 0 r
s
1 .698 0 r
.67732 .47752 m .66831 .47975 L p .65398 .48814 L F P
0 0 0 r
s
1 .615 0 r
.69752 .46721 m .68861 .46722 L .66831 .47975 L p F P
0 0 0 r
s
1 .946 0 r
.66831 .47975 m .68861 .46722 L p .68277 .47129 L F P
0 0 0 r
s
1 .615 0 r
.66831 .47975 m .67732 .47752 L .69752 .46721 L p F P
0 0 0 r
s
1 .946 0 r
.65933 .48762 m .66831 .47975 L p .68277 .47129 L F P
0 0 0 r
s
.926 1 0 r
.64803 .49085 m .66831 .47975 L p .66112 .48496 L F P
0 0 0 r
s
1 .753 0 r
.65719 .48691 m .64803 .49085 L p .63508 .49667 L F P
0 0 0 r
s
.926 1 0 r
.63887 .50108 m .64803 .49085 L p .66112 .48496 L F P
0 0 0 r
s
1 .753 0 r
.64803 .49085 m .62778 .4999 L p .63508 .49667 L F P
0 0 0 r
s
1 .011 0 r
.83839 .43107 m .84683 .44333 L .8678 .43626 L p F P
0 0 0 r
s
1 .018 0 r
.84683 .44333 m .83839 .43107 L .81749 .43855 L p F P
0 0 0 r
s
1 .054 0 r
.78809 .43528 m .79677 .44619 L .81749 .43855 L p F P
0 0 0 r
s
1 .08 0 r
.79677 .44619 m .78809 .43528 L .76746 .44395 L p F P
0 0 0 r
s
.717 1 0 r
.47601 .5199 m .48732 .51518 L .50686 .52229 L p F P
0 0 0 r
s
1 .971 0 r
.48732 .51518 m .47601 .5199 L .45671 .50961 L p F P
0 0 0 r
s
1 .273 0 r
.30344 .44473 m .31571 .45685 L .33423 .45714 L p F P
0 0 0 r
s
1 .152 0 r
.31571 .45685 m .30344 .44473 L .28489 .44706 L p F P
0 0 0 r
s
.841 1 0 r
.57757 .52124 m .58751 .51083 L .60759 .50655 L p F P
0 0 0 r
s
.926 1 0 r
.58751 .51083 m .57757 .52124 L .55738 .52127 L p F P
0 0 0 r
s
1 .191 0 r
.73817 .44564 m .74699 .45291 L .76746 .44395 L p F P
0 0 0 r
s
1 .253 0 r
.74699 .45291 m .73817 .44564 L .71779 .45644 L p F P
0 0 0 r
s
1 .156 0 r
.27242 .43435 m .28489 .44706 L .30344 .44473 L p F P
0 0 0 r
s
.616 1 0 r
.52673 .5296 m .53742 .51921 L .55738 .52127 L p F P
0 0 0 r
s
.841 1 0 r
.53742 .51921 m .52673 .5296 L .50686 .52229 L p F P
0 0 0 r
s
.717 1 0 r
.44507 .51106 m .45671 .50961 L .47601 .5199 L p F P
0 0 0 r
s
1 .923 0 r
.45671 .50961 m .44507 .51106 L .42606 .49945 L p F P
0 0 0 r
s
1 .034 0 r
.80888 .42694 m .81749 .43855 L .83839 .43107 L p F P
0 0 0 r
s
1 .054 0 r
.81749 .43855 m .80888 .42694 L .78809 .43528 L p F P
0 0 0 r
s
1 .005 0 r
.85946 .42372 m .8678 .43626 L .88893 .42921 L p F P
0 0 0 r
s
1 .011 0 r
.8678 .43626 m .85946 .42372 L .83839 .43107 L p F P
0 0 0 r
s
1 .137 0 r
.75868 .43515 m .76746 .44395 L .78809 .43528 L p F P
0 0 0 r
s
1 .191 0 r
.76746 .44395 m .75868 .43515 L .73817 .44564 L p F P
0 0 0 r
s
1 .515 0 r
.68861 .46722 m .69752 .46721 L .71779 .45644 L p F P
0 0 0 r
s
.841 1 0 r
.41419 .4967 m .42606 .49945 L .44507 .51106 L p F P
0 0 0 r
s
1 .793 0 r
.42606 .49945 m .41419 .4967 L .39545 .48601 L p F P
0 0 0 r
s
.811 1 0 r
.59793 .51815 m .60759 .50655 L .62778 .4999 L p F P
0 0 0 r
s
.841 1 0 r
.60759 .50655 m .59793 .51815 L .57757 .52124 L p F P
0 0 0 r
s
1 .431 0 r
.36487 .47129 m .35276 .46141 L .33423 .45714 L p F P
0 0 0 r
s
1 .465 0 r
.322 .44532 m .33423 .45714 L .35276 .46141 L p F P
0 0 0 r
s
1 .273 0 r
.33423 .45714 m .322 .44532 L .30344 .44473 L p F P
0 0 0 r
s
1 .02 0 r
.82986 .41893 m .83839 .43107 L .85946 .42372 L p F P
0 0 0 r
s
1 .034 0 r
.83839 .43107 m .82986 .41893 L .80888 .42694 L p F P
0 0 0 r
s
1 .002 0 r
.8807 .41646 m .88893 .42921 L .91023 .42216 L p F P
0 0 0 r
s
1 .005 0 r
.88893 .42921 m .8807 .41646 L .85946 .42372 L p F P
0 0 0 r
s
1 .28 0 r
.29104 .43193 m .30344 .44473 L .322 .44532 L p F P
0 0 0 r
s
1 .156 0 r
.30344 .44473 m .29104 .43193 L .27242 .43435 L p F P
0 0 0 r
s
1 .093 0 r
.77935 .42518 m .78809 .43528 L .80888 .42694 L p F P
0 0 0 r
s
1 .137 0 r
.78809 .43528 m .77935 .42518 L .75868 .43515 L p F P
0 0 0 r
s
1 .41 0 r
.70896 .45398 m .71779 .45644 L .73817 .44564 L p F P
0 0 0 r
s
1 .515 0 r
.71779 .45644 m .70896 .45398 L .68861 .46722 L p F P
0 0 0 r
s
.389 1 0 r
.49566 .53216 m .50686 .52229 L .52673 .5296 L p F P
0 0 0 r
s
.717 1 0 r
.50686 .52229 m .49566 .53216 L .47601 .5199 L p F P
0 0 0 r
s
.841 1 0 r
.61839 .51144 m .62778 .4999 L .64803 .49085 L p F P
0 0 0 r
s
.811 1 0 r
.62778 .4999 m .61839 .51144 L .59793 .51815 L p F P
0 0 0 r
s
1 .152 0 r
.25979 .42119 m .27242 .43435 L .29104 .43193 L p F P
0 0 0 r
s
.43 1 0 r
.54694 .53557 m .55738 .52127 L .57757 .52124 L p F P
0 0 0 r
s
.616 1 0 r
.55738 .52127 m .54694 .53557 L .52673 .5296 L p F P
0 0 0 r
s
1 .31 0 r
.72937 .44074 m .73817 .44564 L .75868 .43515 L p F P
0 0 0 r
s
1 .41 0 r
.73817 .44564 m .72937 .44074 L .70896 .45398 L p F P
0 0 0 r
s
1 .011 0 r
.85101 .41118 m .85946 .42372 L .8807 .41646 L p F P
0 0 0 r
s
1 .02 0 r
.85946 .42372 m .85101 .41118 L .82986 .41893 L p F P
0 0 0 r
s
1 .06 0 r
.8002 .41582 m .80888 .42694 L .82986 .41893 L p F P
0 0 0 r
s
1 .093 0 r
.80888 .42694 m .8002 .41582 L .77935 .42518 L p F P
0 0 0 r
s
1 .002 0 r
.91023 .42216 m .90211 .40923 L .8807 .41646 L p F P
0 0 0 r
s
.841 1 0 r
.64803 .49085 m .63887 .50108 L .61839 .51144 L p F P
0 0 0 r
s
1 .223 0 r
.7499 .42804 m .75868 .43515 L .77935 .42518 L p F P
0 0 0 r
s
1 .31 0 r
.75868 .43515 m .7499 .42804 L .72937 .44074 L p F P
0 0 0 r
s
.306 1 0 r
.46438 .52651 m .47601 .5199 L .49566 .53216 L p F P
0 0 0 r
s
.717 1 0 r
.47601 .5199 m .46438 .52651 L .44507 .51106 L p F P
0 0 0 r
s
1 .465 0 r
.35276 .46141 m .34052 .45011 L .322 .44532 L p F P
0 0 0 r
s
1 .477 0 r
.30964 .43245 m .322 .44532 L .34052 .45011 L p F P
0 0 0 r
s
1 .28 0 r
.322 .44532 m .30964 .43245 L .29104 .43193 L p F P
0 0 0 r
s
1 .036 0 r
.82124 .40702 m .82986 .41893 L .85101 .41118 L p F P
0 0 0 r
s
1 .06 0 r
.82986 .41893 m .82124 .40702 L .8002 .41582 L p F P
0 0 0 r
s
.926 1 0 r
.66831 .47975 m .65933 .48762 L .63887 .50108 L p F P
0 0 0 r
s
1 .273 0 r
.27849 .41846 m .29104 .43193 L .30964 .43245 L p F P
0 0 0 r
s
1 .152 0 r
.29104 .43193 m .27849 .41846 L .25979 .42119 L p F P
0 0 0 r
s
1 .005 0 r
.87235 .40362 m .8807 .41646 L .90211 .40923 L p F P
0 0 0 r
s
1 .011 0 r
.8807 .41646 m .87235 .40362 L .85101 .41118 L p F P
0 0 0 r
s
1 .946 0 r
.41419 .4967 m .40212 .49288 L .38344 .47923 L p F P
0 0 0 r
s
.389 1 0 r
.43315 .51263 m .44507 .51106 L .46438 .52651 L p F P
0 0 0 r
s
.841 1 0 r
.44507 .51106 m .43315 .51263 L .41419 .4967 L p F P
0 0 0 r
s
.306 1 0 r
.56742 .53854 m .57757 .52124 L .59793 .51815 L p F P
0 0 0 r
s
.43 1 0 r
.57757 .52124 m .56742 .53854 L .54694 .53557 L p F P
0 0 0 r
s
.616 1 0 r
.40212 .49288 m .41419 .4967 L .43315 .51263 L p F P
0 0 0 r
s
1 .152 0 r
.77059 .4162 m .77935 .42518 L .8002 .41582 L p F P
0 0 0 r
s
1 .223 0 r
.77935 .42518 m .77059 .4162 L .7499 .42804 L p F P
0 0 0 r
s
1 .14 0 r
.24701 .40762 m .25979 .42119 L .27849 .41846 L p F P
0 0 0 r
s
1 .793 0 r
.67975 .472 m .68861 .46722 L .70896 .45398 L p F P
0 0 0 r
s
1 .793 0 r
.70896 .45398 m .70015 .45534 L .67975 .472 L p F P
0 0 0 r
s
.841 1 0 r
.67975 .472 m .70015 .45534 L p .6953 .45976 L F P
0 0 0 r
s
1 .946 0 r
.68861 .46722 m .67975 .472 L p .6643 .48416 L F P
0 0 0 r
s
.841 1 0 r
.6709 .48197 m .67975 .472 L p .69101 .46314 L F P
0 0 0 r
s
.841 1 0 r
.6709 .48197 m .69101 .46314 L .68806 .46635 L F
.68806 .46635 m .69101 .46314 L .6953 .45976 L F
.70015 .45534 m .69136 .46083 L .6709 .48197 L p F P
0 0 0 r
s
.389 1 0 r
.6709 .48197 m .68695 .46539 L p .66267 .49594 L F P
0 0 0 r
s
.389 1 0 r
.66267 .49594 m .68695 .46539 L .68291 .47118 L F
.68695 .46539 m .69136 .46083 L p .68291 .47118 L F P
0 0 0 r
s
.389 1 0 r
.69136 .46083 m .68253 .47014 L .6718 .48406 L p F P
0 0 0 r
s
.389 1 0 r
.66198 .49679 m .66208 .49662 L p .66267 .49594 L F P
0 0 0 r
s
.389 1 0 r
.66208 .49662 m .6709 .48197 L p .66267 .49594 L F P
0 0 0 r
s
.389 1 0 r
.6718 .48406 m .66198 .49679 L p .67714 .47824 L F P
0 0 0 r
s
.389 1 0 r
.67714 .47824 m .69136 .46083 L .6718 .48406 L F
0 1 .127 r
.66198 .49679 m .68224 .47051 L p .6537 .51385 L F P
0 0 0 r
s
0 1 .127 r
.6537 .51385 m .68224 .47051 L .68175 .47132 L F
.68224 .47051 m .68253 .47014 L p .68175 .47132 L F P
0 0 0 r
s
0 1 .127 r
.68253 .47014 m .67353 .48211 L .65836 .50634 L p F P
0 0 0 r
s
0 1 .127 r
.65288 .51509 m .65301 .51483 L p .6537 .51385 L F P
0 0 0 r
s
0 1 .127 r
.65301 .51483 m .66198 .49679 L p .6537 .51385 L F P
0 0 0 r
s
0 1 .127 r
.65836 .50634 m .65288 .51509 L p .66362 .49881 L F P
0 0 0 r
s
0 1 .127 r
.66362 .49881 m .68253 .47014 L .65836 .50634 L F
0 1 .671 r
.64345 .53426 m .65288 .51509 L .67353 .48211 L p F P
0 0 0 r
s
0 1 .671 r
.67353 .48211 m .66426 .49464 L .64381 .53359 L p F P
0 0 0 r
s
0 1 .671 r
.64381 .53359 m .64345 .53426 L p .64446 .53251 L F P
0 0 0 r
s
0 1 .671 r
.64446 .53251 m .67353 .48211 L .64381 .53359 L F
1 .923 0 r
.72059 .43873 m .71181 .43981 L .69136 .46083 L p F P
0 0 0 r
s
1 .923 0 r
.69136 .46083 m .70015 .45534 L .71439 .44376 L p F P
0 0 0 r
s
1 .923 0 r
.69136 .46083 m .71439 .44376 L .71022 .44657 L F
.717 1 0 r
.68253 .47014 m .69136 .46083 L .70838 .44334 L p F P
0 0 0 r
s
.717 1 0 r
.70838 .44334 m .71181 .43981 L p .70479 .44708 L F P
0 0 0 r
s
.717 1 0 r
.68253 .47014 m .70838 .44334 L .70479 .44708 L F
.70298 .44374 m .69054 .45979 L p .71131 .44033 L F P
0 0 0 r
s
.717 1 0 r
.69054 .45979 m .68253 .47014 L p .69617 .45601 L F P
0 0 0 r
s
.717 1 0 r
.69617 .45601 m .71131 .44033 L .69054 .45979 L F
.306 1 0 r
.67353 .48211 m .68253 .47014 L .70298 .44374 L p F P
0 0 0 r
s
.306 1 0 r
.69402 .44958 m .67799 .47503 L p .70237 .44453 L F P
0 0 0 r
s
.306 1 0 r
.67799 .47503 m .67353 .48211 L p .68288 .46994 L F P
0 0 0 r
s
.306 1 0 r
.68288 .46994 m .70237 .44453 L .67799 .47503 L F
1 .923 0 r
.71439 .44376 m .72059 .43873 L p .71022 .44657 L F P
0 0 0 r
s
.306 1 0 r
.70298 .44374 m .70288 .4438 L p .70237 .44453 L F P
0 0 0 r
s
.306 1 0 r
.70288 .4438 m .69402 .44958 L p .70237 .44453 L F P
0 0 0 r
s
.717 1 0 r
.71181 .43981 m .71173 .43985 L p .71131 .44033 L F P
0 0 0 r
s
.717 1 0 r
.71173 .43985 m .70298 .44374 L p .71131 .44033 L F P
0 0 0 r
s
1 .946 0 r
.67975 .472 m .65933 .48762 L p .6643 .48416 L F P
0 0 0 r
s
.077 1 0 r
.51571 .5448 m .52673 .5296 L .54694 .53557 L p F P
0 0 0 r
s
.389 1 0 r
.52673 .5296 m .51571 .5448 L .49566 .53216 L p F P
0 0 0 r
s
1 .02 0 r
.84248 .3987 m .85101 .41118 L .87235 .40362 L p F P
0 0 0 r
s
1 .036 0 r
.85101 .41118 m .84248 .3987 L .82124 .40702 L p F P
0 0 0 r
s
1 .631 0 r
.70015 .45534 m .70896 .45398 L .72937 .44074 L p F P
0 0 0 r
s
1 .005 0 r
.90211 .40923 m .89388 .39618 L .87235 .40362 L p F P
0 0 0 r
s
1 .098 0 r
.79146 .40536 m .8002 .41582 L .82124 .40702 L p F P
0 0 0 r
s
1 .152 0 r
.8002 .41582 m .79146 .40536 L .77059 .4162 L p F P
0 0 0 r
s
1 .477 0 r
.72059 .43873 m .72937 .44074 L .7499 .42804 L p F P
0 0 0 r
s
1 .631 0 r
.72937 .44074 m .72059 .43873 L .70015 .45534 L p F P
0 0 0 r
s
.262 1 0 r
.58811 .53707 m .59793 .51815 L .61839 .51144 L p F P
0 0 0 r
s
.306 1 0 r
.59793 .51815 m .58811 .53707 L .56742 .53854 L p F P
0 0 0 r
s
1 .477 0 r
.34052 .45011 m .3282 .43717 L .30964 .43245 L p F P
0 0 0 r
s
1 .465 0 r
.29718 .41851 m .30964 .43245 L .3282 .43717 L p F P
0 0 0 r
s
1 .273 0 r
.30964 .43245 m .29718 .41851 L .27849 .41846 L p F P
0 0 0 r
s
1 .253 0 r
.26581 .40437 m .27849 .41846 L .29718 .41851 L p F P
0 0 0 r
s
1 .14 0 r
.27849 .41846 m .26581 .40437 L .24701 .40762 L p F P
0 0 0 r
s
1 .773 0 r
.3282 .43717 m .34052 .45011 L .35904 .46047 L p F P
0 0 0 r
s
1 .011 0 r
.86391 .39074 m .87235 .40362 L .89388 .39618 L p F P
0 0 0 r
s
1 .02 0 r
.87235 .40362 m .86391 .39074 L .84248 .3987 L p F P
0 0 0 r
s
1 .343 0 r
.74111 .42298 m .7499 .42804 L .77059 .4162 L p F P
0 0 0 r
s
1 .477 0 r
.7499 .42804 m .74111 .42298 L .72059 .43873 L p F P
0 0 0 r
s
1 .06 0 r
.81254 .39547 m .82124 .40702 L .84248 .3987 L p F P
0 0 0 r
s
1 .098 0 r
.82124 .40702 m .81254 .39547 L .79146 .40536 L p F P
0 0 0 r
s
0 1 .127 r
.4841 .54467 m .49566 .53216 L .51571 .5448 L p F P
0 0 0 r
s
.306 1 0 r
.49566 .53216 m .4841 .54467 L .46438 .52651 L p F P
0 0 0 r
s
1 .123 0 r
.23406 .3937 m .24701 .40762 L .26581 .40437 L p F P
0 0 0 r
s
.306 1 0 r
.60889 .53031 m .61839 .51144 L .63887 .50108 L p F P
0 0 0 r
s
.262 1 0 r
.61839 .51144 m .60889 .53031 L .58811 .53707 L p F P
0 0 0 r
s
1 .234 0 r
.76179 .40859 m .77059 .4162 L .79146 .40536 L p F P
0 0 0 r
s
1 .343 0 r
.77059 .4162 m .76179 .40859 L .74111 .42298 L p F P
0 0 0 r
s
0 1 .182 r
.53617 .55565 m .54694 .53557 L .56742 .53854 L p F P
0 0 0 r
s
.077 1 0 r
.54694 .53557 m .53617 .55565 L .51571 .5448 L p F P
0 0 0 r
s
1 .034 0 r
.83384 .38636 m .84248 .3987 L .86391 .39074 L p F P
0 0 0 r
s
1 .06 0 r
.84248 .3987 m .83384 .38636 L .81254 .39547 L p F P
0 0 0 r
s
.616 1 0 r
.43315 .51263 m .42099 .51276 L .40212 .49288 L p F P
0 0 0 r
s
.43 1 0 r
.38989 .48685 m .40212 .49288 L .42099 .51276 L p F P
0 0 0 r
s
1 .011 0 r
.89388 .39618 m .88553 .38301 L .86391 .39074 L p F P
0 0 0 r
s
0 1 .127 r
.45243 .53343 m .46438 .52651 L .4841 .54467 L p F P
0 0 0 r
s
.389 1 0 r
.46438 .52651 m .45243 .53343 L .43315 .51263 L p F P
0 0 0 r
s
1 .152 0 r
.78267 .39575 m .79146 .40536 L .81254 .39547 L p F P
0 0 0 r
s
1 .234 0 r
.79146 .40536 m .78267 .39575 L .76179 .40859 L p F P
0 0 0 r
s
.43 1 0 r
.62966 .51824 m .63887 .50108 L .65933 .48762 L p F P
0 0 0 r
s
.306 1 0 r
.63887 .50108 m .62966 .51824 L .60889 .53031 L p F P
0 0 0 r
s
.077 1 0 r
.42099 .51276 m .43315 .51263 L .45243 .53343 L p F P
0 0 0 r
s
1 .465 0 r
.3282 .43717 m .31581 .42257 L .29718 .41851 L p F P
0 0 0 r
s
1 .431 0 r
.2846 .40363 m .29718 .41851 L .31581 .42257 L p F P
0 0 0 r
s
1 .253 0 r
.29718 .41851 m .2846 .40363 L .26581 .40437 L p F P
0 0 0 r
s
1 .222 0 r
.25298 .38979 m .26581 .40437 L .2846 .40363 L p F P
0 0 0 r
s
1 .123 0 r
.26581 .40437 m .25298 .38979 L .23406 .3937 L p F P
0 0 0 r
s
.616 1 0 r
.65034 .50166 m .65933 .48762 L .67975 .472 L p F P
0 0 0 r
s
.43 1 0 r
.65933 .48762 m .65034 .50166 L .62966 .51824 L p F P
0 0 0 r
s
1 .773 0 r
.35904 .46047 m .34673 .44748 L .3282 .43717 L p F P
0 0 0 r
s
1 .753 0 r
.31581 .42257 m .3282 .43717 L .34673 .44748 L p F P
0 0 0 r
s
1 .018 0 r
.85536 .37785 m .86391 .39074 L .88553 .38301 L p F P
0 0 0 r
s
1 .034 0 r
.86391 .39074 m .85536 .37785 L .83384 .38636 L p F P
0 0 0 r
s
.616 1 0 r
.67975 .472 m .6709 .48197 L .65034 .50166 L p F P
0 0 0 r
s
1 .093 0 r
.80377 .38436 m .81254 .39547 L .83384 .38636 L p F P
0 0 0 r
s
1 .152 0 r
.81254 .39547 m .80377 .38436 L .78267 .39575 L p F P
0 0 0 r
s
1 .103 0 r
.22094 .3795 m .23406 .3937 L .25298 .38979 L p F P
0 0 0 r
s
1 .698 0 r
.71181 .43981 m .72059 .43873 L .74111 .42298 L p F P
0 0 0 r
s
1 .502 0 r
.73231 .42011 m .74111 .42298 L .76179 .40859 L p F P
0 0 0 r
s
1 .698 0 r
.74111 .42298 m .73231 .42011 L .71181 .43981 L p F P
0 0 0 r
s
0 1 .354 r
.55698 .56239 m .56742 .53854 L .58811 .53707 L p F P
0 0 0 r
s
0 1 .182 r
.56742 .53854 m .55698 .56239 L .53617 .55565 L p F P
0 0 0 r
s
1 .018 0 r
.88553 .38301 m .87708 .36975 L .85536 .37785 L p F P
0 0 0 r
s
1 .054 0 r
.82512 .37421 m .83384 .38636 L .85536 .37785 L p F P
0 0 0 r
s
1 .093 0 r
.83384 .38636 m .82512 .37421 L .80377 .38436 L p F P
0 0 0 r
s
0 1 .54 r
.5043 .56342 m .51571 .5448 L .53617 .55565 L p F P
0 0 0 r
s
0 1 .127 r
.51571 .5448 m .5043 .56342 L .4841 .54467 L p F P
0 0 0 r
s
1 .343 0 r
.75296 .40244 m .76179 .40859 L .78267 .39575 L p F P
0 0 0 r
s
1 .502 0 r
.76179 .40859 m .75296 .40244 L .73231 .42011 L p F P
0 0 0 r
s
1 .431 0 r
.31581 .42257 m .30335 .4065 L .2846 .40363 L p F P
0 0 0 r
s
1 .38 0 r
.2719 .38804 m .2846 .40363 L .30335 .4065 L p F P
0 0 0 r
s
1 .222 0 r
.2846 .40363 m .2719 .38804 L .25298 .38979 L p F P
0 0 0 r
s
.43 1 0 r
.42099 .51276 m .40868 .50977 L .38989 .48685 L p F P
0 0 0 r
s
1 .186 0 r
.23998 .37487 m .25298 .38979 L .2719 .38804 L p F P
0 0 0 r
s
1 .103 0 r
.25298 .38979 m .23998 .37487 L .22094 .3795 L p F P
0 0 0 r
s
1 .223 0 r
.77381 .38702 m .78267 .39575 L .80377 .38436 L p F P
0 0 0 r
s
1 .343 0 r
.78267 .39575 m .77381 .38702 L .75296 .40244 L p F P
0 0 0 r
s
1 .753 0 r
.34673 .44748 m .3344 .43193 L .31581 .42257 L p F P
0 0 0 r
s
1 .698 0 r
.30335 .4065 m .31581 .42257 L .3344 .43193 L p F P
0 0 0 r
s
1 .029 0 r
.8467 .36499 m .85536 .37785 L .87708 .36975 L p F P
0 0 0 r
s
1 .054 0 r
.85536 .37785 m .8467 .36499 L .82512 .37421 L p F P
0 0 0 r
s
1 .082 0 r
.20763 .36511 m .22094 .3795 L .23998 .37487 L p F P
0 0 0 r
s
0 1 .414 r
.57805 .56297 m .58811 .53707 L .60889 .53031 L p F P
0 0 0 r
s
0 1 .354 r
.58811 .53707 m .57805 .56297 L .55698 .56239 L p F P
0 0 0 r
s
1 .137 0 r
.79492 .37375 m .80377 .38436 L .82512 .37421 L p F P
0 0 0 r
s
1 .223 0 r
.80377 .38436 m .79492 .37375 L .77381 .38702 L p F P
0 0 0 r
s
.077 1 0 r
.45243 .53343 m .44021 .5385 L .42099 .51276 L p F P
0 0 0 r
s
0 1 .182 r
.40868 .50977 m .42099 .51276 L .44021 .5385 L p F P
0 0 0 r
s
0 1 .671 r
.47217 .55772 m .4841 .54467 L .5043 .56342 L p F P
0 0 0 r
s
0 1 .127 r
.4841 .54467 m .47217 .55772 L .45243 .53343 L p F P
0 0 0 r
s
.841 1 0 r
.3344 .43193 m .34673 .44748 L .36527 .46459 L p F P
0 0 0 r
s
0 1 .54 r
.44021 .5385 m .45243 .53343 L .47217 .55772 L p F P
0 0 0 r
s
1 .029 0 r
.87708 .36975 m .86851 .35641 L .8467 .36499 L p F P
0 0 0 r
s
1 .08 0 r
.8163 .36227 m .82512 .37421 L .8467 .36499 L p F P
0 0 0 r
s
1 .137 0 r
.82512 .37421 m .8163 .36227 L .79492 .37375 L p F P
0 0 0 r
s
1 .38 0 r
.30335 .4065 m .29079 .38936 L .2719 .38804 L p F P
0 0 0 r
s
1 .318 0 r
.25905 .37198 m .2719 .38804 L .29079 .38936 L p F P
0 0 0 r
s
1 .186 0 r
.2719 .38804 m .25905 .37198 L .23998 .37487 L p F P
0 0 0 r
s
0 1 .354 r
.59921 .55618 m .60889 .53031 L .62966 .51824 L p F P
0 0 0 r
s
0 1 .414 r
.60889 .53031 m .59921 .55618 L .57805 .56297 L p F P
0 0 0 r
s
1 .698 0 r
.3344 .43193 m .32204 .41415 L .30335 .4065 L p F P
0 0 0 r
s
1 .615 0 r
.29079 .38936 m .30335 .4065 L .32204 .41415 L p F P
0 0 0 r
s
1 .148 0 r
.22681 .35976 m .23998 .37487 L .25905 .37198 L p F P
0 0 0 r
s
1 .082 0 r
.23998 .37487 m .22681 .35976 L .20763 .36511 L p F P
0 0 0 r
s
1 .698 0 r
.72345 .41923 m .73231 .42011 L .75296 .40244 L p F P
0 0 0 r
s
1 .971 0 r
.73231 .42011 m .72345 .41923 L .70298 .44374 L p F P
0 0 0 r
s
1 .971 0 r
.70298 .44374 m .71181 .43981 L .73231 .42011 L p F P
0 0 0 r
s
0 1 .882 r
.52501 .57994 m .53617 .55565 L .55698 .56239 L p F P
0 0 0 r
s
0 1 .54 r
.53617 .55565 m .52501 .57994 L .5043 .56342 L p F P
0 0 0 r
s
1 .477 0 r
.74405 .39758 m .75296 .40244 L .77381 .38702 L p F P
0 0 0 r
s
1 .698 0 r
.75296 .40244 m .74405 .39758 L .72345 .41923 L p F P
0 0 0 r
s
0 1 .182 r
.62031 .54198 m .62966 .51824 L .65034 .50166 L p F P
0 0 0 r
s
0 1 .354 r
.62966 .51824 m .62031 .54198 L .59921 .55618 L p F P
0 0 0 r
s
1 .044 0 r
.83794 .35215 m .8467 .36499 L .86851 .35641 L p F P
0 0 0 r
s
1 .08 0 r
.8467 .36499 m .83794 .35215 L .8163 .36227 L p F P
0 0 0 r
s
1 .061 0 r
.19413 .35059 m .20763 .36511 L .22681 .35976 L p F P
0 0 0 r
s
1 .31 0 r
.76487 .37908 m .77381 .38702 L .79492 .37375 L p F P
0 0 0 r
s
1 .477 0 r
.77381 .38702 m .76487 .37908 L .74405 .39758 L p F P
0 0 0 r
s
.077 1 0 r
.6709 .48197 m .66198 .49679 L .64125 .52152 L p F P
0 0 0 r
s
.077 1 0 r
.64125 .52152 m .65034 .50166 L .6709 .48197 L p F P
0 0 0 r
s
0 1 .182 r
.65034 .50166 m .64125 .52152 L .62031 .54198 L p F P
0 0 0 r
s
.841 1 0 r
.36527 .46459 m .35298 .44774 L .3344 .43193 L p F P
0 0 0 r
s
.926 1 0 r
.32204 .41415 m .3344 .43193 L .35298 .44774 L p F P
0 0 0 r
s
1 .191 0 r
.78597 .36354 m .79492 .37375 L .8163 .36227 L p F P
0 0 0 r
s
1 .31 0 r
.79492 .37375 m .78597 .36354 L .76487 .37908 L p F P
0 0 0 r
s
1 .318 0 r
.29079 .38936 m .27812 .37159 L .25905 .37198 L p F P
0 0 0 r
s
1 .253 0 r
.24604 .35573 m .25905 .37198 L .27812 .37159 L p F P
0 0 0 r
s
1 .148 0 r
.25905 .37198 m .24604 .35573 L .22681 .35976 L p F P
0 0 0 r
s
1 .044 0 r
.86851 .35641 m .85983 .34299 L .83794 .35215 L p F P
0 0 0 r
s
1 .615 0 r
.32204 .41415 m .30965 .39476 L .29079 .38936 L p F P
0 0 0 r
s
1 .515 0 r
.27812 .37159 m .29079 .38936 L .30965 .39476 L p F P
0 0 0 r
s
1 .111 0 r
.80737 .35048 m .8163 .36227 L .83794 .35215 L p F P
0 0 0 r
s
1 .191 0 r
.8163 .36227 m .80737 .35048 L .78597 .36354 L p F P
0 0 0 r
s
0 1 .182 r
.44021 .5385 m .4278 .53933 L .40868 .50977 L p F P
0 0 0 r
s
0 1 .354 r
.39629 .5022 m .40868 .50977 L .4278 .53933 L p F P
0 0 0 r
s
1 .111 0 r
.21344 .34456 m .22681 .35976 L .24604 .35573 L p F P
0 0 0 r
s
1 .061 0 r
.22681 .35976 m .21344 .34456 L .19413 .35059 L p F P
0 0 0 r
s
0 .811 1 r
.49248 .58292 m .5043 .56342 L .52501 .57994 L p F P
0 0 0 r
s
0 1 .671 r
.5043 .56342 m .49248 .58292 L .47217 .55772 L p F P
0 0 0 r
s
.926 1 0 r
.35298 .44774 m .34073 .42759 L .32204 .41415 L p F P
0 0 0 r
s
1 .946 0 r
.30965 .39476 m .32204 .41415 L .34073 .42759 L p F P
0 0 0 r
s
0 .891 1 r
.54616 .59107 m .55698 .56239 L .57805 .56297 L p F P
0 0 0 r
s
0 1 .882 r
.55698 .56239 m .54616 .59107 L .52501 .57994 L p F P
0 0 0 r
s
1 .044 0 r
.18042 .33596 m .19413 .35059 L .21344 .34456 L p F P
0 0 0 r
s
1 .061 0 r
.82906 .33932 m .83794 .35215 L .85983 .34299 L p F P
0 0 0 r
s
1 .111 0 r
.83794 .35215 m .82906 .33932 L .80737 .35048 L p F P
0 0 0 r
s
0 1 .54 r
.47217 .55772 m .45992 .56848 L .44021 .5385 L p F P
0 0 0 r
s
0 1 .882 r
.4278 .53933 m .44021 .5385 L .45992 .56848 L p F P
0 0 0 r
s
1 .631 0 r
.73503 .39353 m .74405 .39758 L .76487 .37908 L p F P
0 0 0 r
s
1 .923 0 r
.74405 .39758 m .73503 .39353 L .71447 .41965 L p F P
0 0 0 r
s
1 .923 0 r
.71447 .41965 m .72345 .41923 L .74405 .39758 L p F P
0 0 0 r
s
1 .41 0 r
.75582 .37158 m .76487 .37908 L .78597 .36354 L p F P
0 0 0 r
s
1 .631 0 r
.76487 .37908 m .75582 .37158 L .73503 .39353 L p F P
0 0 0 r
s
0 .811 1 r
.45992 .56848 m .47217 .55772 L .49248 .58292 L p F P
0 0 0 r
s
1 .515 0 r
.30965 .39476 m .29717 .37448 L .27812 .37159 L p F P
0 0 0 r
s
1 .41 0 r
.26529 .35363 m .27812 .37159 L .29717 .37448 L p F P
0 0 0 r
s
1 .253 0 r
.27812 .37159 m .26529 .35363 L .24604 .35573 L p F P
0 0 0 r
s
1 .191 0 r
.23283 .33949 m .24604 .35573 L .26529 .35363 L p F P
0 0 0 r
s
1 .111 0 r
.24604 .35573 m .23283 .33949 L .21344 .34456 L p F P
0 0 0 r
s
.717 1 0 r
.72345 .41923 m .71447 .41965 L .69402 .44958 L p F P
0 0 0 r
s
.717 1 0 r
.69402 .44958 m .70298 .44374 L .72345 .41923 L p F P
0 0 0 r
s
1 .253 0 r
.7769 .35353 m .78597 .36354 L .80737 .35048 L p F P
0 0 0 r
s
1 .41 0 r
.78597 .36354 m .7769 .35353 L .75582 .37158 L p F P
0 0 0 r
s
1 .061 0 r
.85983 .34299 m .85103 .32947 L .82906 .33932 L p F P
0 0 0 r
s
1 .08 0 r
.19986 .32935 m .21344 .34456 L .23283 .33949 L p F P
0 0 0 r
s
1 .044 0 r
.21344 .34456 m .19986 .32935 L .18042 .33596 L p F P
0 0 0 r
s
1 .946 0 r
.34073 .42759 m .3285 .40508 L .30965 .39476 L p F P
0 0 0 r
s
1 .793 0 r
.29717 .37448 m .30965 .39476 L .3285 .40508 L p F P
0 0 0 r
s
1 .148 0 r
.79832 .33873 m .80737 .35048 L .82906 .33932 L p F P
0 0 0 r
s
1 .253 0 r
.80737 .35048 m .79832 .33873 L .7769 .35353 L p F P
0 0 0 r
s
.43 1 0 r
.34073 .42759 m .35298 .44774 L .37166 .47062 L p F P
0 0 0 r
s
0 .811 1 r
.56763 .59406 m .57805 .56297 L .59921 .55618 L p F P
0 0 0 r
s
0 .891 1 r
.57805 .56297 m .56763 .59406 L .54616 .59107 L p F P
0 0 0 r
s
0 1 .354 r
.4278 .53933 m .41532 .53387 L .39629 .5022 L p F P
0 0 0 r
s
1 .029 0 r
.16649 .32124 m .18042 .33596 L .19986 .32935 L p F P
0 0 0 r
s
1 .082 0 r
.82006 .32641 m .82906 .33932 L .85103 .32947 L p F P
0 0 0 r
s
1 .148 0 r
.82906 .33932 m .82006 .32641 L .79832 .33873 L p F P
0 0 0 r
s
1 .41 0 r
.29717 .37448 m .28456 .35404 L .26529 .35363 L p F P
0 0 0 r
s
1 .31 0 r
.25227 .33582 m .26529 .35363 L .28456 .35404 L p F P
0 0 0 r
s
1 .191 0 r
.26529 .35363 m .25227 .33582 L .23283 .33949 L p F P
0 0 0 r
s
1 .137 0 r
.21941 .32339 m .23283 .33949 L .25227 .33582 L p F P
0 0 0 r
s
1 .08 0 r
.23283 .33949 m .21941 .32339 L .19986 .32935 L p F P
0 0 0 r
s
0 1 .54 r
.66198 .49679 m .65288 .51509 L .63194 .54563 L p F P
0 0 0 r
s
0 1 .54 r
.63194 .54563 m .64125 .52152 L .66198 .49679 L p F P
0 0 0 r
s
1 .793 0 r
.3285 .40508 m .31623 .38135 L .29717 .37448 L p F P
0 0 0 r
s
1 .631 0 r
.28456 .35404 m .29717 .37448 L .31623 .38135 L p F P
0 0 0 r
s
0 .891 1 r
.58921 .58725 m .59921 .55618 L .62031 .54198 L p F P
0 0 0 r
s
0 .811 1 r
.59921 .55618 m .58921 .58725 L .56763 .59406 L p F P
0 0 0 r
s
.43 1 0 r
.37166 .47062 m .3595 .44734 L .34073 .42759 L p F P
0 0 0 r
s
.616 1 0 r
.3285 .40508 m .34073 .42759 L .3595 .44734 L p F P
0 0 0 r
s
0 .381 1 r
.5134 .60543 m .52501 .57994 L .54616 .59107 L p F P
0 0 0 r
s
0 .811 1 r
.52501 .57994 m .5134 .60543 L .49248 .58292 L p F P
0 0 0 r
s
0 1 .882 r
.64125 .52152 m .63194 .54563 L .6107 .57059 L p F P
0 0 0 r
s
0 1 .882 r
.6107 .57059 m .62031 .54198 L .64125 .52152 L p F P
0 0 0 r
s
1 .054 0 r
.18606 .31415 m .19986 .32935 L .21941 .32339 L p F P
0 0 0 r
s
1 .029 0 r
.19986 .32935 m .18606 .31415 L .16649 .32124 L p F P
0 0 0 r
s
1 .082 0 r
.85103 .32947 m .8421 .31581 L .82006 .32641 L p F P
0 0 0 r
s
1 .515 0 r
.74658 .36397 m .75582 .37158 L .7769 .35353 L p F P
0 0 0 r
s
1 .793 0 r
.75582 .37158 m .74658 .36397 L .72581 .38945 L p F P
0 0 0 r
s
1 .793 0 r
.72581 .38945 m .73503 .39353 L .75582 .37158 L p F P
0 0 0 r
s
0 .891 1 r
.62031 .54198 m .6107 .57059 L .58921 .58725 L p F P
0 0 0 r
s
1 .318 0 r
.76767 .34336 m .7769 .35353 L .79832 .33873 L p F P
0 0 0 r
s
1 .515 0 r
.7769 .35353 m .76767 .34336 L .74658 .36397 L p F P
0 0 0 r
s
.841 1 0 r
.73503 .39353 m .72581 .38945 L .70526 .42017 L p F P
0 0 0 r
s
.841 1 0 r
.70526 .42017 m .71447 .41965 L .73503 .39353 L p F P
0 0 0 r
s
1 .002 0 r
.39361 1.05425 m .40598 1.06315 L .42658 1.05834 L p F P
0 0 0 r
s
0 1 .882 r
.45992 .56848 m .44744 .57377 L .4278 .53933 L p F P
0 0 0 r
s
0 .891 1 r
.41532 .53387 m .4278 .53933 L .44744 .57377 L p F P
0 0 0 r
s
1 .186 0 r
.78911 .32679 m .79832 .33873 L .82006 .32641 L p F P
0 0 0 r
s
1 .318 0 r
.79832 .33873 m .78911 .32679 L .76767 .34336 L p F P
0 0 0 r
s
1 .018 0 r
.15234 .30643 m .16649 .32124 L .18606 .31415 L p F P
0 0 0 r
s
1 .31 0 r
.28456 .35404 m .27176 .33398 L .25227 .33582 L p F P
0 0 0 r
s
1 .223 0 r
.23903 .31838 m .25227 .33582 L .27176 .33398 L p F P
0 0 0 r
s
1 .137 0 r
.25227 .33582 m .23903 .31838 L .21941 .32339 L p F P
0 0 0 r
s
.389 1 0 r
.71447 .41965 m .70526 .42017 L .6848 .45572 L p F P
0 0 0 r
s
.389 1 0 r
.6848 .45572 m .69402 .44958 L .71447 .41965 L p F P
0 0 0 r
s
.616 1 0 r
.3595 .44734 m .34742 .42074 L .3285 .40508 L p F P
0 0 0 r
s
.841 1 0 r
.31623 .38135 m .3285 .40508 L .34742 .42074 L p F P
0 0 0 r
s
1 .631 0 r
.31623 .38135 m .30386 .35749 L .28456 .35404 L p F P
0 0 0 r
s
1 .477 0 r
.27176 .33398 m .28456 .35404 L .30386 .35749 L p F P
0 0 0 r
s
1 .093 0 r
.20575 .30746 m .21941 .32339 L .23903 .31838 L p F P
0 0 0 r
s
1 .054 0 r
.21941 .32339 m .20575 .30746 L .18606 .31415 L p F P
0 0 0 r
s
1 .103 0 r
.81091 .3133 m .82006 .32641 L .8421 .31581 L p F P
0 0 0 r
s
1 .186 0 r
.82006 .32641 m .81091 .3133 L .78911 .32679 L p F P
0 0 0 r
s
1 .005 0 r
.41432 1.04937 m .42658 1.05834 L .44735 1.0535 L p F P
0 0 0 r
s
1 .002 0 r
.42658 1.05834 m .41432 1.04937 L .39361 1.05425 L p F P
0 0 0 r
s
0 .194 1 r
.48028 .5997 m .49248 .58292 L .5134 .60543 L p F P
0 0 0 r
s
0 .811 1 r
.49248 .58292 m .48028 .5997 L .45992 .56848 L p F P
0 0 0 r
s
0 .381 1 r
.44744 .57377 m .45992 .56848 L .48028 .5997 L p F P
0 0 0 r
s
0 1 .127 r
.69402 .44958 m .6848 .45572 L .66426 .49464 L p F P
0 0 0 r
s
0 1 .127 r
.66426 .49464 m .67353 .48211 L .69402 .44958 L p F P
0 0 0 r
s
1 .034 0 r
.17204 .29894 m .18606 .31415 L .20575 .30746 L p F P
0 0 0 r
s
1 .018 0 r
.18606 .31415 m .17204 .29894 L .15234 .30643 L p F P
0 0 0 r
s
.841 1 0 r
.34742 .42074 m .33537 .39249 L .31623 .38135 L p F P
0 0 0 r
s
1 .923 0 r
.30386 .35749 m .31623 .38135 L .33537 .39249 L p F P
0 0 0 r
s
1 .103 0 r
.8421 .31581 m .83304 .30195 L .81091 .3133 L p F P
0 0 0 r
s
1 .005 0 r
.38105 1.04521 m .39361 1.05425 L .41432 1.04937 L p F P
0 0 0 r
s
0 .096 1 r
.53487 .62125 m .54616 .59107 L .56763 .59406 L p F P
0 0 0 r
s
0 .381 1 r
.54616 .59107 m .53487 .62125 L .5134 .60543 L p F P
0 0 0 r
s
1 .011 0 r
.43519 1.04445 m .44735 1.0535 L .46829 1.04862 L p F P
0 0 0 r
s
1 .005 0 r
.44735 1.0535 m .43519 1.04445 L .41432 1.04937 L p F P
0 0 0 r
s
1 .477 0 r
.30386 .35749 m .29131 .33433 L .27176 .33398 L p F P
0 0 0 r
s
1 .343 0 r
.25874 .31463 m .27176 .33398 L .29131 .33433 L p F P
0 0 0 r
s
1 .223 0 r
.27176 .33398 m .25874 .31463 L .23903 .31838 L p F P
0 0 0 r
s
1 .38 0 r
.75824 .33259 m .76767 .34336 L .78911 .32679 L p F P
0 0 0 r
s
1 .615 0 r
.76767 .34336 m .75824 .33259 L .73712 .35554 L p F P
0 0 0 r
s
1 .615 0 r
.73712 .35554 m .74658 .36397 L .76767 .34336 L p F P
0 0 0 r
s
1 .152 0 r
.22555 .30139 m .23903 .31838 L .25874 .31463 L p F P
0 0 0 r
s
1 .093 0 r
.23903 .31838 m .22555 .30139 L .20575 .30746 L p F P
0 0 0 r
s
1 .946 0 r
.74658 .36397 m .73712 .35554 L .71632 .38425 L p F P
0 0 0 r
s
1 .946 0 r
.71632 .38425 m .72581 .38945 L .74658 .36397 L p F P
0 0 0 r
s
1 .011 0 r
.13797 .29149 m .15234 .30643 L .17204 .29894 L p F P
0 0 0 r
s
1 .222 0 r
.77973 .3144 m .78911 .32679 L .81091 .3133 L p F P
0 0 0 r
s
1 .38 0 r
.78911 .32679 m .77973 .3144 L .75824 .33259 L p F P
0 0 0 r
s
1 .06 0 r
.19186 .29169 m .20575 .30746 L .22555 .30139 L p F P
0 0 0 r
s
1 .034 0 r
.20575 .30746 m .19186 .29169 L .17204 .29894 L p F P
0 0 0 r
s
0 .891 1 r
.44744 .57377 m .43487 .57078 L .41532 .53387 L p F P
0 0 0 r
s
1 .923 0 r
.33537 .39249 m .32325 .36418 L .30386 .35749 L p F P
0 0 0 r
s
1 .698 0 r
.29131 .33433 m .30386 .35749 L .32325 .36418 L p F P
0 0 0 r
s
.616 1 0 r
.72581 .38945 m .71632 .38425 L .69574 .41919 L p F P
0 0 0 r
s
.616 1 0 r
.69574 .41919 m .70526 .42017 L .72581 .38945 L p F P
0 0 0 r
s
0 1 .182 r
.3906 .50021 m .3785 .47306 L .3595 .44734 L p F P
0 0 0 r
s
.077 1 0 r
.34742 .42074 m .3595 .44734 L .3785 .47306 L p F P
0 0 0 r
s
1 .123 0 r
.8016 .29983 m .81091 .3133 L .83304 .30195 L p F P
0 0 0 r
s
1 .222 0 r
.81091 .3133 m .8016 .29983 L .77973 .3144 L p F P
0 0 0 r
s
1 .011 0 r
.40187 1.04026 m .41432 1.04937 L .43519 1.04445 L p F P
0 0 0 r
s
1 .005 0 r
.41432 1.04937 m .40187 1.04026 L .38105 1.04521 L p F P
0 0 0 r
s
1 .018 0 r
.45624 1.0395 m .46829 1.04862 L .4894 1.04369 L p F P
0 0 0 r
s
1 .011 0 r
.46829 1.04862 m .45624 1.0395 L .43519 1.04445 L p F P
0 0 0 r
s
1 .02 0 r
.15777 .2837 m .17204 .29894 L .19186 .29169 L p F P
0 0 0 r
s
1 .011 0 r
.17204 .29894 m .15777 .2837 L .13797 .29149 L p F P
0 0 0 r
s
1 .343 0 r
.29131 .33433 m .27852 .31238 L .25874 .31463 L p F P
0 0 0 r
s
1 .234 0 r
.24545 .29612 m .25874 .31463 L .27852 .31238 L p F P
0 0 0 r
s
1 .152 0 r
.25874 .31463 m .24545 .29612 L .22555 .30139 L p F P
0 0 0 r
s
1 .123 0 r
.83304 .30195 m .82382 .28778 L .8016 .29983 L p F P
0 0 0 r
s
.077 1 0 r
.3785 .47306 m .36656 .4414 L .34742 .42074 L p F P
0 0 0 r
s
.389 1 0 r
.33537 .39249 m .34742 .42074 L .36656 .4414 L p F P
0 0 0 r
s
.077 1 0 r
.70526 .42017 m .69574 .41919 L .67522 .45994 L p F P
0 0 0 r
s
.077 1 0 r
.67522 .45994 m .6848 .45572 L .70526 .42017 L p F P
0 0 0 r
s
0 .811 1 r
.65288 .51509 m .64345 .53426 L .62227 .57096 L p F P
0 0 0 r
s
0 .811 1 r
.62227 .57096 m .63194 .54563 L .65288 .51509 L p F P
0 0 0 r
s
.004 0 1 r
.55674 .62682 m .56763 .59406 L .58921 .58725 L p F P
0 0 0 r
s
0 .096 1 r
.56763 .59406 m .55674 .62682 L .53487 .62125 L p F P
0 0 0 r
s
1 .011 0 r
.36831 1.03604 m .38105 1.04521 L .40187 1.04026 L p F P
0 0 0 r
s
1 .698 0 r
.32325 .36418 m .31096 .33702 L .29131 .33433 L p F P
0 0 0 r
s
1 .502 0 r
.27852 .31238 m .29131 .33433 L .31096 .33702 L p F P
0 0 0 r
s
1 .098 0 r
.21181 .2848 m .22555 .30139 L .24545 .29612 L p F P
0 0 0 r
s
1 .06 0 r
.22555 .30139 m .21181 .2848 L .19186 .29169 L p F P
0 0 0 r
s
1 .02 0 r
.42285 1.03527 m .43519 1.04445 L .45624 1.0395 L p F P
0 0 0 r
s
1 .011 0 r
.43519 1.04445 m .42285 1.03527 L .40187 1.04026 L p F P
0 0 0 r
s
1 .029 0 r
.47746 1.0345 m .4894 1.04369 L .51068 1.03873 L p F P
0 0 0 r
s
1 .018 0 r
.4894 1.04369 m .47746 1.0345 L .45624 1.0395 L p F P
0 0 0 r
s
1 .005 0 r
.12337 .2764 m .13797 .29149 L .15777 .2837 L p F P
0 0 0 r
s
.389 1 0 r
.36656 .4414 m .3547 .4076 L .33537 .39249 L p F P
0 0 0 r
s
.717 1 0 r
.32325 .36418 m .33537 .39249 L .3547 .4076 L p F P
0 0 0 r
s
1 .431 0 r
.74857 .32073 m .75824 .33259 L .77973 .3144 L p F P
0 0 0 r
s
1 .698 0 r
.75824 .33259 m .74857 .32073 L .72737 .34552 L p F P
0 0 0 r
s
1 .698 0 r
.72737 .34552 m .73712 .35554 L .75824 .33259 L p F P
0 0 0 r
s
1 .036 0 r
.17772 .27602 m .19186 .29169 L .21181 .2848 L p F P
0 0 0 r
s
1 .02 0 r
.19186 .29169 m .17772 .27602 L .15777 .2837 L p F P
0 0 0 r
s
1 .253 0 r
.77014 .30127 m .77973 .3144 L .8016 .29983 L p F P
0 0 0 r
s
1 .431 0 r
.77973 .3144 m .77014 .30127 L .74857 .32073 L p F P
0 0 0 r
s
.319 0 1 r
.50135 .62786 m .5134 .60543 L .53487 .62125 L p F P
0 0 0 r
s
0 .194 1 r
.5134 .60543 m .50135 .62786 L .48028 .5997 L p F P
0 0 0 r
s
0 .381 1 r
.48028 .5997 m .46779 .60972 L .44744 .57377 L p F P
0 0 0 r
s
0 .096 1 r
.43487 .57078 m .44744 .57377 L .46779 .60972 L p F P
0 0 0 r
s
.926 1 0 r
.73712 .35554 m .72737 .34552 L .70649 .37675 L p F P
0 0 0 r
s
.926 1 0 r
.70649 .37675 m .71632 .38425 L .73712 .35554 L p F P
0 0 0 r
s
0 .381 1 r
.63194 .54563 m .62227 .57096 L .60067 .6007 L p F P
0 0 0 r
s
0 .381 1 r
.60067 .6007 m .6107 .57059 L .63194 .54563 L p F P
0 0 0 r
s
0 .096 1 r
.57876 .62 m .58921 .58725 L .6107 .57059 L p F P
0 0 0 r
s
.004 0 1 r
.58921 .58725 m .57876 .62 L .55674 .62682 L p F P
0 0 0 r
s
1 .02 0 r
.38923 1.03101 m .40187 1.04026 L .42285 1.03527 L p F P
0 0 0 r
s
1 .011 0 r
.40187 1.04026 m .38923 1.03101 L .36831 1.03604 L p F P
0 0 0 r
s
1 .14 0 r
.79211 .28585 m .8016 .29983 L .82382 .28778 L p F P
0 0 0 r
s
1 .253 0 r
.8016 .29983 m .79211 .28585 L .77014 .30127 L p F P
0 0 0 r
s
.717 1 0 r
.3547 .4076 m .34281 .37385 L .32325 .36418 L p F P
0 0 0 r
s
1 .971 0 r
.31096 .33702 m .32325 .36418 L .34281 .37385 L p F P
0 0 0 r
s
1 .034 0 r
.44401 1.03023 m .45624 1.0395 L .47746 1.0345 L p F P
0 0 0 r
s
1 .02 0 r
.45624 1.0395 m .44401 1.03023 L .42285 1.03527 L p F P
0 0 0 r
s
0 1 .54 r
.6848 .45572 m .67522 .45994 L .65455 .50481 L p F P
0 0 0 r
s
0 1 .54 r
.65455 .50481 m .66426 .49464 L .6848 .45572 L p F P
0 0 0 r
s
0 .096 1 r
.6107 .57059 m .60067 .6007 L .57876 .62 L p F P
0 0 0 r
s
1 .502 0 r
.31096 .33702 m .29842 .31173 L .27852 .31238 L p F P
0 0 0 r
s
1 .343 0 r
.26546 .29183 m .27852 .31238 L .29842 .31173 L p F P
0 0 0 r
s
1 .234 0 r
.27852 .31238 m .26546 .29183 L .24545 .29612 L p F P
0 0 0 r
s
1 .152 0 r
.23189 .2784 m .24545 .29612 L .26546 .29183 L p F P
0 0 0 r
s
1 .098 0 r
.24545 .29612 m .23189 .2784 L .21181 .2848 L p F P
0 0 0 r
s
1 .044 0 r
.49886 1.02946 m .51068 1.03873 L .53215 1.03372 L p F P
0 0 0 r
s
1 .029 0 r
.51068 1.03873 m .49886 1.02946 L .47746 1.0345 L p F P
0 0 0 r
s
1 .011 0 r
.14328 .26837 m .15777 .2837 L .17772 .27602 L p F P
0 0 0 r
s
1 .005 0 r
.15777 .2837 m .14328 .26837 L .12337 .2764 L p F P
0 0 0 r
s
.319 0 1 r
.46779 .60972 m .48028 .5997 L .50135 .62786 L p F P
0 0 0 r
s
.43 1 0 r
.71632 .38425 m .70649 .37675 L .68582 .415 L p F P
0 0 0 r
s
.43 1 0 r
.68582 .415 m .69574 .41919 L .71632 .38425 L p F P
0 0 0 r
s
1 .14 0 r
.82382 .28778 m .81443 .27323 L .79211 .28585 L p F P
0 0 0 r
s
1 .06 0 r
.19781 .26854 m .21181 .2848 L .23189 .2784 L p F P
0 0 0 r
s
1 .036 0 r
.21181 .2848 m .19781 .26854 L .17772 .27602 L p F P
0 0 0 r
s
1 .018 0 r
.35537 1.02672 m .36831 1.03604 L .38923 1.03101 L p F P
0 0 0 r
s
1 .971 0 r
.34281 .37385 m .33077 .34183 L .31096 .33702 L p F P
0 0 0 r
s
1 .698 0 r
.29842 .31173 m .31096 .33702 L .33077 .34183 L p F P
0 0 0 r
s
0 .891 1 r
.42237 .55781 m .41004 .53475 L .3906 .50021 L p F P
0 0 0 r
s
1 .036 0 r
.41032 1.02594 m .42285 1.03527 L .44401 1.03023 L p F P
0 0 0 r
s
1 .02 0 r
.42285 1.03527 m .41032 1.02594 L .38923 1.03101 L p F P
0 0 0 r
s
1 .054 0 r
.46535 1.02516 m .47746 1.0345 L .49886 1.02946 L p F P
0 0 0 r
s
1 .034 0 r
.47746 1.0345 m .46535 1.02516 L .44401 1.03023 L p F P
0 0 0 r
s
1 .002 0 r
.10854 .26114 m .12337 .2764 L .14328 .26837 L p F P
0 0 0 r
s
1 .061 0 r
.52044 1.02437 m .53215 1.03372 L .55379 1.02868 L p F P
0 0 0 r
s
1 .044 0 r
.53215 1.03372 m .52044 1.02437 L .49886 1.02946 L p F P
0 0 0 r
s
1 .02 0 r
.16334 .26037 m .17772 .27602 L .19781 .26854 L p F P
0 0 0 r
s
1 .011 0 r
.17772 .27602 m .16334 .26037 L .14328 .26837 L p F P
0 0 0 r
s
1 .343 0 r
.29842 .31173 m .28559 .28856 L .26546 .29183 L p F P
0 0 0 r
s
1 .223 0 r
.25209 .27258 m .26546 .29183 L .28559 .28856 L p F P
0 0 0 r
s
1 .152 0 r
.26546 .29183 m .25209 .27258 L .23189 .2784 L p F P
0 0 0 r
s
1 .465 0 r
.73863 .30738 m .74857 .32073 L .77014 .30127 L p F P
0 0 0 r
s
1 .753 0 r
.74857 .32073 m .73863 .30738 L .7173 .33324 L p F P
0 0 0 r
s
1 .753 0 r
.7173 .33324 m .72737 .34552 L .74857 .32073 L p F P
0 0 0 r
s
1 .273 0 r
.76033 .28716 m .77014 .30127 L .79211 .28585 L p F P
0 0 0 r
s
1 .465 0 r
.77014 .30127 m .76033 .28716 L .73863 .30738 L p F P
0 0 0 r
s
0 1 .882 r
.41004 .53475 m .39795 .50312 L .3785 .47306 L p F P
0 0 0 r
s
0 1 .54 r
.36656 .4414 m .3785 .47306 L .39795 .50312 L p F P
0 0 0 r
s
0 .811 1 r
.66426 .49464 m .65455 .50481 L .63355 .55068 L p F P
0 0 0 r
s
0 .811 1 r
.63355 .55068 m .64345 .53426 L .66426 .49464 L p F P
0 0 0 r
s
0 1 .182 r
.69574 .41919 m .68582 .415 L .66516 .45984 L p F P
0 0 0 r
s
0 1 .182 r
.66516 .45984 m .67522 .45994 L .69574 .41919 L p F P
0 0 0 r
s
1 .034 0 r
.37639 1.02162 m .38923 1.03101 L .41032 1.02594 L p F P
0 0 0 r
s
1 .018 0 r
.38923 1.03101 m .37639 1.02162 L .35537 1.02672 L p F P
0 0 0 r
s
1 .698 0 r
.33077 .34183 m .31849 .31251 L .29842 .31173 L p F P
0 0 0 r
s
1 .477 0 r
.28559 .28856 m .29842 .31173 L .31849 .31251 L p F P
0 0 0 r
s
1 .093 0 r
.21805 .26131 m .23189 .2784 L .25209 .27258 L p F P
0 0 0 r
s
1 .06 0 r
.23189 .2784 m .21805 .26131 L .19781 .26854 L p F P
0 0 0 r
s
1 .152 0 r
.78242 .2712 m .79211 .28585 L .81443 .27323 L p F P
0 0 0 r
s
1 .273 0 r
.79211 .28585 m .78242 .2712 L .76033 .28716 L p F P
0 0 0 r
s
1 .06 0 r
.43159 1.02083 m .44401 1.03023 L .46535 1.02516 L p F P
0 0 0 r
s
1 .036 0 r
.44401 1.03023 m .43159 1.02083 L .41032 1.02594 L p F P
0 0 0 r
s
.841 1 0 r
.72737 .34552 m .7173 .33324 L .69627 .36593 L p F P
0 0 0 r
s
.841 1 0 r
.69627 .36593 m .70649 .37675 L .72737 .34552 L p F P
0 0 0 r
s
0 1 .54 r
.39795 .50312 m .38609 .46564 L .36656 .4414 L p F P
0 0 0 r
s
0 1 .127 r
.3547 .4076 m .36656 .4414 L .38609 .46564 L p F P
0 0 0 r
s
1 .08 0 r
.48686 1.02004 m .49886 1.02946 L .52044 1.02437 L p F P
0 0 0 r
s
1 .054 0 r
.49886 1.02946 m .48686 1.02004 L .46535 1.02516 L p F P
0 0 0 r
s
1 .005 0 r
.12855 .25291 m .14328 .26837 L .16334 .26037 L p F P
0 0 0 r
s
1 .002 0 r
.14328 .26837 m .12855 .25291 L .10854 .26114 L p F P
0 0 0 r
s
1 .082 0 r
.5422 1.01925 m .55379 1.02868 L .57561 1.02359 L p F P
0 0 0 r
s
1 .061 0 r
.55379 1.02868 m .5422 1.01925 L .52044 1.02437 L p F P
0 0 0 r
s
0 1 .127 r
.38609 .46564 m .37438 .42548 L .3547 .4076 L p F P
0 0 0 r
s
.306 1 0 r
.34281 .37385 m .3547 .4076 L .37438 .42548 L p F P
0 0 0 r
s
0 .096 1 r
.46779 .60972 m .45517 .60938 L .43487 .57078 L p F P
0 0 0 r
s
.004 0 1 r
.42237 .55781 m .43487 .57078 L .45517 .60938 L p F P
0 0 0 r
s
.66 0 1 r
.5231 .64814 m .53487 .62125 L .55674 .62682 L p F P
0 0 0 r
s
.319 0 1 r
.53487 .62125 m .5231 .64814 L .50135 .62786 L p F P
0 0 0 r
s
1 .034 0 r
.18356 .25245 m .19781 .26854 L .21805 .26131 L p F P
0 0 0 r
s
1 .02 0 r
.19781 .26854 m .18356 .25245 L .16334 .26037 L p F P
0 0 0 r
s
.306 1 0 r
.37438 .42548 m .36267 .38556 L .34281 .37385 L p F P
0 0 0 r
s
.717 1 0 r
.33077 .34183 m .34281 .37385 L .36267 .38556 L p F P
0 0 0 r
s
1 .152 0 r
.81443 .27323 m .80488 .25822 L .78242 .2712 L p F P
0 0 0 r
s
1 .029 0 r
.34222 1.01727 m .35537 1.02672 L .37639 1.02162 L p F P
0 0 0 r
s
1 .06 0 r
.3976 1.01647 m .41032 1.02594 L .43159 1.02083 L p F P
0 0 0 r
s
1 .034 0 r
.41032 1.02594 m .3976 1.01647 L .37639 1.02162 L p F P
0 0 0 r
s
.306 1 0 r
.70649 .37675 m .69627 .36593 L .67543 .40609 L p F P
0 0 0 r
s
.306 1 0 r
.67543 .40609 m .68582 .415 L .70649 .37675 L p F P
0 0 0 r
s
.717 1 0 r
.36267 .38556 m .35085 .34806 L .33077 .34183 L p F P
0 0 0 r
s
1 .923 0 r
.31849 .31251 m .33077 .34183 L .35085 .34806 L p F P
0 0 0 r
s
1 .093 0 r
.45304 1.01568 m .46535 1.02516 L .48686 1.02004 L p F P
0 0 0 r
s
1 .06 0 r
.46535 1.02516 m .45304 1.01568 L .43159 1.02083 L p F P
0 0 0 r
s
1 .477 0 r
.31849 .31251 m .3059 .2862 L .28559 .28856 L p F P
0 0 0 r
s
1 .31 0 r
.27244 .26738 m .28559 .28856 L .3059 .2862 L p F P
0 0 0 r
s
1 .223 0 r
.28559 .28856 m .27244 .26738 L .25209 .27258 L p F P
0 0 0 r
s
1 .137 0 r
.23842 .2544 m .25209 .27258 L .27244 .26738 L p F P
0 0 0 r
s
1 .093 0 r
.25209 .27258 m .23842 .2544 L .21805 .26131 L p F P
0 0 0 r
s
1 .111 0 r
.50855 1.01488 m .52044 1.02437 L .5422 1.01925 L p F P
0 0 0 r
s
1 .08 0 r
.52044 1.02437 m .50855 1.01488 L .48686 1.02004 L p F P
0 0 0 r
s
1 .011 0 r
.14872 .24467 m .16334 .26037 L .18356 .25245 L p F P
0 0 0 r
s
1 .005 0 r
.16334 .26037 m .14872 .24467 L .12855 .25291 L p F P
0 0 0 r
s
1 .103 0 r
.56414 1.01408 m .57561 1.02359 L .59761 1.01846 L p F P
0 0 0 r
s
1 .082 0 r
.57561 1.02359 m .56414 1.01408 L .5422 1.01925 L p F P
0 0 0 r
s
0 .194 1 r
.61207 .59321 m .62227 .57096 L .64345 .53426 L p F P
0 0 0 r
s
0 .194 1 r
.64345 .53426 m .63355 .55068 L .61207 .59321 L p F P
0 0 0 r
s
0 1 .882 r
.67522 .45994 m .66516 .45984 L .64431 .50942 L p F P
0 0 0 r
s
0 1 .882 r
.64431 .50942 m .65455 .50481 L .67522 .45994 L p F P
0 0 0 r
s
1 .28 0 r
.75029 .27192 m .76033 .28716 L .78242 .2712 L p F P
0 0 0 r
s
1 .477 0 r
.76033 .28716 m .75029 .27192 L .72842 .29229 L p F P
0 0 0 r
s
1 .477 0 r
.72842 .29229 m .73863 .30738 L .76033 .28716 L p F P
0 0 0 r
s
1 .054 0 r
.20393 .24465 m .21805 .26131 L .23842 .2544 L p F P
0 0 0 r
s
1 .034 0 r
.21805 .26131 m .20393 .24465 L .18356 .25245 L p F P
0 0 0 r
s
1 .773 0 r
.73863 .30738 m .72842 .29229 L .7069 .31832 L p F P
0 0 0 r
s
1 .773 0 r
.7069 .31832 m .7173 .33324 L .73863 .30738 L p F P
0 0 0 r
s
1 .923 0 r
.35085 .34806 m .33879 .31423 L .31849 .31251 L p F P
0 0 0 r
s
1 .631 0 r
.3059 .2862 m .31849 .31251 L .33879 .31423 L p F P
0 0 0 r
s
1 .054 0 r
.36336 1.01208 m .37639 1.02162 L .3976 1.01647 L p F P
0 0 0 r
s
1 .029 0 r
.37639 1.02162 m .36336 1.01208 L .34222 1.01727 L p F P
0 0 0 r
s
1 .098 0 r
.41898 1.01128 m .43159 1.02083 L .45304 1.01568 L p F P
0 0 0 r
s
1 .06 0 r
.43159 1.02083 m .41898 1.01128 L .3976 1.01647 L p F P
0 0 0 r
s
1 .156 0 r
.77254 .25581 m .78242 .2712 L .80488 .25822 L p F P
0 0 0 r
s
1 .28 0 r
.78242 .2712 m .77254 .25581 L .75029 .27192 L p F P
0 0 0 r
s
1 .137 0 r
.47467 1.01048 m .48686 1.02004 L .50855 1.01488 L p F P
0 0 0 r
s
1 .093 0 r
.48686 1.02004 m .47467 1.01048 L .45304 1.01568 L p F P
0 0 0 r
s
.811 1 0 r
.7173 .33324 m .7069 .31832 L .68566 .35121 L p F P
0 0 0 r
s
.811 1 0 r
.68566 .35121 m .69627 .36593 L .7173 .33324 L p F P
0 0 0 r
s
.319 0 1 r
.50135 .62786 m .48895 .64237 L .46779 .60972 L p F P
0 0 0 r
s
.66 0 1 r
.45517 .60938 m .46779 .60972 L .48895 .64237 L p F P
0 0 0 r
s
1 .148 0 r
.53043 1.00967 m .5422 1.01925 L .56414 1.01408 L p F P
0 0 0 r
s
1 .111 0 r
.5422 1.01925 m .53043 1.00967 L .50855 1.01488 L p F P
0 0 0 r
s
.901 0 1 r
.48895 .64237 m .50135 .62786 L .5231 .64814 L p F P
0 0 0 r
s
.004 0 1 r
.45517 .60938 m .44258 .59647 L .42237 .55781 L p F P
0 0 0 r
s
0 .096 1 r
.41004 .53475 m .42237 .55781 L .44258 .59647 L p F P
0 0 0 r
s
1 .018 0 r
.16905 .23643 m .18356 .25245 L .20393 .24465 L p F P
0 0 0 r
s
1 .011 0 r
.18356 .25245 m .16905 .23643 L .14872 .24467 L p F P
0 0 0 r
s
1 .123 0 r
.58627 1.00887 m .59761 1.01846 L .6198 1.01328 L p F P
0 0 0 r
s
1 .103 0 r
.59761 1.01846 m .58627 1.00887 L .56414 1.01408 L p F P
0 0 0 r
s
.779 0 1 r
.54533 .65616 m .55674 .62682 L .57876 .62 L p F P
0 0 0 r
s
.66 0 1 r
.55674 .62682 m .54533 .65616 L .5231 .64814 L p F P
0 0 0 r
s
1 .31 0 r
.3059 .2862 m .29295 .26272 L .27244 .26738 L p F P
0 0 0 r
s
1 .191 0 r
.25895 .24784 m .27244 .26738 L .29295 .26272 L p F P
0 0 0 r
s
1 .137 0 r
.27244 .26738 m .25895 .24784 L .23842 .2544 L p F P
0 0 0 r
s
0 1 .354 r
.68582 .415 m .67543 .40609 L .65457 .45329 L p F P
0 0 0 r
s
0 1 .354 r
.65457 .45329 m .66516 .45984 L .68582 .415 L p F P
0 0 0 r
s
1 .156 0 r
.80488 .25822 m .79514 .24269 L .77254 .25581 L p F P
0 0 0 r
s
1 .631 0 r
.33879 .31423 m .32641 .28443 L .3059 .2862 L p F P
0 0 0 r
s
1 .41 0 r
.29295 .26272 m .3059 .2862 L .32641 .28443 L p F P
0 0 0 r
s
1 .044 0 r
.32888 1.00766 m .34222 1.01727 L .36336 1.01208 L p F P
0 0 0 r
s
.319 0 1 r
.62227 .57096 m .61207 .59321 L .59011 .62751 L p F P
0 0 0 r
s
.319 0 1 r
.59011 .62751 m .60067 .6007 L .62227 .57096 L p F P
0 0 0 r
s
1 .08 0 r
.22446 .237 m .23842 .2544 L .25895 .24784 L p F P
0 0 0 r
s
1 .054 0 r
.23842 .2544 m .22446 .237 L .20393 .24465 L p F P
0 0 0 r
s
1 .093 0 r
.38467 1.00685 m .3976 1.01647 L .41898 1.01128 L p F P
0 0 0 r
s
1 .054 0 r
.3976 1.01647 m .38467 1.00685 L .36336 1.01208 L p F P
0 0 0 r
s
1 .152 0 r
.44054 1.00604 m .45304 1.01568 L .47467 1.01048 L p F P
0 0 0 r
s
1 .098 0 r
.45304 1.01568 m .44054 1.00604 L .41898 1.01128 L p F P
0 0 0 r
s
1 .191 0 r
.49648 1.00523 m .50855 1.01488 L .53043 1.00967 L p F P
0 0 0 r
s
1 .137 0 r
.50855 1.01488 m .49648 1.00523 L .47467 1.01048 L p F P
0 0 0 r
s
.262 1 0 r
.69627 .36593 m .68566 .35121 L .66458 .39158 L p F P
0 0 0 r
s
.262 1 0 r
.66458 .39158 m .67543 .40609 L .69627 .36593 L p F P
0 0 0 r
s
1 .186 0 r
.5525 1.00442 m .56414 1.01408 L .58627 1.00887 L p F P
0 0 0 r
s
1 .148 0 r
.56414 1.01408 m .5525 1.00442 L .53043 1.00967 L p F P
0 0 0 r
s
.389 1 0 r
.38297 .39765 m .3713 .3545 L .35085 .34806 L p F P
0 0 0 r
s
.389 1 0 r
.35085 .34806 m .36267 .38556 L .38297 .39765 L p F P
0 0 0 r
s
.841 1 0 r
.33879 .31423 m .35085 .34806 L .3713 .3545 L p F P
0 0 0 r
s
0 1 .127 r
.39456 .44399 m .38297 .39765 L .36267 .38556 L p F P
0 0 0 r
s
0 1 .127 r
.36267 .38556 m .37438 .42548 L .39456 .44399 L p F P
0 0 0 r
s
1 .029 0 r
.18955 .22822 m .20393 .24465 L .22446 .237 L p F P
0 0 0 r
s
1 .018 0 r
.20393 .24465 m .18955 .22822 L .16905 .23643 L p F P
0 0 0 r
s
0 .096 1 r
.44258 .59647 m .43018 .57083 L .41004 .53475 L p F P
0 0 0 r
s
0 .381 1 r
.39795 .50312 m .41004 .53475 L .43018 .57083 L p F P
0 0 0 r
s
1 .14 0 r
.60858 1.00361 m .6198 1.01328 L .64218 1.00806 L p F P
0 0 0 r
s
1 .123 0 r
.6198 1.01328 m .60858 1.00361 L .58627 1.00887 L p F P
0 0 0 r
s
.66 0 1 r
.56777 .64932 m .57876 .62 L .60067 .6007 L p F P
0 0 0 r
s
.779 0 1 r
.57876 .62 m .56777 .64932 L .54533 .65616 L p F P
0 0 0 r
s
1 .273 0 r
.74002 .25554 m .75029 .27192 L .77254 .25581 L p F P
0 0 0 r
s
1 .465 0 r
.75029 .27192 m .74002 .25554 L .71794 .27546 L p F P
0 0 0 r
s
1 .465 0 r
.71794 .27546 m .72842 .29229 L .75029 .27192 L p F P
0 0 0 r
s
.66 0 1 r
.60067 .6007 m .59011 .62751 L .56777 .64932 L p F P
0 0 0 r
s
1 .753 0 r
.72842 .29229 m .71794 .27546 L .69619 .30074 L p F P
0 0 0 r
s
1 .753 0 r
.69619 .30074 m .7069 .31832 L .72842 .29229 L p F P
0 0 0 r
s
.841 1 0 r
.3713 .3545 m .3594 .31603 L .33879 .31423 L p F P
0 0 0 r
s
1 .793 0 r
.32641 .28443 m .33879 .31423 L .3594 .31603 L p F P
0 0 0 r
s
0 1 .671 r
.40621 .49081 m .39456 .44399 L .37438 .42548 L p F P
0 0 0 r
s
0 1 .671 r
.37438 .42548 m .38609 .46564 L .40621 .49081 L p F P
0 0 0 r
s
0 .381 1 r
.65455 .50481 m .64431 .50942 L .62306 .56025 L p F P
0 0 0 r
s
0 .381 1 r
.62306 .56025 m .63355 .55068 L .65455 .50481 L p F P
0 0 0 r
s
1 .08 0 r
.35012 1.00239 m .36336 1.01208 L .38467 1.00685 L p F P
0 0 0 r
s
1 .044 0 r
.36336 1.01208 m .35012 1.00239 L .32888 1.00766 L p F P
0 0 0 r
s
1 .41 0 r
.32641 .28443 m .31367 .25839 L .29295 .26272 L p F P
0 0 0 r
s
1 .253 0 r
.27965 .24157 m .29295 .26272 L .31367 .25839 L p F P
0 0 0 r
s
1 .191 0 r
.29295 .26272 m .27965 .24157 L .25895 .24784 L p F P
0 0 0 r
s
0 .811 1 r
.41805 .53445 m .40621 .49081 L .38609 .46564 L p F P
0 0 0 r
s
0 .811 1 r
.38609 .46564 m .39795 .50312 L .41805 .53445 L p F P
0 0 0 r
s
1 .152 0 r
.40617 1.00158 m .41898 1.01128 L .44054 1.00604 L p F P
0 0 0 r
s
1 .093 0 r
.41898 1.01128 m .40617 1.00158 L .38467 1.00685 L p F P
0 0 0 r
s
0 .381 1 r
.43018 .57083 m .41805 .53445 L .39795 .50312 L p F P
0 0 0 r
s
1 .152 0 r
.76246 .23967 m .77254 .25581 L .79514 .24269 L p F P
0 0 0 r
s
1 .273 0 r
.77254 .25581 m .76246 .23967 L .74002 .25554 L p F P
0 0 0 r
s
1 .111 0 r
.24515 .22951 m .25895 .24784 L .27965 .24157 L p F P
0 0 0 r
s
1 .08 0 r
.25895 .24784 m .24515 .22951 L .22446 .237 L p F P
0 0 0 r
s
1 .223 0 r
.46229 1.00076 m .47467 1.01048 L .49648 1.00523 L p F P
0 0 0 r
s
1 .152 0 r
.47467 1.01048 m .46229 1.00076 L .44054 1.00604 L p F P
0 0 0 r
s
.841 1 0 r
.7069 .31832 m .69619 .30074 L .67469 .33253 L p F P
0 0 0 r
s
.841 1 0 r
.67469 .33253 m .68566 .35121 L .7069 .31832 L p F P
0 0 0 r
s
1 .253 0 r
.51848 .99995 m .53043 1.00967 L .5525 1.00442 L p F P
0 0 0 r
s
1 .191 0 r
.53043 1.00967 m .51848 .99995 L .49648 1.00523 L p F P
0 0 0 r
s
1 .793 0 r
.3594 .31603 m .34719 .28267 L .32641 .28443 L p F P
0 0 0 r
s
1 .515 0 r
.31367 .25839 m .32641 .28443 L .34719 .28267 L p F P
0 0 0 r
s
1 .222 0 r
.57475 .99913 m .58627 1.00887 L .60858 1.00361 L p F P
0 0 0 r
s
1 .186 0 r
.58627 1.00887 m .57475 .99913 L .5525 1.00442 L p F P
0 0 0 r
s
1 .152 0 r
.63109 .99831 m .64218 1.00806 L .66474 1.0028 L p F P
0 0 0 r
s
1 .14 0 r
.64218 1.00806 m .63109 .99831 L .60858 1.00361 L p F P
0 0 0 r
s
1 .152 0 r
.79514 .24269 m .78523 .22664 L .76246 .23967 L p F P
0 0 0 r
s
1 .044 0 r
.21021 .22006 m .22446 .237 L .24515 .22951 L p F P
0 0 0 r
s
1 .029 0 r
.22446 .237 m .21021 .22006 L .18955 .22822 L p F P
0 0 0 r
s
1 .061 0 r
.31532 .9979 m .32888 1.00766 L .35012 1.00239 L p F P
0 0 0 r
s
0 .891 1 r
.66516 .45984 m .65457 .45329 L .63348 .50558 L p F P
0 0 0 r
s
0 .891 1 r
.63348 .50558 m .64431 .50942 L .66516 .45984 L p F P
0 0 0 r
s
1 .137 0 r
.37154 .99708 m .38467 1.00685 L .40617 1.00158 L p F P
0 0 0 r
s
1 .08 0 r
.38467 1.00685 m .37154 .99708 L .35012 1.00239 L p F P
0 0 0 r
s
1 .234 0 r
.42784 .99626 m .44054 1.00604 L .46229 1.00076 L p F P
0 0 0 r
s
1 .152 0 r
.44054 1.00604 m .42784 .99626 L .40617 1.00158 L p F P
0 0 0 r
s
0 1 .414 r
.67543 .40609 m .66458 .39158 L .64346 .43901 L p F P
0 0 0 r
s
0 1 .414 r
.64346 .43901 m .65457 .45329 L .67543 .40609 L p F P
0 0 0 r
s
1 .31 0 r
.48422 .99544 m .49648 1.00523 L .51848 .99995 L p F P
0 0 0 r
s
1 .223 0 r
.49648 1.00523 m .48422 .99544 L .46229 1.00076 L p F P
0 0 0 r
s
.66 0 1 r
.48895 .64237 m .47633 .64455 L .45517 .60938 L p F P
0 0 0 r
s
.779 0 1 r
.44258 .59647 m .45517 .60938 L .47633 .64455 L p F P
0 0 0 r
s
.306 1 0 r
.68566 .35121 m .67469 .33253 L .65332 .3714 L p F P
0 0 0 r
s
.306 1 0 r
.65332 .3714 m .66458 .39158 L .68566 .35121 L p F P
0 0 0 r
s
1 .515 0 r
.34719 .28267 m .33462 .25403 L .31367 .25839 L p F P
0 0 0 r
s
1 .318 0 r
.30055 .23546 m .31367 .25839 L .33462 .25403 L p F P
0 0 0 r
s
1 .253 0 r
.31367 .25839 m .30055 .23546 L .27965 .24157 L p F P
0 0 0 r
s
1 .318 0 r
.54067 .99462 m .5525 1.00442 L .57475 .99913 L p F P
0 0 0 r
s
1 .253 0 r
.5525 1.00442 m .54067 .99462 L .51848 .99995 L p F P
0 0 0 r
s
1 .148 0 r
.26601 .22215 m .27965 .24157 L .30055 .23546 L p F P
0 0 0 r
s
1 .111 0 r
.27965 .24157 m .26601 .22215 L .24515 .22951 L p F P
0 0 0 r
s
1 .431 0 r
.70723 .25708 m .71794 .27546 L .74002 .25554 L p F P
0 0 0 r
s
1 .698 0 r
.71794 .27546 m .70723 .25708 L .68521 .28085 L p F P
0 0 0 r
s
1 .698 0 r
.68521 .28085 m .69619 .30074 L .71794 .27546 L p F P
0 0 0 r
s
1 .253 0 r
.72954 .23814 m .74002 .25554 L .76246 .23967 L p F P
0 0 0 r
s
1 .431 0 r
.74002 .25554 m .72954 .23814 L .70723 .25708 L p F P
0 0 0 r
s
1 .253 0 r
.59719 .99379 m .60858 1.00361 L .63109 .99831 L p F P
0 0 0 r
s
1 .222 0 r
.60858 1.00361 m .59719 .99379 L .57475 .99913 L p F P
0 0 0 r
s
1 0 .712 r
.51088 .66618 m .5231 .64814 L .54533 .65616 L p F P
0 0 0 r
s
.901 0 1 r
.5231 .64814 m .51088 .66618 L .48895 .64237 L p F P
0 0 0 r
s
.616 1 0 r
.3922 .35954 m .38039 .31682 L .3594 .31603 L p F P
0 0 0 r
s
.616 1 0 r
.3594 .31603 m .3713 .3545 L .3922 .35954 L p F P
0 0 0 r
s
1 .946 0 r
.34719 .28267 m .3594 .31603 L .38039 .31682 L p F P
0 0 0 r
s
1 .156 0 r
.65379 .99297 m .66474 1.0028 L .6875 .99749 L p F P
0 0 0 r
s
1 .152 0 r
.66474 1.0028 m .65379 .99297 L .63109 .99831 L p F P
0 0 0 r
s
.077 1 0 r
.40382 .40791 m .3922 .35954 L .3713 .3545 L p F P
0 0 0 r
s
.077 1 0 r
.3713 .3545 m .38297 .39765 L .40382 .40791 L p F P
0 0 0 r
s
1 .111 0 r
.33667 .99255 m .35012 1.00239 L .37154 .99708 L p F P
0 0 0 r
s
1 .061 0 r
.35012 1.00239 m .33667 .99255 L .31532 .9979 L p F P
0 0 0 r
s
1 .061 0 r
.23104 .21195 m .24515 .22951 L .26601 .22215 L p F P
0 0 0 r
s
1 .044 0 r
.24515 .22951 m .23104 .21195 L .21021 .22006 L p F P
0 0 0 r
s
.319 0 1 r
.63355 .55068 m .62306 .56025 L .60127 .60744 L p F P
0 0 0 r
s
.319 0 1 r
.60127 .60744 m .61207 .59321 L .63355 .55068 L p F P
0 0 0 r
s
1 .14 0 r
.75218 .22285 m .76246 .23967 L .78523 .22664 L p F P
0 0 0 r
s
1 .253 0 r
.76246 .23967 m .75218 .22285 L .72954 .23814 L p F P
0 0 0 r
s
1 .223 0 r
.39315 .99173 m .40617 1.00158 L .42784 .99626 L p F P
0 0 0 r
s
1 .137 0 r
.40617 1.00158 m .39315 .99173 L .37154 .99708 L p F P
0 0 0 r
s
.926 1 0 r
.69619 .30074 m .68521 .28085 L .66342 .31045 L p F P
0 0 0 r
s
.926 1 0 r
.66342 .31045 m .67469 .33253 L .69619 .30074 L p F P
0 0 0 r
s
1 .946 0 r
.38039 .31682 m .36829 .2802 L .34719 .28267 L p F P
0 0 0 r
s
1 .615 0 r
.33462 .25403 m .34719 .28267 L .36829 .2802 L p F P
0 0 0 r
s
1 .343 0 r
.44971 .9909 m .46229 1.00076 L .48422 .99544 L p F P
0 0 0 r
s
1 .234 0 r
.46229 1.00076 m .44971 .9909 L .42784 .99626 L p F P
0 0 0 r
s
0 1 .54 r
.41539 .46021 m .40382 .40791 L .38297 .39765 L p F P
0 0 0 r
s
0 1 .54 r
.38297 .39765 m .39456 .44399 L .41539 .46021 L p F P
0 0 0 r
s
1 .41 0 r
.50634 .99007 m .51848 .99995 L .54067 .99462 L p F P
0 0 0 r
s
1 .31 0 r
.51848 .99995 m .50634 .99007 L .48422 .99544 L p F P
0 0 0 r
s
1 .38 0 r
.56304 .98924 m .57475 .99913 L .59719 .99379 L p F P
0 0 0 r
s
1 .318 0 r
.57475 .99913 m .56304 .98924 L .54067 .99462 L p F P
0 0 0 r
s
1 0 .712 r
.47633 .64455 m .48895 .64237 L .51088 .66618 L p F P
0 0 0 r
s
1 .14 0 r
.78523 .22664 m .77514 .21011 L .75218 .22285 L p F P
0 0 0 r
s
1 .273 0 r
.61982 .98841 m .63109 .99831 L .65379 .99297 L p F P
0 0 0 r
s
1 .253 0 r
.63109 .99831 m .61982 .98841 L .59719 .99379 L p F P
0 0 0 r
s
1 .318 0 r
.33462 .25403 m .32165 .2293 L .30055 .23546 L p F P
0 0 0 r
s
1 .186 0 r
.28706 .21485 m .30055 .23546 L .32165 .2293 L p F P
0 0 0 r
s
1 .148 0 r
.30055 .23546 m .28706 .21485 L .26601 .22215 L p F P
0 0 0 r
s
1 .082 0 r
.30154 .98799 m .31532 .9979 L .33667 .99255 L p F P
0 0 0 r
s
1 .152 0 r
.67668 .98757 m .6875 .99749 L .71046 .99214 L p F P
0 0 0 r
s
1 .156 0 r
.6875 .99749 m .67668 .98757 L .65379 .99297 L p F P
0 0 0 r
s
1 .615 0 r
.36829 .2802 m .35583 .2492 L .33462 .25403 L p F P
0 0 0 r
s
1 .38 0 r
.32165 .2293 m .33462 .25403 L .35583 .2492 L p F P
0 0 0 r
s
1 .191 0 r
.35821 .98716 m .37154 .99708 L .39315 .99173 L p F P
0 0 0 r
s
1 .111 0 r
.37154 .99708 m .35821 .98716 L .33667 .99255 L p F P
0 0 0 r
s
.43 1 0 r
.67469 .33253 m .66342 .31045 L .64174 .34638 L p F P
0 0 0 r
s
.43 1 0 r
.64174 .34638 m .65332 .3714 L .67469 .33253 L p F P
0 0 0 r
s
0 .811 1 r
.42707 .51327 m .41539 .46021 L .39456 .44399 L p F P
0 0 0 r
s
0 .811 1 r
.39456 .44399 m .40621 .49081 L .42707 .51327 L p F P
0 0 0 r
s
1 .343 0 r
.41495 .98632 m .42784 .99626 L .44971 .9909 L p F P
0 0 0 r
s
1 .223 0 r
.42784 .99626 m .41495 .98632 L .39315 .99173 L p F P
0 0 0 r
s
1 .082 0 r
.25205 .20388 m .26601 .22215 L .28706 .21485 L p F P
0 0 0 r
s
1 .061 0 r
.26601 .22215 m .25205 .20388 L .23104 .21195 L p F P
0 0 0 r
s
0 1 .354 r
.66458 .39158 m .65332 .3714 L .63189 .41694 L p F P
0 0 0 r
s
0 1 .354 r
.63189 .41694 m .64346 .43901 L .66458 .39158 L p F P
0 0 0 r
s
1 .477 0 r
.47176 .98549 m .48422 .99544 L .50634 .99007 L p F P
0 0 0 r
s
1 .343 0 r
.48422 .99544 m .47176 .98549 L .44971 .9909 L p F P
0 0 0 r
s
.779 0 1 r
.47633 .64455 m .46368 .63168 L .44258 .59647 L p F P
0 0 0 r
s
.66 0 1 r
.43018 .57083 m .44258 .59647 L .46368 .63168 L p F P
0 0 0 r
s
1 .38 0 r
.69631 .23755 m .70723 .25708 L .72954 .23814 L p F P
0 0 0 r
s
1 .615 0 r
.70723 .25708 m .69631 .23755 L .67402 .25926 L p F P
0 0 0 r
s
1 .615 0 r
.67402 .25926 m .68521 .28085 L .70723 .25708 L p F P
0 0 0 r
s
0 .096 1 r
.64431 .50942 m .63348 .50558 L .61194 .5593 L p F P
0 0 0 r
s
0 .096 1 r
.61194 .5593 m .62306 .56025 L .64431 .50942 L p F P
0 0 0 r
s
1 .515 0 r
.52865 .98465 m .54067 .99462 L .56304 .98924 L p F P
0 0 0 r
s
1 .41 0 r
.54067 .99462 m .52865 .98465 L .50634 .99007 L p F P
0 0 0 r
s
1 .222 0 r
.71887 .21995 m .72954 .23814 L .75218 .22285 L p F P
0 0 0 r
s
1 .38 0 r
.72954 .23814 m .71887 .21995 L .69631 .23755 L p F P
0 0 0 r
s
0 .811 1 r
.65457 .45329 m .64346 .43901 L .62208 .49158 L p F P
0 0 0 r
s
0 .811 1 r
.62208 .49158 m .63348 .50558 L .65457 .45329 L p F P
0 0 0 r
s
1 .431 0 r
.58561 .98381 m .59719 .99379 L .61982 .98841 L p F P
0 0 0 r
s
1 .38 0 r
.59719 .99379 m .58561 .98381 L .56304 .98924 L p F P
0 0 0 r
s
.43 1 0 r
.4136 .36143 m .4018 .3154 L .38039 .31682 L p F P
0 0 0 r
s
.43 1 0 r
.38039 .31682 m .3922 .35954 L .4136 .36143 L p F P
0 0 0 r
s
.926 1 0 r
.36829 .2802 m .38039 .31682 L .4018 .3154 L p F P
0 0 0 r
s
1 .946 0 r
.68521 .28085 m .67402 .25926 L .65193 .28592 L p F P
0 0 0 r
s
1 .946 0 r
.65193 .28592 m .66342 .31045 L .68521 .28085 L p F P
0 0 0 r
s
.926 1 0 r
.4018 .3154 m .38973 .27625 L .36829 .2802 L p F P
0 0 0 r
s
1 .698 0 r
.35583 .2492 m .36829 .2802 L .38973 .27625 L p F P
0 0 0 r
s
1 .28 0 r
.64265 .98297 m .65379 .99297 L .67668 .98757 L p F P
0 0 0 r
s
1 .273 0 r
.65379 .99297 m .64265 .98297 L .61982 .98841 L p F P
0 0 0 r
s
.901 0 1 r
.57893 .64542 m .59011 .62751 L .61207 .59321 L p F P
0 0 0 r
s
1 0 .712 r
.59011 .62751 m .57893 .64542 L .5562 .66929 L p F P
0 0 0 r
s
1 0 .712 r
.5562 .66929 m .56777 .64932 L .59011 .62751 L p F P
0 0 0 r
s
.901 0 1 r
.61207 .59321 m .60127 .60744 L .57893 .64542 L p F P
0 0 0 r
s
1 .148 0 r
.32301 .98255 m .33667 .99255 L .35821 .98716 L p F P
0 0 0 r
s
1 .082 0 r
.33667 .99255 m .32301 .98255 L .30154 .98799 L p F P
0 0 0 r
s
0 .194 1 r
.43898 .5627 m .42707 .51327 L .40621 .49081 L p F P
0 0 0 r
s
0 .194 1 r
.40621 .49081 m .41805 .53445 L .43898 .5627 L p F P
0 0 0 r
s
1 .123 0 r
.74173 .20546 m .75218 .22285 L .77514 .21011 L p F P
0 0 0 r
s
1 .222 0 r
.75218 .22285 m .74173 .20546 L .71887 .21995 L p F P
0 0 0 r
s
1 0 .577 r
.5334 .67617 m .54533 .65616 L .56777 .64932 L p F P
0 0 0 r
s
1 0 .712 r
.54533 .65616 m .5334 .67617 L .51088 .66618 L p F P
0 0 0 r
s
1 .14 0 r
.69977 .98213 m .71046 .99214 L .73361 .98674 L p F P
0 0 0 r
s
1 .152 0 r
.71046 .99214 m .69977 .98213 L .67668 .98757 L p F P
0 0 0 r
s
1 .31 0 r
.37993 .98171 m .39315 .99173 L .41495 .98632 L p F P
0 0 0 r
s
1 .191 0 r
.39315 .99173 m .37993 .98171 L .35821 .98716 L p F P
0 0 0 r
s
0 1 .182 r
.42526 .41389 m .4136 .36143 L .3922 .35954 L p F P
0 0 0 r
s
0 1 .182 r
.3922 .35954 m .40382 .40791 L .42526 .41389 L p F P
0 0 0 r
s
1 .38 0 r
.35583 .2492 m .343 .22283 L .32165 .2293 L p F P
0 0 0 r
s
1 .222 0 r
.30832 .20749 m .32165 .2293 L .343 .22283 L p F P
0 0 0 r
s
1 .186 0 r
.32165 .2293 m .30832 .20749 L .28706 .21485 L p F P
0 0 0 r
s
1 .502 0 r
.43693 .98087 m .44971 .9909 L .47176 .98549 L p F P
0 0 0 r
s
1 .343 0 r
.44971 .9909 m .43693 .98087 L .41495 .98632 L p F P
0 0 0 r
s
.66 0 1 r
.46368 .63168 m .45119 .60359 L .43018 .57083 L p F P
0 0 0 r
s
.319 0 1 r
.41805 .53445 m .43018 .57083 L .45119 .60359 L p F P
0 0 0 r
s
1 .698 0 r
.38973 .27625 m .37734 .24341 L .35583 .2492 L p F P
0 0 0 r
s
1 .431 0 r
.343 .22283 m .35583 .2492 L .37734 .24341 L p F P
0 0 0 r
s
1 .103 0 r
.27324 .19581 m .28706 .21485 L .30832 .20749 L p F P
0 0 0 r
s
1 .082 0 r
.28706 .21485 m .27324 .19581 L .25205 .20388 L p F P
0 0 0 r
s
1 .631 0 r
.494 .98003 m .50634 .99007 L .52865 .98465 L p F P
0 0 0 r
s
1 .477 0 r
.50634 .99007 m .494 .98003 L .47176 .98549 L p F P
0 0 0 r
s
.319 0 1 r
.45119 .60359 m .43898 .5627 L .41805 .53445 L p F P
0 0 0 r
s
.616 1 0 r
.66342 .31045 m .65193 .28592 L .62994 .31794 L p F P
0 0 0 r
s
.616 1 0 r
.62994 .31794 m .64174 .34638 L .66342 .31045 L p F P
0 0 0 r
s
1 .615 0 r
.55115 .97919 m .56304 .98924 L .58561 .98381 L p F P
0 0 0 r
s
1 .515 0 r
.56304 .98924 m .55115 .97919 L .52865 .98465 L p F P
0 0 0 r
s
1 .123 0 r
.77514 .21011 m .76488 .19315 L .74173 .20546 L p F P
0 0 0 r
s
1 .465 0 r
.60838 .97834 m .61982 .98841 L .64265 .98297 L p F P
0 0 0 r
s
1 .431 0 r
.61982 .98841 m .60838 .97834 L .58561 .98381 L p F P
0 0 0 r
s
0 1 .182 r
.65332 .3714 m .64174 .34638 L .62 .38823 L p F P
0 0 0 r
s
0 1 .182 r
.62 .38823 m .63189 .41694 L .65332 .3714 L p F P
0 0 0 r
s
1 .103 0 r
.28755 .97792 m .30154 .98799 L .32301 .98255 L p F P
0 0 0 r
s
1 .273 0 r
.66568 .9775 m .67668 .98757 L .69977 .98213 L p F P
0 0 0 r
s
1 .28 0 r
.67668 .98757 m .66568 .9775 L .64265 .98297 L p F P
0 0 0 r
s
1 .253 0 r
.34466 .97707 m .35821 .98716 L .37993 .98171 L p F P
0 0 0 r
s
1 .148 0 r
.35821 .98716 m .34466 .97707 L .32301 .98255 L p F P
0 0 0 r
s
1 .318 0 r
.68523 .21733 m .69631 .23755 L .71887 .21995 L p F P
0 0 0 r
s
1 .515 0 r
.69631 .23755 m .68523 .21733 L .66267 .23674 L p F P
0 0 0 r
s
1 .515 0 r
.66267 .23674 m .67402 .25926 L .69631 .23755 L p F P
0 0 0 r
s
0 1 .882 r
.43692 .47088 m .42526 .41389 L .40382 .40791 L p F P
0 0 0 r
s
0 1 .882 r
.40382 .40791 m .41539 .46021 L .43692 .47088 L p F P
0 0 0 r
s
1 0 .577 r
.56777 .64932 m .5562 .66929 L .5334 .67617 L p F P
0 0 0 r
s
1 .123 0 r
.72306 .97665 m .73361 .98674 L .75696 .98129 L p F P
0 0 0 r
s
1 .14 0 r
.73361 .98674 m .72306 .97665 L .69977 .98213 L p F P
0 0 0 r
s
1 .793 0 r
.67402 .25926 m .66267 .23674 L .64029 .26013 L p F P
0 0 0 r
s
1 .793 0 r
.64029 .26013 m .65193 .28592 L .67402 .25926 L p F P
0 0 0 r
s
1 .477 0 r
.40184 .97622 m .41495 .98632 L .43693 .98087 L p F P
0 0 0 r
s
1 .31 0 r
.41495 .98632 m .40184 .97622 L .37993 .98171 L p F P
0 0 0 r
s
.841 1 0 r
.4236 .31078 m .41151 .27017 L .38973 .27625 L p F P
0 0 0 r
s
.841 1 0 r
.38973 .27625 m .4018 .3154 L .4236 .31078 L p F P
0 0 0 r
s
1 .753 0 r
.37734 .24341 m .38973 .27625 L .41151 .27017 L p F P
0 0 0 r
s
1 .186 0 r
.70803 .20124 m .71887 .21995 L .74173 .20546 L p F P
0 0 0 r
s
1 .318 0 r
.71887 .21995 m .70803 .20124 L .68523 .21733 L p F P
0 0 0 r
s
1 .698 0 r
.4591 .97538 m .47176 .98549 L .494 .98003 L p F P
0 0 0 r
s
1 .502 0 r
.47176 .98549 m .4591 .97538 L .43693 .98087 L p F P
0 0 0 r
s
.306 1 0 r
.43549 .3587 m .4236 .31078 L .4018 .3154 L p F P
0 0 0 r
s
.306 1 0 r
.4018 .3154 m .4136 .36143 L .43549 .3587 L p F P
0 0 0 r
s
1 .431 0 r
.37734 .24341 m .36459 .21575 L .343 .22283 L p F P
0 0 0 r
s
1 .253 0 r
.32979 .19992 m .343 .22283 L .36459 .21575 L p F P
0 0 0 r
s
1 .222 0 r
.343 .22283 m .32979 .19992 L .30832 .20749 L p F P
0 0 0 r
s
1 .793 0 r
.51644 .97453 m .52865 .98465 L .55115 .97919 L p F P
0 0 0 r
s
1 .631 0 r
.52865 .98465 m .51644 .97453 L .494 .98003 L p F P
0 0 0 r
s
0 .891 1 r
.64346 .43901 m .63189 .41694 L .6102 .46729 L p F P
0 0 0 r
s
0 .891 1 r
.6102 .46729 m .62208 .49158 L .64346 .43901 L p F P
0 0 0 r
s
1 .123 0 r
.29463 .18766 m .30832 .20749 L .32979 .19992 L p F P
0 0 0 r
s
1 .103 0 r
.30832 .20749 m .29463 .18766 L .27324 .19581 L p F P
0 0 0 r
s
1 .698 0 r
.57385 .97367 m .58561 .98381 L .60838 .97834 L p F P
0 0 0 r
s
1 .615 0 r
.58561 .98381 m .57385 .97367 L .55115 .97919 L p F P
0 0 0 r
s
.841 1 0 r
.65193 .28592 m .64029 .26013 L .61801 .28781 L p F P
0 0 0 r
s
.841 1 0 r
.61801 .28781 m .62994 .31794 L .65193 .28592 L p F P
0 0 0 r
s
1 .753 0 r
.41151 .27017 m .39914 .23625 L .37734 .24341 L p F P
0 0 0 r
s
1 .465 0 r
.36459 .21575 m .37734 .24341 L .39914 .23625 L p F P
0 0 0 r
s
1 0 .712 r
.51088 .66618 m .49834 .67035 L .47633 .64455 L p F P
0 0 0 r
s
1 0 .577 r
.46368 .63168 m .47633 .64455 L .49834 .67035 L p F P
0 0 0 r
s
1 .477 0 r
.63134 .97282 m .64265 .98297 L .66568 .9775 L p F P
0 0 0 r
s
1 .465 0 r
.64265 .98297 m .63134 .97282 L .60838 .97834 L p F P
0 0 0 r
s
1 .103 0 r
.7311 .18767 m .74173 .20546 L .76488 .19315 L p F P
0 0 0 r
s
1 .186 0 r
.74173 .20546 m .7311 .18767 L .70803 .20124 L p F P
0 0 0 r
s
.077 1 0 r
.64174 .34638 m .62994 .31794 L .6079 .35491 L p F P
0 0 0 r
s
.077 1 0 r
.6079 .35491 m .62 .38823 L .64174 .34638 L p F P
0 0 0 r
s
.66 0 1 r
.62306 .56025 m .61194 .5593 L .58982 .60921 L p F P
0 0 0 r
s
.66 0 1 r
.58982 .60921 m .60127 .60744 L .62306 .56025 L p F P
0 0 0 r
s
1 .186 0 r
.30913 .9724 m .32301 .98255 L .34466 .97707 L p F P
0 0 0 r
s
1 .103 0 r
.32301 .98255 m .30913 .9724 L .28755 .97792 L p F P
0 0 0 r
s
1 .253 0 r
.68891 .97197 m .69977 .98213 L .72306 .97665 L p F P
0 0 0 r
s
1 .273 0 r
.69977 .98213 m .68891 .97197 L .66568 .9775 L p F P
0 0 0 r
s
1 .41 0 r
.3665 .97154 m .37993 .98171 L .40184 .97622 L p F P
0 0 0 r
s
1 .253 0 r
.37993 .98171 m .3665 .97154 L .34466 .97707 L p F P
0 0 0 r
s
0 1 .354 r
.44728 .41348 m .43549 .3587 L .4136 .36143 L p F P
0 0 0 r
s
0 1 .354 r
.4136 .36143 m .42526 .41389 L .44728 .41348 L p F P
0 0 0 r
s
1 0 .296 r
.49834 .67035 m .51088 .66618 L .5334 .67617 L p F P
0 0 0 r
s
1 .103 0 r
.74655 .97111 m .75696 .98129 L .78051 .9758 L p F P
0 0 0 r
s
1 .123 0 r
.75696 .98129 m .74655 .97111 L .72306 .97665 L p F P
0 0 0 r
s
.004 0 1 r
.63348 .50558 m .62208 .49158 L .60024 .54558 L p F P
0 0 0 r
s
.004 0 1 r
.60024 .54558 m .61194 .5593 L .63348 .50558 L p F P
0 0 0 r
s
1 .698 0 r
.42394 .97069 m .43693 .98087 L .4591 .97538 L p F P
0 0 0 r
s
1 .477 0 r
.43693 .98087 m .42394 .97069 L .40184 .97622 L p F P
0 0 0 r
s
0 .381 1 r
.44872 .52888 m .43692 .47088 L .41539 .46021 L p F P
0 0 0 r
s
0 .381 1 r
.41539 .46021 m .42707 .51327 L .44872 .52888 L p F P
0 0 0 r
s
1 .923 0 r
.48147 .96983 m .494 .98003 L .51644 .97453 L p F P
0 0 0 r
s
1 .698 0 r
.494 .98003 m .48147 .96983 L .4591 .97538 L p F P
0 0 0 r
s
1 .41 0 r
.65118 .21401 m .66267 .23674 L .68523 .21733 L p F P
0 0 0 r
s
1 .631 0 r
.66267 .23674 m .65118 .21401 L .62855 .23418 L p F P
0 0 0 r
s
1 .631 0 r
.62855 .23418 m .64029 .26013 L .66267 .23674 L p F P
0 0 0 r
s
.811 1 0 r
.44577 .30236 m .4336 .26158 L .41151 .27017 L p F P
0 0 0 r
s
.811 1 0 r
.41151 .27017 m .4236 .31078 L .44577 .30236 L p F P
0 0 0 r
s
1 .773 0 r
.39914 .23625 m .41151 .27017 L .4336 .26158 L p F P
0 0 0 r
s
1 .946 0 r
.53907 .96897 m .55115 .97919 L .57385 .97367 L p F P
0 0 0 r
s
1 .793 0 r
.55115 .97919 m .53907 .96897 L .51644 .97453 L p F P
0 0 0 r
s
1 .103 0 r
.76488 .19315 m .75446 .17585 L .7311 .18767 L p F P
0 0 0 r
s
1 .253 0 r
.674 .19688 m .68523 .21733 L .70803 .20124 L p F P
0 0 0 r
s
1 .41 0 r
.68523 .21733 m .674 .19688 L .65118 .21401 L p F P
0 0 0 r
s
1 .465 0 r
.39914 .23625 m .38644 .20782 L .36459 .21575 L p F P
0 0 0 r
s
1 .273 0 r
.35148 .19196 m .36459 .21575 L .38644 .20782 L p F P
0 0 0 r
s
1 .253 0 r
.36459 .21575 m .35148 .19196 L .32979 .19992 L p F P
0 0 0 r
s
.389 1 0 r
.62994 .31794 m .61801 .28781 L .5957 .3194 L p F P
0 0 0 r
s
.389 1 0 r
.5957 .3194 m .6079 .35491 L .62994 .31794 L p F P
0 0 0 r
s
1 .753 0 r
.59675 .96812 m .60838 .97834 L .63134 .97282 L p F P
0 0 0 r
s
1 .698 0 r
.60838 .97834 m .59675 .96812 L .57385 .97367 L p F P
0 0 0 r
s
.262 1 0 r
.45778 .35046 m .44577 .30236 L .4236 .31078 L p F P
0 0 0 r
s
.262 1 0 r
.4236 .31078 m .43549 .3587 L .45778 .35046 L p F P
0 0 0 r
s
1 .923 0 r
.64029 .26013 m .62855 .23418 L .60601 .25759 L p F P
0 0 0 r
s
1 .923 0 r
.60601 .25759 m .61801 .28781 L .64029 .26013 L p F P
0 0 0 r
s
1 .14 0 r
.31622 .17937 m .32979 .19992 L .35148 .19196 L p F P
0 0 0 r
s
1 .123 0 r
.32979 .19992 m .31622 .17937 L .29463 .18766 L p F P
0 0 0 r
s
1 .123 0 r
.27333 .96769 m .28755 .97792 L .30913 .9724 L p F P
0 0 0 r
s
0 1 .882 r
.63189 .41694 m .62 .38823 L .59802 .43429 L p F P
0 0 0 r
s
0 1 .882 r
.59802 .43429 m .6102 .46729 L .63189 .41694 L p F P
0 0 0 r
s
1 .465 0 r
.65451 .96726 m .66568 .9775 L .68891 .97197 L p F P
0 0 0 r
s
1 .477 0 r
.66568 .9775 m .65451 .96726 L .63134 .97282 L p F P
0 0 0 r
s
1 .773 0 r
.4336 .26158 m .42121 .2275 L .39914 .23625 L p F P
0 0 0 r
s
1 .477 0 r
.38644 .20782 m .39914 .23625 L .42121 .2275 L p F P
0 0 0 r
s
1 .318 0 r
.33089 .96683 m .34466 .97707 L .3665 .97154 L p F P
0 0 0 r
s
1 .186 0 r
.34466 .97707 m .33089 .96683 L .30913 .9724 L p F P
0 0 0 r
s
1 .148 0 r
.69703 .18228 m .70803 .20124 L .7311 .18767 L p F P
0 0 0 r
s
1 .253 0 r
.70803 .20124 m .69703 .18228 L .674 .19688 L p F P
0 0 0 r
s
1 .222 0 r
.71234 .96639 m .72306 .97665 L .74655 .97111 L p F P
0 0 0 r
s
1 .253 0 r
.72306 .97665 m .71234 .96639 L .68891 .97197 L p F P
0 0 0 r
s
1 .631 0 r
.38853 .96596 m .40184 .97622 L .42394 .97069 L p F P
0 0 0 r
s
1 .41 0 r
.40184 .97622 m .38853 .96596 L .3665 .97154 L p F P
0 0 0 r
s
1 .082 0 r
.77025 .96553 m .78051 .9758 L .80427 .97026 L p F P
0 0 0 r
s
1 .103 0 r
.78051 .9758 m .77025 .96553 L .74655 .97111 L p F P
0 0 0 r
s
0 .891 1 r
.45911 .47315 m .44728 .41348 L .42526 .41389 L p F P
0 0 0 r
s
0 .891 1 r
.42526 .41389 m .43692 .47088 L .45911 .47315 L p F P
0 0 0 r
s
1 .971 0 r
.44624 .9651 m .4591 .97538 L .48147 .96983 L p F P
0 0 0 r
s
1 .698 0 r
.4591 .97538 m .44624 .9651 L .42394 .97069 L p F P
0 0 0 r
s
.717 1 0 r
.61801 .28781 m .60601 .25759 L .58349 .28394 L p F P
0 0 0 r
s
.717 1 0 r
.58349 .28394 m .5957 .3194 L .61801 .28781 L p F P
0 0 0 r
s
.841 1 0 r
.50403 .96424 m .51644 .97453 L .53907 .96897 L p F P
0 0 0 r
s
1 .923 0 r
.51644 .97453 m .50403 .96424 L .48147 .96983 L p F P
0 0 0 r
s
.319 0 1 r
.46077 .58292 m .44872 .52888 L .42707 .51327 L p F P
0 0 0 r
s
.319 0 1 r
.42707 .51327 m .43898 .5627 L .46077 .58292 L p F P
0 0 0 r
s
0 1 .414 r
.46975 .40543 m .45778 .35046 L .43549 .3587 L p F P
0 0 0 r
s
0 1 .414 r
.43549 .3587 m .44728 .41348 L .46975 .40543 L p F P
0 0 0 r
s
.841 1 0 r
.4682 .29012 m .45595 .25047 L .4336 .26158 L p F P
0 0 0 r
s
.841 1 0 r
.4336 .26158 m .44577 .30236 L .4682 .29012 L p F P
0 0 0 r
s
1 .753 0 r
.42121 .2275 m .4336 .26158 L .45595 .25047 L p F P
0 0 0 r
s
.926 1 0 r
.5619 .96337 m .57385 .97367 L .59675 .96812 L p F P
0 0 0 r
s
1 .946 0 r
.57385 .97367 m .5619 .96337 L .53907 .96897 L p F P
0 0 0 r
s
0 1 .54 r
.62 .38823 m .6079 .35491 L .58566 .39534 L p F P
0 0 0 r
s
0 1 .54 r
.58566 .39534 m .59802 .43429 L .62 .38823 L p F P
0 0 0 r
s
1 .082 0 r
.72032 .16961 m .7311 .18767 L .75446 .17585 L p F P
0 0 0 r
s
1 .148 0 r
.7311 .18767 m .72032 .16961 L .69703 .18228 L p F P
0 0 0 r
s
1 0 .577 r
.49834 .67035 m .48569 .6575 L .46368 .63168 L p F P
0 0 0 r
s
1 0 .712 r
.45119 .60359 m .46368 .63168 L .48569 .6575 L p F P
0 0 0 r
s
1 .477 0 r
.42121 .2275 m .40853 .19892 L .38644 .20782 L p F P
0 0 0 r
s
1 .28 0 r
.37341 .1835 m .38644 .20782 L .40853 .19892 L p F P
0 0 0 r
s
1 .273 0 r
.38644 .20782 m .37341 .1835 L .35148 .19196 L p F P
0 0 0 r
s
1 .773 0 r
.61985 .96251 m .63134 .97282 L .65451 .96726 L p F P
0 0 0 r
s
1 .753 0 r
.63134 .97282 m .61985 .96251 L .59675 .96812 L p F P
0 0 0 r
s
.306 1 0 r
.48035 .33668 m .4682 .29012 L .44577 .30236 L p F P
0 0 0 r
s
.306 1 0 r
.44577 .30236 m .45778 .35046 L .48035 .33668 L p F P
0 0 0 r
s
1 .477 0 r
.61673 .20891 m .62855 .23418 L .65118 .21401 L p F P
0 0 0 r
s
1 .698 0 r
.62855 .23418 m .61673 .20891 L .59398 .22853 L p F P
0 0 0 r
s
1 .698 0 r
.59398 .22853 m .60601 .25759 L .62855 .23418 L p F P
0 0 0 r
s
1 .222 0 r
.29502 .96207 m .30913 .9724 L .33089 .96683 L p F P
0 0 0 r
s
1 .123 0 r
.30913 .9724 m .29502 .96207 L .27333 .96769 L p F P
0 0 0 r
s
1 .31 0 r
.6396 .19163 m .65118 .21401 L .674 .19688 L p F P
0 0 0 r
s
1 .477 0 r
.65118 .21401 m .6396 .19163 L .61673 .20891 L p F P
0 0 0 r
s
1 .152 0 r
.33803 .17083 m .35148 .19196 L .37341 .1835 L p F P
0 0 0 r
s
1 .14 0 r
.35148 .19196 m .33803 .17083 L .31622 .17937 L p F P
0 0 0 r
s
1 .431 0 r
.67787 .96164 m .68891 .97197 L .71234 .96639 L p F P
0 0 0 r
s
1 .465 0 r
.68891 .97197 m .67787 .96164 L .65451 .96726 L p F P
0 0 0 r
s
1 .753 0 r
.45595 .25047 m .44352 .21715 L .42121 .2275 L p F P
0 0 0 r
s
1 .465 0 r
.40853 .19892 m .42121 .2275 L .44352 .21715 L p F P
0 0 0 r
s
1 0 .712 r
.60127 .60744 m .58982 .60921 L .56715 .64936 L p F P
0 0 0 r
s
1 0 .712 r
.56715 .64936 m .57893 .64542 L .60127 .60744 L p F P
0 0 0 r
s
1 .515 0 r
.35285 .96121 m .3665 .97154 L .38853 .96596 L p F P
0 0 0 r
s
1 .318 0 r
.3665 .97154 m .35285 .96121 L .33089 .96683 L p F P
0 0 0 r
s
0 1 .127 r
.6079 .35491 m .5957 .3194 L .57327 .35368 L p F P
0 0 0 r
s
0 1 .127 r
.57327 .35368 m .58566 .39534 L .6079 .35491 L p F P
0 0 0 r
s
1 .971 0 r
.60601 .25759 m .59398 .22853 L .57128 .25023 L p F P
0 0 0 r
s
1 .971 0 r
.57128 .25023 m .58349 .28394 L .60601 .25759 L p F P
0 0 0 r
s
1 .186 0 r
.73598 .96077 m .74655 .97111 L .77025 .96553 L p F P
0 0 0 r
s
1 .222 0 r
.74655 .97111 m .73598 .96077 L .71234 .96639 L p F P
0 0 0 r
s
0 .096 1 r
.62208 .49158 m .6102 .46729 L .58808 .51894 L p F P
0 0 0 r
s
0 .096 1 r
.58808 .51894 m .60024 .54558 L .62208 .49158 L p F P
0 0 0 r
s
1 .923 0 r
.41075 .96034 m .42394 .97069 L .44624 .9651 L p F P
0 0 0 r
s
1 .631 0 r
.42394 .97069 m .41075 .96034 L .38853 .96596 L p F P
0 0 0 r
s
1 .191 0 r
.66264 .17653 m .674 .19688 L .69703 .18228 L p F P
0 0 0 r
s
1 .31 0 r
.674 .19688 m .66264 .17653 L .6396 .19163 L p F P
0 0 0 r
s
1 .061 0 r
.79416 .9599 m .80427 .97026 L .82824 .96467 L p F P
0 0 0 r
s
1 .082 0 r
.80427 .97026 m .79416 .9599 L .77025 .96553 L p F P
0 0 0 r
s
.306 1 0 r
.5957 .3194 m .58349 .28394 L .5609 .31226 L p F P
0 0 0 r
s
.306 1 0 r
.5609 .31226 m .57327 .35368 L .5957 .3194 L p F P
0 0 0 r
s
.717 1 0 r
.46873 .95947 m .48147 .96983 L .50403 .96424 L p F P
0 0 0 r
s
1 .971 0 r
.48147 .96983 m .46873 .95947 L .44624 .9651 L p F P
0 0 0 r
s
.901 0 1 r
.47311 .62743 m .46077 .58292 L .43898 .5627 L p F P
0 0 0 r
s
.901 0 1 r
.43898 .5627 m .45119 .60359 L .47311 .62743 L p F P
0 0 0 r
s
.926 1 0 r
.49081 .27463 m .47849 .23719 L .45595 .25047 L p F P
0 0 0 r
s
.926 1 0 r
.45595 .25047 m .4682 .29012 L .49081 .27463 L p F P
0 0 0 r
s
1 .698 0 r
.44352 .21715 m .45595 .25047 L .47849 .23719 L p F P
0 0 0 r
s
1 .082 0 r
.75446 .17585 m .74387 .15828 L .72032 .16961 L p F P
0 0 0 r
s
1 0 .15 r
.52105 .68141 m .5334 .67617 L .5562 .66929 L p F P
0 0 0 r
s
1 0 .296 r
.5334 .67617 m .52105 .68141 L .49834 .67035 L p F P
0 0 0 r
s
.616 1 0 r
.52679 .9586 m .53907 .96897 L .5619 .96337 L p F P
0 0 0 r
s
.841 1 0 r
.53907 .96897 m .52679 .9586 L .50403 .96424 L p F P
0 0 0 r
s
.43 1 0 r
.50308 .31821 m .49081 .27463 L .4682 .29012 L p F P
0 0 0 r
s
.43 1 0 r
.4682 .29012 m .48035 .33668 L .50308 .31821 L p F P
0 0 0 r
s
1 0 .712 r
.48569 .6575 m .47311 .62743 L .45119 .60359 L p F P
0 0 0 r
s
.717 1 0 r
.58349 .28394 m .57128 .25023 L .54858 .2733 L p F P
0 0 0 r
s
.717 1 0 r
.54858 .2733 m .5609 .31226 L .58349 .28394 L p F P
0 0 0 r
s
0 1 .354 r
.4925 .3897 m .48035 .33668 L .45778 .35046 L p F P
0 0 0 r
s
0 1 .354 r
.45778 .35046 m .46975 .40543 L .4925 .3897 L p F P
0 0 0 r
s
.841 1 0 r
.58493 .95772 m .59675 .96812 L .61985 .96251 L p F P
0 0 0 r
s
.926 1 0 r
.59675 .96812 m .58493 .95772 L .5619 .96337 L p F P
0 0 0 r
s
1 .14 0 r
.25888 .95729 m .27333 .96769 L .29502 .96207 L p F P
0 0 0 r
s
1 .111 0 r
.68589 .16328 m .69703 .18228 L .72032 .16961 L p F P
0 0 0 r
s
1 .191 0 r
.69703 .18228 m .68589 .16328 L .66264 .17653 L p F P
0 0 0 r
s
0 .096 1 r
.4711 .53397 m .45911 .47315 L .43692 .47088 L p F P
0 0 0 r
s
0 .096 1 r
.43692 .47088 m .44872 .52888 L .4711 .53397 L p F P
0 0 0 r
s
1 .465 0 r
.44352 .21715 m .43085 .18902 L .40853 .19892 L p F P
0 0 0 r
s
1 .273 0 r
.39556 .17444 m .40853 .19892 L .43085 .18902 L p F P
0 0 0 r
s
1 .28 0 r
.40853 .19892 m .39556 .17444 L .37341 .1835 L p F P
0 0 0 r
s
1 .753 0 r
.64315 .95685 m .65451 .96726 L .67787 .96164 L p F P
0 0 0 r
s
1 .773 0 r
.65451 .96726 m .64315 .95685 L .61985 .96251 L p F P
0 0 0 r
s
.779 0 1 r
.61194 .5593 m .60024 .54558 L .57783 .59577 L p F P
0 0 0 r
s
.779 0 1 r
.57783 .59577 m .58982 .60921 L .61194 .5593 L p F P
0 0 0 r
s
1 .698 0 r
.47849 .23719 m .46603 .20541 L .44352 .21715 L p F P
0 0 0 r
s
1 .431 0 r
.43085 .18902 m .44352 .21715 L .46603 .20541 L p F P
0 0 0 r
s
1 .502 0 r
.5819 .20135 m .59398 .22853 L .61673 .20891 L p F P
0 0 0 r
s
1 .698 0 r
.59398 .22853 m .5819 .20135 L .55906 .21925 L p F P
0 0 0 r
s
1 .698 0 r
.55906 .21925 m .57128 .25023 L .59398 .22853 L p F P
0 0 0 r
s
1 .38 0 r
.3169 .95641 m .33089 .96683 L .35285 .96121 L p F P
0 0 0 r
s
1 .222 0 r
.33089 .96683 m .3169 .95641 L .29502 .96207 L p F P
0 0 0 r
s
0 .811 1 r
.48179 .46531 m .46975 .40543 L .44728 .41348 L p F P
0 0 0 r
s
0 .811 1 r
.44728 .41348 m .45911 .47315 L .48179 .46531 L p F P
0 0 0 r
s
1 .923 0 r
.57128 .25023 m .55906 .21925 L .53627 .23805 L p F P
0 0 0 r
s
1 .923 0 r
.53627 .23805 m .54858 .2733 L .57128 .25023 L p F P
0 0 0 r
s
1 .38 0 r
.70144 .95597 m .71234 .96639 L .73598 .96077 L p F P
0 0 0 r
s
1 .431 0 r
.71234 .96639 m .70144 .95597 L .67787 .96164 L p F P
0 0 0 r
s
1 .343 0 r
.60484 .18485 m .61673 .20891 L .6396 .19163 L p F P
0 0 0 r
s
1 .502 0 r
.61673 .20891 m .60484 .18485 L .5819 .20135 L p F P
0 0 0 r
s
.616 1 0 r
.52584 .2965 m .51352 .25688 L .49081 .27463 L p F P
0 0 0 r
s
.616 1 0 r
.49081 .27463 m .50308 .31821 L .52584 .2965 L p F P
0 0 0 r
s
1 .946 0 r
.47849 .23719 m .49081 .27463 L .51352 .25688 L p F P
0 0 0 r
s
1 .156 0 r
.36005 .16197 m .37341 .1835 L .39556 .17444 L p F P
0 0 0 r
s
1 .152 0 r
.37341 .1835 m .36005 .16197 L .33803 .17083 L p F P
0 0 0 r
s
1 .793 0 r
.37499 .95554 m .38853 .96596 L .41075 .96034 L p F P
0 0 0 r
s
1 .515 0 r
.38853 .96596 m .37499 .95554 L .35285 .96121 L p F P
0 0 0 r
s
1 .946 0 r
.51352 .25688 m .50116 .2224 L .47849 .23719 L p F P
0 0 0 r
s
1 .615 0 r
.46603 .20541 m .47849 .23719 L .50116 .2224 L p F P
0 0 0 r
s
1 .148 0 r
.75982 .9551 m .77025 .96553 L .79416 .9599 L p F P
0 0 0 r
s
1 .186 0 r
.77025 .96553 m .75982 .9551 L .73598 .96077 L p F P
0 0 0 r
s
.389 1 0 r
.5609 .31226 m .54858 .2733 L .52584 .2965 L p F P
0 0 0 r
s
.841 1 0 r
.54858 .2733 m .53627 .23805 L .51352 .25688 L p F P
0 0 0 r
s
.841 1 0 r
.51352 .25688 m .52584 .2965 L .54858 .2733 L p F P
0 0 0 r
s
0 1 .127 r
.57327 .35368 m .5609 .31226 L .53819 .34086 L p F P
0 0 0 r
s
.389 1 0 r
.52584 .2965 m .53819 .34086 L .5609 .31226 L p F P
0 0 0 r
s
.717 1 0 r
.43317 .95466 m .44624 .9651 L .46873 .95947 L p F P
0 0 0 r
s
1 .923 0 r
.44624 .9651 m .43317 .95466 L .41075 .96034 L p F P
0 0 0 r
s
0 1 .182 r
.51537 .36749 m .50308 .31821 L .48035 .33668 L p F P
0 0 0 r
s
0 1 .182 r
.48035 .33668 m .4925 .3897 L .51537 .36749 L p F P
0 0 0 r
s
1 .793 0 r
.50116 .2224 m .51352 .25688 L .53627 .23805 L p F P
0 0 0 r
s
0 .381 1 r
.6102 .46729 m .59802 .43429 L .57566 .48141 L p F P
0 0 0 r
s
0 .381 1 r
.57566 .48141 m .58808 .51894 L .6102 .46729 L p F P
0 0 0 r
s
1 0 .15 r
.5562 .66929 m .54411 .67446 L .52105 .68141 L p F P
0 0 0 r
s
1 0 .296 r
.57893 .64542 m .56715 .64936 L .54411 .67446 L p F P
0 0 0 r
s
1 0 .296 r
.54411 .67446 m .5562 .66929 L .57893 .64542 L p F P
0 0 0 r
s
1 .044 0 r
.81828 .95422 m .82824 .96467 L .85242 .95903 L p F P
0 0 0 r
s
1 .061 0 r
.82824 .96467 m .81828 .95422 L .79416 .9599 L p F P
0 0 0 r
s
1 .223 0 r
.62791 .16994 m .6396 .19163 L .66264 .17653 L p F P
0 0 0 r
s
1 .343 0 r
.6396 .19163 m .62791 .16994 L .60484 .18485 L p F P
0 0 0 r
s
.077 1 0 r
.53819 .34086 m .52584 .2965 L .50308 .31821 L p F P
0 0 0 r
s
1 0 .15 r
.48569 .6575 m .49834 .67035 L .52105 .68141 L p F P
0 0 0 r
s
.389 1 0 r
.49142 .95378 m .50403 .96424 L .52679 .9586 L p F P
0 0 0 r
s
.717 1 0 r
.50403 .96424 m .49142 .95378 L .46873 .95947 L p F P
0 0 0 r
s
.077 1 0 r
.50308 .31821 m .51537 .36749 L .53819 .34086 L p F P
0 0 0 r
s
1 .631 0 r
.52394 .20686 m .53627 .23805 L .55906 .21925 L p F P
0 0 0 r
s
1 .793 0 r
.53627 .23805 m .52394 .20686 L .50116 .2224 L p F P
0 0 0 r
s
0 1 .671 r
.58566 .39534 m .57327 .35368 L .55062 .38845 L p F P
0 0 0 r
s
0 1 .127 r
.53819 .34086 m .55062 .38845 L .57327 .35368 L p F P
0 0 0 r
s
1 .061 0 r
.70938 .15141 m .72032 .16961 L .74387 .15828 L p F P
0 0 0 r
s
1 .111 0 r
.72032 .16961 m .70938 .15141 L .68589 .16328 L p F P
0 0 0 r
s
.43 1 0 r
.54975 .9529 m .5619 .96337 L .58493 .95772 L p F P
0 0 0 r
s
.616 1 0 r
.5619 .96337 m .54975 .9529 L .52679 .9586 L p F P
0 0 0 r
s
1 .515 0 r
.4887 .19269 m .50116 .2224 L .52394 .20686 L p F P
0 0 0 r
s
1 .615 0 r
.50116 .2224 m .4887 .19269 L .46603 .20541 L p F P
0 0 0 r
s
1 .477 0 r
.5468 .1913 m .55906 .21925 L .5819 .20135 L p F P
0 0 0 r
s
1 .631 0 r
.55906 .21925 m .5468 .1913 L .52394 .20686 L p F P
0 0 0 r
s
1 .38 0 r
.45338 .17827 m .46603 .20541 L .4887 .19269 L p F P
0 0 0 r
s
1 .431 0 r
.46603 .20541 m .45338 .17827 L .43085 .18902 L p F P
0 0 0 r
s
0 .811 1 r
.59802 .43429 m .58566 .39534 L .56313 .43654 L p F P
0 0 0 r
s
0 1 .671 r
.55062 .38845 m .56313 .43654 L .58566 .39534 L p F P
0 0 0 r
s
.811 1 0 r
.60817 .95202 m .61985 .96251 L .64315 .95685 L p F P
0 0 0 r
s
.841 1 0 r
.61985 .96251 m .60817 .95202 L .58493 .95772 L p F P
0 0 0 r
s
0 .811 1 r
.56313 .43654 m .57566 .48141 L .59802 .43429 L p F P
0 0 0 r
s
1 .253 0 r
.41793 .16478 m .43085 .18902 L .45338 .17827 L p F P
0 0 0 r
s
1 .273 0 r
.43085 .18902 m .41793 .16478 L .39556 .17444 L p F P
0 0 0 r
s
1 .253 0 r
.28068 .95158 m .29502 .96207 L .3169 .95641 L p F P
0 0 0 r
s
1 .14 0 r
.29502 .96207 m .28068 .95158 L .25888 .95729 L p F P
0 0 0 r
s
1 .137 0 r
.65116 .15652 m .66264 .17653 L .68589 .16328 L p F P
0 0 0 r
s
1 .223 0 r
.66264 .17653 m .65116 .15652 L .62791 .16994 L p F P
0 0 0 r
s
0 1 .54 r
.55062 .38845 m .53819 .34086 L .51537 .36749 L p F P
0 0 0 r
s
1 .698 0 r
.66666 .95114 m .67787 .96164 L .70144 .95597 L p F P
0 0 0 r
s
1 .753 0 r
.67787 .96164 m .66666 .95114 L .64315 .95685 L p F P
0 0 0 r
s
1 .343 0 r
.56977 .17629 m .5819 .20135 L .60484 .18485 L p F P
0 0 0 r
s
1 .477 0 r
.5819 .20135 m .56977 .17629 L .5468 .1913 L p F P
0 0 0 r
s
1 .615 0 r
.33897 .9507 m .35285 .96121 L .37499 .95554 L p F P
0 0 0 r
s
1 .38 0 r
.35285 .96121 m .33897 .9507 L .3169 .95641 L p F P
0 0 0 r
s
0 .891 1 r
.50475 .4473 m .4925 .3897 L .46975 .40543 L p F P
0 0 0 r
s
0 .891 1 r
.46975 .40543 m .48179 .46531 L .50475 .4473 L p F P
0 0 0 r
s
1 .318 0 r
.72523 .95026 m .73598 .96077 L .75982 .9551 L p F P
0 0 0 r
s
1 .38 0 r
.73598 .96077 m .72523 .95026 L .70144 .95597 L p F P
0 0 0 r
s
1 .152 0 r
.38228 .15276 m .39556 .17444 L .41793 .16478 L p F P
0 0 0 r
s
1 .156 0 r
.39556 .17444 m .38228 .15276 L .36005 .16197 L p F P
0 0 0 r
s
1 .41 0 r
.51151 .17947 m .52394 .20686 L .5468 .1913 L p F P
0 0 0 r
s
1 .515 0 r
.52394 .20686 m .51151 .17947 L .4887 .19269 L p F P
0 0 0 r
s
.841 1 0 r
.39734 .94982 m .41075 .96034 L .43317 .95466 L p F P
0 0 0 r
s
1 .793 0 r
.41075 .96034 m .39734 .94982 L .37499 .95554 L p F P
0 0 0 r
s
1 .111 0 r
.78388 .94937 m .79416 .9599 L .81828 .95422 L p F P
0 0 0 r
s
1 .148 0 r
.79416 .9599 m .78388 .94937 L .75982 .9551 L p F P
0 0 0 r
s
1 .234 0 r
.59286 .16217 m .60484 .18485 L .62791 .16994 L p F P
0 0 0 r
s
1 .343 0 r
.60484 .18485 m .59286 .16217 L .56977 .17629 L p F P
0 0 0 r
s
.306 1 0 r
.45579 .94893 m .46873 .95947 L .49142 .95378 L p F P
0 0 0 r
s
.717 1 0 r
.46873 .95947 m .45579 .94893 L .43317 .95466 L p F P
0 0 0 r
s
0 1 .54 r
.51537 .36749 m .52775 .42074 L .55062 .38845 L p F P
0 0 0 r
s
0 1 .882 r
.52775 .42074 m .51537 .36749 L .4925 .3897 L p F P
0 0 0 r
s
1 .061 0 r
.74387 .15828 m .73311 .14051 L .70938 .15141 L p F P
0 0 0 r
s
.66 0 1 r
.48334 .59067 m .4711 .53397 L .44872 .52888 L p F P
0 0 0 r
s
.66 0 1 r
.44872 .52888 m .46077 .58292 L .48334 .59067 L p F P
0 0 0 r
s
1 .029 0 r
.84261 .94849 m .85242 .95903 L .87681 .95334 L p F P
0 0 0 r
s
1 .044 0 r
.85242 .95903 m .84261 .94849 L .81828 .95422 L p F P
0 0 0 r
s
1 .318 0 r
.47608 .1669 m .4887 .19269 L .51151 .17947 L p F P
0 0 0 r
s
1 .38 0 r
.4887 .19269 m .47608 .1669 L .45338 .17827 L p F P
0 0 0 r
s
0 1 .882 r
.4925 .3897 m .50475 .4473 L .52775 .42074 L p F P
0 0 0 r
s
.077 1 0 r
.51431 .94805 m .52679 .9586 L .54975 .9529 L p F P
0 0 0 r
s
.389 1 0 r
.52679 .9586 m .51431 .94805 L .49142 .95378 L p F P
0 0 0 r
s
1 .08 0 r
.67461 .14436 m .68589 .16328 L .70938 .15141 L p F P
0 0 0 r
s
1 .137 0 r
.68589 .16328 m .67461 .14436 L .65116 .15652 L p F P
0 0 0 r
s
1 .31 0 r
.53446 .16619 m .5468 .1913 L .56977 .17629 L p F P
0 0 0 r
s
1 .41 0 r
.5468 .1913 m .53446 .16619 L .51151 .17947 L p F P
0 0 0 r
s
0 .811 1 r
.56313 .43654 m .55062 .38845 L .52775 .42074 L p F P
0 0 0 r
s
.306 1 0 r
.57292 .94716 m .58493 .95772 L .60817 .95202 L p F P
0 0 0 r
s
.43 1 0 r
.58493 .95772 m .57292 .94716 L .54975 .9529 L p F P
0 0 0 r
s
.004 0 1 r
.494 .52634 m .48179 .46531 L .45911 .47315 L p F P
0 0 0 r
s
.004 0 1 r
.45911 .47315 m .4711 .53397 L .494 .52634 L p F P
0 0 0 r
s
1 .152 0 r
.2442 .94672 m .25888 .95729 L .28068 .95158 L p F P
0 0 0 r
s
1 .222 0 r
.4405 .1546 m .45338 .17827 L .47608 .1669 L p F P
0 0 0 r
s
1 .253 0 r
.45338 .17827 m .4405 .1546 L .41793 .16478 L p F P
0 0 0 r
s
.841 1 0 r
.63161 .94627 m .64315 .95685 L .66666 .95114 L p F P
0 0 0 r
s
.811 1 0 r
.64315 .95685 m .63161 .94627 L .60817 .95202 L p F P
0 0 0 r
s
.66 0 1 r
.60024 .54558 m .58808 .51894 L .56544 .56693 L p F P
0 0 0 r
s
.66 0 1 r
.56544 .56693 m .57783 .59577 L .60024 .54558 L p F P
0 0 0 r
s
1 .152 0 r
.61611 .14906 m .62791 .16994 L .65116 .15652 L p F P
0 0 0 r
s
1 .234 0 r
.62791 .16994 m .61611 .14906 L .59286 .16217 L p F P
0 0 0 r
s
1 .431 0 r
.30268 .94583 m .3169 .95641 L .33897 .9507 L p F P
0 0 0 r
s
1 .253 0 r
.3169 .95641 m .30268 .94583 L .28068 .95158 L p F P
0 0 0 r
s
1 .615 0 r
.69037 .94538 m .70144 .95597 L .72523 .95026 L p F P
0 0 0 r
s
1 .698 0 r
.70144 .95597 m .69037 .94538 L .66666 .95114 L p F P
0 0 0 r
s
1 .946 0 r
.36124 .94494 m .37499 .95554 L .39734 .94982 L p F P
0 0 0 r
s
1 .615 0 r
.37499 .95554 m .36124 .94494 L .33897 .9507 L p F P
0 0 0 r
s
1 .14 0 r
.40473 .14318 m .41793 .16478 L .4405 .1546 L p F P
0 0 0 r
s
1 .152 0 r
.41793 .16478 m .40473 .14318 L .38228 .15276 L p F P
0 0 0 r
s
1 0 .577 r
.58982 .60921 m .57783 .59577 L .55489 .63617 L p F P
0 0 0 r
s
1 0 .577 r
.55489 .63617 m .56715 .64936 L .58982 .60921 L p F P
0 0 0 r
s
1 .253 0 r
.49895 .15519 m .51151 .17947 L .53446 .16619 L p F P
0 0 0 r
s
1 .318 0 r
.51151 .17947 m .49895 .15519 L .47608 .1669 L p F P
0 0 0 r
s
1 .253 0 r
.74922 .94449 m .75982 .9551 L .78388 .94937 L p F P
0 0 0 r
s
1 .318 0 r
.75982 .9551 m .74922 .94449 L .72523 .95026 L p F P
0 0 0 r
s
1 .223 0 r
.55754 .15322 m .56977 .17629 L .59286 .16217 L p F P
0 0 0 r
s
1 .31 0 r
.56977 .17629 m .55754 .15322 L .53446 .16619 L p F P
0 0 0 r
s
.389 1 0 r
.41988 .94405 m .43317 .95466 L .45579 .94893 L p F P
0 0 0 r
s
.841 1 0 r
.43317 .95466 m .41988 .94405 L .39734 .94982 L p F P
0 0 0 r
s
1 .08 0 r
.80815 .9436 m .81828 .95422 L .84261 .94849 L p F P
0 0 0 r
s
1 .111 0 r
.81828 .95422 m .80815 .9436 L .78388 .94937 L p F P
0 0 0 r
s
1 0 .15 r
.52105 .68141 m .50845 .66852 L .48569 .6575 L p F P
0 0 0 r
s
1 0 .296 r
.47311 .62743 m .48569 .6575 L .50845 .66852 L p F P
0 0 0 r
s
1 .044 0 r
.69829 .13314 m .70938 .15141 L .73311 .14051 L p F P
0 0 0 r
s
1 .08 0 r
.70938 .15141 m .69829 .13314 L .67461 .14436 L p F P
0 0 0 r
s
0 1 .127 r
.47861 .94315 m .49142 .95378 L .51431 .94805 L p F P
0 0 0 r
s
.306 1 0 r
.49142 .95378 m .47861 .94315 L .45579 .94893 L p F P
0 0 0 r
s
0 .194 1 r
.57566 .48141 m .56313 .43654 L .54026 .47478 L p F P
0 0 0 r
s
0 .811 1 r
.52775 .42074 m .54026 .47478 L .56313 .43654 L p F P
0 0 0 r
s
1 .018 0 r
.86715 .94271 m .87681 .95334 L .90142 .9476 L p F P
0 0 0 r
s
1 .029 0 r
.87681 .95334 m .86715 .94271 L .84261 .94849 L p F P
0 0 0 r
s
1 .093 0 r
.63954 .13691 m .65116 .15652 L .67461 .14436 L p F P
0 0 0 r
s
1 .152 0 r
.65116 .15652 m .63954 .13691 L .61611 .14906 L p F P
0 0 0 r
s
0 1 .182 r
.53741 .94226 m .54975 .9529 L .57292 .94716 L p F P
0 0 0 r
s
.077 1 0 r
.54975 .9529 m .53741 .94226 L .51431 .94805 L p F P
0 0 0 r
s
0 .381 1 r
.54026 .47478 m .52775 .42074 L .50475 .4473 L p F P
0 0 0 r
s
1 0 .712 r
.49582 .63728 m .48334 .59067 L .46077 .58292 L p F P
0 0 0 r
s
1 0 .712 r
.46077 .58292 m .47311 .62743 L .49582 .63728 L p F P
0 0 0 r
s
1 .186 0 r
.46326 .14403 m .47608 .1669 L .49895 .15519 L p F P
0 0 0 r
s
1 .222 0 r
.47608 .1669 m .46326 .14403 L .4405 .1546 L p F P
0 0 0 r
s
.262 1 0 r
.59629 .94137 m .60817 .95202 L .63161 .94627 L p F P
0 0 0 r
s
.306 1 0 r
.60817 .95202 m .59629 .94137 L .57292 .94716 L p F P
0 0 0 r
s
1 .152 0 r
.58077 .14078 m .59286 .16217 L .61611 .14906 L p F P
0 0 0 r
s
1 .223 0 r
.59286 .16217 m .58077 .14078 L .55754 .15322 L p F P
0 0 0 r
s
0 .096 1 r
.51715 .50592 m .50475 .4473 L .48179 .46531 L p F P
0 0 0 r
s
0 .096 1 r
.48179 .46531 m .494 .52634 L .51715 .50592 L p F P
0 0 0 r
s
.319 0 1 r
.58808 .51894 m .57566 .48141 L .55286 .52516 L p F P
0 0 0 r
s
.319 0 1 r
.55286 .52516 m .56544 .56693 L .58808 .51894 L p F P
0 0 0 r
s
1 .273 0 r
.26611 .94092 m .28068 .95158 L .30268 .94583 L p F P
0 0 0 r
s
1 .152 0 r
.28068 .95158 m .26611 .94092 L .2442 .94672 L p F P
0 0 0 r
s
1 0 0 r
.50845 .66852 m .52105 .68141 L .54411 .67446 L p F P
0 0 0 r
s
1 .191 0 r
.52198 .14342 m .53446 .16619 L .55754 .15322 L p F P
0 0 0 r
s
1 .253 0 r
.53446 .16619 m .52198 .14342 L .49895 .15519 L p F P
0 0 0 r
s
.926 1 0 r
.65525 .94047 m .66666 .95114 L .69037 .94538 L p F P
0 0 0 r
s
.841 1 0 r
.66666 .95114 m .65525 .94047 L .63161 .94627 L p F P
0 0 0 r
s
0 .194 1 r
.54026 .47478 m .55286 .52516 L .57566 .48141 L p F P
0 0 0 r
s
1 .698 0 r
.32487 .94002 m .33897 .9507 L .36124 .94494 L p F P
0 0 0 r
s
1 .431 0 r
.33897 .9507 m .32487 .94002 L .30268 .94583 L p F P
0 0 0 r
s
0 .381 1 r
.50475 .4473 m .51715 .50592 L .54026 .47478 L p F P
0 0 0 r
s
1 0 .296 r
.50845 .66852 m .49582 .63728 L .47311 .62743 L p F P
0 0 0 r
s
1 .515 0 r
.7143 .93957 m .72523 .95026 L .74922 .94449 L p F P
0 0 0 r
s
1 .615 0 r
.72523 .95026 m .7143 .93957 L .69037 .94538 L p F P
0 0 0 r
s
1 .123 0 r
.42738 .13329 m .4405 .1546 L .46326 .14403 L p F P
0 0 0 r
s
1 .14 0 r
.4405 .1546 m .42738 .13329 L .40473 .14318 L p F P
0 0 0 r
s
.616 1 0 r
.38371 .93912 m .39734 .94982 L .41988 .94405 L p F P
0 0 0 r
s
1 .946 0 r
.39734 .94982 m .38371 .93912 L .36124 .94494 L p F P
0 0 0 r
s
1 .191 0 r
.77343 .93867 m .78388 .94937 L .80815 .9436 L p F P
0 0 0 r
s
1 .253 0 r
.78388 .94937 m .77343 .93867 L .74922 .94449 L p F P
0 0 0 r
s
0 1 .127 r
.44263 .93822 m .45579 .94893 L .47861 .94315 L p F P
0 0 0 r
s
.389 1 0 r
.45579 .94893 m .44263 .93822 L .41988 .94405 L p F P
0 0 0 r
s
1 .044 0 r
.73311 .14051 m .7222 .12256 L .69829 .13314 L p F P
0 0 0 r
s
1 .054 0 r
.66318 .12556 m .67461 .14436 L .69829 .13314 L p F P
0 0 0 r
s
1 .093 0 r
.67461 .14436 m .66318 .12556 L .63954 .13691 L p F P
0 0 0 r
s
1 .054 0 r
.83263 .93777 m .84261 .94849 L .86715 .94271 L p F P
0 0 0 r
s
1 .08 0 r
.84261 .94849 m .83263 .93777 L .80815 .9436 L p F P
0 0 0 r
s
1 .148 0 r
.48621 .13324 m .49895 .15519 L .52198 .14342 L p F P
0 0 0 r
s
1 .186 0 r
.49895 .15519 m .48621 .13324 L .46326 .14403 L p F P
0 0 0 r
s
0 1 .54 r
.50163 .93732 m .51431 .94805 L .53741 .94226 L p F P
0 0 0 r
s
0 1 .127 r
.51431 .94805 m .50163 .93732 L .47861 .94315 L p F P
0 0 0 r
s
.779 0 1 r
.50643 .58325 m .494 .52634 L .4711 .53397 L p F P
0 0 0 r
s
.779 0 1 r
.4711 .53397 m .48334 .59067 L .50643 .58325 L p F P
0 0 0 r
s
1 .098 0 r
.60418 .12893 m .61611 .14906 L .63954 .13691 L p F P
0 0 0 r
s
1 .152 0 r
.61611 .14906 m .60418 .12893 L .58077 .14078 L p F P
0 0 0 r
s
1 .011 0 r
.89192 .93687 m .90142 .9476 L .92624 .94181 L p F P
0 0 0 r
s
1 .018 0 r
.90142 .9476 m .89192 .93687 L .86715 .94271 L p F P
0 0 0 r
s
1 .137 0 r
.54517 .13179 m .55754 .15322 L .58077 .14078 L p F P
0 0 0 r
s
1 .191 0 r
.55754 .15322 m .54517 .13179 L .52198 .14342 L p F P
0 0 0 r
s
1 0 .15 r
.56715 .64936 m .55489 .63617 L .53165 .66145 L p F P
0 0 0 r
s
1 0 .15 r
.53165 .66145 m .54411 .67446 L .56715 .64936 L p F P
0 0 0 r
s
0 1 .354 r
.56071 .93642 m .57292 .94716 L .59629 .94137 L p F P
0 0 0 r
s
0 1 .182 r
.57292 .94716 m .56071 .93642 L .53741 .94226 L p F P
0 0 0 r
s
1 .156 0 r
.22927 .93597 m .2442 .94672 L .26611 .94092 L p F P
0 0 0 r
s
.306 1 0 r
.61987 .93552 m .63161 .94627 L .65525 .94047 L p F P
0 0 0 r
s
.262 1 0 r
.63161 .94627 m .61987 .93552 L .59629 .94137 L p F P
0 0 0 r
s
.319 0 1 r
.55286 .52516 m .54026 .47478 L .51715 .50592 L p F P
0 0 0 r
s
1 .465 0 r
.28822 .93507 m .30268 .94583 L .32487 .94002 L p F P
0 0 0 r
s
1 .273 0 r
.30268 .94583 m .28822 .93507 L .26611 .94092 L p F P
0 0 0 r
s
1 0 0 r
.54411 .67446 m .53165 .66145 L .50845 .66852 L p F P
0 0 0 r
s
1 .946 0 r
.67912 .93462 m .69037 .94538 L .7143 .93957 L p F P
0 0 0 r
s
.926 1 0 r
.69037 .94538 m .67912 .93462 L .65525 .94047 L p F P
0 0 0 r
s
.926 1 0 r
.34726 .93416 m .36124 .94494 L .38371 .93912 L p F P
0 0 0 r
s
1 .698 0 r
.36124 .94494 m .34726 .93416 L .32487 .94002 L p F P
0 0 0 r
s
1 .103 0 r
.45022 .12315 m .46326 .14403 L .48621 .13324 L p F P
0 0 0 r
s
1 .123 0 r
.46326 .14403 m .45022 .12315 L .42738 .13329 L p F P
0 0 0 r
s
1 0 .712 r
.57783 .59577 m .56544 .56693 L .54235 .60563 L p F P
0 0 0 r
s
1 0 .712 r
.54235 .60563 m .55489 .63617 L .57783 .59577 L p F P
0 0 0 r
s
1 .41 0 r
.73844 .93371 m .74922 .94449 L .77343 .93867 L p F P
0 0 0 r
s
1 .515 0 r
.74922 .94449 m .73844 .93371 L .7143 .93957 L p F P
0 0 0 r
s
.077 1 0 r
.40638 .93326 m .41988 .94405 L .44263 .93822 L p F P
0 0 0 r
s
.616 1 0 r
.41988 .94405 m .40638 .93326 L .38371 .93912 L p F P
0 0 0 r
s
1 .029 0 r
.68703 .11481 m .69829 .13314 L .7222 .12256 L p F P
0 0 0 r
s
1 .054 0 r
.69829 .13314 m .68703 .11481 L .66318 .12556 L p F P
0 0 0 r
s
1 .137 0 r
.79785 .9328 m .80815 .9436 L .83263 .93777 L p F P
0 0 0 r
s
1 .191 0 r
.80815 .9436 m .79785 .9328 L .77343 .93867 L p F P
0 0 0 r
s
1 .111 0 r
.50934 .12236 m .52198 .14342 L .54517 .13179 L p F P
0 0 0 r
s
1 .148 0 r
.52198 .14342 m .50934 .12236 L .48621 .13324 L p F P
0 0 0 r
s
1 .06 0 r
.62778 .11766 m .63954 .13691 L .66318 .12556 L p F P
0 0 0 r
s
1 .098 0 r
.63954 .13691 m .62778 .11766 L .60418 .12893 L p F P
0 0 0 r
s
1 .093 0 r
.56854 .12043 m .58077 .14078 L .60418 .12893 L p F P
0 0 0 r
s
1 .137 0 r
.58077 .14078 m .56854 .12043 L .54517 .13179 L p F P
0 0 0 r
s
0 1 .671 r
.46558 .93235 m .47861 .94315 L .50163 .93732 L p F P
0 0 0 r
s
0 1 .127 r
.47861 .94315 m .46558 .93235 L .44263 .93822 L p F P
0 0 0 r
s
1 .034 0 r
.85734 .9319 m .86715 .94271 L .89192 .93687 L p F P
0 0 0 r
s
1 .054 0 r
.86715 .94271 m .85734 .9319 L .83263 .93777 L p F P
0 0 0 r
s
0 1 .882 r
.52486 .93144 m .53741 .94226 L .56071 .93642 L p F P
0 0 0 r
s
0 1 .54 r
.53741 .94226 m .52486 .93144 L .50163 .93732 L p F P
0 0 0 r
s
.66 0 1 r
.52971 .56057 m .51715 .50592 L .494 .52634 L p F P
0 0 0 r
s
.66 0 1 r
.494 .52634 m .50643 .58325 L .52971 .56057 L p F P
0 0 0 r
s
.319 0 1 r
.51715 .50592 m .52971 .56057 L .55286 .52516 L p F P
0 0 0 r
s
1 .005 0 r
.91691 .93099 m .92624 .94181 L .95129 .93597 L p F P
0 0 0 r
s
1 .011 0 r
.92624 .94181 m .91691 .93099 L .89192 .93687 L p F P
0 0 0 r
s
0 1 .414 r
.58422 .93053 m .59629 .94137 L .61987 .93552 L p F P
0 0 0 r
s
0 1 .354 r
.59629 .94137 m .58422 .93053 L .56071 .93642 L p F P
0 0 0 r
s
.901 0 1 r
.56544 .56693 m .55286 .52516 L .52971 .56057 L p F P
0 0 0 r
s
1 .28 0 r
.2513 .93008 m .26611 .94092 L .28822 .93507 L p F P
0 0 0 r
s
1 .156 0 r
.26611 .94092 m .2513 .93008 L .22927 .93597 L p F P
0 0 0 r
s
1 0 .15 r
.49582 .63728 m .50845 .66852 L .53165 .66145 L p F P
0 0 0 r
s
1 0 .577 r
.51902 .63005 m .50643 .58325 L .48334 .59067 L p F P
0 0 0 r
s
1 0 .577 r
.48334 .59067 m .49582 .63728 L .51902 .63005 L p F P
0 0 0 r
s
.43 1 0 r
.64366 .92962 m .65525 .94047 L .67912 .93462 L p F P
0 0 0 r
s
.306 1 0 r
.65525 .94047 m .64366 .92962 L .61987 .93552 L p F P
0 0 0 r
s
.901 0 1 r
.52971 .56057 m .54235 .60563 L .56544 .56693 L p F P
0 0 0 r
s
1 .753 0 r
.31053 .92917 m .32487 .94002 L .34726 .93416 L p F P
0 0 0 r
s
1 .465 0 r
.32487 .94002 m .31053 .92917 L .28822 .93507 L p F P
0 0 0 r
s
1 .082 0 r
.47327 .11284 m .48621 .13324 L .50934 .12236 L p F P
0 0 0 r
s
1 .103 0 r
.48621 .13324 m .47327 .11284 L .45022 .12315 L p F P
0 0 0 r
s
1 .793 0 r
.70319 .92871 m .7143 .93957 L .73844 .93371 L p F P
0 0 0 r
s
1 .946 0 r
.7143 .93957 m .70319 .92871 L .67912 .93462 L p F P
0 0 0 r
s
.43 1 0 r
.36985 .92825 m .38371 .93912 L .40638 .93326 L p F P
0 0 0 r
s
.926 1 0 r
.38371 .93912 m .36985 .92825 L .34726 .93416 L p F P
0 0 0 r
s
1 .08 0 r
.53265 .11154 m .54517 .13179 L .56854 .12043 L p F P
0 0 0 r
s
1 .111 0 r
.54517 .13179 m .53265 .11154 L .50934 .12236 L p F P
0 0 0 r
s
1 .31 0 r
.7628 .9278 m .77343 .93867 L .79785 .9328 L p F P
0 0 0 r
s
1 .41 0 r
.77343 .93867 m .7628 .9278 L .73844 .93371 L p F P
0 0 0 r
s
1 .034 0 r
.65159 .10686 m .66318 .12556 L .68703 .11481 L p F P
0 0 0 r
s
1 .06 0 r
.66318 .12556 m .65159 .10686 L .62778 .11766 L p F P
0 0 0 r
s
1 .06 0 r
.5921 .1094 m .60418 .12893 L .62778 .11766 L p F P
0 0 0 r
s
1 .093 0 r
.60418 .12893 m .5921 .1094 L .56854 .12043 L p F P
0 0 0 r
s
1 .029 0 r
.7222 .12256 m .71111 .10445 L .68703 .11481 L p F P
0 0 0 r
s
0 1 .54 r
.42925 .92734 m .44263 .93822 L .46558 .93235 L p F P
0 0 0 r
s
.077 1 0 r
.44263 .93822 m .42925 .92734 L .40638 .93326 L p F P
0 0 0 r
s
1 .093 0 r
.82249 .92688 m .83263 .93777 L .85734 .9319 L p F P
0 0 0 r
s
1 .137 0 r
.83263 .93777 m .82249 .92688 L .79785 .9328 L p F P
0 0 0 r
s
1 0 .15 r
.53165 .66145 m .51902 .63005 L .49582 .63728 L p F P
0 0 0 r
s
0 .811 1 r
.48873 .92642 m .50163 .93732 L .52486 .93144 L p F P
0 0 0 r
s
0 1 .671 r
.50163 .93732 m .48873 .92642 L .46558 .93235 L p F P
0 0 0 r
s
1 .02 0 r
.88227 .92597 m .89192 .93687 L .91691 .93099 L p F P
0 0 0 r
s
1 .034 0 r
.89192 .93687 m .88227 .92597 L .85734 .9319 L p F P
0 0 0 r
s
1 0 .296 r
.55489 .63617 m .54235 .60563 L .51902 .63005 L p F P
0 0 0 r
s
1 0 .296 r
.51902 .63005 m .53165 .66145 L .55489 .63617 L p F P
0 0 0 r
s
0 .891 1 r
.5483 .92551 m .56071 .93642 L .58422 .93053 L p F P
0 0 0 r
s
0 1 .882 r
.56071 .93642 m .5483 .92551 L .52486 .93144 L p F P
0 0 0 r
s
1 .002 0 r
.94213 .92505 m .95129 .93597 L .97657 .93008 L p F P
0 0 0 r
s
1 .005 0 r
.95129 .93597 m .94213 .92505 L .91691 .93099 L p F P
0 0 0 r
s
1 .152 0 r
.21409 .92505 m .22927 .93597 L .2513 .93008 L p F P
0 0 0 r
s
0 1 .354 r
.60794 .92459 m .61987 .93552 L .64366 .92962 L p F P
0 0 0 r
s
0 1 .414 r
.61987 .93552 m .60794 .92459 L .58422 .93053 L p F P
0 0 0 r
s
1 0 .712 r
.54235 .60563 m .52971 .56057 L .50643 .58325 L p F P
0 0 0 r
s
1 .477 0 r
.27353 .92413 m .28822 .93507 L .31053 .92917 L p F P
0 0 0 r
s
1 .28 0 r
.28822 .93507 m .27353 .92413 L .2513 .93008 L p F P
0 0 0 r
s
1 0 .712 r
.50643 .58325 m .51902 .63005 L .54235 .60563 L p F P
0 0 0 r
s
.616 1 0 r
.66767 .92367 m .67912 .93462 L .70319 .92871 L p F P
0 0 0 r
s
.43 1 0 r
.67912 .93462 m .66767 .92367 L .64366 .92962 L p F P
0 0 0 r
s
1 .061 0 r
.4965 .10244 m .50934 .12236 L .53265 .11154 L p F P
0 0 0 r
s
1 .082 0 r
.50934 .12236 m .4965 .10244 L .47327 .11284 L p F P
0 0 0 r
s
.841 1 0 r
.33304 .92321 m .34726 .93416 L .36985 .92825 L p F P
0 0 0 r
s
1 .753 0 r
.34726 .93416 m .33304 .92321 L .31053 .92917 L p F P
0 0 0 r
s
1 .054 0 r
.55615 .10082 m .56854 .12043 L .5921 .1094 L p F P
0 0 0 r
s
1 .08 0 r
.56854 .12043 m .55615 .10082 L .53265 .11154 L p F P
0 0 0 r
s
1 .631 0 r
.72749 .92275 m .73844 .93371 L .7628 .9278 L p F P
0 0 0 r
s
1 .793 0 r
.73844 .93371 m .72749 .92275 L .70319 .92871 L p F P
0 0 0 r
s
1 .036 0 r
.61586 .09868 m .62778 .11766 L .65159 .10686 L p F P
0 0 0 r
s
1 .06 0 r
.62778 .11766 m .61586 .09868 L .5921 .1094 L p F P
0 0 0 r
s
1 .018 0 r
.67561 .09641 m .68703 .11481 L .71111 .10445 L p F P
0 0 0 r
s
1 .034 0 r
.68703 .11481 m .67561 .09641 L .65159 .10686 L p F P
0 0 0 r
s
0 1 .182 r
.39265 .92229 m .40638 .93326 L .42925 .92734 L p F P
0 0 0 r
s
.43 1 0 r
.40638 .93326 m .39265 .92229 L .36985 .92825 L p F P
0 0 0 r
s
1 .223 0 r
.78738 .92183 m .79785 .9328 L .82249 .92688 L p F P
0 0 0 r
s
1 .31 0 r
.79785 .9328 m .78738 .92183 L .7628 .9278 L p F P
0 0 0 r
s
0 .811 1 r
.45233 .92137 m .46558 .93235 L .48873 .92642 L p F P
0 0 0 r
s
0 1 .54 r
.46558 .93235 m .45233 .92137 L .42925 .92734 L p F P
0 0 0 r
s
1 .06 0 r
.84736 .9209 m .85734 .9319 L .88227 .92597 L p F P
0 0 0 r
s
1 .093 0 r
.85734 .9319 m .84736 .9209 L .82249 .92688 L p F P
0 0 0 r
s
0 .381 1 r
.5121 .92044 m .52486 .93144 L .5483 .92551 L p F P
0 0 0 r
s
0 .811 1 r
.52486 .93144 m .5121 .92044 L .48873 .92642 L p F P
0 0 0 r
s
1 .011 0 r
.90742 .91998 m .91691 .93099 L .94213 .92505 L p F P
0 0 0 r
s
1 .02 0 r
.91691 .93099 m .90742 .91998 L .88227 .92597 L p F P
0 0 0 r
s
0 .811 1 r
.57195 .91952 m .58422 .93053 L .60794 .92459 L p F P
0 0 0 r
s
0 .891 1 r
.58422 .93053 m .57195 .91952 L .5483 .92551 L p F P
0 0 0 r
s
1 .273 0 r
.23624 .91906 m .2513 .93008 L .27353 .92413 L p F P
0 0 0 r
s
1 .152 0 r
.2513 .93008 m .23624 .91906 L .21409 .92505 L p F P
0 0 0 r
s
1 .002 0 r
.97657 .93008 m .96757 .91906 L .94213 .92505 L p F P
0 0 0 r
s
0 1 .182 r
.63188 .91859 m .64366 .92962 L .66767 .92367 L p F P
0 0 0 r
s
0 1 .354 r
.64366 .92962 m .63188 .91859 L .60794 .92459 L p F P
0 0 0 r
s
1 .044 0 r
.51993 .09203 m .53265 .11154 L .55615 .10082 L p F P
0 0 0 r
s
1 .061 0 r
.53265 .11154 m .51993 .09203 L .4965 .10244 L p F P
0 0 0 r
s
1 .773 0 r
.29596 .91813 m .31053 .92917 L .33304 .92321 L p F P
0 0 0 r
s
1 .477 0 r
.31053 .92917 m .29596 .91813 L .27353 .92413 L p F P
0 0 0 r
s
.841 1 0 r
.6919 .91766 m .70319 .92871 L .72749 .92275 L p F P
0 0 0 r
s
.616 1 0 r
.70319 .92871 m .6919 .91766 L .66767 .92367 L p F P
0 0 0 r
s
1 .034 0 r
.57985 .09026 m .5921 .1094 L .61586 .09868 L p F P
0 0 0 r
s
1 .054 0 r
.5921 .1094 m .57985 .09026 L .55615 .10082 L p F P
0 0 0 r
s
1 .02 0 r
.63982 .0882 m .65159 .10686 L .67561 .09641 L p F P
0 0 0 r
s
1 .036 0 r
.65159 .10686 m .63982 .0882 L .61586 .09868 L p F P
0 0 0 r
s
.306 1 0 r
.35576 .9172 m .36985 .92825 L .39265 .92229 L p F P
0 0 0 r
s
.841 1 0 r
.36985 .92825 m .35576 .9172 L .33304 .92321 L p F P
0 0 0 r
s
1 .018 0 r
.71111 .10445 m .69986 .08617 L .67561 .09641 L p F P
0 0 0 r
s
1 .477 0 r
.752 .91674 m .7628 .9278 L .78738 .92183 L p F P
0 0 0 r
s
1 .631 0 r
.7628 .9278 m .752 .91674 L .72749 .92275 L p F P
0 0 0 r
s
0 1 .882 r
.41565 .91627 m .42925 .92734 L .45233 .92137 L p F P
0 0 0 r
s
0 1 .182 r
.42925 .92734 m .41565 .91627 L .39265 .92229 L p F P
0 0 0 r
s
1 .152 0 r
.81219 .91581 m .82249 .92688 L .84736 .9209 L p F P
0 0 0 r
s
1 .223 0 r
.82249 .92688 m .81219 .91581 L .78738 .92183 L p F P
0 0 0 r
s
0 .194 1 r
.47562 .91534 m .48873 .92642 L .5121 .92044 L p F P
0 0 0 r
s
0 .811 1 r
.48873 .92642 m .47562 .91534 L .45233 .92137 L p F P
0 0 0 r
s
1 .036 0 r
.87245 .91487 m .88227 .92597 L .90742 .91998 L p F P
0 0 0 r
s
1 .06 0 r
.88227 .92597 m .87245 .91487 L .84736 .9209 L p F P
0 0 0 r
s
0 .096 1 r
.53567 .91441 m .5483 .92551 L .57195 .91952 L p F P
0 0 0 r
s
0 .381 1 r
.5483 .92551 m .53567 .91441 L .5121 .92044 L p F P
0 0 0 r
s
1 .005 0 r
.93281 .91394 m .94213 .92505 L .96757 .91906 L p F P
0 0 0 r
s
1 .011 0 r
.94213 .92505 m .93281 .91394 L .90742 .91998 L p F P
0 0 0 r
s
1 .14 0 r
.19866 .91394 m .21409 .92505 L .23624 .91906 L p F P
0 0 0 r
s
0 .891 1 r
.59581 .91347 m .60794 .92459 L .63188 .91859 L p F P
0 0 0 r
s
0 .811 1 r
.60794 .92459 m .59581 .91347 L .57195 .91952 L p F P
0 0 0 r
s
1 .465 0 r
.25858 .91301 m .27353 .92413 L .29596 .91813 L p F P
0 0 0 r
s
1 .273 0 r
.27353 .92413 m .25858 .91301 L .23624 .91906 L p F P
0 0 0 r
s
1 .029 0 r
.54357 .08165 m .55615 .10082 L .57985 .09026 L p F P
0 0 0 r
s
1 .044 0 r
.55615 .10082 m .54357 .08165 L .51993 .09203 L p F P
0 0 0 r
s
.077 1 0 r
.65604 .91254 m .66767 .92367 L .6919 .91766 L p F P
0 0 0 r
s
0 1 .182 r
.66767 .92367 m .65604 .91254 L .63188 .91859 L p F P
0 0 0 r
s
1 .02 0 r
.60376 .07983 m .61586 .09868 L .63982 .0882 L p F P
0 0 0 r
s
1 .034 0 r
.61586 .09868 m .60376 .07983 L .57985 .09026 L p F P
0 0 0 r
s
.811 1 0 r
.31859 .91207 m .33304 .92321 L .35576 .9172 L p F P
0 0 0 r
s
1 .773 0 r
.33304 .92321 m .31859 .91207 L .29596 .91813 L p F P
0 0 0 r
s
1 .923 0 r
.71634 .9116 m .72749 .92275 L .752 .91674 L p F P
0 0 0 r
s
.841 1 0 r
.72749 .92275 m .71634 .9116 L .6919 .91766 L p F P
0 0 0 r
s
1 .011 0 r
.66401 .0779 m .67561 .09641 L .69986 .08617 L p F P
0 0 0 r
s
1 .02 0 r
.67561 .09641 m .66401 .0779 L .63982 .0882 L p F P
0 0 0 r
s
0 1 .354 r
.37868 .91114 m .39265 .92229 L .41565 .91627 L p F P
0 0 0 r
s
.306 1 0 r
.39265 .92229 m .37868 .91114 L .35576 .9172 L p F P
0 0 0 r
s
1 .343 0 r
.77674 .91067 m .78738 .92183 L .81219 .91581 L p F P
0 0 0 r
s
1 .477 0 r
.78738 .92183 m .77674 .91067 L .752 .91674 L p F P
0 0 0 r
s
0 .381 1 r
.43886 .9102 m .45233 .92137 L .47562 .91534 L p F P
0 0 0 r
s
0 1 .882 r
.45233 .92137 m .43886 .9102 L .41565 .91627 L p F P
0 0 0 r
s
1 .098 0 r
.83721 .90973 m .84736 .9209 L .87245 .91487 L p F P
0 0 0 r
s
1 .152 0 r
.84736 .9209 m .83721 .90973 L .81219 .91581 L p F P
0 0 0 r
s
.319 0 1 r
.49912 .90926 m .5121 .92044 L .53567 .91441 L p F P
0 0 0 r
s
0 .194 1 r
.5121 .92044 m .49912 .90926 L .47562 .91534 L p F P
0 0 0 r
s
1 .02 0 r
.89778 .90879 m .90742 .91998 L .93281 .91394 L p F P
0 0 0 r
s
1 .036 0 r
.90742 .91998 m .89778 .90879 L .87245 .91487 L p F P
0 0 0 r
s
.004 0 1 r
.55947 .90832 m .57195 .91952 L .59581 .91347 L p F P
0 0 0 r
s
0 .096 1 r
.57195 .91952 m .55947 .90832 L .53567 .91441 L p F P
0 0 0 r
s
1 .005 0 r
.96757 .91906 m .95842 .90785 L .93281 .91394 L p F P
0 0 0 r
s
1 .253 0 r
.22092 .90785 m .23624 .91906 L .25858 .91301 L p F P
0 0 0 r
s
1 .14 0 r
.23624 .91906 m .22092 .90785 L .19866 .91394 L p F P
0 0 0 r
s
0 1 .882 r
.6199 .90738 m .63188 .91859 L .65604 .91254 L p F P
0 0 0 r
s
0 .891 1 r
.63188 .91859 m .6199 .90738 L .59581 .91347 L p F P
0 0 0 r
s
1 .018 0 r
.56741 .0713 m .57985 .09026 L .60376 .07983 L p F P
0 0 0 r
s
1 .029 0 r
.57985 .09026 m .56741 .0713 L .54357 .08165 L p F P
0 0 0 r
s
1 .753 0 r
.28113 .9069 m .29596 .91813 L .31859 .91207 L p F P
0 0 0 r
s
1 .465 0 r
.29596 .91813 m .28113 .9069 L .25858 .91301 L p F P
0 0 0 r
s
.389 1 0 r
.68041 .90643 m .6919 .91766 L .71634 .9116 L p F P
0 0 0 r
s
.077 1 0 r
.6919 .91766 m .68041 .90643 L .65604 .91254 L p F P
0 0 0 r
s
1 .011 0 r
.62788 .0695 m .63982 .0882 L .66401 .0779 L p F P
0 0 0 r
s
1 .02 0 r
.63982 .0882 m .62788 .0695 L .60376 .07983 L p F P
0 0 0 r
s
.262 1 0 r
.34143 .90596 m .35576 .9172 L .37868 .91114 L p F P
0 0 0 r
s
.811 1 0 r
.35576 .9172 m .34143 .90596 L .31859 .91207 L p F P
0 0 0 r
s
1 .011 0 r
.69986 .08617 m .68842 .06768 L .66401 .0779 L p F P
0 0 0 r
s
1 .698 0 r
.74101 .90549 m .752 .91674 L .77674 .91067 L p F P
0 0 0 r
s
1 .923 0 r
.752 .91674 m .74101 .90549 L .71634 .9116 L p F P
0 0 0 r
s
0 .891 1 r
.40182 .90502 m .41565 .91627 L .43886 .9102 L p F P
0 0 0 r
s
0 1 .354 r
.41565 .91627 m .40182 .90502 L .37868 .91114 L p F P
0 0 0 r
s
1 .234 0 r
.8017 .90454 m .81219 .91581 L .83721 .90973 L p F P
0 0 0 r
s
1 .343 0 r
.81219 .91581 m .8017 .90454 L .77674 .91067 L p F P
0 0 0 r
s
.319 0 1 r
.46228 .90407 m .47562 .91534 L .49912 .90926 L p F P
0 0 0 r
s
0 .381 1 r
.47562 .91534 m .46228 .90407 L .43886 .9102 L p F P
0 0 0 r
s
1 .06 0 r
.86247 .9036 m .87245 .91487 L .89778 .90879 L p F P
0 0 0 r
s
1 .098 0 r
.87245 .91487 m .86247 .9036 L .83721 .90973 L p F P
0 0 0 r
s
.66 0 1 r
.52284 .90312 m .53567 .91441 L .55947 .90832 L p F P
0 0 0 r
s
.319 0 1 r
.53567 .91441 m .52284 .90312 L .49912 .90926 L p F P
0 0 0 r
s
1 .011 0 r
.92333 .90265 m .93281 .91394 L .95842 .90785 L p F P
0 0 0 r
s
1 .02 0 r
.93281 .91394 m .92333 .90265 L .89778 .90879 L p F P
0 0 0 r
s
1 .123 0 r
.18296 .90265 m .19866 .91394 L .22092 .90785 L p F P
0 0 0 r
s
0 .096 1 r
.58348 .90217 m .59581 .91347 L .6199 .90738 L p F P
0 0 0 r
s
.004 0 1 r
.59581 .91347 m .58348 .90217 L .55947 .90832 L p F P
0 0 0 r
s
1 .431 0 r
.24339 .9017 m .25858 .91301 L .28113 .9069 L p F P
0 0 0 r
s
1 .253 0 r
.25858 .91301 m .24339 .9017 L .22092 .90785 L p F P
0 0 0 r
s
0 1 .54 r
.6442 .90122 m .65604 .91254 L .68041 .90643 L p F P
0 0 0 r
s
0 1 .882 r
.65604 .91254 m .6442 .90122 L .6199 .90738 L p F P
0 0 0 r
s
1 .011 0 r
.59147 .06098 m .60376 .07983 L .62788 .0695 L p F P
0 0 0 r
s
1 .018 0 r
.60376 .07983 m .59147 .06098 L .56741 .0713 L p F P
0 0 0 r
s
.841 1 0 r
.30389 .90075 m .31859 .91207 L .34143 .90596 L p F P
0 0 0 r
s
1 .753 0 r
.31859 .91207 m .30389 .90075 L .28113 .9069 L p F P
0 0 0 r
s
1 .005 0 r
.65222 .05922 m .66401 .0779 L .68842 .06768 L p F P
0 0 0 r
s
1 .011 0 r
.66401 .0779 m .65222 .05922 L .62788 .0695 L p F P
0 0 0 r
s
.717 1 0 r
.70501 .90027 m .71634 .9116 L .74101 .90549 L p F P
0 0 0 r
s
.389 1 0 r
.71634 .9116 m .70501 .90027 L .68041 .90643 L p F P
0 0 0 r
s
0 1 .414 r
.36448 .89979 m .37868 .91114 L .40182 .90502 L p F P
0 0 0 r
s
.262 1 0 r
.37868 .91114 m .36448 .89979 L .34143 .90596 L p F P
0 0 0 r
s
1 .502 0 r
.76591 .89932 m .77674 .91067 L .8017 .90454 L p F P
0 0 0 r
s
1 .698 0 r
.77674 .91067 m .76591 .89932 L .74101 .90549 L p F P
0 0 0 r
s
0 .096 1 r
.42516 .89884 m .43886 .9102 L .46228 .90407 L p F P
0 0 0 r
s
0 .891 1 r
.43886 .9102 m .42516 .89884 L .40182 .90502 L p F P
0 0 0 r
s
1 .152 0 r
.8269 .89836 m .83721 .90973 L .86247 .9036 L p F P
0 0 0 r
s
1 .234 0 r
.83721 .90973 m .8269 .89836 L .8017 .90454 L p F P
0 0 0 r
s
.901 0 1 r
.48593 .89788 m .49912 .90926 L .52284 .90312 L p F P
0 0 0 r
s
.319 0 1 r
.49912 .90926 m .48593 .89788 L .46228 .90407 L p F P
0 0 0 r
s
1 .034 0 r
.88797 .89741 m .89778 .90879 L .92333 .90265 L p F P
0 0 0 r
s
1 .06 0 r
.89778 .90879 m .88797 .89741 L .86247 .9036 L p F P
0 0 0 r
s
.779 0 1 r
.54677 .89693 m .55947 .90832 L .58348 .90217 L p F P
0 0 0 r
s
.66 0 1 r
.55947 .90832 m .54677 .89693 L .52284 .90312 L p F P
0 0 0 r
s
1 .222 0 r
.20534 .89645 m .22092 .90785 L .24339 .9017 L p F P
0 0 0 r
s
1 .123 0 r
.22092 .90785 m .20534 .89645 L .18296 .90265 L p F P
0 0 0 r
s
1 .011 0 r
.95842 .90785 m .94912 .89645 L .92333 .90265 L p F P
0 0 0 r
s
0 .381 1 r
.60771 .89597 m .6199 .90738 L .6442 .90122 L p F P
0 0 0 r
s
0 .096 1 r
.6199 .90738 m .60771 .89597 L .58348 .90217 L p F P
0 0 0 r
s
1 .698 0 r
.26606 .89549 m .28113 .9069 L .30389 .90075 L p F P
0 0 0 r
s
1 .431 0 r
.28113 .9069 m .26606 .89549 L .24339 .9017 L p F P
0 0 0 r
s
1 .005 0 r
.61574 .05067 m .62788 .0695 L .65222 .05922 L p F P
0 0 0 r
s
1 .011 0 r
.62788 .0695 m .61574 .05067 L .59147 .06098 L p F P
0 0 0 r
s
0 1 .127 r
.66873 .89501 m .68041 .90643 L .70501 .90027 L p F P
0 0 0 r
s
0 1 .54 r
.68041 .90643 m .66873 .89501 L .6442 .90122 L p F P
0 0 0 r
s
.306 1 0 r
.32686 .89453 m .34143 .90596 L .36448 .89979 L p F P
0 0 0 r
s
.841 1 0 r
.34143 .90596 m .32686 .89453 L .30389 .90075 L p F P
0 0 0 r
s
1 .005 0 r
.68842 .06768 m .67679 .04896 L .65222 .05922 L p F P
0 0 0 r
s
1 .971 0 r
.72984 .89405 m .74101 .90549 L .76591 .89932 L p F P
0 0 0 r
s
.717 1 0 r
.74101 .90549 m .72984 .89405 L .70501 .90027 L p F P
0 0 0 r
s
0 .811 1 r
.38775 .89357 m .40182 .90502 L .42516 .89884 L p F P
0 0 0 r
s
0 1 .414 r
.40182 .90502 m .38775 .89357 L .36448 .89979 L p F P
0 0 0 r
s
1 .343 0 r
.79104 .89309 m .8017 .90454 L .8269 .89836 L p F P
0 0 0 r
s
1 .502 0 r
.8017 .90454 m .79104 .89309 L .76591 .89932 L p F P
0 0 0 r
s
.66 0 1 r
.44872 .89261 m .46228 .90407 L .48593 .89788 L p F P
0 0 0 r
s
0 .096 1 r
.46228 .90407 m .44872 .89261 L .42516 .89884 L p F P
0 0 0 r
s
1 .093 0 r
.85232 .89212 m .86247 .9036 L .88797 .89741 L p F P
0 0 0 r
s
1 .152 0 r
.86247 .9036 m .85232 .89212 L .8269 .89836 L p F P
0 0 0 r
s
1 0 .712 r
.50978 .89164 m .52284 .90312 L .54677 .89693 L p F P
0 0 0 r
s
.901 0 1 r
.52284 .90312 m .50978 .89164 L .48593 .89788 L p F P
0 0 0 r
s
1 .103 0 r
.167 .89116 m .18296 .90265 L .20534 .89645 L p F P
0 0 0 r
s
1 .018 0 r
.91369 .89116 m .92333 .90265 L .94912 .89645 L p F P
0 0 0 r
s
1 .034 0 r
.92333 .90265 m .91369 .89116 L .88797 .89741 L p F P
0 0 0 r
s
.66 0 1 r
.57093 .89068 m .58348 .90217 L .60771 .89597 L p F P
0 0 0 r
s
.779 0 1 r
.58348 .90217 m .57093 .89068 L .54677 .89693 L p F P
0 0 0 r
s
1 .38 0 r
.22793 .89019 m .24339 .9017 L .26606 .89549 L p F P
0 0 0 r
s
1 .222 0 r
.24339 .9017 m .22793 .89019 L .20534 .89645 L p F P
0 0 0 r
s
0 .811 1 r
.63217 .88971 m .6442 .90122 L .66873 .89501 L p F P
0 0 0 r
s
0 .381 1 r
.6442 .90122 m .63217 .88971 L .60771 .89597 L p F P
0 0 0 r
s
.926 1 0 r
.28894 .88922 m .30389 .90075 L .32686 .89453 L p F P
0 0 0 r
s
1 .698 0 r
.30389 .90075 m .28894 .88922 L .26606 .89549 L p F P
0 0 0 r
s
1 .002 0 r
.64024 .04034 m .65222 .05922 L .67679 .04896 L p F P
0 0 0 r
s
1 .005 0 r
.65222 .05922 m .64024 .04034 L .61574 .05067 L p F P
0 0 0 r
s
.306 1 0 r
.69349 .88874 m .70501 .90027 L .72984 .89405 L p F P
0 0 0 r
s
0 1 .127 r
.70501 .90027 m .69349 .88874 L .66873 .89501 L p F P
0 0 0 r
s
0 1 .354 r
.35004 .88826 m .36448 .89979 L .38775 .89357 L p F P
0 0 0 r
s
.306 1 0 r
.36448 .89979 m .35004 .88826 L .32686 .89453 L p F P
0 0 0 r
s
1 .698 0 r
.7549 .88777 m .76591 .89932 L .79104 .89309 L p F P
0 0 0 r
s
1 .971 0 r
.76591 .89932 m .7549 .88777 L .72984 .89405 L p F P
0 0 0 r
s
.004 0 1 r
.41123 .88729 m .42516 .89884 L .44872 .89261 L p F P
0 0 0 r
s
0 .811 1 r
.42516 .89884 m .41123 .88729 L .38775 .89357 L p F P
0 0 0 r
s
1 .223 0 r
.8164 .8868 m .8269 .89836 L .85232 .89212 L p F P
0 0 0 r
s
1 .343 0 r
.8269 .89836 m .8164 .8868 L .79104 .89309 L p F P
0 0 0 r
s
1 0 .712 r
.4725 .88631 m .48593 .89788 L .50978 .89164 L p F P
0 0 0 r
s
.66 0 1 r
.48593 .89788 m .4725 .88631 L .44872 .89261 L p F P
0 0 0 r
s
1 .054 0 r
.87799 .88583 m .88797 .89741 L .91369 .89116 L p F P
0 0 0 r
s
1 .093 0 r
.88797 .89741 m .87799 .88583 L .85232 .89212 L p F P
0 0 0 r
s
1 0 .577 r
.53387 .88534 m .54677 .89693 L .57093 .89068 L p F P
0 0 0 r
s
1 0 .712 r
.54677 .89693 m .53387 .88534 L .50978 .89164 L p F P
0 0 0 r
s
1 .018 0 r
.94912 .89645 m .93966 .88485 L .91369 .89116 L p F P
0 0 0 r
s
1 .186 0 r
.1895 .88485 m .20534 .89645 L .22793 .89019 L p F P
0 0 0 r
s
1 .103 0 r
.20534 .89645 m .1895 .88485 L .167 .89116 L p F P
0 0 0 r
s
.319 0 1 r
.59531 .88437 m .60771 .89597 L .63217 .88971 L p F P
0 0 0 r
s
.66 0 1 r
.60771 .89597 m .59531 .88437 L .57093 .89068 L p F P
0 0 0 r
s
1 .615 0 r
.25072 .88388 m .26606 .89549 L .28894 .88922 L p F P
0 0 0 r
s
1 .38 0 r
.26606 .89549 m .25072 .88388 L .22793 .89019 L p F P
0 0 0 r
s
0 1 .671 r
.65685 .88339 m .66873 .89501 L .69349 .88874 L p F P
0 0 0 r
s
0 .811 1 r
.66873 .89501 m .65685 .88339 L .63217 .88971 L p F P
0 0 0 r
s
.43 1 0 r
.31204 .8829 m .32686 .89453 L .35004 .88826 L p F P
0 0 0 r
s
.926 1 0 r
.32686 .89453 m .31204 .8829 L .28894 .88922 L p F P
0 0 0 r
s
1 .002 0 r
.67679 .04896 m .66497 .02998 L .64024 .04034 L p F P
0 0 0 r
s
.717 1 0 r
.71848 .88241 m .72984 .89405 L .7549 .88777 L p F P
0 0 0 r
s
.306 1 0 r
.72984 .89405 m .71848 .88241 L .69349 .88874 L p F P
0 0 0 r
s
0 .891 1 r
.37344 .88192 m .38775 .89357 L .41123 .88729 L p F P
0 0 0 r
s
0 1 .354 r
.38775 .89357 m .37344 .88192 L .35004 .88826 L p F P
0 0 0 r
s
1 .477 0 r
.78019 .88143 m .79104 .89309 L .8164 .8868 L p F P
0 0 0 r
s
1 .698 0 r
.79104 .89309 m .78019 .88143 L .7549 .88777 L p F P
0 0 0 r
s
.779 0 1 r
.43493 .88094 m .44872 .89261 L .4725 .88631 L p F P
0 0 0 r
s
.004 0 1 r
.44872 .89261 m .43493 .88094 L .41123 .88729 L p F P
0 0 0 r
s
1 .137 0 r
.842 .88045 m .85232 .89212 L .87799 .88583 L p F P
0 0 0 r
s
1 .223 0 r
.85232 .89212 m .842 .88045 L .8164 .8868 L p F P
0 0 0 r
s
1 0 .296 r
.4965 .87996 m .50978 .89164 L .53387 .88534 L p F P
0 0 0 r
s
1 0 .712 r
.50978 .89164 m .4965 .87996 L .4725 .88631 L p F P
0 0 0 r
s
1 .029 0 r
.90389 .87947 m .91369 .89116 L .93966 .88485 L p F P
0 0 0 r
s
1 .054 0 r
.91369 .89116 m .90389 .87947 L .87799 .88583 L p F P
0 0 0 r
s
1 .082 0 r
.15077 .87947 m .167 .89116 L .1895 .88485 L p F P
0 0 0 r
s
1 0 .712 r
.55817 .87898 m .57093 .89068 L .59531 .88437 L p F P
0 0 0 r
s
1 0 .577 r
.57093 .89068 m .55817 .87898 L .53387 .88534 L p F P
0 0 0 r
s
1 .318 0 r
.21221 .87849 m .22793 .89019 L .25072 .88388 L p F P
0 0 0 r
s
1 .186 0 r
.22793 .89019 m .21221 .87849 L .1895 .88485 L p F P
0 0 0 r
s
0 .194 1 r
.61993 .878 m .63217 .88971 L .65685 .88339 L p F P
0 0 0 r
s
.319 0 1 r
.63217 .88971 m .61993 .878 L .59531 .88437 L p F P
0 0 0 r
s
1 .946 0 r
.27373 .87751 m .28894 .88922 L .31204 .8829 L p F P
0 0 0 r
s
1 .615 0 r
.28894 .88922 m .27373 .87751 L .25072 .88388 L p F P
0 0 0 r
s
0 1 .127 r
.68177 .87701 m .69349 .88874 L .71848 .88241 L p F P
0 0 0 r
s
0 1 .671 r
.69349 .88874 m .68177 .87701 L .65685 .88339 L p F P
0 0 0 r
s
0 1 .182 r
.33535 .87652 m .35004 .88826 L .37344 .88192 L p F P
0 0 0 r
s
.43 1 0 r
.35004 .88826 m .33535 .87652 L .31204 .8829 L p F P
0 0 0 r
s
1 .923 0 r
.7437 .87603 m .7549 .88777 L .78019 .88143 L p F P
0 0 0 r
s
.717 1 0 r
.7549 .88777 m .7437 .87603 L .71848 .88241 L p F P
0 0 0 r
s
0 .096 1 r
.39705 .87553 m .41123 .88729 L .43493 .88094 L p F P
0 0 0 r
s
0 .891 1 r
.41123 .88729 m .39705 .87553 L .37344 .88192 L p F P
0 0 0 r
s
1 .31 0 r
.80572 .87504 m .8164 .8868 L .842 .88045 L p F P
0 0 0 r
s
1 .477 0 r
.8164 .8868 m .80572 .87504 L .78019 .88143 L p F P
0 0 0 r
s
1 0 .577 r
.45885 .87454 m .4725 .88631 L .4965 .87996 L p F P
0 0 0 r
s
.779 0 1 r
.4725 .88631 m .45885 .87454 L .43493 .88094 L p F P
0 0 0 r
s
1 .08 0 r
.86783 .87405 m .87799 .88583 L .90389 .87947 L p F P
0 0 0 r
s
1 .137 0 r
.87799 .88583 m .86783 .87405 L .842 .88045 L p F P
0 0 0 r
s
1 0 .15 r
.52073 .87355 m .53387 .88534 L .55817 .87898 L p F P
0 0 0 r
s
1 0 .296 r
.53387 .88534 m .52073 .87355 L .4965 .87996 L p F P
0 0 0 r
s
1 .029 0 r
.93966 .88485 m .93003 .87306 L .90389 .87947 L p F P
0 0 0 r
s
1 .148 0 r
.17338 .87306 m .1895 .88485 L .21221 .87849 L p F P
0 0 0 r
s
1 .082 0 r
.1895 .88485 m .17338 .87306 L .15077 .87947 L p F P
0 0 0 r
s
.901 0 1 r
.5827 .87256 m .59531 .88437 L .61993 .878 L p F P
0 0 0 r
s
1 0 .712 r
.59531 .88437 m .5827 .87256 L .55817 .87898 L p F P
0 0 0 r
s
1 .515 0 r
.23512 .87207 m .25072 .88388 L .27373 .87751 L p F P
0 0 0 r
s
1 .318 0 r
.25072 .88388 m .23512 .87207 L .21221 .87849 L p F P
0 0 0 r
s
0 .811 1 r
.64477 .87157 m .65685 .88339 L .68177 .87701 L p F P
0 0 0 r
s
0 .194 1 r
.65685 .88339 m .64477 .87157 L .61993 .878 L p F P
0 0 0 r
s
.616 1 0 r
.29696 .87107 m .31204 .8829 L .33535 .87652 L p F P
0 0 0 r
s
1 .946 0 r
.31204 .8829 m .29696 .87107 L .27373 .87751 L p F P
0 0 0 r
s
.389 1 0 r
.70692 .87058 m .71848 .88241 L .7437 .87603 L p F P
0 0 0 r
s
0 1 .127 r
.71848 .88241 m .70692 .87058 L .68177 .87701 L p F P
0 0 0 r
s
0 1 .882 r
.35888 .87008 m .37344 .88192 L .39705 .87553 L p F P
0 0 0 r
s
0 1 .182 r
.37344 .88192 m .35888 .87008 L .33535 .87652 L p F P
0 0 0 r
s
1 .631 0 r
.76916 .86958 m .78019 .88143 L .80572 .87504 L p F P
0 0 0 r
s
1 .923 0 r
.78019 .88143 m .76916 .86958 L .7437 .87603 L p F P
0 0 0 r
s
.66 0 1 r
.42089 .86908 m .43493 .88094 L .45885 .87454 L p F P
0 0 0 r
s
0 .096 1 r
.43493 .88094 m .42089 .86908 L .39705 .87553 L p F P
0 0 0 r
s
1 .191 0 r
.83149 .86858 m .842 .88045 L .86783 .87405 L p F P
0 0 0 r
s
1 .31 0 r
.842 .88045 m .83149 .86858 L .80572 .87504 L p F P
0 0 0 r
s
1 0 .15 r
.48299 .86808 m .4965 .87996 L .52073 .87355 L p F P
0 0 0 r
s
1 0 .577 r
.4965 .87996 m .48299 .86808 L .45885 .87454 L p F P
0 0 0 r
s
1 .061 0 r
.13425 .86758 m .15077 .87947 L .17338 .87306 L p F P
0 0 0 r
s
1 .044 0 r
.89391 .86758 m .90389 .87947 L .93003 .87306 L p F P
0 0 0 r
s
1 .08 0 r
.90389 .87947 m .89391 .86758 L .86783 .87405 L p F P
0 0 0 r
s
1 0 .296 r
.54519 .86708 m .55817 .87898 L .5827 .87256 L p F P
0 0 0 r
s
1 0 .15 r
.55817 .87898 m .54519 .86708 L .52073 .87355 L p F P
0 0 0 r
s
1 .253 0 r
.19621 .86658 m .21221 .87849 L .23512 .87207 L p F P
0 0 0 r
s
1 .148 0 r
.21221 .87849 m .19621 .86658 L .17338 .87306 L p F P
0 0 0 r
s
.319 0 1 r
.60747 .86608 m .61993 .878 L .64477 .87157 L p F P
0 0 0 r
s
.901 0 1 r
.61993 .878 m .60747 .86608 L .5827 .87256 L p F P
0 0 0 r
s
1 .793 0 r
.25826 .86558 m .27373 .87751 L .29696 .87107 L p F P
0 0 0 r
s
1 .515 0 r
.27373 .87751 m .25826 .86558 L .23512 .87207 L p F P
0 0 0 r
s
0 1 .54 r
.66984 .86508 m .68177 .87701 L .70692 .87058 L p F P
0 0 0 r
s
0 .811 1 r
.68177 .87701 m .66984 .86508 L .64477 .87157 L p F P
0 0 0 r
s
.077 1 0 r
.3204 .86458 m .33535 .87652 L .35888 .87008 L p F P
0 0 0 r
s
.616 1 0 r
.33535 .87652 m .3204 .86458 L .29696 .87107 L p F P
0 0 0 r
s
.841 1 0 r
.7323 .86408 m .7437 .87603 L .76916 .86958 L p F P
0 0 0 r
s
.389 1 0 r
.7437 .87603 m .7323 .86408 L .70692 .87058 L p F P
0 0 0 r
s
0 .381 1 r
.38263 .86358 m .39705 .87553 L .42089 .86908 L p F P
0 0 0 r
s
0 1 .882 r
.39705 .87553 m .38263 .86358 L .35888 .87008 L p F P
0 0 0 r
s
1 .41 0 r
.79486 .86307 m .80572 .87504 L .83149 .86858 L p F P
0 0 0 r
s
1 .631 0 r
.80572 .87504 m .79486 .86307 L .76916 .86958 L p F P
0 0 0 r
s
1 0 .712 r
.44496 .86257 m .45885 .87454 L .48299 .86808 L p F P
0 0 0 r
s
.66 0 1 r
.45885 .87454 m .44496 .86257 L .42089 .86908 L p F P
0 0 0 r
s
1 .111 0 r
.8575 .86207 m .86783 .87405 L .89391 .86758 L p F P
0 0 0 r
s
1 .191 0 r
.86783 .87405 m .8575 .86207 L .83149 .86858 L p F P
0 0 0 r
s
1 0 0 r
.50737 .86156 m .52073 .87355 L .54519 .86708 L p F P
0 0 0 r
s
1 0 .15 r
.52073 .87355 m .50737 .86156 L .48299 .86808 L p F P
0 0 0 r
s
1 .044 0 r
.93003 .87306 m .92024 .86106 L .89391 .86758 L p F P
0 0 0 r
s
1 .111 0 r
.15698 .86106 m .17338 .87306 L .19621 .86658 L p F P
0 0 0 r
s
1 .061 0 r
.17338 .87306 m .15698 .86106 L .13425 .86758 L p F P
0 0 0 r
s
1 0 .712 r
.56987 .86055 m .5827 .87256 L .60747 .86608 L p F P
0 0 0 r
s
1 0 .296 r
.5827 .87256 m .56987 .86055 L .54519 .86708 L p F P
0 0 0 r
s
1 .41 0 r
.21925 .86005 m .23512 .87207 L .25826 .86558 L p F P
0 0 0 r
s
1 .253 0 r
.23512 .87207 m .21925 .86005 L .19621 .86658 L p F P
0 0 0 r
s
0 .381 1 r
.63247 .85954 m .64477 .87157 L .66984 .86508 L p F P
0 0 0 r
s
.319 0 1 r
.64477 .87157 m .63247 .85954 L .60747 .86608 L p F P
0 0 0 r
s
.841 1 0 r
.28161 .85904 m .29696 .87107 L .3204 .86458 L p F P
0 0 0 r
s
1 .793 0 r
.29696 .87107 m .28161 .85904 L .25826 .86558 L p F P
0 0 0 r
s
.077 1 0 r
.69515 .85853 m .70692 .87058 L .7323 .86408 L p F P
0 0 0 r
s
0 1 .54 r
.70692 .87058 m .69515 .85853 L .66984 .86508 L p F P
0 0 0 r
s
0 1 .54 r
.34407 .85802 m .35888 .87008 L .38263 .86358 L p F P
0 0 0 r
s
.077 1 0 r
.35888 .87008 m .34407 .85802 L .3204 .86458 L p F P
0 0 0 r
s
1 .793 0 r
.75793 .85752 m .76916 .86958 L .79486 .86307 L p F P
0 0 0 r
s
.841 1 0 r
.76916 .86958 m .75793 .85752 L .7323 .86408 L p F P
0 0 0 r
s
.319 0 1 r
.40661 .85701 m .42089 .86908 L .44496 .86257 L p F P
0 0 0 r
s
0 .381 1 r
.42089 .86908 m .40661 .85701 L .38263 .86358 L p F P
0 0 0 r
s
1 .253 0 r
.8208 .8565 m .83149 .86858 L .8575 .86207 L p F P
0 0 0 r
s
1 .41 0 r
.83149 .86858 m .8208 .8565 L .79486 .86307 L p F P
0 0 0 r
s
1 0 .296 r
.46925 .856 m .48299 .86808 L .50737 .86156 L p F P
0 0 0 r
s
1 0 .712 r
.48299 .86808 m .46925 .856 L .44496 .86257 L p F P
0 0 0 r
s
1 .061 0 r
.88376 .85549 m .89391 .86758 L .92024 .86106 L p F P
0 0 0 r
s
1 .111 0 r
.89391 .86758 m .88376 .85549 L .8575 .86207 L p F P
0 0 0 r
s
1 .044 0 r
.11744 .85549 m .13425 .86758 L .15698 .86106 L p F P
0 0 0 r
s
1 0 .15 r
.53198 .85498 m .54519 .86708 L .56987 .86055 L p F P
0 0 0 r
s
1 0 0 r
.54519 .86708 m .53198 .85498 L .50737 .86156 L p F P
0 0 0 r
s
1 .191 0 r
.17993 .85447 m .19621 .86658 L .21925 .86005 L p F P
0 0 0 r
s
1 .111 0 r
.19621 .86658 m .17993 .85447 L .15698 .86106 L p F P
0 0 0 r
s
.66 0 1 r
.59479 .85396 m .60747 .86608 L .63247 .85954 L p F P
0 0 0 r
s
1 0 .712 r
.60747 .86608 m .59479 .85396 L .56987 .86055 L p F P
0 0 0 r
s
1 .631 0 r
.24252 .85345 m .25826 .86558 L .28161 .85904 L p F P
0 0 0 r
s
1 .41 0 r
.25826 .86558 m .24252 .85345 L .21925 .86005 L p F P
0 0 0 r
s
0 1 .882 r
.65771 .85294 m .66984 .86508 L .69515 .85853 L p F P
0 0 0 r
s
0 .381 1 r
.66984 .86508 m .65771 .85294 L .63247 .85954 L p F P
0 0 0 r
s
.389 1 0 r
.30519 .85243 m .3204 .86458 L .34407 .85802 L p F P
0 0 0 r
s
.841 1 0 r
.3204 .86458 m .30519 .85243 L .28161 .85904 L p F P
0 0 0 r
s
.616 1 0 r
.72071 .85192 m .7323 .86408 L .75793 .85752 L p F P
0 0 0 r
s
.077 1 0 r
.7323 .86408 m .72071 .85192 L .69515 .85853 L p F P
0 0 0 r
s
0 .811 1 r
.36796 .85141 m .38263 .86358 L .40661 .85701 L p F P
0 0 0 r
s
0 1 .54 r
.38263 .86358 m .36796 .85141 L .34407 .85802 L p F P
0 0 0 r
s
1 .515 0 r
.7838 .8509 m .79486 .86307 L .8208 .8565 L p F P
0 0 0 r
s
1 .793 0 r
.79486 .86307 m .7838 .8509 L .75793 .85752 L p F P
0 0 0 r
s
.901 0 1 r
.43082 .85038 m .44496 .86257 L .46925 .856 L p F P
0 0 0 r
s
.319 0 1 r
.44496 .86257 m .43082 .85038 L .40661 .85701 L p F P
0 0 0 r
s
1 .148 0 r
.84699 .84987 m .8575 .86207 L .88376 .85549 L p F P
0 0 0 r
s
1 .253 0 r
.8575 .86207 m .84699 .84987 L .8208 .8565 L p F P
0 0 0 r
s
1 0 .15 r
.49377 .84936 m .50737 .86156 L .53198 .85498 L p F P
0 0 0 r
s
1 0 .296 r
.50737 .86156 m .49377 .84936 L .46925 .856 L p F P
0 0 0 r
s
1 .061 0 r
.92024 .86106 m .91027 .84885 L .88376 .85549 L p F P
0 0 0 r
s
1 .08 0 r
.14029 .84885 m .15698 .86106 L .17993 .85447 L p F P
0 0 0 r
s
1 .044 0 r
.15698 .86106 m .14029 .84885 L .11744 .85549 L p F P
0 0 0 r
s
1 0 .577 r
.55682 .84833 m .56987 .86055 L .59479 .85396 L p F P
0 0 0 r
s
1 0 .15 r
.56987 .86055 m .55682 .84833 L .53198 .85498 L p F P
0 0 0 r
s
1 .31 0 r
.2031 .84782 m .21925 .86005 L .24252 .85345 L p F P
0 0 0 r
s
1 .191 0 r
.21925 .86005 m .2031 .84782 L .17993 .85447 L p F P
0 0 0 r
s
0 .096 1 r
.61995 .8473 m .63247 .85954 L .65771 .85294 L p F P
0 0 0 r
s
.66 0 1 r
.63247 .85954 m .61995 .8473 L .59479 .85396 L p F P
0 0 0 r
s
1 .923 0 r
.266 .84679 m .28161 .85904 L .30519 .85243 L p F P
0 0 0 r
s
1 .631 0 r
.28161 .85904 m .266 .84679 L .24252 .85345 L p F P
0 0 0 r
s
0 1 .182 r
.68318 .84627 m .69515 .85853 L .72071 .85192 L p F P
0 0 0 r
s
0 1 .882 r
.69515 .85853 m .68318 .84627 L .65771 .85294 L p F P
0 0 0 r
s
0 1 .127 r
.32899 .84576 m .34407 .85802 L .36796 .85141 L p F P
0 0 0 r
s
.389 1 0 r
.34407 .85802 m .32899 .84576 L .30519 .85243 L p F P
0 0 0 r
s
1 .946 0 r
.74651 .84524 m .75793 .85752 L .7838 .8509 L p F P
0 0 0 r
s
.616 1 0 r
.75793 .85752 m .74651 .84524 L .72071 .85192 L p F P
0 0 0 r
s
0 .194 1 r
.39208 .84473 m .40661 .85701 L .43082 .85038 L p F P
0 0 0 r
s
0 .811 1 r
.40661 .85701 m .39208 .84473 L .36796 .85141 L p F P
0 0 0 r
s
1 .318 0 r
.80992 .84421 m .8208 .8565 L .84699 .84987 L p F P
0 0 0 r
s
1 .515 0 r
.8208 .8565 m .80992 .84421 L .7838 .8509 L p F P
0 0 0 r
s
1 0 .712 r
.45526 .84369 m .46925 .856 L .49377 .84936 L p F P
0 0 0 r
s
.901 0 1 r
.46925 .856 m .45526 .84369 L .43082 .85038 L p F P
0 0 0 r
s
1 .029 0 r
.10033 .84318 m .11744 .85549 L .14029 .84885 L p F P
0 0 0 r
s
1 .082 0 r
.87343 .84318 m .88376 .85549 L .91027 .84885 L p F P
0 0 0 r
s
1 .148 0 r
.88376 .85549 m .87343 .84318 L .84699 .84987 L p F P
0 0 0 r
s
1 0 .296 r
.51853 .84266 m .53198 .85498 L .55682 .84833 L p F P
0 0 0 r
s
1 0 .15 r
.53198 .85498 m .51853 .84266 L .49377 .84936 L p F P
0 0 0 r
s
1 .137 0 r
.16337 .84214 m .17993 .85447 L .2031 .84782 L p F P
0 0 0 r
s
1 .08 0 r
.17993 .85447 m .16337 .84214 L .14029 .84885 L p F P
0 0 0 r
s
.779 0 1 r
.5819 .84162 m .59479 .85396 L .61995 .8473 L p F P
0 0 0 r
s
1 0 .577 r
.59479 .85396 m .5819 .84162 L .55682 .84833 L p F P
0 0 0 r
s
1 .477 0 r
.22649 .8411 m .24252 .85345 L .266 .84679 L p F P
0 0 0 r
s
1 .31 0 r
.24252 .85345 m .22649 .8411 L .2031 .84782 L p F P
0 0 0 r
s
0 .891 1 r
.64535 .84058 m .65771 .85294 L .68318 .84627 L p F P
0 0 0 r
s
0 .096 1 r
.65771 .85294 m .64535 .84058 L .61995 .8473 L p F P
0 0 0 r
s
.717 1 0 r
.28971 .84006 m .30519 .85243 L .32899 .84576 L p F P
0 0 0 r
s
1 .923 0 r
.30519 .85243 m .28971 .84006 L .266 .84679 L p F P
0 0 0 r
s
.43 1 0 r
.70891 .83954 m .72071 .85192 L .74651 .84524 L p F P
0 0 0 r
s
0 1 .182 r
.72071 .85192 m .70891 .83954 L .68318 .84627 L p F P
0 0 0 r
s
0 1 .671 r
.35302 .83902 m .36796 .85141 L .39208 .84473 L p F P
0 0 0 r
s
0 1 .127 r
.36796 .85141 m .35302 .83902 L .32899 .84576 L p F P
0 0 0 r
s
1 .615 0 r
.77255 .8385 m .7838 .8509 L .80992 .84421 L p F P
0 0 0 r
s
1 .946 0 r
.7838 .8509 m .77255 .8385 L .74651 .84524 L p F P
0 0 0 r
s
.319 0 1 r
.41643 .83798 m .43082 .85038 L .45526 .84369 L p F P
0 0 0 r
s
0 .194 1 r
.43082 .85038 m .41643 .83798 L .39208 .84473 L p F P
0 0 0 r
s
1 .186 0 r
.83629 .83746 m .84699 .84987 L .87343 .84318 L p F P
0 0 0 r
s
1 .318 0 r
.84699 .84987 m .83629 .83746 L .80992 .84421 L p F P
0 0 0 r
s
1 0 .577 r
.47993 .83694 m .49377 .84936 L .51853 .84266 L p F P
0 0 0 r
s
1 0 .712 r
.49377 .84936 m .47993 .83694 L .45526 .84369 L p F P
0 0 0 r
s
1 .054 0 r
.12331 .83642 m .14029 .84885 L .16337 .84214 L p F P
0 0 0 r
s
1 .029 0 r
.14029 .84885 m .12331 .83642 L .10033 .84318 L p F P
0 0 0 r
s
1 .082 0 r
.91027 .84885 m .90013 .83642 L .87343 .84318 L p F P
0 0 0 r
s
1 0 .712 r
.54353 .83589 m .55682 .84833 L .5819 .84162 L p F P
0 0 0 r
s
1 0 .296 r
.55682 .84833 m .54353 .83589 L .51853 .84266 L p F P
0 0 0 r
s
1 .223 0 r
.18666 .83537 m .2031 .84782 L .22649 .8411 L p F P
0 0 0 r
s
1 .137 0 r
.2031 .84782 m .18666 .83537 L .16337 .84214 L p F P
0 0 0 r
s
.004 0 1 r
.60722 .83485 m .61995 .8473 L .64535 .84058 L p F P
0 0 0 r
s
.779 0 1 r
.61995 .8473 m .60722 .83485 L .5819 .84162 L p F P
0 0 0 r
s
1 .698 0 r
.25011 .83432 m .266 .84679 L .28971 .84006 L p F P
0 0 0 r
s
1 .477 0 r
.266 .84679 m .25011 .83432 L .22649 .8411 L p F P
0 0 0 r
s
0 1 .354 r
.671 .8338 m .68318 .84627 L .70891 .83954 L p F P
0 0 0 r
s
0 .891 1 r
.68318 .84627 m .671 .8338 L .64535 .84058 L p F P
0 0 0 r
s
.306 1 0 r
.31365 .83327 m .32899 .84576 L .35302 .83902 L p F P
0 0 0 r
s
.717 1 0 r
.32899 .84576 m .31365 .83327 L .28971 .84006 L p F P
0 0 0 r
s
.926 1 0 r
.73488 .83275 m .74651 .84524 L .77255 .8385 L p F P
0 0 0 r
s
.43 1 0 r
.74651 .84524 m .73488 .83275 L .70891 .83954 L p F P
0 0 0 r
s
0 .811 1 r
.37729 .83222 m .39208 .84473 L .41643 .83798 L p F P
0 0 0 r
s
0 1 .671 r
.39208 .84473 m .37729 .83222 L .35302 .83902 L p F P
0 0 0 r
s
1 .38 0 r
.79885 .8317 m .80992 .84421 L .83629 .83746 L p F P
0 0 0 r
s
1 .615 0 r
.80992 .84421 m .79885 .8317 L .77255 .8385 L p F P
0 0 0 r
s
.66 0 1 r
.44102 .83117 m .45526 .84369 L .47993 .83694 L p F P
0 0 0 r
s
.319 0 1 r
.45526 .84369 m .44102 .83117 L .41643 .83798 L p F P
0 0 0 r
s
1 .103 0 r
.86292 .83064 m .87343 .84318 L .90013 .83642 L p F P
0 0 0 r
s
1 .186 0 r
.87343 .84318 m .86292 .83064 L .83629 .83746 L p F P
0 0 0 r
s
1 .018 0 r
.08292 .83064 m .10033 .84318 L .12331 .83642 L p F P
0 0 0 r
s
1 0 .712 r
.50484 .83012 m .51853 .84266 L .54353 .83589 L p F P
0 0 0 r
s
1 0 .577 r
.51853 .84266 m .50484 .83012 L .47993 .83694 L p F P
0 0 0 r
s
1 .093 0 r
.1465 .82959 m .16337 .84214 L .18666 .83537 L p F P
0 0 0 r
s
1 .054 0 r
.16337 .84214 m .1465 .82959 L .12331 .83642 L p F P
0 0 0 r
s
.66 0 1 r
.56877 .82906 m .5819 .84162 L .60722 .83485 L p F P
0 0 0 r
s
1 0 .712 r
.5819 .84162 m .56877 .82906 L .54353 .83589 L p F P
0 0 0 r
s
1 .343 0 r
.21018 .82853 m .22649 .8411 L .25011 .83432 L p F P
0 0 0 r
s
1 .223 0 r
.22649 .8411 m .21018 .82853 L .18666 .83537 L p F P
0 0 0 r
s
0 .811 1 r
.63278 .82801 m .64535 .84058 L .671 .8338 L p F P
0 0 0 r
s
.004 0 1 r
.64535 .84058 m .63278 .82801 L .60722 .83485 L p F P
0 0 0 r
s
1 .971 0 r
.27395 .82748 m .28971 .84006 L .31365 .83327 L p F P
0 0 0 r
s
1 .698 0 r
.28971 .84006 m .27395 .82748 L .25011 .83432 L p F P
0 0 0 r
s
.306 1 0 r
.69689 .82695 m .70891 .83954 L .73488 .83275 L p F P
0 0 0 r
s
0 1 .354 r
.70891 .83954 m .69689 .82695 L .671 .8338 L p F P
0 0 0 r
s
0 1 .127 r
.33782 .82642 m .35302 .83902 L .37729 .83222 L p F P
0 0 0 r
s
.306 1 0 r
.35302 .83902 m .33782 .82642 L .31365 .83327 L p F P
0 0 0 r
s
1 .698 0 r
.7611 .82589 m .77255 .8385 L .79885 .8317 L p F P
0 0 0 r
s
.926 1 0 r
.77255 .8385 m .7611 .82589 L .73488 .83275 L p F P
0 0 0 r
s
0 .381 1 r
.40179 .82536 m .41643 .83798 L .44102 .83117 L p F P
0 0 0 r
s
0 .811 1 r
.41643 .83798 m .40179 .82536 L .37729 .83222 L p F P
0 0 0 r
s
1 .222 0 r
.8254 .82483 m .83629 .83746 L .86292 .83064 L p F P
0 0 0 r
s
1 .38 0 r
.83629 .83746 m .8254 .82483 L .79885 .8317 L p F P
0 0 0 r
s
.779 0 1 r
.46584 .8243 m .47993 .83694 L .50484 .83012 L p F P
0 0 0 r
s
.66 0 1 r
.47993 .83694 m .46584 .8243 L .44102 .83117 L p F P
0 0 0 r
s
1 .103 0 r
.90013 .83642 m .8898 .82376 L .86292 .83064 L p F P
0 0 0 r
s
1 .034 0 r
.10602 .82376 m .12331 .83642 L .1465 .82959 L p F P
0 0 0 r
s
1 .018 0 r
.12331 .83642 m .10602 .82376 L .08292 .83064 L p F P
0 0 0 r
s
.901 0 1 r
.53 .82323 m .54353 .83589 L .56877 .82906 L p F P
0 0 0 r
s
1 0 .712 r
.54353 .83589 m .53 .82323 L .50484 .83012 L p F P
0 0 0 r
s
1 .152 0 r
.16993 .8227 m .18666 .83537 L .21018 .82853 L p F P
0 0 0 r
s
1 .093 0 r
.18666 .83537 m .16993 .8227 L .1465 .82959 L p F P
0 0 0 r
s
0 .096 1 r
.59425 .82217 m .60722 .83485 L .63278 .82801 L p F P
0 0 0 r
s
.66 0 1 r
.60722 .83485 m .59425 .82217 L .56877 .82906 L p F P
0 0 0 r
s
1 .502 0 r
.23393 .82163 m .25011 .83432 L .27395 .82748 L p F P
0 0 0 r
s
1 .343 0 r
.25011 .83432 m .23393 .82163 L .21018 .82853 L p F P
0 0 0 r
s
0 1 .414 r
.6586 .8211 m .671 .8338 L .69689 .82695 L p F P
0 0 0 r
s
0 .811 1 r
.671 .8338 m .6586 .8211 L .63278 .82801 L p F P
0 0 0 r
s
.717 1 0 r
.29803 .82056 m .31365 .83327 L .33782 .82642 L p F P
0 0 0 r
s
1 .971 0 r
.31365 .83327 m .29803 .82056 L .27395 .82748 L p F P
0 0 0 r
s
.841 1 0 r
.72304 .82003 m .73488 .83275 L .7611 .82589 L p F P
0 0 0 r
s
.306 1 0 r
.73488 .83275 m .72304 .82003 L .69689 .82695 L p F P
0 0 0 r
s
0 1 .54 r
.36223 .8195 m .37729 .83222 L .40179 .82536 L p F P
0 0 0 r
s
0 1 .127 r
.37729 .83222 m .36223 .8195 L .33782 .82642 L p F P
0 0 0 r
s
1 .431 0 r
.78758 .81896 m .79885 .8317 L .8254 .82483 L p F P
0 0 0 r
s
1 .698 0 r
.79885 .8317 m .78758 .81896 L .7611 .82589 L p F P
0 0 0 r
s
0 .096 1 r
.42652 .81842 m .44102 .83117 L .46584 .8243 L p F P
0 0 0 r
s
0 .381 1 r
.44102 .83117 m .42652 .81842 L .40179 .82536 L p F P
0 0 0 r
s
1 .123 0 r
.85222 .81789 m .86292 .83064 L .8898 .82376 L p F P
0 0 0 r
s
1 .222 0 r
.86292 .83064 m .85222 .81789 L .8254 .82483 L p F P
0 0 0 r
s
1 .011 0 r
.0652 .81789 m .08292 .83064 L .10602 .82376 L p F P
0 0 0 r
s
.66 0 1 r
.49091 .81735 m .50484 .83012 L .53 .82323 L p F P
0 0 0 r
s
.779 0 1 r
.50484 .83012 m .49091 .81735 L .46584 .8243 L p F P
0 0 0 r
s
1 .06 0 r
.12934 .81681 m .1465 .82959 L .16993 .8227 L p F P
0 0 0 r
s
1 .034 0 r
.1465 .82959 m .12934 .81681 L .10602 .82376 L p F P
0 0 0 r
s
.319 0 1 r
.5554 .81628 m .56877 .82906 L .59425 .82217 L p F P
0 0 0 r
s
.901 0 1 r
.56877 .82906 m .5554 .81628 L .53 .82323 L p F P
0 0 0 r
s
1 .234 0 r
.19358 .81574 m .21018 .82853 L .23393 .82163 L p F P
0 0 0 r
s
1 .152 0 r
.21018 .82853 m .19358 .81574 L .16993 .8227 L p F P
0 0 0 r
s
0 .891 1 r
.61998 .8152 m .63278 .82801 L .6586 .8211 L p F P
0 0 0 r
s
0 .096 1 r
.63278 .82801 m .61998 .8152 L .59425 .82217 L p F P
0 0 0 r
s
1 .698 0 r
.25791 .81466 m .27395 .82748 L .29803 .82056 L p F P
0 0 0 r
s
1 .502 0 r
.27395 .82748 m .25791 .81466 L .23393 .82163 L p F P
0 0 0 r
s
.262 1 0 r
.68466 .81412 m .69689 .82695 L .72304 .82003 L p F P
0 0 0 r
s
0 1 .414 r
.69689 .82695 m .68466 .81412 L .6586 .8211 L p F P
0 0 0 r
s
.389 1 0 r
.32235 .81358 m .33782 .82642 L .36223 .8195 L p F P
0 0 0 r
s
.717 1 0 r
.33782 .82642 m .32235 .81358 L .29803 .82056 L p F P
0 0 0 r
s
1 .753 0 r
.74944 .81305 m .7611 .82589 L .78758 .81896 L p F P
0 0 0 r
s
.841 1 0 r
.7611 .82589 m .74944 .81305 L .72304 .82003 L p F P
0 0 0 r
s
0 1 .882 r
.38688 .8125 m .40179 .82536 L .42652 .81842 L p F P
0 0 0 r
s
0 1 .54 r
.40179 .82536 m .38688 .8125 L .36223 .8195 L p F P
0 0 0 r
s
1 .253 0 r
.81432 .81196 m .8254 .82483 L .85222 .81789 L p F P
0 0 0 r
s
1 .431 0 r
.8254 .82483 m .81432 .81196 L .78758 .81896 L p F P
0 0 0 r
s
.004 0 1 r
.4515 .81142 m .46584 .8243 L .49091 .81735 L p F P
0 0 0 r
s
0 .096 1 r
.46584 .8243 m .4515 .81142 L .42652 .81842 L p F P
0 0 0 r
s
1 .02 0 r
.08841 .81088 m .10602 .82376 L .12934 .81681 L p F P
0 0 0 r
s
1 .011 0 r
.10602 .82376 m .08841 .81088 L .0652 .81789 L p F P
0 0 0 r
s
1 .123 0 r
.8898 .82376 m .87929 .81088 L .85222 .81789 L p F P
0 0 0 r
s
.319 0 1 r
.51623 .81034 m .53 .82323 L .5554 .81628 L p F P
0 0 0 r
s
.66 0 1 r
.53 .82323 m .51623 .81034 L .49091 .81735 L p F P
0 0 0 r
s
1 .098 0 r
.15289 .8098 m .16993 .8227 L .19358 .81574 L p F P
0 0 0 r
s
1 .06 0 r
.16993 .8227 m .15289 .8098 L .12934 .81681 L p F P
0 0 0 r
s
0 .381 1 r
.58105 .80926 m .59425 .82217 L .61998 .8152 L p F P
0 0 0 r
s
.319 0 1 r
.59425 .82217 m .58105 .80926 L .5554 .81628 L p F P
0 0 0 r
s
1 .343 0 r
.21746 .80871 m .23393 .82163 L .25791 .81466 L p F P
0 0 0 r
s
1 .234 0 r
.23393 .82163 m .21746 .80871 L .19358 .81574 L p F P
0 0 0 r
s
0 1 .354 r
.64597 .80817 m .6586 .8211 L .68466 .81412 L p F P
0 0 0 r
s
0 .891 1 r
.6586 .8211 m .64597 .80817 L .61998 .8152 L p F P
0 0 0 r
s
1 .923 0 r
.28213 .80763 m .29803 .82056 L .32235 .81358 L p F P
0 0 0 r
s
1 .698 0 r
.29803 .82056 m .28213 .80763 L .25791 .81466 L p F P
0 0 0 r
s
.811 1 0 r
.71099 .80708 m .72304 .82003 L .74944 .81305 L p F P
0 0 0 r
s
.262 1 0 r
.72304 .82003 m .71099 .80708 L .68466 .81412 L p F P
0 0 0 r
s
.077 1 0 r
.3469 .80654 m .36223 .8195 L .38688 .8125 L p F P
0 0 0 r
s
.389 1 0 r
.36223 .8195 m .3469 .80654 L .32235 .81358 L p F P
0 0 0 r
s
1 .465 0 r
.7761 .80599 m .78758 .81896 L .81432 .81196 L p F P
0 0 0 r
s
1 .753 0 r
.78758 .81896 m .7761 .80599 L .74944 .81305 L p F P
0 0 0 r
s
0 .891 1 r
.41176 .80545 m .42652 .81842 L .4515 .81142 L p F P
0 0 0 r
s
0 1 .882 r
.42652 .81842 m .41176 .80545 L .38688 .8125 L p F P
0 0 0 r
s
1 .005 0 r
.04715 .8049 m .0652 .81789 L .08841 .81088 L p F P
0 0 0 r
s
1 .14 0 r
.84132 .8049 m .85222 .81789 L .87929 .81088 L p F P
0 0 0 r
s
1 .253 0 r
.85222 .81789 m .84132 .8049 L .81432 .81196 L p F P
0 0 0 r
s
0 .096 1 r
.47673 .80435 m .49091 .81735 L .51623 .81034 L p F P
0 0 0 r
s
.004 0 1 r
.49091 .81735 m .47673 .80435 L .4515 .81142 L p F P
0 0 0 r
s
1 .036 0 r
.11186 .80381 m .12934 .81681 L .15289 .8098 L p F P
0 0 0 r
s
1 .02 0 r
.12934 .81681 m .11186 .80381 L .08841 .81088 L p F P
0 0 0 r
s
0 .194 1 r
.54179 .80326 m .5554 .81628 L .58105 .80926 L p F P
0 0 0 r
s
.319 0 1 r
.5554 .81628 m .54179 .80326 L .51623 .81034 L p F P
0 0 0 r
s
1 .152 0 r
.17667 .80271 m .19358 .81574 L .21746 .80871 L p F P
0 0 0 r
s
1 .098 0 r
.19358 .81574 m .17667 .80271 L .15289 .8098 L p F P
0 0 0 r
s
0 1 .882 r
.60695 .80216 m .61998 .8152 L .64597 .80817 L p F P
0 0 0 r
s
0 .381 1 r
.61998 .8152 m .60695 .80216 L .58105 .80926 L p F P
0 0 0 r
s
1 .477 0 r
.24158 .80162 m .25791 .81466 L .28213 .80763 L p F P
0 0 0 r
s
1 .343 0 r
.25791 .81466 m .24158 .80162 L .21746 .80871 L p F P
0 0 0 r
s
.306 1 0 r
.67221 .80107 m .68466 .81412 L .71099 .80708 L p F P
0 0 0 r
s
0 1 .354 r
.68466 .81412 m .67221 .80107 L .64597 .80817 L p F P
0 0 0 r
s
.841 1 0 r
.30659 .80052 m .32235 .81358 L .3469 .80654 L p F P
0 0 0 r
s
1 .923 0 r
.32235 .81358 m .30659 .80052 L .28213 .80763 L p F P
0 0 0 r
s
1 .773 0 r
.73757 .79997 m .74944 .81305 L .7761 .80599 L p F P
0 0 0 r
s
.811 1 0 r
.74944 .81305 m .73757 .79997 L .71099 .80708 L p F P
0 0 0 r
s
0 1 .182 r
.37169 .79942 m .38688 .8125 L .41176 .80545 L p F P
0 0 0 r
s
.077 1 0 r
.38688 .8125 m .37169 .79942 L .3469 .80654 L p F P
0 0 0 r
s
1 .273 0 r
.80303 .79887 m .81432 .81196 L .84132 .8049 L p F P
0 0 0 r
s
1 .465 0 r
.81432 .81196 m .80303 .79887 L .7761 .80599 L p F P
0 0 0 r
s
0 .811 1 r
.4369 .79832 m .4515 .81142 L .47673 .80435 L p F P
0 0 0 r
s
0 .891 1 r
.4515 .81142 m .4369 .79832 L .41176 .80545 L p F P
0 0 0 r
s
1 .14 0 r
.87929 .81088 m .86859 .79777 L .84132 .8049 L p F P
0 0 0 r
s
1 .011 0 r
.07049 .79777 m .08841 .81088 L .11186 .80381 L p F P
0 0 0 r
s
1 .005 0 r
.08841 .81088 m .07049 .79777 L .04715 .8049 L p F P
0 0 0 r
s
0 .381 1 r
.5022 .79721 m .51623 .81034 L .54179 .80326 L p F P
0 0 0 r
s
0 .096 1 r
.51623 .81034 m .5022 .79721 L .47673 .80435 L p F P
0 0 0 r
s
1 .06 0 r
.13554 .79666 m .15289 .8098 L .17667 .80271 L p F P
0 0 0 r
s
1 .036 0 r
.15289 .8098 m .13554 .79666 L .11186 .80381 L p F P
0 0 0 r
s
0 .811 1 r
.56761 .79611 m .58105 .80926 L .60695 .80216 L p F P
0 0 0 r
s
0 .194 1 r
.58105 .80926 m .56761 .79611 L .54179 .80326 L p F P
0 0 0 r
s
1 .223 0 r
.20069 .79556 m .21746 .80871 L .24158 .80162 L p F P
0 0 0 r
s
1 .152 0 r
.21746 .80871 m .20069 .79556 L .17667 .80271 L p F P
0 0 0 r
s
0 1 .182 r
.63311 .795 m .64597 .80817 L .67221 .80107 L p F P
0 0 0 r
s
0 1 .882 r
.64597 .80817 m .63311 .795 L .60695 .80216 L p F P
0 0 0 r
s
1 .631 0 r
.26594 .79445 m .28213 .80763 L .30659 .80052 L p F P
0 0 0 r
s
1 .477 0 r
.28213 .80763 m .26594 .79445 L .24158 .80162 L p F P
0 0 0 r
s
.841 1 0 r
.69871 .79389 m .71099 .80708 L .73757 .79997 L p F P
0 0 0 r
s
.306 1 0 r
.71099 .80708 m .69871 .79389 L .67221 .80107 L p F P
0 0 0 r
s
.616 1 0 r
.33129 .79334 m .3469 .80654 L .37169 .79942 L p F P
0 0 0 r
s
.841 1 0 r
.3469 .80654 m .33129 .79334 L .30659 .80052 L p F P
0 0 0 r
s
1 .477 0 r
.76442 .79279 m .7761 .80599 L .80303 .79887 L p F P
0 0 0 r
s
1 .773 0 r
.7761 .80599 m .76442 .79279 L .73757 .79997 L p F P
0 0 0 r
s
0 1 .354 r
.39673 .79223 m .41176 .80545 L .4369 .79832 L p F P
0 0 0 r
s
0 1 .182 r
.41176 .80545 m .39673 .79223 L .37169 .79942 L p F P
0 0 0 r
s
1 .002 0 r
.02877 .79167 m .04715 .8049 L .07049 .79777 L p F P
0 0 0 r
s
1 .152 0 r
.83022 .79167 m .84132 .8049 L .86859 .79777 L p F P
0 0 0 r
s
1 .273 0 r
.84132 .8049 m .83022 .79167 L .80303 .79887 L p F P
0 0 0 r
s
0 .891 1 r
.46228 .79112 m .47673 .80435 L .5022 .79721 L p F P
0 0 0 r
s
0 .811 1 r
.47673 .80435 m .46228 .79112 L .4369 .79832 L p F P
0 0 0 r
s
1 .02 0 r
.09406 .79056 m .11186 .80381 L .13554 .79666 L p F P
0 0 0 r
s
1 .011 0 r
.11186 .80381 m .09406 .79056 L .07049 .79777 L p F P
0 0 0 r
s
0 .811 1 r
.52793 .79 m .54179 .80326 L .56761 .79611 L p F P
0 0 0 r
s
0 .381 1 r
.54179 .80326 m .52793 .79 L .5022 .79721 L p F P
0 0 0 r
s
1 .093 0 r
.15946 .78945 m .17667 .80271 L .20069 .79556 L p F P
0 0 0 r
s
1 .06 0 r
.17667 .80271 m .15946 .78945 L .13554 .79666 L p F P
0 0 0 r
s
0 1 .54 r
.59368 .78889 m .60695 .80216 L .63311 .795 L p F P
0 0 0 r
s
0 .811 1 r
.60695 .80216 m .59368 .78889 L .56761 .79611 L p F P
0 0 0 r
s
1 .31 0 r
.22495 .78833 m .24158 .80162 L .26594 .79445 L p F P
0 0 0 r
s
1 .223 0 r
.24158 .80162 m .22495 .78833 L .20069 .79556 L p F P
0 0 0 r
s
.43 1 0 r
.65953 .78777 m .67221 .80107 L .69871 .79389 L p F P
0 0 0 r
s
0 1 .182 r
.67221 .80107 m .65953 .78777 L .63311 .795 L p F P
0 0 0 r
s
1 .793 0 r
.29054 .78721 m .30659 .80052 L .33129 .79334 L p F P
0 0 0 r
s
1 .631 0 r
.30659 .80052 m .29054 .78721 L .26594 .79445 L p F P
0 0 0 r
s
1 .753 0 r
.72548 .78665 m .73757 .79997 L .76442 .79279 L p F P
0 0 0 r
s
.841 1 0 r
.73757 .79997 m .72548 .78665 L .69871 .79389 L p F P
0 0 0 r
s
.43 1 0 r
.35623 .78609 m .37169 .79942 L .39673 .79223 L p F P
0 0 0 r
s
.616 1 0 r
.37169 .79942 m .35623 .78609 L .33129 .79334 L p F P
0 0 0 r
s
1 .28 0 r
.79153 .78553 m .80303 .79887 L .83022 .79167 L p F P
0 0 0 r
s
1 .477 0 r
.80303 .79887 m .79153 .78553 L .76442 .79279 L p F P
0 0 0 r
s
0 1 .414 r
.42203 .78497 m .4369 .79832 L .46228 .79112 L p F P
0 0 0 r
s
0 1 .354 r
.4369 .79832 m .42203 .78497 L .39673 .79223 L p F P
0 0 0 r
s
1 .005 0 r
.05224 .78441 m .07049 .79777 L .09406 .79056 L p F P
0 0 0 r
s
1 .002 0 r
.07049 .79777 m .05224 .78441 L .02877 .79167 L p F P
0 0 0 r
s
1 .152 0 r
.86859 .79777 m .85768 .78441 L .83022 .79167 L p F P
0 0 0 r
s
0 1 .882 r
.48792 .78385 m .5022 .79721 L .52793 .79 L p F P
0 0 0 r
s
0 .891 1 r
.5022 .79721 m .48792 .78385 L .46228 .79112 L p F P
0 0 0 r
s
1 .034 0 r
.11787 .78328 m .13554 .79666 L .15946 .78945 L p F P
0 0 0 r
s
1 .02 0 r
.13554 .79666 m .11787 .78328 L .09406 .79056 L p F P
0 0 0 r
s
0 1 .671 r
.55392 .78272 m .56761 .79611 L .59368 .78889 L p F P
0 0 0 r
s
0 .811 1 r
.56761 .79611 m .55392 .78272 L .52793 .79 L p F P
0 0 0 r
s
1 .137 0 r
.18361 .78216 m .20069 .79556 L .22495 .78833 L p F P
0 0 0 r
s
1 .093 0 r
.20069 .79556 m .18361 .78216 L .15946 .78945 L p F P
0 0 0 r
s
.077 1 0 r
.62001 .78159 m .63311 .795 L .65953 .78777 L p F P
0 0 0 r
s
0 1 .54 r
.63311 .795 m .62001 .78159 L .59368 .78889 L p F P
0 0 0 r
s
1 .41 0 r
.24945 .78103 m .26594 .79445 L .29054 .78721 L p F P
0 0 0 r
s
1 .31 0 r
.26594 .79445 m .24945 .78103 L .22495 .78833 L p F P
0 0 0 r
s
.926 1 0 r
.68621 .78046 m .69871 .79389 L .72548 .78665 L p F P
0 0 0 r
s
.43 1 0 r
.69871 .79389 m .68621 .78046 L .65953 .78777 L p F P
0 0 0 r
s
1 .946 0 r
.31539 .7799 m .33129 .79334 L .35623 .78609 L p F P
0 0 0 r
s
1 .793 0 r
.33129 .79334 m .31539 .7799 L .29054 .78721 L p F P
0 0 0 r
s
1 .465 0 r
.75251 .77933 m .76442 .79279 L .79153 .78553 L p F P
0 0 0 r
s
1 .753 0 r
.76442 .79279 m .75251 .77933 L .72548 .78665 L p F P
0 0 0 r
s
.306 1 0 r
.38143 .77877 m .39673 .79223 L .42203 .78497 L p F P
0 0 0 r
s
.43 1 0 r
.39673 .79223 m .38143 .77877 L .35623 .78609 L p F P
0 0 0 r
s
1 .156 0 r
.81892 .7782 m .83022 .79167 L .85768 .78441 L p F P
0 0 0 r
s
1 .28 0 r
.83022 .79167 m .81892 .7782 L .79153 .78553 L p F P
0 0 0 r
s
0 1 .354 r
.44757 .77764 m .46228 .79112 L .48792 .78385 L p F P
0 0 0 r
s
0 1 .414 r
.46228 .79112 m .44757 .77764 L .42203 .78497 L p F P
0 0 0 r
s
1 .011 0 r
.07594 .77707 m .09406 .79056 L .11787 .78328 L p F P
0 0 0 r
s
1 .005 0 r
.09406 .79056 m .07594 .77707 L .05224 .78441 L p F P
0 0 0 r
s
0 1 .54 r
.51382 .7765 m .52793 .79 L .55392 .78272 L p F P
0 0 0 r
s
0 1 .882 r
.52793 .79 m .51382 .7765 L .48792 .78385 L p F P
0 0 0 r
s
1 .054 0 r
.14192 .77593 m .15946 .78945 L .18361 .78216 L p F P
0 0 0 r
s
1 .034 0 r
.15946 .78945 m .14192 .77593 L .11787 .78328 L p F P
0 0 0 r
s
0 1 .127 r
.58016 .77536 m .59368 .78889 L .62001 .78159 L p F P
0 0 0 r
s
0 1 .671 r
.59368 .78889 m .58016 .77536 L .55392 .78272 L p F P
0 0 0 r
s
1 .191 0 r
.20801 .7748 m .22495 .78833 L .24945 .78103 L p F P
0 0 0 r
s
1 .137 0 r
.22495 .78833 m .20801 .7748 L .18361 .78216 L p F P
0 0 0 r
s
.616 1 0 r
.64661 .77423 m .65953 .78777 L .68621 .78046 L p F P
0 0 0 r
s
.077 1 0 r
.65953 .78777 m .64661 .77423 L .62001 .78159 L p F P
0 0 0 r
s
1 .515 0 r
.27419 .77366 m .29054 .78721 L .31539 .7799 L p F P
0 0 0 r
s
1 .41 0 r
.29054 .78721 m .27419 .77366 L .24945 .78103 L p F P
0 0 0 r
s
1 .698 0 r
.71317 .77309 m .72548 .78665 L .75251 .77933 L p F P
0 0 0 r
s
.926 1 0 r
.72548 .78665 m .71317 .77309 L .68621 .78046 L p F P
0 0 0 r
s
.926 1 0 r
.34048 .77252 m .35623 .78609 L .38143 .77877 L p F P
0 0 0 r
s
1 .946 0 r
.35623 .78609 m .34048 .77252 L .31539 .7799 L p F P
0 0 0 r
s
1 .273 0 r
.77982 .77194 m .79153 .78553 L .81892 .7782 L p F P
0 0 0 r
s
1 .465 0 r
.79153 .78553 m .77982 .77194 L .75251 .77933 L p F P
0 0 0 r
s
.262 1 0 r
.40688 .77137 m .42203 .78497 L .44757 .77764 L p F P
0 0 0 r
s
.306 1 0 r
.42203 .78497 m .40688 .77137 L .38143 .77877 L p F P
0 0 0 r
s
1 .156 0 r
.85768 .78441 m .84658 .7708 L .81892 .7782 L p F P
0 0 0 r
s
0 1 .182 r
.47337 .77023 m .48792 .78385 L .51382 .7765 L p F P
0 0 0 r
s
0 1 .354 r
.48792 .78385 m .47337 .77023 L .44757 .77764 L p F P
0 0 0 r
s
1 .018 0 r
.09988 .76966 m .11787 .78328 L .14192 .77593 L p F P
0 0 0 r
s
1 .011 0 r
.11787 .78328 m .09988 .76966 L .07594 .77707 L p F P
0 0 0 r
s
0 1 .127 r
.53997 .76908 m .55392 .78272 L .58016 .77536 L p F P
0 0 0 r
s
0 1 .54 r
.55392 .78272 m .53997 .76908 L .51382 .7765 L p F P
0 0 0 r
s
1 .08 0 r
.16621 .76851 m .18361 .78216 L .20801 .7748 L p F P
0 0 0 r
s
1 .054 0 r
.18361 .78216 m .16621 .76851 L .14192 .77593 L p F P
0 0 0 r
s
.389 1 0 r
.60667 .76793 m .62001 .78159 L .64661 .77423 L p F P
0 0 0 r
s
0 1 .127 r
.62001 .78159 m .60667 .76793 L .58016 .77536 L p F P
0 0 0 r
s
1 .253 0 r
.23265 .76736 m .24945 .78103 L .27419 .77366 L p F P
0 0 0 r
s
1 .191 0 r
.24945 .78103 m .23265 .76736 L .20801 .7748 L p F P
0 0 0 r
s
1 .946 0 r
.67348 .76678 m .68621 .78046 L .71317 .77309 L p F P
0 0 0 r
s
.616 1 0 r
.68621 .78046 m .67348 .76678 L .64661 .77423 L p F P
0 0 0 r
s
1 .615 0 r
.29919 .76621 m .31539 .7799 L .34048 .77252 L p F P
0 0 0 r
s
1 .515 0 r
.31539 .7799 m .29919 .76621 L .27419 .77366 L p F P
0 0 0 r
s
1 .431 0 r
.74039 .76563 m .75251 .77933 L .77982 .77194 L p F P
0 0 0 r
s
1 .698 0 r
.75251 .77933 m .74039 .76563 L .71317 .77309 L p F P
0 0 0 r
s
.841 1 0 r
.36583 .76506 m .38143 .77877 L .40688 .77137 L p F P
0 0 0 r
s
.926 1 0 r
.38143 .77877 m .36583 .76506 L .34048 .77252 L p F P
0 0 0 r
s
1 .152 0 r
.8074 .76448 m .81892 .7782 L .84658 .7708 L p F P
0 0 0 r
s
1 .273 0 r
.81892 .7782 m .8074 .76448 L .77982 .77194 L p F P
0 0 0 r
s
.306 1 0 r
.43258 .7639 m .44757 .77764 L .47337 .77023 L p F P
0 0 0 r
s
.262 1 0 r
.44757 .77764 m .43258 .7639 L .40688 .77137 L p F P
0 0 0 r
s
.077 1 0 r
.49944 .76275 m .51382 .7765 L .53997 .76908 L p F P
0 0 0 r
s
0 1 .182 r
.51382 .7765 m .49944 .76275 L .47337 .77023 L p F P
0 0 0 r
s
1 .029 0 r
.12406 .76217 m .14192 .77593 L .16621 .76851 L p F P
0 0 0 r
s
1 .018 0 r
.14192 .77593 m .12406 .76217 L .09988 .76966 L p F P
0 0 0 r
s
.306 1 0 r
.56639 .76159 m .58016 .77536 L .60667 .76793 L p F P
0 0 0 r
s
0 1 .127 r
.58016 .77536 m .56639 .76159 L .53997 .76908 L p F P
0 0 0 r
s
1 .111 0 r
.19075 .76101 m .20801 .7748 L .23265 .76736 L p F P
0 0 0 r
s
1 .08 0 r
.20801 .7748 m .19075 .76101 L .16621 .76851 L p F P
0 0 0 r
s
.841 1 0 r
.63345 .76043 m .64661 .77423 L .67348 .76678 L p F P
0 0 0 r
s
.389 1 0 r
.64661 .77423 m .63345 .76043 L .60667 .76793 L p F P
0 0 0 r
s
1 .318 0 r
.25754 .75985 m .27419 .77366 L .29919 .76621 L p F P
0 0 0 r
s
1 .253 0 r
.27419 .77366 m .25754 .75985 L .23265 .76736 L p F P
0 0 0 r
s
1 .615 0 r
.70062 .75927 m .71317 .77309 L .74039 .76563 L p F P
0 0 0 r
s
1 .946 0 r
.71317 .77309 m .70062 .75927 L .67348 .76678 L p F P
0 0 0 r
s
1 .698 0 r
.32444 .75869 m .34048 .77252 L .36583 .76506 L p F P
0 0 0 r
s
1 .615 0 r
.34048 .77252 m .32444 .75869 L .29919 .76621 L p F P
0 0 0 r
s
1 .253 0 r
.76789 .7581 m .77982 .77194 L .8074 .76448 L p F P
0 0 0 r
s
1 .431 0 r
.77982 .77194 m .76789 .7581 L .74039 .76563 L p F P
0 0 0 r
s
.811 1 0 r
.39144 .75752 m .40688 .77137 L .43258 .7639 L p F P
0 0 0 r
s
.841 1 0 r
.40688 .77137 m .39144 .75752 L .36583 .76506 L p F P
0 0 0 r
s
1 .152 0 r
.84658 .7708 m .83527 .75694 L .8074 .76448 L p F P
0 0 0 r
s
.43 1 0 r
.45855 .75636 m .47337 .77023 L .49944 .76275 L p F P
0 0 0 r
s
.306 1 0 r
.47337 .77023 m .45855 .75636 L .43258 .7639 L p F P
0 0 0 r
s
.389 1 0 r
.52576 .75519 m .53997 .76908 L .56639 .76159 L p F P
0 0 0 r
s
.077 1 0 r
.53997 .76908 m .52576 .75519 L .49944 .76275 L p F P
0 0 0 r
s
1 .044 0 r
.14848 .7546 m .16621 .76851 L .19075 .76101 L p F P
0 0 0 r
s
1 .029 0 r
.16621 .76851 m .14848 .7546 L .12406 .76217 L p F P
0 0 0 r
s
.717 1 0 r
.59308 .75402 m .60667 .76793 L .63345 .76043 L p F P
0 0 0 r
s
.306 1 0 r
.60667 .76793 m .59308 .75402 L .56639 .76159 L p F P
0 0 0 r
s
1 .148 0 r
.21553 .75343 m .23265 .76736 L .25754 .75985 L p F P
0 0 0 r
s
1 .111 0 r
.23265 .76736 m .21553 .75343 L .19075 .76101 L p F P
0 0 0 r
s
1 .793 0 r
.66051 .75285 m .67348 .76678 L .70062 .75927 L p F P
0 0 0 r
s
.841 1 0 r
.67348 .76678 m .66051 .75285 L .63345 .76043 L p F P
0 0 0 r
s
1 .38 0 r
.28269 .75226 m .29919 .76621 L .32444 .75869 L p F P
0 0 0 r
s
1 .318 0 r
.29919 .76621 m .28269 .75226 L .25754 .75985 L p F P
0 0 0 r
s
1 .38 0 r
.72804 .75167 m .74039 .76563 L .76789 .7581 L p F P
0 0 0 r
s
1 .615 0 r
.74039 .76563 m .72804 .75167 L .70062 .75927 L p F P
0 0 0 r
s
1 .753 0 r
.34995 .75109 m .36583 .76506 L .39144 .75752 L p F P
0 0 0 r
s
1 .698 0 r
.36583 .76506 m .34995 .75109 L .32444 .75869 L p F P
0 0 0 r
s
1 .14 0 r
.79567 .7505 m .8074 .76448 L .83527 .75694 L p F P
0 0 0 r
s
1 .253 0 r
.8074 .76448 m .79567 .7505 L .76789 .7581 L p F P
0 0 0 r
s
.841 1 0 r
.41731 .74991 m .43258 .7639 L .45855 .75636 L p F P
0 0 0 r
s
.811 1 0 r
.43258 .7639 m .41731 .74991 L .39144 .75752 L p F P
0 0 0 r
s
.616 1 0 r
.48478 .74873 m .49944 .76275 L .52576 .75519 L p F P
0 0 0 r
s
.43 1 0 r
.49944 .76275 m .48478 .74873 L .45855 .75636 L p F P
0 0 0 r
s
.717 1 0 r
.55236 .74755 m .56639 .76159 L .59308 .75402 L p F P
0 0 0 r
s
.389 1 0 r
.56639 .76159 m .55236 .74755 L .52576 .75519 L p F P
0 0 0 r
s
1 .061 0 r
.17316 .74696 m .19075 .76101 L .21553 .75343 L p F P
0 0 0 r
s
1 .044 0 r
.19075 .76101 m .17316 .74696 L .14848 .7546 L p F P
0 0 0 r
s
1 .923 0 r
.62005 .74637 m .63345 .76043 L .66051 .75285 L p F P
0 0 0 r
s
.717 1 0 r
.63345 .76043 m .62005 .74637 L .59308 .75402 L p F P
0 0 0 r
s
1 .186 0 r
.24057 .74578 m .25754 .75985 L .28269 .75226 L p F P
0 0 0 r
s
1 .148 0 r
.25754 .75985 m .24057 .74578 L .21553 .75343 L p F P
0 0 0 r
s
1 .515 0 r
.68784 .74519 m .70062 .75927 L .72804 .75167 L p F P
0 0 0 r
s
1 .793 0 r
.70062 .75927 m .68784 .74519 L .66051 .75285 L p F P
0 0 0 r
s
1 .431 0 r
.30809 .74459 m .32444 .75869 L .34995 .75109 L p F P
0 0 0 r
s
1 .38 0 r
.32444 .75869 m .30809 .74459 L .28269 .75226 L p F P
0 0 0 r
s
1 .222 0 r
.75574 .744 m .76789 .7581 L .79567 .7505 L p F P
0 0 0 r
s
1 .38 0 r
.76789 .7581 m .75574 .744 L .72804 .75167 L p F P
0 0 0 r
s
1 .773 0 r
.37572 .74341 m .39144 .75752 L .41731 .74991 L p F P
0 0 0 r
s
1 .753 0 r
.39144 .75752 m .37572 .74341 L .34995 .75109 L p F P
0 0 0 r
s
1 .14 0 r
.83527 .75694 m .82374 .74281 L .79567 .7505 L p F P
0 0 0 r
s
.926 1 0 r
.44345 .74222 m .45855 .75636 L .48478 .74873 L p F P
0 0 0 r
s
.841 1 0 r
.45855 .75636 m .44345 .74222 L .41731 .74991 L p F P
0 0 0 r
s
.841 1 0 r
.51129 .74103 m .52576 .75519 L .55236 .74755 L p F P
0 0 0 r
s
.616 1 0 r
.52576 .75519 m .51129 .74103 L .48478 .74873 L p F P
0 0 0 r
s
1 .971 0 r
.57923 .73984 m .59308 .75402 L .62005 .74637 L p F P
0 0 0 r
s
.717 1 0 r
.59308 .75402 m .57923 .73984 L .55236 .74755 L p F P
0 0 0 r
s
1 .082 0 r
.19809 .73924 m .21553 .75343 L .24057 .74578 L p F P
0 0 0 r
s
1 .061 0 r
.21553 .75343 m .19809 .73924 L .17316 .74696 L p F P
0 0 0 r
s
1 .631 0 r
.64729 .73864 m .66051 .75285 L .68784 .74519 L p F P
0 0 0 r
s
1 .923 0 r
.66051 .75285 m .64729 .73864 L .62005 .74637 L p F P
0 0 0 r
s
1 .222 0 r
.26587 .73805 m .28269 .75226 L .30809 .74459 L p F P
0 0 0 r
s
1 .186 0 r
.28269 .75226 m .26587 .73805 L .24057 .74578 L p F P
0 0 0 r
s
1 .318 0 r
.71545 .73745 m .72804 .75167 L .75574 .744 L p F P
0 0 0 r
s
1 .515 0 r
.72804 .75167 m .71545 .73745 L .68784 .74519 L p F P
0 0 0 r
s
1 .465 0 r
.33376 .73685 m .34995 .75109 L .37572 .74341 L p F P
0 0 0 r
s
1 .431 0 r
.34995 .75109 m .33376 .73685 L .30809 .74459 L p F P
0 0 0 r
s
1 .123 0 r
.78372 .73625 m .79567 .7505 L .82374 .74281 L p F P
0 0 0 r
s
1 .222 0 r
.79567 .7505 m .78372 .73625 L .75574 .744 L p F P
0 0 0 r
s
1 .753 0 r
.40175 .73565 m .41731 .74991 L .44345 .74222 L p F P
0 0 0 r
s
1 .773 0 r
.41731 .74991 m .40175 .73565 L .37572 .74341 L p F P
0 0 0 r
s
1 .946 0 r
.46985 .73445 m .48478 .74873 L .51129 .74103 L p F P
0 0 0 r
s
.926 1 0 r
.48478 .74873 m .46985 .73445 L .44345 .74222 L p F P
0 0 0 r
s
1 .923 0 r
.53806 .73325 m .55236 .74755 L .57923 .73984 L p F P
0 0 0 r
s
.841 1 0 r
.55236 .74755 m .53806 .73325 L .51129 .74103 L p F P
0 0 0 r
s
1 .698 0 r
.60638 .73204 m .62005 .74637 L .64729 .73864 L p F P
0 0 0 r
s
1 .971 0 r
.62005 .74637 m .60638 .73204 L .57923 .73984 L p F P
0 0 0 r
s
1 .103 0 r
.22328 .73144 m .24057 .74578 L .26587 .73805 L p F P
0 0 0 r
s
1 .082 0 r
.24057 .74578 m .22328 .73144 L .19809 .73924 L p F P
0 0 0 r
s
1 .41 0 r
.67481 .73084 m .68784 .74519 L .71545 .73745 L p F P
0 0 0 r
s
1 .631 0 r
.68784 .74519 m .67481 .73084 L .64729 .73864 L p F P
0 0 0 r
s
1 .253 0 r
.29143 .73023 m .30809 .74459 L .33376 .73685 L p F P
0 0 0 r
s
1 .222 0 r
.30809 .74459 m .29143 .73023 L .26587 .73805 L p F P
0 0 0 r
s
1 .186 0 r
.74335 .72963 m .75574 .744 L .78372 .73625 L p F P
0 0 0 r
s
1 .318 0 r
.75574 .744 m .74335 .72963 L .71545 .73745 L p F P
0 0 0 r
s
1 .477 0 r
.35969 .72903 m .37572 .74341 L .40175 .73565 L p F P
0 0 0 r
s
1 .465 0 r
.37572 .74341 m .35969 .72903 L .33376 .73685 L p F P
0 0 0 r
s
1 .123 0 r
.82374 .74281 m .81199 .72842 L .78372 .73625 L p F P
0 0 0 r
s
1 .698 0 r
.42806 .72781 m .44345 .74222 L .46985 .73445 L p F P
0 0 0 r
s
1 .753 0 r
.44345 .74222 m .42806 .72781 L .40175 .73565 L p F P
0 0 0 r
s
1 .793 0 r
.49653 .7266 m .51129 .74103 L .53806 .73325 L p F P
0 0 0 r
s
1 .946 0 r
.51129 .74103 m .49653 .7266 L .46985 .73445 L p F P
0 0 0 r
s
1 .698 0 r
.56512 .72539 m .57923 .73984 L .60638 .73204 L p F P
0 0 0 r
s
1 .923 0 r
.57923 .73984 m .56512 .72539 L .53806 .73325 L p F P
0 0 0 r
s
1 .477 0 r
.63381 .72417 m .64729 .73864 L .67481 .73084 L p F P
0 0 0 r
s
1 .698 0 r
.64729 .73864 m .63381 .72417 L .60638 .73204 L p F P
0 0 0 r
s
1 .123 0 r
.24873 .72356 m .26587 .73805 L .29143 .73023 L p F P
0 0 0 r
s
1 .103 0 r
.26587 .73805 m .24873 .72356 L .22328 .73144 L p F P
0 0 0 r
s
1 .253 0 r
.70262 .72295 m .71545 .73745 L .74335 .72963 L p F P
0 0 0 r
s
1 .41 0 r
.71545 .73745 m .70262 .72295 L .67481 .73084 L p F P
0 0 0 r
s
1 .273 0 r
.31726 .72234 m .33376 .73685 L .35969 .72903 L p F P
0 0 0 r
s
1 .253 0 r
.33376 .73685 m .31726 .72234 L .29143 .73023 L p F P
0 0 0 r
s
1 .103 0 r
.77154 .72173 m .78372 .73625 L .81199 .72842 L p F P
0 0 0 r
s
1 .186 0 r
.78372 .73625 m .77154 .72173 L .74335 .72963 L p F P
0 0 0 r
s
1 .465 0 r
.38589 .72112 m .40175 .73565 L .42806 .72781 L p F P
0 0 0 r
s
1 .477 0 r
.40175 .73565 m .38589 .72112 L .35969 .72903 L p F P
0 0 0 r
s
1 .615 0 r
.45464 .7199 m .46985 .73445 L .49653 .7266 L p F P
0 0 0 r
s
1 .698 0 r
.46985 .73445 m .45464 .7199 L .42806 .72781 L p F P
0 0 0 r
s
1 .631 0 r
.52349 .71867 m .53806 .73325 L .56512 .72539 L p F P
0 0 0 r
s
1 .793 0 r
.53806 .73325 m .52349 .71867 L .49653 .7266 L p F P
0 0 0 r
s
1 .502 0 r
.59246 .71744 m .60638 .73204 L .63381 .72417 L p F P
0 0 0 r
s
1 .698 0 r
.60638 .73204 m .59246 .71744 L .56512 .72539 L p F P
0 0 0 r
s
1 .31 0 r
.66153 .71621 m .67481 .73084 L .70262 .72295 L p F P
0 0 0 r
s
1 .477 0 r
.67481 .73084 m .66153 .71621 L .63381 .72417 L p F P
0 0 0 r
s
1 .14 0 r
.27445 .7156 m .29143 .73023 L .31726 .72234 L p F P
0 0 0 r
s
1 .123 0 r
.29143 .73023 m .27445 .7156 L .24873 .72356 L p F P
0 0 0 r
s
1 .148 0 r
.73072 .71498 m .74335 .72963 L .77154 .72173 L p F P
0 0 0 r
s
1 .253 0 r
.74335 .72963 m .73072 .71498 L .70262 .72295 L p F P
0 0 0 r
s
1 .28 0 r
.34335 .71436 m .35969 .72903 L .38589 .72112 L p F P
0 0 0 r
s
1 .273 0 r
.35969 .72903 m .34335 .71436 L .31726 .72234 L p F P
0 0 0 r
s
1 .103 0 r
.81199 .72842 m .80002 .71375 L .77154 .72173 L p F P
0 0 0 r
s
1 .431 0 r
.41237 .71313 m .42806 .72781 L .45464 .7199 L p F P
0 0 0 r
s
1 .465 0 r
.42806 .72781 m .41237 .71313 L .38589 .72112 L p F P
0 0 0 r
s
1 .515 0 r
.48149 .71189 m .49653 .7266 L .52349 .71867 L p F P
0 0 0 r
s
1 .615 0 r
.49653 .7266 m .48149 .71189 L .45464 .7199 L p F P
0 0 0 r
s
1 .477 0 r
.55073 .71065 m .56512 .72539 L .59246 .71744 L p F P
0 0 0 r
s
1 .631 0 r
.56512 .72539 m .55073 .71065 L .52349 .71867 L p F P
0 0 0 r
s
1 .343 0 r
.62008 .70941 m .63381 .72417 L .66153 .71621 L p F P
0 0 0 r
s
1 .502 0 r
.63381 .72417 m .62008 .70941 L .59246 .71744 L p F P
0 0 0 r
s
1 .191 0 r
.68954 .70817 m .70262 .72295 L .73072 .71498 L p F P
0 0 0 r
s
1 .31 0 r
.70262 .72295 m .68954 .70817 L .66153 .71621 L p F P
0 0 0 r
s
1 .152 0 r
.30044 .70755 m .31726 .72234 L .34335 .71436 L p F P
0 0 0 r
s
1 .14 0 r
.31726 .72234 m .30044 .70755 L .27445 .7156 L p F P
0 0 0 r
s
1 .082 0 r
.75912 .70693 m .77154 .72173 L .80002 .71375 L p F P
0 0 0 r
s
1 .148 0 r
.77154 .72173 m .75912 .70693 L .73072 .71498 L p F P
0 0 0 r
s
1 .273 0 r
.36972 .7063 m .38589 .72112 L .41237 .71313 L p F P
0 0 0 r
s
1 .28 0 r
.38589 .72112 m .36972 .7063 L .34335 .71436 L p F P
0 0 0 r
s
1 .38 0 r
.43912 .70506 m .45464 .7199 L .48149 .71189 L p F P
0 0 0 r
s
1 .431 0 r
.45464 .7199 m .43912 .70506 L .41237 .71313 L p F P
0 0 0 r
s
1 .41 0 r
.50864 .70381 m .52349 .71867 L .55073 .71065 L p F P
0 0 0 r
s
1 .515 0 r
.52349 .71867 m .50864 .70381 L .48149 .71189 L p F P
0 0 0 r
s
1 .343 0 r
.57826 .70256 m .59246 .71744 L .62008 .70941 L p F P
0 0 0 r
s
1 .477 0 r
.59246 .71744 m .57826 .70256 L .55073 .71065 L p F P
0 0 0 r
s
1 .223 0 r
.648 .7013 m .66153 .71621 L .68954 .70817 L p F P
0 0 0 r
s
1 .343 0 r
.66153 .71621 m .648 .7013 L .62008 .70941 L p F P
0 0 0 r
s
1 .111 0 r
.71785 .70005 m .73072 .71498 L .75912 .70693 L p F P
0 0 0 r
s
1 .191 0 r
.73072 .71498 m .71785 .70005 L .68954 .70817 L p F P
0 0 0 r
s
1 .156 0 r
.3267 .69942 m .34335 .71436 L .36972 .7063 L p F P
0 0 0 r
s
1 .152 0 r
.34335 .71436 m .3267 .69942 L .30044 .70755 L p F P
0 0 0 r
s
1 .082 0 r
.80002 .71375 m .78781 .69879 L .75912 .70693 L p F P
0 0 0 r
s
1 .253 0 r
.39637 .69816 m .41237 .71313 L .43912 .70506 L p F P
0 0 0 r
s
1 .273 0 r
.41237 .71313 m .39637 .69816 L .36972 .7063 L p F P
0 0 0 r
s
1 .318 0 r
.46616 .6969 m .48149 .71189 L .50864 .70381 L p F P
0 0 0 r
s
1 .38 0 r
.48149 .71189 m .46616 .6969 L .43912 .70506 L p F P
0 0 0 r
s
1 .31 0 r
.53606 .69563 m .55073 .71065 L .57826 .70256 L p F P
0 0 0 r
s
1 .41 0 r
.55073 .71065 m .53606 .69563 L .50864 .70381 L p F P
0 0 0 r
s
1 .234 0 r
.60608 .69437 m .62008 .70941 L .648 .7013 L p F P
0 0 0 r
s
1 .343 0 r
.62008 .70941 m .60608 .69437 L .57826 .70256 L p F P
0 0 0 r
s
1 .137 0 r
.67621 .6931 m .68954 .70817 L .71785 .70005 L p F P
0 0 0 r
s
1 .223 0 r
.68954 .70817 m .67621 .6931 L .648 .7013 L p F P
0 0 0 r
s
1 .061 0 r
.74645 .69183 m .75912 .70693 L .78781 .69879 L p F P
0 0 0 r
s
1 .111 0 r
.75912 .70693 m .74645 .69183 L .71785 .70005 L p F P
0 0 0 r
s
1 .152 0 r
.35324 .6912 m .36972 .7063 L .39637 .69816 L p F P
0 0 0 r
s
1 .156 0 r
.36972 .7063 m .35324 .6912 L .3267 .69942 L p F P
0 0 0 r
s
1 .222 0 r
.42331 .68993 m .43912 .70506 L .46616 .6969 L p F P
0 0 0 r
s
1 .253 0 r
.43912 .70506 m .42331 .68993 L .39637 .69816 L p F P
0 0 0 r
s
1 .253 0 r
.49349 .68865 m .50864 .70381 L .53606 .69563 L p F P
0 0 0 r
s
1 .318 0 r
.50864 .70381 m .49349 .68865 L .46616 .6969 L p F P
0 0 0 r
s
1 .223 0 r
.56378 .68738 m .57826 .70256 L .60608 .69437 L p F P
0 0 0 r
s
1 .31 0 r
.57826 .70256 m .56378 .68738 L .53606 .69563 L p F P
0 0 0 r
s
1 .152 0 r
.63419 .6861 m .648 .7013 L .67621 .6931 L p F P
0 0 0 r
s
1 .234 0 r
.648 .7013 m .63419 .6861 L .60608 .69437 L p F P
0 0 0 r
s
1 .08 0 r
.70472 .68482 m .71785 .70005 L .74645 .69183 L p F P
0 0 0 r
s
1 .137 0 r
.71785 .70005 m .70472 .68482 L .67621 .6931 L p F P
0 0 0 r
s
1 .061 0 r
.78781 .69879 m .77536 .68353 L .74645 .69183 L p F P
0 0 0 r
s
1 .14 0 r
.38006 .68289 m .39637 .69816 L .42331 .68993 L p F P
0 0 0 r
s
1 .152 0 r
.39637 .69816 m .38006 .68289 L .35324 .6912 L p F P
0 0 0 r
s
1 .186 0 r
.45053 .68161 m .46616 .6969 L .49349 .68865 L p F P
0 0 0 r
s
1 .222 0 r
.46616 .6969 m .45053 .68161 L .42331 .68993 L p F P
0 0 0 r
s
1 .191 0 r
.5211 .68032 m .53606 .69563 L .56378 .68738 L p F P
0 0 0 r
s
1 .253 0 r
.53606 .69563 m .5211 .68032 L .49349 .68865 L p F P
0 0 0 r
s
1 .152 0 r
.5918 .67903 m .60608 .69437 L .63419 .6861 L p F P
0 0 0 r
s
1 .223 0 r
.60608 .69437 m .5918 .67903 L .56378 .68738 L p F P
0 0 0 r
s
1 .093 0 r
.66261 .67774 m .67621 .6931 L .70472 .68482 L p F P
0 0 0 r
s
1 .152 0 r
.67621 .6931 m .66261 .67774 L .63419 .6861 L p F P
0 0 0 r
s
1 .044 0 r
.73354 .67644 m .74645 .69183 L .77536 .68353 L p F P
0 0 0 r
s
1 .08 0 r
.74645 .69183 m .73354 .67644 L .70472 .68482 L p F P
0 0 0 r
s
1 .123 0 r
.40718 .6745 m .42331 .68993 L .45053 .68161 L p F P
0 0 0 r
s
1 .14 0 r
.42331 .68993 m .40718 .6745 L .38006 .68289 L p F P
0 0 0 r
s
1 .148 0 r
.47804 .6732 m .49349 .68865 L .5211 .68032 L p F P
0 0 0 r
s
1 .186 0 r
.49349 .68865 m .47804 .6732 L .45053 .68161 L p F P
0 0 0 r
s
1 .137 0 r
.54902 .6719 m .56378 .68738 L .5918 .67903 L p F P
0 0 0 r
s
1 .191 0 r
.56378 .68738 m .54902 .6719 L .5211 .68032 L p F P
0 0 0 r
s
1 .098 0 r
.62012 .67059 m .63419 .6861 L .66261 .67774 L p F P
0 0 0 r
s
1 .152 0 r
.63419 .6861 m .62012 .67059 L .5918 .67903 L p F P
0 0 0 r
s
1 .054 0 r
.69133 .66929 m .70472 .68482 L .73354 .67644 L p F P
0 0 0 r
s
1 .093 0 r
.70472 .68482 m .69133 .66929 L .66261 .67774 L p F P
0 0 0 r
s
1 .044 0 r
.77536 .68353 m .76267 .66798 L .73354 .67644 L p F P
0 0 0 r
s
1 .103 0 r
.43458 .66601 m .45053 .68161 L .47804 .6732 L p F P
0 0 0 r
s
1 .123 0 r
.45053 .68161 m .43458 .66601 L .40718 .6745 L p F P
0 0 0 r
s
1 .111 0 r
.50585 .6647 m .5211 .68032 L .54902 .6719 L p F P
0 0 0 r
s
1 .148 0 r
.5211 .68032 m .50585 .6647 L .47804 .6732 L p F P
0 0 0 r
s
1 .093 0 r
.57723 .66338 m .5918 .67903 L .62012 .67059 L p F P
0 0 0 r
s
1 .137 0 r
.5918 .67903 m .57723 .66338 L .54902 .6719 L p F P
0 0 0 r
s
1 .06 0 r
.64874 .66206 m .66261 .67774 L .69133 .66929 L p F P
0 0 0 r
s
1 .098 0 r
.66261 .67774 m .64874 .66206 L .62012 .67059 L p F P
0 0 0 r
s
1 .029 0 r
.72037 .66074 m .73354 .67644 L .76267 .66798 L p F P
0 0 0 r
s
1 .054 0 r
.73354 .67644 m .72037 .66074 L .69133 .66929 L p F P
0 0 0 r
s
1 .082 0 r
.46228 .65743 m .47804 .6732 L .50585 .6647 L p F P
0 0 0 r
s
1 .103 0 r
.47804 .6732 m .46228 .65743 L .43458 .66601 L p F P
0 0 0 r
s
1 .08 0 r
.53396 .65611 m .54902 .6719 L .57723 .66338 L p F P
0 0 0 r
s
1 .111 0 r
.54902 .6719 m .53396 .65611 L .50585 .6647 L p F P
0 0 0 r
s
1 .06 0 r
.60576 .65477 m .62012 .67059 L .64874 .66206 L p F P
0 0 0 r
s
1 .093 0 r
.62012 .67059 m .60576 .65477 L .57723 .66338 L p F P
0 0 0 r
s
1 .034 0 r
.67768 .65344 m .69133 .66929 L .72037 .66074 L p F P
0 0 0 r
s
1 .06 0 r
.69133 .66929 m .67768 .65344 L .64874 .66206 L p F P
0 0 0 r
s
1 .029 0 r
.76267 .66798 m .74971 .65211 L .72037 .66074 L p F P
0 0 0 r
s
1 .061 0 r
.49028 .64876 m .50585 .6647 L .53396 .65611 L p F P
0 0 0 r
s
1 .082 0 r
.50585 .6647 m .49028 .64876 L .46228 .65743 L p F P
0 0 0 r
s
1 .054 0 r
.56238 .64742 m .57723 .66338 L .60576 .65477 L p F P
0 0 0 r
s
1 .08 0 r
.57723 .66338 m .56238 .64742 L .53396 .65611 L p F P
0 0 0 r
s
1 .036 0 r
.63459 .64607 m .64874 .66206 L .67768 .65344 L p F P
0 0 0 r
s
1 .06 0 r
.64874 .66206 m .63459 .64607 L .60576 .65477 L p F P
0 0 0 r
s
1 .018 0 r
.70693 .64473 m .72037 .66074 L .74971 .65211 L p F P
0 0 0 r
s
1 .034 0 r
.72037 .66074 m .70693 .64473 L .67768 .65344 L p F P
0 0 0 r
s
1 .044 0 r
.51859 .63999 m .53396 .65611 L .56238 .64742 L p F P
0 0 0 r
s
1 .061 0 r
.53396 .65611 m .51859 .63999 L .49028 .64876 L p F P
0 0 0 r
s
1 .034 0 r
.59111 .63864 m .60576 .65477 L .63459 .64607 L p F P
0 0 0 r
s
1 .054 0 r
.60576 .65477 m .59111 .63864 L .56238 .64742 L p F P
0 0 0 r
s
1 .02 0 r
.66374 .63728 m .67768 .65344 L .70693 .64473 L p F P
0 0 0 r
s
1 .036 0 r
.67768 .65344 m .66374 .63728 L .63459 .64607 L p F P
0 0 0 r
s
1 .018 0 r
.74971 .65211 m .7365 .63592 L .70693 .64473 L p F P
0 0 0 r
s
1 .029 0 r
.54722 .63113 m .56238 .64742 L .59111 .63864 L p F P
0 0 0 r
s
1 .044 0 r
.56238 .64742 m .54722 .63113 L .51859 .63999 L p F P
0 0 0 r
s
1 .02 0 r
.62015 .62976 m .63459 .64607 L .66374 .63728 L p F P
0 0 0 r
s
1 .034 0 r
.63459 .64607 m .62015 .62976 L .59111 .63864 L p F P
0 0 0 r
s
1 .011 0 r
.69322 .62838 m .70693 .64473 L .7365 .63592 L p F P
0 0 0 r
s
1 .02 0 r
.70693 .64473 m .69322 .62838 L .66374 .63728 L p F P
0 0 0 r
s
1 .018 0 r
.57616 .62217 m .59111 .63864 L .62015 .62976 L p F P
0 0 0 r
s
1 .029 0 r
.59111 .63864 m .57616 .62217 L .54722 .63113 L p F P
0 0 0 r
s
1 .011 0 r
.64952 .62078 m .66374 .63728 L .69322 .62838 L p F P
0 0 0 r
s
1 .02 0 r
.66374 .63728 m .64952 .62078 L .62015 .62976 L p F P
0 0 0 r
s
1 .011 0 r
.7365 .63592 m .72302 .61939 L .69322 .62838 L p F P
0 0 0 r
s
1 .011 0 r
.60542 .61311 m .62015 .62976 L .64952 .62078 L p F P
0 0 0 r
s
1 .018 0 r
.62015 .62976 m .60542 .61311 L .57616 .62217 L p F P
0 0 0 r
s
1 .005 0 r
.67922 .61171 m .69322 .62838 L .72302 .61939 L p F P
0 0 0 r
s
1 .011 0 r
.69322 .62838 m .67922 .61171 L .64952 .62078 L p F P
0 0 0 r
s
1 .005 0 r
.63501 .60395 m .64952 .62078 L .67922 .61171 L p F P
0 0 0 r
s
1 .011 0 r
.64952 .62078 m .63501 .60395 L .60542 .61311 L p F P
0 0 0 r
s
1 .005 0 r
.72302 .61939 m .70925 .60253 L .67922 .61171 L p F P
0 0 0 r
s
1 .002 0 r
.66493 .59468 m .67922 .61171 L .70925 .60253 L p F P
0 0 0 r
s
1 .005 0 r
.67922 .61171 m .66493 .59468 L .63501 .60395 L p F P
0 0 0 r
s
1 .002 0 r
.70925 .60253 m .6952 .58531 L .66493 .59468 L p F P
0 0 0 r
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[227]:=",
  ImageSize->{265.313, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004900017b000`400?l00000o`00003o/03oool2
000005L0oooo002^0?ooo`80000000<0oooo000000000000EP3oool00:/0oooo0`0000030?ooo`80
0000EP3oool00:T0oooo0P0000060?ooo`030000003oool0000005D0oooo002W0?ooo`800000203o
ool00`000000oooo0000001E0?ooo`00Y03oool3000000X0oooo00@000000?ooo`3oool00000E03o
ool00:80oooo0P00000=0?ooo`050000003oool0oooo0?ooo`000000D`3oool009l0oooo0`00000=
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0D@3oool009d0oooo0P00000>0?oo
o`<0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`1@0?ooo`00V`3oool2000000h0
oooo0P0000030?l000030000003oool0000000@0oooo00<000000?ooo`3oool0C`3oool009P0oooo
0`00000=0?ooo`<000001@3o00000`000000oooo000000040?ooo`030000003oool0oooo04l0oooo
002F0?ooo`8000003P3oool200000080o`4000<000000?l0003o0000103o0002000000D0oooo00<0
00000?ooo`3oool0CP3oool009<0oooo0`00000>0?ooo`800000103o0@000`000000o`000?l00004
0?l0008000001@3oool00`000000oooo0?ooo`1>0?ooo`00T@3oool2000000l0oooo0P0000070?l1
00030000003o0000o`0000<0o`000P0000060?ooo`030000003oool0oooo04d0oooo002?0?ooo`80
00003`3oool2000000030?l200000000o`4000H0o`4000<000000?l0003o00000`0000000`3o0@00
0000000000060?ooo`030000003oool0oooo04`0oooo002<0?ooo`<000003`3oool2000000<0o`80
00<000000?l1003o0@001@3o0@03000000@0o`400P0000060?ooo`030000003oool0oooo04`0oooo
002:0?ooo`8000003`3oool3000000H0o`8000<000000?l1003o0@000P3o0@0200000080o`8000<0
00000?l1003o0@000P3o0@000`000000o`40000000060?ooo`030000003oool0oooo04/0oooo0027
0?ooo`<000003@3oool400000080o`@000<000000?l2003o0P00103o0P000`000000o`400?l10002
000000@0o`8000<000000?l1003o0@000P3o0@0010000000o`400?l1000000060?ooo`030000003o
ool0oooo04X0oooo00250?ooo`8000003P3oool2000000H0o`@000<000000?l2003o0P001@3o0P02
000000L0o`8000@000000?l1003o0@00o`400`0000000`3o0P0000000?ooo`040?ooo`030000003o
ool0oooo04X0oooo00230?ooo`8000003P3oool2000000030?l700000000o`@000H0o`@000<00000
0?l2003o0P000P3o0P02000000030?l500000000o`8000H0o`8000<000000?l1003o0@000P000003
0?l200030000003oool0oooo00@0oooo00<000000?ooo`3oool0B@3oool00800oooo0`00000>0?oo
o`800000103o1`000`000000o`@00?l400040?l400030000003o0P00o`8000800000103o1@000`00
0000o`800?l200050?l20080000000<0o`800000003o0P000`3o0P000`000000oooo0?ooo`030?oo
o`030000003oool0oooo04T0oooo001n0?ooo`8000003`3oool2000000H0o`L000<000000?l4003o
1000103o1003000000H0o`D000<000000?l2003o0P000`3o0P02000000040?l500000000o`800000
00@0o`8000<000000?ooo`3oool0103oool00`000000oooo0?ooo`180?ooo`00N`3oool3000000l0
oooo0P0000000`3o2`0000000?l700060?l700030000003o1000o`@000<000000P3o20000`000000
o`D00?l500050?l500030000003o0P00o`80008000000`3o1@000`000000o`80000000050?l20003
0000003oool0oooo00@0oooo00<000000?ooo`3oool0A`3oool007T0oooo0P00000@0?ooo`800000
0`3o2`000`000000o`L00?l700050?l700<000001@3o20000`000000o`D00?l500050?l500<00000
1P3o1@02000000<0o`800P0000000`3o100000000?ooo`040?ooo`030000003oool0oooo04L0oooo
001g0?ooo`800000403oool2000000H0o`/000<000000?l7003o1`000P3o1`0200000080o`d000<0
00000?l8003o2000103o20000`000000o`D00?l500020?l5008000000P3o2@000`000000o`D00?l5
00040?l50080000000<0o`800000000000000`3o10000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo04H0oooo001d0?ooo`<00000403oool2000000030?l?00000000o`/000D0o`/000<00000
0?l7003o1`000P0000040?l=00030000003o2000o`P000@0o`P000<000000?l5003o1@000P000004
0?l900030000003o1@00o`D000D0o`D00P0000060?l400030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0A@3oool00780oooo0P00000A0?ooo`8000000`3o3`000`000000o`/00?l;00050?l;
008000001`3o3@000`000000o`P00?l800030?l800<000001`3o2@000`000000o`D00?l500020?l5
0080000000<0o`P00000003o10001@3o10000`000000oooo0?ooo`040?ooo`030000003oool0oooo
04D0oooo001_0?ooo`<00000403oool3000000H0o`l000<000000?l;003o2`000P3o2`0200000003
0?lD00000000o`d000H0o`d000<000000?l8003o20000`0000020?l?00030000003o2@00o`T000D0
o`T000<000000?l5003o1@000P0000030?l800030000003o1000o`@000D0o`@000<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`140?ooo`00K@3oool200000100oooo0`0000020?lD00030000
003o3`00o`l000@0o`l000<000000?l;003o2`000P0000040?lD00030000003o3@00o`d000D0o`d0
0P0000050?l?00030000003o2@00o`T000D0o`T00`0000050?l800800000103o1002000000030?l7
00000000oooo00@0oooo00<000000?ooo`3oool0A03oool006/0oooo0P00000@0?ooo`8000001@3o
50000`000000o`l00?l?00050?l?008000001P3o50000`000000o`d00?l=00030?l=00<000001`3o
3`000`000000o`T00?l900020?l9008000000P3o3`000`000000o`P00?l800030?l8008000000P3o
1002000000<0o`L000<000000?ooo`3oool0103oool00`000000oooo0?ooo`130?ooo`00J03oool3
00000100oooo0`0000070?lD00030000003o3`00o`l00080o`l00P0000000`3o700000000?lD0006
0?lD00030000003o3@00o`d0008000000`3o5`000`000000o`l00?l?00040?l?00030000003o2@00
o`T000800000103o3`000`000000o`P00?l800030?l800040000003o20000000000000H0o`L000<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`120?ooo`00IP3oool200000140oooo0P000003
0?lJ00030000003o5000oa@000@0oa@000<000000?l?003o3`000P0000040?lL00030000003o5000
oa@000D0oa@00P0000050?lG00030000003o3`00o`l000D0o`l00P0000070?l?00030000003o2000
o`P00080o`P00P0000000`3o3@0000000?l700050?l700030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0@P3oool006<0oooo0`00000@0?ooo`<000001@3o6P000`000000oa@00?lD00050?lD
008000001P3o70000`000000oa@00?lD00030?lD00<000001`3o5`000`000000o`l00?l?00020?l?
0080000000<0oaT00000003o3`001P3o3`000`000000o`P00?l8000300000080o`d000<000000?l7
003o1`001@3o1`000`000000oooo0?ooo`040?ooo`030000003oool0oooo0440oooo001Q0?ooo`80
00004@3oool2000000030?lO00000000oaX000H0oaX000<000000?lD003o50000P3o500200000003
0?lU00000000oa`000H0oa`000<000000?lD003o50000P0000030?lS00030000003o5`00oaL000@0
oaL000<000000?l?003o3`000P0000040?lI00030000003o3`00o`l000D0o`l00P0000020?l=0005
0000003o3@00o`d00?l=00000000103o1`02000000030?l;00000000oooo00D0oooo00<000000?oo
o`3oool0@03oool005h0oooo0`00000A0?ooo`800000103o7`000`000000oaX00?lJ00040?lJ0003
0000003o5000oa@0008000000`3o9@000`000000oa`00?lL00050?lL00<000001@3o8`000`000000
oaL00?lG00050?lG008000001P3o6@000`000000o`l00?l?00030?l?0080000000D0oaL00000003o
3@00o`d0000000030?l=00030000003o1`00o`L0008000000`3o2`000`000000oooo0?ooo`040?oo
o`030000003oool0oooo0400oooo001L0?ooo`8000004@3oool3000000H0oal000<000000?lJ003o
6P001@3o6P02000000H0obD000<000000?lL003o70000P3o7002000000030?l`00000000ob<000H0
ob<000<000000?lG003o5`000P3o5`02000000030?lV00000000oaT000H0oaT000<000000?l?003o
3`000P0000030?lG00040000003o3@00o`d0000000@0o`d00P0000060?l;00030000003oool0oooo
00@0oooo00<000000?ooo`3oool0?`3oool005X0oooo0P00000@0?ooo`<000000P3o8`000`000000
oal00?lO00050?lO00030000003o6P00oaX00080oaX00`0000070?lU00030000003o7000oa`00080
0000103o<0000`000000ob<00?lS00040?lS00030000003o5`00oaL0008000000`3o9P000`000000
oaT00?lI00050?lI00<000001P3o5`000`000000o`d0000000020?l=0080000000<0oa@00000003o
2`001@3o2`000`000000oooo0?ooo`040?ooo`030000003oool0oooo03l0oooo001G0?ooo`<00000
403oool2000000H0ob<000<000000?lO003o7`00103o7`000`000000oaX00?lJ0002000000<0obl0
00<000000?lU003o9@001@3o9@02000000H0oc0000<000000?lS003o8`001@3o8`02000000H0obH0
00<000000?lI003o6@000P3o6@0200000080obH000<000000?lG003o5`00103o5`000`000000o`d0
00000002000000<0oa@000<000000?l;003o2`001@3o2`000`000000oooo0?ooo`040?ooo`030000
003oool0oooo03h0oooo001E0?ooo`8000004@3oool2000000030?lV00000000ob<000D0ob<000<0
00000?lO003o7`00103o7`03000000D0obl000<000000?lU003o9@000`3o9@02000000030?m00000
0000oc0000H0oc0000<000000?lS003o8`000P3o8`02000000030?li00000000obH000D0obH000<0
00000?lI003o6@000P0000040?lV00030000003o5`00oaL000D0oaL00P0000060?lD00030000003o
2`00o`/00080o`/00P0000000`3o3`0000000?ooo`050?ooo`030000003oool0oooo03d0oooo001B
0?ooo`<000004@3oool2000000<0obH000<000000?lS003o8`001@3o8`000`000000oal00?lO0003
000000030?lh00000000obl000H0obl000D000000?lU003o9@00obD0000000030?m000030000003o
<000oc0000D0oc0000<000000?lS003o8`000P0000030?li00030000003o9P00obH000D0obH00P00
00070?lV00030000003o5`00oaL00080oaL00P0000000`3o8`0000000?lD00050?lD00030000003o
2`00o`/0008000000`3o3`000`000000oooo0?ooo`040?ooo`030000003oool0oooo03d0oooo001@
0?ooo`8000004P3oool2000000H0obH000<000000?lS003o8`001@3o8`02000000D0ocP000<00000
0?l_003o;`00103o;`0010000000obD00000000000050?m000030000003o<000oc0000D0oc000P00
00060?li00030000003o9P00obH00080obH00P0000000`3o>`0000000?lV00060?lV00030000003o
5`00oaL0008000000`3o8`000`000000oa@00?lD00050?lD008000001P3o3`000`000000oooo0?oo
o`040?ooo`030000003oool0oooo03`0oooo001>0?ooo`8000004@3oool3000000030?lW00000000
obH000H0obH000<000000?lS003o8`000P3o8`03000000H0ocP000<000000?l_003o;`001@3o;`00
0`000000od000?m000050?m000030000003o<000oc0000<0oc000`0000070?li00030000003o9P00
obH0008000000`3o>`000`000000obH00?lV00050?lV00<000001@3o8`02000000@0oa@00P000000
0`3o700000000?l?00060?l?00030000003oool0oooo00@0oooo00<000000?ooo`3oool0>`3oool0
04/0oooo0`00000A0?ooo`8000001@3o9`000`000000obH00?lV00040?lV00030000003o8`00ob<0
008000000`3o@0000`000000ocP00?lh00040?lh00030000003o;`00obl00080obl00P0000000`3o
D@0000000?m000060?m000050000003o<000oc000?l`000000000`3oC`000`000000ocT00?li0005
0?li008000001P3o>`000`000000obH00?lV00020?lV008000000P3o>@000`000000ob<00?lS0003
0?lS008000000P3o5002000000<0oa`000<000000?l?003o3`000`3o3`02000000030?lD00000000
oooo00@0oooo00<000000?ooo`3oool0>`3oool004T0oooo0P00000B0?ooo`<000001P3o9`000`00
0000obH00?lV00050?lV008000001@3o@0000`000000ocP00?lh00040?lh00030000003o;`00obl0
008000000`3oD@000`000000od000?m000050?m000040000003o<0000000000000@0odl000<00000
0?li003o>@000`3o>@03000000L0oc/000<000000?lV003o9P000P0000040?li00030000003o8`00
ob<000@0ob<00`0000060?lL00030000003o3`00o`l0008000000`3o50000`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03X0oooo00160?ooo`<000004P3oool2000000<0obH000<000000?lW
003o9`00103o9`000`000000obH00?lV00020?lV00<000001`3o@0000`000000ocP00?lh00040?lh
008000001P3oD@000`000000od000?m000050?m000030000003oC`00odl000D0odl000D000000?li
003o>@00ocT0000000030?mG00030000003o>`00oc/000D0oc/00P0000070?li00030000003o8`00
ob<00080ob<00P0000000`3o<00000000?lL00060?lL008000001P3o50000`000000oooo0?ooo`03
0?ooo`030000003oool0oooo03X0oooo00140?ooo`8000004P3oool3000000D0obH000<000000?lW
003o9`00103o9`000`000000obH00?lV0002000000<0odD000<000000?m0003o@000103o@0000`00
0000ocP00?lh00020?lh0080000000<0of400000003oD@001P3oD@000`000000od000?m000020?m0
00<000001`3oC`0010000000ocT00000000000040?mG00030000003o>`00oc/000<0oc/00P000000
0`3oE`0000000?li00060?li00030000003o8`00ob<00080000000@0oc000000003o<00000001@3o
7002000000030?lU00000000oa@000D0oa@000<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0i0?ooo`00@P3oool200000140oooo0`0000020?lS00030000003o9P00obH000@0obH000<00000
0?lW003o9`000`3o9`03000000D0odD000<000000?m0003o@0001@3o@00010000000ocP000000000
00030?mQ00030000003oD@00oe4000D0oe4000<000000?m0003o@0000P0000030?mX00030000003o
C`00odl000D0odl000<000000?mG003oE`001@3oE`001@000000oc/00?lk003o>`00000000<0oeL0
00<000000?li003o>@001P3o>@02000000<0oc0000@000000?l`003o<00000000`3o70001@000000
obD00?lU003o9@00000000L0oa@000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0h0?oo
o`00?`3oool300000100oooo0`0000050?lS00030000003o9P00obH000@0obH000<000000?lW003o
9`000`0000000`3oA`0000000?m500060?m500030000003o@000od0000@0od000P0000060?mQ0003
0000003oD@00oe4000D0oe400P0000050?mX00030000003oC`00odl000<0odl00`0000070?mG0004
0000003o>`000000000000D0oeL000<000000?li003o>@000`3o>@03000000@0oc0000D000000?l`
003o<00000000?lL0002000000D0obD000<000000?lD003o50000P3o5002000000030?lJ00000000
oooo00@0oooo00<000000?ooo`3oool0>03oool003d0oooo0P00000@0?ooo`<000000P3o7`000`00
0000ob<00?lS00040?lS00030000003o9P00obH000<0obH00`0000050?m700030000003oA@00odD0
00@0odD000<000000?m0003o@0000P3o@002000000030?m^00000000of4000D0of4000<000000?mA
003oD@000`3oD@03000000L0ofP000D000000?m?003oC`00odl0000000030?mj00030000003oE`00
oeL000D0oeL000<000000?mG003oE`001P3oE`001@000000ocT00?li003o>@00000000<0odl000D0
00000?l`003o<000oc00000000030?l`00030000003o9@00obD000D0obD000<000000?lD003o5000
0P0000030?lJ00030000003oool0oooo00@0oooo00<000000?ooo`3oool0=`3oool003X0oooo0`00
000?0?ooo`<000001P3o7`000`000000ob<00?lS00030?lS00030000003o9P00obH000<000000P3o
A@000`000000odL00?m700030?m700030000003oA@00odD000D0odD000@000000?m0000000000000
0`3oKP000`000000of400?mQ00050?mQ00050000003oD@00oe400?mA000000000`3oP`000`000000
ofP00?mX00040?mX00040000003oC`000000000000@0ogX000<000000?mG003oE`00103oE`000`00
0000oh00000000070?mG00040000003o>@000000000000@0odl000H000000?l`003o<000oc000000
003o<002000000030?m000000000obD000H0obD00P0000060?lJ00030000003oool0oooo00@0oooo
00<000000?ooo`3oool0=P3oool003P0oooo0P00000@0?ooo`8000000P3o6P000`000000oal00?lO
00040?lO00030000003o8`00ob<000<0ob<00`0000050?m500030000003oA`00odL000@0odL000<0
00000?m5003oA@000`3oA@03000000H0ofh000<000000?mQ003oH@00103oH@0010000000oe400000
000000040?n300030000003oJ000ofP000D0ofP000<000000?mj003oNP001@3oNP000`000000oeL0
0?mG00020?mG00040000003oP000oh00000000P0oeL000<000000?m?003oC`001@3oC`000`000000
oc000?l`0002000000<0od0000<000000?lU003o9@000`3o9@02000000030?l_00000000oaX000D0
oaX000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0f0?ooo`00=P3oool2000000l0oooo
0`0000050?lJ00030000003o7`00oal000@0oal000<000000?lS003o8`000P0000020?m000030000
003oA@00odD000@0odD000<000000?m7003oA`000`3oA`000`000000odD00?m5000300000080ogL0
00<000000?m^003oKP00103oKP000`000000of400?mQ00050?mQ00030000003oP`00oh<000D0oh<0
00<000000?mX003oJ0000P3oJ003000000L0ogX000<000000?mG003oE`000P0000040?n000030000
003oE`00oeL000@0oeL00P0000070?m?00040000003o<0000000000000D0od0000D000000?lU003o
9@00obD0000000030?l_00030000003o6P00oaX000D0oaX000<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0e0?ooo`00<`3oool3000000h0oooo0`0000020?lD00030000003o6P00oaX000<0
oaX000<000000?lO003o7`00103o7`03000000@0od0000<000000?m5003oA@00103oA@000`000000
odL00?m700040?m7008000001@3oM`000`000000ofh00?m^00050?m^00030000003oH@00of400080
of400`0000070?n300050000003oJ000ofP00?mX000000000`3oX@000`000000ogX00?mj00050?mj
008000001P3oP0000`000000oeL00?mG00030?mG00040000003oNP00ogX0000000L0odl000<00000
0?m0000000001@3o@00010000000obD00000000000050?l_00030000003o6P00oaX00080oaX00`00
00060?ooo`030000003oool0oooo03D0oooo000a0?ooo`8000003`3oool2000000D0oa@000<00000
0?lJ003o6P00103o6P000`000000oal00?lO0003000000030?lh00000000od0000D0od0000<00000
0?m5003oA@00103oA@0010000000odL00?m7003oA`03000000L0ogL000<000000?m^003oKP00103o
KP000`000000of400?mQ0002000000<0oid000<000000?n3003oP`001@3oP`03000000@0oj4000<0
00000?mj003oNP001@3oNP000`000000oh000?n000060?n000030000003oE`00oeL0008000000`3o
NP000`000000odl00?m?00030?m?0080000000<0ofP00000000000001P3o@0000`000000obl00?l_
00050?l_00030000003o6P00oaX0008000000`3o7`000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo03@0oooo000^0?ooo`<000003`3oool2000000030?l?00000000oa@000D0oa@000<00000
0?lJ003o6P000`3o6P03000000D0ocP000<000000?m0003o@0000`3o@0000`000000odD00?m50004
0?m500040000003oA`000000000000<0ogX000<000000?mg003oM`00103oM`000`000000ofh00?m^
00050?m^008000001@3oW@000`000000oh<00?n300050?n300030000003oX@00oj4000@0oj4000<0
00000?mj003oNP00103oNP02000000P0oh0000<000000?mG000000001P3oNP001@000000odl00?m?
003oC`00000000<0ofP00P0000040?m00080000000<0oe400000003o;`001P3o;`02000000D0oal0
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0c0?ooo`00;03oool200000100oooo0P00
00040?l?00030000003o5000oa@000<0oa@000<000000?lJ003o6P000`0000020?l_00030000003o
>000ocP000<0ocP000<000000?m0003o@000103o@0000`000000odD00?m500030?m5008000001@3o
NP000`000000ogL00?mg00050?mg00030000003oKP00ofh00080ofh00`0000070?nM00030000003o
P`00oh<00080oh<00`0000070?nQ00030000003oNP00ogX00080ogX000@000000?nb003o/P000000
203oP0000`000000ogX00?mj00050?mj00040000003oC`000000000000D0ofP000D000000?m0003o
@000od00000000030?mA00030000003o;`00obl000<0obl00`0000070?lO00030000003oool0oooo
00@0oooo00<000000?ooo`3oool0<`3oool002X0oooo0P00000@0?ooo`8000001P3o3`000`000000
oa@00?lD00030?lD00<000001@3o;`000`000000ocP00?lh00040?lh00030000003o@000od0000<0
od0000<000000?m5003oA@000`0000000`3oM`0000000?mj00050?mj00030000003oM`00ogL000@0
ogL000<000000?m^003oKP000P0000030?nb00030000003oW@00oid000@0oid000D000000?n3003o
P`00oh<0000000030?o;00030000003oX@00oj4000@0oj4000<000000?mj003oNP000P0000030?nb
00030000003oP000oh0000@0oh000`0000080?mj00030000003oJ000ofP000D0ofP000@000000?m0
0000000000001@3oD@001@000000obl00?l_003o;`00000000<0ocP000<000000?lO003o7`000P3o
7`02000000030?lS00000000oooo00D0oooo00<000000?ooo`3oool0<P3oool002L0oooo0`00000?
0?ooo`<000000P3o2`000`000000o`l00?l?00040?l?00030000003o5000oa@0008000000P3o9@00
0`000000obl00?l_00040?l_00030000003o>000ocP000<0ocP000<000000?m0003o@0000P3o@004
000000D0ogL000<000000?mj003oNP000`3oNP000`000000ogL00?mg00050?mg008000001@3o/P00
0`000000oid00?nM00050?nM00<00000103ob`000`000000oj400?nQ00050?nQ008000001P3o/P00
0`000000oh000?n000020?n000050000003o/P00ok800?nb000000001P3oNP02000000L0ofP00P00
00070?mA00040000003o;`000000000000@0ocP000<000000?lO003o7`000P0000030?lS00030000
003oool0oooo00D0oooo00<000000?ooo`3oool0<@3oool002D0oooo0P00000?0?ooo`<000001@3o
2`000`000000o`l00?l?00040?l?00<00000103o9@000`000000obl00?l_00050?l_00030000003o
>000ocP00080ocP01@0000020?m^00030000003oM`00ogL000@0ogL000<000000?mj003oNP00103o
NP000`000000ogL00?mg00020?mg00<000001P3o/P000`000000oid00?nM00050?nM00030000003o
b`00ol/000@0ol/000<000000?nQ003oX@001@3oX@000`000000ok800?nb00050?nb00050000003o
P000oh000?n000000000103o/P000`000000ogX00?mj00030?mj00040000003oX@00oj40000000H0
ofP000<000000?n3000000001`3oD@000`000000ocP00?lh00050?lh008000001P3o8`000`000000
oooo0?ooo`040?ooo`030000003oool0oooo0340oooo000R0?ooo`<000003`3oool200000080o`L0
00<000000?l;003o2`00103o2`000`000000o`l00?l?000300000080oa`000<000000?lU003o9@00
0`3o9@000`000000obl00?l_00040?l_00030000003o>000ocP0008000000P3oH@000`000000ofh0
0?m^00030?m^00030000003oM`00ogL000@0ogL000<000000?mj003oNP000`3oNP000`000000ogL0
0?mg0002000000<0ol0000<000000?nb003o/P00103o/P000`000000oid00?nM00020?nM00<00000
1`3ob`000`000000oj400?nQ00020?nQ00<00000203o/P03000000H0ok8000<000000?mj003oNP00
0P0000030?nQ00030000003oJ000ofP000<0ofP00P0000000`3oP`0000000?mA00040?mA00<00000
1P3o>0000`000000od00000000070?lS00030000003oool0oooo00@0oooo00<000000?ooo`3oool0
<03oool00200oooo0P00000?0?ooo`<000001@3o1`000`000000o`/00?l;00030?l;00<000001@3o
70000`000000obD00?lU00040?lU00030000003o;`00obl000<0obl00`0000040?mQ00030000003o
KP00ofh000<0ofh000<000000?mg003oM`00103oM`000`000000ogX00?mj00030?mj00<000001@3o
`0000`000000ok800?nb00040?nb00050000003oW@00oid00?nM000000000`3olP000`000000ol/0
0?o;00040?o;00050000003oX@00oj400?nQ000000000`3ok0000`000000ok800?nb00050?nb0003
0000003o/P00ok8000H0ok8000<000000?mj000000001P3oX@000`000000ofP00?mX000200000080
oh<000<000000?n3000000000`3oD@001@000000of400?mQ003oH@00000000@0ocP000@000000?m0
003o@00000001@3o8`02000000030?lV00000000oooo00@0oooo00<000000?ooo`3oool0<03oool0
01h0oooo0P00000>0?ooo`<000000P3o10000`000000o`L00?l700040?l700030000003o2`00o`/0
008000000P3o50000`000000oa`00?lL00040?lL00030000003o9@00obD000<0obD000<000000?l_
003o;`000`0000000`3oD@0000000?mQ00050?mQ00030000003oKP00ofh000<0ofh000<000000?mg
003oM`00103oM`000`000000ogX000000002000000030?o500000000ol0000D0ol0000<000000?nb
003o/P001@3o/P03000000@0oo8000<000000?o;003ob`001@3ob`03000000@0on`000<000000?nb
003o/P00103o/P02000000T0ok8000<000000?nQ003oX@001@3oX@000`000000ofP0000000040?n3
00040000003oP`0000000?mA00800000103oH@000`000000ocP00?lh0002000000@0od0000D00000
0?lS003o8`00ob<0000000030?lV00030000003oool0oooo00@0oooo00<000000?ooo`3oool0;`3o
ool001/0oooo0`00000=0?ooo`<000001@3o10000`000000o`L00?l700040?l700<000001@3o5000
0`000000oa`00?lL00030?lL00030000003o9@00obD00080obD0100000050?mA00030000003oH@00
of4000<0of4000<000000?m^003oKP000`3oKP000`000000ogL00?mg00030?mg00<000001@3oa@00
0`000000ol000?o000040?o000030000003o/P00ok8000@0ok8000<000000?ob003olP00103olP00
0`000000ol/00?o;00050?o;00030000003ok000on`000@0on`000<000000?nb003o/P000`3o/P00
10000000ooP00?oh000000070?nb00800000203oX@000`000000oh<00?n300030?n300040000003o
P`00oh<0000000L0of400P0000060?m000040000003o8`000000000000D0obH000<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0^0?ooo`006@3oool2000000h0oooo0P0000020?l200030000
003o1000o`@000@0o`@000<000000?l7003o1`000`0000020?l=00030000003o5000oa@000<0oa@0
00<000000?lL003o70000`3o700500000080od0000<000000?mA003oD@00103oD@000`000000of40
0?mQ00040?mQ00030000003oKP00ofh000<0ofh000<000000?mg000000000P0000000`3o`0000000
0?o500050?o500030000003o`000ol0000@0ol0000<000000?nb003o/P000P3o/P03000000L0oo80
00<000000?o;003ob`000`3ob`02000000L0on`000D000000?nb003o/P00ok80000000030?oh0003
0000003o/P00ok8000@0ok8000@000000?o/003ok00000001P3oX@02000000D0oh<000@000000?n3
0000000000001`3oH@000`000000od000?m000060?m000030000003o9P00obH000D0obH000<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0^0?ooo`005`3oool2000000d0oooo0`0000050?l2
00030000003o1000o`@000<0o`@00`0000060?l=00030000003o5000oa@000<0oa@000<000000?lL
003o70000P0000020?l`00030000003o@000od0000<0od0000<000000?mA003oD@00103oD@000`00
0000of400?mQ00030?mQ00040000003oKP00ofh00?m^00@000001@3o`0000`000000olD00?o50003
0?o500030000003o`000ol0000@0ol0000D000000?nb003o/P00ok80000000030>go00030000003o
lP00oo8000@0oo8000<000000?o;003ob`000P3ob`0010000000eol00=Oo000000060?o/00040000
003o/P00ok80000000D0ooP000<000000?nb003o/P000P3o/P001@000000on`00?o/003ok0000000
00D0oj4000@000000?o;003ob`000000103oP`0200000080oid000<000000?mQ003oH@000`3oH@00
0`000000ofh0000000050?m00080000000<0odD00000003o9P001P3o9P000`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02d0oooo000G0?ooo`8000002P3oool300000080o`4000<000000?l2
003o0P00103o0P000`000000o`@00?l4000200000080o`P000<000000?l=003o3@00103o3@000`00
0000oa@00?lD00030?lD00<00000103o<0000`000000od000?m000030?m000030000003oD@00oe40
00@0oe4000<000000?mQ003oH@000`3oH@0400000080ok8000<000000?o0003o`000103o`0000`00
0000olD00?o500040?o500030000003o`000ol0000@0ol000`0000040>go00030000003olP00oo80
00@0oo8000<000000?o;003ob`000P0000030=Oo00030000003ok000on`000D0on`00P0000060?oh
00030000003o/P00ok800080ok8000<000000?o/003ok0000P3ok0001@000000oj400?nQ003oX@00
000000<0ol/000<000000?n3003oP`000P3oP`001@000000oid00?nM003oW@00000000@0of4000@0
00000?m^003oKP000000103o@0001@000000odD00?m5003oA@00000000D0obH00`0000070?ooo`03
0000003oool0oooo02`0oooo000G0?ooo`030000003oool0000000L0oooo0P0000060?l100030000
003o0P00o`8000<0o`800`0000050?l800030000003o3@00o`d000@0o`d000<000000?lD003o5000
0P0000020?lS00030000003o<000oc0000<0oc0000<000000?m0003o@0000`3o@0000`000000oe40
0?mA00040?mA00030000003oH@0000000080000000<0oid00000003o/P00103o/P000`000000ol00
0?o000030?o000030000003oa@00olD000@0olD000<000000?o0003o`000103o`0000`000000kOl0
0>go00040>go00030000003olP00oo8000D0oo800P0000050=Oo00030000003ok000on`000D0on`0
00<000000?oh003on0001P3on00010000000ok800?nb000000050?o/00040000003oX@00oj400000
00D0ol/000<000000?n3003oP`000P0000030?nM00030000003oH@00of4000800000103oKP001000
0000od000000000000050?m500030000003o9P00obH0008000000`3o9`000`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02`0oooo000G0?ooo`040000003oool0oooo000000@0oooo0P000000
0`3o000000000?l100060?l100030000003o0P00o`80008000000P3o1@000`000000o`P00?l80003
0?l800030000003o3@00o`d000@0o`d00`0000050?lS00030000003o<000oc0000<0oc0000<00000
0?m0003o@0000P3o@0000`000000oe400?mA00020?mA00@000001@3oW@000`000000ok800?nb0002
0?nb00030000003o`000ol0000@0ol0000<000000?o5003oa@000`3oa@000`000000ol000?o00002
0?o000<000001P3]o`000`000000oo800?ob00050?ob00030000003Go`00eol000@0eol000<00000
0?o/003ok000103ok002000000P0ooP000<000000?nb000000001`3ok002000000H0ol/000D00000
0?n300000000oid0000000040?nM008000001`3oKP000`000000odD00?m500060?m5008000001@3o
9`000`000000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo000F0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`0000000000103o00000`000000o`400?l100050?l1008000001@3o
1@000`000000o`P00?l800030?l800030000003o3@00o`d000<000000P3o5`000`000000ob<00?lS
00030?lS00030000003o<000oc0000<0oc0000@000000?m0003o@000od001P0000020?n300030000
003oW@00oid000@0oid000<000000?nb003o/P000`3o/P000`000000ol000?o000030?o000030000
003oa@00olD000@0olD000@000000?o00000000000000`3Go`000`000000kOl00>go00040>go0003
0000003olP00oo8000<0oo800P0000070=Oo00030000003ok000on`00080on`000@000000;Oo002g
o`000000203on0000`000000on`00?o/00060?o/00030000003ob`00ol/000H0ol/000@000000?nM
003oW@000000103oW@000`000000ofh00?m^00050?m^00030000003oM`00000000D0odD00`000007
0?lW00030000003oool0oooo00@0oooo00<000000?ooo`3oool0:`3oool001H0oooo00<000000?oo
o`3oool00`3oool00`000000o`000?l000040?l000030000003o0@00o`4000<0o`400P0000000`3o
0P0000000?l500040?l500030000003o2000o`P000<0o`P00`0000050?lG00030000003o8`00ob<0
00@0ob<000@000000?l`003o<000oc001@0000030?mX00030000003oP`00oh<000<0oh<000<00000
0?nM003oW@000`3oW@000`000000ok800?nb00030?nb00030000003o`000ol0000<0ol0000<00000
0?o5003oa@000`3oa@03000000D0eol000<000000>go003]o`00103]o`000`000000oo800?ob0002
0?ob00040000002Mo`00WOl0000000H0eol000D000000?o/003ok000on`0000000030;Oo00030000
003on000ooP000D0ooP00P0000070?o/008000001`3ob`0200000080oid000L000000?nM003oW@00
oid00000003o/P00000000D0ofh000@000000?mg003oM`000000103oA@001@000000odL00?m7003o
A`00000000@0obL00P0000000`3o9P0000000?ooo`050?ooo`030000003oool0oooo02X0oooo000F
0?ooo`030000003oool0oooo00@0oooo00<000000?l0003o0000103o00000`000000o`400?l10002
000000<0o`8000<000000?l5003o1@00103o1@000`000000o`P00?l8000200000080o`l000<00000
0?lG003o5`00103o5`000`000000ob<00?lS00030?lS00@000000P3oC`000`000000ofP00?mX0003
0?mX00030000003oP`00oh<000<0oh<000<000000?nM003oW@00103oW@000`000000ok800?nb0003
0?nb00030000003o`000ol0000<0ol0000<000000?o5000000000P0000000`3?o`0000000=Oo0005
0=Oo00030000003]o`00kOl000@0kOl000<000000?ob003olP000P00000309go00030000003Go`00
eol000@0eol000@000000?o/003ok00000001@2go`000`000000ooP00?oh00030?oh00040000002g
o`00]ol0000000D0on`000@000000=Oo003Go`0000001@3ob`001P000000oo800?ob00000000oid0
00000080oid000@000000?nb003o/P0000000`3oKP02000000@0ogL000@000000?m5000000000000
103oA`000`000000obL00?lW0002000000<0obH000<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0Y0?ooo`005P3oool00`000000oooo0?ooo`050?ooo`030000003o0000o`0000<0o`000`00
00060?l200030000003o1@00o`D000<0o`D00`0000050?l?00030000003o5`00oaL000<0oaL000<0
00000?lS003o8`000`0000000`3o>@0000000?m?00040?m?00030000003oJ000ofP000<0ofP000<0
00000?n3003oP`000`3oP`000`000000oid00?nM00030?nM00030000003o/P00ok8000<0ok8000<0
00000?o0003o`0000P3o`003000000D0col000<000000=Oo003Go`000`3Go`000`000000kOl00>go
00050>go008000001@2Mo`000`000000eol00=Oo00050=Oo008000001P2go`000`000000ooP00?oh
00020?oh00050000002go`00]ol00;Oo000000001@3ok00010000000eol00=Oo000000040?o;0009
0000003olP00oo800?ob00000000oid00000003oW@00000000@0ok8000<000000?m^000000001`3o
M`000`000000odL00?m700050?m7008000001P3o9P000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02T0oooo000F0?ooo`030000003oool0oooo00H0oooo00<000000?l0003o00000P000002
0?l100030000003o0P00o`8000@0o`8000<000000?l5003o1@000`0000020?l900030000003o3`00
o`l000@0o`l000@000000?lG003o5`00oaL0100000050?li00030000003oC`00odl00080odl000<0
00000?mX003oJ0000`3oJ0000`000000oh<00?n300030?n300030000003oW@00oid000<0oid000<0
00000?nb003o/P00103o/P001P000000ol00000000000000eol0000000H0col000<000000=Oo003G
o`00103Go`000`000000kOl00>go00040>go00030000002Mo`00WOl000@0WOl000<000000=Oo003G
o`001@3Go`000`000000]ol00;Oo00060;Oo00050000003on000ooP00?oh000000000`2go`000`00
0000on`00?o/00020?o/00030000003Go`00eol00080eol000D000000?o;003ob`00ol/000000004
0?ob0080000000<0oid00000003o/P00103o/P000`000000ogL00?mg00050?mg008000001@3oA`02
000000030?m500000000obH000H0obH000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0X
0?ooo`005P3oool00`000000oooo0?ooo`070?ooo`8000001@3o0@000`000000o`800?l200030?l2
00<000001@3o2@000`000000o`l00?l?00040?l?00@000000`3o9P000`000000ocT00?li00030?li
00030000003oC`00odl000<0odl000<000000?mX003oJ0000`3oJ0000`000000oh<00?n300030?n3
00030000003oW@00oid000<0oid000@000000?nb003o/P00ok80100000040=Oo00030000003?o`00
col000<0col000<000000=Oo003Go`00103Go`000`000000kOl00>go00020>go00<000001`2Mo`00
0`000000eol00=Oo00030=Oo00800000202go`0010000000ooP00?oh000000050;Oo00040000003o
k000on`0000000D0eol000@000000?o;003ob`0000001@3olP03000000D0ok8000<000000?o00000
00001@3oM`0010000000ogX00?mj000000030?m700050000003oA@00odD00?m5000000001@3o9P03
000000L0oooo00<000000?ooo`3oool09`3oool001D0oooo00<000000?ooo`3oool02@3oool00`00
0000o`400?l100040?l100030000003o0P00o`80008000000P3o1@000`000000o`T00?l900040?l9
00030000003o3`00o`l000<000000P3o6@000`000000obH00?lV00030?lV00030000003o>@00ocT0
00<0ocT000<000000?m?003oC`000P3oC`000`000000ofP00?mX00030?mX00040000003oP`00oh<0
0?n300`000000P3]o`000`000000eol00=Oo00030=Oo00030000003?o`00col000<0col000<00000
0=Oo003Go`00103Go`001@000000kOl00>go003]o`0000000080K_l000<0000009go002Mo`001@2M
o`000`000000eol00=Oo00020=Oo00040000001So`00Hol0000000P0]ol00P0000060;Oo00030000
003ok000000000L0eol00P0000070?ob00030000003o/P00ok8000@0ok8000<000000?o000000000
103oM`001P000000ogX00?mj003oNP0000000?m7008000001@3oA@000`000000obH00?lV00020000
00<0ob<000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0W0?ooo`005@3oool00`000000
oooo0?ooo`0:0?ooo`030000003o0@00o`4000<0o`400`0000050?l500030000003o2@00o`T000<0
o`T00`0000050?lI00030000003o9P00obH000<0obH000<000000?li003o>@000`3o>@0010000000
odl00?m?003oC`0;00000080ol/000<000000?ob003olP000`3olP000`000000kOl00>go00040>go
00030000003Go`00eol00080eol000<000000<oo003?o`00103?o`000`000000eol00=Oo00040=Oo
00<00000101^o`000`000000WOl009go000409go00050000003Go`00eol00=Oo000000000`1So`00
0`000000]ol00;Oo00060;Oo00030000002go`00]ol000H0]ol00P0000070=Oo00030000003olP00
oo8000D0oo800`0000040?nb00050000003o`000ol000?o0000000000P3oM`000`000000ogX00?mj
00030?mj00030000003oA@00odD000H0odD00P0000050?lS00030000003oool0oooo00D0oooo00<0
00000?ooo`3oool09P3oool001D0oooo00<000000?ooo`3oool02`3oool00`000000o`400?l10002
00000080o`8000<000000?l5003o1@00103o1@000`000000o`T00?l9000200000080o`l000<00000
0?lI003o6@00103o6@000`000000obH00?lV00030?lV00040000003o>@00ocT00?li00D000000`3o
NP000`000000oj400?nQ00020?nQ00030000003ob`00ol/000<0ol/000<000000?ob003olP000`3o
lP000`000000kOl00>go00030>go00030000003Go`00eol00080eol000<000000<oo003?o`00103?
o`000`000000eol00=Oo00040=Oo00030000001^o`00K_l000@0K_l000<0000009go002Mo`00102M
o`0010000000eol00=Oo0000000506?o00030000002go`00]ol000@0]ol00P0000080;Oo00030000
003Go`00eol000D0eol00P0000060?ob00040000003]o`000000000000<0ok8000<000000?o0003o
`0000P3o`0000`000000ogL0000000050?mj00030000003oM`00000000D0odD00`0000070?lS0003
0000003oool0oooo00@0oooo00<000000?ooo`3oool09P3oool001D0oooo00<000000?ooo`3oool0
303oool2000000D0o`8000<000000?l5003o1@000`3o1@03000000D0o`l000<000000?lI003o6@00
0`3o6@000`000000obH00?lV00020?lV00D000000P3oE`000`000000ogX00?mj00030?mj00030000
003oX@00oj4000<0oj4000<000000?o;003ob`000P3ob`000`000000oo800?ob00030?ob00030000
003]o`00kOl000<0kOl000<000000=Oo003Go`000`3Go`000`000000col00<oo00030<oo00030000
003Go`00eol00080eol00`00000606ko00030000002Mo`00WOl000D0WOl00P00000606?o00030000
002go`00]ol000<0]ol000@0000004ko001>o`0000001P2go`02000000L0eol000<0000009go0000
00001@3olP001`000000kOl00000003]o`0000000?nb000000001P3o`0000`000000ogX00?mj0003
0?mj00040000003oM`00ogL0000000@0odD000D000000?m0003o@000od00000000040?lS00800000
00<0oal00000003oool01@3oool00`000000oooo0?ooo`0U0?ooo`005@3oool00`000000oooo0?oo
o`0=0?ooo`030000003o0P00o`8000@0o`8000<000000?l5003o1@000P0000020?l800030000003o
3`00o`l000@0o`l000@000000?lI003o6@00oaT01P0000030?lk00030000003oE`00oeL00080oeL0
00<000000?mj003oNP000`3oNP000`000000oj400?nQ00020?nQ00030000003ob`00ol/00080ol/0
00<000000?ob003olP000`3olP000`000000kOl00>go00030>go00030000003Go`00eol000<0eol0
00<000000<oo003?o`00103?o`0010000000eol000000000000204ko00030000001^o`00K_l000@0
K_l000<0000009go002Mo`001@2Mo`000`000000Hol006?o000506?o00030000002go`00]ol00080
]ol000D0000004ko001>o`00C_l0000000050;Oo00040000001So`00Hol0000000D0eol000@00000
09go002Mo`000000103olP0010000000kOl00>go003]o`02000000030?nb00000000ol0000@0ol00
00<000000?o5000000000`3oNP000`000000ogL00?mg00020?mg00040000003oA@000000000000@0
od0000<000000?lS003o8`000P0000040?lO00030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0903oool001D0oooo00<000000?ooo`3oool03P3oool00`000000o`800?l200030?l200<00000
1@3o20000`000000o`l00?l?00030?l?00@000000`3o9P000`000000oc/00?lk00030?lk00030000
003oE`00oeL00080oeL000<000000?mj003oNP000`3oNP000`000000oj400?nQ00020?nQ00030000
003ob`00ol/000<0ol/000<000000?ob003olP000`3olP000`000000kOl00>go00030>go00030000
003Go`00eol00080eol000<000000<oo003?o`00103?o`02000000D0C_l000<0000006ko001^o`00
101^o`000`000000WOl009go000309go00800000201So`001@000000]ol00;Oo002go`00000000<0
C_l000<000000;Oo002go`000`2go`0010000000Hol006?o000000040=Oo00030000002Mo`00WOl0
0080WOl000@000000?ob003olP000000103]o`000`000000kOl0000000050?o000040000003oa@00
olD0000000<0ogX000<000000?mg003oM`000`3oM`000`000000od000?m000050?m0008000001`3o
7`000`000000oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo000E0?ooo`030000003oool0
oooo00l0oooo00<000000?l2003o0P000P0000020?l400030000003o2000o`P000@0o`P000<00000
0?l?003o3`000P0000020?lG00030000003o9P00obH000<0obH000<000000?lk003o>`000`3o>`00
0`000000oeL00?mG00020?mG00030000003oNP00ogX000<0ogX000<000000?nQ003oX@000P3oX@00
0`000000ol/00?o;00020?o;00030000003olP00oo8000<0oo8000<000000>go003]o`000`3]o`00
0`000000eol00=Oo00020=Oo00030000003?o`00col00080col00`00000604ko00030000001^o`00
K_l000@0K_l000<0000009go002Mo`000P2Mo`00100000004ol001?o0000000706?o00040000002g
o`00]ol0000000D0C_l000D000000;Oo002go`00]ol00000000306?o00030000003Go`00eol00080
eol000<0000009go002Mo`000P2Mo`000`000000oo80000000050>go00<00000103o`0000`000000
olD00?o500020?o500030000003oNP00000000D0ogL000<000000?m^000000001@3o@0000`000000
ocP0000000050?lO00<000001P3oool00`000000oooo0?ooo`0S0?ooo`00503oool00`000000oooo
0?ooo`0A0?ooo`8000001@3o10000`000000o`P00?l800030?l800<000001@3o5`000`000000obH0
0?lV00020?lV00030000003o>`00oc/000<0oc/000<000000?mG003oE`000P3oE`000`000000ogX0
0?mj00030?mj00030000003oX@00oj400080oj4000<000000?o;003ob`000P3ob`000`000000oo80
0?ob00030?ob00030000003]o`00kOl000<0kOl000<000000=Oo003Go`000`3Go`0010000000col0
00000000000204?o00030000001>o`00C_l000@0C_l000<0000006ko001^o`00101^o`001@000000
WOl009go002Mo`00000000<04ol000<0000006?o001So`001P1So`02000000H0C_l000@000000;Oo
002go`0000001@1So`0010000000eol00=Oo0000000609go008000001@3]o`0010000000eol00=Oo
000000030?o000030000003oa@00olD000<0olD000<000000?mg003oM`000`3oM`0010000000ofh0
0?m^000000030?m0008000000`3o>0000`000000oal00?lO0002000000<0oaX000<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0R0?ooo`00503oool00`000000oooo0?ooo`0B0?ooo`030000
003o1000o`@000@0o`@000<000000?l8003o20000P0000020?l=00030000003o5`00oaL000<0oaL0
00<000000?lV003o9P000`3o9P0010000000oc/00?lk003o>`0@00000080oj4000<000000?o;003o
b`000P3ob`000`000000oo800?ob00030?ob00030000003]o`00kOl000<0kOl000<000000=Oo003G
o`001000000504?o00030000001>o`00C_l000<0C_l000<0000006ko001^o`00101^o`0010000000
WOl009go0000000401?o00030000001So`00Hol000H0Hol000<0000004ko001>o`001@1>o`000`00
0000]ol00000000606?o00030000003Go`00000000L0WOl000<000000>go003]o`00103]o`001000
0000eol00=Oo000000020?o000030000003oa@00olD000<0olD000<000000?o0000000000P3oM`02
000000@0ofh000<000000?m0000000001P3o>002000000D0oaX000<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0R0?ooo`00503oool00`000000oooo0?ooo`0C0?ooo`8000000`3o10040000
00@0o`d000<000000?lG003o5`00103o5`0010000000obH00?lV003o9P0500000080oeL000<00000
0?n0003oP0000`3oP0000`000000ok800?nb00020?nb00030000003ok000on`001H000000P1>o`00
0`000000@ol004?o000404?o00030000001>o`00C_l000@0C_l000<0000006ko001^o`00101^o`02
000000H04ol000<0000006?o001So`00101So`02000000P0C_l00P00000706?o008000001P2Mo`00
0`000000K_l0000000040>go008000000`3Go`02000000D0olD000H000000?o0003o`00000000?mg
000000070?m^00030000003o>000ocP000<0ocP00`0000070?lJ00030000003oool0oooo00@0oooo
00<000000?ooo`3oool08@3oool001@0oooo00<000000?ooo`3oool0503oool4000000<0o`L000<0
00000?l=003o3@000`3o3@000`000000oaL00?lG00020?lG00D000000`3o>@000`000000oeL00?mG
00020?mG00030000003oP000oh000080oh0000<000000?nb003o/P000`3o/P001@000000on`00?o/
003ok000000000@0eol000<0000009go002Mo`000`2Mo`000`000000K_l006ko000306ko00030000
001>o`00C_l000<0C_l000<0000004?o0013o`000`13o`000`000000C_l004ko000404ko00030000
001^o`00K_l000@0K_l000<0000001?o000Co`001@0Co`000`000000Hol006?o000306?o00040000
0000ob000?lP000000L0C_l000<0000006?o001So`001P1So`000`000000WOl009go000509go0003
0000001^o`00000000<0kOl000<000000=Oo000000000`3Go`000`000000olD00?o500030?o50003
0000003o`000ol000080ol0000<000000?m^003oKP00103oKP02000000030?mQ00000000ocP00080
ocP000D000000?l_003o;`00obl0000000040?lJ00<000001P3oool00`000000oooo0?ooo`0Q0?oo
o`00503oool00`000000oooo0?ooo`0E0?ooo`800000103o1`000`000000o`d00?l=00030?l=00D0
00000`3o8`000`000000ocT00?li00020?li00030000003oE`00oeL00080oeL000<000000?n0003o
P0000`3oP0000`000000ok800?nb00020?nb00030000003ok000on`00080on`000<000000=Oo003G
o`000P3Go`000`000000WOl009go000209go00030000001^o`00K_l000<0K_l000<0000004ko001>
o`000`1>o`000`000000@ol004?o000304?o00030000001>o`00C_l000@0C_l000<0000006ko001^
o`000`1^o`02000000L04ol000<0000006?o001So`000`1So`00100000000?lP003o8000000604ko
008000001`1So`02000000H0WOl000L0000006ko001^o`00K_l00000003]o`0000000080eol000H0
00000=Oo003Go`0000000<oo000000040?o500070000003o`000ol000?o000000000ok8000000004
0?m^00060000003oH@00of400?mQ00000000ocP00P0000040?l_00030000003o6P00oaX000800000
0`3o50000`000000oooo0?ooo`040?ooo`030000003oool0oooo0200oooo000D0?ooo`030000003o
ool0oooo01H0oooo00<000000?l7003o1`000`3o1`000`000000o`d00?l=000200000080oa@000<0
00000?lS003o8`000`3o8`000`000000ocT00?li00030?li00030000003oE`00oeL00080oeL000<0
00000?n0003oP0000P3oP0000`000000ok800?nb00020?nb00030000003ok000on`00080on`000<0
00000=Oo003Go`000P3Go`000`000000WOl009go000309go00030000001^o`00K_l000<0K_l000<0
000004ko001>o`000P1>o`000`000000@ol004?o000404?o00030000001>o`00C_l000<0C_l000<0
000006ko001^o`000P1^o`00100000000?l^003o;P00000701?o00050000001So`00Hol006?o0000
00000`00ob000`000000C_l004ko000404ko000300000000ob00000000H0Hol000<0000001?o0000
0000102Mo`000`000000K_l006ko000206ko00030000003]o`0000000080eol000H000000=Oo003G
o`0000000<oo000000030?o500030000003o`000ol000080ol0000D000000?nb003o/P0000000?m^
0002000000D0of4000<000000?l_003o;`001@3o;`02000000D0oa@000<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0O0?ooo`004`3oool00`000000oooo0?ooo`0G0?ooo`8000000`3o1`04
000000D0oa@000<000000?lS003o8`000`3o8`000`000000ocT00?li00020?li00030000003oE`00
oeL00080oeL000<000000?n0003oP0000`3oP0000`000000ok800?nb00020?nb00050000003ok000
on`00?o/000000001@3Go`000`000000WOl009go000209go00030000001^o`00K_l000<0K_l000<0
000004ko001>o`000`1>o`000`000000@ol004?o000304?o00030000001>o`00C_l000@0C_l000@0
000006ko0000000000000`00obh00`0000004ol001?o000501?o00040000001So`00Hol0000000@0
0?lP00<0000004ko001>o`000`1>o`00100000000?lP003o8000000506?o00040000000Co`004ol0
000000@0WOl000<0000006ko001^o`000`1^o`001`000000eol00=Oo003Go`0000000=Oo00000000
0`3?o`000`000000olD0000000040?o000030000003o/P00ok800080ok8000<000000?mQ003oH@00
0`3oH@02000000030?mA00000000obl000<0obl00P0000000`3o9@0000000?lD00040?lD00800000
1P3oool00`000000oooo0?ooo`0O0?ooo`004`3oool00`000000oooo0?ooo`0H0?ooo`@000000`3o
2`000`000000oa@00?lD00040?lD00040000003o8`00ob<00?lS00l000000P3oP0000`000000ok80
0?nb00020?nb00030000003ok000on`00080on`000<000000=Oo003Go`000P3Go`000`000000WOl0
09go000209go00030000001^o`00K_l000<0K_l000<0000004ko001>o`000`1>o`000`000000@ol0
04?o000304?o00030000001>o`00C_l000@0C_l00P000005003o;P030000000Co`004ol000D04ol0
00<0000006?o000000001P00ob001@000000C_l004ko001>o`00000000<00?lP00<0000006?o001S
o`000P1So`000`0000004ol001?o000201?o00040000002Mo`00WOl0000000D0K_l000<0000004ko
000000000P3Go`02000000D0col000<000000?o0003o`0000P3o`0000`000000ok800?nb00020?nb
00030000003oW@00000000<0of4000<000000?mA003oD@000P3oD@0010000000obl0000000000004
0?lU00030000003o5000oa@0008000000P3o3`000`000000oooo0?ooo`040?ooo`030000003oool0
oooo01h0oooo000C0?ooo`030000003oool0oooo01T0oooo0P0000050?l;00030000003o5000oa@0
00<0oa@0100000030?l`00030000003oC`00odl00080odl000<000000?mj003oNP000P3oNP000`00
0000ok800000000500000080ok8000D000000?o/003ok000on`0000000040=Oo00030000002Mo`00
WOl00080WOl000<0000006ko001^o`000`1^o`000`000000C_l004ko000304ko000300000013o`00
@ol000<0@ol000<0000004ko001>o`00101>o`000`0000000?l^003o;P05003o;P030000000Co`00
4ol000D04ol00P000006003o80050000001>o`00C_l004ko000000001000ob001@000000Hol006?o
001So`00000000@04ol000<0000009go000000001P1^o`000`000000C_l0000000020=Oo00800000
103?o`000`000000eol0000000020?o000030000003o/P00ok800080ok8000D000000?nM003oW@00
00000?mQ0002000000H0oe4000<000000?lU003o9@001@3o9@02000000D0o`l000<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0M0?ooo`004`3oool00`000000oooo0?ooo`0J0?ooo`800000
1@3o2`000`000000oa@00?lD000200000080oa`000<000000?l`003o<0000`3o<0000`000000odl0
0?m?00020?m?00050000003oNP00ogX00?mj00000000103o/P000`000000ooP00?oh000400000080
on`000<000000=Oo003Go`000`3Go`000`000000WOl009go000209go00030000001^o`00K_l000<0
K_l000<0000004ko001>o`000`1>o`000`000000@ol004?o000304?o00040000001>o`00C_l004ko
00<000001`00obh00`0000004ol001?o000501?o000300000000ob000?lP00D00?lP00@0000004ko
001>o`0000001@00ob0010000000Hol006?o0000000601?o008000001@1^o`001`000000C_l004ko
001>o`0000000=Oo000000001@3?o`001P000000eol00=Oo00000000ol00000000<0ok8000<00000
0?nM003oW@000P3oW@000`000000oe400?mA00040?mA0080000000<0od000000003o9@000`3o9@03
000000L0o`l000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`004`3oool00`00
0000oooo0?ooo`0K0?ooo`8000000`3o2`04000000D0oa`000<000000?l`003o<0000P3o<0000`00
0000odl00?m?00020?m?00030000003oNP00ogX00080ogX000<000000?nb003o/P000P3o/P001P00
0000ooP00?oh003on00000000;Oo0080000000<0on`00000003Go`000`3Go`000`000000WOl009go
000209go00030000001^o`00K_l000<0K_l000<0000004ko001>o`000`1>o`000`000000@ol004?o
000304?o00040000001>o`000000000000<00?mJ00<00000003o;P00obh01000obh00`0000004ol0
01?o000401?o008000001`00ob000`000000C_l000000006003o80030000001So`00000000L04ol0
00<0000006ko001^o`00101^o`001`000000C_l004ko001>o`0000000=Oo00000000103?o`000`00
0000eol00=Oo00020=Oo00030000003o/P00ok800080ok8000L000000?nM003oW@00oid00000003o
P`00000000@0oe4000D000000?m0003o@000od00000000020?lU008000000`3o70000`000000o`l0
0?l?00020?l?00<000001P3oool00`000000oooo0?ooo`0L0?ooo`004`3oool00`000000oooo0?oo
o`0L0?ooo`@000000`3o3`000`000000oa`00?lL00030?lL00030000003o<000oc0000<0oc0000<0
00000?m?003oC`000P3oC`000`000000ogX00?mj00020?mj00050000003o/P00ok800?nb00000000
103on0000`000000]ol00;Oo0004000000<0eol000D0000009go002Mo`00WOl00000000506ko0003
0000001>o`00C_l000<0C_l000<0000004?o0013o`000P13o`03000000D00?mJ00<00000003o;P00
obh01000obh00`0000004ol001?o000301?o000300000000ohX0000000P00?lP0P000007003o8080
00001P0Co`02000000D0K_l000<0000004ko001>o`000`1>o`02000000<0col000<000000=Oo003G
o`000P3Go`000`000000kOl0000000020?nb00050000003oW@00oid00?nM000000000`3oP`001000
0000oe400000000000050?m0008000001@3o70000`000000o`l00?l?0002000000<0o`/000<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`004P3oool00`000000oooo0?ooo`0N0?oo
o`800000103o3`000`000000oa`00?lL00040?lL00040000003o<000oc000?l`00X0000000<0ogX0
0000003o/P000`3o/P001@000000ooP00?oh003on000000000<0]ol000<0000006?o001So`001@00
000209go00030000001^o`00K_l000<0K_l000<0000004ko001>o`00101>o`001P000000@ol00000
000000000?mY000000H00?mJ00<00000003o;P00obh01@00obh01@0000004ol001?o000Co`000000
00<00?n:00<00000003o8000ob001@00ob000`0000000?lP003o8006003o80030000000Co`004ol0
00D04ol000<00000003o;P000000101^o`000`000000C_l004ko000204ko000300000013o`000000
00<0col000D000000=Oo003Go`00eol0000000020>go00030000003o/P00000000<0oid000<00000
0?n3003oP`000`3oP`000`000000od000?m000030?m00080000000<0oc000000003o7000103o7003
000000D0o`/000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`004P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003o3`00o`l000<0o`l000<000000?lL003o70000P3o70050000
00<0od0000D000000?mX003oJ000ofP0000000020?nQ00@000000P3o/P001@000000ooP00?oh003o
n000000000@0]ol000<0000006?o001So`000P1So`001P0000004ol0000000000000WOl0000000D0
K_l000@0000004ko001>o`00C_l010000004003oJ@0300000000oeX00?mJ00<00?mJ00<00000003o
;P00obh01@00obh01@0000004ol001?o000Co`00000000<00?n:00<00000003o8000ob001000ob02
000000L00?lP0P00000601?o000400000000obh00?l^000000<0K_l000<0000004ko001>o`000`1>
o`000`000000@ol0000000020<oo00030000003Go`00eol00080eol000D000000>go003]o`00kOl0
000000040?nM00030000003oP`00oh<00080oh<000<000000?mX000000000`3o@0001@000000oc00
0?l`003o<00000000080oa`00`0000020?lD00030000003o2`00o`/000<0o`/00P0000060?ooo`03
0000003oool0oooo01X0oooo000B0?ooo`030000003oool0oooo0200oooo00@000000?l?003o3`00
o`l01P0000030?lU00030000003o@000od000080od0000<000000?mX003oJ0000P3oJ0001P000000
oj400?nQ003oX@0000000?o/0080000000<0ok800000003on0000P3on0001@000000]ol00;Oo002g
o`00000000@0Hol000@0000001?o000Co`004ol02`000002003oFP0300000000ofT00?mY00<00?mY
00<00000003oFP00oeX01000oeX00`0000000?l^003o;P04003o;P040000000Co`004ol0000000@0
0?n:00<00000003o8000ob001000ob000`0000000?n[00000006003o800300000000ohX0000000D0
4ol000D00000003o;P00obh00?l^0000000206ko00030000001>o`00C_l00080C_l000L0000004?o
0013o`00@ol00000003?o`00000000<0eol000H000000>go003]o`00kOl00000003olP0200000003
0?nM00000000oh<000<0oh<000D000000?mX003oJ00000000?m00002000000D0oc000P0000050?lD
00030000003o2`00o`/000<000000P3o1`000`000000oooo0?ooo`030?ooo`030000003oool0oooo
01X0oooo000B0?ooo`030000003oool0oooo0240oooo0`0000030?lD00030000003o9@00obD000<0
obD000<000000?m0003o@0000`3o@0001@000000ofP00?mX003oJ000000000@0oj4000<000000?o/
003ok0000`0000020?oh00050000002go`00]ol00;Oo000000001@1So`001@0000004ol001?o000C
o`00000000D00?l^00<00000003oFP00oeX00`00oeX00`0000000?mY003oJ@03003oJ@0300000000
oeX00?mJ00@00?mJ00<00000003o;P00obh01@00obh2000000D00?n:00<00000003o8000ob000`00
ob00100000000?n[003oZ`000005003o800400000000ohX00?n:000000@04ol000<00000003o;P00
obh00P00obh00`000000K_l00000000504ko000400000013o`00@ol004?o008000000`3Go`000`00
0000kOl00>go00020>go00050000003olP00oo800?ob000000000`3oP`02000000@0ofP000<00000
0?l`003o<0000`3o<002000000030?lS00000000oa@000@0oa@00`0000050?l700030000003oool0
oooo00@0oooo00<000000?ooo`3oool06@3oool00180oooo00<000000?ooo`3oool08P3oool00`00
0000oa@00?lD00030?lD00030000003o9@00obD000<0obD000<000000?m0003o@0000P3o@0000`00
0000ofP00?mX00020?mX00050000003oX@00oj400?nQ000000000`3ok0001P000000]ol000000000
0000ooP0000000<0]ol000<0000006?o001So`000P1So`001@0000004ol001?o000Co`00000000D0
0?l^00<00000003oFP00oeX01000oeX00`0000000?mY003oJ@02003oJ@0300000000oeX00?mJ00@0
0?mJ00<00000003o;P00obh01@00obh00`0000000?n:003oRP05003oRP0500000000ob000?lP003o
800000000`00oj/00`0000000?lP003o8003003o800400000000ohX00?n:000000@04ol000<00000
003o;P00obh00`00obh2000000@0C_l000<0000004?o0013o`000P13o`001@000000C_l00000003G
o`00000000@0kOl000T000000?ob003olP00oo800000003ob`0000000?n3000000001@3oJ0001@00
0000odl0000000000000oc0000800000103o8`000`000000oa@00?lD000200000080o`d000<00000
0?l7003o1`000`3o1`02000000H0oooo00<000000?ooo`3oool0603oool00180oooo00<000000?oo
o`3oool08`3oool00`000000oa@00?lD00030?lD00040000003o9@00obD00?lU00X0000000<0ofP0
0000003oX@000`3oX@001@000000on`00?o/003ok00000000080]ol00P0000030;Oo00030000001S
o`00Hol00080Hol000<0000001?o000Co`000P0Co`000`0000000?l^003o;P03003o;P0300000000
oeX00?mJ00<00?mJ00<00000003oJ@00ofT00`00ofT00`0000000?mJ003oFP04003oFP0300000000
obh00?l^00<00?l^0P000007003oRP0500000000ob000?lP003o800000000`00oj/00`0000000?lP
003o8002003o800300000000ohX00?n:00800?n:00@0000001?o000Co`0000001P00obh00`000000
C_l004ko000304ko000300000013o`00@ol00080@ol000D0000004ko00000000eol0000000030>go
00050000003olP00oo800?ob000000000`3ob`000`000000ofP00?mX00020?mX00800000103oC`00
0`000000ob<00?lS00050?lS008000001@3o3@000`000000o`L00?l7000200000080o`@000<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`004P3oool00`000000oooo0?ooo`0T0?oo
o`040000003o5000oa@00?lD00D000000`3o;`000`000000oe400?mA00020?mA00030000003oP`00
000000@0000000<0oj400000003ok0000P3ok00010000000]ol00;Oo002go`03000000030;Oo0000
0000Hol000<0Hol000<0000001?o000Co`000P0Co`000`0000000?l^003o;P03003o;P0300000000
oeX00?mJ00<00?mJ00<00000003oJ@00ofT00`00ofT00`0000000?mJ003oFP04003oFP0300000000
obh00?l^00800?l^00<00000003oh@0000001`00ohX0100000000?lP003o80000005003oZ`050000
0000ob000?lP003o800000001000ohX0100000004ol001?o00000006003o;P8000000`1>o`000`00
0000@ol004?o000204?o008000000P1>o`001@000000kOl00>go003]o`00000000<0oo8000H00000
0?o;003ob`00ol/00000003oX@02000000030?mX00000000odl000<0odl00P0000000`3o>@000000
0?lS00030?lS00<000001`3o3@02000000@0o`@000<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0G0?ooo`004@3oool00`000000oooo0?ooo`0V0?ooo`<000000`3o6P000`000000obl00?l_
00020?l_00030000003oD@00oe400080oe4000<000000?n3003oP`000P3oP`020?o;00<000000`3o
k0001P000000]ol00;Oo002go`00000004ko00<00000101So`001@0000004ol001?o000Co`000000
00D00?l^00<00000003oFP00oeX00`00oeX00`0000000?mY003oJ@03003oJ@0300000000oeX00?mJ
00@00?mJ00D00000003o;P00obh00?l^00000003003oh@0300000000ohX00?n:00@00?n:00<00000
003o800000001P00oj/0100000000?lP003o80000005003oRP030000000Co`00000000H00?l^00<0
0000003oFP0000000`1>o`000`000000@ol004?o000204?o0080000000<0C_l00000001^o`000P00
00000`3]o`0000000?ob00020?ob00040000003ob`00ol/0000000@0oj4000<000000?m?003oC`00
0P3oC`001@000000ocT00?li003o>@0000000080ob<00P0000030?lG00030000003o3@00o`d00080
o`d00`0000060?l400030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00140oooo
00<000000?ooo`3oool09`3oool00`000000oaX00?lJ00020?lJ00030000003o;`00obl000<0obl0
00<000000?mA003oD@000P3oD@001@000000oh<00?n3003oP`00000000<0ol/00`0000000`3ok000
00000;Oo00020;Oo00050000001>o`00C_l004ko00000000101So`001@0000004ol001?o000Co`00
000000D00?l^00<00000003oFP00oeX00`00oeX00`0000000?mY003oJ@03003oJ@0300000000oeX0
0?mJ00@00?mJ00@00000003o;P00obh000001000on400`0000000?n:003oRP05003oRP8000001P00
oj/0100000000?lP003o80000006003oRP8000001P00obh01P0000000?mJ003oFP000000C_l00000
00@0@ol000D0000004ko00000000C_l00000000306ko00050000003olP00oo800?ob000000000P3o
b`000`000000oj400?nQ00020?nQ00040000003oNP0000000?m?008000001@3o>@02000000D0oaL0
00<000000?l=003o3@000P0000030?l800030000003o1000o`@000<0o`@00P0000050?ooo`030000
003oool0oooo01H0oooo000A0?ooo`030000003oool0oooo02L0oooo00<000000?lJ003o6P000`3o
6P0010000000obl00?l_003o;`0900000080oh<000H000000?o;003ob`00ol/00000003Go`030000
0080]ol000@0000004ko001>o`00C_l00`00000206?o00030000000Co`004ol000804ol000<00000
003o;P00obh00P00obh00`0000000?mJ003oFP04003oFP0300000000ofT00?mY00<00?mY00<00000
003oFP00oeX01000oeX2000000D00?oQ00<00000003oRP00ohX01@00ohX00`0000000?n[003oZ`05
003oZ`0300000000ob00000000L00?n:00<00000003o;P00obh01000obh01`0000000?mJ003oFP00
oeX0000004ko000000001013o`0010000000C_l000000000000306ko00050000002Mo`0000000?ob
000000000`3ob`001@000000oj400?nQ003oX@00000000<0ogX000<000000?li003o>@000`3o>@02
000000030?lV00000000oaL000@0oaL00`0000050?l800030000003o1000o`@000<000000P3o0P00
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo000A0?ooo`030000003oool0oooo
02P0oooo00@000000?lJ003o6P00oaX01@0000030?lh00030000003oH@00of400080of4010000003
0?o;00050000003Go`00eol00=Oo000000000`2go`002@000000C_l004ko001>o`000000003o8000
0000Hol00000000401?o000300000000obh00?l^00<00?l^00<00000003oFP00oeX00`00oeX00`00
00000?mY003oJ@03003oJ@0300000000oeX00?mJ00@00?mJ00<00000003oh@00on401000on400`00
00000?n:003oRP04003oRP8000002000oj/2000000L00?n:00<00000003o;P00obh01000obh00`00
00000?mJ003oFP02003oFP0300000013o`00@ol00080@ol000<0000004ko001>o`000P00000306ko
00030000002Mo`00WOl0008000000P3ob`000`000000oj400?nQ0002000000<0ogX000<000000?mG
000000000P3o>@02000000<0obH000<000000?lG003o5`000`0000020?l?00030000003o2000o`P0
00<0o`P00`0000050?l200030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00140
oooo00<000000?ooo`3oool0:@3oool3000000<0oal000<000000?lh003o>0000`3o>0000`000000
of400?mQ00020?mQ00040000003oW@000000000000<0ol/000<000000=Oo003Go`000P0000020;Oo
00050000001>o`00C_l004ko000000000P00ob03000000<04ol000<00000003o;P00obh00`00obh0
0`0000000?mJ003oFP03003oFP0300000000ofT00?mY00<00?mY00<00000003oFP00oeX00P00oeX3
000000H00?oQ00<00000003oRP00ohX01000ohX2000000P00?n[00<00000003oRP00ohX01@00ohX0
0`0000000?oQ00000004003o;P0300000000oeX00?mJ00<00?mJ0P00000304?o00040000001>o`00
C_l0000000<0K_l000@0000009go002Mo`0000000P3Go`0200000080oj4000@000000?mj003oNP00
ogX00P0000030?mG008000001P3o9P02000000D0o`l000<000000?l8003o20000`0000020?l50003
0000003o0P00o`8000<0o`800P0000050?ooo`030000003oool0oooo01@0oooo000A0?ooo`030000
003oool0oooo02X0oooo00<000000?lO003o7`000`3o7`02000000@0ocP000D000000?mQ003oH@00
of40000000030?nM0080000000<0ol/00000003Go`000P3Go`04000000<0C_l000<00000003o8000
ob000P00ob02000000804ol000<00000003o;P00obh00`00obh00`0000000?mJ003oFP03003oFP03
00000000ofT00?mY00<00?mY00D00000003oFP00oeX00?mJ00000002003To`0300000000on400?oQ
00D00?oQ00<00000003oRP00ohX00P00ohX0100000000<oo003?o`000006003oZ`8000001`00ohX0
0`0000000?oQ00000004003o;P0300000000oeX00?mJ00800?mJ00<00000003oJ@0000000P13o`00
1@000000C_l004ko001>o`0000000080K_l000D0000009go002Mo`00WOl0000000020=Oo00030000
003ok0000000008000000P3oNP000`000000oeL00?mG00020?mG00030000003o>`00000000@0obH0
0P0000000`3o6@0000000?l?00040?l?00<000001@3o1@000`000000o`800?l20003000000030?l1
00000000oooo00D0oooo00<000000?ooo`3oool04`3oool00100oooo00<000000?ooo`3oool0;03o
ool2000000<0oal02P0000000`3oH@0000000?nM00020?nM00040?ob00000000ol/000000080eol0
00<0000006?o001So`000P00000204ko000300000000ob000?lP00800?lP00H00000003oRP000000
000001?o00000004003o;P0300000000oeX00?mJ00<00?mJ00<00000003oJ@00ofT01000ofT30000
00@00>Co00<00000003oh@00on401000on401@0000000?n:003oRP00ohX0000000<00<oo00<00000
003oZ`00oj/01000oj/00`0000000<oo00000005003oRP0500000000on400?oQ003oh@0000000`00
obh00`0000000?mJ003oFP02003oFP0600000000ofT00?mY00000013o`0000000P1>o`0200000080
K_l000@0000009go002Mo`0000000P3Go`0010000000on`00?o/000000020?nb008000000`3oE`02
000000<0oc/000@000000?lV000000000000103o6@000`000000o`l00?l?000200000080o`T000<0
00000?l5003o1@000`3o1@03000000D0o`4000<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0C0?ooo`00403oool00`000000oooo0?ooo`0^0?ooo`<000000`3o8`000`000000od000?m00002
0?m000030000003oKP00000000<0000000D0oid00000003olP00oo80000000020=Oo00050000001S
o`00Hol006?o000000000`1>o`001@0000000?lP003o8000ob00000000<00?n:0`000004003o;P03
00000000oeX00?mJ00<00?mJ00<00000003oJ@00ofT00P00ofT2000000H00>Co00<00000003oh@00
on401000on401@0000000?n:003oRP00ohX0000000<00<oo00<00000003oZ`00oj/00`00oj/01000
00000<oo003?o`000005003oRP0500000000on400?oQ003oh@0000000P00obh00`0000000?mJ003o
FP02003oFP0300000000ofT00?mY00800?mY00@0000004ko001>o`00C_l00P0000001@1^o`000000
09go002Mo`0000000080eol000@000000?o/003ok00000000`3o/P001@000000oh000000003oE`00
000000H0oc/000<000000?lI003o6@001@3o6@02000000@0o`T000<000000?l5003o1@000`000000
0`3o0P0000000?l100050?l100030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool0
0100oooo00<000000?ooo`3oool0;`3oool00`000000ob<00?lS00020?lS00030000003o@000od00
0080od0000<000000?m^003oKP000P3oKP0400000080oo8000@000000=Oo003Go`0000000P1So`02
00000080C_l000<00000003o8000ob000P00ob001P0000000?n:003oRP00ohX00000003oh@<00000
00<00?l^00000000oeX01000oeX00`0000000?mY0000000200000003003?o`0000000>Co00D00>Co
00<00000003oh@00on401000on40100000000?n:003oRP000004003?o`0300000000oj/00?n[00<0
0?n[00D00000003?o`00col00<oo00000003003oRP0300000000on400?oQ00<00?oQ00<00000003o
;P0000001000oeX00`0000000?mY003oJ@02003oJ@@0000000<0K_l00000000000000`2Mo`000`00
0000eol0000000020?o/00050000003o/P00ok800?nb000000000`3oP0000`000000oc/00?lk0003
0?lk0080000000@0obH00000003o6@00oaT00`0000020?l?00030000003o2@00o`T00080o`T00`00
00050?l200030000003o0@00o`4000<0o`400P0000050?ooo`030000003oool0oooo0180oooo000@
0?ooo`030000003oool0oooo02l0oooo00<000000?lS003o8`000`3o8`000`000000od000?m00002
0?m000050000003oKP00ofh00?m^000000000P3o/P02000000030?ob000000000000008000000`1S
o`020000000304ko000000000?lP00<00?lP00D00000003oRP00ohX00?n:00000004003oh@T00000
1000col00`0000000>Co003To`04003To`0300000000on400?oQ00D00?oQ0P000006003?o`050000
0000oj/00?n[003oZ`0000001000col01@0000000?n:003oRP00ohX0000000D00?oQ0P000005003o
FP0500000000ofT00?mY003oJ@0000000`00oeX010000000K_l000000000000209go00030000003G
o`0000000080on`000<000000?nb003o/P000P0000020?n00080000000@0oeL00000003o>`00oc/0
0P0000040?lV008000001@3o3`000`000000o`T00?l9000200000080o`D000<000000?l2003o0P00
0`3o0P000`000000o`400?l1000300000080o`0000<000000?ooo`3oool00P3oool2000001<0oooo
000@0?ooo`030000003oool0oooo0300oooo00@000000?lS003o8`00ob<02P0000000`3oKP000000
0?nb00020?nb00040000003olP00000009go008000000P1So`00100000000?lP000000000004003o
800300000000ohX00?n:00800?n:00<00000003oh@00on400P00on400`0000000>Co003To`03003T
o`0300000000col00<oo00@00<oo00<00000003To`00i?l00`00i?l00`0000000?oQ003oh@05003o
h@8000001P00col01@0000000?n[003oZ`00oj/0000000@00<oo00D00000003oRP00ohX00?n:0000
0006003oh@0300000000oeX00?mJ00800?mJ00<00000003oJ@00ofT00P00ofT01@0000000?mJ003o
FP0000000?l^00<000000P2Mo`0500000080ok8000<000000?n0003oP0000P0000040?mG00800000
103o9P02000000030?lG00000000o`l000@0o`l00`0000040?l500030000003o0P00o`8000<0o`80
0`0000050?l000030000003oool000000080000000<0oooo0000003oool04P3oool00100oooo00<0
00000?ooo`3oool0<@3oool3000000<0obH000<000000?m5003oA@000P3oA@000`000000ogL00000
000200000080ok800P000000103olP00000009go0000000206?o000300000000ob000?lP00800000
0`00ob000`0000000?n:003oRP02003oRP0300000000on400?oQ00800?oQ00<00000003To`00i?l0
0`00i?l00`0000000<oo003?o`04003?o`0300000000i?l00>Co00@00>Co00<00000003oh@00on40
1000on400`0000000<oo003?o`05003?o`0400000000oj/00?n[000000H00<oo00<00000003oRP00
00001`00on400`0000000?mJ003oFP02003oFP0500000000ofT00?mY003oJ@0000000`00oeX01@00
00000?l^003o;P0000004ol000<000000P2go`000`000000ooP000000004000000@0oeL00P000000
103o>@0000000?lV003o9P02000000<0oaL000<000000?l?003o3`000`0000000`3o200000000?l5
00050?l500030000003o0P00o`80008000000P3o0@000`000000o`000?l000030?l000800000103o
ool00`000000oooo0?ooo`0A0?ooo`00403oool00`000000oooo0?ooo`0b0?ooo`030000003o9P00
obH00080obH000<000000?m5003oA@000P3oA@000`000000ogL00?mg00020?mg0080000000@0ok80
0000003]o`0000000P2Mo`0010000000Hol006?o00000002003o800300000000ob000?lP00800?lP
00D00000003oRP00ohX00?n:00000005003oh@0300000000i?l00>Co00<00>Co00<00000003?o`00
col00`00col00`0000000>Co003To`04003To`0300000000on400?oQ00<00?oQ0P000007003?o`04
00000000oj/00?n[000000H00<oo00<00000003oRP0000001P00on400`0000000>Co00000003003o
FP0500000000ofT00?mY003oJ@0000000P00oeX01@0000000?l^003o;P0000004ol00080000000@0
Hol00000002go`0000000P3on00010000000ok800000003oNP02000000030?mG00000000000000@0
ocT00P0000060?lG008000001@3o20000`000000o`D00?l500030?l500<00000103o0@000`000000
o`000?l00003000000H0oooo00<000000?ooo`3oool04@3oool000l0oooo00<000000?ooo`3oool0
=03oool2000000<0obH000<000000?m5003oA@000P3oA@001P000000ogL00?mg003oM`0000000?o0
008000000P3]o`001P000000WOl0000000000000Hol0000000800?lP0P000003003o800500000000
ohX00?n:003oRP0000001@00on400`0000000>Co003To`03003To`0300000000col00<oo00<00<oo
00<00000003To`00i?l01000i?l00`0000000?oQ003oh@02003oh@0300000000HOl0000000P00<oo
0P000008003?o`0300000000on400?oQ00D00?oQ00<00000003To`0000000P00oeX01@0000000?mY
003oJ@00ofT0000000<00?mJ00D00000003o;P00obh0000001?o0003000000070;Oo00000000ooP0
0?oh00000000ok80000000040?mj00030000003o>@00ocT00080ocT00P0000000`3o8`0000000?lG
00030?lG0080000000<0o`d00000003o2000103o20000`000000o`D00?l5000300000080o`8000<0
00000?l1003o0@000P3o0@03000000X0oooo00<000000?ooo`3oool0403oool000l0oooo00<00000
0?ooo`3oool0=P3oool<000000050?mg00000000ol000?o0000000000P3]o`000`000000WOl001?o
0002000000<00?lP0P000002003o800500000000ohX00?n:003oRP0000001@00on400`0000000>Co
003To`03003To`0300000000col00<oo00<00<oo00<00000003To`00i?l01000i?l01@0000000?oQ
003oh@00on40000000<0067o00<00000003?o`00col01@00col2000000P00<oo00<00000003oh@00
on401000on401`0000000>Co003To`00i?l00000003oFP0000000`00ofT0100000000?mJ003oFP00
0002003o;P030000000Co`004ol0008000000P2go`001@000000ooP00000003o/P00000000<0ogX0
0P0000000`3oC`0000000?li0002000000@0ob<000@000000?lG000000000000103o3@0010000000
o`P00?l8003o2004000000D0o`8000<000000?l1003o0@000P00000=0?ooo`030000003oool0oooo
0100oooo000?0?ooo`030000003oool0oooo03L0oooo00D000000?lW003o9`00obL0000000040?m7
00030000003oNP000000008000000P3o`0000`000000kOl0000000020000000301?o000000000000
00800?lP00<00000003oZ`0000000P000004003oRP0300000000on400?oQ00800?oQ00<00000003T
o`00i?l00`00i?l00`0000000<oo003?o`03003?o`0300000000i?l00>Co00@00>Co00D00000003o
h@00on400?oQ00000003001Qo`0300000000col00<oo00D00<oo00<00000003?o`00col01`00col0
0`0000000?oQ003oh@04003oh@0400000000i?l00>Co003To`8000001000ofT0100000000?mJ003o
FP000002003o;P030000000Co`004ol00080000000H0]ol00000003on00000000?nb000000020?mj
00800000103oC`000`000000ob<00?lS00050?lS00030000003o3@00o`d000D0o`d00`0000030?l4
00030000003o0P00o`8000<0o`800`00000?0?ooo`030000003oool0oooo0100oooo000?0?ooo`03
0000003oool0oooo03L0oooo00<000000?lW003o9`000P3o9`02000000<0odL00P0000020?mj00P0
000000D04ol000000000ob000?lP00000003003oZ`8000000`00ohX00`0000000?oQ003oh@02003o
h@0300000000i?l00>Co00<00>Co00<00000003?o`00col01000col00`0000000>Co003To`04003T
o`0300000000on40000000@0067o00<00000003?o`00col01000col2000000P00<oo00<00000001Q
o`0000001000on400`0000000>Co003To`03003To`0500000000ofT00?mY003oJ@0000000P00oeX0
100000000?l^003o;P00000201?o0080000000<0]ol00000000000001P0000030?m?008000000P3o
<0000`000000ob<00?lS000300000080oa@000<000000?l=003o3@000P3o3@03000000D0o`@000<0
00000?l2003o0P000`00000B0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0
oooo03P0oooo00@000000?lW003o9`00obL02@0000002@3oNP000000000000000000eol00000001^
o`00000001?o0002000000800?lP00D00000003oZ`00oj/00?n[00000003003oRP0300000000on40
0?oQ00<00?oQ00<00000003To`00i?l00P00i?l00`0000000<oo003?o`04003?o`0300000000i?l0
0>Co00@00>Co0P000005001Qo`0300000000col00<oo00@00<oo00<00000000ao`0000001`00col0
0`000000067o00000004003oh@0300000000i?l00>Co00<00>Co0P000002003oJ@0400000000oeX0
0?mJ000000800?l^00<0000001?o000Co`001`000000103oX@0000000?mX003oJ003000000D0oc00
0P0000050?lD00030000003o3@00o`d0008000000`3o1`000`000000o`@00?l400020?l400<00000
5@3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`0i0?ooo`<000000`3o
9P000`000000odD00?m500020?m500@0000000L0olD00000003Go`00000006ko000000004ol00080
000000<00?lP00000000oj/00P00oj/2000000800?n:00<00000003oh@00on400`00on400`000000
0>Co003To`03003To`0300000000col00<oo00<00<oo00<00000003To`00i?l01000i?l00`000000
067o001Qo`04001Qo`0300000000col00<oo00<00<oo00@00000000ao`00<Ol000001P00col01000
0000067o001Qo`000003003oh@0300000000i?l00>Co00<00>Co00<00000003?o`00col00P000002
003oFP0400000000obh00?l^000000804ol00`0000000`2go`0000000000000300000080ofP00P00
0000103o@00000000?l`003o<00200000080oa`000<000000?lD003o50000`3o5003000000D0o`L0
00<000000?l4003o10000P00000H0?ooo`030000003oool0oooo0100oooo000>0?ooo`030000003o
ool0oooo03/0oooo00<000000?lV003o9P000`3o9P000`000000odD00?m500020?m500070000003o
M`0000000000003oa@0000000=Oo000400000004003oRP0000000?lP000000800?n[00H00000003?
o`0000000000003oRP000004003oh@0300000000i?l00>Co00<00>Co00<00000003?o`00col00`00
col00`0000000>Co003To`03003To`8000001`00HOl00`0000000<oo003?o`02003?o`0400000000
<Ol0037o000000H00<oo00D00000001Qo`00HOl0067o00000002003oh@0300000000i?l00>Co00<0
0>Co00D00000003?o`00col00<oo00000002003oFP0400000000obh00?l^000000804ol000<00000
04ko000000000P000000103oX@0000000?mX003oJ002000000@0od000P0000050?lL00030000003o
5000oa@0008000000P3o2`000`000000o`L00?l700030?l700<000006P3oool00`000000oooo0?oo
o`0@0?ooo`003P3oool00`000000oooo0?ooo`0l0?ooo`040000003o9P00obH00?lV00T0000000<0
ogL0000000000000100000001@0Co`00000000000000ob00000000<00?n[00<00000003?o`00col0
0P000004003oh@0300000000i?l00>Co00<00>Co00<00000003?o`00col00`00col00`0000000>Co
003To`02003To`03000000006?l0000000L0067o00D00000003?o`00col00<oo00000004000ao`03
00000000col00<oo00800<oo00<00000001Qo`00HOl00P00HOl00`0000000?oQ00000005003To`03
00000000col00<oo00800<oo0`000002003o;P030000000Co`00000000X00000103o@00200000003
0?lU00000000oa`000@0oa`00`0000040?l;00030000003o1`00o`L000<000007@3oool00`000000
oooo0?ooo`0@0?ooo`003P3oool00`000000oooo0?ooo`0m0?ooo`<000000`3o8`000`000000od00
0?m000020?m000X0000000<00?n:0000000000000`00oj/01@0000000<oo003?o`00col0000000@0
0?oQ00<00000003To`00i?l00`00i?l00`0000000<oo003?o`04003?o`0400000000i?l000000000
00<001So00<00000001Qo`00HOl01000HOl0100000000<oo003?o`000005000ao`0300000000col0
0<oo00800<oo00<00000001Qo`00HOl00P00HOl00`0000000?oQ00000005003To`0500000000col0
0<oo003?o`0000000P00i?l70000000304ko00000000000000@0000000@0oe40000000000000od00
0P0000030?lU00030000003o7000oa`000<000000P3o3`0010000000o`/00?l;003o2`0400000240
oooo00<000000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3oool0?P3oool00`000000ob<0
0?lS00030?lS00030000003o@000od000080od0000H000000?m^0000000000000?o0003?o`040000
0003003oRP000000000000800?n[00@00000003?o`00col00<oo0`000003003oh@0300000000i?l0
0>Co00800>Co00<00000003?o`00col01000col2000000D001So00<00000001Qo`00HOl01000HOl0
100000000<oo003?o`000005000ao`0500000000col00<oo003?o`0000001P00HOl00`0000000>Co
003To`03003To`0300000000col00<oo00800<oo00@00000003To`00i?l000000P00on401@000000
0?n:000000000000eol000@000001@3oD@000`000000obD00?lU00040?lU008000001P3o3`030000
02D0oooo00<000000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3oool0?`3oool010000000
ob<00?lS003o8`0<000000040<oo000000000?l^000000800?n:00@00000003oZ`00oj/000000`00
col00`000000067o001Qo`0200000003003oh@0000000>Co00@00>Co00<00000003?o`00col00P00
col2000000H001So00<00000001Qo`00HOl01@00HOl2000000L0037o00@00000003?o`00col00000
1P00HOl00`0000000>Co003To`03003To`0500000000col00<oo003?o`0000000P00i?l01@000000
0?oQ003oh@0000000?n:00H000000`3oD@0300000080obl000<000000?lU003o9@000P0000020?lD
008000000P3o3`02000002T0oooo00<000000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3o
ool0@03oool3000000<0oal000<000000?lh003o>0000P3o>0000`000000of400000000200000005
04ko00000000000000000000ohX00P000002003oZ`0500000000col00<oo003?o`0000000`00HOl4
000000<00>Co00<00000003?o`0000000P0000000`010?l00000000Ho`05000Ho`0300000000HOl0
067o00D0067o0P000007000ao`0300000000col0000000L0067o00<00000003To`00i?l00`00i?l0
1@0000000<oo003?o`00col0000000800>Co00D00000003oh@00on400000003oRP09000000H0obl0
0P0000060?lD00800000:`3oool00`000000oooo0?ooo`0?0?ooo`003P3oool00`000000oooo0?oo
o`110?ooo`030000003o7`00oal000<0oal000<000000?lh003o>0000P3o>00010000000of400?mQ
003oH@0200000004003o;P0000000?n:003oRP80000000<00?n[00000000col00P00col00`000000
067o001Qo`02001Qo`03000000006?l001So00D0000010010?l00`00000001So000Ho`04000Ho`03
00000000HOl0067o00D0067o00<00000000ao`00<Ol01P00<Ol00`0000000<oo00000006001Qo`03
000000006?l0000000<00>Co00D00000003?o`00col00<oo00000002003To`0500000000on400?oQ
00000000ohX0100000000`3oH@000000000000020?lh008000000P3o;`0200000080oaX000<00000
0?lD003o50000`00000^0?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000003oool0oooo
04<0oooo00@000000?lO003o7`00oal03`0000001@00ohX0000000000000oj/0000000<00<oo00<0
0000001Qo`00HOl00P00HOl00`00000001So000Ho`03000Ho`03000000010?l00@3o00@00@3o00<0
0000000Ho`006?l010006?l00`000000067o001Qo`03001Qo`8000002@00<Ol00`000000067o001Q
o`05001Qo`03000000006?l0000000<00>Co00D00000003?o`00col00<oo00000002003To`030000
0000on400?oQ0080000000<00?lP0000000000000P0000000`3o>00000000?lh00030?lh00800000
1@3o6P0200000340oooo00<000000?ooo`3oool03`3oool000d0oooo00<000000?ooo`3oool0A03o
ool3000000<0oaX000<000000?l_003o;`000P3o;`000`000000oe400?mA00020?mA0080000000<0
0?n:00000000col00P000003003?o`0300000000HOl0067o00<0067o00<00000000Ho`006?l00P00
6?l00`0000000@3o0040o`040040o`03000000006?l001So00@001So00<00000001Qo`00HOl00P00
HOl010000000D@3o0540o`000008000ao`0300000000HOl0067o00@0067o00L00000000Ho`006?l0
01So00000000i?l0000000@00<oo00L00000003To`00i?l00000003oh@0000000?n:00@0000000<0
od000000003o>000100000020?lO00030000003o6P00oaX000800000=03oool00`000000oooo0?oo
o`0?0?ooo`003@3oool00`000000oooo0?ooo`150?ooo`030000003o6P00oaX000<0oaX000<00000
0?l_003o;`000P3o;`0010000000oe400?mA003oD@04000000800<oo0P000002003?o`0300000000
HOl0067o00<0067o00<00000000Ho`006?l00`006?l00`0000000@3o0040o`030040o`0300000000
6?l001So00@001So00<00000001Qo`00HOl00P00HOl010000000D@3o0540o`000007000ao`800000
1P00HOl01`00000001So000Ho`006?l00000003To`0000000`00col0100000000>Co003To`000002
003oh@@00000103o@002000000H0oal00P00000g0?ooo`030000003oool0oooo00h0oooo000=0?oo
o`030000003oool0oooo04H0oooo0P0000030?lJ00`0000000D00?n:00000000col00<oo00000003
003?o`0300000000HOl0067o0080067o00<00000000Ho`006?l00`006?l00`0000000@3o0040o`03
0040o`03000000006?l001So00@001So00D00000001Qo`00HOl0067o000000030540o`0300000000
<Ol0037o00D0037o00<000000540o`0000001000HOl00`00000001So000Ho`03000Ho`0300000000
col00<oo00800<oo00@00000003To`00i?l000000P00on4300000080od000P0000020?lS00800000
0P3o7`02000003X0oooo00<000000?ooo`3oool03P3oool000d0oooo00<000000?ooo`3oool0B03o
ool300000080oa@000<000000?lU003o9@000P3o9@0200000080od000`000002003?o`8000000P00
col00`000000067o001Qo`02001Qo`03000000006?l001So00<001So00<000000040o`010?l00`01
0?l00`00000001So000Ho`04000Ho`0400000000HOl0067o000000D0D@3o00<00000000ao`00<Ol0
0`00<Ol010000000D@3o0540o`000004001Qo`03000000006?l001So00<001So00D00000003?o`00
col00<oo00000003003To`0500000000on40000000000000oj/00`0000050?lS00<00000?03oool0
0`000000oooo0?ooo`0>0?ooo`003@3oool00`000000oooo0?ooo`180?ooo`800000103o50020000
00<0obD0100000002@00on400000003?o`00col00000000ao`0000000<oo00000004001Qo`030000
00006?l001So00<001So00<000000040o`010?l00`010?l00`00000001So000Ho`05000Ho`800000
1P1A0?l00`000000037o000ao`03000ao`040000001A0?l0D@3o000000@0067o00<00000000Ho`00
6?l00`006?l2000000800<oo00@00000003To`00i?l000000P00on4300000080obH000<000000?lS
003o8`001000000n0?ooo`030000003oool0oooo00h0oooo000<0?ooo`030000003oool0oooo04X0
oooo0P0000030?lD00D000000P3o70000`000000oc0000000002000000800<oo0P0000000`00col0
0000001Qo`04001Qo`03000000006?l001So008001So00<000000040o`010?l010010?l00`000000
01So000Ho`04000Ho`8000001P1A0?l00`000000037o000ao`02000ao`050000001A0?l0D@3o0540
o`0000000`00HOl00`00000001So000Ho`03000Ho`03000000010?l00@3o008000000`00i?l01@00
00000?oQ0000000000000?n[00@0obH00P0000030?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool03P3oool000`0oooo00<000000?ooo`3oool0B`3oool4000000<0o`l000<000000?lL
003o70000P3o700200000009003oh@0000000<oo003?o`000000037o00000000col0000000@0067o
00<00000000Ho`006?l00P006?l00`0000000@3o0040o`040040o`03000000006?l001So00@001So
00<000000540o`1A0?l01@1A0?l00`000000037o000ao`02000ao`030000001A0?l0D@3o0080D@3o
00@00000001Qo`00HOl000001@006?l0100000000@3o0040o`010?l200000003003To`0000000?oQ
00<000000P3o9P02000000H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0>0?oo
o`00303oool00`000000oooo0?ooo`1<0?ooo`8000001@3o3`0010000000oa`00?lL003o70050000
0004003?o`000000037o000ao`8000001000HOl00`00000001So000Ho`03000Ho`03000000010?l0
0@3o00<00@3o00<00000000Ho`006?l00`006?l2000000P0D@3o00@00000000ao`00<Ol000001@1A
0?l00`000000067o00000005000Ho`03000000010?l00@3o00800@3o00<00000000Ho`0000001`00
00080?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03P3oool000`0oooo00<00000
0?ooo`3oool0C@3oool2000000<0o`l01@0000020?lD000500000000on400000003?o`0000000`00
<Ol00`000000067o001Qo`02001Qo`03000000006?l001So00<001So00<000000040o`010?l00`01
0?l00`00000001So000Ho`02000Ho`040000002X0?l0Z03o000000L0D@3o00@00000000ao`00<Ol0
00001@1A0?l00`000000067o00000005000Ho`05000000010?l00@3o0040o`0000000`006?l01000
0000067o00000000000;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool0
00`0oooo00<000000?ooo`3oool0CP3oool4000000<0o`/000<000000?lD003o50000P3o50030000
0004003?o`000000037o000ao`<000000P00HOl00`00000001So000Ho`03000Ho`03000000010?l0
0@3o00<00@3o00D00000000Ho`006?l001So000000030:P0o`030000001A0?l0D@3o00D0D@3o00<0
0000000ao`0000001`1A0?l00`00000001So000Ho`03000Ho`03000000010?l00@3o00800@3o00D0
0000000Ho`006?l00000001Qo`02000000`0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0=0?ooo`00303oool00`000000oooo0?ooo`1?0?ooo`8000001@3o2`000`000000oa@00?lD
000400000003003?o`000000037o0080037o00<000000540o`0000000P00HOl00`00000001So000H
o`02000Ho`03000000010?l00@3o00@00@3o00<00000000Ho`000000102X0?l00`000000D@3o0540
o`060540o`8000001`1A0?l00`00000001So000Ho`03000Ho`05000000010?l00@3o0040o`000000
0`006?l010000000067o00000000000<0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool03@3oool000/0oooo00<000000?ooo`3oool0D@3oool2000000<0o`/0100000020?l=00@00000
0`00<Ol00`000000D@3o0540o`03000000@001So00<000000040o`010?l010010?l2000000D0Z03o
00<000000540o`1A0?l01P1A0?l00`000000D@3o0540o`050540o`8000001@006?l01@0000000@3o
0040o`010?l00000008001So00@00000001Qo`00000000003@3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo00d0oooo000;0?ooo`030000003oool0oooo0580oooo100000030?l70007
0000003o3@00o`d00?l=00000000067o00000003000ao`030000001A0?l0D@3o0080D@3o0P000004
000Ho`03000000010?l00@3o00800@3o0P0000070:P0o`030000001A0?l0D@3o00@0D@3o0P000007
0540o`030000002X0?l0000000<001So00D000000040o`010?l00@3o00000003000Ho`0400000000
HOl00000000000d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`002`3o
ool00`000000oooo0?ooo`1C0?ooo`8000001@3o1`07000000<0037o00H000000540o`1A0?l0D@3o
0000002X0?l300000003000Ho`0000000@3o00<0000000<0a`3o0000002X0?l01P2X0?l00`000000
D@3o0540o`040540o`030000003V0?l0000000D0D@3o00@000000:P0o`2X0?l000000`006?l01@00
00000@3o0040o`010?l00000008001So00@00000001Qo`00000000003P3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo00d0oooo000;0?ooo`030000003oool0oooo05@0oooo0P000002
0?l70080000000L0o`@00000003o2000o`P000000000HOl0000000<0037o00D000000540o`1A0?l0
D@3o000000040:P0o`<0000010370?l00`000000Z03o0:P0o`050:P0o`030000001A0?l0D@3o00<0
D@3o00@000000>H0o`3V0?l000001@1A0?l01`000000Z03o0:P0o`2X0?l00000000Ho`0000001001
0?l01@00000001So000Ho`000000067o008000003P3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo00d0oooo000;0?ooo`030000003oool0oooo05D0oooo0`0000040?l400030000003o
2000000000<000000P00<Ol00`000000D@3o0540o`020540o`030000002X0?l0Z03o0080Z03o00<0
00000<L0o`370?l010370?l00`000000Z03o0:P0o`040:P0o`030000001A0?l0D@3o00<0D@3o00@0
00000>H0o`3V0?l00000101A0?l00`000000Z03o0:P0o`020:P0o`03000000006?l0000000<00@3o
00@00000000Ho`006?l001So0`00000?0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool03@3oool000/0oooo00<000000?ooo`3oool0EP3oool2000000D0o`@00`0000001@00HOl0D@3o
00000000<Ol0000000@0D@3o00<000000:P0o`2X0?l00P2X0?l00`000000a`3o0<L0o`040<L0o`03
0000002X0?l0Z03o00D0Z03o00D000000540o`1A0?l0D@3o000000030>H0o`030000001A0?l0D@3o
0080D@3o00<000000:P0o`2X0?l00`2X0?l00`0000000@3o0040o`020040o`05000000006?l001So
00000000HOl00P00000?0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0303oool0
00/0oooo00<000000?ooo`3oool0E`3oool200000080o`@00P0000000`3o0P000000000000020000
00040540o`000000037o000000<0D@3o00<000000:P0o`2X0?l00`2X0?l00`000000a`3o0<L0o`03
0<L0o`030000002X0?l0Z03o00D0Z03o00@000000540o`1A0?l000001@3V0?l010000000D@3o0540
o`0000060:P0o`05000000010?l00@3o0040o`0000000`006?l300000100oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0<0?ooo`002P3oool00`000000oooo0?ooo`1I0?ooo`<00000
103o0P03000000040540o`000000037o000000<0D@3o00<000000:P0o`2X0?l00`2X0?l00`000000
a`3o0<L0o`030<L0o`030000002X0?l0Z03o00D0Z03o00@000000540o`1A0?l000001@3V0?l01000
0000D@3o0540o`0000060:P0o`8000000P010?l01P00000001So000Ho`000000067o00000140oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0<0?ooo`002P3oool00`000000oooo0?oo
o`1J0?ooo`800000103o0P04000000030540o`000000000000<0D@3o00<000000:P0o`2X0?l00`2X
0?l00`000000a`3o0<L0o`030<L0o`030000002X0?l0Z03o00D0Z03o00<000000540o`0000001P3V
0?l00`000000D@3o000000060:P0o`03000000370?l0a`3o008000000`006?l300000180oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0<0?ooo`002P3oool00`000000oooo0?ooo`1K
0?ooo`030000003o0P00o`80008000000P3o0@0200000080D@3o0P0000030540o`030000002X0?l0
Z03o0080Z03o00<000000<L0o`370?l010370?l00`000000Z03o0:P0o`050:P0o`8000001P3V0?l0
0`000000D@3o000000060:P0o`04000000370?l0a`3o0<L0o`80000000@001So0000000000000000
4`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00`0oooo000:0?ooo`030000003o
ool0oooo05`0oooo0P0000040?l1008000000`1A0?l01@000000D@3o0540o`1A0?l0000000@0Z03o
00<000000<L0o`370?l010370?l00`000000Z03o0:P0o`050:P0o`030000003V0?l0iP3o00H0iP3o
00<000000:P0o`2X0?l0102X0?l00`000000a`3o0<L0o`020<L0o`030000002X0?l0000000800000
503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00`0oooo000:0?ooo`030000003o
ool0oooo05d0oooo0P0000030?l100<000000P1A0?l200000080D@3o00<000000:P0o`2X0?l00`2X
0?l00`000000a`3o0<L0o`030<L0o`030000002X0?l0Z03o00@0Z03o0P0000080>H0o`030000002X
0?l0Z03o00@0Z03o00D000000<L0o`370?l0a`3o000000020:P0o`030000001A0?l0000001@0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0<0?ooo`002P3oool00`000000oooo0?oo
o`1N0?ooo`@0000000<0o`000000000000000`1A0?l2000000030540o`000000Z03o00@0Z03o00<0
00000<L0o`370?l00`370?l00`000000Z03o0:P0o`030:P0o`030000003o0;H0000000L0iP3o0P00
00050:P0o`03000000370?l0a`3o0080a`3o00<000000:P0o`2X0?l00P00000E0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool02`3oool000T0oooo00<000000?ooo`3oool0H03oool2
000000<0o`000P0000020540o`80000000<0D@3o0000002X0?l0102X0?l00`000000a`3o0<L0o`03
0<L0o`040000002X0?l0Z03o0:P0o`8000000`3o0;H00`000000iP3o0>H0o`040>H0o`030000003o
0;H0000000@0Z03o00D000000<L0o`370?l0a`3o000000020:P0o`030000001A0?l0000001D0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0;0?ooo`002@3oool00`000000oooo0?oo
o`1Q0?ooo`8000000P3o000200000080D@3o00D000000>H0o`000000D@3o000000040:P0o`030000
00370?l0a`3o00@0a`3o00<000000:P0o`0000001@3o0;H00`000000iP3o0>H0o`030>H0o`040000
003o0;H0o`2f000000<0Z03o00<000000<L0o`370?l00P370?l00`000000Z03o0:P0o`02000001H0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0;0?ooo`002@3oool00`000000oooo
0?ooo`1R0?ooo`H0000000@0D@3o0000003V0?l0iP3o0P0000040:P0o`03000000370?l0a`3o00@0
a`3o0P0000060?l0]P030000003V0?l0iP3o00<0iP3o00@000000?l0]P3o0;H000000`2X0?l01@00
0000a`3o0<L0o`370?l000000080Z03o00<000000540o`0000005P3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo00/0oooo00090?ooo`030000003oool0oooo0680oooo00@000000?oo
o`3oool0oooo0`000000101A0?l000000>H0o`3V0?l2000000@0Z03o00<000000<L0o`370?l00P37
0?l2000000L0o`2f00<000000>H0o`3V0?l00P3V0?l00`000000o`2f0?l0]P020?l0]P030000002X
0?l0000000@0a`3o00<000000:P0o`2X0?l00P00000C0?ooo`80000000<0oooo000000000000@03o
ool00`000000oooo0?ooo`0;0?ooo`002@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo0080oooo0P0000001P1A0?l000000>H0o`3V0?l000000?l0]P<0000000<0Z03o000000370?l0
0`0000000`3o09<000000?l0]P070?l0]P050000003V0?l0iP3o0>H0o`000000103o0;H00`000000
Z03o000000040<L0o`050000002X0?l000000540o`0000004@3oool500000080oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0;0?ooo`002@3oool00`000000oooo0?ooo`1R0?ooo`03
0000003oool0oooo0080oooo100000030>H0o`040000003o0;H0o`2f0?l0]P<000001@3o09<00`00
0000o`2f0?l0]P050?l0]P040000003V0?l0iP3o000000H0o`2f00<000000<L0o`370?l00P370?l0
0`000000Z03o0:P0o`02000000l0oooo1@0000030?l000040000003oool0oooo000003h0oooo00<0
00000?ooo`3oool02`3oool000T0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`03
0?ooo`030000002X0?l0000000<0iP3o00<000000?l0]P3o0;H00P3o0;H00`000000o`2C0?l0T`04
0?l0T`030000003o0;H0o`2f00D0o`2f00@000000>H0o`3V0?l000001P3o0;H00`000000a`3o0<L0
o`020<L0o`040000002X0?l00000000000d0oooo100000070?l000040000003oool0oooo000003h0
oooo00<000000?ooo`3oool02`3oool000P0oooo00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`040?ooo`<000000P3V0?l00`000000o`2f0?l0]P030?l0]P030000003o09<0o`2C00<0o`2C
00<000000?l0]P3o0;H01@3o0;H00`000000iP3o000000060?l0]P030000003o09<000000080a`3o
00<000000:P0o`2X0?l00P0000090?ooo`D0000000<0o`400000003o0000203o000010000000oooo
0?ooo`00000n0?ooo`030000003oool0oooo00X0oooo00080?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0103oool00`000000Z03o000000030>H0o`030000003o0;H0o`2f0080o`2f
00<000000?l0T`3o09<0103o09<00`000000o`2f0?l0]P050?l0]P8000001P3o0;H00`000000o`2C
000000020<L0o`040000002X0?l00000000000H0oooo1P0000050?l100030000003o0000o`0000H0
o`000P0000020?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool02P3oool000P0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`050?ooo`<000000P3V0?l00`000000o`2f
0?l0]P020?l0]P030000003o09<0o`2C00@0o`2C00<000000?l0]P3o0;H01@3o0;H00`000000o`2f
0?l0]P040?l0]P040000003o09<0o`2C0?l0T`80000000<0Z03o0000000000001@3oool5000000T0
o`4000@000000?l0003o0000o`00100000020?l100040000003oool0oooo000003`0oooo00<00000
0?ooo`3oool02P3oool000P0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`050?oo
o`040000002X0?l0000000000080iP3o00<000000?l0]P3o0;H00P3o0;H00`000000o`2C0?l0T`03
0?l0T`030000003o0;H0o`2f00@0o`2f0P0000060?l0]P030000003o09<0o`2C0080o`2C0`000000
103V0?l0oooo0?ooo`3oool4000000<0o`8000<000000?l1003o0@001P3o0@04000000L0o`4000@0
00000?ooo`3oool00000>`3oool00`000000oooo0?ooo`0:0?ooo`00203oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo00H0oooo0P000000103o0;H000000>H0o`0000040?l0]P030000
003o09<0o`2C00@0o`2C00<000000?l0]P3o0;H00P3o0;H010000000o`1;0?l0B`0000040?l0]P03
0000003o09<0o`2C0080o`2C00D000000?l0]P3o0;H000000?ooo`03000000L0o`8000<000000?l1
003o0@00103o0@0200000080o`8000<000000?l1003o0@001`3o0@000`000000oooo0000000k0?oo
o`030000003oool0oooo00X0oooo00080?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool01`3oool00`000000o`2f0?l0]P02000000@0o`2f00<000000?l0T`3o09<0103o09<01@000000
o`2f0?l0]P3o0;H0000000<0o`1;00<000000?l0]P3o0;H00P3o0;H00`000000o`2C0?l0T`020?l0
T`D000000P3o10000`000000o`800?l200060?l200030000003o0@00o`4000<000001@3o0P000`00
0000o`400?l100060?l10080000000<0oooo0000003oool0>@3oool00`000000oooo0?ooo`0:0?oo
o`001`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00L0oooo0P0000020?l0]P80
0000103o0;H00`000000o`2C0?l0T`030?l0T`040000003o0;H0o`2f000000@0o`1;00D000000?l0
]P3o0;H0o`2f000000020?l0T`D000001@3o10000`000000o`800?l200060?l200<00000203o0P00
0`000000o`400?l100040?l1008000000P3o0P000`000000oooo0000000i0?ooo`030000003oool0
oooo00X0oooo00070?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0203oool01@00
0000o`2f0?l0]P3o0;H0000000@0o`2f00<000000?l0T`3o09<0103o09<2000000H0o`1;00<00000
0?l0]P0000001P0000080?l400040000003o0P00o`800?l200@000000P3o1@000`000000o`800?l2
00070?l200030000003o0@00o`4000<00000103o0P0010000000oooo0?ooo`00000i0?ooo`030000
003oool0oooo00T0oooo00070?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0203o
ool200000080o`2f0`0000020?l0]P030000003o09<0o`2C00<0o`2C0P0000050?l0B`L00000103o
1`000`000000o`@00?l400050?l400@000001`3o1@000`000000o`800?l200060?l200<00000203o
0P0010000000oooo0?ooo`00000h0?ooo`030000003oool0oooo00T0oooo00070?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool02P3oool01P000000o`2f0?l0]P3o0;H000000?l0B`80
000000<0o`2f0000003o09<00`0000000`3o02H000000?l0B`020?l0B`D000002@3o1`000`000000
o`@00?l4000400000080o`P000<000000?l5003o1@001`3o1@0010000000o`800?l2003o0P040000
0080o`D000<000000?l2003o0P001P3o0P001@000000oooo0?ooo`3oool0000003L0oooo00<00000
0?ooo`3oool02@3oool000L0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0;0?oo
o`040000003o0;H0o`2f000000<0o`1;0`0000050?l09PD000000`3o2`000`000000o`L00?l70006
0?l700<000001`3o20000`000000o`D00?l500060?l500@000001P3o1@000`000000o`800?l20006
0?l2008000000P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00T0oooo00070?oo
o`030000003oool0oooo06<0oooo00<000000?ooo`3oool0303oool00`000000o`2f000000040?l0
B`030000003o02H0o`0V0080o`0V100000060?l;00030000003o1`00o`L000@0o`L00P0000020?l=
00030000003o2000o`P000H0o`P000@000000?l5003o1@00o`D0100000020?l900030000003o1@00
o`D000H0o`D000@000000?l2003o0P00o`80100000020?l400040000003oool0oooo000003H0oooo
00<000000?ooo`3oool02@3oool000L0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`0=0?ooo`030000003o0;H0000000@0o`1;1@0000000`3o3`0000000?l;00070?l;00030000003o
1`00o`L000<000001@3o3@000`000000o`P00?l800050?l800@000001`3o2@000`000000o`D00?l5
00050?l500@000001`3o100010000000oooo0?ooo`00000e0?ooo`030000003oool0oooo00T0oooo
00060?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool03P3oool8000000D0o`l000<0
00000?l;003o2`001@3o2`03000000P0o`d000<000000?l8003o20000`3o200200000080o`l000<0
00000?l9003o2@001`3o2@000`000000o`D00?l5000400000080o`P000<000000?l4003o10001`3o
100010000000oooo0?ooo`00000d0?ooo`030000003oool0oooo00T0oooo00060?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool0303oool7000000T0o`l000<000000?l;003o2`001000
00020?lD00030000003o3@00o`d000L0o`d000<000000?l8003o20000P0000050?l?00030000003o
2@00o`T000H0o`T00`0000070?l800030000003o1000o`@000H0o`@00P0000020?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02@3oool000H0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`090?ooo`H00000103o50000`000000o`l00?l?00060?l?00<000001`3o5000
0`000000o`d00?l=00060?l=00<000001`3o3`000`000000o`T00?l900040?l9008000000P3o3`00
0`000000o`P00?l800060?l800040000003o1000o`@00?l400@000000P3o1`000`000000oooo0000
000d0?ooo`030000003oool0oooo00P0oooo00060?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool01`3oool5000000P0oa@000@000000?l?003o3`00o`l0100000020?lL00030000003o
5000oa@000H0oa@000@000000?l=003o3@00o`d0100000020?lG00030000003o3`00o`l000H0o`l0
00<000000?l9003o2@000`0000040?l?00030000003o2000o`P000H0o`P0100000060?l700040000
003oool0oooo000003<0oooo00<000000?ooo`3oool0203oool000H0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`040?ooo`D000000`3o6P000`000000oa@00?lD00050?lD00@00000
1`3o70000`000000oa@00?lD00050?lD00@000001P3o5`000`000000o`l00?l?00060?l?00<00000
203o3`0010000000o`P00?l8003o200400000080o`d000<000000?l7003o1`001P3o1`0010000000
oooo0?ooo`00000b0?ooo`030000003oool0oooo00P0oooo00060?ooo`030000003oool0oooo06@0
oooo00@000000?ooo`3oool0oooo1@0000060?lJ00030000003o5000oa@000<0oa@00P0000020?lU
00030000003o7000oa`000L0oa`000<000000?lD003o5000100000020?lS00030000003o5`00oaL0
00H0oaL000@000000?l?003o3`00o`l0100000020?lI00030000003o3`00o`l000H0o`l010000006
0?l=00030000003o1`00o`L000H0o`L00P0000020?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0203oool000D0oooo00<000000?ooo`3oool0I@3oool5000000030?lO00000000oaX0
00P0oaX000<000000?lD003o50000P0000050?lU00030000003o7000oa`000H0oa`00`0000070?lS
00030000003o5`00oaL000D0oaL0100000070?lI00030000003o3`00o`l000<0o`l00P0000020?lG
00030000003o3@00o`d000H0o`d000@000000?l7003o1`00o`L0100000020?l;00040000003oool0
oooo00000300oooo00<000000?ooo`3oool0203oool000D0oooo00<000000?ooo`3oool0HP3oool5
000000D0oal00P0000070?lJ00<00000203o9@0010000000oa`00?lL003o700400000080oc0000<0
00000?lS003o8`001P3o8`000`000000oaL00?lG000400000080obH000<000000?lI003o6@001`3o
6@000`000000o`l00?l?0002000000D0oaL000<000000?l=003o3@001@3o3@04000000H0o`/000@0
00000?ooo`3oool00000<03oool00`000000oooo0?ooo`080?ooo`001@3oool00`000000oooo0?oo
o`1N0?ooo`L000002@3o7`000`000000oaX00?lJ000400000080obl000<000000?lU003o9@001P3o
9@04000000L0oc0000<000000?lS003o8`001@3o8`03000000L0obH000<000000?lI003o6@001P3o
6@03000000L0oaL000<000000?l=003o3@000`3o3@0200000080oa@000<000000?l;003o2`001P3o
2`0010000000oooo0?ooo`00000_0?ooo`030000003oool0oooo00P0oooo00050?ooo`030000003o
ool0oooo05/0oooo1P0000040?lS00030000003o7`00oal000H0oal00`0000070?l_00030000003o
9@00obD000<0obD00P0000020?m000030000003o<000oc0000L0oc0000<000000?lS003o8`001000
00020?li00030000003o9P00obH000H0obH000@000000?lI003o6@00oaT0100000020?lV00030000
003o5`00oaL000H0oaL000<000000?l=003o3@000P0000050?lD00030000003o2`00o`/000D0o`/0
0P0000020?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01`3oool000D0oooo00<0
00000?ooo`3oool0E`3oool7000000P0ob<000@000000?lO003o7`00oal0100000020?lh00030000
003o;`00obl000H0obl000<000000?lU003o9@000P0000050?m000030000003o<000oc0000H0oc00
0`0000070?li00030000003o9P00obH000D0obH0100000060?lV00030000003o5`00oaL000H0oaL0
0`0000080?lD00030000003o2`00o`/000@000000P3o3`0010000000oooo0?ooo`00000^0?ooo`03
0000003oool0oooo00L0oooo00050?ooo`030000003oool0oooo05@0oooo1P0000040?lV00030000
003o8`00ob<000D0ob<0100000070?lh00030000003o;`00obl000D0obl00`0000080?m000040000
003o<000oc000?l`00@000000P3oC`000`000000ocT00?li00060?li00030000003o9P00obH000@0
00000P3o>`000`000000obH00?lV00060?lV00040000003o5`00oaL00?lG00@000000P3o8`000`00
0000oa@00?lD00060?lD00<000001`3o3`0010000000oooo0?ooo`00000]0?ooo`030000003oool0
oooo00L0oooo00050?ooo`030000003oool0oooo0500oooo1`0000080?lV00030000003o8`00ob<0
00@000000P3o@0000`000000ocP00?lh00070?lh00030000003o;`00obl000@000000P3oD@000`00
0000od000?m000060?m000@000001P3oC`000`000000ocT00?li00060?li00<000001`3o>`000`00
0000obH00?lV00050?lV00@000001P3o8`000`000000oa@00?lD00040?lD008000000P3o70000`00
0000o`l00?l?00060?l?00040000003oool0oooo000002`0oooo00<000000?ooo`3oool01`3oool0
00@0oooo00<000000?ooo`3oool0CP3oool3000000040?lW000000000000000000<0obL000<00000
0?lV003o9P001@3o9P03000000L0od000P0000070?lh00<000001`3oD@000`000000od000?m00003
0?m0008000000P3oJ0000`000000odl00?m?00060?m?00040000003o>@00ocT00?li00@000000P3o
E`000`000000oc/00?lk00060?lk00030000003o9P00obH000@000000P3o>@000`000000ob<00?lS
00060?lS00030000003o5000oa@000<00000103o70000`000000o`l00?l?00060?l?0080000000<0
oooo0000003oool0:`3oool00`000000oooo0?ooo`070?ooo`00103oool00`000000oooo0?ooo`1<
0?ooo`H000001`3o9`000`000000obH00?lV000400000080odD000<000000?m0003o@0001`3o@000
0`000000ocP00?lh000400000080of4000<000000?mA003oD@001P3oD@000`000000od000?m00002
000000D0ofP000<000000?m?003oC`001@3oC`04000000H0oeL000<000000?lk003o>`001P3o>`03
000000L0ocT000<000000?lS003o8`001@3o8`03000000P0oa`000@000000?l?003o3`00o`l01000
00020?lD00030000003oool0000002/0oooo00<000000?ooo`3oool01`3oool000@0oooo00<00000
0?ooo`3oool0BP3oool4000000<0obH000<000000?lW003o9`001@3o9`03000000L0odD000<00000
0?m0003o@0001P3o@003000000L0of4000<000000?mA003oD@001@3oD@03000000P0ofP000<00000
0?m?003oC`00100000020?mj00030000003oE`00oeL000H0oeL000@000000?lk003o>`00oc/01000
00020?mG00030000003o>@00ocT000H0ocT000<000000?lS003o8`00100000020?l`00030000003o
7000oa`000H0oa`0100000060?lD00040000003oool0oooo000002X0oooo00<000000?ooo`3oool0
1`3oool000@0oooo00<000000?ooo`3oool0A`3oool4000000L0obH000<000000?lW003o9`001000
00020?m700030000003oA@00odD000H0odD000@000000?m0003o@000od00100000020?m^00030000
003oH@00of4000H0of4000<000000?mA003oD@00100000020?n300030000003oJ000ofP000H0ofP0
0`0000070?mj00030000003oE`00oeL000D0oeL0100000060?mG00030000003o>@00ocT000H0ocT0
0`0000070?l`00030000003o7000oa`000<0oa`00P0000020?lU00030000003o5000oa@000H0oa@0
00@000000?ooo`3oool00000:P3oool00`000000oooo0?ooo`060?ooo`00103oool00`000000oooo
0?ooo`130?ooo`D0000000<0ob<00000003o9P001`3o9P03000000L0odL000<000000?m5003oA@00
1@3oA@04000000L0ofh000<000000?mQ003oH@001@3oH@03000000L0oh<000<000000?mX003oJ000
0`3oJ00200000080oj4000<000000?mj003oNP001P3oNP000`000000oeL00?mG000400000080oh00
00<000000?mG003oE`001P3oE`0010000000ocT00?li003o>@0400000080odl000<000000?l`003o
<0001P3o<0000`000000oa`00?lL0002000000@0obD000<000000?lD003o50001P3o500200000080
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`060?ooo`00103oool00`000000oooo
0?ooo`100?ooo`D000001@3o8`0200000080obH0100000020?m500030000003oA`00odL000H0odL0
00<000000?m5003oA@00100000020?mg00030000003oKP00ofh000L0ofh000<000000?mQ003oH@00
100000020?nM00030000003oP`00oh<000H0oh<000<000000?mX003oJ0000P0000050?nQ00030000
003oNP00ogX000D0ogX00`0000070?n000030000003oE`00oeL000D0oeL0100000060?m?00030000
003o<000oc0000H0oc000`0000070?lU00040000003o5000oa@00?lD00@000000P3o6P000`000000
oooo0000000Y0?ooo`030000003oool0oooo00H0oooo00030?ooo`030000003oool0oooo03d0oooo
1`0000090?lS008000001`3oA@02000000H0odL00`0000070?mg008000001`3oKP03000000L0oid0
00<000000?n3003oP`001@3oP`03000000P0oj4000<000000?mj003oNP00100000020?nb00030000
003oP000oh0000H0oh0000<000000?mG003oE`00100000020?mj00030000003oC`00odl000H0odl0
00@000000?l`003o<000oc00100000020?m000030000003o9@00obD000D0obD0100000060?lJ0004
0000003oool0oooo000002P0oooo00<000000?ooo`3oool01P3oool000<0oooo00<000000?ooo`3o
ool0>P3oool5000000D0oal00P0000050?lS0080000000<0od000000003oA@00203oA@000`000000
odL00?m7000300000080ogX000<000000?mg003oM`001`3oM`000`000000ofh00?m^000400000080
ok8000<000000?nM003oW@001P3oW@000`000000oh<00?n3000400000080ol/000<000000?nQ003o
X@001P3oX@03000000L0ok8000<000000?n0003oP0001@3oP003000000L0ogX000<000000?m?003o
C`001@3oC`04000000L0od0000<000000?lU003o9@00100000020?l_00030000003o6P00oaX000H0
oaX000@000000?ooo`3oool000009`3oool00`000000oooo0?ooo`060?ooo`000`3oool00`000000
oooo0?ooo`0g0?ooo`H000002@3o7`000`000000ob<00?lS0002000000@0od000P0000070?m500<0
00001P3oNP02000000L0ogL00`0000070?nb00030000003oW@00oid000D0oid00`0000070?o;0080
00000P3oX@0400000080on`000<000000?nb003o/P001P3o/P000`000000oh000?n0000400000080
ok8000<000000?mj003oNP001P3oNP000`000000odl00?m?000400000080ofP000<000000?m0003o
@0001P3o@003000000L0obl000<000000?lJ003o6P001@3o6P0200000080oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`060?ooo`000`3oool00`000000oooo0?ooo`0d0?ooo`D00000
103o6P02000000L0oal00`0000080?m000030000003oA@00odD000@000000P3oM`000`000000ogX0
0?mj00060?mj00030000003oM`00ogL000@000000P3o`0000`000000ok800?nb00060?nb00030000
003oW@00oid000@000000P3olP000`000000ol/00?o;00060?o;00<000001`3ok0000`000000ok80
0?nb00050?nb00<000001`3o/P000`000000ogX00?mj00050?mj00<000001`3oJ00200000080od00
100000020?mA00030000003o;`00obl000H0obl000<000000?lJ003o6P00100000020?lO00040000
003oool0oooo000002D0oooo00<000000?ooo`3oool01P3oool000<0oooo00<000000?ooo`3oool0
<03oool7000000P0oaX000<000000?lO003o7`00100000020?lh00030000003o@000od0000H0od00
0`0000070?mg00030000003oNP00ogX000D0ogX00`0000070?o000030000003o/P00ok8000D0ok80
0`0000070?ob008000000P3ob`0400000080eol000<000000?o/003ok0001P3ok0000`000000ok80
0?nb000400000080ooP000<000000?nb003o/P001P3o/P000`000000ogX00?mj000400000080oj40
00<000000?mX003oJ0001P3oJ003000000H0oe4000<000000?l_003o;`001P3o;`03000000H0oal0
00@000000?ooo`3oool000009@3oool00`000000oooo0?ooo`060?ooo`000`3oool00`000000oooo
0?ooo`0]0?ooo`H00000103o50000`000000oaX00?lJ00050?lJ00<000001`3o>00200000080od00
100000020?m^00030000003oM`00ogL000H0ogL000<000000?mj003oNP00100000020?o500030000
003o`000ol0000H0ol0000<000000?nb003o/P00100000020>go00030000003olP00oo8000H0oo80
0`0000060=Oo00030000003ok000on`000H0on`00`0000060?oh00030000003o/P00ok8000H0ok80
0`0000060?nQ00030000003oJ000ofP000@0ofP00P0000020?n300030000003oD@00oe4000D0oe40
00@000000?l_003o;`00obl0100000020?lh00030000003o7`00oal000D0oal000@000000?ooo`3o
ool000009@3oool00`000000oooo0?ooo`050?ooo`000P3oool00`000000oooo0?ooo`0Z0?ooo`L0
0000203o50000`000000oaX00?lJ000400000080obl000<000000?lh003o>0001P3o>003000000L0
ofh000<000000?mg003oM`001@3oM`03000000L0olD000<000000?o0003o`0001@3o`003000000L0
kOl00P0000020?ob00@000000P2Mo`000`000000eol00=Oo00050=Oo00040000003ok000on`00?o/
00@000000P2go`000`000000ooP00?oh00050?oh00040000003o/P00ok800?nb00@000000P3ok000
0`000000oj400?nQ00050?nQ00030000003oJ000ofP000<00000103oP`000`000000oe400?mA0005
0?mA00@000001P3o>0000`000000oal00?lO00050?lO008000000P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00D0oooo00020?ooo`030000003oool0oooo02L0oooo1P0000040?l?
00030000003o5000oa@000D0oa@00`0000070?l_008000000P3o>00400000080of4000<000000?m^
003oKP001P3oKP000`000000ogL00?mg000400000080ol0000<000000?o5003oa@001P3oa@000`00
0000ol000?o0000400000080eol000<000000>go003]o`001P3]o`03000000H0WOl000<000000=Oo
003Go`001@3Go`04000000H0]ol000<000000?oh003on0001@3on004000000H0on`000<000000?nQ
003oX@001@3oX@03000000P0oh<000<000000?mA003oD@00100000020?mQ00030000003o>000ocP0
00H0ocP000<000000?lO003o7`00100000020?lS00040000003oool0oooo000002<0oooo00<00000
0?ooo`3oool01@3oool00080oooo00<000000?ooo`3oool0903oool6000000P0o`l000<000000?lD
003o5000100000020?lU008000001`3o;`03000000L0of4000<000000?m^003oKP001@3oKP030000
00L0ol0000<000000?o5003oa@001@3oa@03000000L0eol00P0000020>go00@000000P1^o`000`00
0000WOl009go000509go00030000003Go`00eol000@000000P1So`000`000000]ol00;Oo00060;Oo
00030000003on000ooP000@000000P2go`000`000000on`00?o/00060?o/00030000003oX@00oj40
00@000000P3ob`000`000000oh<00?n300060?n300<000001P3oH@000`000000ocP00?lh00060?lh
00<000001P3o8`001@000000oooo0?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool0
0080oooo00<000000?ooo`3oool08@3oool6000000<0o`/00P0000060?l?00<00000203o9@020000
0080obl00`0000020?mA00030000003oH@00of4000H0of4000<000000?m^003oKP00100000020?nb
00030000003o`000ol0000H0ol0000<000000?o5003oa@00100000020<oo00030000003Go`00eol0
00H0eol00`00000706ko00030000002Mo`00WOl000@0WOl00`00000706?o00030000002go`00]ol0
00D0]ol00`0000070;Oo00030000003ok000on`000D0on`00`0000070?o;008000000P3oP`040000
0080oid000<000000?mQ003oH@001@3oH@0010000000ocP00?lh003o>00400000080od0000<00000
0?lS003o8`001@3o8`001@000000oooo0?ooo`3oool000000240oooo00<000000?ooo`3oool01@3o
ool00080oooo00<000000?ooo`3oool07@3oool7000000P0o`/000<000000?l?003o3`000`000002
0?lL00800000203o9@03000000H0oe400P0000060?mQ00<000001`3o/P000`000000ol000?o00005
0?o000<000001`3?o`0200000080eol01000000204ko00030000001^o`00K_l000H0K_l000<00000
09go002Mo`000`00000201?o00030000001So`00Hol000H0Hol000<000000;Oo002go`0010000002
04ko00030000002go`00]ol000H0]ol000<000000?o/003ok000100000020=Oo00030000003ob`00
ol/000H0ol/00`0000060?nM00030000003oH@00of4000D0of40100000060?m000030000003o8`00
ob<000D0ob<00P0000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool0
0080oooo00<000000?ooo`3oool06P3oool6000000@0o`L000<000000?l;003o2`001@3o2`030000
00L0oa`00P0000020?lU00@000000P3o@0000`000000oe400?mA00060?mA00030000003oH@00of40
00<000000P3oW@000`000000ok800?nb00060?nb00030000003o`000ol0000@000000P3Go`000`00
0000col00<oo00060<oo00<000001`1>o`000`000000K_l006ko000506ko00<000001P0Co`000`00
0000Hol006?o000506?o00<000001`1>o`000`000000]ol00;Oo00050;Oo00<000001`3Go`020000
0080ol/0100000020?ob00030000003oW@00oid000D0oid000<000000?mQ003oH@00100000020?m^
00030000003o@000od0000H0od0000<000000?lS003o8`00100000020?lV00040000003oool0oooo
00000200oooo00<000000?ooo`3oool01@3oool00080oooo00<000000?ooo`3oool05`3oool60000
00P0o`L000<000000?l;003o2`00100000020?lD00030000003o7000oa`000H0oa`00`0000070?m0
00030000003oD@00oe4000D0oe400`0000060?nM00030000003o/P00ok8000D0ok800`0000070=Oo
008000000P3?o`0400000080@ol000<0000004ko001>o`001P1>o`000`000000K_l006ko00040000
00800?l^00<0000001?o000Co`001@0Co`000`000000Hol006?o0004000000800?lP00<0000004ko
001>o`001P1>o`000`000000]ol00;Oo000400000080Hol000<000000=Oo003Go`001P3Go`030000
00H0oo8000<000000?nM003oW@001@3oW@03000000L0ofh000<000000?m0003o@0001@3o@0030000
00L0obH000@000000?ooo`3oool00000803oool00`000000oooo0?ooo`040?ooo`0000<0oooo0000
003oool05P3oool6000000<0o`@00P0000060?l700<000001`3o500200000080oa`0100000020?l`
00030000003o@000od0000H0od0000<000000?mA003oD@00100000020?n300030000003oW@00oid0
00D0oid000<000000?nb003o/P00100000020>go00030000003Go`00eol000H0eol00`00000704?o
00030000001>o`00C_l000D0C_l00`000006003o;P030000000Co`004ol000D04ol00`000007003o
80030000001>o`00C_l000D0C_l00`00000706?o00040000003Go`00eol00=Oo00@000000P2Mo`00
0`000000oo800?ob00050?ob00030000003oW@00oid000@000000P3o/P000`000000ofh00?m^0006
0?m^00030000003o@000od0000@000000P3oA@000`000000obH00?lV00050?lV008000000P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00000`3oool000000?ooo`0C0?oo
o`H00000203o10000`000000o`L00?l7000300000080o`d00P0000070?lD00<000001`3o<0000`00
0000od000?m000050?m000<000001`3oP`000`000000oid00?nM00040?nM00<000001`3]o`020000
0080eol01000000204ko000300000013o`00@ol000H0@ol000<0000004ko001>o`0010000002003o
FP0300000000obh00?l^00D00?l^00<0000001?o000Co`0010000002003oRP0300000000ob000?lP
00H00?lP00<0000004ko001>o`0010000002003o80030000001So`00Hol000D0Hol01000000609go
00030000003olP00oo8000D0oo800`0000060?nb00030000003oKP00ofh000H0ofh00`0000070?m5
00030000003o9P00obH000@000000P3o9`0010000000oooo0?ooo`00000N0?ooo`030000003oool0
oooo00@0oooo00000`3oool000000?ooo`0@0?ooo`H000000`3o0P02000000H0o`@00`0000070?l=
008000000P3o500300000080ob<000<000000?l`003o<0001P3o<0000`000000od000?m000040000
0080ofP000<000000?n3003oP`001P3oP`000`000000oid00?nM000300000080oo800P0000070>go
00<000001`1>o`000`000000@ol004?o000504?o00<000001P00oeX00`0000000?l^003o;P05003o
;P<000001`00ohX2000000@00?lP1@000007003o80030000001So`00Hol000@000000P0Co`000`00
0000WOl009go000609go00030000003olP00oo8000@000000P3]o`000`000000ok800?nb00050?nb
00040000003oKP00ofh00?m^00@000000P3oM`000`000000odD00?m500050?m500<000001P3o9`00
10000000oooo0?ooo`00000N0?ooo`030000003oool0oooo00@0oooo00000`3oool000000?ooo`0<
0?ooo`L00000203o0P000`000000o`@00?l4000300000080o`P00P0000070?l=00<000001P3o8`02
000000H0oc000`0000070?mX00030000003oP`00oh<000D0oh<00`0000070?ob008000000P3]o`03
00000080K_l000<0000004ko001>o`001P1>o`000`000000@ol004?o0004000000800?mY00<00000
003oFP00oeX01@00oeX00`0000000?l^003o;P04000000800?oQ00<00000003oRP00ohX01P00ohX5
000000@00?n[00<00000003o8000ob001@00ob03000000L04ol000<0000009go002Mo`001@2Mo`03
000000L0kOl000<000000?nb003o/P000P3o/P06000000L0ogL000<000000?m5003oA@0010000002
0?m700030000003o9`00obL000D0obL000@000000?ooo`3oool000007@3oool00`000000oooo0?oo
o`040?ooo`0000<0oooo0000003oool02@3oool6000000@0o`4000<000000?l2003o0P001@3o0P03
000000L0o`P00P0000020?l=00<000000P3o5`000`000000ob<00?lS00060?lS00030000003o<000
oc0000<000000P3oC`000`000000ofP00?mX00060?mX00030000003oP`00oh<000@000000P3ob`00
0`000000oo800?ob00060?ob00<000001P1^o`000`000000C_l004ko000504ko00<000001`00ofT0
0`0000000?mJ003oFP04003oFP<000001`00on42000000800?n:10000002003?o`0300000000oj/0
0?n[00D00?n[00<00000003o8000ob0010000002003oRP030000000Co`004ol000H04ol000<00000
09go002Mo`001000000206ko00030000003]o`00kOl000D0kOl01@0000040?o000030000003oM`00
ogL000H0ogL00`0000060?m700030000003o9`00obL000D0obL00P0000020?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0103oool000030?ooo`000000oooo00H0oooo1`0000070?l1
00030000003o0P00o`8000@000000P3o1@000`000000o`P00?l800060?l800<000001P3o5`020000
00H0ob<00`0000060?m?008000001P3oJ003000000L0ol/00P0000020?ob00@000000P2Mo`000`00
0000K_l006ko000506ko00030000001>o`00C_l000@000000P00oeX00`0000000?mY003oJ@06003o
J@0300000000oeX00?mJ00<000000P00i?l00`0000000?oQ003oh@06003oh@<000001`00col00`00
00000?n[003oZ`04003oZ`<000001`00ohX00`0000004ol001?o000501?o00<000001`1^o`000`00
0000kOl00>go000400000080eol000<000000?o0003o`0001@3o`00200000080ogL0100000020?mj
00030000003oA`00odL000D0odL000<000000?lW003o9`00100000020?lV00040000003oool0oooo
000001/0oooo00<000000?ooo`3oool0103oool000030000003oool0oooo00@0oooo1@0000040?l0
00800000103o0@04000000L0o`D00P0000020?l800@000000P3o3`000`000000oaL00?lG00060?lG
00030000003o8`00ob<000<000000P3o>@000`000000odl00?m?00060?m?00030000003oJ000ofP0
00<000000P3oX@02000000L0ol/00`00000709go00030000001^o`00K_l000@0K_l00`000007003o
FP0300000000ofT00?mY00D00?mY0`000006003To`8000000P00on4400000080067o00<00000003?
o`00col01P00col00`0000000?n[003oZ`03000000800<oo00<00000003oRP00ohX01P00ohX00`00
00004ol001?o0004000000800?l^00<0000006ko001^o`001@1^o`03000000H0eol000<000000?o0
003o`0001P3o`003000000H0ogX000<000000?m7003oA`001@3oA`03000000L0obH000@000000?oo
o`3oool000006P3oool00`000000oooo0?ooo`040?ooo`0000<000000?ooo`3oool00P3oool50000
00L0o`001@0000030?l2008000001`3o1@03000000L0o`l000<000000?lG003o5`001@3o5`030000
00H0ocT00P0000040?m?00D000001`3oX@0200000080ol/00`0000020=Oo00030000002Mo`00WOl0
00H0WOl000<0000006ko001^o`000`000002003o;P0300000000oeX00?mJ00H00?mJ00<00000003o
J@00ofT010000002003?o`0300000000i?l00>Co00D00>Co0`000007001Qo`0300000000col00<oo
00D00<oo0`000006003?o`0300000000ohX00?n:00D00?n:0`000007003o;P030000001^o`00K_l0
00@000000P1>o`000`000000eol00=Oo00050=Oo00040000003o`000ol000?o000@000000P3oa@00
0`000000ogX00?mj00050?mj00030000003oA`00odL000@000000P3oA@000`000000obH00?lV0005
0?lV0080000000<0oooo0000003oool06P3oool00`000000oooo0?ooo`030?ooo`0000<000000?oo
o`0000000P0000050?ooo`8000000P3o000300000080o`4000<000000?l2003o0P001@3o0P020000
0080o`D00`0000020?l900030000003o3`00o`l000H0o`l000<000000?lG003o5`00100000020?lV
00030000003o>@00ocT000D0ocT01@0000040?mj00030000003oX@00oj4000H0oj400`0000060=Oo
00030000002Mo`00WOl000D0WOl00`000006003o;P8000001000oeX5000000L00<oo0P000002003T
o`<000000P006?l00`000000067o001Qo`06001Qo`0300000000col00<oo00@000000P00<Ol00`00
00000<oo003?o`05003?o`0300000000ohX00?n:00@000000P00on400`0000000?l^003o;P05003o
;P<000001P1>o`000`000000eol00=Oo00050=Oo00@000001P3oa@000`000000ogX00?mj00050?mj
00<000001`3oA@000`000000obH00?lV000400000080ob<000<000000?ooo`0000006P3oool00`00
0000oooo0?ooo`030?ooo`000P00000:0?ooo`8000001P3o0@02000000H0o`800`0000060?l90080
00001P3o3`03000000L0obH00P0000020?li00<000000P3oE`000`000000ogX00?mj00050?mj0080
00000P3oX@0400000080on`000<000000=Oo003Go`001@3Go`000`000000WOl009go000400000080
4ol000<00000003o;P00obh01@00obh5000000@00>Co00<00000003?o`00col01P00col3000000H0
01So00<00000001Qo`00HOl01@00HOl3000000L0037o00<00000003?o`00col00P00col5000000L0
0?oQ00<00000003o;P00obh010000002003oFP030000001>o`00C_l000D0C_l000<000000=Oo003G
o`00100000020<oo00030000003oa@00olD000H0olD000<000000?mj003oNP00100000020?mg0003
0000003oA@00odD000D0odD00`0000060?lS00040000003oool0oooo000001T0oooo00<000000?oo
o`3oool00`3oool000030?ooo`000000000000X0oooo00<000000?l1003o0@001P3o0@000`000000
o`800?l2000300000080o`D00P0000070?l900030000003o3`00o`l000<000000P3o6@02000000L0
obH00`0000060?mG008000001P3oNP03000000L0on`000<000000=Oo003Go`00103Go`03000000L0
4ol00P000002003o;P<000000P00on400`0000000>Co003To`05003To`8000000P00col400000080
0@3o00<00000000Ho`006?l01@006?l00`000000067o001Qo`0400000080D@3o00<00000000ao`00
<Ol01@00<Ol5000000@0067o00<00000003oh@00on401@00on43000000H00?mJ00<0000004ko001>
o`001@1>o`03000000L0col00P0000040?o500D000001`3oM`000`000000odD00?m5000400000080
od0000<000000?lS003o8`001@3o8`0010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo
00<0oooo00030?ooo`030000003oool0oooo00P0oooo0P0000060?l100<000001`3o1@02000000@0
o`T0100000070?lI008000000P3o9P0300000080oc/000<000000?mG003oE`001P3oE`000`000000
ogX00?mj000300000080ok8000<000000?o/003ok0001P3ok0000`000000eol00=Oo000300000080
Hol000<0000001?o000Co`001P0Co`03000000H00?oQ00<00000003To`00i?l01@00i?l3000000H0
0@3o00<00000000Ho`006?l01@006?l3000000L0D@3o00<00000000ao`00<Ol0100000020540o`03
00000000HOl0067o00D0067o00<00000003oh@00on4010000002003To`0300000000oeX00?mJ00D0
0?mJ00<0000004ko001>o`001000000204?o00030000003?o`00col000H0col01@0000040?o00003
0000003oM`00ogL000D0ogL00`0000060?m000030000003o8`00ob<000D0ob<00P0000020?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool0
2@3oool00`000000o`400?l1000300000080o`800P0000070?l500D000000`3o3`000`000000oaT0
0?lI00060?lI00<000001P3o>`000`000000oeL00?mG00050?mG00<000001P3o/P02000000@0on`0
1@00000606?o008000000P0Co`04000000800?n:00<00000003oh@00on401@00on400`0000000>Co
003To`040000008001So00<000000040o`010?l01@010?l00`00000001So000Ho`0400000080Z03o
00<000000540o`1A0?l01@1A0?l3000000L0D@3o00<00000001Qo`00HOl01000HOl3000000L00>Co
00<00000003oFP00oeX01000oeX3000000L0@ol00P0000020<oo00@000000P3Go`000`000000ol00
0?o000050?o000030000003oM`00ogL000@000000P3oKP000`000000od000?m000050?m000030000
003o8`00ob<000@000000P3o7`0010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo00<0
oooo00050?ooo`8000002P3oool2000000L0o`800P0000020?l500<000000P3o20000`000000o`l0
0?l?00040?l?008000000P3o6@0400000080obH000<000000?lk003o>`001@3o>`000`000000oeL0
0?mG000400000080oh0000<000000?nb003o/P001@3o/P05000000@0]ol000<0000006?o001So`00
1@1So`03000000L00?n:00<00000003oh@00on401000on43000000L001So0P0000040040o`@00000
1`2X0?l200000080D@3o0`0000020>H0o`030000001A0?l0D@3o00H0D@3o00<00000001Qo`00HOl0
0`000002000Ho`0300000000i?l00>Co00H00>Co00<00000003oFP00oeX00`000002003oJ@030000
0013o`00@ol000H0@ol00`0000060=Oo00030000003o`000ol0000D0ol000`0000060?m^00030000
003o@000od0000D0od000`0000070?lO00030000003oool0000001H0oooo00<000000?ooo`3oool0
0`3oool000L0oooo00<000000?ooo`3oool0203oool00`000000o`800?l200060?l200<000001P3o
20000`000000o`l00?l?00040?l?00<000001`3o9P000`000000oc/00?lk00040?lk00<000001`3o
P00200000080ok800`0000020?oh00030000002go`00]ol000D0]ol00P00000206?o00<000000P00
ob000`0000000?n:003oRP06003oRP0300000000on400?oQ00<000000P00HOl00`00000001So000H
o`06000Ho`D000000`370?l00`000000Z03o0:P0o`060:P0o`<000001P3V0?l00`000000D@3o0540
o`050540o`<000001P006?l2000000@00>Co1@000006003oJ@8000000P13o`0400000080C_l000<0
00000=Oo003Go`001@3Go`000`000000ol000?o0000400000080ok8000<000000?m^003oKP001@3o
KP000`000000od000?m0000400000080ocP000<000000?lO003o7`001@3o7`02000000030?ooo`00
0000oooo01D0oooo00<000000?ooo`3oool00P3oool000P0oooo0P0000090?ooo`8000000P3o0P04
00000080o`@000<000000?l8003o20001@3o20000`000000o`l00?l?000300000080oaL00P000007
0?lV00030000003o>`00oc/000<000000P3oE`02000000L0oh000`0000060?oh00030000002go`00
]ol000D0]ol00`000006003o800300000000ohX00?n:00D00?n:0`000006001Qo`8000000P006?l4
00000080Z03o00<000000<L0o`370?l010370?l200000080Z03o100000020?l0]P030000003V0?l0
iP3o00D0iP3o00<000000540o`1A0?l0100000020:P0o`03000000006?l001So00D001So1@000004
003?o`0300000000ofT00?mY00D00?mY0`00000604ko00030000003Go`00eol000D0eol00`000007
0?nb00030000003oKP00ofh00080ofh01@0000070?lh00030000003o7`00oal000@0000000D0oaX0
0000003oool0oooo0000000E0?ooo`030000003oool0oooo0080oooo000:0?ooo`030000003oool0
oooo00P0oooo0P0000070?l400030000003o2000o`P000@0o`P00`0000070?lG00800000103o9P04
000000L0oeL00P0000020?n000<000000P3o/P000`000000ooP00?oh00050?oh00030000002go`00
]ol000@000000P1>o`000`0000000?lP003o8005003o800300000000ohX00?n:00@000000P00col0
0`000000067o001Qo`05001Qo`<000001P2X0?l00`000000a`3o0<L0o`050<L0o`<000001P3o0;H0
0`000000iP3o0>H0o`050>H0o`<000001`2X0?l00`00000001So000Ho`04000000800@3o00<00000
003?o`00col01@00col00`0000000?mY003oJ@04000000800?mJ00<0000004ko001>o`001@1>o`00
0`000000eol00=Oo000400000080kOl000<000000?nb003o/P001@3o/P05000000@0of4000<00000
0?lh003o>0001@3o>003000000H0oaX000@000000?ooo`3oool00000503oool00`000000oooo0?oo
o`020?ooo`002`3oool2000000T0oooo0P0000070?l400030000003o2000o`P000<000000P3o3@02
000000L0oaL01@0000030?li00030000003oE`00oeL000H0oeL00`0000060?nb00030000003on000
ooP000@0ooP00`00000704ko008000001000ob04000000L00<oo0P000002001Qo`<000000P1A0?l0
0`000000Z03o0:P0o`050:P0o`03000000370?l0a`3o00@000000P3o09<00`000000o`2f0?l0]P05
0?l0]P030000003V0?l0iP3o00@000000P3o0;H00`000000Z03o0:P0o`050:P0o`<000001P010?l0
0`0000000<oo003?o`05003?o`<000001`00oeX00`000000C_l004ko000204ko00D000001`3]o`00
0`000000ok800?nb000400000080oid000<000000?mQ003oH@001@3oH@000`000000ocP00?lh0004
00000080obl000<000000?lJ003o6P00103o6P001@000000oooo0?ooo`3oool0000001<0oooo00<0
00000?ooo`3oool00P3oool000d0oooo00<000000?ooo`3oool0203oool2000000@0o`@010000007
0?l=008000000P3o5`0300000080ob<000<000000?li003o>@00103o>@0200000080oeL010000002
0?mj00030000003o/P00ok8000D0ok8000<000000?oh003on0000`0000020;Oo00030000001>o`00
C_l000H0C_l01@000003003oZ`0300000000col00<oo00H00<oo0`0000060540o`030000002X0?l0
Z03o00@0Z03o0`0000070?l0T`800000103o0;H4000000L0o`2f00<000000:P0o`2X0?l010000002
0<L0o`03000000010?l00@3o00D00@3o00<00000003?o`00col010000002003To`0300000000oeX0
0?mJ00D00?mJ1@00000406ko00030000003]o`00kOl000D0kOl00`0000060?nM00030000003oH@00
of4000D0of400`0000060?l_00030000003o6P00oaX00080oaX0100000020?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool00P3oool000h0oooo00<000000?ooo`3oool02@3oool40000
00<0o`L00P0000070?l=00<000001P3o8`000`000000ocT00?li00040?li00<000001`3oNP020000
00@0ok80100000060;Oo008000000P1>o`04000000800?lP00<00000003oZ`00oj/01000oj/20000
00800<oo10000002000ao`030000001A0?l0D@3o00D0D@3o00<000000:P0o`2X0?l00`0000020?l0
]P030000003o09<0o`2C00H0o`2C1@0000030?l0B`030000003o0;H0o`2f00D0o`2f0`0000060<L0
o`03000000010?l00@3o00D00@3o0`000007003To`0300000000oeX00?mJ00@000000P00obh00`00
0000K_l006ko000506ko00030000003]o`00kOl000@000000P3olP000`000000oid00?nM00050?nM
00030000003oH@00of4000@000000P3oD@000`000000obl00?l_00040?l_00D00000103o50001000
0000oooo0?ooo`00000B0?ooo`030000003oool0oooo0080oooo000?0?ooo`8000002P3oool00`00
0000o`L00?l700050?l7008000000P3o3@0300000080oa@000<000000?lS003o8`001@3o8`000`00
0000ocT00?li000300000080odl00P0000070?mj00D000000`3ok0000`000000]ol00;Oo00050;Oo
00<000001`00ob000`0000000?n[003oZ`04003oZ`<000001`00<Ol00`000000D@3o0540o`020540
o`D000001P3o0;H200000080o`2C100000020?l09P030000003o04/0o`1;00@0o`1;0P0000020?l0
]P<000000P3o09<00`000000a`3o0<L0o`050<L0o`03000000010?l00@3o00@000000P006?l00`00
00000>Co003To`05003To`<000001P00obh00`000000K_l006ko000506ko00<000001`3olP000`00
0000oid00?nM00020?nM00D000001P3oD@000`000000obl00?l_000400000080obD000<000000?lD
003o50001@3o500010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo0080oooo000A0?oo
o`030000003oool0oooo00P0oooo0P0000060?l700<000001P3o5002000000@0ob<0100000070?m?
008000000P3oNP0300000080oj4000<000000?o/003ok000103ok00200000080]ol00`00000206?o
000300000000ob000?lP00H00?lP00<00000003oZ`00oj/00`000002003?o`0300000000<Ol0037o
00D0037o1@0000040>H0o`030000003o0;H0o`2f00D0o`2f0`0000060?l09P030000003o04/0o`1;
00D0o`1;0`0000060?l0T`80000010370?l4000000L001So00<00000003To`00i?l010000002003o
h@0300000000obh00?l^00D00?l^00<0000006ko001^o`001000000209go00030000003olP00oo80
00D0oo801@0000040?n300030000003oD@00oe4000@0oe400`0000060?lU00030000003o5000oa@0
00D0oa@00P0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00180
oooo0P00000:0?ooo`030000003o1`00o`L000<000000P3o2`000`000000oa@00?lD00050?lD00D0
00000`3o<0000`000000odl00?m?00060?m?00<000001P3oX@000`000000on`00?o/00040?o/00<0
00001P1So`02000000@00?lP1@000006003?o`8000000P00<Ol300000080D@3o00<000000>H0o`3V
0?l01@3V0?l200000080o`2f0`0000020?l0B`030000003o02H0o`0V00D0o`0V00<000000?l0B`3o
04/0100000020?l09P030000003o09<0o`2C00D0o`2C1@0000030:P0o`03000000006?l001So00D0
01So0`000007003oh@0300000000obh00?l^00800?l^1@00000709go00030000003olP00oo8000@0
00000P3ob`000`000000oh<00?n300040?n300030000003oD@00oe4000@000000P3o@0000`000000
obD00?lU00050?lU00030000003o5000oa@000@000000P3o3`0010000000oooo0?ooo`00000@0?oo
o`030000003oool0oooo0040oooo000D0?ooo`030000003oool0oooo00P0oooo0P0000060?l;0080
00000P3o500300000080oa`000<000000?l`003o<000103o<00200000080odl0100000020?mX0003
0000003oX@00oj4000D0oj4000<000000?o/003ok0000`0000020=Oo00030000001So`00Hol000D0
Hol01@000004003oRP0300000000col00<oo00D00<oo0`0000060540o`030000003V0?l0iP3o00D0
iP3o0`0000060?l0B`800000103o02H4000000L0o`0V00<000000?l0T`3o09<0100000020?l0]P03
0000002X0?l0Z03o00@0Z03o0P000002000Ho`<000000P00HOl00`0000000?oQ003oh@05003oh@D0
0000100Co`000`000000WOl009go000509go00<000001P3ob`000`000000oh<00?n300040?n300<0
00001`3o@0000`000000obD00?lU00020?lU00D000001`3o3`000`000000oooo0000000@0?ooo`03
0000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo00P0oooo00<000000?l;003o2`00
1@3o2`03000000H0oa`000<000000?l`003o<000103o<003000000L0ofP00P0000040?nQ00@00000
1P3Go`0200000080Hol00`00000201?o000300000000ohX00?n:00D00?n:0P000002003?o`<00000
0P00HOl00`000000D@3o0540o`050540o`030000003V0?l0iP3o00@000000P3o0;H00`000000o`1;
0?l0B`050?l0B`D000000`3o00000`000000o`0V0?l09P050?l09P<000001`3o0;H00`000000Z03o
0:P0o`020:P0o`D000001P00HOl2000000800?oQ0`000002003oRP030000000Co`004ol000D04ol0
00<0000009go002Mo`00100000020=Oo00030000003ob`00ol/000D0ol/000<000000?n3003oP`00
0`0000020?mX00030000003o@000od0000D0od001@0000040?lL00030000003o3`00o`l000D0o`l0
0P0000000`3oool000000?ooo`0>0?ooo`030000003oool0oooo0040oooo000F0?ooo`8000002@3o
ool200000080o`/00`0000020?l?00030000003o7000oa`000D0oa`000<000000?l`003o<0000`00
00020?m0008000001`3oJ005000000<0ol/000<000000=Oo003Go`001@3Go`03000000H04ol000<0
0000003oRP00ohX01@00ohX3000000H0067o0P0000040540o`@000001`3o0;H00`000000o`1;0?l0
B`0400000080o`0V00<000000?l0003o0000103o000200000080o`0V0`0000020?l0B`030000003o
0;H0o`2f00D0o`2f1@0000040540o`0300000000HOl0067o00D0067o0`000005003oRP030000000C
o`004ol000D04ol00`0000070=Oo00030000003ob`00ol/00080ol/01@0000060?mX00030000003o
@000od0000@000000P3o<0000`000000oa`00?lL00050?lL00030000003o3`00o`l000@000000P3o
2`000`000000oooo0000000>0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000003oool0
oooo00P0oooo0P0000060?l?00800000103o7004000000L0od000P0000020?mX00<000000P3oP`00
0`000000ol/00?o;00040?o;008000000P3Go`0300000080WOl000<0000001?o000Co`001@0Co`00
0`0000000?n:003oRP04000000800?oQ00<00000001Qo`00HOl01@00HOl5000000<0Z03o00<00000
0?l0]P3o0;H01@3o0;H3000000L0o`0V00<000000?l0003o00000P3o0005000000H0o`1;0P000002
0?l0]P<000000P3V0?l00`000000D@3o0540o`050540o`0300000000HOl0067o00@000000P00col0
0`0000000?n:003oRP04003oRP030000000Co`004ol000@000000P1So`000`000000eol00=Oo0005
0=Oo00D00000103oX@000`000000ofP00?mX00040?mX00<000001P3o<0000`000000oa`00?lL0005
0?lL00<000001P3o2`0010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo0040oooo000I
0?ooo`8000002@3oool00`000000o`l00?l?00050?l?00D000000`3o9@02000000L0od000`000006
0?n300030000003ob`00ol/000@0ol/00`00000609go00800000100Co`04000000L00?oQ00<00000
001Qo`00HOl010000002000Ho`030000002X0?l0Z03o00@0Z03o0P0000020?l0]P<000000P3o09<0
0`000000o`0V0?l09P050?l09PD00000103o02H00`000000o`1;0?l0B`050?l0B`<000001@3V0?l0
0`000000D@3o0540o`050540o`<000001`00col00`0000000?n:003oRP02003oRP@000001`1So`00
0`000000eol00=Oo000400000080on`000<000000?nQ003oX@00103oX@000`000000ofP00?mX0004
00000080odl000<000000?l`003o<0001@3o<0000`000000oa`00?lL000400000080oa@000<00000
0?l;003o2`00103o2`0200000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`01
0?ooo`006`3oool00`000000oooo0?ooo`070?ooo`8000000P3o3`0300000080oa@00P0000060?lU
008000000P3o@00300000080oe4000<000000?n3003oP`001@3oP`000`000000ol/00?o;00030000
0080oo8000<0000009go002Mo`001@2Mo`05000000<00?l^00<00000003oh@00on401@00on430000
00L001So00<000000:P0o`2X0?l00P2X0?l5000000H0o`2C0P0000020?l09P<000000P3o04/00`00
0000o`0V0?l09P050?l09P030000003o04/0o`1;00@000000P3o0;H00`000000iP3o0>H0o`040>H0
o`030000001A0?l0D@3o00@000000P00<Ol00`0000000<oo003?o`05003?o`D000000`00ob000`00
0000Hol006?o000506?o00<000001P3ok0000`000000oj400?nQ00040?nQ00<000001`3oC`000`00
0000oc000?l`00020?l`00D000001P3o50000`000000o`/00?l;000400000080o`L000@000000?oo
o`3oool000002`3oool00`000000oooo0?ooo`010?ooo`00703oool2000000T0oooo0P0000070?lD
00800000103o9@04000000H0oe400P0000040?n300@000001P3olP0200000080WOl00`00000206ko
000300000000obh00?l^00@00?l^0P000002003oh@<000000P00i?l00`00000001So000Ho`05000H
o`D0000010370?l00`000000o`2C0?l0T`050?l0T`<000001P3o04/00`000000o`0V0?l09P040?l0
9P<000001`3o0;H00`000000iP3o0>H0o`020>H0o`@000001`00<Ol00`0000000<oo003?o`040000
00800?n[00<00000003o8000ob001000ob000`000000Hol006?o000400000080]ol000<000000?o/
003ok0001@3ok0000`000000oj400?nQ000300000080ogX000<000000?m?003oC`001@3oC`050000
00@0ob<000<000000?lD003o5000103o5003000000L0o`L000<000000?ooo`000000303oool10000
0040oooo0@3oool001h0oooo00<000000?ooo`3oool01`3oool2000000L0oa@01@0000030?l_0003
0000003oD@00oe4000D0oe401@0000030?nM00030000003olP00oo8000D0oo800`00000606ko0080
00001000obh4000000H00>Co0P000002000Ho`<000000P010?l00`000000a`3o0<L0o`050<L0o`03
0000003o09<0o`2C00@000000P3o0;H00`000000o`1;0?l0B`050?l0B`030000003o02H0o`0V00<0
00000P3o09<00`000000o`2f0?l0]P050?l0]PD000000`1A0?l00`000000037o000ao`05000ao`<0
00001`00oj/00`0000000?lP003o8002003o80@000001`2go`000`000000on`00?o/00020?o/00D0
00001P3oNP000`000000odl00?m?000400000080ocT000<000000?lS003o8`001@3o8`000`000000
oa@00?lD000300000080o`d000<000000?l7003o1`001@3o1`02000000030?ooo`000000oooo00X0
oooo0@0000010?ooo`40oooo000O0?ooo`030000003oool0oooo00P0oooo0P0000020?lD00<00000
0P3o6P000`000000obl00?l_00040?l_008000000P3oD@0300000080of4000<000000?nM003oW@00
103oW@0200000080oo800`0000020>go00030000001^o`00K_l000D0K_l01@000003003oFP030000
0000i?l00>Co00D00>Co0`0000060040o`03000000370?l0a`3o00@0a`3o0`0000070?l0]P030000
003o04/0o`1;0080o`1;1@0000060?l0T`030000003o0;H0o`2f00@000000P2X0?l00`000000D@3o
0540o`040540o`8000000P00<Ol3000000800<oo00<00000003oZ`00oj/01@00oj/5000000<0C_l0
00<000000;Oo002go`001@2go`05000000@0ok8000<000000?mj003oNP00103oNP03000000L0ocT0
00<000000?lS003o8`000P3o8`05000000H0o`d000<000000?l7003o1`00100000001@3o10000000
0?ooo`3oool0000000X0oooo0@0000010?ooo`40oooo000P0?ooo`8000002P3oool2000000H0oaX0
00<000000?l_003o;`00103o;`03000000H0of400P0000040?nM00@000001P3]o`0200000080K_l0
0`00000204ko000300000000oeX00?mJ00@00?mJ0P000002003To`<000000P00col00`0000000@3o
0040o`050040o`03000000370?l0a`3o00<000000P2X0?l00`000000o`2f0?l0]P050?l0]PD00000
103o0;H00`000000o`2C0?l0T`040?l0T`<000001`2X0?l00`000000D@3o0540o`020540o`D00000
1P00col00`0000000?n[003oZ`04000000800?lP00<0000004ko001>o`00101>o`000`000000]ol0
0;Oo000400000080ooP000<000000?nb003o/P001@3o/P000`000000ogX00?mj000300000080oeL0
00<000000?li003o>@001@3o>@05000000@0oaL000<000000?l=003o3@00103o3@03000000H0o`@0
00@000000?ooo`3oool000002@3oool100000040oooo0@3oool00280oooo00<000000?ooo`3oool0
203oool00`000000oaX00?lJ00050?lJ00030000003o;`00obl000<000000P3o>0000`000000of40
0?mQ00050?mQ00D000000`3o/P000`000000kOl00>go00050>go00<000001P1>o`02000000@00?mJ
10000006003?o`80000010010?l4000000H0Z03o0P0000020?l0]P<000000P3V0?l00`000000o`2f
0?l0]P050?l0]P030000003o09<0o`2C00<000000P370?l00`000000Z03o0:P0o`050:P0o`D00000
1000HOl00`0000000<oo003?o`04003?o`<000001P00ob000`000000C_l004ko000404ko00<00000
1`3on0000`000000ok800?nb00020?nb00D000001P3oE`000`000000ocT00?li000400000080obH0
00<000000?lG003o5`00103o5`000`000000o`d00?l=000400000080o`P000<000000?l4003o1000
103o10001@000000oooo0?ooo`3oool0000000P0oooo0@0000010?ooo`40oooo000S0?ooo`800000
2@3oool2000000@0oaX0100000060?lh008000000P3oH@0300000080ofh000<000000?nb003o/P00
103o/P0200000080kOl00`0000020=Oo00030000001>o`00C_l000D0C_l01@000003003oJ@030000
0000col00<oo00D00<oo1@000003000Ho`030000002X0?l0Z03o00D0Z03o0`0000060>H0o`800000
103o0;H4000000H0a`3o0P0000020:P0o`<000000P006?l00`000000067o001Qo`05001Qo`030000
0000col00<oo00<000000P00ohX00`0000000?lP003o8005003o80030000001>o`00C_l000<00000
0P2go`000`000000ooP00?oh00050?oh00D00000103oP0000`000000oeL00?mG00040?mG00<00000
1P3o9P000`000000oaL00?lG00020?lG00D000001`3o20000`000000o`@00?l400020?l400<00000
0P3oool00`000000oooo0?ooo`060?ooo`4000000@3oool10?ooo`009@3oool00`000000oooo0?oo
o`080?ooo`@000000`3o7`000`000000ocP00?lh00050?lh00<000001P3oKP02000000@0ok801000
00060=Oo008000000P1>o`0300000080@ol000<00000003oJ@00ofT01000ofT2000000800<oo0`00
0002003To`03000000006?l001So00@001So0P0000020:P0o`<000000P1A0?l00`000000iP3o0>H0
o`050>H0o`D000000`2X0?l00`000000a`3o0<L0o`050<L0o`<000001P006?l00`000000067o001Q
o`02001Qo`D000001P00ohX00`0000000?lP003o8002003o80D000001P2go`000`000000ooP00?oh
000400000080ok8000<000000?n0003oP000103oP0000`000000oeL00?mG000400000080oc/000<0
00000?lV003o9P00103o9P05000000@0o`l000<000000?l8003o20001@3o2005000000<0o`8000@0
00000?ooo`3oool000001`3oool100000040oooo0@3oool002H0oooo0P0000090?ooo`030000003o
7`00oal000@0oal00P0000020?lh00<000000P3o@0000`000000ofh00?m^00050?m^00D000000`3o
`0000`000000eol00=Oo00050=Oo00<000001P13o`02000000@00?mY10000006003To`0300000000
6?l001So008001So1@0000060540o`030000003V0?l0iP3o00@000000P1A0?l00`000000Z03o0:P0
o`040:P0o`03000000370?l0a`3o00@000000P010?l00`00000001So000Ho`04000Ho`D000001000
on400`0000000?n:003oRP04003oRPD00000101So`000`000000]ol00;Oo00040;Oo00<000001`3o
/P000`000000oh000?n000020?n000@000001`3o>`000`000000obH00?lV000300000080oaT000<0
00000?l?003o3`001@3o3`000`000000o`P00?l8000400000080o`D000<000000?l2003o0P00103o
0P0010000000oooo0?ooo`0000070?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01`3o
ool2000000@0oal0100000060?m0008000000P3oKP0300000080ogL000<000000?o0003o`000103o
`00200000080eol00`0000020<oo000300000013o`00@ol000D0@ol01@000003003oFP0300000000
i?l00>Co00@00>Co1@000004001Qo`030000001A0?l0D@3o00@0D@3o0`0000070540o`030000002X
0?l0Z03o0080Z03o100000070040o`03000000006?l001So00<000000P00i?l00`0000000?oQ003o
h@05003oh@0300000000ohX00?n:00<000000P0Co`000`000000Hol006?o000506?o00030000002g
o`00]ol000<000000P3ok0000`000000ok800?nb00050?nb00D000000`3oE`000`000000oc/00?lk
00050?lk00<000001P3o6@000`000000o`l00?l?00020?l?00D000001P3o1@000`000000o`800?l2
00020?l200@000000P3oool00`000000oooo0?ooo`040?ooo`4000000@3oool002T0oooo00<00000
0?ooo`3oool0203oool4000000<0ob<00P0000050?m000@000001P3oM`02000000@0ol0010000006
0<oo008000000P13o`0300000080C_l000<00000003oFP00oeX01000oeX00`0000000>Co003To`03
000000800?oQ00<00000001Qo`00HOl01@00HOl00`000000D@3o0540o`0300000080037o00<00000
0540o`1A0?l01@1A0?l5000000<001So00<000000040o`010?l01@010?l3000000H00>Co0P000004
003oh@@000001P0Co`000`000000Hol006?o000206?o00D000001P3ok0000`000000ok800?nb0004
00000080ogX000<000000?mG003oE`00103oE`000`000000oc/00?lk000400000080obH000<00000
0?lI003o6@00103o6@05000000@0o`T000<000000?l5003o1@00103o1@05000000@0o`4000@00000
0?ooo`3oool000001@3oool100000040oooo000Z0?ooo`8000002@3oool00`000000ob<00?lS0005
0?lS00D000000`3oA@000`000000ogL00?mg00050?mg00D000000`3oa@000`000000col00<oo0005
0<oo00<000001P1>o`000`0000000?mJ003oFP02003oFP@000001P00on42000000@0067o10000006
000ao`8000000P1A0?l300000080067o00<00000000Ho`006?l010006?l2000000800@3o0`000002
003?o`0300000000i?l00>Co00D00>Co1@000003003o;P030000000Co`004ol000@04ol01@000004
0=Oo00800000103ok004000000L0ogX000<000000?mG003oE`000P3oE`04000000H0obH000<00000
0?lI003o6@00100000020?l?00030000003o2@00o`T000@0o`T000<000000?l5003o1@0010000002
0?l200030000003o0@00o`4000@0o`400P0000000`3oool000000?ooo`040?ooo`4000000@3oool0
02`0oooo00<000000?ooo`3oool01`3oool200000080ob<00`0000020?lV00030000003oA@00odD0
00@0odD00P0000020?mg00<000000P3oNP000`000000olD00?o500040?o5008000000P3?o`030000
0080eol000<0000004ko001>o`00101>o`05000000<00?l^00<00000003oh@00on401@00on450000
00<00<oo0P000005000ao`@000001P00HOl00`00000001So000Ho`02000Ho`D000001P00col00`00
00000>Co003To`04000000800?mJ00<00000003o;P00obh01000obh00`0000004ol001?o00030000
0080WOl000<000000=Oo003Go`001@3Go`05000000<0oj4000<000000?mj003oNP001@3oNP050000
00<0ocT000<000000?lV003o9P00103o9P03000000L0o`l000<000000?l9003o2@000P3o2@040000
00L0o`8000<000000?l1003o0@000`0000020?l000030000003oool0000000@0oooo0@0000010?oo
o`00;@3oool2000000T0oooo0P0000060?lV00800000103oA@04000000H0ogX00P0000040?o500@0
00001P3Go`000`000000C_l004ko000300000080K_l000<00000003o;P00obh01000obh200000080
0?oQ0`000002003oRP0300000000col00<oo00D00<oo1@000003003?o`0300000000HOl0067o00@0
067o1@000004003To`0300000000col00<oo00@00<oo0`000007003oFP0300000000obh00?l^0080
0?l^1000000609go00030000003Go`00eol000@000000P3ob`000`000000oj400?nQ00040?nQ0003
0000003oNP00ogX000@000000P3oC`000`000000ocT00?li00040?li00030000003o9P00obH000<0
00000P3o5`000`000000o`l00?l?00050?l?00D000000`3o1@000`000000o`800?l200050?l200<0
00001P3o00000`000000oooo000000030?ooo`4000000@3oool002l0oooo00<000000?ooo`3oool0
1`3oool00`000000obH00?lV00050?lV00D000000`3oA`000`000000ogX00?mj00050?mj00D00000
0`3o`002000000@0eol01000000606ko008000001000obh4000000H00?n:0P000002003?o`<00000
0P00oj/00`0000000<oo003?o`04003?o`0300000000HOl0067o00<000000P00on400`0000000>Co
003To`05003To`0300000000col00<oo00<000000P00ofT00`0000000?mJ003oFP05003oFPD00000
0`1^o`000`000000WOl009go000409go00<000001`3ob`000`000000oj400?nQ00020?nQ00@00000
1P3oC`000`000000ocT00?li00020?li00D000001P3o5`000`000000o`l00?l?000400000080o`P0
00<000000?l5003o1@00103o1@000`000000o`800?l2000400000080o`4000<000000?l0003o0000
103o0002000000050?ooo`000000oooo0?ooo`0000000@3oool00300oooo00<000000?ooo`3oool0
1`3oool200000080obH00`0000020?lW00030000003oA`00odL000@0odL00P0000020?mj00<00000
0P3oM`000`000000ol000?o000040?o000D000000`3]o`000`000000K_l006ko000506ko00D00000
0`0Co`000`0000000?n:003oRP05003oRP<000001P00oj/00`0000000<oo003?o`02003?o`@00000
1P00on42000000@00>Co10000006003oJ@0300000000oeX00?mJ00@000000P1>o`000`000000K_l0
06ko000406ko00030000002Mo`00WOl000<000000P3olP000`000000ol/00?o;00050?o;00D00000
0`3oJ0000`000000odl00?m?00040?m?00D00000103o8`02000000@0oaL0100000060?l800030000
003o1@00o`D00080o`D01@0000060?l100030000003o0000o`0000@00000103oool00`000000oooo
000000010?ooo`00<@3oool2000000T0oooo0P0000060?lW00800000103oA`04000000H0ogL000<0
00000?o0003o`0000`0000020?nb00030000003]o`00kOl000@0kOl00P00000206ko00<000000P2M
o`000`0000004ol001?o000401?o000300000000ohX00?n:00@000000P00ob000`0000000?n[003o
Z`04003oZ`D000000`00ohX00`0000000?oQ003oh@05003oh@D000000`00oeX2000000@00?mY1000
000704ko00030000001^o`00K_l00080K_l0100000060?ob00030000003ob`00ol/000@000000P3o
P`000`000000ofP00?mX00040?mX00030000003oC`00odl000<000000P3o<0000`000000ob<00?lS
00050?lS00D000000`3o3@000`000000o`P00?l800040?l800D00000103o0P000`000000o`400?l1
00040?l100<000002@3oool100000040oooo0@00000003<0oooo00<000000?ooo`3oool01`3oool0
0`000000obL00?lW00050?lW00D000000`3oA@000`000000ogL00?mg00040?mg00<000001P3o/P02
000000@0kOl01000000609go00030000000Co`004ol000804ol010000007003o800300000000oj/0
0?n[00<000000P00ob000`0000000?n:003oRP04003oRP8000000P00on43000000800?l^00<00000
003oFP00oeX01000oeX5000000<0@ol000<0000004ko001>o`001@1>o`05000000<0kOl00P000004
0?ob00@000001`3oP`000`000000ofP00?mX00020?mX00@000001P3o<0000`000000ob<00?lS0004
00000080oa@000<000000?l=003o3@00103o3@000`000000o`P00?l8000300000080o`@000<00000
0?l2003o0P00103o0P000`000000o`400?l10004000000`0oooo0@0000010?ooo`400000000d0?oo
o`800000203oool200000080obL00`0000020?lV00030000003oA@00odD000@0odD00P0000020?mg
008000000P3oKP000`000000ok800?nb00050?nb00D000000`3olP000`000000WOl009go000409go
00D000000`1So`02000000D00?lP10000006003o800300000000ohX00?n:00800?n:1@000006003o
;P0300000000oeX00?mJ00<000000P1>o`000`000000@ol004?o000404?o00030000001>o`00C_l0
00@000000P3Go`000`000000kOl00>go00040>go00D000000`3oW@000`000000oh<00?n300050?n3
00D000000`3o@0000`000000oc000?l`00040?l`00<000001P3o50000`000000o`d00?l=00020?l=
00D000001P3o10000`000000o`800?l200020?l200@000004@3oool200000000=P3oool00`000000
oooo0?ooo`070?ooo`8000001P3o9P02000000@0odD0100000050?m^008000000P3o/P0300000080
oid000<000000?ob003olP00103olP0200000080WOl00P0000020=Oo00030000001So`00Hol000D0
Hol01@00000304ko000300000000ob000?lP00@00?lP1@00000401?o008000001000obh4000000H0
C_l000<0000004?o0013o`000P13o`04000000L0eol000<000000>go003]o`000`0000020?nb0003
0000003oW@00oid000@0oid000<000000?n3003oP`00100000020?mA00030000003o@000od0000@0
od0000<000000?l`003o<0000`0000020?lL00030000003o5000oa@000@0oa@01@0000040?l70003
0000003o1000o`@000@0o`@01@00000D0?ooo`<00000000g0?ooo`800000203oool00`000000obH0
0?lV00050?lV00D000000`3o@002000000@0ofh0100000060?nM00800000103olP04000000D0eol0
0P00000206?o00<000000P2go`000`000000C_l004ko000404ko000300000000ob000?lP00<00000
0P1So`000`0000004ol001?o000501?o00D000000`1^o`000`000000C_l004ko000404ko00D00000
0`3?o`02000000@0eol01@0000060?nb00030000003oW@00oid00080oid0100000060?mA00030000
003o@000od000080od001@0000060?lL00030000003o5000oa@000<000000P3o2`000`000000o`L0
0?l700040?l700030000003o1000o`@000@000005@3oool4000000<0oooo000i0?ooo`030000003o
ool0oooo00H0oooo0P0000020?lV00<000000P3o8`000`000000od000?m000040?m000D000000`3o
H@000`000000oid00?nM00050?nM00D000000`3ob`02000000@0eol0100000060;Oo00030000001>
o`00C_l00080C_l01000000606?o008000000P0Co`0300000080WOl000<0000006ko001^o`00101^
o`000`000000C_l004ko000300000080eol000<000000<oo003?o`00103?o`05000000@0ol0000<0
00000?nb003o/P00103o/P05000000<0of4000<000000?mA003oD@00103oD@05000000@0obD000<0
00000?lL003o70000P3o7005000000H0o`/000<000000?l7003o1`000P3o1`04000001@0oooo1@00
00070?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`8000001P3o8`000`000000od000?m00003
00000080ocP000<000000?mQ003oH@00103oH@0200000080oid00`0000020?n300030000003ob`00
ol/000@0ol/01@0000030?o/00030000002go`00]ol000@0]ol01@0000030;Oo008000001@1So`04
000000H0WOl000<0000006ko001^o`000P1^o`04000000H0eol000<000000<oo003?o`000`000002
0?o500030000003o`000ol0000D0ol0000<000000?nb003o/P000`0000020?m^00030000003oH@00
of4000@0of4000<000000?mA003oD@000`0000020?l_00030000003o9@00obD000@0obD01@000004
0?l?00030000003o2`00o`/000@0o`/01@00000D0?ooo`@00000303oool003/0oooo0P0000080?oo
o`800000103o8`04000000H0ocP00P0000040?mQ00@000001P3oP`000`000000ol/00?o;00030000
0080oj4000<000000?o/003ok000103ok0000`000000]ol00;Oo000300000080ooP000<000000;Oo
002go`001@2go`05000000<0eol000<0000009go002Mo`00102Mo`05000000<0kOl00P0000040=Oo
00@000001P3oa@000`000000ol000?o000020?o000D000001P3oKP000`000000of400?mQ00020?mQ
00@000001P3o;`000`000000obD00?lU000300000080oa@000<000000?l?003o3`00103o3`000`00
0000o`/00?l;0004000001D0oooo1000000@0?ooo`00?@3oool00`000000oooo0?ooo`070?ooo`@0
00000`3o7`000`000000ocP00?lh00050?lh00D000000`3oD@02000000@0oh<0100000060?nQ0080
00000`3ok004000000H0ooP00P0000020;Oo00<000000P3ok0000`000000eol00=Oo00040=Oo0003
0000002Mo`00WOl000<000000P3olP000`000000kOl00>go00040>go00D000000`3o`0000`000000
olD00?o500040?o500D00000103oM`02000000@0ofh01P0000030?lh00800000103o;`04000000H0
oa@000<000000?l?003o3`000P3o3`04000001@0oooo1@00000D0?ooo`00?P3oool2000000T0oooo
00<000000?lO003o7`000`3o7`0200000080ocP00`0000020?l_00030000003oD@00oe4000@0oe40
1@0000030?mX00030000003oX@00oj4000D0oj40100000030?nb008000001@3on004000000H0on`0
00<000000=Oo003Go`000P3Go`04000000H0oo8000<000000>go003]o`000`0000020?nb00030000
003o`000ol0000@0ol0000<000000?o5003oa@000`0000020?mj00030000003oM`00ogL000D0ogL0
1@0000030?m000030000003o>000ocP000@0ocP01@0000030?lJ00800000103o5006000001@0oooo
1000000I0?ooo`00@03oool00`000000oooo0?ooo`070?ooo`8000000`3o7`04000000H0obl00P00
00020?mA008000000P3o@0000`000000ofP00?mX00040?mX008000000P3oX@0300000080ogX000<0
00000?nb003o/P00103o/P05000000<0ok8000<000000?o/003ok000103ok005000000<0ol/00P00
00040?ob00@000001P3o/P000`000000ol000?o000020?o000@000001P3oNP000`000000ogL00?mg
000400000080odD000<000000?m0003o@000103o@0000`000000ocP00?lh000300000080oal000<0
00000?lJ003o6P00103o6P05000001D0oooo1@00000M0?ooo`00@@3oool00`000000oooo0?ooo`08
0?ooo`<000000`3o6P02000000D0obl0100000050?m000800000103oJ004000000H0ogX000<00000
0?nb003o/P000`0000020?n000030000003o/P00ok8000@0ok8000<000000?o/003ok0000`000002
0?nQ00030000003ob`00ol/000@0ol/01@0000030?nM00030000003o/P00ok8000@0ok801@000003
0?mg00800000103oNP04000000H0odD000<000000?m0003o@0000P3o@005000000H0oal000<00000
0?lJ003o6P000`00000F0?ooo`@000008P3oool00480oooo0P0000090?ooo`030000003o6P00oaX0
00@0oaX01@0000030?lU00800000103o@006000000<0odl00P0000040?mj00@000001P3oP0000`00
0000ok800?nb00020?nb00@000001P3oX@000`000000ol/00?o;000300000080oh<000<000000?nM
003oW@00103oW@000`000000ok800?nb000300000080ofh000<000000?mg003oM`00103oM`050000
00<0odL000<000000?m5003oA@00103oA@05000000@0ob<000<000000?lO003o7`000P3o7`050000
01D0oooo1000000V0?ooo`00A03oool00`000000oooo0?ooo`070?ooo`030000003o6P00oaX000<0
00000P3o50000`000000obD00?lU00040?lU00D000000`3o<0000`000000odl00?m?00040?m?00D0
00000`3oE`02000000@0oh001P0000030?mj00800000103oX@04000000H0oh<000<000000?nM003o
W@000P3oW@04000000H0ofh000<000000?mg003oM`000`0000020?m500030000003oA`00odL000@0
odL000<000000?m5003oA@000`0000020?lV00030000003o8`00ob<000@0ob<01@00000E0?ooo`D0
0000:P3oool004D0oooo0P0000080?ooo`8000001P3o50000`000000obD00?lU000300000080oa`0
00<000000?l`003o<000103o<0000`000000odl00?m?000300000080ocT000<000000?mG003oE`00
103oE`05000000<0oeL000<000000?mj003oNP00103oNP05000000<0ofP00P0000040?n300H00000
0`3oH@02000000@0ofh0100000060?m500030000003oA`00odL00080odL0100000060?lV00030000
003o8`00ob<000<000005P3oool4000002l0oooo00170?ooo`030000003oool0oooo00H0oooo0P00
00040?lD00@000001P3o7002000000<0oc00100000060?li008000000P3oE`0200000080oc/000<0
00000?mG003oE`00103oE`000`000000ogX00?mj000300000080odl000<000000?mX003oJ000103o
J005000000<0oe4000<000000?mQ003oH@00103oH@05000000<0od000P0000040?m500H000000`3o
9`02000000@0obH01000000D0?ooo`D00000<`3oool004P0oooo0P0000080?ooo`@000000`3o3`00
0`000000oa`00?lL00050?lL00@000000`3o8`02000000D0ocT0100000050?lk008000000`3oE`04
000000H0odl00P0000020?mX008000000P3o@0000`000000oe400?mA00040?mA00030000003oH@00
of4000<000000P3o>0000`000000od000?m000040?m000D000000`3o9P000`000000obL00?lW0004
0?lW00D00000503oool4000003P0oooo001:0?ooo`030000003oool0oooo00L0oooo00<000000?l?
003o3`000`3o3`0200000080oa`00`0000020?lD00030000003o8`00ob<000@0ob<01@0000030?lV
00800000103o>`05000000<0ocT00P0000050?m?00@000001@3o@002000000<0oe40100000060?lh
00030000003o@000od0000<000000P3o8`000`000000obH00?lV00040?lV00030000003o9`00obL0
00<00000503oool5000003`0oooo001;0?ooo`030000003oool0oooo00L0oooo00<000000?l?003o
3`000P3o3`04000000H0oa@000<000000?lS003o8`000`0000020?lG00030000003o9P00obH000@0
obH01@0000030?lV00030000003o>@00ocT000@0ocT01@0000030?l`00800000103o@005000000<0
obl00P0000040?lh00@000001P3o8`000`000000obH00?lV00020?lV00@000004`3oool400000440
oooo001<0?ooo`800000203oool4000000<0o`/00P0000040?lD00@000001P3o5`000`000000obH0
0?lV000300000080oaT000<000000?lV003o9P00103o9P000`000000ocT00?li000300000080ob<0
00<000000?l`003o<000103o<005000000<0obD000<000000?l_003o;`000`3o;`05000000<0oal0
0P0000040?lS00H000004`3oool4000004D0oooo001>0?ooo`030000003oool0oooo00H0oooo0P00
00050?l;00D000000`3o3@02000000@0oaL0100000060?lI00030000003o9P00obH00080obH01000
00060?lS00030000003o<000oc0000<000000P3o70000`000000obD00?lU00040?lU00030000003o
;`00obl0008000000P3o6P000`000000oal00?lO00040?lO00D00000503oool5000004T0oooo001?
0?ooo`800000203oool5000000<0o`L000<000000?l=003o3@00103o3@04000000<0o`l00P000004
0?lI00H000000`3o5`02000000@0ob<0100000060?lL00030000003o9@00obD00080obD010000005
0?lJ00030000003o7`00oal000<000005@3oool4000004h0oooo001A0?ooo`030000003oool0oooo
00L0oooo00<000000?l7003o1`00103o1`000`000000o`d00?l=000300000080o`P000<000000?l?
003o3`00103o3`04000000<0o`l000<000000?lG003o5`00103o5`05000000<0oa@00P0000040?lL
00H000000`3o5002000000<0oaX01000000C0?ooo`D00000DP3oool00580oooo0P0000080?ooo`03
0000003o1`00o`L00080o`L0100000060?l800030000003o3`00o`l000<000000P3o2@000`000000
o`l00?l?00030?l?00030000003o5`00oaL000<000000P3o3@000`000000oa@00?lD00040?lD00D0
00000`3o3`02000000@0oa@01@00000C0?ooo`@00000E`3oool005@0oooo00<000000?ooo`3oool0
1P3oool4000000<0o`@00P0000040?l800@000001P3o2@0010000000o`l00?l?003o3`04000000H0
o`d000<000000?lD003o50000`0000020?l;00030000003o3`00o`l000@0o`l01@00000D0?ooo`@0
0000F`3oool005D0oooo00<000000?ooo`3oool01P3oool2000000@0o`@01P0000030?l500800000
103o2@05000000<0o`P00P0000040?l=00@000001P3o2`000`000000o`l00?l?0003000001@0oooo
1@00001O0?ooo`00EP3oool2000000P0oooo100000030?l200030000003o1@00o`D000@0o`D01@00
00030?l500800000103o2005000000<0o`L00P0000040?l;00@000004`3oool4000006@0oooo001H
0?ooo`030000003oool0oooo00L0oooo00<000000?l2003o0P000`3o0P0200000080o`D00P000002
0?l200030000003o1@00o`D000@0o`D01@0000030?l4008000000`3o1`0600000180oooo1@00001X
0?ooo`00F@3oool2000000P0oooo00<000000?l2003o0P000P3o0P04000000D0o`800P0000020?l5
008000000P3o0P000`000000o`@00?l400040?l400@00000503oool4000006d0oooo001K0?ooo`03
0000003oool0oooo00H0oooo100000030?l100800000103o0P04000000D0o`8000<000000?l4003o
10000`00000C0?ooo`D00000L@3oool005`0oooo00<000000?ooo`3oool01P3oool2000000@0o`40
1P0000030?l1008000000`3o0P0400000180oooo1000001f0?ooo`00G@3oool2000000P0oooo1000
00030?l000800000103o0@0500000180oooo1000001j0?ooo`00G`3oool00`000000oooo0?ooo`07
0?ooo`030000003o0000o`0000<0o`001@00000B0?ooo`D00000OP3oool00600oooo0P0000070?oo
o`8000000P3o0002000001<0oooo100000230?ooo`00HP3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0000000000100oooo1@0000270?ooo`00H`3oool2000000@0oooo00<000000?ooo`3o
ool03@3oool4000008`0oooo001U0?ooo`050000003oool0oooo0?ooo`0000002`3oool400000900
oooo001V0?ooo`040000003oool0oooo000000H0oooo1@00002D0?ooo`00I`3oool300000080oooo
1000002I0?ooo`00J@3oool3000009d0oooo0000\
\>"],
  ImageRangeCache->{{{0, 264.313}, {286.938, 0}} -> {0.0486402, \
-4.72903*^-05, 0.00324458, 0.00324458}}]
}, Open  ]],

Cell["\<\
Again, since the primitive graphics is immediately available to us, we can \
modify it The surfaces are actually contained in the second and fourth parts \
of the graphics. Here the shadow is moved to the bottom and then raised with \
DrawingTransform to just below the beginning of the main surface. Then the \
main surface is changed to a constant color wireframe so we can see through \
it. ColorMix from DrawingPaper is used for the ColorFunction.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(With[\[IndentingNewLine]{g1 = 
            ShadowPlot3D[
                E\^\(-\((x\^2 + y\^2)\)\), {x, \(-2\), 2}, {y, \(-2\), 2}, 
                ShadowPosition \[Rule] \(-1\), PlotPoints \[Rule] 25, 
                ColorFunction \[Rule] ColorMix[Cadet, PermanentRedViolet]] // 
              DrawGraphics3D}, \[IndentingNewLine]Draw3DItems[\
\[IndentingNewLine]{\((g1\[LeftDoubleBracket]2\[RightDoubleBracket] /. 
                  RGBColor[__] \[Rule] Melon)\) // 
              UseWireFrame, \[IndentingNewLine]EdgeForm[], 
            g1\[LeftDoubleBracket]4\[RightDoubleBracket] /. 
              DrawingTransform3D[#1 &, #2 &, #3 + 
                    0.45 &]}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
              1}, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Lighting \[Rule] 
            False, \[IndentingNewLine]PlotRange \[Rule] 
            All, \[IndentingNewLine]Background \[Rule] 
            CyanWhite]\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[228]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.878 1 1 r
MFill
% Scaling calculations
-0.0567234 1.16608 4.36391e-017 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.373 .619 .627 r
.41157 .57082 m .42216 .58164 L .44004 .57579 L F
.42953 .56489 m .44004 .57579 L .45804 .56991 L F
.41157 .57082 m .44004 .57579 L .42953 .56489 L F
.89 .66 .41 r
.5 Mabswid
[ ] 0 setdash
.42156 .59932 m
.43954 .59362 L
s
.41091 .58867 m
.42156 .59932 L
s
.373 .619 .627 r
.40084 .55985 m .41157 .57082 L .42953 .56489 L F
.44761 .55893 m .45804 .56991 L .47617 .56398 L F
.42953 .56489 m .45804 .56991 L .44761 .55893 L F
.89 .66 .41 r
.43954 .59362 m
.45764 .58796 L
s
.42896 .58299 m
.43954 .59362 L
s
.373 .619 .627 r
.41888 .55385 m .42953 .56489 L .44761 .55893 L F
.40084 .55985 m .42953 .56489 L .41888 .55385 L F
.374 .618 .626 r
.46583 .55292 m .47617 .56398 L .49443 .55801 L F
.373 .619 .627 r
.44761 .55893 m .47617 .56398 L .46583 .55292 L F
.89 .66 .41 r
.42896 .58299 m
.41091 .58867 L
s
.40011 .57795 m
.41091 .58867 L
s
.45764 .58796 m
.47587 .58236 L
s
.44714 .57741 m
.45764 .58796 L
s
.373 .619 .627 r
.38998 .54874 m .40084 .55985 L .41888 .55385 L F
.374 .618 .626 r
.43705 .54781 m .44761 .55893 L .46583 .55292 L F
.373 .619 .627 r
.41888 .55385 m .44761 .55893 L .43705 .54781 L F
.375 .617 .626 r
.48417 .54687 m .49443 .55801 L .51282 .552 L F
.374 .618 .626 r
.46583 .55292 m .49443 .55801 L .48417 .54687 L F
.89 .66 .41 r
.44714 .57741 m
.42896 .58299 L
s
.41823 .57236 m
.42896 .58299 L
s
.47587 .58236 m
.49424 .57686 L
s
.46545 .57199 m
.47587 .58236 L
s
.374 .618 .626 r
.40809 .54266 m .41888 .55385 L .43705 .54781 L F
.373 .619 .627 r
.38998 .54874 m .41888 .55385 L .40809 .54266 L F
.375 .617 .625 r
.45534 .54172 m .46583 .55292 L .48417 .54687 L F
.374 .618 .626 r
.43705 .54781 m .46583 .55292 L .45534 .54172 L F
.376 .616 .625 r
.50265 .54078 m .51282 .552 L .53135 .54594 L F
.375 .617 .626 r
.48417 .54687 m .51282 .552 L .50265 .54078 L F
.89 .66 .41 r
.41823 .57236 m
.40011 .57795 L
s
.38916 .56719 m
.40011 .57795 L
s
.46545 .57199 m
.44714 .57741 L
s
.43649 .56698 m
.44714 .57741 L
s
.374 .618 .626 r
.37896 .53748 m .38998 .54874 L .40809 .54266 L F
.375 .617 .625 r
.42634 .53654 m .43705 .54781 L .45534 .54172 L F
.374 .618 .626 r
.40809 .54266 m .43705 .54781 L .42634 .53654 L F
.89 .66 .41 r
.49424 .57686 m
.51274 .57147 L
s
.4839 .56679 m
.49424 .57686 L
s
.377 .615 .624 r
.47377 .53559 m .48417 .54687 L .50265 .54078 L F
.375 .617 .625 r
.45534 .54172 m .48417 .54687 L .47377 .53559 L F
.377 .615 .624 r
.52125 .53464 m .53135 .54594 L .55 .53984 L F
.376 .616 .625 r
.50265 .54078 m .53135 .54594 L .52125 .53464 L F
.89 .66 .41 r
.43649 .56698 m
.41823 .57236 L
s
.40735 .56178 m
.41823 .57236 L
s
.375 .617 .625 r
.39716 .53132 m .40809 .54266 L .42634 .53654 L F
.374 .618 .626 r
.37896 .53748 m .40809 .54266 L .39716 .53132 L F
.89 .66 .41 r
.4839 .56679 m
.46545 .57199 L
s
.45488 .5619 m
.46545 .57199 L
s
.377 .615 .624 r
.44472 .53037 m .45534 .54172 L .47377 .53559 L F
.375 .617 .625 r
.42634 .53654 m .45534 .54172 L .44472 .53037 L F
.89 .66 .41 r
.51274 .57147 m
.53138 .56622 L
s
.50248 .56184 m
.51274 .57147 L
s
.379 .613 .623 r
.49233 .52942 m .50265 .54078 L .52125 .53464 L F
.377 .615 .624 r
.47377 .53559 m .50265 .54078 L .49233 .52942 L F
.379 .613 .623 r
.54 .52846 m .55 .53984 L .56879 .5337 L F
.377 .615 .624 r
.52125 .53464 m .55 .53984 L .54 .52846 L F
.89 .66 .41 r
.40735 .56178 m
.38916 .56719 L
s
.37805 .55643 m
.38916 .56719 L
s
.375 .617 .626 r
.36781 .52607 m .37896 .53748 L .39716 .53132 L F
.89 .66 .41 r
.45488 .5619 m
.43649 .56698 L
s
.42568 .55674 m
.43649 .56698 L
s
.377 .615 .624 r
.41549 .52512 m .42634 .53654 L .44472 .53037 L F
.375 .617 .625 r
.39716 .53132 m .42634 .53654 L .41549 .52512 L F
.89 .66 .41 r
.50248 .56184 m
.4839 .56679 L
s
.4734 .55724 m
.4839 .56679 L
s
.38 .612 .622 r
.46323 .52416 m .47377 .53559 L .49233 .52942 L F
.377 .615 .624 r
.44472 .53037 m .47377 .53559 L .46323 .52416 L F
.89 .66 .41 r
.53138 .56622 m
.55016 .56108 L
s
.52122 .55718 m
.53138 .56622 L
s
.382 .611 .621 r
.51103 .5232 m .52125 .53464 L .54 .52846 L F
.379 .613 .623 r
.49233 .52942 m .52125 .53464 L .51103 .5232 L F
.381 .612 .621 r
.55887 .52224 m .56879 .5337 L .58771 .52751 L F
.379 .613 .623 r
.54 .52846 m .56879 .5337 L .55887 .52224 L F
.89 .66 .41 r
.42568 .55674 m
.40735 .56178 L
s
.39632 .55132 m
.40735 .56178 L
s
.377 .615 .624 r
.38608 .51983 m .39716 .53132 L .41549 .52512 L F
.375 .617 .626 r
.36781 .52607 m .39716 .53132 L .38608 .51983 L F
.89 .66 .41 r
.4734 .55724 m
.45488 .5619 L
s
.44413 .55225 m
.45488 .5619 L
s
.38 .612 .622 r
.43396 .51887 m .44472 .53037 L .46323 .52416 L F
.377 .615 .624 r
.41549 .52512 m .44472 .53037 L .43396 .51887 L F
.384 .609 .619 r
.48188 .5179 m .49233 .52942 L .51103 .5232 L F
.38 .612 .622 r
.46323 .52416 m .49233 .52942 L .48188 .5179 L F
.89 .66 .41 r
.52122 .55718 m
.50248 .56184 L
s
.49207 .55307 m
.50248 .56184 L
s
.385 .608 .619 r
.52986 .51693 m .54 .52846 L .55887 .52224 L F
.382 .611 .621 r
.51103 .5232 m .54 .52846 L .52986 .51693 L F
.89 .66 .41 r
.55016 .56108 m
.5691 .556 L
s
.5401 .55275 m
.55016 .56108 L
s
.383 .61 .62 r
.57789 .51597 m .58771 .52751 L .60677 .52128 L F
.381 .612 .621 r
.55887 .52224 m .58771 .52751 L .57789 .51597 L F
.89 .66 .41 r
.39632 .55132 m
.37805 .55643 L
s
.36678 .54569 m
.37805 .55643 L
s
.376 .616 .625 r
.3565 .51451 m .36781 .52607 L .38608 .51983 L F
.89 .66 .41 r
.44413 .55225 m
.42568 .55674 L
s
.4147 .54682 m
.42568 .55674 L
s
.38 .612 .622 r
.4045 .51354 m .41549 .52512 L .43396 .51887 L F
.377 .615 .624 r
.38608 .51983 m .41549 .52512 L .4045 .51354 L F
.385 .608 .618 r
.45255 .51257 m .46323 .52416 L .48188 .5179 L F
.38 .612 .622 r
.43396 .51887 m .46323 .52416 L .45255 .51257 L F
.89 .66 .41 r
.49207 .55307 m
.4734 .55724 L
s
.46273 .54847 m
.4734 .55724 L
s
.388 .605 .616 r
.50066 .5116 m .51103 .5232 L .52986 .51693 L F
.384 .609 .619 r
.48188 .5179 m .51103 .5232 L .50066 .5116 L F
.388 .605 .616 r
.54882 .51063 m .55887 .52224 L .57789 .51597 L F
.385 .608 .619 r
.52986 .51693 m .55887 .52224 L .54882 .51063 L F
.89 .66 .41 r
.5401 .55275 m
.52122 .55718 L
s
.51089 .54942 m
.52122 .55718 L
s
.384 .609 .619 r
.59704 .50965 m .60677 .52128 L .62597 .515 L F
.383 .61 .62 r
.57789 .51597 m .60677 .52128 L .59704 .50965 L F
.89 .66 .41 r
.5691 .556 m
.58818 .55088 L
s
.55915 .54847 m
.5691 .556 L
s
.4147 .54682 m
.39632 .55132 L
s
.38511 .54101 m
.39632 .55132 L
s
.379 .613 .623 r
.37486 .50819 m .38608 .51983 L .4045 .51354 L F
.376 .616 .625 r
.3565 .51451 m .38608 .51983 L .37486 .50819 L F
.385 .608 .618 r
.42305 .50721 m .43396 .51887 L .45255 .51257 L F
.38 .612 .622 r
.4045 .51354 m .43396 .51887 L .42305 .50721 L F
.89 .66 .41 r
.46273 .54847 m
.44413 .55225 L
s
.43321 .54322 m
.44413 .55225 L
s
.391 .602 .614 r
.47129 .50623 m .48188 .5179 L .50066 .5116 L F
.385 .608 .618 r
.45255 .51257 m .48188 .5179 L .47129 .50623 L F
.393 .6 .612 r
.51958 .50525 m .52986 .51693 L .54882 .51063 L F
.388 .605 .616 r
.50066 .5116 m .52986 .51693 L .51958 .50525 L F
.89 .66 .41 r
.51089 .54942 m
.49207 .55307 L
s
.48147 .54556 m
.49207 .55307 L
s
.391 .602 .614 r
.56793 .50427 m .57789 .51597 L .59704 .50965 L F
.388 .605 .616 r
.54882 .51063 m .57789 .51597 L .56793 .50427 L F
.385 .608 .618 r
.61634 .50329 m .62597 .515 L .64531 .50867 L F
.384 .609 .619 r
.59704 .50965 m .62597 .515 L .61634 .50329 L F
.89 .66 .41 r
.38511 .54101 m
.36678 .54569 L
s
.35535 .53496 m
.36678 .54569 L
s
.55915 .54847 m
.5401 .55275 L
s
.52989 .54624 m
.5401 .55275 L
s
.377 .615 .624 r
.34503 .5028 m .3565 .51451 L .37486 .50819 L F
.89 .66 .41 r
.58818 .55088 m
.60742 .54561 L
s
.57837 .54416 m
.58818 .55088 L
s
.384 .609 .619 r
.39335 .50181 m .4045 .51354 L .42305 .50721 L F
.379 .613 .623 r
.37486 .50819 m .4045 .51354 L .39335 .50181 L F
.89 .66 .41 r
.43321 .54322 m
.4147 .54682 L
s
.40354 .53729 m
.4147 .54682 L
s
.392 .601 .614 r
.44173 .50083 m .45255 .51257 L .47129 .50623 L F
.385 .608 .618 r
.42305 .50721 m .45255 .51257 L .44173 .50083 L F
.398 .595 .609 r
.49016 .49984 m .50066 .5116 L .51958 .50525 L F
.391 .602 .614 r
.47129 .50623 m .50066 .5116 L .49016 .49984 L F
.398 .595 .609 r
.53864 .49886 m .54882 .51063 L .56793 .50427 L F
.393 .6 .612 r
.51958 .50525 m .54882 .51063 L .53864 .49886 L F
.89 .66 .41 r
.48147 .54556 m
.46273 .54847 L
s
.45187 .54079 m
.46273 .54847 L
s
.393 .6 .612 r
.58718 .49787 m .59704 .50965 L .61634 .50329 L F
.391 .602 .614 r
.56793 .50427 m .59704 .50965 L .58718 .49787 L F
.385 .607 .618 r
.63577 .49688 m .64531 .50867 L .66479 .5023 L F
.385 .608 .618 r
.61634 .50329 m .64531 .50867 L .63577 .49688 L F
.89 .66 .41 r
.52989 .54624 m
.51089 .54942 L
s
.50039 .54356 m
.51089 .54942 L
s
.382 .611 .621 r
.36348 .49638 m .37486 .50819 L .39335 .50181 L F
.377 .615 .624 r
.34503 .5028 m .37486 .50819 L .36348 .49638 L F
.89 .66 .41 r
.40354 .53729 m
.38511 .54101 L
s
.37372 .53087 m
.38511 .54101 L
s
.60742 .54561 m
.6268 .54008 L
s
.59774 .53961 m
.60742 .54561 L
s
.57837 .54416 m
.55915 .54847 L
s
.54907 .54334 m
.55915 .54847 L
s
.391 .602 .614 r
.41199 .49539 m .42305 .50721 L .44173 .50083 L F
.384 .609 .619 r
.39335 .50181 m .42305 .50721 L .41199 .49539 L F
.4 .593 .607 r
.46055 .4944 m .47129 .50623 L .49016 .49984 L F
.392 .601 .614 r
.44173 .50083 m .47129 .50623 L .46055 .4944 L F
.406 .588 .603 r
.50917 .49341 m .51958 .50525 L .53864 .49886 L F
.398 .595 .609 r
.49016 .49984 m .51958 .50525 L .50917 .49341 L F
.89 .66 .41 r
.45187 .54079 m
.43321 .54322 L
s
.4221 .53494 m
.43321 .54322 L
s
.403 .59 .605 r
.55784 .49241 m .56793 .50427 L .58718 .49787 L F
.398 .595 .609 r
.53864 .49886 m .56793 .50427 L .55784 .49241 L F
.395 .598 .611 r
.60657 .49142 m .61634 .50329 L .63577 .49688 L F
.393 .6 .612 r
.58718 .49787 m .61634 .50329 L .60657 .49142 L F
.89 .66 .41 r
.37372 .53087 m
.35535 .53496 L
s
.34375 .52424 m
.35535 .53496 L
s
.379 .613 .623 r
.33342 .49092 m .34503 .5028 L .36348 .49638 L F
.385 .608 .618 r
.65535 .49042 m .66479 .5023 L .68442 .49589 L F
.385 .607 .618 r
.63577 .49688 m .66479 .5023 L .65535 .49042 L F
.89 .66 .41 r
.50039 .54356 m
.48147 .54556 L
s
.47068 .53976 m
.48147 .54556 L
s
.388 .605 .616 r
.38206 .48992 m .39335 .50181 L .41199 .49539 L F
.382 .611 .621 r
.36348 .49638 m .39335 .50181 L .38206 .48992 L F
.4 .593 .607 r
.43076 .48892 m .44173 .50083 L .46055 .4944 L F
.391 .602 .614 r
.41199 .49539 m .44173 .50083 L .43076 .48892 L F
.89 .66 .41 r
.6268 .54008 m
.64632 .53417 L
s
.61727 .53461 m
.6268 .54008 L
s
.54907 .54334 m
.52989 .54624 L
s
.5195 .54237 m
.52989 .54624 L
s
.4221 .53494 m
.40354 .53729 L
s
.39219 .52818 m
.40354 .53729 L
s
.59774 .53961 m
.57837 .54416 L
s
.56843 .54043 m
.57837 .54416 L
s
.411 .582 .599 r
.47951 .48793 m .49016 .49984 L .50917 .49341 L F
.4 .593 .607 r
.46055 .4944 m .49016 .49984 L .47951 .48793 L F
.414 .579 .597 r
.52832 .48692 m .53864 .49886 L .55784 .49241 L F
.406 .588 .603 r
.50917 .49341 m .53864 .49886 L .52832 .48692 L F
.408 .586 .602 r
.57718 .48592 m .58718 .49787 L .60657 .49142 L F
.403 .59 .605 r
.55784 .49241 m .58718 .49787 L .57718 .48592 L F
.395 .598 .611 r
.6261 .48492 m .63577 .49688 L .65535 .49042 L F
.60657 .49142 m .63577 .49688 L .6261 .48492 L F
.89 .66 .41 r
.47068 .53976 m
.45187 .54079 L
s
.44079 .53441 m
.45187 .54079 L
s
.385 .608 .619 r
.35194 .48442 m .36348 .49638 L .38206 .48992 L F
.379 .613 .623 r
.33342 .49092 m .36348 .49638 L .35194 .48442 L F
.384 .609 .619 r
.67507 .48392 m .68442 .49589 L .70419 .48942 L F
.385 .608 .618 r
.65535 .49042 m .68442 .49589 L .67507 .48392 L F
.398 .595 .609 r
.40078 .48341 m .41199 .49539 L .43076 .48892 L F
.388 .605 .616 r
.38206 .48992 m .41199 .49539 L .40078 .48341 L F
.89 .66 .41 r
.39219 .52818 m
.37372 .53087 L
s
.36216 .52087 m
.37372 .53087 L
s
.413 .58 .598 r
.44967 .48241 m .46055 .4944 L .47951 .48793 L F
.4 .593 .607 r
.43076 .48892 m .46055 .4944 L .44967 .48241 L F
.89 .66 .41 r
.64632 .53417 m
.66597 .52784 L
s
.63694 .52896 m
.64632 .53417 L
s
.424 .57 .59 r
.49861 .4814 m .50917 .49341 L .52832 .48692 L F
.411 .582 .599 r
.47951 .48793 m .50917 .49341 L .49861 .4814 L F
.89 .66 .41 r
.5195 .54237 m
.50039 .54356 L
s
.48967 .54023 m
.50039 .54356 L
s
.61727 .53461 m
.59774 .53961 L
s
.58797 .53714 m
.59774 .53961 L
s
.422 .571 .591 r
.54761 .48039 m .55784 .49241 L .57718 .48592 L F
.414 .579 .597 r
.52832 .48692 m .55784 .49241 L .54761 .48039 L F
.89 .66 .41 r
.56843 .54043 m
.54907 .54334 L
s
.53882 .54169 m
.54907 .54334 L
s
.41 .583 .6 r
.59667 .47938 m .60657 .49142 L .6261 .48492 L F
.408 .586 .602 r
.57718 .48592 m .60657 .49142 L .59667 .47938 L F
.89 .66 .41 r
.44079 .53441 m
.4221 .53494 L
s
.41077 .52748 m
.4221 .53494 L
s
.381 .612 .621 r
.32164 .47888 m .33342 .49092 L .35194 .48442 L F
.395 .598 .611 r
.64578 .47837 m .65535 .49042 L .67507 .48392 L F
.6261 .48492 m .65535 .49042 L .64578 .47837 L F
.89 .66 .41 r
.36216 .52087 m
.34375 .52424 L
s
.33197 .51346 m
.34375 .52424 L
s
.393 .6 .612 r
.37061 .47787 m .38206 .48992 L .40078 .48341 L F
.385 .608 .619 r
.35194 .48442 m .38206 .48992 L .37061 .47787 L F
.383 .61 .62 r
.69495 .47736 m .70419 .48942 L .72411 .48291 L F
.384 .609 .619 r
.67507 .48392 m .70419 .48942 L .69495 .47736 L F
.411 .582 .599 r
.41963 .47686 m .43076 .48892 L .44967 .48241 L F
.398 .595 .609 r
.40078 .48341 m .43076 .48892 L .41963 .47686 L F
.429 .565 .586 r
.46871 .47584 m .47951 .48793 L .49861 .4814 L F
.413 .58 .598 r
.44967 .48241 m .47951 .48793 L .46871 .47584 L F
.89 .66 .41 r
.66597 .52784 m
.68574 .52108 L
s
.65673 .52255 m
.66597 .52784 L
s
.437 .558 .58 r
.51785 .47483 m .52832 .48692 L .54761 .48039 L F
.424 .57 .59 r
.49861 .4814 m .52832 .48692 L .51785 .47483 L F
.89 .66 .41 r
.48967 .54023 m
.47068 .53976 L
s
.45964 .53603 m
.47068 .53976 L
s
.41077 .52748 m
.39219 .52818 L
s
.38064 .51942 m
.39219 .52818 L
s
.429 .565 .586 r
.56705 .47381 m .57718 .48592 L .59667 .47938 L F
.422 .571 .591 r
.54761 .48039 m .57718 .48592 L .56705 .47381 L F
.89 .66 .41 r
.63694 .52896 m
.61727 .53461 L
s
.60768 .53308 m
.61727 .53461 L
s
.411 .582 .599 r
.6163 .4728 m .6261 .48492 L .64578 .47837 L F
.41 .583 .6 r
.59667 .47938 m .6261 .48492 L .6163 .4728 L F
.388 .605 .616 r
.34025 .47229 m .35194 .48442 L .37061 .47787 L F
.381 .612 .621 r
.32164 .47888 m .35194 .48442 L .34025 .47229 L F
.393 .6 .612 r
.6656 .47178 m .67507 .48392 L .69495 .47736 L F
.395 .598 .611 r
.64578 .47837 m .67507 .48392 L .6656 .47178 L F
.89 .66 .41 r
.53882 .54169 m
.5195 .54237 L
s
.50889 .54203 m
.5195 .54237 L
s
.406 .588 .603 r
.38941 .47127 m .40078 .48341 L .41963 .47686 L F
.393 .6 .612 r
.37061 .47787 m .40078 .48341 L .38941 .47127 L F
.89 .66 .41 r
.58797 .53714 m
.56843 .54043 L
s
.55835 .54105 m
.56843 .54043 L
s
.381 .612 .621 r
.71496 .47076 m .72411 .48291 L .74417 .47635 L F
.383 .61 .62 r
.69495 .47736 m .72411 .48291 L .71496 .47076 L F
.429 .565 .586 r
.43863 .47025 m .44967 .48241 L .46871 .47584 L F
.411 .582 .599 r
.41963 .47686 m .44967 .48241 L .43863 .47025 L F
.89 .66 .41 r
.38064 .51942 m
.36216 .52087 L
s
.35041 .5109 m
.36216 .52087 L
s
.447 .547 .573 r
.48791 .46923 m .49861 .4814 L .51785 .47483 L F
.429 .565 .586 r
.46871 .47584 m .49861 .4814 L .48791 .46923 L F
.89 .66 .41 r
.45964 .53603 m
.44079 .53441 L
s
.42947 .52942 m
.44079 .53441 L
s
.68574 .52108 m
.70564 .51395 L
s
.67663 .51539 m
.68574 .52108 L
s
.449 .546 .571 r
.53724 .46821 m .54761 .48039 L .56705 .47381 L F
.437 .558 .58 r
.51785 .47483 m .54761 .48039 L .53724 .46821 L F
.434 .561 .583 r
.58663 .46719 m .59667 .47938 L .6163 .4728 L F
.429 .565 .586 r
.56705 .47381 m .59667 .47938 L .58663 .46719 L F
.383 .61 .62 r
.3097 .46667 m .32164 .47888 L .34025 .47229 L F
.41 .583 .6 r
.63607 .46616 m .64578 .47837 L .6656 .47178 L F
.411 .582 .599 r
.6163 .4728 m .64578 .47837 L .63607 .46616 L F
.89 .66 .41 r
.65673 .52255 m
.63694 .52896 L
s
.62753 .52791 m
.63694 .52896 L
s
.398 .595 .609 r
.359 .46565 m .37061 .47787 L .38941 .47127 L F
.388 .605 .616 r
.34025 .47229 m .37061 .47787 L .359 .46565 L F
.89 .66 .41 r
.35041 .5109 m
.33197 .51346 L
s
.32002 .50253 m
.33197 .51346 L
s
.391 .602 .614 r
.68557 .46514 m .69495 .47736 L .71496 .47076 L F
.393 .6 .612 r
.6656 .47178 m .69495 .47736 L .68557 .46514 L F
.424 .57 .59 r
.40836 .46462 m .41963 .47686 L .43863 .47025 L F
.406 .588 .603 r
.38941 .47127 m .41963 .47686 L .40836 .46462 L F
.89 .66 .41 r
.42947 .52942 m
.41077 .52748 L
s
.39922 .52073 m
.41077 .52748 L
s
.50889 .54203 m
.48967 .54023 L
s
.4787 .53996 m
.48967 .54023 L
s
.379 .613 .623 r
.73513 .46411 m .74417 .47635 L .76438 .46974 L F
.381 .612 .621 r
.71496 .47076 m .74417 .47635 L .73513 .46411 L F
.451 .544 .57 r
.45777 .4636 m .46871 .47584 L .48791 .46923 L F
.429 .565 .586 r
.43863 .47025 m .46871 .47584 L .45777 .4636 L F
.89 .66 .41 r
.70564 .51395 m
.72566 .50654 L
s
.69665 .50756 m
.70564 .51395 L
s
.60768 .53308 m
.58797 .53714 L
s
.57809 .5398 m
.58797 .53714 L
s
.467 .529 .558 r
.50724 .46257 m .51785 .47483 L .53724 .46821 L F
.447 .547 .573 r
.48791 .46923 m .51785 .47483 L .50724 .46257 L F
.89 .66 .41 r
.55835 .54105 m
.53882 .54169 L
s
.52836 .5447 m
.53882 .54169 L
s
.46 .536 .564 r
.55677 .46154 m .56705 .47381 L .58663 .46719 L F
.449 .546 .571 r
.53724 .46821 m .56705 .47381 L .55677 .46154 L F
.435 .559 .581 r
.60635 .46051 m .6163 .4728 L .63607 .46616 L F
.434 .561 .583 r
.58663 .46719 m .6163 .4728 L .60635 .46051 L F
.89 .66 .41 r
.39922 .52073 m
.38064 .51942 L
s
.36889 .51085 m
.38064 .51942 L
s
.391 .602 .614 r
.3284 .45999 m .34025 .47229 L .359 .46565 L F
.383 .61 .62 r
.3097 .46667 m .34025 .47229 L .3284 .45999 L F
.408 .586 .602 r
.656 .45948 m .6656 .47178 L .68557 .46514 L F
.41 .583 .6 r
.63607 .46616 m .6656 .47178 L .656 .45948 L F
.89 .66 .41 r
.67663 .51539 m
.65673 .52255 L
s
.64749 .52143 m
.65673 .52255 L
s
.414 .579 .597 r
.37789 .45896 m .38941 .47127 L .40836 .46462 L F
.398 .595 .609 r
.359 .46565 m .38941 .47127 L .37789 .45896 L F
.388 .605 .616 r
.7057 .45844 m .71496 .47076 L .73513 .46411 L F
.391 .602 .614 r
.68557 .46514 m .71496 .47076 L .7057 .45844 L F
.447 .547 .573 r
.42744 .45793 m .43863 .47025 L .45777 .4636 L F
.424 .57 .59 r
.40836 .46462 m .43863 .47025 L .42744 .45793 L F
.89 .66 .41 r
.4787 .53996 m
.45964 .53603 L
s
.44833 .53452 m
.45964 .53603 L
s
.377 .615 .624 r
.75545 .45741 m .76438 .46974 L .78475 .46308 L F
.379 .613 .623 r
.73513 .46411 m .76438 .46974 L .75545 .45741 L F
.477 .519 .551 r
.47706 .45689 m .48791 .46923 L .50724 .46257 L F
.451 .544 .57 r
.45777 .4636 m .48791 .46923 L .47706 .45689 L F
.89 .66 .41 r
.72566 .50654 m
.74582 .49897 L
s
.71676 .49927 m
.72566 .50654 L
s
.36889 .51085 m
.35041 .5109 L
s
.33848 .50078 m
.35041 .5109 L
s
.485 .511 .545 r
.52672 .45586 m .53724 .46821 L .55677 .46154 L F
.467 .529 .558 r
.50724 .46257 m .53724 .46821 L .52672 .45586 L F
.57645 .45482 m .58663 .46719 L .60635 .46051 L F
.46 .536 .564 r
.55677 .46154 m .58663 .46719 L .57645 .45482 L F
.89 .66 .41 r
.62753 .52791 m
.60768 .53308 L
s
.59802 .53727 m
.60768 .53308 L
s
.384 .609 .619 r
.2976 .4543 m .3097 .46667 L .3284 .45999 L F
.434 .561 .583 r
.62623 .45378 m .63607 .46616 L .656 .45948 L F
.435 .559 .581 r
.60635 .46051 m .63607 .46616 L .62623 .45378 L F
.403 .59 .605 r
.34723 .45326 m .359 .46565 L .37789 .45896 L F
.391 .602 .614 r
.3284 .45999 m .359 .46565 L .34723 .45326 L F
.89 .66 .41 r
.69665 .50756 m
.67663 .51539 L
s
.66755 .51364 m
.67663 .51539 L
s
.44833 .53452 m
.42947 .52942 L
s
.41789 .52568 m
.42947 .52942 L
s
.403 .59 .605 r
.67607 .45274 m .68557 .46514 L .7057 .45844 L F
.408 .586 .602 r
.656 .45948 m .68557 .46514 L .67607 .45274 L F
.89 .66 .41 r
.52836 .5447 m
.50889 .54203 L
s
.49801 .54598 m
.50889 .54203 L
s
.33848 .50078 m
.32002 .50253 L
s
.30791 .49133 m
.32002 .50253 L
s
.437 .558 .58 r
.39692 .45222 m .40836 .46462 L .42744 .45793 L F
.414 .579 .597 r
.37789 .45896 m .40836 .46462 L .39692 .45222 L F
.385 .608 .619 r
.72597 .4517 m .73513 .46411 L .75545 .45741 L F
.388 .605 .616 r
.7057 .45844 m .73513 .46411 L .72597 .4517 L F
.89 .66 .41 r
.57809 .5398 m
.55835 .54105 L
s
.54809 .54747 m
.55835 .54105 L
s
.477 .519 .551 r
.44668 .45118 m .45777 .4636 L .47706 .45689 L F
.447 .547 .573 r
.42744 .45793 m .45777 .4636 L .44668 .45118 L F
.376 .616 .625 r
.77593 .45066 m .78475 .46308 L .80527 .45637 L F
.377 .615 .624 r
.75545 .45741 m .78475 .46308 L .77593 .45066 L F
.89 .66 .41 r
.74582 .49897 m
.76611 .49136 L
s
.737 .49071 m
.74582 .49897 L
s
.503 .494 .532 r
.49648 .45014 m .50724 .46257 L .52672 .45586 L F
.477 .519 .551 r
.47706 .45689 m .50724 .46257 L .49648 .45014 L F
.5 .497 .534 r
.54635 .44909 m .55677 .46154 L .57645 .45482 L F
.485 .511 .545 r
.52672 .45586 m .55677 .46154 L .54635 .44909 L F
.89 .66 .41 r
.41789 .52568 m
.39922 .52073 L
s
.38744 .5144 m
.39922 .52073 L
s
.469 .527 .557 r
.59628 .44805 m .60635 .46051 L .62623 .45378 L F
.467 .529 .558 r
.57645 .45482 m .60635 .46051 L .59628 .44805 L F
.393 .6 .612 r
.31638 .44752 m .3284 .45999 L .34723 .45326 L F
.384 .609 .619 r
.2976 .4543 m .3284 .45999 L .31638 .44752 L F
.89 .66 .41 r
.64749 .52143 m
.62753 .52791 L
s
.6181 .5329 m
.62753 .52791 L
s
.71676 .49927 m
.69665 .50756 L
s
.68769 .50472 m
.69665 .50756 L
s
.429 .565 .586 r
.64626 .447 m .656 .45948 L .67607 .45274 L F
.434 .561 .583 r
.62623 .45378 m .656 .45948 L .64626 .447 L F
.422 .571 .591 r
.36621 .44648 m .37789 .45896 L .39692 .45222 L F
.403 .59 .605 r
.34723 .45326 m .37789 .45896 L .36621 .44648 L F
.398 .595 .609 r
.6963 .44595 m .7057 .45844 L .72597 .4517 L F
.403 .59 .605 r
.67607 .45274 m .7057 .45844 L .6963 .44595 L F
.89 .66 .41 r
.38744 .5144 m
.36889 .51085 L
s
.35695 .50215 m
.36889 .51085 L
s
.467 .529 .558 r
.4161 .44543 m .42744 .45793 L .44668 .45118 L F
.437 .558 .58 r
.39692 .45222 m .42744 .45793 L .4161 .44543 L F
.89 .66 .41 r
.49801 .54598 m
.4787 .53996 L
s
.46742 .543 m
.4787 .53996 L
s
.382 .611 .621 r
.7464 .4449 m .75545 .45741 L .77593 .45066 L F
.385 .608 .619 r
.72597 .4517 m .75545 .45741 L .7464 .4449 L F
.51 .487 .527 r
.46605 .44438 m .47706 .45689 L .49648 .45014 L F
.477 .519 .551 r
.44668 .45118 m .47706 .45689 L .46605 .44438 L F
.89 .66 .41 r
.76611 .49136 m
.78654 .48379 L
s
.75736 .48212 m
.76611 .49136 L
s
.375 .617 .626 r
.79656 .44385 m .80527 .45637 L .82594 .44961 L F
.376 .616 .625 r
.77593 .45066 m .80527 .45637 L .79656 .44385 L F
.529 .469 .513 r
.51606 .44333 m .52672 .45586 L .54635 .44909 L F
.503 .494 .532 r
.49648 .45014 m .52672 .45586 L .51606 .44333 L F
.89 .66 .41 r
.35695 .50215 m
.33848 .50078 L
s
.32638 .49031 m
.33848 .50078 L
s
.51 .487 .527 r
.56613 .44228 m .57645 .45482 L .59628 .44805 L F
.5 .497 .534 r
.54635 .44909 m .57645 .45482 L .56613 .44228 L F
.89 .66 .41 r
.59802 .53727 m
.57809 .5398 L
s
.56807 .54932 m
.57809 .5398 L
s
.385 .608 .618 r
.28532 .44175 m .2976 .4543 L .31638 .44752 L F
.89 .66 .41 r
.737 .49071 m
.71676 .49927 L
s
.7079 .495 m
.71676 .49927 L
s
.467 .529 .558 r
.61625 .44122 m .62623 .45378 L .64626 .447 L F
.469 .527 .557 r
.59628 .44805 m .62623 .45378 L .61625 .44122 L F
.408 .586 .602 r
.3353 .4407 m .34723 .45326 L .36621 .44648 L F
.393 .6 .612 r
.31638 .44752 m .34723 .45326 L .3353 .4407 L F
.89 .66 .41 r
.54809 .54747 m
.52836 .5447 L
s
.51763 .55339 m
.52836 .5447 L
s
.66755 .51364 m
.64749 .52143 L
s
.63829 .52636 m
.64749 .52143 L
s
.422 .571 .591 r
.66644 .44017 m .67607 .45274 L .6963 .44595 L F
.429 .565 .586 r
.64626 .447 m .67607 .45274 L .66644 .44017 L F
.449 .546 .571 r
.38533 .43964 m .39692 .45222 L .4161 .44543 L F
.422 .571 .591 r
.36621 .44648 m .39692 .45222 L .38533 .43964 L F
.89 .66 .41 r
.32638 .49031 m
.30791 .49133 L
s
.29564 .47974 m
.30791 .49133 L
s
.46742 .543 m
.44833 .53452 L
s
.43673 .535 m
.44833 .53452 L
s
.393 .6 .612 r
.71668 .43911 m .72597 .4517 L .7464 .4449 L F
.398 .595 .609 r
.6963 .44595 m .72597 .4517 L .71668 .43911 L F
.503 .494 .532 r
.43542 .43859 m .44668 .45118 L .46605 .44438 L F
.467 .529 .558 r
.4161 .44543 m .44668 .45118 L .43542 .43859 L F
.89 .66 .41 r
.78654 .48379 m
.80714 .47632 L
s
.77786 .47365 m
.78654 .48379 L
s
.379 .613 .623 r
.76698 .43806 m .77593 .45066 L .79656 .44385 L F
.382 .611 .621 r
.7464 .4449 m .77593 .45066 L .76698 .43806 L F
.545 .453 .501 r
.48558 .43753 m .49648 .45014 L .51606 .44333 L F
.51 .487 .527 r
.46605 .44438 m .49648 .45014 L .48558 .43753 L F
.374 .618 .626 r
.81734 .437 m .82594 .44961 L .84677 .4428 L F
.375 .617 .626 r
.79656 .44385 m .82594 .44961 L .81734 .437 L F
.55 .449 .497 r
.53579 .43647 m .54635 .44909 L .56613 .44228 L F
.529 .469 .513 r
.51606 .44333 m .54635 .44909 L .53579 .43647 L F
.89 .66 .41 r
.75736 .48212 m
.737 .49071 L
s
.7282 .48488 m
.737 .49071 L
s
.514 .484 .524 r
.58606 .43541 m .59628 .44805 L .61625 .44122 L F
.51 .487 .527 r
.56613 .44228 m .59628 .44805 L .58606 .43541 L F
.89 .66 .41 r
.43673 .535 m
.41789 .52568 L
s
.40606 .52272 m
.41789 .52568 L
s
.395 .598 .611 r
.30419 .43488 m .31638 .44752 L .3353 .4407 L F
.385 .608 .618 r
.28532 .44175 m .31638 .44752 L .30419 .43488 L F
.46 .536 .564 r
.63638 .43435 m .64626 .447 L .66644 .44017 L F
.467 .529 .558 r
.61625 .44122 m .64626 .447 L .63638 .43435 L F
.89 .66 .41 r
.68769 .50472 m
.66755 .51364 L
s
.65853 .51764 m
.66755 .51364 L
s
.429 .565 .586 r
.35436 .43382 m .36621 .44648 L .38533 .43964 L F
.408 .586 .602 r
.3353 .4407 m .36621 .44648 L .35436 .43382 L F
.414 .579 .597 r
.68677 .43329 m .6963 .44595 L .71668 .43911 L F
.422 .571 .591 r
.66644 .44017 m .6963 .44595 L .68677 .43329 L F
.89 .66 .41 r
.40606 .52272 m
.38744 .5144 L
s
.37545 .50799 m
.38744 .5144 L
s
.485 .511 .545 r
.4046 .43276 m .4161 .44543 L .43542 .43859 L F
.449 .546 .571 r
.38533 .43964 m .4161 .44543 L .4046 .43276 L F
.89 .66 .41 r
.6181 .5329 m
.59802 .53727 L
s
.58828 .54915 m
.59802 .53727 L
s
.388 .605 .616 r
.73722 .43222 m .7464 .4449 L .76698 .43806 L F
.393 .6 .612 r
.71668 .43911 m .7464 .4449 L .73722 .43222 L F
.545 .453 .501 r
.45489 .43169 m .46605 .44438 L .48558 .43753 L F
.503 .494 .532 r
.43542 .43859 m .46605 .44438 L .45489 .43169 L F
.89 .66 .41 r
.80714 .47632 m
.8279 .46897 L
s
.79852 .46542 m
.80714 .47632 L
s
.377 .615 .624 r
.78772 .43116 m .79656 .44385 L .81734 .437 L F
.379 .613 .623 r
.76698 .43806 m .79656 .44385 L .78772 .43116 L F
.89 .66 .41 r
.37545 .50799 m
.35695 .50215 L
s
.34484 .49296 m
.35695 .50215 L
s
.51763 .55339 m
.49801 .54598 L
s
.48681 .55458 m
.49801 .54598 L
s
.579 .421 .476 r
.50525 .43063 m .51606 .44333 L .53579 .43647 L F
.545 .453 .501 r
.48558 .43753 m .51606 .44333 L .50525 .43063 L F
.373 .619 .627 r
.83828 .43009 m .84677 .4428 L .86776 .43594 L F
.374 .618 .626 r
.81734 .437 m .84677 .4428 L .83828 .43009 L F
.89 .66 .41 r
.77786 .47365 m
.75736 .48212 L
s
.74861 .47471 m
.75736 .48212 L
s
.564 .435 .487 r
.55566 .42956 m .56613 .44228 L .58606 .43541 L F
.55 .449 .497 r
.53579 .43647 m .56613 .44228 L .55566 .42956 L F
.89 .66 .41 r
.34484 .49296 m
.32638 .49031 L
s
.31413 .47926 m
.32638 .49031 L
s
.385 .607 .618 r
.27287 .42903 m .28532 .44175 L .30419 .43488 L F
.89 .66 .41 r
.7079 .495 m
.68769 .50472 L
s
.67881 .50704 m
.68769 .50472 L
s
.51 .487 .527 r
.60613 .42849 m .61625 .44122 L .63638 .43435 L F
.514 .484 .524 r
.58606 .43541 m .61625 .44122 L .60613 .42849 L F
.89 .66 .41 r
.56807 .54932 m
.54809 .54747 L
s
.53758 .56102 m
.54809 .54747 L
s
.41 .583 .6 r
.32319 .42796 m .3353 .4407 L .35436 .43382 L F
.395 .598 .611 r
.30419 .43488 m .3353 .4407 L .32319 .42796 L F
.449 .546 .571 r
.65667 .42742 m .66644 .44017 L .68677 .43329 L F
.46 .536 .564 r
.63638 .43435 m .66644 .44017 L .65667 .42742 L F
.37357 .42689 m .38533 .43964 L .4046 .43276 L F
.429 .565 .586 r
.35436 .43382 m .38533 .43964 L .37357 .42689 L F
.406 .588 .603 r
.70726 .42635 m .71668 .43911 L .73722 .43222 L F
.414 .579 .597 r
.68677 .43329 m .71668 .43911 L .70726 .42635 L F
.89 .66 .41 r
.31413 .47926 m
.29564 .47974 L
s
.28321 .46765 m
.29564 .47974 L
s
.529 .469 .513 r
.42401 .42582 m .43542 .43859 L .45489 .43169 L F
.485 .511 .545 r
.4046 .43276 m .43542 .43859 L .42401 .42582 L F
.384 .609 .619 r
.75791 .42528 m .76698 .43806 L .78772 .43116 L F
.388 .605 .616 r
.73722 .43222 m .76698 .43806 L .75791 .42528 L F
.89 .66 .41 r
.8279 .46897 m
.84882 .46174 L
s
.81936 .45745 m
.8279 .46897 L
s
.59 .411 .468 r
.47451 .42474 m .48558 .43753 L .50525 .43063 L F
.545 .453 .501 r
.45489 .43169 m .48558 .43753 L .47451 .42474 L F
.89 .66 .41 r
.63829 .52636 m
.6181 .5329 L
s
.60865 .54604 m
.6181 .5329 L
s
.375 .617 .625 r
.80862 .42421 m .81734 .437 L .83828 .43009 L F
.377 .615 .624 r
.78772 .43116 m .81734 .437 L .80862 .42421 L F
.89 .66 .41 r
.79852 .46542 m
.77786 .47365 L
s
.76916 .46482 m
.77786 .47365 L
s
.607 .394 .456 r
.52507 .42367 m .53579 .43647 L .55566 .42956 L F
.579 .421 .476 r
.50525 .43063 m .53579 .43647 L .52507 .42367 L F
.89 .66 .41 r
.7282 .48488 m
.7079 .495 L
s
.69912 .49513 m
.7079 .495 L
s
.48681 .55458 m
.46742 .543 L
s
.45581 .54907 m
.46742 .543 L
s
.373 .619 .627 r
.85939 .42313 m .86776 .43594 L .88891 .42903 L F
.83828 .43009 m .86776 .43594 L .85939 .42313 L F
.569 .431 .484 r
.57569 .4226 m .58606 .43541 L .60613 .42849 L F
.564 .435 .487 r
.55566 .42956 m .58606 .43541 L .57569 .4226 L F
.395 .598 .611 r
.29182 .42206 m .30419 .43488 L .32319 .42796 L F
.385 .607 .618 r
.27287 .42903 m .30419 .43488 L .29182 .42206 L F
.5 .497 .534 r
.62637 .42152 m .63638 .43435 L .65667 .42742 L F
.51 .487 .527 r
.60613 .42849 m .63638 .43435 L .62637 .42152 L F
.434 .561 .583 r
.34235 .42098 m .35436 .43382 L .37357 .42689 L F
.41 .583 .6 r
.32319 .42796 m .35436 .43382 L .34235 .42098 L F
.437 .558 .58 r
.67711 .42044 m .68677 .43329 L .70726 .42635 L F
.449 .546 .571 r
.65667 .42742 m .68677 .43329 L .67711 .42044 L F
.5 .497 .534 r
.39293 .4199 m .4046 .43276 L .42401 .42582 L F
.46 .536 .564 r
.37357 .42689 m .4046 .43276 L .39293 .4199 L F
.398 .595 .609 r
.7279 .41936 m .73722 .43222 L .75791 .42528 L F
.406 .588 .603 r
.70726 .42635 m .73722 .43222 L .7279 .41936 L F
.89 .66 .41 r
.45581 .54907 m
.43673 .535 L
s
.42482 .53681 m
.43673 .535 L
s
.579 .421 .476 r
.44358 .41882 m .45489 .43169 L .47451 .42474 L F
.529 .469 .513 r
.42401 .42582 m .45489 .43169 L .44358 .41882 L F
.89 .66 .41 r
.74861 .47471 m
.7282 .48488 L
s
.71948 .48256 m
.7282 .48488 L
s
.84882 .46174 m
.86992 .45459 L
s
.84036 .44974 m
.84882 .46174 L
s
.38 .612 .622 r
.77876 .41828 m .78772 .43116 L .80862 .42421 L F
.384 .609 .619 r
.75791 .42528 m .78772 .43116 L .77876 .41828 L F
.89 .66 .41 r
.81936 .45745 m
.79852 .46542 L
s
.78987 .45537 m
.79852 .46542 L
s
.632 .37 .438 r
.49428 .41774 m .50525 .43063 L .52507 .42367 L F
.59 .411 .468 r
.47451 .42474 m .50525 .43063 L .49428 .41774 L F
.89 .66 .41 r
.65853 .51764 m
.63829 .52636 L
s
.62911 .53945 m
.63829 .52636 L
s
.374 .618 .626 r
.82968 .4172 m .83828 .43009 L .85939 .42313 L F
.375 .617 .625 r
.80862 .42421 m .83828 .43009 L .82968 .4172 L F
.89 .66 .41 r
.42482 .53681 m
.40606 .52272 L
s
.39398 .51975 m
.40606 .52272 L
s
.625 .376 .442 r
.54505 .41666 m .55566 .42956 L .57569 .4226 L F
.607 .394 .456 r
.52507 .42367 m .55566 .42956 L .54505 .41666 L F
.89 .66 .41 r
.39398 .51975 m
.37545 .50799 L
s
.36327 .50086 m
.37545 .50799 L
s
.36327 .50086 m
.34484 .49296 L
s
.33257 .48286 m
.34484 .49296 L
s
.58828 .54915 m
.56807 .54932 L
s
.55785 .5673 m
.56807 .54932 L
s
.385 .608 .618 r
.26025 .41612 m .27287 .42903 L .29182 .42206 L F
.373 .619 .627 r
.88066 .41612 m .88891 .42903 L .91022 .42206 L F
.85939 .42313 m .88891 .42903 L .88066 .41612 L F
.564 .435 .487 r
.59587 .41558 m .60613 .42849 L .62637 .42152 L F
.569 .431 .484 r
.57569 .4226 m .60613 .42849 L .59587 .41558 L F
.89 .66 .41 r
.53758 .56102 m
.51763 .55339 L
s
.50657 .5683 m
.51763 .55339 L
s
.33257 .48286 m
.31413 .47926 L
s
.30174 .46742 m
.31413 .47926 L
s
.411 .582 .599 r
.31092 .41504 m .32319 .42796 L .34235 .42098 L F
.395 .598 .611 r
.29182 .42206 m .32319 .42796 L .31092 .41504 L F
.485 .511 .545 r
.64676 .41449 m .65667 .42742 L .67711 .42044 L F
.5 .497 .534 r
.62637 .42152 m .65667 .42742 L .64676 .41449 L F
.467 .529 .558 r
.36165 .41395 m .37357 .42689 L .39293 .4199 L F
.434 .561 .583 r
.34235 .42098 m .37357 .42689 L .36165 .41395 L F
.89 .66 .41 r
.76916 .46482 m
.74861 .47471 L
s
.73992 .46998 m
.74861 .47471 L
s
.424 .57 .59 r
.6977 .41341 m .70726 .42635 L .7279 .41936 L F
.437 .558 .58 r
.67711 .42044 m .70726 .42635 L .6977 .41341 L F
.89 .66 .41 r
.30174 .46742 m
.28321 .46765 L
s
.27064 .455 m
.28321 .46765 L
s
.55 .449 .497 r
.41244 .41286 m .42401 .42582 L .44358 .41882 L F
.5 .497 .534 r
.39293 .4199 m .42401 .42582 L .41244 .41286 L F
.391 .602 .614 r
.74871 .41232 m .75791 .42528 L .77876 .41828 L F
.398 .595 .609 r
.7279 .41936 m .75791 .42528 L .74871 .41232 L F
.632 .37 .438 r
.46329 .41178 m .47451 .42474 L .49428 .41774 L F
.579 .421 .476 r
.44358 .41882 m .47451 .42474 L .46329 .41178 L F
.89 .66 .41 r
.67881 .50704 m
.65853 .51764 L
s
.64959 .52936 m
.65853 .51764 L
s
.86992 .45459 m
.89118 .44751 L
s
.86155 .44223 m
.86992 .45459 L
s
.84036 .44974 m
.81936 .45745 L
s
.81075 .44643 m
.81936 .45745 L
s
.377 .615 .624 r
.79977 .41123 m .80862 .42421 L .82968 .4172 L F
.38 .612 .622 r
.77876 .41828 m .80862 .42421 L .79977 .41123 L F
.667 .336 .412 r
.5142 .41069 m .52507 .42367 L .54505 .41666 L F
.632 .37 .438 r
.49428 .41774 m .52507 .42367 L .5142 .41069 L F
.373 .619 .627 r
.8509 .41014 m .85939 .42313 L .88066 .41612 L F
.374 .618 .626 r
.82968 .4172 m .85939 .42313 L .8509 .41014 L F
.632 .37 .438 r
.56518 .4096 m .57569 .4226 L .59587 .41558 L F
.625 .376 .442 r
.54505 .41666 m .57569 .4226 L .56518 .4096 L F
.373 .619 .627 r
.88066 .41612 m .91022 .42206 L .90209 .40905 L F
.395 .598 .611 r
.27929 .40905 m .29182 .42206 L .31092 .41504 L F
.385 .608 .618 r
.26025 .41612 m .29182 .42206 L .27929 .40905 L F
.89 .66 .41 r
.78987 .45537 m
.76916 .46482 L
s
.76047 .45789 m
.76916 .46482 L
s
.55 .449 .497 r
.61621 .40851 m .62637 .42152 L .64676 .41449 L F
.564 .435 .487 r
.59587 .41558 m .62637 .42152 L .61621 .40851 L F
.435 .559 .581 r
.33016 .40796 m .34235 .42098 L .36165 .41395 L F
.411 .582 .599 r
.31092 .41504 m .34235 .42098 L .33016 .40796 L F
.467 .529 .558 r
.6673 .40741 m .67711 .42044 L .6977 .41341 L F
.485 .511 .545 r
.64676 .41449 m .67711 .42044 L .6673 .40741 L F
.89 .66 .41 r
.69912 .49513 m
.67881 .50704 L
s
.67004 .51628 m
.67881 .50704 L
s
.51 .487 .527 r
.3811 .40687 m .39293 .4199 L .41244 .41286 L F
.467 .529 .558 r
.36165 .41395 m .39293 .4199 L .3811 .40687 L F
.411 .582 .599 r
.71846 .40632 m .7279 .41936 L .74871 .41232 L F
.424 .57 .59 r
.6977 .41341 m .7279 .41936 L .71846 .40632 L F
.607 .394 .456 r
.4321 .40577 m .44358 .41882 L .46329 .41178 L F
.55 .449 .497 r
.41244 .41286 m .44358 .41882 L .4321 .40577 L F
.89 .66 .41 r
.50657 .5683 m
.48681 .55458 L
s
.47522 .56752 m
.48681 .55458 L
s
.60865 .54604 m
.58828 .54915 L
s
.5784 .57053 m
.58828 .54915 L
s
.385 .608 .618 r
.76967 .40522 m .77876 .41828 L .79977 .41123 L F
.391 .602 .614 r
.74871 .41232 m .77876 .41828 L .76967 .40522 L F
.89 .66 .41 r
.86155 .44223 m
.84036 .44974 L
s
.83183 .43798 m
.84036 .44974 L
s
.682 .322 .401 r
.48316 .40468 m .49428 .41774 L .5142 .41069 L F
.632 .37 .438 r
.46329 .41178 m .49428 .41774 L .48316 .40468 L F
.89 .66 .41 r
.89118 .44751 m
.91262 .44045 L
s
.88292 .43488 m
.89118 .44751 L
s
.375 .617 .625 r
.82095 .40413 m .82968 .4172 L .8509 .41014 L F
.377 .615 .624 r
.79977 .41123 m .82968 .4172 L .82095 .40413 L F
.69 .314 .395 r
.53428 .40358 m .54505 .41666 L .56518 .4096 L F
.667 .336 .412 r
.5142 .41069 m .54505 .41666 L .53428 .40358 L F
.89 .66 .41 r
.81075 .44643 m
.78987 .45537 L
s
.78119 .44659 m
.78987 .45537 L
s
.373 .619 .627 r
.87228 .40303 m .88066 .41612 L .90209 .40905 L F
.8509 .41014 m .88066 .41612 L .87228 .40303 L F
.384 .609 .619 r
.24744 .40303 m .26025 .41612 L .27929 .40905 L F
.89 .66 .41 r
.71948 .48256 m
.69912 .49513 L
s
.69046 .50111 m
.69912 .49513 L
s
.625 .376 .442 r
.58546 .40248 m .59587 .41558 L .61621 .40851 L F
.632 .37 .438 r
.56518 .4096 m .59587 .41558 L .58546 .40248 L F
.41 .583 .6 r
.29847 .40193 m .31092 .41504 L .33016 .40796 L F
.395 .598 .611 r
.27929 .40905 m .31092 .41504 L .29847 .40193 L F
.89 .66 .41 r
.35095 .49232 m
.33257 .48286 L
s
.32019 .47151 m
.33257 .48286 L
s
.32019 .47151 m
.30174 .46742 L
s
.28922 .45469 m
.30174 .46742 L
s
.529 .469 .513 r
.63671 .40138 m .64676 .41449 L .6673 .40741 L F
.55 .449 .497 r
.61621 .40851 m .64676 .41449 L .63671 .40138 L F
.469 .527 .557 r
.34956 .40083 m .36165 .41395 L .3811 .40687 L F
.435 .559 .581 r
.33016 .40796 m .36165 .41395 L .34956 .40083 L F
.89 .66 .41 r
.3817 .51576 m
.36327 .50086 L
s
.35095 .49232 m
.36327 .50086 L
s
.447 .547 .573 r
.68801 .40028 m .6977 .41341 L .71846 .40632 L F
.467 .529 .558 r
.6673 .40741 m .6977 .41341 L .68801 .40028 L F
.89 .66 .41 r
.28922 .45469 m
.27064 .455 L
s
.25792 .44178 m
.27064 .455 L
s
.55785 .5673 m
.53758 .56102 L
s
.52674 .58244 m
.53758 .56102 L
s
.564 .435 .487 r
.4007 .39973 m .41244 .41286 L .4321 .40577 L F
.51 .487 .527 r
.3811 .40687 m .41244 .41286 L .4007 .39973 L F
.89 .66 .41 r
.73992 .46998 m
.71948 .48256 L
s
.71086 .48495 m
.71948 .48256 L
s
.47522 .56752 m
.45581 .54907 L
s
.44383 .5572 m
.45581 .54907 L
s
.4 .593 .607 r
.73937 .39918 m .74871 .41232 L .76967 .40522 L F
.411 .582 .599 r
.71846 .40632 m .74871 .41232 L .73937 .39918 L F
.667 .336 .412 r
.45191 .39862 m .46329 .41178 L .48316 .40468 L F
.607 .394 .456 r
.4321 .40577 m .46329 .41178 L .45191 .39862 L F
.89 .66 .41 r
.41263 .53875 m
.39398 .51975 L
s
.3817 .51576 m
.39398 .51975 L
s
.88292 .43488 m
.86155 .44223 L
s
.85309 .42994 m
.86155 .44223 L
s
.38 .612 .622 r
.7908 .39807 m .79977 .41123 L .82095 .40413 L F
.385 .608 .618 r
.76967 .40522 m .79977 .41123 L .7908 .39807 L F
.723 .282 .37 r
.50318 .39752 m .5142 .41069 L .53428 .40358 L F
.682 .322 .401 r
.48316 .40468 m .5142 .41069 L .50318 .39752 L F
.89 .66 .41 r
.91262 .44045 m
.90447 .42761 L
s
.44383 .5572 m
.42482 .53681 L
s
.41263 .53875 m
.42482 .53681 L
s
.83183 .43798 m
.81075 .44643 L
s
.8021 .43619 m
.81075 .44643 L
s
.374 .618 .626 r
.84229 .39697 m .8509 .41014 L .87228 .40303 L F
.375 .617 .625 r
.82095 .40413 m .8509 .41014 L .84229 .39697 L F
.698 .306 .389 r
.55451 .39641 m .56518 .4096 L .58546 .40248 L F
.69 .314 .395 r
.53428 .40358 m .56518 .4096 L .55451 .39641 L F
.89 .66 .41 r
.62911 .53945 m
.60865 .54604 L
s
.59914 .56926 m
.60865 .54604 L
s
.393 .6 .612 r
.26657 .39586 m .27929 .40905 L .29847 .40193 L F
.384 .609 .619 r
.24744 .40303 m .27929 .40905 L .26657 .39586 L F
.373 .619 .627 r
.87228 .40303 m .90209 .40905 L .89384 .39586 L F
.89 .66 .41 r
.76047 .45789 m
.73992 .46998 L
s
.7313 .46883 m
.73992 .46998 L
s
.607 .394 .456 r
.60591 .39531 m .61621 .40851 L .63671 .40138 L F
.625 .376 .442 r
.58546 .40248 m .61621 .40851 L .60591 .39531 L F
.434 .561 .583 r
.3178 .39475 m .33016 .40796 L .34956 .40083 L F
.41 .583 .6 r
.29847 .40193 m .33016 .40796 L .3178 .39475 L F
.503 .494 .532 r
.65736 .3942 m .6673 .40741 L .68801 .40028 L F
.529 .469 .513 r
.63671 .40138 m .6673 .40741 L .65736 .3942 L F
.514 .484 .524 r
.3691 .39364 m .3811 .40687 L .4007 .39973 L F
.469 .527 .557 r
.34956 .40083 m .3811 .40687 L .3691 .39364 L F
.429 .565 .586 r
.70888 .39309 m .71846 .40632 L .73937 .39918 L F
.447 .547 .573 r
.68801 .40028 m .71846 .40632 L .70888 .39309 L F
.625 .376 .442 r
.42046 .39253 m .4321 .40577 L .45191 .39862 L F
.564 .435 .487 r
.4007 .39973 m .4321 .40577 L .42046 .39253 L F
.392 .601 .614 r
.76045 .39198 m .76967 .40522 L .7908 .39807 L F
.4 .593 .607 r
.73937 .39918 m .76967 .40522 L .76045 .39198 L F
.89 .66 .41 r
.78119 .44659 m
.76047 .45789 L
s
.75183 .45353 m
.76047 .45789 L
s
.723 .282 .37 r
.47188 .39142 m .48316 .40468 L .50318 .39752 L F
.667 .336 .412 r
.45191 .39862 m .48316 .40468 L .47188 .39142 L F
.89 .66 .41 r
.90447 .42761 m
.88292 .43488 L
s
.87456 .42221 m
.88292 .43488 L
s
.85309 .42994 m
.83183 .43798 L
s
.82322 .42665 m
.83183 .43798 L
s
.377 .615 .624 r
.81209 .39086 m .82095 .40413 L .84229 .39697 L F
.38 .612 .622 r
.7908 .39807 m .82095 .40413 L .81209 .39086 L F
.751 .255 .35 r
.52336 .39031 m .53428 .40358 L .55451 .39641 L F
.723 .282 .37 r
.50318 .39752 m .53428 .40358 L .52336 .39031 L F
.383 .61 .62 r
.23445 .38975 m .24744 .40303 L .26657 .39586 L F
.373 .619 .627 r
.86379 .38975 m .87228 .40303 L .89384 .39586 L F
.374 .618 .626 r
.84229 .39697 m .87228 .40303 L .86379 .38975 L F
.69 .314 .395 r
.5749 .38919 m .58546 .40248 L .60591 .39531 L F
.698 .306 .389 r
.55451 .39641 m .58546 .40248 L .5749 .38919 L F
.89 .66 .41 r
.64959 .52936 m
.62911 .53945 L
s
.61994 .56263 m
.62911 .53945 L
s
.408 .586 .602 r
.28584 .38864 m .29847 .40193 L .3178 .39475 L F
.393 .6 .612 r
.26657 .39586 m .29847 .40193 L .28584 .38864 L F
.89 .66 .41 r
.30771 .45871 m
.28922 .45469 L
s
.27658 .44105 m
.28922 .45469 L
s
.579 .421 .476 r
.62651 .38808 m .63671 .40138 L .65736 .3942 L F
.607 .394 .456 r
.60591 .39531 m .63671 .40138 L .62651 .38808 L F
.89 .66 .41 r
.33854 .48181 m
.32019 .47151 L
s
.30771 .45871 m
.32019 .47151 L
s
.467 .529 .558 r
.33729 .38752 m .34956 .40083 L .3691 .39364 L F
.434 .561 .583 r
.3178 .39475 m .34956 .40083 L .33729 .38752 L F
.89 .66 .41 r
.8021 .43619 m
.78119 .44659 L
s
.77253 .43954 m
.78119 .44659 L
s
.477 .519 .551 r
.67818 .38696 m .68801 .40028 L .70888 .39309 L F
.503 .494 .532 r
.65736 .3942 m .68801 .40028 L .67818 .38696 L F
.89 .66 .41 r
.27658 .44105 m
.25792 .44178 L
s
.24506 .42803 m
.25792 .44178 L
s
.569 .431 .484 r
.3888 .3864 m .4007 .39973 L .42046 .39253 L F
.514 .484 .524 r
.3691 .39364 m .4007 .39973 L .3888 .3864 L F
.89 .66 .41 r
.52674 .58244 m
.50657 .5683 L
s
.49509 .58908 m
.50657 .5683 L
s
.413 .58 .598 r
.72991 .38584 m .73937 .39918 L .76045 .39198 L F
.429 .565 .586 r
.70888 .39309 m .73937 .39918 L .72991 .38584 L F
.69 .314 .395 r
.44037 .38528 m .45191 .39862 L .47188 .39142 L F
.625 .376 .442 r
.42046 .39253 m .45191 .39862 L .44037 .38528 L F
.89 .66 .41 r
.5784 .57053 m
.55785 .5673 L
s
.54733 .59469 m
.55785 .5673 L
s
.385 .608 .618 r
.7817 .38472 m .7908 .39807 L .81209 .39086 L F
.392 .601 .614 r
.76045 .39198 m .7908 .39807 L .7817 .38472 L F
.89 .66 .41 r
.36928 .50962 m
.35095 .49232 L
s
.33854 .48181 m
.35095 .49232 L
s
.87456 .42221 m
.85309 .42994 L
s
.84455 .41783 m
.85309 .42994 L
s
.771 .236 .335 r
.492 .38416 m .50318 .39752 L .52336 .39031 L F
.723 .282 .37 r
.47188 .39142 m .50318 .39752 L .492 .38416 L F
.89 .66 .41 r
.90447 .42761 m
.89621 .41467 L
s
.67004 .51628 m
.64959 .52936 L
s
.64072 .55062 m
.64959 .52936 L
s
.375 .617 .625 r
.83355 .3836 m .84229 .39697 L .86379 .38975 L F
.377 .615 .624 r
.81209 .39086 m .84229 .39697 L .83355 .3836 L F
.761 .246 .343 r
.5437 .38304 m .55451 .39641 L .5749 .38919 L F
.751 .255 .35 r
.52336 .39031 m .55451 .39641 L .5437 .38304 L F
.391 .602 .614 r
.25367 .38248 m .26657 .39586 L .28584 .38864 L F
.383 .61 .62 r
.23445 .38975 m .26657 .39586 L .25367 .38248 L F
.373 .619 .627 r
.86379 .38975 m .89384 .39586 L .88547 .38248 L F
.89 .66 .41 r
.82322 .42665 m
.8021 .43619 L
s
.79343 .42703 m
.8021 .43619 L
s
.667 .336 .412 r
.59545 .38192 m .60591 .39531 L .62651 .38808 L F
.69 .314 .395 r
.5749 .38919 m .60591 .39531 L .59545 .38192 L F
.429 .565 .586 r
.30526 .38135 m .3178 .39475 L .33729 .38752 L F
.408 .586 .602 r
.28584 .38864 m .3178 .39475 L .30526 .38135 L F
.545 .453 .501 r
.64727 .38079 m .65736 .3942 L .67818 .38696 L F
.579 .421 .476 r
.62651 .38808 m .65736 .3942 L .64727 .38079 L F
.89 .66 .41 r
.69046 .50111 m
.67004 .51628 L
s
.66139 .53404 m
.67004 .51628 L
s
.51 .487 .527 r
.35692 .38023 m .3691 .39364 L .3888 .3864 L F
.467 .529 .558 r
.33729 .38752 m .3691 .39364 L .35692 .38023 L F
.89 .66 .41 r
.40021 .53924 m
.3817 .51576 L
s
.36928 .50962 m
.3817 .51576 L
s
.451 .544 .57 r
.69916 .37967 m .70888 .39309 L .72991 .38584 L F
.477 .519 .551 r
.67818 .38696 m .70888 .39309 L .69916 .37967 L F
.632 .37 .438 r
.40865 .3791 m .42046 .39253 L .44037 .38528 L F
.569 .431 .484 r
.3888 .3864 m .42046 .39253 L .40865 .3791 L F
.4 .593 .607 r
.7511 .37854 m .76045 .39198 L .7817 .38472 L F
.413 .58 .598 r
.72991 .38584 m .76045 .39198 L .7511 .37854 L F
.89 .66 .41 r
.71086 .48495 m
.69046 .50111 L
s
.68192 .5143 m
.69046 .50111 L
s
.751 .255 .35 r
.46043 .37797 m .47188 .39142 L .492 .38416 L F
.69 .314 .395 r
.44037 .38528 m .47188 .39142 L .46043 .37797 L F
.89 .66 .41 r
.89621 .41467 m
.87456 .42221 L
s
.86609 .40956 m
.87456 .42221 L
s
.38 .612 .622 r
.80311 .37741 m .81209 .39086 L .83355 .3836 L F
.385 .608 .618 r
.7817 .38472 m .81209 .39086 L .80311 .37741 L F
.802 .206 .312 r
.51228 .37684 m .52336 .39031 L .5437 .38304 L F
.771 .236 .335 r
.492 .38416 m .52336 .39031 L .51228 .37684 L F
.89 .66 .41 r
.49509 .58908 m
.47522 .56752 L
s
.46322 .58352 m
.47522 .56752 L
s
.7313 .46883 m
.71086 .48495 L
s
.70236 .4931 m
.71086 .48495 L
s
.84455 .41783 m
.82322 .42665 L
s
.81455 .41593 m
.82322 .42665 L
s
.381 .612 .621 r
.22128 .37628 m .23445 .38975 L .25367 .38248 L F
.374 .618 .626 r
.85518 .37628 m .86379 .38975 L .88547 .38248 L F
.375 .617 .625 r
.83355 .3836 m .86379 .38975 L .85518 .37628 L F
.751 .255 .35 r
.56419 .37571 m .5749 .38919 L .59545 .38192 L F
.761 .246 .343 r
.5437 .38304 m .5749 .38919 L .56419 .37571 L F
.89 .66 .41 r
.29515 .44444 m
.27658 .44105 L
s
.26383 .4266 m
.27658 .44105 L
s
.43152 .5657 m
.41263 .53875 L
s
.40021 .53924 m
.41263 .53875 L
s
.403 .59 .605 r
.27303 .37515 m .28584 .38864 L .30526 .38135 L F
.391 .602 .614 r
.25367 .38248 m .28584 .38864 L .27303 .37515 L F
.89 .66 .41 r
.75183 .45353 m
.7313 .46883 L
s
.72277 .47202 m
.7313 .46883 L
s
.632 .37 .438 r
.61616 .37458 m .62651 .38808 L .64727 .38079 L F
.667 .336 .412 r
.59545 .38192 m .62651 .38808 L .61616 .37458 L F
.89 .66 .41 r
.32607 .46896 m
.30771 .45871 L
s
.29515 .44444 m
.30771 .45871 L
s
.46 .536 .564 r
.32484 .37401 m .33729 .38752 L .35692 .38023 L F
.429 .565 .586 r
.30526 .38135 m .33729 .38752 L .32484 .37401 L F
.89 .66 .41 r
.26383 .4266 m
.24506 .42803 L
s
.23203 .41386 m
.24506 .42803 L
s
.46322 .58352 m
.44383 .5572 L
s
.43152 .5657 m
.44383 .5572 L
s
.51 .487 .527 r
.6682 .37345 m .67818 .38696 L .69916 .37967 L F
.545 .453 .501 r
.64727 .38079 m .67818 .38696 L .6682 .37345 L F
.89 .66 .41 r
.77253 .43954 m
.75183 .45353 L
s
.74325 .45227 m
.75183 .45353 L
s
.564 .435 .487 r
.37672 .37288 m .3888 .3864 L .40865 .3791 L F
.51 .487 .527 r
.35692 .38023 m .3888 .3864 L .37672 .37288 L F
.429 .565 .586 r
.7203 .37231 m .72991 .38584 L .7511 .37854 L F
.451 .544 .57 r
.69916 .37967 m .72991 .38584 L .7203 .37231 L F
.698 .306 .389 r
.42865 .37175 m .44037 .38528 L .46043 .37797 L F
.632 .37 .438 r
.40865 .3791 m .44037 .38528 L .42865 .37175 L F
.89 .66 .41 r
.59914 .56926 m
.5784 .57053 L
s
.56828 .60254 m
.5784 .57053 L
s
.391 .602 .614 r
.77246 .37118 m .7817 .38472 L .80311 .37741 L F
.4 .593 .607 r
.7511 .37854 m .7817 .38472 L .77246 .37118 L F
.802 .206 .312 r
.48066 .37061 m .492 .38416 L .51228 .37684 L F
.751 .255 .35 r
.46043 .37797 m .492 .38416 L .48066 .37061 L F
.89 .66 .41 r
.89621 .41467 m
.88784 .40165 L
s
.86609 .40956 m
.84455 .41783 L
s
.83592 .40601 m
.84455 .41783 L
s
.377 .615 .624 r
.82469 .37004 m .83355 .3836 L .85518 .37628 L F
.38 .612 .622 r
.80311 .37741 m .83355 .3836 L .82469 .37004 L F
.89 .66 .41 r
.79343 .42703 m
.77253 .43954 L
s
.76388 .43458 m
.77253 .43954 L
s
.35679 .5004 m
.33854 .48181 L
s
.32607 .46896 m
.33854 .48181 L
s
.813 .195 .304 r
.53272 .36947 m .5437 .38304 L .56419 .37571 L F
.802 .206 .312 r
.51228 .37684 m .5437 .38304 L .53272 .36947 L F
.388 .605 .616 r
.24058 .3689 m .25367 .38248 L .27303 .37515 L F
.381 .612 .621 r
.22128 .37628 m .25367 .38248 L .24058 .3689 L F
.374 .618 .626 r
.85518 .37628 m .88547 .38248 L .87698 .3689 L F
.723 .282 .37 r
.58485 .36833 m .59545 .38192 L .61616 .37458 L F
.751 .255 .35 r
.56419 .37571 m .59545 .38192 L .58485 .36833 L F
.422 .571 .591 r
.29254 .36776 m .30526 .38135 L .32484 .37401 L F
.403 .59 .605 r
.27303 .37515 m .30526 .38135 L .29254 .36776 L F
.59 .411 .468 r
.63704 .36719 m .64727 .38079 L .6682 .37345 L F
.632 .37 .438 r
.61616 .37458 m .64727 .38079 L .63704 .36719 L F
.5 .497 .534 r
.34457 .36662 m .35692 .38023 L .37672 .37288 L F
.46 .536 .564 r
.32484 .37401 m .35692 .38023 L .34457 .36662 L F
.89 .66 .41 r
.81455 .41593 m
.79343 .42703 L
s
.78473 .41918 m
.79343 .42703 L
s
.477 .519 .551 r
.68929 .36605 m .69916 .37967 L .7203 .37231 L F
.51 .487 .527 r
.6682 .37345 m .69916 .37967 L .68929 .36605 L F
.89 .66 .41 r
.54733 .59469 m
.52674 .58244 L
s
.51548 .61139 m
.52674 .58244 L
s
.625 .376 .442 r
.39666 .36547 m .40865 .3791 L .42865 .37175 L F
.564 .435 .487 r
.37672 .37288 m .40865 .3791 L .39666 .36547 L F
.411 .582 .599 r
.74161 .3649 m .7511 .37854 L .77246 .37118 L F
.429 .565 .586 r
.7203 .37231 m .7511 .37854 L .74161 .3649 L F
.761 .246 .343 r
.44882 .36433 m .46043 .37797 L .48066 .37061 L F
.698 .306 .389 r
.42865 .37175 m .46043 .37797 L .44882 .36433 L F
.384 .609 .619 r
.79399 .36376 m .80311 .37741 L .82469 .37004 L F
.391 .602 .614 r
.77246 .37118 m .80311 .37741 L .79399 .36376 L F
.89 .66 .41 r
.88784 .40165 m
.86609 .40956 L
s
.85753 .39698 m
.86609 .40956 L
s
.836 .173 .288 r
.50104 .36318 m .51228 .37684 L .53272 .36947 L F
.802 .206 .312 r
.48066 .37061 m .51228 .37684 L .50104 .36318 L F
.89 .66 .41 r
.28251 .42889 m
.26383 .4266 L
s
.25093 .41153 m
.26383 .4266 L
s
.379 .613 .623 r
.20791 .36261 m .22128 .37628 L .24058 .3689 L F
.375 .617 .626 r
.84644 .36261 m .85518 .37628 L .87698 .3689 L F
.377 .615 .624 r
.82469 .37004 m .85518 .37628 L .84644 .36261 L F
.89 .66 .41 r
.38764 .53657 m
.36928 .50962 L
s
.35679 .5004 m
.36928 .50962 L
s
.802 .206 .312 r
.55332 .36204 m .56419 .37571 L .58485 .36833 L F
.813 .195 .304 r
.53272 .36947 m .56419 .37571 L .55332 .36204 L F
.398 .595 .609 r
.26003 .36146 m .27303 .37515 L .29254 .36776 L F
.388 .605 .616 r
.24058 .3689 m .27303 .37515 L .26003 .36146 L F
.89 .66 .41 r
.31358 .45375 m
.29515 .44444 L
s
.28251 .42889 m
.29515 .44444 L
s
.83592 .40601 m
.81455 .41593 L
s
.80584 .40595 m
.81455 .41593 L
s
.682 .322 .401 r
.60567 .36089 m .61616 .37458 L .63704 .36719 L F
.723 .282 .37 r
.58485 .36833 m .61616 .37458 L .60567 .36089 L F
.89 .66 .41 r
.61994 .56263 m
.59914 .56926 L
s
.58946 .6038 m
.59914 .56926 L
s
.25093 .41153 m
.23203 .41386 L
s
.21884 .39939 m
.23203 .41386 L
s
.449 .546 .571 r
.31221 .36031 m .32484 .37401 L .34457 .36662 L F
.422 .571 .591 r
.29254 .36776 m .32484 .37401 L .31221 .36031 L F
.545 .453 .501 r
.65808 .35974 m .6682 .37345 L .68929 .36605 L F
.59 .411 .468 r
.63704 .36719 m .6682 .37345 L .65808 .35974 L F
.55 .449 .497 r
.36446 .35916 m .37672 .37288 L .39666 .36547 L F
.5 .497 .534 r
.34457 .36662 m .37672 .37288 L .36446 .35916 L F
.447 .547 .573 r
.71055 .35859 m .7203 .37231 L .74161 .3649 L F
.477 .519 .551 r
.68929 .36605 m .7203 .37231 L .71055 .35859 L F
.69 .314 .395 r
.41677 .35801 m .42865 .37175 L .44882 .36433 L F
.625 .376 .442 r
.39666 .36547 m .42865 .37175 L .41677 .35801 L F
.398 .595 .609 r
.76309 .35743 m .77246 .37118 L .79399 .36376 L F
.411 .582 .599 r
.74161 .3649 m .77246 .37118 L .76309 .35743 L F
.813 .195 .304 r
.46915 .35686 m .48066 .37061 L .50104 .36318 L F
.761 .246 .343 r
.44882 .36433 m .48066 .37061 L .46915 .35686 L F
.89 .66 .41 r
.88784 .40165 m
.87937 .38858 L
s
.379 .613 .623 r
.81569 .35628 m .82469 .37004 L .84644 .36261 L F
.384 .609 .619 r
.79399 .36376 m .82469 .37004 L .81569 .35628 L F
.89 .66 .41 r
.3443 .48753 m
.32607 .46896 L
s
.31358 .45375 m
.32607 .46896 L
s
.848 .162 .279 r
.52158 .3557 m .53272 .36947 L .55332 .36204 L F
.836 .173 .288 r
.50104 .36318 m .53272 .36947 L .52158 .3557 L F
.89 .66 .41 r
.85753 .39698 m
.83592 .40601 L
s
.82722 .39455 m
.83592 .40601 L
s
.385 .608 .619 r
.22729 .35512 m .24058 .3689 L .26003 .36146 L F
.379 .613 .623 r
.20791 .36261 m .24058 .3689 L .22729 .35512 L F
.375 .617 .626 r
.84644 .36261 m .87698 .3689 L .86836 .35512 L F
.771 .236 .335 r
.57409 .35455 m .58485 .36833 L .60567 .36089 L F
.802 .206 .312 r
.55332 .36204 m .58485 .36833 L .57409 .35455 L F
.414 .579 .597 r
.27963 .35397 m .29254 .36776 L .31221 .36031 L F
.398 .595 .609 r
.26003 .36146 m .29254 .36776 L .27963 .35397 L F
.89 .66 .41 r
.41893 .57223 m
.40021 .53924 L
s
.38764 .53657 m
.40021 .53924 L
s
.632 .37 .438 r
.62666 .35339 m .63704 .36719 L .65808 .35974 L F
.682 .322 .401 r
.60567 .36089 m .63704 .36719 L .62666 .35339 L F
.89 .66 .41 r
.64072 .55062 m
.61994 .56263 L
s
.6107 .59716 m
.61994 .56263 L
s
.485 .511 .545 r
.33204 .35281 m .34457 .36662 L .36446 .35916 L F
.449 .546 .571 r
.31221 .36031 m .34457 .36662 L .33204 .35281 L F
.503 .494 .532 r
.67929 .35223 m .68929 .36605 L .71055 .35859 L F
.545 .453 .501 r
.65808 .35974 m .68929 .36605 L .67929 .35223 L F
.89 .66 .41 r
.51548 .61139 m
.49509 .58908 L
s
.48314 .61414 m
.49509 .58908 L
s
.76388 .43458 m
.74325 .45227 L
s
.73471 .45436 m
.74325 .45227 L
s
.74325 .45227 m
.72277 .47202 L
s
.607 .394 .456 r
.3845 .35165 m .39666 .36547 L .41677 .35801 L F
.55 .449 .497 r
.36446 .35916 m .39666 .36547 L .3845 .35165 L F
.89 .66 .41 r
.71432 .47993 m
.72277 .47202 L
s
.72277 .47202 m
.70236 .4931 L
s
.424 .57 .59 r
.73198 .35107 m .74161 .3649 L .76309 .35743 L F
.447 .547 .573 r
.71055 .35859 m .74161 .3649 L .73198 .35107 L F
.89 .66 .41 r
.78473 .41918 m
.76388 .43458 L
s
.75524 .43185 m
.76388 .43458 L
s
.751 .255 .35 r
.43704 .35049 m .44882 .36433 L .46915 .35686 L F
.69 .314 .395 r
.41677 .35801 m .44882 .36433 L .43704 .35049 L F
.89 .66 .41 r
.26977 .41236 m
.25093 .41153 L
s
.23789 .39604 m
.25093 .41153 L
s
.388 .605 .616 r
.78474 .34991 m .79399 .36376 L .81569 .35628 L F
.398 .595 .609 r
.76309 .35743 m .79399 .36376 L .78474 .34991 L F
.89 .66 .41 r
.69395 .50754 m
.70236 .4931 L
s
.70236 .4931 m
.68192 .5143 L
s
.848 .162 .279 r
.48963 .34932 m .50104 .36318 L .52158 .3557 L F
.813 .195 .304 r
.46915 .35686 m .50104 .36318 L .48963 .34932 L F
.89 .66 .41 r
.66139 .53404 m
.64072 .55062 L
s
.63185 .58259 m
.64072 .55062 L
s
.87937 .38858 m
.85753 .39698 L
s
.84888 .38453 m
.85753 .39698 L
s
.30106 .4365 m
.28251 .42889 L
s
.26977 .41236 m
.28251 .42889 L
s
.377 .615 .624 r
.19434 .34874 m .20791 .36261 L .22729 .35512 L F
.376 .616 .625 r
.83757 .34874 m .84644 .36261 L .86836 .35512 L F
.379 .613 .623 r
.81569 .35628 m .84644 .36261 L .83757 .34874 L F
.89 .66 .41 r
.80584 .40595 m
.78473 .41918 L
s
.776 .41273 m
.78473 .41918 L
s
.67347 .53544 m
.68192 .5143 L
s
.68192 .5143 m
.66139 .53404 L
s
.836 .173 .288 r
.54229 .34816 m .55332 .36204 L .57409 .35455 L F
.848 .162 .279 r
.52158 .3557 m .55332 .36204 L .54229 .34816 L F
.89 .66 .41 r
.65279 .5613 m
.66139 .53404 L
s
.393 .6 .612 r
.24684 .34758 m .26003 .36146 L .27963 .35397 L F
.385 .608 .619 r
.22729 .35512 m .26003 .36146 L .24684 .34758 L F
.89 .66 .41 r
.23789 .39604 m
.21884 .39939 L
s
.20546 .38472 m
.21884 .39939 L
s
.723 .282 .37 r
.59502 .34699 m .60567 .36089 L .62666 .35339 L F
.771 .236 .335 r
.57409 .35455 m .60567 .36089 L .59502 .34699 L F
.89 .66 .41 r
.56828 .60254 m
.54733 .59469 L
s
.53641 .63123 m
.54733 .59469 L
s
.45081 .60023 m
.43152 .5657 L
s
.41893 .57223 m
.43152 .5657 L
s
.437 .558 .58 r
.2994 .34641 m .31221 .36031 L .33204 .35281 L F
.414 .579 .597 r
.27963 .35397 m .31221 .36031 L .2994 .34641 L F
.89 .66 .41 r
.37503 .52924 m
.35679 .5004 L
s
.3443 .48753 m
.35679 .5004 L
s
.579 .421 .476 r
.64781 .34583 m .65808 .35974 L .67929 .35223 L F
.632 .37 .438 r
.62666 .35339 m .65808 .35974 L .64781 .34583 L F
.89 .66 .41 r
.48314 .61414 m
.46322 .58352 L
s
.45081 .60023 m
.46322 .58352 L
s
.529 .469 .513 r
.35202 .34524 m .36446 .35916 L .3845 .35165 L F
.485 .511 .545 r
.33204 .35281 m .36446 .35916 L .35202 .34524 L F
.89 .66 .41 r
.82722 .39455 m
.80584 .40595 L
s
.79706 .39678 m
.80584 .40595 L
s
.467 .529 .558 r
.70066 .34466 m .71055 .35859 L .73198 .35107 L F
.503 .494 .532 r
.67929 .35223 m .71055 .35859 L .70066 .34466 L F
.667 .336 .412 r
.40471 .34407 m .41677 .35801 L .43704 .35049 L F
.607 .394 .456 r
.3845 .35165 m .41677 .35801 L .40471 .34407 L F
.406 .588 .603 r
.75358 .34349 m .76309 .35743 L .78474 .34991 L F
.424 .57 .59 r
.73198 .35107 m .76309 .35743 L .75358 .34349 L F
.89 .66 .41 r
.33186 .47097 m
.31358 .45375 L
s
.30106 .4365 m
.31358 .45375 L
s
.802 .206 .312 r
.45746 .3429 m .46915 .35686 L .48963 .34932 L F
.751 .255 .35 r
.43704 .35049 m .46915 .35686 L .45746 .3429 L F
.382 .611 .621 r
.80657 .34232 m .81569 .35628 L .83757 .34874 L F
.388 .605 .616 r
.78474 .34991 m .81569 .35628 L .80657 .34232 L F
.89 .66 .41 r
.87937 .38858 m
.87079 .37549 L
s
.86 .15 .27 r
.51028 .34173 m .52158 .3557 L .54229 .34816 L F
.848 .162 .279 r
.48963 .34932 m .52158 .3557 L .51028 .34173 L F
.382 .611 .621 r
.21382 .34114 m .22729 .35512 L .24684 .34758 L F
.377 .615 .624 r
.19434 .34874 m .22729 .35512 L .21382 .34114 L F
.376 .616 .625 r
.83757 .34874 m .86836 .35512 L .85962 .34114 L F
.802 .206 .312 r
.56317 .34056 m .57409 .35455 L .59502 .34699 L F
.836 .173 .288 r
.54229 .34816 m .57409 .35455 L .56317 .34056 L F
.89 .66 .41 r
.84888 .38453 m
.82722 .39455 L
s
.81843 .38349 m
.82722 .39455 L
s
.406 .588 .603 r
.26653 .33997 m .27963 .35397 L .2994 .34641 L F
.393 .6 .612 r
.24684 .34758 m .27963 .35397 L .26653 .33997 L F
.667 .336 .412 r
.61612 .33938 m .62666 .35339 L .64781 .34583 L F
.723 .282 .37 r
.59502 .34699 m .62666 .35339 L .61612 .33938 L F
.467 .529 .558 r
.31932 .33879 m .33204 .35281 L .35202 .34524 L F
.437 .558 .58 r
.2994 .34641 m .33204 .35281 L .31932 .33879 L F
.529 .469 .513 r
.66913 .33821 m .67929 .35223 L .70066 .34466 L F
.579 .421 .476 r
.64781 .34583 m .67929 .35223 L .66913 .33821 L F
.37217 .33762 m .3845 .35165 L .40471 .34407 L F
.529 .469 .513 r
.35202 .34524 m .3845 .35165 L .37217 .33762 L F
.89 .66 .41 r
.2569 .39527 m
.23789 .39604 L
s
.22467 .38036 m
.23789 .39604 L
s
.437 .558 .58 r
.72221 .33703 m .73198 .35107 L .75358 .34349 L F
.467 .529 .558 r
.70066 .34466 m .73198 .35107 L .72221 .33703 L F
.89 .66 .41 r
.28849 .41775 m
.26977 .41236 L
s
.2569 .39527 m
.26977 .41236 L
s
.723 .282 .37 r
.42508 .33644 m .43704 .35049 L .45746 .3429 L F
.667 .336 .412 r
.40471 .34407 m .43704 .35049 L .42508 .33644 L F
.393 .6 .612 r
.77536 .33585 m .78474 .34991 L .80657 .34232 L F
.406 .588 .603 r
.75358 .34349 m .78474 .34991 L .77536 .33585 L F
.836 .173 .288 r
.47806 .33526 m .48963 .34932 L .51028 .34173 L F
.802 .206 .312 r
.45746 .3429 m .48963 .34932 L .47806 .33526 L F
.376 .616 .625 r
.18057 .33467 m .19434 .34874 L .21382 .34114 L F
.377 .615 .624 r
.82857 .33467 m .83757 .34874 L .85962 .34114 L F
.382 .611 .621 r
.80657 .34232 m .83757 .34874 L .82857 .33467 L F
.89 .66 .41 r
.87079 .37549 m
.84888 .38453 L
s
.84012 .37222 m
.84888 .38453 L
s
.848 .162 .279 r
.5311 .33408 m .54229 .34816 L .56317 .34056 L F
.86 .15 .27 r
.51028 .34173 m .54229 .34816 L .5311 .33408 L F
.89 .66 .41 r
.22467 .38036 m
.20546 .38472 L
s
.19189 .36994 m
.20546 .38472 L
s
.388 .605 .616 r
.23345 .33348 m .24684 .34758 L .26653 .33997 L F
.382 .611 .621 r
.21382 .34114 m .24684 .34758 L .23345 .33348 L F
.89 .66 .41 r
.40617 .57426 m
.38764 .53657 L
s
.37503 .52924 m
.38764 .53657 L
s
.751 .255 .35 r
.58421 .33289 m .59502 .34699 L .61612 .33938 L F
.802 .206 .312 r
.56317 .34056 m .59502 .34699 L .58421 .33289 L F
.424 .57 .59 r
.28639 .3323 m .2994 .34641 L .31932 .33879 L F
.406 .588 .603 r
.26653 .33997 m .2994 .34641 L .28639 .3323 L F
.89 .66 .41 r
.36247 .51638 m
.3443 .48753 L
s
.33186 .47097 m
.3443 .48753 L
s
.31946 .45121 m
.30106 .4365 L
s
.28849 .41775 m
.30106 .4365 L
s
.607 .394 .456 r
.63739 .33171 m .64781 .34583 L .66913 .33821 L F
.667 .336 .412 r
.61612 .33938 m .64781 .34583 L .63739 .33171 L F
.503 .494 .532 r
.3394 .33112 m .35202 .34524 L .37217 .33762 L F
.467 .529 .558 r
.31932 .33879 m .35202 .34524 L .3394 .33112 L F
.485 .511 .545 r
.69063 .33052 m .70066 .34466 L .72221 .33703 L F
.529 .469 .513 r
.66913 .33821 m .70066 .34466 L .69063 .33052 L F
.89 .66 .41 r
.58946 .6038 m
.56828 .60254 L
s
.55781 .64499 m
.56828 .60254 L
s
.79706 .39678 m
.776 .41273 L
s
.76722 .40752 m
.776 .41273 L
s
.776 .41273 m
.75524 .43185 L
s
.74656 .43116 m
.75524 .43185 L
s
.75524 .43185 m
.73471 .45436 L
s
.632 .37 .438 r
.39247 .32993 m .40471 .34407 L .42508 .33644 L F
.579 .421 .476 r
.37217 .33762 m .40471 .34407 L .39247 .32993 L F
.414 .579 .597 r
.74393 .32933 m .75358 .34349 L .77536 .33585 L F
.437 .558 .58 r
.72221 .33703 m .75358 .34349 L .74393 .32933 L F
.771 .236 .335 r
.44561 .32874 m .45746 .3429 L .47806 .33526 L F
.723 .282 .37 r
.42508 .33644 m .45746 .3429 L .44561 .32874 L F
.385 .608 .619 r
.79731 .32815 m .80657 .34232 L .82857 .33467 L F
.393 .6 .612 r
.77536 .33585 m .80657 .34232 L .79731 .32815 L F
.89 .66 .41 r
.81843 .38349 m
.79706 .39678 L
s
.7882 .3883 m
.79706 .39678 L
s
.72615 .45953 m
.73471 .45436 L
s
.73471 .45436 m
.71432 .47993 L
s
.848 .162 .279 r
.49882 .32755 m .51028 .34173 L .5311 .33408 L F
.836 .173 .288 r
.47806 .33526 m .51028 .34173 L .49882 .32755 L F
.89 .66 .41 r
.87079 .37549 m
.86209 .36237 L
s
.379 .613 .623 r
.20014 .32696 m .21382 .34114 L .23345 .33348 L F
.376 .616 .625 r
.18057 .33467 m .21382 .34114 L .20014 .32696 L F
.377 .615 .624 r
.82857 .33467 m .85962 .34114 L .85075 .32696 L F
.89 .66 .41 r
.53641 .63123 m
.51548 .61139 L
s
.50371 .646 m
.51548 .61139 L
s
.813 .195 .304 r
.55209 .32636 m .56317 .34056 L .58421 .33289 L F
.848 .162 .279 r
.5311 .33408 m .56317 .34056 L .55209 .32636 L F
.398 .595 .609 r
.25324 .32576 m .26653 .33997 L .28639 .3323 L F
.388 .605 .616 r
.23345 .33348 m .26653 .33997 L .25324 .32576 L F
.69 .314 .395 r
.60542 .32517 m .61612 .33938 L .63739 .33171 L F
.751 .255 .35 r
.58421 .33289 m .61612 .33938 L .60542 .32517 L F
.89 .66 .41 r
.27584 .39818 m
.2569 .39527 L
s
.24387 .37798 m
.2569 .39527 L
s
.447 .547 .573 r
.30641 .32457 m .31932 .33879 L .3394 .33112 L F
.424 .57 .59 r
.28639 .3323 m .31932 .33879 L .30641 .32457 L F
.89 .66 .41 r
.24387 .37798 m
.22467 .38036 L
s
.21125 .36465 m
.22467 .38036 L
s
.84012 .37222 m
.81843 .38349 L
s
.80955 .37275 m
.81843 .38349 L
s
.55 .449 .497 r
.65883 .32397 m .66913 .33821 L .69063 .33052 L F
.607 .394 .456 r
.63739 .33171 m .66913 .33821 L .65883 .32397 L F
.89 .66 .41 r
.70587 .49225 m
.71432 .47993 L
s
.71432 .47993 m
.69395 .50754 L
s
.545 .453 .501 r
.35964 .32338 m .37217 .33762 L .39247 .32993 L F
.503 .494 .532 r
.3394 .33112 m .37217 .33762 L .35964 .32338 L F
.449 .546 .571 r
.7123 .32278 m .72221 .33703 L .74393 .32933 L F
.485 .511 .545 r
.69063 .33052 m .72221 .33703 L .7123 .32278 L F
.682 .322 .401 r
.41294 .32218 m .42508 .33644 L .44561 .32874 L F
.632 .37 .438 r
.39247 .32993 m .42508 .33644 L .41294 .32218 L F
.398 .595 .609 r
.76583 .32158 m .77536 .33585 L .79731 .32815 L F
.414 .579 .597 r
.74393 .32933 m .77536 .33585 L .76583 .32158 L F
.802 .206 .312 r
.46631 .32098 m .47806 .33526 L .49882 .32755 L F
.771 .236 .335 r
.44561 .32874 m .47806 .33526 L .46631 .32098 L F
.89 .66 .41 r
.30709 .42919 m
.28849 .41775 L
s
.27584 .39818 m
.28849 .41775 L
s
.43807 .61443 m
.41893 .57223 L
s
.40617 .57426 m
.41893 .57223 L
s
.21125 .36465 m
.19189 .36994 L
s
.1781 .3551 m
.19189 .36994 L
s
.375 .617 .626 r
.1666 .32038 m .18057 .33467 L .20014 .32696 L F
.379 .613 .623 r
.81943 .32038 m .82857 .33467 L .85075 .32696 L F
.385 .608 .619 r
.79731 .32815 m .82857 .33467 L .81943 .32038 L F
.89 .66 .41 r
.35004 .49792 m
.33186 .47097 L
s
.31946 .45121 m
.33186 .47097 L
s
.836 .173 .288 r
.51974 .31978 m .5311 .33408 L .55209 .32636 L F
.848 .162 .279 r
.49882 .32755 m .5311 .33408 L .51974 .31978 L F
.384 .609 .619 r
.21986 .31918 m .23345 .33348 L .25324 .32576 L F
.379 .613 .623 r
.20014 .32696 m .23345 .33348 L .21986 .31918 L F
.89 .66 .41 r
.86209 .36237 m
.84012 .37222 L
s
.83125 .36 m
.84012 .37222 L
s
.761 .246 .343 r
.57324 .31858 m .58421 .33289 L .60542 .32517 L F
.813 .195 .304 r
.55209 .32636 m .58421 .33289 L .57324 .31858 L F
.89 .66 .41 r
.68555 .52796 m
.69395 .50754 L
s
.69395 .50754 m
.67347 .53544 L
s
.411 .582 .599 r
.27319 .31798 m .28639 .3323 L .30641 .32457 L F
.398 .595 .609 r
.25324 .32576 m .28639 .3323 L .27319 .31798 L F
.89 .66 .41 r
.6107 .59716 m
.58946 .6038 L
s
.5795 .64951 m
.58946 .6038 L
s
.625 .376 .442 r
.62681 .31738 m .63739 .33171 L .65883 .32397 L F
.69 .314 .395 r
.60542 .32517 m .63739 .33171 L .62681 .31738 L F
.477 .519 .551 r
.32659 .31678 m .3394 .33112 L .35964 .32338 L F
.447 .547 .573 r
.30641 .32457 m .3394 .33112 L .32659 .31678 L F
.5 .497 .534 r
.68044 .31618 m .69063 .33052 L .7123 .32278 L F
.55 .449 .497 r
.65883 .32397 m .69063 .33052 L .68044 .31618 L F
.59 .411 .468 r
.38005 .31557 m .39247 .32993 L .41294 .32218 L F
.545 .453 .501 r
.35964 .32338 m .39247 .32993 L .38005 .31557 L F
.89 .66 .41 r
.39339 .56955 m
.37503 .52924 L
s
.36247 .51638 m
.37503 .52924 L
s
.50371 .646 m
.48314 .61414 L
s
.47072 .64043 m
.48314 .61414 L
s
.422 .571 .591 r
.73414 .31497 m .74393 .32933 L .76583 .32158 L F
.449 .546 .571 r
.7123 .32278 m .74393 .32933 L .73414 .31497 L F
.723 .282 .37 r
.43358 .31437 m .44561 .32874 L .46631 .32098 L F
.682 .322 .401 r
.41294 .32218 m .44561 .32874 L .43358 .31437 L F
.388 .605 .616 r
.78791 .31376 m .79731 .32815 L .81943 .32038 L F
.398 .595 .609 r
.76583 .32158 m .79731 .32815 L .78791 .31376 L F
.89 .66 .41 r
.47072 .64043 m
.45081 .60023 L
s
.43807 .61443 m
.45081 .60023 L
s
.813 .195 .304 r
.48717 .31316 m .49882 .32755 L .51974 .31978 L F
.802 .206 .312 r
.46631 .32098 m .49882 .32755 L .48717 .31316 L F
.89 .66 .41 r
.26304 .37843 m
.24387 .37798 L
s
.23064 .3608 m
.24387 .37798 L
s
.86209 .36237 m
.85328 .3492 L
s
.377 .615 .624 r
.18625 .31255 m .20014 .32696 L .21986 .31918 L F
.375 .617 .626 r
.1666 .32038 m .20014 .32696 L .18625 .31255 L F
.379 .613 .623 r
.81943 .32038 m .85075 .32696 L .84174 .31255 L F
.89 .66 .41 r
.66501 .56423 m
.67347 .53544 L
s
.67347 .53544 m
.65279 .5613 L
s
.802 .206 .312 r
.54084 .31195 m .55209 .32636 L .57324 .31858 L F
.836 .173 .288 r
.51974 .31978 m .55209 .32636 L .54084 .31195 L F
.391 .602 .614 r
.23975 .31134 m .25324 .32576 L .27319 .31798 L F
.384 .609 .619 r
.21986 .31918 m .25324 .32576 L .23975 .31134 L F
.89 .66 .41 r
.23064 .3608 m
.21125 .36465 L
s
.19761 .34902 m
.21125 .36465 L
s
.698 .306 .389 r
.59457 .31074 m .60542 .32517 L .62681 .31738 L F
.761 .246 .343 r
.57324 .31858 m .60542 .32517 L .59457 .31074 L F
.89 .66 .41 r
.29468 .40597 m
.27584 .39818 L
s
.26304 .37843 m
.27584 .39818 L
s
.429 .565 .586 r
.29331 .31013 m .30641 .32457 L .32659 .31678 L F
.411 .582 .599 r
.27319 .31798 m .30641 .32457 L .29331 .31013 L F
.89 .66 .41 r
.7882 .3883 m
.76722 .40752 L
s
.75832 .40309 m
.76722 .40752 L
s
.76722 .40752 m
.74656 .43116 L
s
.80955 .37275 m
.7882 .3883 L
s
.77923 .38021 m
.7882 .3883 L
s
.63185 .58259 m
.6107 .59716 L
s
.60126 .64289 m
.6107 .59716 L
s
.33776 .47465 m
.31946 .45121 L
s
.30709 .42919 m
.31946 .45121 L
s
.564 .435 .487 r
.64837 .30953 m .65883 .32397 L .68044 .31618 L F
.625 .376 .442 r
.62681 .31738 m .65883 .32397 L .64837 .30953 L F
.51 .487 .527 r
.34693 .30892 m .35964 .32338 L .38005 .31557 L F
.477 .519 .551 r
.32659 .31678 m .35964 .32338 L .34693 .30892 L F
.46 .536 .564 r
.70223 .30831 m .7123 .32278 L .73414 .31497 L F
.5 .497 .534 r
.68044 .31618 m .7123 .32278 L .70223 .30831 L F
.89 .66 .41 r
.64413 .5978 m
.65279 .5613 L
s
.65279 .5613 m
.63185 .58259 L
s
.632 .37 .438 r
.40062 .30771 m .41294 .32218 L .43358 .31437 L F
.59 .411 .468 r
.38005 .31557 m .41294 .32218 L .40062 .30771 L F
.89 .66 .41 r
.83125 .36 m
.80955 .37275 L
s
.80055 .36216 m
.80955 .37275 L
s
.73777 .43179 m
.74656 .43116 L
s
.74656 .43116 m
.72615 .45953 L
s
.403 .59 .605 r
.75616 .3071 m .76583 .32158 L .78791 .31376 L F
.422 .571 .591 r
.73414 .31497 m .76583 .32158 L .75616 .3071 L F
.89 .66 .41 r
.62286 .62506 m
.63185 .58259 L
s
.751 .255 .35 r
.45438 .30649 m .46631 .32098 L .48717 .31316 L F
.723 .282 .37 r
.43358 .31437 m .46631 .32098 L .45438 .30649 L F
.89 .66 .41 r
.19761 .34902 m
.1781 .3551 L
s
.16408 .34024 m
.1781 .3551 L
s
.374 .618 .626 r
.15242 .30588 m .1666 .32038 L .18625 .31255 L F
.381 .612 .621 r
.81016 .30588 m .81943 .32038 L .84174 .31255 L F
.388 .605 .616 r
.78791 .31376 m .81943 .32038 L .81016 .30588 L F
.802 .206 .312 r
.50821 .30527 m .51974 .31978 L .54084 .31195 L F
.813 .195 .304 r
.48717 .31316 m .51974 .31978 L .50821 .30527 L F
.38 .612 .622 r
.20607 .30466 m .21986 .31918 L .23975 .31134 L F
.377 .615 .624 r
.18625 .31255 m .21986 .31918 L .20607 .30466 L F
.751 .255 .35 r
.56211 .30405 m .57324 .31858 L .59457 .31074 L F
.802 .206 .312 r
.54084 .31195 m .57324 .31858 L .56211 .30405 L F
.4 .593 .607 r
.25979 .30344 m .27319 .31798 L .29331 .31013 L F
.391 .602 .614 r
.23975 .31134 m .27319 .31798 L .25979 .30344 L F
.89 .66 .41 r
.85328 .3492 m
.83125 .36 L
s
.82226 .34776 m
.83125 .36 L
s
.632 .37 .438 r
.61607 .30283 m .62681 .31738 L .64837 .30953 L F
.698 .306 .389 r
.59457 .31074 m .62681 .31738 L .61607 .30283 L F
.89 .66 .41 r
.55781 .64499 m
.53641 .63123 L
s
.52497 .67479 m
.53641 .63123 L
s
.451 .544 .57 r
.31358 .30222 m .32659 .31678 L .34693 .30892 L F
.429 .565 .586 r
.29331 .31013 m .32659 .31678 L .31358 .30222 L F
.51 .487 .527 r
.6701 .30161 m .68044 .31618 L .70223 .30831 L F
.564 .435 .487 r
.64837 .30953 m .68044 .31618 L .6701 .30161 L F
.89 .66 .41 r
.71749 .4668 m
.72615 .45953 L
s
.72615 .45953 m
.70587 .49225 L
s
.545 .453 .501 r
.36744 .301 m .38005 .31557 L .40062 .30771 L F
.51 .487 .527 r
.34693 .30892 m .38005 .31557 L .36744 .301 L F
.89 .66 .41 r
.38073 .55674 m
.36247 .51638 L
s
.35004 .49792 m
.36247 .51638 L
s
.32559 .44801 m
.30709 .42919 L
s
.29468 .40597 m
.30709 .42919 L
s
.25005 .35901 m
.23064 .3608 L
s
.21719 .34392 m
.23064 .3608 L
s
.429 .565 .586 r
.7242 .30039 m .73414 .31497 L .75616 .3071 L F
.46 .536 .564 r
.70223 .30831 m .73414 .31497 L .7242 .30039 L F
.667 .336 .412 r
.42137 .29978 m .43358 .31437 L .45438 .30649 L F
.632 .37 .438 r
.40062 .30771 m .43358 .31437 L .42137 .29978 L F
.89 .66 .41 r
.28215 .38262 m
.26304 .37843 L
s
.25005 .35901 m
.26304 .37843 L
s
.391 .602 .614 r
.77836 .29916 m .78791 .31376 L .81016 .30588 L F
.403 .59 .605 r
.75616 .3071 m .78791 .31376 L .77836 .29916 L F
.761 .246 .343 r
.47536 .29855 m .48717 .31316 L .50821 .30527 L F
.751 .255 .35 r
.45438 .30649 m .48717 .31316 L .47536 .29855 L F
.375 .617 .625 r
.17216 .29794 m .18625 .31255 L .20607 .30466 L F
.374 .618 .626 r
.15242 .30588 m .18625 .31255 L .17216 .29794 L F
.381 .612 .621 r
.81016 .30588 m .84174 .31255 L .8326 .29794 L F
.89 .66 .41 r
.21719 .34392 m
.19761 .34902 L
s
.18374 .3335 m
.19761 .34902 L
s
.771 .236 .335 r
.52942 .29732 m .54084 .31195 L .56211 .30405 L F
.802 .206 .312 r
.50821 .30527 m .54084 .31195 L .52942 .29732 L F
.89 .66 .41 r
.85328 .3492 m
.84435 .33593 L
s
.42512 .62247 m
.40617 .57426 L
s
.39339 .56955 m
.40617 .57426 L
s
.385 .608 .618 r
.22605 .29671 m .23975 .31134 L .25979 .30344 L F
.38 .612 .622 r
.20607 .30466 m .23975 .31134 L .22605 .29671 L F
.69 .314 .395 r
.58355 .29609 m .59457 .31074 L .61607 .30283 L F
.751 .255 .35 r
.56211 .30405 m .59457 .31074 L .58355 .29609 L F
.413 .58 .598 r
.28 .29548 m .29331 .31013 L .31358 .30222 L F
.4 .593 .607 r
.25979 .30344 m .29331 .31013 L .28 .29548 L F
.569 .431 .484 r
.63775 .29486 m .64837 .30953 L .6701 .30161 L F
.632 .37 .438 r
.61607 .30283 m .64837 .30953 L .63775 .29486 L F
.477 .519 .551 r
.33403 .29425 m .34693 .30892 L .36744 .301 L F
.451 .544 .57 r
.31358 .30222 m .34693 .30892 L .33403 .29425 L F
.467 .529 .558 r
.69201 .29363 m .70223 .30831 L .7242 .30039 L F
.51 .487 .527 r
.6701 .30161 m .70223 .30831 L .69201 .29363 L F
.579 .421 .476 r
.38812 .29301 m .40062 .30771 L .42137 .29978 L F
.545 .453 .501 r
.36744 .301 m .40062 .30771 L .38812 .29301 L F
.408 .586 .602 r
.74635 .2924 m .75616 .3071 L .77836 .29916 L F
.429 .565 .586 r
.7242 .30039 m .75616 .3071 L .74635 .2924 L F
.89 .66 .41 r
.6973 .50768 m
.70587 .49225 L
s
.70587 .49225 m
.68555 .52796 L
s
.18374 .3335 m
.16408 .34024 L
s
.14984 .32532 m
.16408 .34024 L
s
.31345 .4197 m
.29468 .40597 L
s
.28215 .38262 m
.29468 .40597 L
s
.69 .314 .395 r
.44228 .29178 m .45438 .30649 L .47536 .29855 L F
.667 .336 .412 r
.42137 .29978 m .45438 .30649 L .44228 .29178 L F
.89 .66 .41 r
.80055 .36216 m
.77923 .38021 L
s
.77009 .372 m
.77923 .38021 L
s
.77923 .38021 m
.75832 .40309 L
s
.373 .619 .627 r
.13802 .29116 m .15242 .30588 L .17216 .29794 L F
.383 .61 .62 r
.80075 .29116 m .81016 .30588 L .8326 .29794 L F
.391 .602 .614 r
.77836 .29916 m .81016 .30588 L .80075 .29116 L F
.751 .255 .35 r
.49651 .29054 m .50821 .30527 L .52942 .29732 L F
.761 .246 .343 r
.47536 .29855 m .50821 .30527 L .49651 .29054 L F
.89 .66 .41 r
.82226 .34776 m
.80055 .36216 L
s
.79138 .3514 m
.80055 .36216 L
s
.377 .615 .624 r
.19207 .28993 m .20607 .30466 L .22605 .29671 L F
.375 .617 .625 r
.17216 .29794 m .20607 .30466 L .19207 .28993 L F
.89 .66 .41 r
.36829 .53574 m
.35004 .49792 L
s
.33776 .47465 m
.35004 .49792 L
s
.723 .282 .37 r
.5508 .28931 m .56211 .30405 L .58355 .29609 L F
.771 .236 .335 r
.52942 .29732 m .56211 .30405 L .5508 .28931 L F
.89 .66 .41 r
.74923 .39861 m
.75832 .40309 L
s
.75832 .40309 m
.73777 .43179 L
s
.392 .601 .614 r
.24619 .28869 m .25979 .30344 L .28 .29548 L F
.385 .608 .618 r
.22605 .29671 m .25979 .30344 L .24619 .28869 L F
.89 .66 .41 r
.26945 .35994 m
.25005 .35901 L
s
.23682 .34023 m
.25005 .35901 L
s
.625 .376 .442 r
.60517 .28807 m .61607 .30283 L .63775 .29486 L F
.69 .314 .395 r
.58355 .29609 m .61607 .30283 L .60517 .28807 L F
.89 .66 .41 r
.23682 .34023 m
.21719 .34392 L
s
.20349 .32739 m
.21719 .34392 L
s
.429 .565 .586 r
.30038 .28745 m .31358 .30222 L .33403 .29425 L F
.413 .58 .598 r
.28 .29548 m .31358 .30222 L .30038 .28745 L F
.89 .66 .41 r
.84435 .33593 m
.82226 .34776 L
s
.81312 .33534 m
.82226 .34776 L
s
.514 .484 .524 r
.6596 .28683 m .6701 .30161 L .69201 .29363 L F
.569 .431 .484 r
.63775 .29486 m .6701 .30161 L .6596 .28683 L F
.503 .494 .532 r
.35464 .28621 m .36744 .301 L .38812 .29301 L F
.477 .519 .551 r
.33403 .29425 m .36744 .301 L .35464 .28621 L F
.434 .561 .583 r
.7141 .28558 m .7242 .30039 L .74635 .2924 L F
.467 .529 .558 r
.69201 .29363 m .7242 .30039 L .7141 .28558 L F
.607 .394 .456 r
.40897 .28496 m .42137 .29978 L .44228 .29178 L F
.579 .421 .476 r
.38812 .29301 m .42137 .29978 L .40897 .28496 L F
.393 .6 .612 r
.76868 .28434 m .77836 .29916 L .80075 .29116 L F
.408 .586 .602 r
.74635 .2924 m .77836 .29916 L .76868 .28434 L F
.698 .306 .389 r
.46336 .28372 m .47536 .29855 L .49651 .29054 L F
.69 .314 .395 r
.44228 .29178 m .47536 .29855 L .46336 .28372 L F
.89 .66 .41 r
.30124 .39133 m
.28215 .38262 L
s
.26945 .35994 m
.28215 .38262 L
s
.20349 .32739 m
.18374 .3335 L
s
.16963 .31807 m
.18374 .3335 L
s
.374 .618 .626 r
.15785 .2831 m .17216 .29794 L .19207 .28993 L F
.373 .619 .627 r
.13802 .29116 m .17216 .29794 L .15785 .2831 L F
.383 .61 .62 r
.80075 .29116 m .8326 .29794 L .82332 .2831 L F
.89 .66 .41 r
.52497 .67479 m
.50371 .646 L
s
.49139 .68252 m
.50371 .646 L
s
.72877 .43252 m
.73777 .43179 L
s
.73777 .43179 m
.71749 .4668 L
s
.723 .282 .37 r
.51783 .28247 m .52942 .29732 L .5508 .28931 L F
.751 .255 .35 r
.49651 .29054 m .52942 .29732 L .51783 .28247 L F
.89 .66 .41 r
.45787 .66365 m
.43807 .61443 L
s
.42512 .62247 m
.43807 .61443 L
s
.38 .612 .622 r
.21214 .28185 m .22605 .29671 L .24619 .28869 L F
.377 .615 .624 r
.19207 .28993 m .22605 .29671 L .21214 .28185 L F
.89 .66 .41 r
.5795 .64951 m
.55781 .64499 L
s
.54683 .6956 m
.55781 .64499 L
s
.677 .55272 m
.68555 .52796 L
s
.68555 .52796 m
.66501 .56423 L
s
.84435 .33593 m
.83527 .32245 L
s
.3561 .50777 m
.33776 .47465 L
s
.32559 .44801 m
.33776 .47465 L
s
.667 .336 .412 r
.57236 .28122 m .58355 .29609 L .60517 .28807 L F
.723 .282 .37 r
.5508 .28931 m .58355 .29609 L .57236 .28122 L F
.4 .593 .607 r
.2665 .2806 m .28 .29548 L .30038 .28745 L F
.392 .601 .614 r
.24619 .28869 m .28 .29548 L .2665 .2806 L F
.564 .435 .487 r
.62697 .27998 m .63775 .29486 L .6596 .28683 L F
.625 .376 .442 r
.60517 .28807 m .63775 .29486 L .62697 .27998 L F
.447 .547 .573 r
.32093 .27935 m .33403 .29425 L .35464 .28621 L F
.429 .565 .586 r
.30038 .28745 m .33403 .29425 L .32093 .27935 L F
.469 .527 .557 r
.68164 .27872 m .69201 .29363 L .7141 .28558 L F
.514 .484 .524 r
.6596 .28683 m .69201 .29363 L .68164 .27872 L F
.529 .469 .513 r
.37542 .2781 m .38812 .29301 L .40897 .28496 L F
.503 .494 .532 r
.35464 .28621 m .38812 .29301 L .37542 .2781 L F
.89 .66 .41 r
.16963 .31807 m
.14984 .32532 L
s
.13537 .31033 m
.14984 .32532 L
s
.41 .583 .6 r
.73638 .27747 m .74635 .2924 L .76868 .28434 L F
.434 .561 .583 r
.7141 .28558 m .74635 .2924 L .73638 .27747 L F
.89 .66 .41 r
.41214 .62112 m
.39339 .56955 L
s
.38073 .55674 m
.39339 .56955 L
s
.625 .376 .442 r
.42999 .27684 m .44228 .29178 L .46336 .28372 L F
.607 .394 .456 r
.40897 .28496 m .44228 .29178 L .42999 .27684 L F
.89 .66 .41 r
.25649 .33842 m
.23682 .34023 L
s
.22333 .3222 m
.23682 .34023 L
s
.373 .619 .627 r
.1234 .27622 m .13802 .29116 L .15785 .2831 L F
.384 .609 .619 r
.79119 .27622 m .80075 .29116 L .82332 .2831 L F
.393 .6 .612 r
.76868 .28434 m .80075 .29116 L .79119 .27622 L F
.89 .66 .41 r
.49139 .68252 m
.47072 .64043 L
s
.45787 .66365 m
.47072 .64043 L
s
.69 .314 .395 r
.48462 .27559 m .49651 .29054 L .51783 .28247 L F
.698 .306 .389 r
.46336 .28372 m .49651 .29054 L .48462 .27559 L F
.89 .66 .41 r
.34412 .47498 m
.32559 .44801 L
s
.31345 .4197 m
.32559 .44801 L
s
.375 .617 .625 r
.17785 .27496 m .19207 .28993 L .21214 .28185 L F
.374 .618 .626 r
.15785 .2831 m .19207 .28993 L .17785 .27496 L F
.89 .66 .41 r
.28886 .36413 m
.26945 .35994 L
s
.25649 .33842 m
.26945 .35994 L
s
.682 .322 .401 r
.53933 .27433 m .5508 .28931 L .57236 .28122 L F
.723 .282 .37 r
.51783 .28247 m .5508 .28931 L .53933 .27433 L F
.89 .66 .41 r
.22333 .3222 m
.20349 .32739 L
s
.18954 .3112 m
.20349 .32739 L
s
.385 .608 .618 r
.23238 .2737 m .24619 .28869 L .2665 .2806 L F
.38 .612 .622 r
.21214 .28185 m .24619 .28869 L .23238 .2737 L F
.607 .394 .456 r
.5941 .27308 m .60517 .28807 L .62697 .27998 L F
.667 .336 .412 r
.57236 .28122 m .60517 .28807 L .5941 .27308 L F
.89 .66 .41 r
.81312 .33534 m
.79138 .3514 L
s
.78203 .34008 m
.79138 .3514 L
s
.79138 .3514 m
.77009 .372 L
s
.70857 .47441 m
.71749 .4668 L
s
.71749 .4668 m
.6973 .50768 L
s
.411 .582 .599 r
.28698 .27245 m .30038 .28745 L .32093 .27935 L F
.4 .593 .607 r
.2665 .2806 m .30038 .28745 L .28698 .27245 L F
.89 .66 .41 r
.76071 .36301 m
.77009 .372 L
s
.77009 .372 m
.74923 .39861 L
s
.51 .487 .527 r
.64894 .27182 m .6596 .28683 L .68164 .27872 L F
.564 .435 .487 r
.62697 .27998 m .6596 .28683 L .64894 .27182 L F
.467 .529 .558 r
.34164 .27119 m .35464 .28621 L .37542 .2781 L F
.447 .547 .573 r
.32093 .27935 m .35464 .28621 L .34164 .27119 L F
.89 .66 .41 r
.65637 .59877 m
.66501 .56423 L
s
.66501 .56423 m
.64413 .5978 L
s
.83527 .32245 m
.81312 .33534 L
s
.80381 .3225 m
.81312 .33534 L
s
.435 .559 .581 r
.70386 .27055 m .7141 .28558 L .73638 .27747 L F
.469 .527 .557 r
.68164 .27872 m .7141 .28558 L .70386 .27055 L F
.55 .449 .497 r
.39638 .26992 m .40897 .28496 L .42999 .27684 L F
.529 .469 .513 r
.37542 .2781 m .40897 .28496 L .39638 .26992 L F
.89 .66 .41 r
.33226 .43991 m
.31345 .4197 L
s
.30124 .39133 m
.31345 .4197 L
s
.395 .598 .611 r
.75884 .26929 m .76868 .28434 L .79119 .27622 L F
.41 .583 .6 r
.73638 .27747 m .76868 .28434 L .75884 .26929 L F
.89 .66 .41 r
.18954 .3112 m
.16963 .31807 L
s
.15528 .30269 m
.16963 .31807 L
s
.632 .37 .438 r
.45118 .26866 m .46336 .28372 L .48462 .27559 L F
.625 .376 .442 r
.42999 .27684 m .46336 .28372 L .45118 .26866 L F
.373 .619 .627 r
.14333 .26803 m .15785 .2831 L .17785 .27496 L F
.1234 .27622 m .15785 .2831 L .14333 .26803 L F
.384 .609 .619 r
.79119 .27622 m .82332 .2831 L .8139 .26803 L F
.89 .66 .41 r
.73987 .39304 m
.74923 .39861 L
s
.74923 .39861 m
.72877 .43252 L
s
.667 .336 .412 r
.50606 .26739 m .51783 .28247 L .53933 .27433 L F
.69 .314 .395 r
.48462 .27559 m .51783 .28247 L .50606 .26739 L F
.377 .615 .624 r
.19802 .26676 m .21214 .28185 L .23238 .2737 L F
.375 .617 .625 r
.17785 .27496 m .21214 .28185 L .19802 .26676 L F
.89 .66 .41 r
.60126 .64289 m
.5795 .64951 L
s
.56909 .70405 m
.5795 .64951 L
s
.632 .37 .438 r
.561 .26613 m .57236 .28122 L .5941 .27308 L F
.682 .322 .401 r
.53933 .27433 m .57236 .28122 L .561 .26613 L F
.89 .66 .41 r
.83527 .32245 m
.82603 .30864 L
s
.391 .602 .614 r
.25279 .26549 m .2665 .2806 L .28698 .27245 L F
.385 .608 .618 r
.23238 .2737 m .2665 .2806 L .25279 .26549 L F
.55 .449 .497 r
.61602 .26486 m .62697 .27998 L .64894 .27182 L F
.607 .394 .456 r
.5941 .27308 m .62697 .27998 L .61602 .26486 L F
.89 .66 .41 r
.32038 .40493 m
.30124 .39133 L
s
.28886 .36413 m
.30124 .39133 L
s
.424 .57 .59 r
.30762 .26422 m .32093 .27935 L .34164 .27119 L F
.411 .582 .599 r
.28698 .27245 m .32093 .27935 L .30762 .26422 L F
.89 .66 .41 r
.27621 .33884 m
.25649 .33842 L
s
.24324 .31823 m
.25649 .33842 L
s
.24324 .31823 m
.22333 .3222 L
s
.20956 .30488 m
.22333 .3222 L
s
.467 .529 .558 r
.6711 .26359 m .68164 .27872 L .70386 .27055 L F
.51 .487 .527 r
.64894 .27182 m .68164 .27872 L .6711 .26359 L F
.485 .511 .545 r
.36253 .26295 m .37542 .2781 L .39638 .26992 L F
.467 .529 .558 r
.34164 .27119 m .37542 .2781 L .36253 .26295 L F
.89 .66 .41 r
.15528 .30269 m
.13537 .31033 L
s
.12066 .29522 m
.13537 .31033 L
s
.411 .582 .599 r
.72626 .26232 m .73638 .27747 L .75884 .26929 L F
.435 .559 .581 r
.70386 .27055 m .73638 .27747 L .72626 .26232 L F
.89 .66 .41 r
.39933 .60841 m
.38073 .55674 L
s
.36829 .53574 m
.38073 .55674 L
s
.63524 .64142 m
.64413 .5978 L
s
.64413 .5978 m
.62286 .62506 L
s
.564 .435 .487 r
.41751 .26168 m .42999 .27684 L .45118 .26866 L F
.55 .449 .497 r
.39638 .26992 m .42999 .27684 L .41751 .26168 L F
.373 .619 .627 r
.10855 .26104 m .1234 .27622 L .14333 .26803 L F
.385 .608 .618 r
.78149 .26104 m .79119 .27622 L .8139 .26803 L F
.395 .598 .611 r
.75884 .26929 m .79119 .27622 L .78149 .26104 L F
.625 .376 .442 r
.47255 .26041 m .48462 .27559 L .50606 .26739 L F
.632 .37 .438 r
.45118 .26866 m .48462 .27559 L .47255 .26041 L F
.89 .66 .41 r
.20956 .30488 m
.18954 .3112 L
s
.17532 .29525 m
.18954 .3112 L
s
.374 .618 .626 r
.16342 .25977 m .17785 .27496 L .19802 .26676 L F
.373 .619 .627 r
.14333 .26803 m .17785 .27496 L .16342 .25977 L F
.632 .37 .438 r
.52767 .25913 m .53933 .27433 L .561 .26613 L F
.667 .336 .412 r
.50606 .26739 m .53933 .27433 L .52767 .25913 L F
.38 .612 .622 r
.21836 .25849 m .23238 .2737 L .25279 .26549 L F
.377 .615 .624 r
.19802 .26676 m .23238 .2737 L .21836 .25849 L F
.89 .66 .41 r
.68843 .52383 m
.6973 .50768 L
s
.6973 .50768 m
.677 .55272 L
s
.62286 .62506 m
.60126 .64289 L
s
.59144 .69747 m
.60126 .64289 L
s
.30833 .37183 m
.28886 .36413 L
s
.27621 .33884 m
.28886 .36413 L
s
.71943 .43174 m
.72877 .43252 L
s
.72877 .43252 m
.70857 .47441 L
s
.579 .421 .476 r
.58286 .25785 m .5941 .27308 L .61602 .26486 L F
.632 .37 .438 r
.561 .26613 m .5941 .27308 L .58286 .25785 L F
.398 .595 .609 r
.27337 .25721 m .28698 .27245 L .30762 .26422 L F
.391 .602 .614 r
.25279 .26549 m .28698 .27245 L .27337 .25721 L F
.89 .66 .41 r
.61357 .67576 m
.62286 .62506 L
s
.5 .497 .534 r
.63812 .25657 m .64894 .27182 L .6711 .26359 L F
.55 .449 .497 r
.61602 .26486 m .64894 .27182 L .63812 .25657 L F
.437 .558 .58 r
.32844 .25593 m .34164 .27119 L .36253 .26295 L F
.424 .57 .59 r
.30762 .26422 m .34164 .27119 L .32844 .25593 L F
.89 .66 .41 r
.80381 .3225 m
.78203 .34008 L
s
.77243 .32778 m
.78203 .34008 L
s
.78203 .34008 m
.76071 .36301 L
s
.434 .561 .583 r
.69345 .25529 m .70386 .27055 L .72626 .26232 L F
.467 .529 .558 r
.6711 .26359 m .70386 .27055 L .69345 .25529 L F
.5 .497 .534 r
.38359 .25465 m .39638 .26992 L .41751 .26168 L F
.485 .511 .545 r
.36253 .26295 m .39638 .26992 L .38359 .25465 L F
.89 .66 .41 r
.17532 .29525 m
.15528 .30269 L
s
.14068 .28729 m
.15528 .30269 L
s
.82603 .30864 m
.80381 .3225 L
s
.7943 .309 m
.80381 .3225 L
s
.395 .598 .611 r
.74885 .25401 m .75884 .26929 L .78149 .26104 L F
.411 .582 .599 r
.72626 .26232 m .75884 .26929 L .74885 .25401 L F
.89 .66 .41 r
.44476 .67885 m
.42512 .62247 L
s
.41214 .62112 m
.42512 .62247 L
s
.75106 .35253 m
.76071 .36301 L
s
.76071 .36301 m
.73987 .39304 L
s
.569 .431 .484 r
.43881 .25337 m .45118 .26866 L .47255 .26041 L F
.564 .435 .487 r
.41751 .26168 m .45118 .26866 L .43881 .25337 L F
.89 .66 .41 r
.26324 .3157 m
.24324 .31823 L
s
.22969 .29929 m
.24324 .31823 L
s
.373 .619 .627 r
.12857 .25273 m .14333 .26803 L .16342 .25977 L F
.10855 .26104 m .14333 .26803 L .12857 .25273 L F
.385 .608 .618 r
.78149 .26104 m .8139 .26803 L .80433 .25273 L F
.89 .66 .41 r
.54683 .6956 m
.52497 .67479 L
s
.51292 .721 m
.52497 .67479 L
s
.607 .394 .456 r
.49411 .25208 m .50606 .26739 L .52767 .25913 L F
.625 .376 .442 r
.47255 .26041 m .50606 .26739 L .49411 .25208 L F
.89 .66 .41 r
.38683 .58421 m
.36829 .53574 L
s
.3561 .50777 m
.36829 .53574 L
s
.375 .617 .625 r
.18368 .25144 m .19802 .26676 L .21836 .25849 L F
.374 .618 .626 r
.16342 .25977 m .19802 .26676 L .18368 .25144 L F
.59 .411 .468 r
.54947 .2508 m .561 .26613 L .58286 .25785 L F
.632 .37 .438 r
.52767 .25913 m .561 .26613 L .54947 .2508 L F
.89 .66 .41 r
.22969 .29929 m
.20956 .30488 L
s
.19551 .28811 m
.20956 .30488 L
s
.384 .609 .619 r
.23886 .25015 m .25279 .26549 L .27337 .25721 L F
.38 .612 .622 r
.21836 .25849 m .25279 .26549 L .23886 .25015 L F
.89 .66 .41 r
.29601 .34165 m
.27621 .33884 L
s
.26324 .3157 m
.27621 .33884 L
s
.82603 .30864 m
.81662 .29438 L
s
.529 .469 .513 r
.6049 .24951 m .61602 .26486 L .63812 .25657 L F
.579 .421 .476 r
.58286 .25785 m .61602 .26486 L .6049 .24951 L F
.406 .588 .603 r
.29412 .24886 m .30762 .26422 L .32844 .25593 L F
.398 .595 .609 r
.27337 .25721 m .30762 .26422 L .29412 .24886 L F
.46 .536 .564 r
.66041 .24822 m .6711 .26359 L .69345 .25529 L F
.5 .497 .534 r
.63812 .25657 m .6711 .26359 L .66041 .24822 L F
.449 .546 .571 r
.34944 .24757 m .36253 .26295 L .38359 .25465 L F
.437 .558 .58 r
.32844 .25593 m .36253 .26295 L .34944 .24757 L F
.89 .66 .41 r
.14068 .28729 m
.12066 .29522 L
s
.10571 .27997 m
.12066 .29522 L
s
.41 .583 .6 r
.71599 .24693 m .72626 .26232 L .74885 .25401 L F
.434 .561 .583 r
.69345 .25529 m .72626 .26232 L .71599 .24693 L F
.89 .66 .41 r
.73016 .38524 m
.73987 .39304 L
s
.73987 .39304 m
.71943 .43174 L
s
.51 .487 .527 r
.40483 .24628 m .41751 .26168 L .43881 .25337 L F
.5 .497 .534 r
.38359 .25465 m .41751 .26168 L .40483 .24628 L F
.89 .66 .41 r
.37469 .55028 m
.3561 .50777 L
s
.34412 .47498 m
.3561 .50777 L
s
.385 .607 .618 r
.77163 .24563 m .78149 .26104 L .80433 .25273 L F
.395 .598 .611 r
.74885 .25401 m .78149 .26104 L .77163 .24563 L F
.89 .66 .41 r
.19551 .28811 m
.17532 .29525 L
s
.16085 .27943 m
.17532 .29525 L
s
.564 .435 .487 r
.4603 .24499 m .47255 .26041 L .49411 .25208 L F
.569 .431 .484 r
.43881 .25337 m .47255 .26041 L .4603 .24499 L F
.373 .619 .627 r
.14876 .24434 m .16342 .25977 L .18368 .25144 L F
.12857 .25273 m .16342 .25977 L .14876 .24434 L F
.579 .421 .476 r
.51584 .24369 m .52767 .25913 L .54947 .2508 L F
.607 .394 .456 r
.49411 .25208 m .52767 .25913 L .51584 .24369 L F
.89 .66 .41 r
.36287 .50974 m
.34412 .47498 L
s
.33226 .43991 m
.34412 .47498 L
s
.377 .615 .624 r
.20412 .24304 m .21836 .25849 L .23886 .25015 L F
.375 .617 .625 r
.18368 .25144 m .21836 .25849 L .20412 .24304 L F
.89 .66 .41 r
.69925 .48 m
.70857 .47441 L
s
.70857 .47441 m
.68843 .52383 L
s
.35126 .46623 m
.33226 .43991 L
s
.32038 .40493 m
.33226 .43991 L
s
.545 .453 .501 r
.57145 .24239 m .58286 .25785 L .6049 .24951 L F
.59 .411 .468 r
.54947 .2508 m .58286 .25785 L .57145 .24239 L F
.89 .66 .41 r
.66811 .57876 m
.677 .55272 L
s
.677 .55272 m
.65637 .59877 L
s
.388 .605 .616 r
.25954 .24174 m .27337 .25721 L .29412 .24886 L F
.384 .609 .619 r
.23886 .25015 m .27337 .25721 L .25954 .24174 L F
.89 .66 .41 r
.33968 .42308 m
.32038 .40493 L
s
.30833 .37183 m
.32038 .40493 L
s
.485 .511 .545 r
.62713 .24109 m .63812 .25657 L .66041 .24822 L F
.529 .469 .513 r
.6049 .24951 m .63812 .25657 L .62713 .24109 L F
.414 .579 .597 r
.31504 .24044 m .32844 .25593 L .34944 .24757 L F
.406 .588 .603 r
.29412 .24886 m .32844 .25593 L .31504 .24044 L F
.89 .66 .41 r
.28335 .31472 m
.26324 .3157 L
s
.24993 .29459 m
.26324 .3157 L
s
.24993 .29459 m
.22969 .29929 L
s
.21582 .28138 m
.22969 .29929 L
s
.429 .565 .586 r
.68288 .23979 m .69345 .25529 L .71599 .24693 L F
.46 .536 .564 r
.66041 .24822 m .69345 .25529 L .68288 .23979 L F
.37061 .23914 m .38359 .25465 L .40483 .24628 L F
.449 .546 .571 r
.34944 .24757 m .38359 .25465 L .37061 .23914 L F
.89 .66 .41 r
.16085 .27943 m
.14068 .28729 L
s
.12584 .2718 m
.14068 .28729 L
s
.32797 .38275 m
.30833 .37183 L
s
.29601 .34165 m
.30833 .37183 L
s
.395 .598 .611 r
.73871 .23849 m .74885 .25401 L .77163 .24563 L F
.41 .583 .6 r
.71599 .24693 m .74885 .25401 L .73871 .23849 L F
.89 .66 .41 r
.47857 .71547 m
.45787 .66365 L
s
.44476 .67885 m
.45787 .66365 L
s
.7943 .309 m
.77243 .32778 L
s
.76258 .31415 m
.77243 .32778 L
s
.77243 .32778 m
.75106 .35253 L
s
.514 .484 .524 r
.42625 .23784 m .43881 .25337 L .4603 .24499 L F
.51 .487 .527 r
.40483 .24628 m .43881 .25337 L .42625 .23784 L F
.89 .66 .41 r
.81662 .29438 m
.7943 .309 L
s
.78457 .29464 m
.7943 .309 L
s
.385 .607 .618 r
.77163 .24563 m .80433 .25273 L .79461 .23719 L F
.89 .66 .41 r
.51292 .721 m
.49139 .68252 L
s
.47857 .71547 m
.49139 .68252 L
s
.55 .449 .497 r
.48197 .23653 m .49411 .25208 L .51584 .24369 L F
.564 .435 .487 r
.4603 .24499 m .49411 .25208 L .48197 .23653 L F
.89 .66 .41 r
.21582 .28138 m
.19551 .28811 L
s
.18117 .27172 m
.19551 .28811 L
s
.374 .618 .626 r
.16912 .23588 m .18368 .25144 L .20412 .24304 L F
.373 .619 .627 r
.14876 .24434 m .18368 .25144 L .16912 .23588 L F
.545 .453 .501 r
.53775 .23523 m .54947 .2508 L .57145 .24239 L F
.579 .421 .476 r
.51584 .24369 m .54947 .2508 L .53775 .23523 L F
.89 .66 .41 r
.74108 .33997 m
.75106 .35253 L
s
.75106 .35253 m
.73016 .38524 L
s
.379 .613 .623 r
.22472 .23457 m .23886 .25015 L .25954 .24174 L F
.377 .615 .624 r
.20412 .24304 m .23886 .25015 L .22472 .23457 L F
.89 .66 .41 r
.31599 .34663 m
.29601 .34165 L
s
.28335 .31472 m
.29601 .34165 L
s
.503 .494 .532 r
.59361 .23392 m .6049 .24951 L .62713 .24109 L F
.545 .453 .501 r
.57145 .24239 m .6049 .24951 L .59361 .23392 L F
.89 .66 .41 r
.81662 .29438 m
.80702 .27953 L
s
.70966 .42769 m
.71943 .43174 L
s
.71943 .43174 m
.69925 .48 L
s
.393 .6 .612 r
.2804 .23326 m .29412 .24886 L .31504 .24044 L F
.388 .605 .616 r
.25954 .24174 m .29412 .24886 L .2804 .23326 L F
.449 .546 .571 r
.64954 .23261 m .66041 .24822 L .68288 .23979 L F
.485 .511 .545 r
.62713 .24109 m .66041 .24822 L .64954 .23261 L F
.422 .571 .591 r
.33614 .23195 m .34944 .24757 L .37061 .23914 L F
.414 .579 .597 r
.31504 .24044 m .34944 .24757 L .33614 .23195 L F
.89 .66 .41 r
.12584 .2718 m
.10571 .27997 L
s
.408 .586 .602 r
.70555 .2313 m .71599 .24693 L .73871 .23849 L F
.429 .565 .586 r
.68288 .23979 m .71599 .24693 L .70555 .2313 L F
.89 .66 .41 r
.4316 .68155 m
.41214 .62112 L
s
.39933 .60841 m
.41214 .62112 L
s
.467 .529 .558 r
.39196 .23064 m .40483 .24628 L .42625 .23784 L F
.46 .536 .564 r
.37061 .23914 m .40483 .24628 L .39196 .23064 L F
.89 .66 .41 r
.18117 .27172 m
.16085 .27943 L
s
.14612 .26364 m
.16085 .27943 L
s
.385 .608 .618 r
.76163 .22998 m .77163 .24563 L .79461 .23719 L F
.395 .598 .611 r
.73871 .23849 m .77163 .24563 L .76163 .22998 L F
.51 .487 .527 r
.44785 .22932 m .4603 .24499 L .48197 .23653 L F
.514 .484 .524 r
.42625 .23784 m .4603 .24499 L .44785 .22932 L F
.89 .66 .41 r
.2703 .29083 m
.24993 .29459 L
s
.23627 .27516 m
.24993 .29459 L
s
.529 .469 .513 r
.50382 .22801 m .51584 .24369 L .53775 .23523 L F
.55 .449 .497 r
.48197 .23653 m .51584 .24369 L .50382 .22801 L F
.375 .617 .626 r
.18965 .22735 m .20412 .24304 L .22472 .23457 L F
.374 .618 .626 r
.16912 .23588 m .20412 .24304 L .18965 .22735 L F
.89 .66 .41 r
.56909 .70405 m
.54683 .6956 L
s
.53522 .74952 m
.54683 .6956 L
s
.30362 .31512 m
.28335 .31472 L
s
.2703 .29083 m
.28335 .31472 L
s
.51 .487 .527 r
.55986 .22669 m .57145 .24239 L .59361 .23392 L F
.545 .453 .501 r
.53775 .23523 m .57145 .24239 L .55986 .22669 L F
.89 .66 .41 r
.23627 .27516 m
.21582 .28138 L
s
.20165 .26421 m
.21582 .28138 L
s
.72004 .37422 m
.73016 .38524 L
s
.73016 .38524 m
.70966 .42769 L
s
.382 .611 .621 r
.2455 .22603 m .25954 .24174 L .2804 .23326 L F
.379 .613 .623 r
.22472 .23457 m .25954 .24174 L .2455 .22603 L F
.467 .529 .558 r
.61597 .22537 m .62713 .24109 L .64954 .23261 L F
.503 .494 .532 r
.59361 .23392 m .62713 .24109 L .61597 .22537 L F
.398 .595 .609 r
.30143 .22471 m .31504 .24044 L .33614 .23195 L F
.393 .6 .612 r
.2804 .23326 m .31504 .24044 L .30143 .22471 L F
.89 .66 .41 r
.64733 .63526 m
.65637 .59877 L
s
.65637 .59877 m
.63524 .64142 L
s
.422 .571 .591 r
.67215 .22405 m .68288 .23979 L .70555 .2313 L F
.449 .546 .571 r
.64954 .23261 m .68288 .23979 L .67215 .22405 L F
.429 .565 .586 r
.35742 .22339 m .37061 .23914 L .39196 .23064 L F
.422 .571 .591 r
.33614 .23195 m .37061 .23914 L .35742 .22339 L F
.89 .66 .41 r
.14612 .26364 m
.12584 .2718 L
s
.67909 .53741 m
.68843 .52383 L
s
.68843 .52383 m
.66811 .57876 L
s
.393 .6 .612 r
.72841 .22273 m .73871 .23849 L .76163 .22998 L F
.408 .586 .602 r
.70555 .2313 m .73871 .23849 L .72841 .22273 L F
.469 .527 .557 r
.41349 .22206 m .42625 .23784 L .44785 .22932 L F
.467 .529 .558 r
.39196 .23064 m .42625 .23784 L .41349 .22206 L F
.89 .66 .41 r
.78457 .29464 m
.76258 .31415 L
s
.75246 .29897 m
.76258 .31415 L
s
.76258 .31415 m
.74108 .33997 L
s
.385 .608 .618 r
.76163 .22998 m .79461 .23719 L .78474 .2214 L F
.89 .66 .41 r
.80702 .27953 m
.78457 .29464 L
s
.77462 .27931 m
.78457 .29464 L
s
.20165 .26421 m
.18117 .27172 L
s
.16657 .25552 m
.18117 .27172 L
s
.5 .497 .534 r
.46964 .22074 m .48197 .23653 L .50382 .22801 L F
.51 .487 .527 r
.44785 .22932 m .48197 .23653 L .46964 .22074 L F
.503 .494 .532 r
.52585 .21941 m .53775 .23523 L .55986 .22669 L F
.529 .469 .513 r
.50382 .22801 m .53775 .23523 L .52585 .21941 L F
.376 .616 .625 r
.21036 .21875 m .22472 .23457 L .2455 .22603 L F
.375 .617 .626 r
.18965 .22735 m .22472 .23457 L .21036 .21875 L F
.477 .519 .551 r
.58215 .21808 m .59361 .23392 L .61597 .22537 L F
.51 .487 .527 r
.55986 .22669 m .59361 .23392 L .58215 .21808 L F
.89 .66 .41 r
.80702 .27953 m
.79723 .26405 L
s
.73077 .32497 m
.74108 .33997 L
s
.74108 .33997 m
.72004 .37422 L
s
.385 .608 .619 r
.26646 .21742 m .2804 .23326 L .30143 .22471 L F
.382 .611 .621 r
.2455 .22603 m .2804 .23326 L .26646 .21742 L F
.89 .66 .41 r
.29084 .2879 m
.2703 .29083 L
s
.25686 .26946 m
.2703 .29083 L
s
.34792 .39589 m
.32797 .38275 L
s
.32797 .38275 m
.33968 .42308 L
s
.31599 .34663 m
.32797 .38275 L
s
.437 .558 .58 r
.63851 .21675 m .64954 .23261 L .67215 .22405 L F
.467 .529 .558 r
.61597 .22537 m .64954 .23261 L .63851 .21675 L F
.89 .66 .41 r
.25686 .26946 m
.23627 .27516 L
s
.22227 .25695 m
.23627 .27516 L
s
.33622 .35306 m
.31599 .34663 L
s
.30362 .31512 m
.31599 .34663 L
s
.403 .59 .605 r
.32264 .21608 m .33614 .23195 L .35742 .22339 L F
.398 .595 .609 r
.30143 .22471 m .33614 .23195 L .32264 .21608 L F
.403 .59 .605 r
.69495 .21542 m .70555 .2313 L .72841 .22273 L F
.422 .571 .591 r
.67215 .22405 m .70555 .2313 L .69495 .21542 L F
.89 .66 .41 r
.41861 .66899 m
.39933 .60841 L
s
.38683 .58421 m
.39933 .60841 L
s
.434 .561 .583 r
.37889 .21475 m .39196 .23064 L .41349 .22206 L F
.429 .565 .586 r
.35742 .22339 m .39196 .23064 L .37889 .21475 L F
.89 .66 .41 r
.35935 .44447 m
.33968 .42308 L
s
.33968 .42308 m
.35126 .46623 L
s
.16657 .25552 m
.14612 .26364 L
s
.384 .609 .619 r
.75146 .21408 m .76163 .22998 L .78474 .2214 L F
.393 .6 .612 r
.72841 .22273 m .76163 .22998 L .75146 .21408 L F
.89 .66 .41 r
.6894 .48095 m
.69925 .48 L
s
.69925 .48 m
.67909 .53741 L
s
.467 .529 .558 r
.43521 .21342 m .44785 .22932 L .46964 .22074 L F
.469 .527 .557 r
.41349 .22206 m .44785 .22932 L .43521 .21342 L F
.485 .511 .545 r
.49161 .21208 m .50382 .22801 L .52585 .21941 L F
.5 .497 .534 r
.46964 .22074 m .50382 .22801 L .49161 .21208 L F
.89 .66 .41 r
.32413 .31642 m
.30362 .31512 L
s
.29084 .2879 m
.30362 .31512 L
s
.22227 .25695 m
.20165 .26421 L
s
.18718 .24749 m
.20165 .26421 L
s
.477 .519 .551 r
.54808 .21074 m .55986 .22669 L .58215 .21808 L F
.503 .494 .532 r
.52585 .21941 m .55986 .22669 L .54808 .21074 L F
.89 .66 .41 r
.37068 .49703 m
.35126 .46623 L
s
.35126 .46623 m
.36287 .50974 L
s
.69939 .41883 m
.70966 .42769 L
s
.70966 .42769 m
.6894 .48095 L
s
.377 .615 .624 r
.23124 .21007 m .2455 .22603 L .26646 .21742 L F
.376 .616 .625 r
.21036 .21875 m .2455 .22603 L .23124 .21007 L F
.89 .66 .41 r
.62589 .68774 m
.63524 .64142 L
s
.63524 .64142 m
.61357 .67576 L
s
.447 .547 .573 r
.60463 .2094 m .61597 .22537 L .63851 .21675 L F
.477 .519 .551 r
.58215 .21808 m .61597 .22537 L .60463 .2094 L F
.388 .605 .616 r
.2876 .20873 m .30143 .22471 L .32264 .21608 L F
.385 .608 .619 r
.26646 .21742 m .30143 .22471 L .2876 .20873 L F
.89 .66 .41 r
.59144 .69747 m
.56909 .70405 L
s
.55805 .7623 m
.56909 .70405 L
s
.414 .579 .597 r
.66125 .20806 m .67215 .22405 L .69495 .21542 L F
.437 .558 .58 r
.63851 .21675 m .67215 .22405 L .66125 .20806 L F
.89 .66 .41 r
.70952 .35941 m
.72004 .37422 L
s
.72004 .37422 m
.69939 .41883 L
s
.408 .586 .602 r
.34403 .20739 m .35742 .22339 L .37889 .21475 L F
.403 .59 .605 r
.32264 .21608 m .35742 .22339 L .34403 .20739 L F
.391 .602 .614 r
.71794 .20671 m .72841 .22273 L .75146 .21408 L F
.403 .59 .605 r
.69495 .21542 m .72841 .22273 L .71794 .20671 L F
.89 .66 .41 r
.40599 .641 m
.38683 .58421 L
s
.37469 .55028 m
.38683 .58421 L
s
.38211 .55037 m
.36287 .50974 L
s
.36287 .50974 m
.37469 .55028 L
s
.435 .559 .581 r
.40053 .20604 m .41349 .22206 L .43521 .21342 L F
.434 .561 .583 r
.37889 .21475 m .41349 .22206 L .40053 .20604 L F
.89 .66 .41 r
.77462 .27931 m
.75246 .29897 L
s
.74208 .28223 m
.75246 .29897 L
s
.75246 .29897 m
.73077 .32497 L
s
.27763 .26423 m
.25686 .26946 L
s
.24305 .24997 m
.25686 .26946 L
s
.18718 .24749 m
.16657 .25552 L
s
.384 .609 .619 r
.75146 .21408 m .78474 .2214 L .77471 .20537 L F
.89 .66 .41 r
.79723 .26405 m
.77462 .27931 L
s
.76445 .26298 m
.77462 .27931 L
s
.46538 .73847 m
.44476 .67885 L
s
.4316 .68155 m
.44476 .67885 L
s
.46 .536 .564 r
.45711 .20469 m .46964 .22074 L .49161 .21208 L F
.467 .529 .558 r
.43521 .21342 m .46964 .22074 L .45711 .20469 L F
.89 .66 .41 r
.31159 .28549 m
.29084 .2879 L
s
.27763 .26423 m
.29084 .2879 L
s
.39383 .60001 m
.37469 .55028 L
s
.467 .529 .558 r
.51377 .20335 m .52585 .21941 L .54808 .21074 L F
.485 .511 .545 r
.49161 .21208 m .52585 .21941 L .51377 .20335 L F
.89 .66 .41 r
.24305 .24997 m
.22227 .25695 L
s
.20796 .23955 m
.22227 .25695 L
s
.451 .544 .57 r
.5705 .202 m .58215 .21808 L .60463 .2094 L F
.477 .519 .551 r
.54808 .21074 m .58215 .21808 L .5705 .202 L F
.89 .66 .41 r
.79723 .26405 m
.78724 .24793 L
s
.72014 .3075 m
.73077 .32497 L
s
.73077 .32497 m
.70952 .35941 L
s
.379 .613 .623 r
.25231 .20132 m .26646 .21742 L .2876 .20873 L F
.377 .615 .624 r
.23124 .21007 m .26646 .21742 L .25231 .20132 L F
.89 .66 .41 r
.60375 .72981 m
.61357 .67576 L
s
.61357 .67576 m
.59144 .69747 L
s
.424 .57 .59 r
.6273 .20064 m .63851 .21675 L .66125 .20806 L F
.447 .547 .573 r
.60463 .2094 m .63851 .21675 L .6273 .20064 L F
.391 .602 .614 r
.30892 .19997 m .32264 .21608 L .34403 .20739 L F
.388 .605 .616 r
.2876 .20873 m .32264 .21608 L .30892 .19997 L F
.89 .66 .41 r
.58103 .75578 m
.59144 .69747 L
s
.65866 .60166 m
.66811 .57876 L
s
.66811 .57876 m
.64733 .63526 L
s
.53522 .74952 m
.51292 .721 L
s
.50028 .7633 m
.51292 .721 L
s
.398 .595 .609 r
.68418 .19929 m .69495 .21542 L .71794 .20671 L F
.414 .579 .597 r
.66125 .20806 m .69495 .21542 L .68418 .19929 L F
.41 .583 .6 r
.36561 .19861 m .37889 .21475 L .40053 .20604 L F
.408 .586 .602 r
.34403 .20739 m .37889 .21475 L .36561 .19861 L F
.383 .61 .62 r
.74113 .19793 m .75146 .21408 L .77471 .20537 L F
.391 .602 .614 r
.71794 .20671 m .75146 .21408 L .74113 .19793 L F
.434 .561 .583 r
.42237 .19726 m .43521 .21342 L .45711 .20469 L F
.435 .559 .581 r
.40053 .20604 m .43521 .21342 L .42237 .19726 L F
.89 .66 .41 r
.35683 .3597 m
.33622 .35306 L
s
.33622 .35306 m
.34792 .39589 L
s
.32413 .31642 m
.33622 .35306 L
s
.20796 .23955 m
.18718 .24749 L
s
.34495 .3178 m
.32413 .31642 L
s
.31159 .28549 m
.32413 .31642 L
s
.449 .546 .571 r
.47921 .1959 m .49161 .21208 L .51377 .20335 L F
.46 .536 .564 r
.45711 .20469 m .49161 .21208 L .47921 .1959 L F
.447 .547 .573 r
.53612 .19454 m .54808 .21074 L .5705 .202 L F
.467 .529 .558 r
.51377 .20335 m .54808 .21074 L .53612 .19454 L F
.89 .66 .41 r
.29859 .25927 m
.27763 .26423 L
s
.26401 .24321 m
.27763 .26423 L
s
.36833 .40947 m
.34792 .39589 L
s
.34792 .39589 m
.35935 .44447 L
s
.429 .565 .586 r
.59311 .19317 m .60463 .2094 L .6273 .20064 L F
.451 .544 .57 r
.5705 .202 m .60463 .2094 L .59311 .19317 L F
.381 .612 .621 r
.27355 .19249 m .2876 .20873 L .30892 .19997 L F
.379 .613 .623 r
.25231 .20132 m .2876 .20873 L .27355 .19249 L F
.89 .66 .41 r
.50028 .7633 m
.47857 .71547 L
s
.46538 .73847 m
.47857 .71547 L
s
.26401 .24321 m
.24305 .24997 L
s
.2289 .23172 m
.24305 .24997 L
s
.406 .588 .603 r
.65017 .19181 m .66125 .20806 L .68418 .19929 L F
.424 .57 .59 r
.6273 .20064 m .66125 .20806 L .65017 .19181 L F
.89 .66 .41 r
.33261 .28309 m
.31159 .28549 L
s
.29859 .25927 m
.31159 .28549 L
s
.6986 .34078 m
.70952 .35941 L
s
.70952 .35941 m
.68861 .40425 L
s
.393 .6 .612 r
.33042 .19113 m .34403 .20739 L .36561 .19861 L F
.391 .602 .614 r
.30892 .19997 m .34403 .20739 L .33042 .19113 L F
.388 .605 .616 r
.70731 .19045 m .71794 .20671 L .74113 .19793 L F
.398 .595 .609 r
.68418 .19929 m .71794 .20671 L .70731 .19045 L F
.89 .66 .41 r
.68861 .40425 m
.69939 .41883 L
s
.69939 .41883 m
.67894 .47497 L
s
.76445 .26298 m
.74208 .28223 L
s
.73146 .26412 m
.74208 .28223 L
s
.74208 .28223 m
.72014 .3075 L
s
.411 .582 .599 r
.38737 .18976 m .40053 .20604 L .42237 .19726 L F
.41 .583 .6 r
.36561 .19861 m .40053 .20604 L .38737 .18976 L F
.89 .66 .41 r
.78724 .24793 m
.76445 .26298 L
s
.75407 .24577 m
.76445 .26298 L
s
.383 .61 .62 r
.74113 .19793 m .77471 .20537 L .76452 .18908 L F
.89 .66 .41 r
.66912 .54468 m
.67909 .53741 L
s
.67909 .53741 m
.65866 .60166 L
s
.429 .565 .586 r
.44439 .18839 m .45711 .20469 L .47921 .1959 L F
.434 .561 .583 r
.42237 .19726 m .45711 .20469 L .44439 .18839 L F
.89 .66 .41 r
.67894 .47497 m
.6894 .48095 L
s
.6894 .48095 m
.66912 .54468 L
s
.437 .558 .58 r
.50149 .18702 m .51377 .20335 L .53612 .19454 L F
.449 .546 .571 r
.47921 .1959 m .51377 .20335 L .50149 .18702 L F
.89 .66 .41 r
.2289 .23172 m
.20796 .23955 L
s
.70924 .28787 m
.72014 .3075 L
s
.72014 .3075 m
.6986 .34078 L
s
.429 .565 .586 r
.55866 .18565 m .5705 .202 L .59311 .19317 L F
.447 .547 .573 r
.53612 .19454 m .5705 .202 L .55866 .18565 L F
.89 .66 .41 r
.37958 .46665 m
.35935 .44447 L
s
.35935 .44447 m
.37068 .49703 L
s
.78724 .24793 m
.77707 .2312 L
s
.411 .582 .599 r
.61591 .18428 m .6273 .20064 L .65017 .19181 L F
.429 .565 .586 r
.59311 .19317 m .6273 .20064 L .61591 .18428 L F
.383 .61 .62 r
.29498 .18359 m .30892 .19997 L .33042 .19113 L F
.381 .612 .621 r
.27355 .19249 m .30892 .19997 L .29498 .18359 L F
.393 .6 .612 r
.67324 .1829 m .68418 .19929 L .70731 .19045 L F
.406 .588 .603 r
.65017 .19181 m .68418 .19929 L .67324 .1829 L F
.89 .66 .41 r
.31979 .25428 m
.29859 .25927 L
s
.28516 .23657 m
.29859 .25927 L
s
.395 .598 .611 r
.35211 .18221 m .36561 .19861 L .38737 .18976 L F
.393 .6 .612 r
.33042 .19113 m .36561 .19861 L .35211 .18221 L F
.89 .66 .41 r
.28516 .23657 m
.26401 .24321 L
s
.25002 .22399 m
.26401 .24321 L
s
.381 .612 .621 r
.73064 .18153 m .74113 .19793 L .76452 .18908 L F
.388 .605 .616 r
.70731 .19045 m .74113 .19793 L .73064 .18153 L F
.41 .583 .6 r
.40932 .18084 m .42237 .19726 L .44439 .18839 L F
.411 .582 .599 r
.38737 .18976 m .42237 .19726 L .40932 .18084 L F
.89 .66 .41 r
.36615 .31819 m
.34495 .3178 L
s
.34495 .3178 m
.35683 .3597 L
s
.33261 .28309 m
.34495 .3178 L
s
.422 .571 .591 r
.4666 .17946 m .47921 .1959 L .50149 .18702 L F
.429 .565 .586 r
.44439 .18839 m .47921 .1959 L .4666 .17946 L F
.89 .66 .41 r
.45207 .74563 m
.4316 .68155 L
s
.41861 .66899 m
.4316 .68155 L
s
.424 .57 .59 r
.52396 .17807 m .53612 .19454 L .55866 .18565 L F
.437 .558 .58 r
.50149 .18702 m .53612 .19454 L .52396 .17807 L F
.89 .66 .41 r
.35393 .28003 m
.33261 .28309 L
s
.31979 .25428 m
.33261 .28309 L
s
.25002 .22399 m
.2289 .23172 L
s
.37792 .36492 m
.35683 .3597 L
s
.35683 .3597 m
.36833 .40947 L
s
.68737 .31883 m
.6986 .34078 L
s
.6986 .34078 m
.67737 .3839 L
s
.413 .58 .598 r
.5814 .17669 m .59311 .19317 L .61591 .18428 L F
.429 .565 .586 r
.55866 .18565 m .59311 .19317 L .5814 .17669 L F
.89 .66 .41 r
.63766 .66816 m
.64733 .63526 L
s
.64733 .63526 m
.62589 .68774 L
s
.75407 .24577 m
.73146 .26412 L
s
.72063 .24496 m
.73146 .26412 L
s
.73146 .26412 m
.70924 .28787 L
s
.39077 .52916 m
.37068 .49703 L
s
.37068 .49703 m
.38211 .55037 L
s
.398 .595 .609 r
.63891 .1753 m .65017 .19181 L .67324 .1829 L F
.411 .582 .599 r
.61591 .18428 m .65017 .19181 L .63891 .1753 L F
.384 .609 .619 r
.3166 .17461 m .33042 .19113 L .35211 .18221 L F
.383 .61 .62 r
.29498 .18359 m .33042 .19113 L .3166 .17461 L F
.89 .66 .41 r
.77707 .2312 m
.75407 .24577 L
s
.7435 .22786 m
.75407 .24577 L
s
.385 .608 .619 r
.69651 .17392 m .70731 .19045 L .73064 .18153 L F
.393 .6 .612 r
.67324 .1829 m .70731 .19045 L .69651 .17392 L F
.89 .66 .41 r
.67737 .3839 m
.68861 .40425 L
s
.68861 .40425 m
.66786 .46067 L
s
.69811 .26668 m
.70924 .28787 L
s
.70924 .28787 m
.68737 .31883 L
s
.395 .598 .611 r
.37399 .17322 m .38737 .18976 L .40932 .18084 L F
.35211 .18221 m .38737 .18976 L .37399 .17322 L F
.381 .612 .621 r
.73064 .18153 m .76452 .18908 L .75417 .17253 L F
.408 .586 .602 r
.43146 .17183 m .44439 .18839 L .4666 .17946 L F
.41 .583 .6 r
.40932 .18084 m .44439 .18839 L .43146 .17183 L F
.89 .66 .41 r
.30653 .22988 m
.28516 .23657 L
s
.27133 .21628 m
.28516 .23657 L
s
.34126 .24886 m
.31979 .25428 L
s
.30653 .22988 m
.31979 .25428 L
s
.414 .579 .597 r
.48901 .17044 m .50149 .18702 L .52396 .17807 L F
.422 .571 .591 r
.4666 .17946 m .50149 .18702 L .48901 .17044 L F
.89 .66 .41 r
.77707 .2312 m
.76672 .21397 L
s
.411 .582 .599 r
.54664 .16905 m .55866 .18565 L .5814 .17669 L F
.424 .57 .59 r
.52396 .17807 m .55866 .18565 L .54664 .16905 L F
.89 .66 .41 r
.38933 .42109 m
.36833 .40947 L
s
.36833 .40947 m
.37958 .46665 L
s
.55805 .7623 m
.53522 .74952 L
s
.52294 .79933 m
.53522 .74952 L
s
.4 .593 .607 r
.60434 .16765 m .61591 .18428 L .63891 .1753 L F
.413 .58 .598 r
.5814 .17669 m .61591 .18428 L .60434 .16765 L F
.89 .66 .41 r
.27133 .21628 m
.25002 .22399 L
s
.388 .605 .616 r
.66212 .16625 m .67324 .1829 L .69651 .17392 L F
.398 .595 .609 r
.63891 .1753 m .67324 .1829 L .66212 .16625 L F
.89 .66 .41 r
.6759 .29452 m
.68737 .31883 L
s
.68737 .31883 m
.66576 .3586 L
s
.385 .608 .618 r
.3384 .16555 m .35211 .18221 L .37399 .17322 L F
.384 .609 .619 r
.3166 .17461 m .35211 .18221 L .3384 .16555 L F
.89 .66 .41 r
.66786 .46067 m
.67894 .47497 L
s
.67894 .47497 m
.65842 .54235 L
s
.3756 .2756 m
.35393 .28003 L
s
.35393 .28003 m
.36615 .31819 L
s
.34126 .24886 m
.35393 .28003 L
s
.38777 .31644 m
.36615 .31819 L
s
.36615 .31819 m
.37792 .36492 L
s
.379 .613 .623 r
.71998 .16485 m .73064 .18153 L .75417 .17253 L F
.385 .608 .619 r
.69651 .17392 m .73064 .18153 L .71998 .16485 L F
.89 .66 .41 r
.40213 .59298 m
.38211 .55037 L
s
.38211 .55037 m
.39383 .60001 L
s
.395 .598 .611 r
.39606 .16415 m .40932 .18084 L .43146 .17183 L F
.37399 .17322 m .40932 .18084 L .39606 .16415 L F
.403 .59 .605 r
.4538 .16275 m .4666 .17946 L .48901 .17044 L F
.408 .586 .602 r
.43146 .17183 m .4666 .17946 L .4538 .16275 L F
.89 .66 .41 r
.4389 .73326 m
.41861 .66899 L
s
.40599 .641 m
.41861 .66899 L
s
.406 .588 .603 r
.51161 .16134 m .52396 .17807 L .54664 .16905 L F
.414 .579 .597 r
.48901 .17044 m .52396 .17807 L .51161 .16134 L F
.89 .66 .41 r
.7435 .22786 m
.72063 .24496 L
s
.70963 .22516 m
.72063 .24496 L
s
.72063 .24496 m
.69811 .26668 L
s
.66576 .3586 m
.67737 .3839 L
s
.67737 .3839 m
.65625 .43796 L
s
.32812 .22291 m
.30653 .22988 L
s
.29285 .2085 m
.30653 .22988 L
s
.68681 .24459 m
.69811 .26668 L
s
.69811 .26668 m
.6759 .29452 L
s
.4 .593 .607 r
.56951 .15994 m .5814 .17669 L .60434 .16765 L F
.411 .582 .599 r
.54664 .16905 m .5814 .17669 L .56951 .15994 L F
.89 .66 .41 r
.363 .24259 m
.34126 .24886 L
s
.32812 .22291 m
.34126 .24886 L
s
.64848 .6164 m
.65866 .60166 L
s
.65866 .60166 m
.63766 .66816 L
s
.39953 .36693 m
.37792 .36492 L
s
.37792 .36492 m
.38933 .42109 L
s
.76672 .21397 m
.7435 .22786 L
s
.73275 .20946 m
.7435 .22786 L
s
.391 .602 .614 r
.62748 .15853 m .63891 .1753 L .66212 .16625 L F
.4 .593 .607 r
.60434 .16765 m .63891 .1753 L .62748 .15853 L F
.89 .66 .41 r
.65842 .54235 m
.66912 .54468 L
s
.66912 .54468 m
.64848 .6164 L
s
.29285 .2085 m
.27133 .21628 L
s
.382 .611 .621 r
.68553 .15712 m .69651 .17392 L .71998 .16485 L F
.388 .605 .616 r
.66212 .16625 m .69651 .17392 L .68553 .15712 L F
.89 .66 .41 r
.41387 .65246 m
.39383 .60001 L
s
.39383 .60001 m
.40599 .641 L
s
.385 .607 .618 r
.36039 .15641 m .37399 .17322 L .39606 .16415 L F
.385 .608 .618 r
.3384 .16555 m .37399 .17322 L .36039 .15641 L F
.379 .613 .623 r
.71998 .16485 m .75417 .17253 L .74366 .15571 L F
.89 .66 .41 r
.40054 .4863 m
.37958 .46665 L
s
.37958 .46665 m
.39077 .52916 L
s
.42612 .70112 m
.40599 .641 L
s
.66426 .26896 m
.6759 .29452 L
s
.6759 .29452 m
.6539 .32981 L
s
.393 .6 .612 r
.41832 .155 m .43146 .17183 L .4538 .16275 L F
.395 .598 .611 r
.39606 .16415 m .43146 .17183 L .41832 .155 L F
.89 .66 .41 r
.61585 .73014 m
.62589 .68774 L
s
.62589 .68774 m
.60375 .72981 L
s
.398 .595 .609 r
.47633 .15359 m .48901 .17044 L .51161 .16134 L F
.403 .59 .605 r
.4538 .16275 m .48901 .17044 L .47633 .15359 L F
.89 .66 .41 r
.76672 .21397 m
.75619 .19637 L
s
.48716 .79386 m
.46538 .73847 L
s
.45207 .74563 m
.46538 .73847 L
s
.39762 .2692 m
.3756 .2756 L
s
.3756 .2756 m
.38777 .31644 L
s
.363 .24259 m
.3756 .2756 L
s
.398 .595 .609 r
.53441 .15217 m .54664 .16905 L .56951 .15994 L F
.406 .588 .603 r
.51161 .16134 m .54664 .16905 L .53441 .15217 L F
.89 .66 .41 r
.6539 .32981 m
.66576 .3586 L
s
.66576 .3586 m
.64423 .40809 L
s
.40981 .31159 m
.38777 .31644 L
s
.38777 .31644 m
.39953 .36693 L
s
.392 .601 .614 r
.59258 .15075 m .60434 .16765 L .62748 .15853 L F
.4 .593 .607 r
.56951 .15994 m .60434 .16765 L .59258 .15075 L F
.89 .66 .41 r
.34997 .21542 m
.32812 .22291 L
s
.31458 .20054 m
.32812 .22291 L
s
.384 .609 .619 r
.65082 .14933 m .66212 .16625 L .68553 .15712 L F
.391 .602 .614 r
.62748 .15853 m .66212 .16625 L .65082 .14933 L F
.89 .66 .41 r
.38504 .23512 m
.363 .24259 L
s
.34997 .21542 m
.363 .24259 L
s
.52294 .79933 m
.50028 .7633 L
s
.48716 .79386 m
.50028 .7633 L
s
.65625 .43796 m
.66786 .46067 L
s
.66786 .46067 m
.647 .52837 L
s
.70963 .22516 m
.68681 .24459 L
s
.67538 .22229 m
.68681 .24459 L
s
.68681 .24459 m
.66426 .26896 L
s
.377 .615 .624 r
.70914 .14791 m .71998 .16485 L .74366 .15571 L F
.382 .611 .621 r
.68553 .15712 m .71998 .16485 L .70914 .14791 L F
.89 .66 .41 r
.31458 .20054 m
.29285 .2085 L
s
.385 .608 .618 r
.38258 .14719 m .39606 .16415 L .41832 .155 L F
.385 .607 .618 r
.36039 .15641 m .39606 .16415 L .38258 .14719 L F
.89 .66 .41 r
.73275 .20946 m
.70963 .22516 L
s
.69848 .20512 m
.70963 .22516 L
s
.58103 .75578 m
.55805 .7623 L
s
.54629 .81635 m
.55805 .7623 L
s
.391 .602 .614 r
.44078 .14577 m .4538 .16275 L .47633 .15359 L F
.393 .6 .612 r
.41832 .155 m .4538 .16275 L .44078 .14577 L F
.89 .66 .41 r
.41099 .42812 m
.38933 .42109 L
s
.38933 .42109 m
.40054 .4863 L
s
.65252 .24323 m
.66426 .26896 L
s
.66426 .26896 m
.6419 .2993 L
s
.6419 .2993 m
.6539 .32981 L
s
.6539 .32981 m
.63196 .37328 L
s
.393 .6 .612 r
.49906 .14434 m .51161 .16134 L .53441 .15217 L F
.398 .595 .609 r
.47633 .15359 m .51161 .16134 L .49906 .14434 L F
.89 .66 .41 r
.75619 .19637 m
.73275 .20946 L
s
.72185 .19081 m
.73275 .20946 L
s
.391 .602 .614 r
.55742 .14291 m .56951 .15994 L .59258 .15075 L F
.398 .595 .609 r
.53441 .15217 m .56951 .15994 L .55742 .14291 L F
.89 .66 .41 r
.42166 .36421 m
.39953 .36693 L
s
.39953 .36693 m
.41099 .42812 L
s
.41995 .26049 m
.39762 .2692 L
s
.39762 .2692 m
.40981 .31159 L
s
.38504 .23512 m
.39762 .2692 L
s
.385 .608 .618 r
.61585 .14148 m .62748 .15853 L .65082 .14933 L F
.392 .601 .614 r
.59258 .15075 m .62748 .15853 L .61585 .14148 L F
.89 .66 .41 r
.59319 .77975 m
.60375 .72981 L
s
.60375 .72981 m
.58103 .75578 L
s
.379 .613 .623 r
.67437 .14005 m .68553 .15712 L .70914 .14791 L F
.384 .609 .619 r
.65082 .14933 m .68553 .15712 L .67437 .14005 L F
.89 .66 .41 r
.37207 .20722 m
.34997 .21542 L
s
.33653 .19226 m
.34997 .21542 L
s
.43222 .30305 m
.40981 .31159 L
s
.40981 .31159 m
.42166 .36421 L
s
.377 .615 .624 r
.70914 .14791 m .74366 .15571 L .73297 .13861 L F
.89 .66 .41 r
.41174 .55815 m
.39077 .52916 L
s
.39077 .52916 m
.40213 .59298 L
s
.62983 .26871 m
.6419 .2993 L
s
.6419 .2993 m
.61959 .33614 L
s
.40735 .22624 m
.38504 .23512 L
s
.37207 .20722 m
.38504 .23512 L
s
.384 .609 .619 r
.40497 .13789 m .41832 .155 L .44078 .14577 L F
.385 .608 .618 r
.38258 .14719 m .41832 .155 L .40497 .13789 L F
.89 .66 .41 r
.56987 .80988 m
.58103 .75578 L
s
.33653 .19226 m
.31458 .20054 L
s
.75619 .19637 m
.74551 .17849 L
s
.64423 .40809 m
.65625 .43796 L
s
.65625 .43796 m
.63498 .50263 L
s
.388 .605 .616 r
.46344 .13646 m .47633 .15359 L .49906 .14434 L F
.391 .602 .614 r
.44078 .14577 m .47633 .15359 L .46344 .13646 L F
.89 .66 .41 r
.67538 .22229 m
.65252 .24323 L
s
.64071 .21815 m
.65252 .24323 L
s
.65252 .24323 m
.62983 .26871 L
s
.69848 .20512 m
.67538 .22229 L
s
.66384 .20027 m
.67538 .22229 L
s
.388 .605 .616 r
.52199 .13502 m .53441 .15217 L .55742 .14291 L F
.393 .6 .612 r
.49906 .14434 m .53441 .15217 L .52199 .13502 L F
.385 .608 .618 r
.58062 .13357 m .59258 .15075 L .61585 .14148 L F
.391 .602 .614 r
.55742 .14291 m .59258 .15075 L .58062 .13357 L F
.89 .66 .41 r
.647 .52837 m
.65842 .54235 L
s
.65842 .54235 m
.63748 .61838 L
s
.72185 .19081 m
.69848 .20512 L
s
.6872 .18513 m
.69848 .20512 L
s
.44254 .24945 m
.41995 .26049 L
s
.41995 .26049 m
.43222 .30305 L
s
.40735 .22624 m
.41995 .26049 L
s
.61774 .23929 m
.62983 .26871 L
s
.62983 .26871 m
.6072 .29909 L
s
.38 .612 .622 r
.63934 .13213 m .65082 .14933 L .67437 .14005 L F
.385 .608 .618 r
.61585 .14148 m .65082 .14933 L .63934 .13213 L F
.376 .616 .625 r
.69813 .13068 m .70914 .14791 L .73297 .13861 L F
.379 .613 .623 r
.67437 .14005 m .70914 .14791 L .69813 .13068 L F
.89 .66 .41 r
.63196 .37328 m
.64423 .40809 L
s
.64423 .40809 m
.62253 .46694 L
s
.39441 .19818 m
.37207 .20722 L
s
.35871 .18355 m
.37207 .20722 L
s
.45492 .29082 m
.43222 .30305 L
s
.43222 .30305 m
.44424 .35587 L
s
.4299 .21596 m
.40735 .22624 L
s
.39441 .19818 m
.40735 .22624 L
s
.383 .61 .62 r
.42755 .12851 m .44078 .14577 L .46344 .13646 L F
.384 .609 .619 r
.40497 .13789 m .44078 .14577 L .42755 .12851 L F
.89 .66 .41 r
.62717 .69095 m
.63766 .66816 L
s
.63766 .66816 m
.61585 .73014 L
s
.44424 .35587 m
.42166 .36421 L
s
.42166 .36421 m
.43329 .42825 L
s
.61959 .33614 m
.63196 .37328 L
s
.63196 .37328 m
.60987 .4245 L
s
.35871 .18355 m
.33653 .19226 L
s
.74551 .17849 m
.72185 .19081 L
s
.7108 .17207 m
.72185 .19081 L
s
.385 .608 .619 r
.4863 .12706 m .49906 .14434 L .52199 .13502 L F
.388 .605 .616 r
.46344 .13646 m .49906 .14434 L .4863 .12706 L F
.89 .66 .41 r
.42231 .49964 m
.40054 .4863 L
s
.40054 .4863 m
.41174 .55815 L
s
.6072 .29909 m
.61959 .33614 L
s
.61959 .33614 m
.59716 .37905 L
s
.384 .609 .619 r
.54513 .12561 m .55742 .14291 L .58062 .13357 L F
.388 .605 .616 r
.52199 .13502 m .55742 .14291 L .54513 .12561 L F
.89 .66 .41 r
.43329 .42825 m
.41099 .42812 L
s
.41099 .42812 m
.42231 .49964 L
s
.59485 .26394 m
.6072 .29909 L
s
.6072 .29909 m
.58451 .33397 L
s
.66384 .20027 m
.64071 .21815 L
s
.62883 .19421 m
.64071 .21815 L
s
.64071 .21815 m
.61774 .23929 L
s
.60562 .21179 m
.61774 .23929 L
s
.61774 .23929 m
.59485 .26394 L
s
.46534 .23642 m
.44254 .24945 L
s
.44254 .24945 m
.45492 .29082 L
s
.4299 .21596 m
.44254 .24945 L
s
.38 .612 .622 r
.60404 .12415 m .61585 .14148 L .63934 .13213 L F
.385 .608 .618 r
.58062 .13357 m .61585 .14148 L .60404 .12415 L F
.89 .66 .41 r
.47378 .80537 m
.45207 .74563 L
s
.4389 .73326 m
.45207 .74563 L
s
.63748 .61838 m
.64848 .6164 L
s
.64848 .6164 m
.62717 .69095 L
s
.47782 .27543 m
.45492 .29082 L
s
.45492 .29082 m
.46713 .34187 L
s
.377 .615 .624 r
.66303 .1227 m .67437 .14005 L .69813 .13068 L F
.38 .612 .622 r
.63934 .13213 m .67437 .14005 L .66303 .1227 L F
.89 .66 .41 r
.6872 .18513 m
.66384 .20027 L
s
.6522 .17887 m
.66384 .20027 L
s
.58253 .23176 m
.59485 .26394 L
s
.59485 .26394 m
.57195 .29177 L
s
.376 .616 .625 r
.69813 .13068 m .73297 .13861 L .7221 .12124 L F
.89 .66 .41 r
.42318 .63197 m
.40213 .59298 L
s
.40213 .59298 m
.41387 .65246 L
s
.74551 .17849 m
.73466 .16044 L
s
.45267 .20445 m
.4299 .21596 L
s
.41698 .18831 m
.4299 .21596 L
s
.41698 .18831 m
.39441 .19818 L
s
.38112 .17436 m
.39441 .19818 L
s
.381 .612 .621 r
.45034 .11904 m .46344 .13646 L .4863 .12706 L F
.383 .61 .62 r
.42755 .12851 m .46344 .13646 L .45034 .11904 L F
.89 .66 .41 r
.46713 .34187 m
.44424 .35587 L
s
.44424 .35587 m
.45611 .42012 L
s
.48829 .22199 m
.46534 .23642 L
s
.46534 .23642 m
.47782 .27543 L
s
.45267 .20445 m
.46534 .23642 L
s
.50084 .25785 m
.47782 .27543 L
s
.47782 .27543 m
.4902 .32306 L
s
.7108 .17207 m
.6872 .18513 L
s
.67578 .1654 m
.6872 .18513 L
s
.38112 .17436 m
.35871 .18355 L
s
.382 .611 .621 r
.50937 .11758 m .52199 .13502 L .54513 .12561 L F
.385 .608 .619 r
.4863 .12706 m .52199 .13502 L .50937 .11758 L F
.89 .66 .41 r
.57195 .29177 m
.58451 .33397 L
s
.55948 .25385 m
.57195 .29177 L
s
.57195 .29177 m
.54897 .32175 L
s
.60562 .21179 m
.58253 .23176 L
s
.5702 .20286 m
.58253 .23176 L
s
.58253 .23176 m
.55948 .25385 L
s
.54703 .22061 m
.55948 .25385 L
s
.55948 .25385 m
.53642 .27734 L
s
.38 .612 .622 r
.56847 .11611 m .58062 .13357 L .60404 .12415 L F
.384 .609 .619 r
.54513 .12561 m .58062 .13357 L .56847 .11611 L F
.89 .66 .41 r
.62883 .19421 m
.60562 .21179 L
s
.59346 .18646 m
.60562 .21179 L
s
.52391 .23921 m
.50084 .25785 L
s
.50084 .25785 m
.51332 .30096 L
s
.48829 .22199 m
.50084 .25785 L
s
.63498 .50263 m
.647 .52837 L
s
.647 .52837 m
.62568 .60479 L
s
.377 .615 .624 r
.62766 .11465 m .63934 .13213 L .66303 .1227 L F
.38 .612 .622 r
.60404 .12415 m .63934 .13213 L .62766 .11465 L F
.89 .66 .41 r
.58451 .33397 m
.59716 .37905 L
s
.58451 .33397 m
.56163 .37199 L
s
.53642 .27734 m
.54897 .32175 L
s
.52391 .23921 m
.53642 .27734 L
s
.53642 .27734 m
.51332 .30096 L
s
.54703 .22061 m
.52391 .23921 L
s
.51136 .20686 m
.52391 .23921 L
s
.4902 .32306 m
.46713 .34187 L
s
.46713 .34187 m
.47928 .40368 L
s
.375 .617 .626 r
.68693 .11318 m .69813 .13068 L .7221 .12124 L F
.377 .615 .624 r
.66303 .1227 m .69813 .13068 L .68693 .11318 L F
.89 .66 .41 r
.6522 .17887 m
.62883 .19421 L
s
.61687 .1716 m
.62883 .19421 L
s
.51136 .20686 m
.48829 .22199 L
s
.47561 .19207 m
.48829 .22199 L
s
.47561 .19207 m
.45267 .20445 L
s
.43976 .17771 m
.45267 .20445 L
s
.51332 .30096 m
.52583 .35204 L
s
.51332 .30096 m
.4902 .32306 L
s
.4902 .32306 m
.50257 .38024 L
s
.5702 .20286 m
.54703 .22061 L
s
.53453 .19169 m
.54703 .22061 L
s
.54629 .81635 m
.52294 .79933 L
s
.51005 .83602 m
.52294 .79933 L
s
.43976 .17771 m
.41698 .18831 L
s
.40375 .16468 m
.41698 .18831 L
s
.73466 .16044 m
.7108 .17207 L
s
.6996 .15334 m
.7108 .17207 L
s
.54897 .32175 m
.56163 .37199 L
s
.54897 .32175 m
.52583 .35204 L
s
.59716 .37905 m
.60987 .4245 L
s
.59716 .37905 m
.57445 .4263 L
s
.45611 .42012 m
.43329 .42825 L
s
.43329 .42825 m
.44485 .50336 L
s
.379 .613 .623 r
.47333 .10949 m .4863 .12706 L .50937 .11758 L F
.381 .612 .621 r
.45034 .11904 m .4863 .12706 L .47333 .10949 L F
.89 .66 .41 r
.59346 .18646 m
.5702 .20286 L
s
.55782 .17702 m
.5702 .20286 L
s
.67578 .1654 m
.6522 .17887 L
s
.64045 .15818 m
.6522 .17887 L
s
.53453 .19169 m
.51136 .20686 L
s
.4987 .17924 m
.51136 .20686 L
s
.40375 .16468 m
.38112 .17436 L
s
.379 .613 .623 r
.53264 .10802 m .54513 .12561 L .56847 .11611 L F
.382 .611 .621 r
.50937 .11758 m .54513 .12561 L .53264 .10802 L F
.89 .66 .41 r
.43506 .7009 m
.41387 .65246 L
s
.41387 .65246 m
.42612 .70112 L
s
.377 .615 .624 r
.59203 .10654 m .60404 .12415 L .62766 .11465 L F
.38 .612 .622 r
.56847 .11611 m .60404 .12415 L .59203 .10654 L F
.89 .66 .41 r
.4987 .17924 m
.47561 .19207 L
s
.46273 .16659 m
.47561 .19207 L
s
.62253 .46694 m
.63498 .50263 L
s
.63498 .50263 m
.61324 .57543 L
s
.46047 .7932 m
.4389 .73326 L
s
.42612 .70112 m
.4389 .73326 L
s
.60987 .4245 m
.62253 .46694 L
s
.60987 .4245 m
.58742 .48143 L
s
.375 .617 .625 r
.6515 .10505 m .66303 .1227 L .68693 .11318 L F
.377 .615 .624 r
.62766 .11465 m .66303 .1227 L .6515 .10505 L F
.89 .66 .41 r
.61687 .1716 m
.59346 .18646 L
s
.58123 .16316 m
.59346 .18646 L
s
.73466 .16044 m
.72366 .14227 L
s
.375 .617 .626 r
.68693 .11318 m .7221 .12124 L .71105 .10357 L F
.89 .66 .41 r
.55782 .17702 m
.53453 .19169 L
s
.52194 .16635 m
.53453 .19169 L
s
.43369 .57893 m
.41174 .55815 L
s
.41174 .55815 m
.42318 .63197 L
s
.52583 .35204 m
.53848 .41064 L
s
.52583 .35204 m
.50257 .38024 L
s
.51005 .83602 m
.48716 .79386 L
s
.47378 .80537 m
.48716 .79386 L
s
.62253 .46694 m
.60041 .53284 L
s
.46273 .16659 m
.43976 .17771 L
s
.42658 .15457 m
.43976 .17771 L
s
.6996 .15334 m
.67578 .1654 L
s
.66423 .14597 m
.67578 .1654 L
s
.44485 .50336 m
.42231 .49964 L
s
.42231 .49964 m
.43369 .57893 L
s
.56163 .37199 m
.57445 .4263 L
s
.56163 .37199 m
.53848 .41064 L
s
.60494 .76068 m
.61585 .73014 L
s
.61585 .73014 m
.59319 .77975 L
s
.4475 .75701 m
.42612 .70112 L
s
.47928 .40368 m
.45611 .42012 L
s
.45611 .42012 m
.468 .49547 L
s
.64045 .15818 m
.61687 .1716 L
s
.60481 .15022 m
.61687 .1716 L
s
.377 .615 .624 r
.49653 .09985 m .50937 .11758 L .53264 .10802 L F
.379 .613 .623 r
.47333 .10949 m .50937 .11758 L .49653 .09985 L F
.89 .66 .41 r
.52194 .16635 m
.4987 .17924 L
s
.48588 .15516 m
.4987 .17924 L
s
.42658 .15457 m
.40375 .16468 L
s
.377 .615 .624 r
.55612 .09836 m .56847 .11611 L .59203 .10654 L F
.379 .613 .623 r
.53264 .10802 m .56847 .11611 L .55612 .09836 L F
.89 .66 .41 r
.50257 .38024 m
.51507 .44653 L
s
.50257 .38024 m
.47928 .40368 L
s
.58123 .16316 m
.55782 .17702 L
s
.54533 .15371 m
.55782 .17702 L
s
.375 .617 .625 r
.61579 .09687 m .62766 .11465 L .6515 .10505 L F
.377 .615 .624 r
.59203 .10654 m .62766 .11465 L .61579 .09687 L F
.89 .66 .41 r
.47928 .40368 m
.4915 .4759 L
s
.374 .618 .626 r
.67555 .09538 m .68693 .11318 L .71105 .10357 L F
.375 .617 .625 r
.6515 .10505 m .68693 .11318 L .67555 .09538 L F
.89 .66 .41 r
.72366 .14227 m
.6996 .15334 L
s
.68825 .13467 m
.6996 .15334 L
s
.48588 .15516 m
.46273 .16659 L
s
.44962 .14413 m
.46273 .16659 L
s
.62568 .60479 m
.63748 .61838 L
s
.63748 .61838 m
.61579 .69764 L
s
.66423 .14597 m
.64045 .15818 L
s
.62857 .13816 m
.64045 .15818 L
s
.54533 .15371 m
.52194 .16635 L
s
.5092 .14366 m
.52194 .16635 L
s
.60481 .15022 m
.58123 .16316 L
s
.56888 .14152 m
.58123 .16316 L
s
.57445 .4263 m
.58742 .48143 L
s
.57445 .4263 m
.55134 .47466 L
s
.376 .616 .625 r
.51994 .09013 m .53264 .10802 L .55612 .09836 L F
.377 .615 .624 r
.49653 .09985 m .53264 .10802 L .51994 .09013 L F
.89 .66 .41 r
.44962 .14413 m
.42658 .15457 L
s
.53848 .41064 m
.55134 .47466 L
s
.53848 .41064 m
.51507 .44653 L
s
.375 .617 .625 r
.57982 .08862 m .59203 .10654 L .61579 .09687 L F
.377 .615 .624 r
.55612 .09836 m .59203 .10654 L .57982 .08862 L F
.374 .618 .626 r
.63978 .08712 m .6515 .10505 L .67555 .09538 L F
.375 .617 .625 r
.61579 .09687 m .6515 .10505 L .63978 .08712 L F
.89 .66 .41 r
.61579 .69764 m
.62717 .69095 L
s
.62717 .69095 m
.60494 .76068 L
s
.5092 .14366 m
.48588 .15516 L
s
.47285 .13349 m
.48588 .15516 L
s
.56987 .80988 m
.54629 .81635 L
s
.5338 .85651 m
.54629 .81635 L
s
.72366 .14227 m
.71249 .12399 L
s
.68825 .13467 m
.66423 .14597 L
s
.65254 .12682 m
.66423 .14597 L
s
.374 .618 .626 r
.67555 .09538 m .71105 .10357 L .69982 .08561 L F
.89 .66 .41 r
.62857 .13816 m
.60481 .15022 L
s
.59261 .12984 m
.60481 .15022 L
s
.56888 .14152 m
.54533 .15371 L
s
.5327 .13227 m
.54533 .15371 L
s
.468 .49547 m
.44485 .50336 L
s
.44485 .50336 m
.45655 .58689 L
s
.58177 .81648 m
.59319 .77975 L
s
.59319 .77975 m
.56987 .80988 L
s
.47285 .13349 m
.44962 .14413 L
s
.375 .617 .626 r
.54356 .08032 m .55612 .09836 L .57982 .08862 L F
.376 .616 .625 r
.51994 .09013 m .55612 .09836 L .54356 .08032 L F
.89 .66 .41 r
.58742 .48143 m
.60041 .53284 L
s
.58742 .48143 m
.56442 .54007 L
s
.44536 .66075 m
.42318 .63197 L
s
.42318 .63197 m
.43506 .7009 L
s
.374 .618 .626 r
.60373 .0788 m .61579 .09687 L .63978 .08712 L F
.375 .617 .625 r
.57982 .08862 m .61579 .09687 L .60373 .0788 L F
.89 .66 .41 r
.5327 .13227 m
.5092 .14366 L
s
.49627 .12277 m
.5092 .14366 L
s
.51507 .44653 m
.5278 .51959 L
s
.51507 .44653 m
.4915 .4759 L
s
.71249 .12399 m
.68825 .13467 L
s
.67673 .11602 m
.68825 .13467 L
s
.65254 .12682 m
.62857 .13816 L
s
.61654 .11865 m
.62857 .13816 L
s
.59261 .12984 m
.56888 .14152 L
s
.55638 .12109 m
.56888 .14152 L
s
.373 .619 .627 r
.66398 .07728 m .67555 .09538 L .69982 .08561 L F
.374 .618 .626 r
.63978 .08712 m .67555 .09538 L .66398 .07728 L F
.89 .66 .41 r
.5579 .85007 m
.56987 .80988 L
s
.61324 .57543 m
.62568 .60479 L
s
.62568 .60479 m
.60359 .68447 L
s
.4915 .4759 m
.468 .49547 L
s
.468 .49547 m
.48009 .57927 L
s
.45655 .58689 m
.43369 .57893 L
s
.43369 .57893 m
.44536 .66075 L
s
.4915 .4759 m
.50396 .55596 L
s
.49627 .12277 m
.47285 .13349 L
s
.55134 .47466 m
.56442 .54007 L
s
.55134 .47466 m
.5278 .51959 L
s
.60041 .53284 m
.61324 .57543 L
s
.60041 .53284 m
.57762 .60111 L
s
.374 .618 .626 r
.5674 .07041 m .57982 .08862 L .60373 .0788 L F
.375 .617 .626 r
.54356 .08032 m .57982 .08862 L .5674 .07041 L F
.89 .66 .41 r
.55638 .12109 m
.5327 .13227 L
s
.51989 .11206 m
.5327 .13227 L
s
.49676 .85106 m
.47378 .80537 L
s
.46047 .7932 m
.47378 .80537 L
s
.61654 .11865 m
.59261 .12984 L
s
.58026 .11016 m
.59261 .12984 L
s
.61324 .57543 m
.59077 .65118 L
s
.67673 .11602 m
.65254 .12682 L
s
.64068 .10786 m
.65254 .12682 L
s
.373 .619 .627 r
.62786 .06888 m .63978 .08712 L .66398 .07728 L F
.374 .618 .626 r
.60373 .0788 m .63978 .08712 L .62786 .06888 L F
.89 .66 .41 r
.71249 .12399 m
.70115 .10558 L
s
.373 .619 .627 r
.66398 .07728 m .69982 .08561 L .6884 .06735 L F
.89 .66 .41 r
.51989 .11206 m
.49627 .12277 L
s
.5338 .85651 m
.51005 .83602 L
s
.49676 .85106 m
.51005 .83602 L
s
.58026 .11016 m
.55638 .12109 L
s
.5437 .10142 m
.55638 .12109 L
s
.64068 .10786 m
.61654 .11865 L
s
.60434 .09947 m
.61654 .11865 L
s
.373 .619 .627 r
.59145 .06042 m .60373 .0788 L .62786 .06888 L F
.374 .618 .626 r
.5674 .07041 m .60373 .0788 L .59145 .06042 L F
.89 .66 .41 r
.70115 .10558 m
.67673 .11602 L
s
.66504 .09735 m
.67673 .11602 L
s
.45751 .73734 m
.43506 .7009 L
s
.43506 .7009 m
.4475 .75701 L
s
.373 .619 .627 r
.65221 .05887 m .66398 .07728 L .6884 .06735 L F
.62786 .06888 m .66398 .07728 L .65221 .05887 L F
.89 .66 .41 r
.60359 .68447 m
.61579 .69764 L
s
.61579 .69764 m
.59313 .77192 L
s
.5278 .51959 m
.54082 .59467 L
s
.5278 .51959 m
.50396 .55596 L
s
.59313 .77192 m
.60494 .76068 L
s
.60494 .76068 m
.58177 .81648 L
s
.5437 .10142 m
.51989 .11206 L
s
.48009 .57927 m
.45655 .58689 L
s
.45655 .58689 m
.46858 .67333 L
s
.56442 .54007 m
.57762 .60111 L
s
.56442 .54007 m
.54082 .59467 L
s
.60434 .09947 m
.58026 .11016 L
s
.56772 .09088 m
.58026 .11016 L
s
.66504 .09735 m
.64068 .10786 L
s
.62864 .08897 m
.64068 .10786 L
s
.48337 .83904 m
.46047 .7932 L
s
.4475 .75701 m
.46047 .7932 L
s
.70115 .10558 m
.68963 .08702 L
s
.373 .619 .627 r
.61573 .05033 m .62786 .06888 L .65221 .05887 L F
.59145 .06042 m .62786 .06888 L .61573 .05033 L F
.65221 .05887 m .6884 .06735 L .67678 .04877 L F
.89 .66 .41 r
.4702 .79953 m
.4475 .75701 L
s
.46858 .67333 m
.44536 .66075 L
s
.44536 .66075 m
.45751 .73734 L
s
.56772 .09088 m
.5437 .10142 L
s
.50396 .55596 m
.51675 .63862 L
s
.50396 .55596 m
.48009 .57927 L
s
.62864 .08897 m
.60434 .09947 L
s
.59196 .08043 m
.60434 .09947 L
s
.48009 .57927 m
.49252 .666 L
s
.68963 .08702 m
.66504 .09735 L
s
.65317 .07858 m
.66504 .09735 L
s
.373 .619 .627 r
.64024 .04015 m .65221 .05887 L .67678 .04877 L F
.61573 .05033 m .65221 .05887 L .64024 .04015 L F
.89 .66 .41 r
.57762 .60111 m
.59077 .65118 L
s
.57762 .60111 m
.55408 .66486 L
s
.59077 .65118 m
.60359 .68447 L
s
.60359 .68447 m
.58053 .75918 L
s
.59196 .08043 m
.56772 .09088 L
s
.5579 .85007 m
.5338 .85651 L
s
.52073 .87355 m
.5338 .85651 L
s
.65317 .07858 m
.62864 .08897 L
s
.61642 .07003 m
.62864 .08897 L
s
.68963 .08702 m
.67793 .06826 L
s
.5695 .83141 m
.58177 .81648 L
s
.58177 .81648 m
.5579 .85007 L
s
.59077 .65118 m
.56741 .7221 L
s
.373 .619 .627 r
.64024 .04015 m .67678 .04877 L .66497 .02988 L F
.89 .66 .41 r
.54082 .59467 m
.55408 .66486 L
s
.54082 .59467 m
.51675 .63862 L
s
.52073 .87355 m
.49676 .85106 L
s
.48337 .83904 m
.49676 .85106 L
s
.61642 .07003 m
.59196 .08043 L
s
.54519 .86708 m
.5579 .85007 L
s
.67793 .06826 m
.65317 .07858 L
s
.6411 .05965 m
.65317 .07858 L
s
.49252 .666 m
.46858 .67333 L
s
.46858 .67333 m
.48107 .75434 L
s
.48107 .75434 m
.45751 .73734 L
s
.45751 .73734 m
.4702 .79953 L
s
.58053 .75918 m
.59313 .77192 L
s
.59313 .77192 m
.5695 .83141 L
s
.6411 .05965 m
.61642 .07003 L
s
.51675 .63862 m
.52988 .71603 L
s
.51675 .63862 m
.49252 .666 L
s
.67793 .06826 m
.66602 .04926 L
s
.49252 .666 m
.50538 .7473 L
s
.55408 .66486 m
.56741 .7221 L
s
.55408 .66486 m
.52988 .71603 L
s
.50737 .86156 m
.48337 .83904 L
s
.4702 .79953 m
.48337 .83904 L
s
.49405 .82008 m
.4702 .79953 L
s
.66602 .04926 m
.6411 .05965 L
s
.56741 .7221 m
.58053 .75918 L
s
.58053 .75918 m
.55655 .81905 L
s
.56741 .7221 m
.54323 .77897 L
s
.54519 .86708 m
.52073 .87355 L
s
.50737 .86156 m
.52073 .87355 L
s
.55655 .81905 m
.5695 .83141 L
s
.5695 .83141 m
.54519 .86708 L
s
.50538 .7473 m
.48107 .75434 L
s
.48107 .75434 m
.49405 .82008 L
s
.52988 .71603 m
.54323 .77897 L
s
.52988 .71603 m
.50538 .7473 L
s
.53198 .85498 m
.54519 .86708 L
s
.50538 .7473 m
.5186 .8133 L
s
.53198 .85498 m
.50737 .86156 L
s
.49405 .82008 m
.50737 .86156 L
s
.5186 .8133 m
.49405 .82008 L
s
.54323 .77897 m
.55655 .81905 L
s
.55655 .81905 m
.53198 .85498 L
s
.54323 .77897 m
.5186 .8133 L
s
.5186 .8133 m
.53198 .85498 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[228]:=",
  ImageSize->{265.313, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004900017b000`400?l00000o`00003oo`3Pool9
0>3oo`40oooo003o0>3oo`T0h?oo0@3oool00?l0h?oo2@3Pool10?ooo`00o`3Pool90>3oo`40oooo
003o0>3oo`T0h?oo0@3oool00?l0h?oo2@3Pool10?ooo`00o`3Pool90>3oo`40oooo003o0>3oo`T0
h?oo0@3oool00:d0h?oo0`1OWZ1H0>3oo`40oooo002[0>3oo`H0GijPE`3Pool10?ooo`00Z@3Pool8
05nNX5L0h?oo0@3oool00:L0h?oo2`1OWZ1F0>3oo`40oooo002U0>3oo`d0GijPEP3Pool10?ooo`00
XP3Pool=05nNX080hjQX0P1OWZ1E0>3oo`40oooo002P0>3oo`/0GijP103SZ6P205nNX0030>>XJ01O
WZ00GijP05@0h?oo0@3oool009h0h?oo2P1OWZ030>>XJ0H0GijP00<0hjQX05nNX01OWZ00E03Pool1
0?ooo`00W03Pool:05nNX080hjQX0P1OWZ000`3SZ6P0GijP05nNX00505nNX0030>>XJ01OWZ00GijP
05<0h?oo0@3oool009T0h?oo2`1OWZ020>>XJ0@0GijP00<0hjQX05nNX01OWZ001@1OWZ000`3SZ6P0
GijP05nNX01C0>3oo`40oooo002E0>3oo`d0GijP0P3SZ6P705nNX0030>>XJ01OWZ00GijP00@0GijP
0P3SZ6P205nNX580h?oo0@3oool009<0h?oo0`1OWJ0:05nNX080hjQX00<0GijP0>>XJ01OWZ001P1O
WZ000`3SZ6P0GijP05nNX0040>>XJ080GijP00<0hjQX05nNX01OWZ00D@3Pool10?ooo`00T@3Pool6
05nMX0L0GijP0P3SZ6P405nNX0030>>XJ01OWZ00GijP00D0GijP0P3SZ6P605nNX0030>>XJ01OWZ00
GijP0540h?oo0@3oool008l0h?oo2@1OWJ0405nNX080hjQX0P1OWIl405nNX0030>>XJ01OWZ00GijP
00<0GijP0P3SZ6P00`1OWZ00hjQX05nNX00605nNX0030>>XJ01OWZ00GijP0500h?oo0@3oool008`0
h?oo101PWIl905nMX00505nNX03SZ6P0hjQX05nMW`3SZ6P00`1OWIl405nNX0030>>XJ01OWZ00GijP
0080hjQX0`1OWZ000`3SZ6P0GijP05nNX00505nNX0030>>XJ01OWZ00GijP0500h?oo0@3oool008T0
h?oo201PWIl705nMX080hjQX0`1OWIl0103SZ6P0GifO05nMW`1OWIl405nNX0<0hjQX1P1OWZ000`3S
Z6P0GijP05nNX00405nNX080hjQX0P1OWZ1?0>3oo`40oooo00270>3oo`X0H9fO101OWJ030>>XJ080
H9fO101OWIl01@3SZ6P0GifO05nMW`1OWIl0GijP0080hjQX00<0GijP05nMW`3SZ6P00P1OWIl405nN
X0030>>XJ01OWZ00GijP00@0hjQX0P1OWZ000`3SZ6P0GijP05nNX01>0>3oo`40oooo00250>3oo``0
H9fO103SZ6P2062MW`040>>XJ01PWIl0H9fO062MW`<0GifO00<0hjQX05nMW`1OWIl00P3SZ6P405nM
W`040>>XJ01OWIl0GifO05nMW`@0GijP0P3SZ6P605nNX0030>>XJ01OWZ00GijP04h0h?oo0@3oool0
08<0h?oo301PWIl20>>XJ0H0H9fO00@0hjQX062MW`1PWIl0H9fO101OWIl20>>XJ080H9fO1@1OWIl0
1@3SZ6P0GifO05nMW`1OWIl0GijP0080hjQX00@0GifO0>>XJ01OWIl0GifO1@1OWZ000`3SZ6P0GijP
05nNX01=0>3oo`40oooo00210>3oo`<0HIbO2@1PWIl20>>XJ004066LW`3SZ6P0HIbO066LW`D0H9fO
00D0hjQX062MW`1PWIl0H9fO05nMW`020>>XJ003062MW`3SZ6P0H9fO0080H9fO101OWIl00`3SZ6P0
GifO05nMW`020>>XJ0<0GifO00@0hjQX05nMW`1OWIl0GifO101OWZ020>>XJ00305nNX03Pool0h?oo
04/0h?oo0@3oool007l0h?oo1P1QW9l6062MW`80hjQX0`1QW9l0103SZ6P0HIbO066LW`1QW9l4062M
W`030>>XJ01PWIl0H9fO0080hjQX0`1PWIl0103SZ6P0H9fO062MW`1PWIl405nMW`<0hjQX0P1PWIl4
05nMW`050>>XJ01OWIl0GifO05nMW`1OWZ000P3SZ6P205nMX0030>>XJ01OWJ00h?oo04/0h?oo0@3o
ool007d0h?oo201QW9l4062MW`80hjQX0P1QW9h4066LW`040>>XJ01QW9l0HIbO066LW`@0H9fO0P3S
Z6P2066LW`@0H9fO00D0hjQX062MW`1PWIl0H9fO05nMW`020>>XJ080H9fO00@0hjQX062MW`1PWIl0
H9fO0`1OWIl00`3SZ6P0GifO05nMW`020>>XJ0@0GifP00<0hjQX05nMX01OWJ00B`3Pool10?ooo`00
NP3Pool4066LWPP0HIbO00@0H9fO0>>XJ03SZ6P0hjQX101QW9h4066LW`030>>XJ01QW9l0HIbO0080
HIbO0P3SZ6P00`1QW9l0hjQX066LW`02066LW`<0H9fO00<0hjQX062MW`1PWIl00P3SZ6P4062MW`04
0>>XJ01PWIl0H9fO062MW`@0GifO0P3SZ6P2062MW`D0GifP00<0hjQX05nMX03Pool0BP3Pool10?oo
o`00M`3Pool8066LWPH0HIbO0P3SZ6P3066LWP030>>XJ01QW9h0HIbN0080HIbN0`1QW9l00`3SZ6P0
HIbO06:KWP020>>XJ0<0HIbO00<0hjQX066LW`1QW9l00P1QW9l3062MW`80hjQX0P1QW9l5062MW`05
0>>XJ01PWIl0H9fO062MW`1OWIl00P3SZ6P00`1PWIl0hjQX062MW`02062MW`@0GifP00<0hjQX05nM
X01OWJ00BP3Pool10?ooo`00M@3Pool306:LWPP0HIbN0P1QW9l30>>XJ080HY^N0`1QW9h00`3SZ6P0
HIbN066LWP03066LWP80HIbO0`3SZ6P306:KWP<0HIbO00<0hjQX066LW`1QW9l00P1QW9l20>>XJ003
066LW`3SZ6P0HIbO0080HIbO101PWIl00`3SZ6P0H9fO062MW`020>>XJ0<0H9fO00@0hjQX062MW`1P
WIl0H9fO101OWJ020>>XJ00305nMX03Pool0h?oo04P0h?oo0@3oool007<0h?oo1P1RW9h7066LWP80
hjQX00<0HY^N0>>XJ01RVih00`1RVih3066LWP030>>XJ01QW9h0HIbN0080HIbN0P3SZ6P206:KWP04
0>>XJ01RVih0HY^N06:KWP<0HIbO00<0hjQX066LW`1RVih00P3SZ6P4066LW`040>>XJ01QW9l0HIbO
066LW`@0H9fO0P3SZ6P2066LW`@0H9fO00D0hjQX062MW`1PWIl0H9fO05nMX0020>>XJ080H9fO00<0
hjQX062MW`3Pool0B03Pool10?ooo`00L@3Pool806:LWPD0HIbN0P3SZ6P01@1SVYd0HY^N06:KWP1R
Vih0hjQX00@0HY^N0P1QW9h00`3SZ6P0HIbN06>JW@020>>XJ00506>JW@1RVih0HY^N06:KWP3SZ6P0
101RVih2066LW`0306:KWP3SZ6P0hjQX00<0HY^N0`1QW9l00`3SZ6P0HIbO066LW`03066LW`80hjQX
00<0HIbO0>>XJ01QW9l00P1QW9l3062MW`030>>XJ01PWIl0H9fO0080hjQX101PWIl00`3SZ6P0H9fO
062MW`180>3oo`40oooo001^0>3oo`@0HY^N201RW9h2066LWP80hjQX101SVYd206:KWP030>>XJ01R
Vih0HY^N0080HY^N0`1SVYd20>>XJ0@0HiZM0`1RVih00`3SZ6P0HY^N06:KWP0206:KWP80hjQX00<0
HY^N0>>XJ01RVih00P1RVih4066LW`030>>XJ01RVih0HY^N0080hjQX0`1QW9l0103SZ6P0HIbO066L
W`1QW9l4062MW`80hjQX0P1QW9l5062MW`030>>XJ01PWIl0H9fO04L0h?oo0@3oool006/0h?oo201R
Vih706:LWP80hjQX00<0HiZM0>>XJ01SVYd00`1SVYd306:KWP030>>XJ01RVih0I9VL0080I9VL0P3S
Z6P00`1SVYd0hjQX06>JW@0406>JW@80HY^N00<0hjQX06BJW@1TVYd00P3SZ6P306:KWP030>>XJ01R
Vih0HY^N0080HY^N0P1QW9l0101RVih0hjQX0>>XJ03SZ6P206:KWP@0HIbO00D0hjQX066LW`1QW9l0
HIbO062MW`020>>XJ003066LW`3SZ6P0HIbO0080HIbO101PWIl00`3SZ6P0H9fO062MW`170>3oo`40
oooo001X0>3oo``0HY^N0`1RW9h0101TVYd0hjQX0>>XJ01TVYd206>JW@030>>XJ01SVYd0HiZM00<0
HiZM0P1RVih00`3SZ6P0I9VL06BIW0020>>XJ00506BIW01SVYd0HiZM06>JW@3SZ6P0101SVYd306BJ
W@80hjQX0`1TVYd306:KWP030>>XJ01RVih0HY^N0080HY^N0P3SZ6P206:KWP040>>XJ01RVih0HY^N
06:KWP<0HIbO00<0hjQX066LW`1QW9l00P3SZ6P3066LW`040>>XJ01QW9l0HIbO066LW`@0H9fO0P3S
Z6P2062MWdH0h?oo0@3oool006D0h?oo3`1RVih0101TVYd0hjQX0>>XJ03SZ6P406BJW@80HiZM00<0
hjQX06>JW@1SVYd00P1SVYd306BIW080hjQX101TVI`206>JW@030>>XJ01SVYd0HiZM00<0IIRK0`3S
Z6P506BJW@80HY^N00<0hjQX06BIW@1TVId00P3SZ6P406:KWP030>>XJ01RVih0HY^N0080HY^N0`1Q
W9l20>>XJ080HY^N101QW9l01@3SZ6P0HIbO066LW`1QW9l0H9fO0080hjQX0P1PWIl00`3SZ6P0H9fO
062MW`150>3oo`40oooo001S0>3oo`l0HY^N0`3SZ6P206BJW@030>>XJ01TVYd0I9ZM00<0I9ZM0P1S
VYd00`3SZ6P0IIRK06FHV`0206FHV`<0hjQX1P1TVI`206>JW@030>>XJ01UV9/0IIRK0080hjQX00@0
IIRK06BJW@1TVYd0hjQX101TVYd306BIW@80hjQX0`1TVId406:KWP030>>XJ01RVih0HY^N0080HY^N
0P3SZ6P00`1RVih0hjQX06:KWP0206:KWP<0HIbO00<0hjQX066LW`1QW9l00P3SZ6P4062MW`030>>X
J01PWIl0H9fO04D0h?oo0@3oool00640h?oo3`1RVih20>>XJ0@0I9VL00<0I9ZM0>>XJ01TVYd0101T
VYd206FHV`030>>XJ01UV9/0IIRK0080hjQX00@0IIRK06BIW01TVI`0hjQX1@1TVI`306FHV`80hjQX
0`1UV9/206BJW@030>>XJ01TVYd0I9ZM00<0IYNK0P3SZ6P00`1TVId0hjQX06BIW@0306BIW@<0HY^N
00<0hjQX06BJW@1TVYd00P3SZ6P306:KWP030>>XJ01RVih0HY^N0080HY^N0`1QW9l20>>XJ080HIbN
1@1PWIl00`3SZ6P0H9fO062MW`140>3oo`40oooo001O0>3oo`l0HY^N0P3SZ6P00`1TVI`0hjQX06BI
W00306BIW080I9ZM00<0hjQX06BJW@1TVYd00`1WUiX206FHV`80hjQX101UV9/0101TVI`0hjQX06BI
W01TVI`406NFVP<0hjQX1@1UV9/206BJW@060>>XJ01VUi/0IYNK06JGV`3SZ6P0IYNK0P1TVId00`3S
Z6P0I9VM06BIW@0206BIW@@0I9ZM0P3SZ6P306BJW@<0HY^N00D0hjQX06:KWP1RVih0HY^N066LWP02
0>>XJ003066LWP3SZ6P0HIbN0080HIbN101PWIl00`3SZ6P0H9fO062MW`140>3oo`40oooo001L0>3o
o`l0HY^N00@0IIVL0>>XJ03SZ6P0IIVL0P1TVI`00`3SZ6P0I9VL06BIW00306BIW080I9ZM00<0hjQX
06NGVP1WUiX00P1WUiX30>>XJ0H0IIRK00<0IiJJ0>>XJ01WUYX00P1WUYX20>>XJ00406NFVP1UV9/0
IIRK0>>XJ0@0IIRK0P1VUi/0103SZ6P0IYNK0>>XJ03SZ6P206JGV`<0I9VM00<0hjQX06BIW@1VUi/0
0P1VUi/0101TVYd0hjQX0>>XJ03SZ6P406BJW@<0HY^N00<0hjQX06:KWP1SVYd00P3SZ6P3066LWP03
0>>XJ01QW9h0HIbN0080HIbN0`1PWIl20>>XJ080HIbO@`3Pool10?ooo`00F@3Pool?06:KWP80IIVL
0P3SZ6P406FIW080I9VL00<0hjQX06BIW01TVI`00P1TVI`206NGVP030>>XJ01WUiX0IiNJ0080hjQX
0P1WUiX00`1UV9/0hjQX06FHV`0206FHV`<0JIBH00@0hjQX06NFVP3SZ6P0hjQX101WUYX00`1UV9/0
hjQX06FHV`0406VDV@80IYNK00<0hjQX06JGV`1VUi/00`1VUi/206BIW@0306JGV`3SZ6P0IYNK0080
IYNK00D0hjQX06BJW@1TVYd0I9ZM0>>XJ00406BJW@80HY^N00<0HiZM0>>XJ03SZ6P00`1SVYd3066L
WP050>>XJ01QW9h0HIbN066LWP1QW9l00P3SZ6P2066LW`030>>XJ01QW9l0HIbO0480h?oo0@3oool0
05L0h?oo3P1RVih306FIW080hjQX00<0IIVL0>>XJ01UVI`0101UVI`0101TVI`0hjQX06BIW01TVI`3
06RFVP80IiNJ0P3SZ6P506NGVP030>>XJ01UV9/0JIBH00D0JIBH00<0hjQX06NFVP1WUYX0101WUYX2
06VDV@030>>XJ01YU9T0JIBI0080JIBI0`3SZ6P806JGV`050>>XJ01VUi/0hjQX0>>XJ01VUi/00`1T
VYd00`3SZ6P0I9ZM06BJW@0206BJW@0406>JW@3SZ6P0hjQX0>>XJ0@0HiZM0`1QW9h00`3SZ6P0HIbN
06:KWP020>>XJ0@0HIbO00@0hjQX066LW`1QW9l0HIbO@@3Pool10?ooo`00E@3Pool=06:KWP@0IIVL
0P3SZ6P306FIW0030>>XJ01UVI`0IIVL00@0IIVL00<0J9JJ0>>XJ01XUYX00`1XUYX30>>XJ0H0IiNJ
00<0JIBH0>>XJ01YU9P00`1YU9P20>>XJ00306NFVP3SZ6P0IiJJ0080IiJJ0`1/TIL0101YU9T0hjQX
06VDV@1YU9T20>>XJ080JIBI00<0IYNK0>>XJ01VUi/0101YU9T306JGV`030>>XJ01VUi/0IYNK0080
IYNK0`1TVYd01@3SZ6P0IIRK06FHV`1UV9/0hjQX00<0HiZM00<0hjQX06>JW@1SVYd00P1SVYd2066L
WP0306:KWP3SZ6P0hjQX00<0HY^N101QW9l00`3SZ6P0HIbO066LW`110>3oo`40oooo001C0>3oo`h0
HY^N0P1UVI`30>>XJ0H0IIVL00<0hjQX06FIW01UVI`0101XUIT00`3SZ6P0J9JJ06RFVP020>>XJ080
J9JJ00@0IiNJ0>>XJ01WUiX0IiNJ101/TYL00`3SZ6P0JIBH06VDV0020>>XJ0<0JIBH00<0hjQX06NF
VP1/TIL01@1/TIL00`1YU9T0hjQX0>>XJ00506VDV@030>>XJ01YU9T0JIBI00@0JIBI0`3SZ6P406JG
V`<0IIRK00D0hjQX06FHV`3SZ6P0hjQX06FHV`0306>JW@030>>XJ01SVYd0HiZM0080HiZM00D0HY^N
0>>XJ03SZ6P0HY^N0>>XJ00306:KWP@0HIbO00@0hjQX066LWP1QW9h0HIbN@03Pool10?ooo`00D03P
ool406:LWP/0HY^N00@0IIVL0>>XJ03SZ6P0hjQX0P1UVI`00`3SZ6P0IIVL06FIW00406FIW00306RE
V@3SZ6P0J9FI00@0J9FI0`3SZ6P506RFVP030>>XJ01/TYL0K9:G00D0K9:G0P3SZ6P506VDV00306bA
U`3SZ6P0K96G00@0K96G0`3SZ6P306VDV@<0KI2F00<0JIBI0>>XJ01YU9T00P1YU9T20>>XJ00406VD
V@1VUi/0IYNK0>>XJ0@0JIBI0`1UV9/00`3SZ6P0IIRK06FHV`0206FHV`<0HiZM00D0hjQX06BIW01T
VI`0I9VL0>>XJ00306:KWP030>>XJ01RVih0HY^N0080HY^N0P1QW9l00`1QW9h0hjQX0>>XJ003066L
WSl0h?oo0@3oool004d0h?oo201RW9h806:KWP<0hjQX1@1UVI`00`3SZ6P0IIVL06FIW00206FIW0<0
JIBI00<0hjQX06REV@1XUIT00`3SZ6P00`1XUIT0hjQX06RFVP0206RFVP@0KI2F00<0hjQX06bBU`1/
TYL00P1/TYL20>>XJ00406bBU`3SZ6P0JIBH06VDV0@0KhjD00<0K96G0>>XJ01/TIL00P1/TIL01@3S
Z6P0K96G06bAU`1YU9T0hjQX00H0KI2F00@0hjQX06VDV@3SZ6P0hjQX1@1YU9T00`3SZ6P0JIBI06VD
V@0306VDV@<0hjQX101UV9/306BIW0050>>XJ01TVI`0hjQX0>>XJ01TVI`0101RVih01@3SZ6P0HY^N
06:KWP1RVih0HIbN0080hjQX00<0HIbN0>>XJ01QW9h00P1QW9ho0>3oo`40oooo001;0>3oo`<0HIbN
201RW9h406:KWP<0hjQX00<0I9VL06FIW03SZ6P01P1UVI`00`3SZ6P0IIVL06VDV@0506VDV@80hjQX
1@1XUIT00`3SZ6P0KI2F06f@UP0406f@UP030>>XJ01/TYL0K9:G0080hjQX0`1/TYL00`3SZ6P0KhjD
06n>U00506n>U0040>>XJ01/TIL0hjQX0>>XJ0<0K96G00<0KI2F0>>XJ01]T9H01@1]T9H00`1YU9T0
hjQX06VDV@0206VDV@<0KI2F0P1YU9T01P3SZ6P0JIBI06VDV@1YU9T0hjQX06VDV@80IIRK00<0hjQX
06NFVP1WUYX00P1WUYX306BIW0030>>XJ01TVI`0I9VL0080I9VL0`1RVih00`3SZ6P0HiZM06>JW@02
0>>XJ0@0HIbN00@0hjQX066LWP1QW9h0HIbN?P3Pool10?ooo`00B03Pool7066LWPP0HYbN00<0I9VL
0>>XJ03SZ6P01@1TVI`00`3SZ6P0IIVL06FIW00406FIW00306VDV@3SZ6P0JIBI00<0JIBI0`3SZ6P4
06REV@80KhnE00<0hjQX06f@UP1]T9H01@1]T9H20>>XJ080K9:G101bRi800`3SZ6P0KhjD06n>U005
06n>U0030>>XJ01/TIL0K96G00@0LXbB00<0KI2F0>>XJ01]T9H00`1]T9H20>>XJ00306VDV@3SZ6P0
KI2F00D0KI2F00<0JIBI0>>XJ01YU9T00P3SZ6P206VDV@80IiJJ00<0hjQX06NFVP1WUYX00`1WUYX2
0>>XJ00306BIW03SZ6P0I9VL0080I9VL101SVYd20>>XJ080HiZM101QW9h0103SZ6P0HIbN066LWP1Q
W9hn0>3oo`40oooo00160>3oo`<0HIbO1`1QW9h406:LWP80I9ZM0P3SZ6P00`1TVI`0hjQX06BIW005
06BIW0030>>XJ01UVI`0IIVL00@0J9FI00<0hjQX06VDV@1YU9T00P3SZ6P306VDV@030>>XJ01XUIT0
KhnE00@0KhnE00<0hjQX06f@UP1]T9H00P1]T9H30>>XJ0L0LX^B00<0hjQX06n>U01_SY@00`1_SY@3
0>>XJ0L0LXbB00D0hjQX06f@UP1]T9H0KI2F0>>XJ00306f@UP030>>XJ01]T9H0KI2F00@0KI2F0P1Y
U9T00`3SZ6P0JIBI06VDV@0306bAU`80IiJJ00H0hjQX06NFVP1WUYX0IiJJ0>>XJ01WUYX206BIW003
0>>XJ01UV9/0IIRK0080IIRK00D0HiZM0>>XJ03SZ6P0HiZM0>>XJ00306>JW@@0HIbN00@0hjQX06:L
WP1RW9h0HYbN?@3Pool10?ooo`00A03Pool6066LW`L0HIbN0`1TVYd20>>XJ0<0I9ZM00<0hjQX06BI
W01TVI`0101TVI`00`1XUIT0hjQX06REV@0406REV@<0hjQX1@1YU9T00`3SZ6P0KhnE06n?U@0406n?
U@060>>XJ01]T9H0KI2F06f@UP3SZ6P0KI2F0P1eRI000`3SZ6P0LX^B07:;TP0507:;TP050>>XJ01_
SY@0KhjD06n>U03SZ6P00`1gQhh00`3SZ6P0LXbB07:<TP0507:<TP<0hjQX101cRi400`1]T9H0hjQX
06f@UP0506f@UP80hjQX1P1/TIL00`1WUYX0hjQX06NFVP020>>XJ080IiJJ0`1UV9/01@3SZ6P0IIRK
06FHV`1UV9/0hjQX00<0HiZM00@0hjQX06>JW@1SVYd0HiZM0P1RW9h20>>XJ00406:LWP3SZ6P0HYbN
06:LWSd0h?oo0@3oool00480h?oo2@1QW9l5066LWP80HiZM0P3SZ6P606BJW@030>>XJ01TVI`0I9VL
00@0J9JJ00<0hjQX06REV@1XUIT00`3SZ6P00`1XUIT0hjQX06VDV@0206VDV@<0KhnD00<0hjQX06n?
U@1_SiD01@1_SiD30>>XJ0@0MHV@00<0hjQX07F9T01bRi801@1bRi80103SZ6P0MhN>0>>XJ03SZ6P4
07N7SP030>>XJ01bS980LXbB00D0LXbB00<0hjQX07>;T@1cRi401@1cRi400`3SZ6P0KI2F06f@UP03
06f@UP040>>XJ01/TIL0K96G0>>XJ0D0K96G0P1WUYX00`3SZ6P0IiJJ06NFVP0306VDV080IIRK00@0
hjQX06FHV`3SZ6P0hjQX0P1UV9/306>JW@050>>XJ01TVYd0I9ZM06BJW@3SZ6P00`1RW9h0103SZ6P0
HYbN06:LWP1RW9hl0>3oo`40oooo00100>3oo`<0H9fO2@1QW9l2066LWP0706>JW@3SZ6P0hjQX0>>X
J01SVYd0I9ZM0>>XJ00506BJW@030>>XJ01XUYX0J9JJ00D0J9JJ0P3SZ6P506REV@030>>XJ01_Si@0
KhnD00@0KhnD00<0hjQX06n?U@1_SiD0101_SiD00`3SZ6P0MHV@07F9T00507F9T0030>>XJ01bRi80
LX^B00<0LX^B0P1lPX/00`3SZ6P0MhN>07N7SP0407N7SP030>>XJ01gQhh0LXbB0080LXbB0P1jQ8d2
0>>XJ0P0Lh^A00<0hjQX06f@UP1]T9H00P3SZ6P207:<TP0306bAU`3SZ6P0K96G00@0K96G0P3SZ6P0
0`1WUYX0hjQX06VDV00406VDV080IIRK00<0hjQX06FHV`1UV9/00P1UV9/306BJW@050>>XJ01TVYd0
hjQX0>>XJ01TVYd0101RW9h00`3SZ6P0HYbN06:LWP0l0>3oo`40oooo000m0>3oo`L0H9fO201QW9l3
0>>XJ0D0HiZM00<0hjQX06BJW@1TVYd00P1TVYd206NGVP030>>XJ01XUYX0J9JJ0080J9JJ0`3SZ6P4
06REV@80KhnE00<0hjQX06n?U01_Si@0101_Si@00`3SZ6P0KhnD06n?U@0206n?U@<0hjQX00<0MhN>
07F9T01eRI00101eRI00103SZ6P0MHV@07:;TP1bRi8207b2R`<0hjQX00<0O8:;07N7SP1gQhh0101g
Qhh00`3SZ6P0NXB=07Z4S@0207Z4S@040>>XJ01jQ8d0NXB=0>>XJ0L0Lh^A00<0hjQX07:<TP3SZ6P0
1@1bS9800`1/TIL0hjQX06bAU`0206bAU`050>>XJ01/TIL0JIBH06VDV03SZ6P01@1YU9P20>>XJ003
06FHV`3SZ6P0IIRK00<0IiNJ0`1TVYd00`3SZ6P0I9ZM06BJW@0206BJW@<0HYbN00@0hjQX06:KWP1R
Vih0HY^N>`3Pool10?ooo`00>P3Pool;062MW`@0HIbO0`3SZ6P00`1RVih0HiZM0>>XJ00606>JW@03
0>>XJ01TVYd0IiNJ00<0IiNJ00<0hjQX06RFVP1XUYX00P3SZ6P306RFVP030>>XJ01_SiD0KhnE00@0
KhnE00<0hjQX06n?U01_Si@0101_Si@0103SZ6P0KhnD0>>XJ03SZ6P307N7SP030>>XJ01gQhh0MHV@
00D0MHV@00D0hjQX07b2R`1lPX/0O8:;0>>XJ00307b2R`030>>XJ01gQhh0MhN>00<0MhN>00@0P7j8
0>>XJ020OXP0NXB=0P3SZ6P307Z4S@030>>XJ01jQ8d0Lh^A0080Lh^A101jQ8d00`3SZ6P0LXbB07:<
TP0507:<TP040>>XJ01/TIL0hjQX0>>XJ0<0KhjD0P1YU9P01P3SZ6P0JIBH06VDV01YU9P0hjQX06VD
V080IIRK00<0hjQX06NGVP1WUiX00`1WUiX20>>XJ00306BJW@3SZ6P0I9ZM0080I9ZM101RVih0103S
Z6P0HY^N06:KWP1RVihj0>3oo`40oooo000g0>3oo`l0H9fO0`3SZ6P506:KWP0306>JW@3SZ6P0HiZM
00@0HiZM00<0hjQX06NGVP1WUiX00P1WUiX40>>XJ0@0J9JJ00<0KI2F0>>XJ01]T9H01@1_SiD00`3S
Z6P0KhnE06n?U00306n?U0<0hjQX00<0N8J>07N7SP1gQhh00P1gQhh00`3SZ6P0MhN>07N7SP0407F9
T00307moR03SZ6P0Ogn80080hjQX101lPX/0103SZ6P0O8:;07N7SP1gQhh4081nR080hjQX1@1jQ8d0
0`3SZ6P0NXB=07Z4S@0407Z4S@<0hjQX1`1bS9800`1_SY@0hjQX06n>U00506n>U00306VDV03SZ6P0
JIBH0080hjQX0P1YU9P306NGVP060>>XJ01WUiX0IiNJ06NGVP3SZ6P0IiNJ0P1TVYd00`3SZ6P0I9VL
06BIW00206BIW00506:KWP3SZ6P0hjQX06:KWP3SZ6P00`1RVihi0>3oo`40oooo000f0>3oo`80GifP
2`1PWIl01P1QW9h0hjQX0>>XJ01QW9h0HY^N0>>XJ0H0HY^N00<0hjQX06>JW@1SVYd00`1UV9/50>>X
J080IiNJ00@0hjQX06NGVP1XUYX0J9JJ0`1]T9H00`3SZ6P0KI2F06f@UP0506n?U@030>>XJ01_SiD0
hjQX0080hjQX00<0N8J>0>>XJ01hQXh00P1hQXh307N7SP040>>XJ01gQhh0MhN>07N7SPD0Ogn800<0
hjQX07moR01lPX/0101lPX/00`3SZ6P0O8:;081nR005081nR0030>>XJ020OXP0P7j800<0NXB=0P22
O8H00`3SZ6P0PWb607Z4S@0207Z4S@050>>XJ01jQ8d0NXB=07Z4S@3SZ6P00`1bS98307N7SP80hjQX
1`1_SY@00`1YU9P0hjQX06VDV00406bBU`80IiNJ00@0hjQX06NGVP3SZ6P0hjQX0P1WUiX306BIW005
0>>XJ01TVI`0I9VL06BIW03SZ6P00`1RVih0103SZ6P0HY^N06:KWP1RVihi0>3oo`40oooo000d0>3o
o`D0GifP1`1PWIl0101QW9h0hjQX0>>XJ03SZ6P4066LWP0306:KWP3SZ6P0HY^N00@0HY^N00@0IIRK
0>>XJ01UV9/0IIRK0P3SZ6P206FHV`030>>XJ01WUiX0IiNJ00<0IiNJ00<0hjQX06f@UP1]T9H0101]
T9H00`3SZ6P0KI2F06n?U@0406n?U@80hjQX00<0MhN>07R6SP1hQXh00P1hQXh0103SZ6P0N8J>07R6
SP1hQXh307N7SP040>>XJ022O8H0PWb6089lQP80Ogn80`3SZ6P207moR0@0O8:;00<0QgR30>>XJ027
N8<01020OXP20>>XJ080P7j81@22O8H01@3SZ6P0PWb6089lQP1jQ8d0hjQX00@0NXB=00<0hjQX07N7
SP1gQhh00`1gQhh0103SZ6P0MhN>07N7SP3SZ6P606n>U080hjQX1P1/TYL206NGVP030>>XJ01WUiX0
IiNJ00<0J9JJ0P1TVI`0103SZ6P0I9VL0>>XJ03SZ6P206BIW0<0HY^N00@0hjQX06:KWP1RVih0HY^N
>03Pool10?ooo`00<P3Pool805nMX0@0H9fO0`3SZ6P2066LWP030>>XJ01QW9h0HIbN00<0HIbN00@0
hjQX06:KWP1RVih0HY^N0`1TVI`30>>XJ0@0IIRK00@0hjQX06NGVP1WUiX0IiNJ0P1/TYL00`3SZ6P0
K9:G06f@UP0406f@UP030>>XJ01]T9H0KI2F0080KhnE0`3SZ6P307N7SP<0N8J>00@0hjQX07R6SP1h
QXh0N8J>0`22O8H0103SZ6P0PWb6089lQP22O8H20>>XJ0<0Ogn800<0hjQX07moR01oOhP01027N8<0
0`3SZ6P0QgR308MhP`02081nR0040>>XJ020OXP0P7j80>>XJ080Rg>01@22O8H30>>XJ0<0NXB=0`20
OXP01@3SZ6P0MhN>07N7SP1gQhh0hjQX00<0MhN>00@0hjQX06n>U01_SY@0KhjD0P1bRi80103SZ6P0
LX^B06bBU`3SZ6P606bBU`030>>XJ01WUiX0hjQX00D0J9JJ0P1TVI`00`3SZ6P0I9VL06BIW00206BI
W0<0HY^N00<0hjQX06:KWP1RVih00P1RVihg0>3oo`40oooo000_0>3oo`@0GijP201OWJ030>>XJ0@0
HIbO00<0HIbN0>>XJ01QW9h01@1QW9h00`3SZ6P0I9VL06BIW0030>>XJ00306BIW03SZ6P0IIRK00D0
IIRK00<0hjQX06bBU`1/TYL00`1/TYL00`3SZ6P0K9:G06f@UP0406f@UP040>>XJ01]T9H0hjQX0>>X
J0<0MhN>00@0hjQX07N7SP1gQhh0MhN>0P1hQXh00`3SZ6P0Pg^608=kQP0208=kQP<0PWb60`3SZ6P2
089lQP<0Ogn800@0hjQX08abO`2<LWl0S79o0`27N8<00`3SZ6P0QgR308MhP`020>>XJ080P7j800<0
Rg>00>>XJ02;Lh000P2;Lh04089lQP030>>XJ022O8H0PWb600H0P7j800@0hjQX081nR01gQhh0hjQX
1@1gQhh01@3SZ6P0LX^B07:;TP1bRi80hjQX00<0LX^B00<0hjQX06bBU`1/TYL00`1/TYL0103SZ6P0
J9JJ06RFVP3SZ6P506RFVP80hjQX00<0I9VL0>>XJ01TVI`00`1UVI`306:KWP030>>XJ01RVih0HY^N
0080HY^N=P3Pool10?ooo`00;03Pool805nNX0@0GifP0`3SZ6P2066LW`030>>XJ01QW9l0HIbO00<0
HIbO00@0HIbN0>>XJ01QW9h0HIbN0`1SVYd30>>XJ0D0I9VL00@0hjQX06FHV`1UV9/0IIRK0P1YU9P0
0`3SZ6P0K9:G06bBU`0306bBU`030>>XJ01/TYL0K9:G00<0KI2F0`3SZ6P00`1eRI00MhN>07N7SP02
07N7SP040>>XJ01gQhh0MhN>07N7SP<0Pg^600<0hjQX08=kQP23NhH00P23NhH2089lQP030>>XJ022
O8H0PWb60080PWb60`2<LWl00`3SZ6P0S79o08abO`0208abO`<0QgR30P3SZ6P208MhP`<0Rg>000<0
hjQX08]cP02;Lh000P2;Lh02089lQP80hjQX00<0PWb608]cP02;Lh001P20OXP20>>XJ0<0MhN>0`1l
PX/0103SZ6P0LX^B07:;TP3SZ6P507:;TP030>>XJ01/TYL0K9:G0080hjQX0P1]T9H206RFVP060>>X
J01XUYX0J9JJ06RFVP3SZ6P0J9JJ0P1TVI`00`3SZ6P0IIVL06FIW00206FIW00506:KWP3SZ6P0hjQX
06:KWP3SZ6P00`1RVihf0>3oo`40oooo000Z0>3oo`/0GijP0`3SZ6P4062MW`80HIbO00<0hjQX066L
W`1QW9l00`1QW9l00`3SZ6P0HiZM06>JW@030>>XJ00306>JW@3SZ6P0I9VL00D0I9VL00<0hjQX06VD
V01YU9P0101YU9P00`3SZ6P0K9:G06bBU`0306bBU`030>>XJ01/TYL0hjQX0080hjQX00<0MHV@0>>X
J01eRI000P1eRI0407N7SP040>>XJ01gQhh0PWb6089lQP80Pg^600<0hjQX08=kQP23NhH00P23NhH3
0>>XJ003089lQP2@Kg`0T6ml0080T6ml0P2<LWl00`3SZ6P0S79o08abO`0308abO`80QgR300<0hjQX
09A[N@2DJgT00P2DJgT308]cP0030>>XJ02;Lh00Rg>00080Rg>000@0hjQX089lQP2;Lh00hjQX0`2;
Lh05081nR0030>>XJ020OXP0O8:;00H0O8:;0P3SZ6P607:;TP030>>XJ01]T9H0hjQX00D0KI2F00<0
J9JJ0>>XJ01XUYX00P3SZ6P206RFVP<0IIVL00D0hjQX06FIW01UVI`0IIVL0>>XJ00306:KWP030>>X
J01RVih0HY^N0080HY^N=@3Pool10?ooo`009`3Pool<05nNX080hjQX0P1PWIl00`3SZ6P0H9fO062M
W`03062MW`03066LW`3SZ6P0HIbO00<0HIbO00@0HY^N0>>XJ03SZ6P0hjQX1@1SVYd0103SZ6P0I9VL
06BIW01TVI`306NFVP030>>XJ01YU9P0JIBH00<0JIBH00@0hjQX06VDV01/TYL0K9:G103SZ6P00`1b
Ri80MHV@07F9T00207F9T0040>>XJ01eRI00MHV@07F9T0<0MhN>00<0hjQX089lQP22O8H00P22O8H0
0`23NhH0hjQX08=kQP0208=kQP050>>XJ023NhH0T6ml091_O03SZ6P01@2@Kg`208abO`030>>XJ02<
LWl0S79o0080S79o00<0U6]i0>>XJ03SZ6P01@2DJgT208]cP0050>>XJ02;Lh00Rg>008]cP03SZ6P0
0`2;Lh00103SZ6P0Rg>008]cP02;Lh04081nR080hjQX0P27N8<607b2R`030>>XJ01lPX/0LX^B0080
LX^B101eRI000`3SZ6P0KI2F06f@UP0506f@UP0306RFVP3SZ6P0J9JJ00@0J9FI0P1UVI`01@3SZ6P0
IIVL0>>XJ03SZ6P0IIVL00@0HY^N00@0hjQX06:KWP1RVih0HY^N=@3Pool10?ooo`00903Pool<05nN
X0<0hjQX0`1OWIl2062MW`030>>XJ01PWIl0H9fO00<0H9fO00@0HIbO0>>XJ01QW9l0HY^N0P3SZ6P2
06:KWP030>>XJ01SVYd0HiZM00<0HiZM00<0hjQX06NFVP1WUYX0101WUYX00`3SZ6P0IiJJ06VDV003
06VDV0@0hjQX0P1bRi80103SZ6P0LX^B07:;TP1bRi8307F9T0030>>XJ01eRI00MHV@0080MHV@0`22
O8H0103SZ6P0PWb6089lQP22O8H208=kQP<0hjQX0`2AKW/00`2@Kg`0hjQX091_O005091_O00308ab
O`3SZ6P0S79o00<0VfAd00@0hjQX09A[N@2DJgT0hjQX1@2DJgT01@2;Lh00hjQX08]cP02GJGL0hjQX
0080UfUg0`2;Lh00103SZ6P0Rg>008]cP02;Lh02081nR0040>>XJ027N8<0QgR30>>XJ080QgR3101l
PX/20>>XJ00307b2R`1eRI00MHV@00@0MHV@0P3SZ6P706f@UP030>>XJ01XUIT0hjQX00@0J9FI0`1U
VI`00`3SZ6P0IIVL06FIW00206FIW0@0HY^N00@0hjQX06:KWP1RVih0HY^N=03Pool10?ooo`008@3P
ool=05nNX080hjQX0P1OWIl00`3SZ6P0GifO05nMW`0205nMW`80H9fO00<0hjQX062MW`1PWIl00P1P
WIl40>>XJ0D0HY^N00<0hjQX06>JW@1SVYd00P1SVYd00`1UV9/0hjQX06NFVP0506NFVP030>>XJ01W
UYX0hjQX0080hjQX00@0KhjD0>>XJ01_SY@0KhjD0`1bRi80103SZ6P0LX^B07:;TP1bRi8307F9T003
0>>XJ01oOhP0Ogn80080Ogn80P22O8H00`3SZ6P0PWb6089lQP02089lQP80hjQX1P2AKW/00`2@Kg`0
hjQX091_O004091_O00409]TM03SZ6P0VfAd09]TM080hjQX0P2KI7@00`2DJgT0hjQX09A[N@0409A[
N@80UfUg0P3SZ6P409MYM`80Rg>000H0hjQX08]cP02;Lh00Rg>008MhP`3SZ6P308MhP`040>>XJ027
N8<0QgR308MhP`80O8:;00D0hjQX07moR01oOhP0hjQX07moR00407F9T0040>>XJ01eRI00MHV@0>>X
J0<0KI2F0P1_SiD0103SZ6P0KhnE06REV@3SZ6P506REV@80hjQX00<0IIVL0>>XJ01UVI`00`1UVI`0
101RVih0hjQX0>>XJ03SZ6P306:KWS@0h?oo0@3oool00200h?oo2`1OWZ030>>XJ0<0GijP0P1OWIl0
0`3SZ6P0GifO05nMW`0205nMW`03062MW`3SZ6P0hjQX00<0hjQX0P1QW9l00`1RVih0hjQX06:KWP04
06:KWP030>>XJ01SVYd0HiZM00<0IIRK00<0hjQX06FHV`1WUYX00P1WUYX40>>XJ0D0KhjD00<0hjQX
06n>U01_SY@00P1bRi800`3SZ6P0LX^B07:;TP0207:;TP80Ogn800<0hjQX07moR01oOhP00`1oOhP2
089lQP060>>XJ022O8H0hjQX0>>XJ02AKW/0hjQX1`2AKW/00`3SZ6P0T6ml091_O00409mPL@0309]T
M03SZ6P0hjQX00D0VfAd00<0hjQX09A[N@2DJgT0102QGW000`2GJGL0hjQX09MYM`0509MYM`80Rg>0
00@0hjQX09A[N@2DJgT0hjQX1027N8<01P3SZ6P0QgR308MhP`27N8<0Ogn80>>XJ0<0Ogn800<0hjQX
07moR01oOhP00P1eRI001@3SZ6P0MHV@07F9T01eRI00hjQX00@0KhnE00<0hjQX06n?U@1_SiD00P1X
UIT01@3SZ6P0J9FI06REV@1XUIT0hjQX00<0IIVL00<0hjQX06FIW01UVI`00P1UVI`01@3SZ6P0HY^N
06:KWP1RVih0hjQX00<0HY^N<`3Pool10?ooo`007P3Pool:05nNX0<0hjQX0P1OWZ000`3SZ6P0GijP
05nNX00205nNX080GifO00<0hjQX05nMW`1OWIl00P3SZ6P2066LW`030>>XJ01QW9l0HIbO00<0HIbO
00<0hjQX06:KWP1RVih0101RVih0103SZ6P0IIRK06FHV`1UV9/60>>XJ080IiJJ00<0hjQX06bAU`1/
TIL0101_SY@0103SZ6P0KhjD06n>U01_SY@207:;TP030>>XJ01lPX/0O8:;0080O8:;0P1oOhP00`3S
Z6P0Ogn807moR00307moR003089lQP3SZ6P0hjQX00<0T6ml00<0TFik0>>XJ02AKW/01@2AKW/00`3S
Z6P0Wf1a09mPL@0509mPL@030>>XJ02KI7@0VfAd00@0VfAd00<0hjQX0:5NL02QGW00102QGW020>>X
J0H0UfUg0P2DJgT00`3SZ6P0U6]i0>>XJ00209A[N@@0QgR300D0hjQX08abO`2<LWl0S79o0>>XJ004
07moR0060>>XJ01oOhP0Ogn807F9T03SZ6P0MHV@0`1gQhh0103SZ6P0KhnE06n?U@3SZ6P406n?U@03
06REV@3SZ6P0J9FI0080hjQX0P1YU9T306FIW0050>>XJ01UVI`0hjQX0>>XJ01UVI`00`1RVih00`3S
Z6P0HY^N06:KWP0206:KWS80h?oo0@3oool001`0h?oo2@1OWZ030>>XJ0D0GijP00<0hjQX05nNX01O
WZ000`1OWZ00101OWIl0hjQX0>>XJ03SZ6P3062MW`80HIbO00<0hjQX066LW`1QW9l00`1QW9l00`3S
Z6P0HY^N06:KWP0306BJW@@0hjQX0`1UV9/00`3SZ6P0IIRK06bAU`0306bAU`030>>XJ01/TIL0K96G
00<0KhjD00@0hjQX06n>U01_SY@0KhjD0P1lPX/00`3SZ6P0O8:;07b2R`0307b2R`0307moR03SZ6P0
Ogn800<0Ogn80`3SZ6P5091_O0030>>XJ02AKW/0TFik00<0TFik0P2QGW000`3SZ6P0Wf1a09mPL@02
09mPL@<0hjQX0`2KI7@40:YFJ@030>>XJ02QGW00XEi`0080XEi`00@0hjQX0:5NL02QGW00hjQX0P2G
JGL40:5NL080U6]i00<0hjQX09A[N@2DJgT00P2DJgT208MhP`0608abO`3SZ6P0S79o08abO`3SZ6P0
S79o101oOhP0103SZ6P0Ogn807moR03SZ6P507N7SP030>>XJ01gQhh0hjQX00D0KhnE0P1YU9T00`3S
Z6P0JIBI06VDV@0306VDV@<0IIVL00@0hjQX06FIW01UVI`0IIVL101RVih00`3SZ6P0HY^N06:KWP02
06:KWS40h?oo0@3oool001d0h?oo1P1OWZ020>>XJ080GijP00<0hjQX05nNX01OWZ00101OWZ000`3S
Z6P0GijP05nNX0030>>XJ080H9fO00<0hjQX062MW`1PWIl00P1PWIl00`1QW9l0hjQX066LW`04066L
W`030>>XJ01TVYd0I9ZM00<0hjQX00<0I9ZM0>>XJ01UV9/0101UV9/00`3SZ6P0JIBI06VDV@0306bA
U`040>>XJ01/TIL0K96G06bAU`<0KhjD00@0hjQX07N7SP1gQhh0MhN>0P1lPX/00`3SZ6P0O8:;07b2
R`0307b2R`0307moR03SZ6P0Ogn80080hjQX0P2<LWl00`3SZ6P0T6ml091_O004091_O0030>>XJ02A
KW/0TFik00@0XEi`00D0hjQX09mPL@2OH740Wf1a0>>XJ00309mPL@030>>XJ02ZEVT0ZUIY00@0ZUIY
00D0hjQX0:5NL02QGW00XEi`0>>XJ0030:5NL0030>>XJ02QGW00XEi`00D0XEi`0P3SZ6P409A[N@@0
S79o0P3SZ6P308abO`<0Ogn800@0PWb60>>XJ03SZ6P0PWb61P1gQhh00`3SZ6P0MhN>06n?U@0206n?
U@<0KhnD00<0hjQX06VDV@3SZ6P01@1YU9T00`1UVI`0hjQX0>>XJ00406FIW00506:KWP3SZ6P0hjQX
06:KWP3SZ6P00`1RViha0>3oo`40oooo000N0>3oo`<0GijP0P3SZ6P505nNX0030>>XJ01OWZ00GijP
00<0GijP0`3SZ6P0101OWZ00GifO05nMW`1OWIl2062MW`030>>XJ01PWIl0H9fO0080H9fO00D0HIbO
0>>XJ01QW9l0HIbO06:KWP040>>XJ0D0I9ZM00<0hjQX06FHV`1UV9/00`1YU9T00`3SZ6P0JIBI06VD
V@0306bAU`040>>XJ01/TIL0K96G06bAU`80MhN>00<0hjQX07N7SP1gQhh00P1gQhh00`1lPX/0hjQX
07b2R`0307b2R`@0hjQX1@2<LWl00`3SZ6P0T6ml091_O003091_O0030>>XJ02QGW00XEi`00D0XEi`
0`3SZ6P209mPL@80/51U00<0hjQX0:YFJ@2ZEVT0102ZEVT01@3SZ6P0ZUIY0:5NL03SZ6P0XEi`00@0
[U9V00<0hjQX0:5NL02QGW000`2QGW001@3SZ6P0XEi`09A[N@3SZ6P0U6]i00<0VfAd0`2<LWl00`3S
Z6P0S79o08abO`0208abO`@0PWb600@0hjQX089lQP22O8H0PWb6101gQhh20>>XJ00307N7SP1_Si@0
KhnD00<0KhnD00@0hjQX06n?U01YU9T0hjQX1@1YU9T0103SZ6P0IIVL06FIW03SZ6P306FIW0050>>X
J01RVih0HY^N06:KWP3SZ6P0101RVih`0>3oo`40oooo000O0>3oo`80hjQX00<0GijP0>>XJ01OWZ00
1@1OWZ000`3SZ6P0GijP05nNX0020>>XJ00305nNX01OWIl0hjQX00D0GifO00<0H9fO0>>XJ01PWIl0
101PWIl40>>XJ0<0HY^N00<0hjQX06BJW@1TVYd00`1TVYd00`3SZ6P0JIBI06VDV@0306VDV@040>>X
J01YU9T0JIBI06VDV@80K96G00<0hjQX07:<TP1bS9800P1bS9800`1gQhh0hjQX07N7SP0407N7SPD0
hjQX0P27N8<00`3SZ6P0S79o08abO`0408abO`040>>XJ02@Kg`0T6ml091_O080Wf1a00<0hjQX09mP
L@2QGW001@2QGW000`3SZ6P0XEi`0;1@I@040;1@I@030>>XJ02`D6D0ZUIY00D0ZUIY0P3SZ6P60:iB
IP030>>XJ02QGW00XEi`00<0XEi`00@0hjQX0:5NL02KI7@0hjQX1@2KI7@00`2<LWl0hjQX0>>XJ002
08abO`<0T6ml0P22O8H20>>XJ0@0PWb60P1gQhh01@3SZ6P0N8J>07R6SP3SZ6P0N8J>00<0KhnD00P0
hjQX06n?U01_Si@0KhnD06VDV@3SZ6P0JIBI06REV@80hjQX00D0J9FI06FIW01UVI`0hjQX06FIW002
0>>XJ080IIVL0`1RVih0103SZ6P0HY^N06:KWP1RVih`0>3oo`40oooo000M0>3oo`80hjQX00D0h?oo
05nNX01OWZ00GijP0>>XJ00605nNX080hjQX101OWZ000`1OWIl0hjQX05nMW`0405nMW`04062MW`3S
Z6P0H9fO062MW`80hjQX00<0HIbO06:KWP3SZ6P01@1RVih0103SZ6P0I9ZM06BJW@1TVYd206JGV`03
0>>XJ01YU9T0JIBI00<0JIBI00<0hjQX06VDV@1YU9T00`1bS9800`3SZ6P0LXbB07:<TP0207:<TP03
07N7SP3SZ6P0MhN>00<0hjQX00<0MhN>0>>XJ027N8<01@27N8<00`3SZ6P0S79o08abO`0308abO`03
0>>XJ02OH740Wf1a00@0Wf1a00<0hjQX09mPL@2QGW000P2QGW030>>XJ080/TiS102`D6D00`3SZ6P0
/51U0;1@I@030:YFJ@80^DQN00<0hjQX0;U8GP2^DVH01@2^DVH00`3SZ6P0[U9V0:5NL0020:5NL005
0>>XJ02ZEVT0ZUIY0:YFJ@3SZ6P01@2KI7@0103SZ6P0S79o08abO`3SZ6P5091_O0040>>XJ022O8H0
PWb60>>XJ0<0PWb600<0N8J>0>>XJ01hQXh00P1hQXh00`3SZ6P0N8J>06n?U00206n?U0080>>XJ01_
Si@0KhnD06n?U01XUIT0hjQX06REV@3SZ6P406REV@80IIVL00<0hjQX06FIW01UVI`00P1UVI`406:K
WP040>>XJ01RVih0HY^N06:KWRl0h?oo0@3oool001/0h?oo0P3SZ6P40>3oo`80GijP00<0hjQX05nN
X01OWZ000P1OWZ020>>XJ00305nNX03SZ6P0GijP00@0GijP00<0hjQX05nMW`1OWIl0101OWIl30>>X
J0@0HIbO00<0HY^N0>>XJ01RVih00`1RVih00`3SZ6P0IYNK06JGV`0306JGV`030>>XJ01VUi/0JIBI
00<0JIBI00@0hjQX06VDV@1]T9H0KI2F2P3SZ6P00`1gQhh0P7j8081nR002081nR0030>>XJ027N8<0
QgR300<0QgR300<0hjQX08abO`2<LWl00P2<LWl00`2KI7@0hjQX09]TM00509mPL@050>>XJ02OH740
Wf1a0:5NL03SZ6P00P2bCV<0103SZ6P0/TiS0;9>H`2bCV<40;1@I@030>>XJ02`D6D0^DQN00<0^DQN
0P3SZ6P20;U8GPH0[U9V00@0hjQX0:YFJ@2ZEVT0hjQX102ZEVT00`3SZ6P0VfAd09]TM00309]TM004
0>>XJ02@Kg`0T6ml0>>XJ0D0T6ml00@0hjQX089lQP22O8H0hjQX1023NhH00`3SZ6P0N8J>07R6SP02
07R6SP050>>XJ01hQXh0KhnD0>>XJ01_Si@0101_SiD00`1XUIT0hjQX06REV@0506REV@030>>XJ01U
VI`0hjQX00@0I9VL00@0HY^N0>>XJ03SZ6P0hjQX0`1RVih_0>3oo`40oooo000L0>3oo`030>>XJ03P
ool0h?oo00<0h?oo0P1OWZ00103SZ6P0GijP0>>XJ03SZ6P405nNX0030>>XJ01OWZ00GijP00<0GijP
00<0hjQX05nMW`1OWIl00`3SZ6P00`1PWIl0HIbO0>>XJ005066LW`040>>XJ01RVih0HY^N06:KWP80
I9VM00<0hjQX06JGV`1VUi/00`1VUi/0103SZ6P0IYNK06VDV@1YU9T50>>XJ00306f@UP1bS980hjQX
00D0LXbB00<0hjQX081nR020OXP01020OXP00`3SZ6P0QgR308MhP`0308MhP`030>>XJ027N8<0VfAd
00@0VfAd00<0hjQX09]TM02OH740102OH7430>>XJ0@0/TiS00@0hjQX0;9>H`2bCV<0/TiS0`2`D6D0
0`3SZ6P0`45I0<11F@020;U8GP040>>XJ02iB5h0^DQN0>>XJ080^DQN0`2^DVH20;U8GP030>>XJ02i
B5h0hjQX00H0ZUIY00D0hjQX09]TM02KI7@0Wf1a0>>XJ00209mPL@03091_O03SZ6P0T6ml00<0T6ml
00<0hjQX091_O023NhH00P23NhH0103SZ6P0Pg^608=kQP3SZ6P507R6SP030>>XJ01hQXh0hjQX00H0
KhnE0P3SZ6P506REV@040>>XJ01TVI`0I9VL0>>XJ0@0I9VL00D0hjQX06:KWP1RVih0HY^N0>>XJ003
06:LWRh0h?oo0@3oool001d0h?oo00<0hjQX0>3oo`3Pool00`3Pool00`1OWZ00hjQX0>>XJ00605nN
X0030>>XJ01OWZ00GijP00<0GijP0`3SZ6P5062MW`030>>XJ01QW9l0HIbO00@0HIbO00@0hjQX06BI
W@1TVId0I9VM2`3SZ6P206f@UP030>>XJ01]T9H0KI2F0080KI2F00@0LXbB0>>XJ01bS980LXbB0`1j
Q8d00`3SZ6P0P7j8081nR003081nR0030>>XJ020OXP0QgR30080QgR300@0U6]i0>>XJ02DJgT0U6]i
102KI7@00`3SZ6P0VfAd09]TM00309mPL@040;1@I@3SZ6P0/51U0;1@I@@0/TiS00@0hjQX0;9>H`2b
CV<0/TiS0`30@ET01@3SZ6P0`45I0<11F@30@ET0hjQX00<0^DQN00<0hjQX0;U8GP2iB5h01P2iB5h2
0>>XJ0H0ZUIY00@0hjQX09mPL@2OH740hjQX102OH7401@2@Kg`0hjQX091_O02@Kg`0hjQX00<0TFik
0P23NhH00`3SZ6P0Pg^60>>XJ00208=kQP<0N8J>0P1gQhh00`3SZ6P0MhN>06n?U@0406n?U@040>>X
J01_SiD0KhnE0>>XJ080J9FI00@0J9JJ0>>XJ01XUYX0J9JJ0P1TVI`01@3SZ6P0I9VL0>>XJ03SZ6P0
I9VL0080HY^N00<0HYbN0>>XJ01RW9h00`1RW9h]0>3oo`40oooo000N0>3oo`030>>XJ03Pool0h?oo
00<0hjQX0P1OWZ000`3SZ6P0GijP05nNX00405nNX0030>>XJ01OWZ00GijP0080hjQX00<0GifO062M
W`3SZ6P01P1PWIl00`3SZ6P0HIbO066LW`0306:KWP@0hjQX0P1TVId00`3SZ6P0I9VM06JGV`0306JG
V`030>>XJ01YU9T0JIBI00<0KI2F00<0hjQX06f@UP1]T9H00P1]T9H00`3SZ6P0NXB=07Z4S@0307Z4
S@030>>XJ020OXP0P7j800<0P7j800<0hjQX081nR02DJgT0102DJgT00`3SZ6P0U6]i09A[N@0309]T
M0030>>XJ02KI7@0VfAd0080/51U0`3SZ6P30;1@I@<0/TiS00<0hjQX0<8nE`32?UL00P32?UL20<11
F@050>>XJ030@ET0`45I0>>XJ030@ET00`2iB5h0103SZ6P0aCaE0<DlE@35?5D50;U8GP030>>XJ02i
B5h0^DQN00<0ZUIY0P2`D6D00`3SZ6P0Wf1a0>>XJ00609mPL@030>>XJ02@Kg`0hjQX00D0TFik0P23
NhH0103SZ6P0Pg^608=kQP23NhH407N7SP040>>XJ01gQhh0hjQX07N7SP<0KhnE00D0hjQX06n?U@1_
SiD0KhnE0>>XJ00206RFVP040>>XJ01XUYX0J9JJ06RFVP<0I9VL00@0hjQX06BIW01TVI`0I9VL101R
W9h00`3SZ6P0HYbN06:LWP0206:LWR`0h?oo0@3oool001l0h?oo0P3SZ6P50>3oo`0305nNX03SZ6P0
GijP00@0GijP0`3SZ6P405nMW`03062MW`3SZ6P0H9fO00@0H9fO00<0hjQX06:KWP1RVih00`3SZ6P0
0`1RVih0hjQX06BIW@0406BIW@030>>XJ01TVId0JIBI0080JIBI00@0hjQX06VDV@1YU9T0JIBI0P1]
T9H00`3SZ6P0KI2F07>;T@0307>;T@030>>XJ01jQ8d0NXB=0080NXB=00<0hjQX07Z4S@20OXP00`20
OXP00`2;Lh00hjQX08]cP00409A[N@040>>XJ02DJgT0U6]i09A[N@80VfAd00D0hjQX0:YFJ@2ZEVT0
ZUIY0>>XJ0020;1@I@030>>XJ02`D6D0/51U0080/51U0P32?UL00`3SZ6P0`SiG0<8nE`030<8nE`80
`45I0P3SZ6P20<11F@@0aCaE00@0hjQX0<DlE@35?5D0aCaE0`2iB5h20>>XJ080^DQN1P2`D6D20>>X
J0H0Wf1a00<0TFik0>>XJ03SZ6P01P2AKW/20>>XJ00408=kQP22O8H0PWb6089lQP80MhN>00@0hjQX
07N7SP1gQhh0hjQX0P1gQhh206n?U@030>>XJ01]T9H0KI2F0080KI2F0P3SZ6P506RFVP0306BIW03S
Z6P0hjQX00@0I9ZM00D0HYbN0>>XJ03SZ6P0HYbN0>>XJ00306:LWR`0h?oo0@3oool00200h?oo00<0
hjQX0>3oo`3Pool0103Pool0101OWZ00hjQX05nNX01OWZ020>>XJ00305nNX01OWIl0hjQX00D0GifO
00D0H9fO0>>XJ01PWIl0H9fO066LW`040>>XJ0D0HY^N00H0hjQX06BIW@1TVId0I9VM06JGV`3SZ6P2
06JGV`<0JIBI00H0hjQX06VDV@1YU9T0JIBI07>;T@3SZ6P507>;T@030>>XJ01jQ8d0NXB=0080NXB=
00<0hjQX07Z4S@1jQ8d0102;Lh000`3SZ6P0Rg>008]cP00309A[N@040>>XJ02DJgT0U6]i09A[N@<0
ZUIY0`3SZ6P01@2ZEVT0/51U0;1@I@2`D6D0hjQX0080/51U0P30@ET20<8nE`030>>XJ032?UL0`SiG
00<0`SiG00<0`45I0>>XJ030@ET00`3==4l30<DlE@030>>XJ035?5D0aCaE0080aCaE00D0^DQN0>>X
J02iB5h0`45I0>>XJ0020<11F@D0/51U00<0hjQX0;1@I@2OH7400P2OH7440:5NL0030>>XJ02AKW/0
TFik00D0TFik00<0hjQX089lQP3SZ6P01022O8H00`1gQhh0hjQX07N7SP0207N7SP040>>XJ01gQhh0
KI2F0>>XJ0D0KI2F00<0hjQX06RFVP1XUYX0101XUYX0103SZ6P0I9ZM06BJW@3SZ6P306BJW@050>>X
J01RW9h0HYbN06:LWP3SZ6P0101QW9h[0>3oo`40oooo000Q0>3oo`030>>XJ03Pool0h?oo00@0h?oo
0`3SZ6P405nNX00305nMW`3SZ6P0GifO00@0GifO103SZ6P3066LW`030>>XJ01RVih0HY^N00<0HY^N
00<0hjQX06JGV`1VUi/00`1VUi/00`3SZ6P0IYNK06JGV`0206VDV@030>>XJ01YU9T0JIBI0080KI2F
00<0Lh^A0>>XJ01cRi400`1cRi400`3SZ6P0Lh^A07Z4S@0207Z4S@04089lQP3SZ6P0PWb6089lQP<0
Rg>000@0hjQX08]cP02;Lh00Rg>00P2DJgT00`3SZ6P0XEi`0:5NL0020:5NL0030:YFJ@3SZ6P0hjQX
00@0ZUIY0P2`D6D00`3SZ6P0`45I0<11F@030<11F@030<8nE`3SZ6P0`SiG00@0`SiG0P3SZ6P50<dd
C`80aCaE00<0hjQX0<DlE@35?5D00P35?5D01@30@ET0hjQX0<11F@30@ET0hjQX00<0`45I0`2`D6D2
0>>XJ0030;1@I@2QGW00XEi`00@0XEi`0P3SZ6P4095^N`80T6ml00@0hjQX091_O022O8H0hjQX1022
O8H0203SZ6P0MhN>07N7SP1gQhh0MHV@0>>XJ01eRI00hjQX1@1]T9H00`3SZ6P0KI2F0>>XJ00206RF
VP80IiNJ00H0hjQX06NGVP1TVYd0I9ZM0>>XJ01TVYd20>>XJ080I9ZM0`1QW9h0103SZ6P0HIbN066L
WP1QW9h[0>3oo`40oooo000R0>3oo`030>>XJ03Pool0h?oo00<0hjQX00<0h?oo05nNX03SZ6P01@1O
WZ00101OWIl0hjQX05nMW`1OWIl20>>XJ003062MW`1QW9l0hjQX00D0HIbO00@0hjQX06:KWP1RVih0
HY^N0P1TVYd00`3SZ6P0IYNK06JGV`0206JGV`040>>XJ01VUi/0IYNK06JGV`80JIBI00<0hjQX06f@
UP1]T9H00P1]T9H00`3SZ6P0Lh^A07>;T@0307>;T@030>>XJ022O8H0PWb60080PWb600@0hjQX089l
QP22O8H0PWb60P2;Lh00103SZ6P0Rg>008]cP02;Lh030:5NL0030>>XJ02QGW00hjQX0080hjQX00<0
ZUIY0>>XJ02ZEVT0102ZEVT00`30@ET0hjQX0<11F@050<11F@030>>XJ032?UL0`SiG0080d35=00<0
hjQX0=0aC@3SZ6P01P3==4l20<DlE@050>>XJ03==4l0cCA?0<ddC`3SZ6P00`30@ET00`3SZ6P0`45I
0<11F@020<11F@80/51U00@0hjQX0;9>H`3SZ6P0/TiS1@2QGW000`3SZ6P0XEi`0>>XJ005091_O005
0>>XJ02@Kg`0PWb6089lQP3SZ6P00P22O8H00`3SZ6P0PWb607F9T00407F9T0030>>XJ01eRI00MHV@
00<0KI2F00@0hjQX06f@UP1]T9H0hjQX0`1WUiX0103SZ6P0IiNJ06NGVP1WUiX206BJW@030>>XJ01T
VYd0I9ZM00<0HiZM0`1QW9h0103SZ6P0HIbN066LWP1QW9hZ0>3oo`40oooo000S0>3oo`80hjQX1@3P
ool00`3SZ6P0GijP05nNX00405nNX0<0hjQX101PWIl00`1QW9l0hjQX066LW`03066LW`030>>XJ01T
VYd0I9ZM00<0I9ZM00<0hjQX06BJW@1VUi/00`1VUi/00`3SZ6P0IYNK06JGV`0206f@UP030>>XJ01]
T9H0KI2F00<0KI2F00L0hjQX07>;T@1cRi40Lh^A07Z4S@3SZ6P0NXB=00<0PWb600<0hjQX089lQP22
O8H00P22O8H208]cP0040>>XJ02GJGL0UfUg09MYM`@0hjQX102QGW000`3SZ6P0ZUIY0:YFJ@040;U8
GP030>>XJ030@ET0`45I00@0`45I00D0hjQX0=0aC@3@<Dd0d35=0>>XJ0030=0aC@030>>XJ03==4l0
cCA?00D0cCA?00@0hjQX0<ddC`3==4l0hjQX0P3==4l20<11F@030>>XJ030@ET0`45I0080`45I00D0
/TiS0>>XJ02bCV<0/TiS0>>XJ0020;9>H`<0XEi`00D0hjQX09mPL@2OH740hjQX09mPL@03091_O008
0>>XJ02@Kg`0T6ml091_O022O8H0hjQX089lQP3SZ6P307moR0<0MHV@00<0hjQX07F9T03SZ6P00P1e
RI000`1]T9H0hjQX06f@UP0306bBU`030>>XJ01WUiX0hjQX00D0IiNJ00<0hjQX06BJW@3SZ6P0101S
VYd0101QW9h0hjQX0>>XJ03SZ6P3066LWRX0h?oo0@3oool002@0h?oo00<0hjQX0>3oo`3Pool0103P
ool00`3SZ6P0GijP05nNX0030>>XJ00305nMX01PWIl0hjQX00D0H9fO00@0hjQX066LW`1QW9l0HIbO
0P1RVih0103SZ6P0I9ZM06BJW@1TVYdE0>>XJ0<0NXB=00<0hjQX07Z4S@22O8H00P22O8H0103SZ6P0
PWb6089lQP22O8H60>>XJ00309MYM`2QGW00hjQX00D0XEi`00<0^DQN0>>XJ02iB5h0102iB5h00`3S
Z6P0`45I0<11F@020<11F@<0cCA?00<0hjQX0=0aC@3SZ6P0103@<Dd0103SZ6P0cCA?0<ddC`3==4l3
0=H/B@040<ddC`3SZ6P0cCA?0>>XJ0@0cCA?0P30@ET01@3SZ6P0`SiG0<8nE`32?UL0hjQX00<0/TiS
00H0hjQX0;9>H`2bCV<0/TiS09mPL@3SZ6P309mPL@050>>XJ02OH740Wf1a091_O03SZ6P0102@Kg`2
07moR080hjQX101oOhP207F9T0030>>XJ01eRI00hjQX0080MHV@00<0K9:G0>>XJ01/TYL0101/TYL0
0`3SZ6P0IiNJ06NGVP0306NGVP040>>XJ01SVYd0HiZM0>>XJ0@0HiZM00D0hjQX066LWP1QW9h0HIbN
0>>XJ003066LWbT0h?oo0@3oool002D0h?oo00<0hjQX0>3oo`3Pool00`3Pool30>>XJ0D0GifP00<0
hjQX062MW`1PWIl0101PWIl0103SZ6P0HY^N06:KWP1RVih50>>XJ0<0I9ZM00<0hjQX06BJW@1YU9T0
0P1YU9T01P3SZ6P0JIBI06VDV@1YU9T0KI2F0>>XJ080KI2F0P1bS9800`3SZ6P0LXbB07Z4S@0<0>>X
J00308]cP02GJGL0hjQX00D0UfUg00@0hjQX0:5NL02QGW00XEi`0`2^DVH00`3SZ6P0^DQN0;U8GP04
0;U8GP030>>XJ03==4l0cCA?00@0cCA?0P3SZ6P50=0aC@030>>XJ03F;4T0eRa900D0eRa900<0cCA?
0>>XJ03SZ6P0103==4l20<8nE`060>>XJ032?UL0`SiG0<8nE`3SZ6P0`SiG0`2bCV<01@3SZ6P0/TiS
0;1@I@2`D6D0hjQX00@0Wf1a00@0hjQX09mPL@2OH740hjQX0P2@Kg`308abO`0307moR03SZ6P0Ogn8
00D0Ogn800L0hjQX07F9T01eRI00LX^B0>>XJ01bRi80hjQX00D0K9:G00<0hjQX06bBU`3SZ6P00P1W
UiX0101UV9/0hjQX06FHV`1UV9/206>JW@050>>XJ01SVYd0hjQX0>>XJ01SVYd00`1QW9l0103SZ6P0
HIbO066LW`1QW9lY0>3oo`40oooo000V0>3oo`030>>XJ03Pool0h?oo0080hjQX0P3Pool00`3SZ6P0
GifP05nMX00405nMX0030>>XJ01PWIl0H9fO0080HIbO1@3SZ6P306:KWP060>>XJ01TVYd0I9ZM06BJ
W@1UV9/0hjQX0P1UV9/206VDV@030>>XJ01YU9T0JIBI0080JIBI00<0LXbB0>>XJ01bS9800`1bS980
0`3SZ6P0LXbB07Z4S@0207Z4S@060>>XJ01jQ8d0NXB=07Z4S@2;Lh00hjQX1@2;Lh000`3SZ6P0UfUg
09MYM`0409MYM`030>>XJ02^DVH0[U9V00<0[U9V00<0hjQX0;U8GP2iB5h00P2iB5h20<DlE@030>>X
J035?5D0cCA?00@0cCA?00<0hjQX0<ddC`3@<Dd00P3@<Dd20=TYA`030>>XJ03I:DL0eRa900H0eRa9
00<0hjQX0<ddC`3==4l0103@<Dd01@32?UL0hjQX0<8nE`32?UL0hjQX00<0`SiG0P2bCV<01@3SZ6P0
/51U0;1@I@3SZ6P0/51U00@0Wf1a00<0hjQX09mPL@3SZ6P01P2<LWl20>>XJ0D0Ogn800<0hjQX07:;
TP1bRi800`1bRi800`3SZ6P0LX^B06bBU`0306bBU`070>>XJ01/TYL0K9:G06FHV`3SZ6P0IIRK0>>X
J00406FHV`80HiZM00<0hjQX06:KWP1RVih00P1RVih3066LW`040>>XJ01QW9l0HIbO066LWbP0h?oo
0@3oool002L0h?oo0P3SZ6P50>3oo`030>>XJ01OWJ00GifP00<0GifP1@3SZ6P3066LW`030>>XJ01R
Vih0HY^N0080HY^N00<0hjQX06FHV`1UV9/00`1UV9/00`3SZ6P0IIRK06FHV`0206VDV@030>>XJ01Y
U9T0K96G0080K96G00<0hjQX07:<TP1bS9800P1bS9800`3SZ6P0LXbB07:<TP0307Z4S@050>>XJ020
OXP0P7j8081nR03SZ6P01P2;Lh000`3SZ6P0UfUg09MYM`030:5NL0030>>XJ02^DVH0[U9V00<0[U9V
00<0hjQX0:iBIP35?5D01035?5D00`3SZ6P0aCaE0<DlE@030<ddC`80hjQX00<0cCA?0=TYA`3I:DL0
0`3I:DL00`3SZ6P0fBU70=TYA`050=H/B@80hjQX1`3@<Dd00`3SZ6P0`SiG0>>XJ0040<8nE`80/51U
00<0hjQX0;1@I@3SZ6P00`2`D6D309mPL@0409]TM03SZ6P0hjQX09]TM0D0S79o00<0hjQX08abO`3S
Z6P00P1oOhP207b2R`030>>XJ01lPX/0LX^B0080LX^B0P3SZ6P207:;TP80K9:G00<0hjQX06VDV01Y
U9P00P1YU9P00`1UV9/0hjQX06FHV`0406FHV`80hjQX00<0HY^N0>>XJ01RVih00`1RVih20>>XJ004
066LW`3SZ6P0HIbO066LWbP0h?oo0@3oool002P0h?oo00<0hjQX0>3oo`3Pool0103Pool00`3SZ6P0
GifP05nMX0020>>XJ003062MW`1QW9l0hjQX00D0HIbO00@0hjQX06:KWP1RVih0HY^N0P1SVYd00`3S
Z6P0HiZM06FHV`0306FHV`050>>XJ01UV9/0IIRK06bAU`3SZ6P0101/TIL00`3SZ6P0LXbB07:<TP02
07:<TP030>>XJ01bS980LXbB00<0P7j800<0hjQX081nR020OXP00P20OXP00`3SZ6P0Rg>008]cP003
08]cP0030>>XJ02QGW00XEi`00<0XEi`00<0hjQX0:5NL02^DVH00`2^DVH00`3SZ6P0^DQN0;U8GP04
0<DlE@080>>XJ035?5D0aCaE0<DlE@3==4l0hjQX0<ddC`3SZ6P20=H/B@D0fBU700<0hjQX0=TYA`3I
:DL00`3F;4T00`3SZ6P0fBU70>>XJ0080=0aC@80hjQX00<0`SiG0<11F@30@ET00P30@ET20;1@I@80
hjQX0`2`D6D409]TM0030>>XJ02KI7@0VfAd00@0S79o00@0hjQX08abO`2<LWl0hjQX0`1lPX/00`3S
Z6P0O8:;07b2R`0307:;TP060>>XJ01bRi80hjQX07:;TP1YU9P0hjQX1@1YU9P0103SZ6P0IIRK0>>X
J01UV9/206BIW0050>>XJ01TVI`0HY^N06:KWP3SZ6P00P1RVih20>>XJ00506:KWP1QW9l0HIbO066L
W`3SZ6P00P1PWIlW0>3oo`40oooo000Y0>3oo`030>>XJ03Pool0h?oo00<0h?oo0`3SZ6P4062MW`03
066LW`3SZ6P0HIbO00@0HIbO00<0hjQX06>JW@1SVYd00P1SVYd00`3SZ6P0HiZM06>JW@0306FHV`06
0>>XJ01WUYX0IiJJ06NFVP1/TIL0hjQX101/TIL01@3SZ6P0LXbB07:<TP1bS980hjQX00<0MhN>0P20
OXP00`3SZ6P0P7j8081nR002081nR0040>>XJ02;Lh00Rg>008]cP080U6]i00<0hjQX0:5NL02QGW00
0`2QGW000`3SZ6P0XEi`0:5NL0040;U8GP030>>XJ02iB5h0^DQN00@0aCaE00@0hjQX0<DlE@3SZ6P0
hjQX0`3F;4T00`3SZ6P0eRa90=H/B@040=TYA`030>>XJ03I:DL0fBU70080fBU700D0hjQX0=TYA`3I
:DL0fBU70>>XJ0070=0aC@030>>XJ030@ET0`45I00D0`45I00<0/51U0>>XJ02`D6D0102ZEVT309]T
M0040>>XJ02KI7@0VfAd09]TM0<0S79o00L0hjQX08MhP`27N8<0QgR30>>XJ01lPX/0hjQX00@0O8:;
00L0LX^B0>>XJ01bRi80KhjD0>>XJ01_SY@0hjQX00D0JIBH00D0hjQX06VDV01TVI`0hjQX06BIW002
0>>XJ0<0I9VL0P1RVih20>>XJ0<0HY^N101PWIl00`3SZ6P0H9fO062MW`0V0>3oo`40oooo000Z0>3o
o`030>>XJ03Pool0h?oo0080hjQX00<0h?oo062MW`3SZ6P01@1PWIl0101QW9l0hjQX066LW`1QW9l2
066LWP040>>XJ01QW9h0HiZM06>JW@/0hjQX00<0IiJJ0>>XJ01/TIL00`1/TIL00`3SZ6P0K96G07N7
SP0207N7SP060>>XJ01gQhh0MhN>07N7SP20OXP0hjQX1020OXP00`3SZ6P0U6]i09A[N@0309A[N@03
0>>XJ02DJgT0XEi`00<0XEi`00@0hjQX0:YFJ@2ZEVT0ZUIY0`2iB5h0103SZ6P0^DQN0;U8GP2iB5h3
0<DlE@80hjQX0P3==4l30=H/B@040>>XJ03F;4T0eRa90=H/B@<0fBU700D0hjQX0=`VA@3L9TD0g2I5
0>>XJ0040=TYA`030>>XJ03I:DL0d35=0080d35=0P3==4l20>>XJ0L0`45I0P3SZ6P60:YFJ@0409]T
M03SZ6P0VfAd0>>XJ080VfAd0P27N8<00`3SZ6P0QgR308MhP`0208MhP`030>>XJ01lPX/0hjQX00@0
O8:;00<0KhjD0>>XJ01_SY@00P1_SY@00`3SZ6P0KhjD06n>U00306VDV0060>>XJ01WUYX0IiJJ06NF
VP1TVI`0hjQX1P1TVI`00`3SZ6P0HY^N0>>XJ004066LWP04062MW`3SZ6P0hjQX0>>XJ0<0H9fO9@3P
ool10?ooo`00:`3Pool20>>XJ0@0h?oo00<0H9fO0>>XJ01PWIl0101PWIl90>>XJ0<0HiZM00<0hjQX
06BIW01TVI`00P1WUYX00`3SZ6P0IiJJ06NFVP050>>XJ00406bAU`1_SY@0hjQX06n>U080MhN>00<0
hjQX07N7SP1gQhh00P1gQhh01`20OXP0hjQX081nR020OXP0QgR30>>XJ027N8<0102DJgT00`3SZ6P0
U6]i09A[N@020:5NL080ZUIY00@0hjQX0:YFJ@2ZEVT0ZUIY0P2iB5h0103SZ6P0^DQN0;U8GP2iB5h3
0<ddC`030>>XJ03==4l0cCA?0080cCA?0P3F;4T0103SZ6P0eRa90=H/B@3F;4T30=`VA@050>>XJ03L
9TD0g2I50=`VA@3SZ6P0103I:DL00`3SZ6P0fBU70<ddC`040<ddC`80hjQX00<0cCA?0<11F@30@ET0
0P30@ET20;U8GP030>>XJ02ZEVT0hjQX00H0ZUIY00<0hjQX09]TM03SZ6P00`2DJgT00`3SZ6P0QgR3
08MhP`0408MhP`040>>XJ01lPX/0O8:;07b2R`80MhN>00L0hjQX06n>U01_SY@0KhjD0>>XJ01_SY@0
hjQX0080KhjD0P1WUYX01`3SZ6P0IiJJ06NFVP1WUYX0hjQX06BIW03SZ6P00`1TVI`20>>XJ0<0HIbN
00<0hjQX066LWP1QW9h00P3SZ6P3062MW`030>>XJ01PWIl0H9fO02D0h?oo0@3oool002`0h?oo00<0
hjQX0>3oo`3Pool00`3Pool0101PWIl0hjQX062MW`1PWIl20>>XJ080H9fO00<0hjQX066LWP1QW9h0
0P1QW9h00`3SZ6P0HIbN06BIW00206BIW0040>>XJ01TVI`0I9VL06BIW080IiJJ00D0hjQX06NFVP1W
UYX0IiJJ0>>XJ00206n>U0@0hjQX00<0KhjD07N7SP3SZ6P01@1gQhh00`3SZ6P0QgR308MhP`0208Mh
P`030>>XJ027N8<0U6]i00<0U6]i00<0hjQX09A[N@2ZEVT00`2ZEVT00`3SZ6P0ZUIY0:YFJ@020:YF
J@030;U8GP3SZ6P0^DQN00<0`45I0`3SZ6P50<ddC`030=H/B@3SZ6P0eRa900<0fBU70`3L9TD00`3S
Z6P0g2I50>>XJ0020=`VA@<0fBU700<0hjQX0=H/B@3F;4T00`3==4l01@3SZ6P0cCA?0<ddC`3SZ6P0
cCA?00@0^DQN00@0hjQX0;U8GP2iB5h0hjQX1@2ZEVT01@3SZ6P0U6]i09A[N@2DJgT0hjQX0080U6]i
00<0hjQX08MhP`27N8<01027N8<20>>XJ0<0MhN>00<0hjQX07N7SP1gQhh00P1_SY@00`3SZ6P0KhjD
0>>XJ00306bAU`030>>XJ01WUYX0IiJJ0080IiJJ00H0hjQX06NFVP1TVI`0hjQX06BIW03SZ6P306>J
W@<0HIbN0P3SZ6P2066LWP<0H9fO00@0hjQX062MW`1PWIl0H9fO903Pool10?ooo`00;@3Pool20>>X
J0<0h?oo103SZ6P4062MW`030>>XJ01QW9h0HIbN0080HIbN00<0HY^N0>>XJ01RVih00`1TVI`01`3S
Z6P0I9VL06BIW01TVI`0IiJJ0>>XJ01WUYX00`1YU9P01P3SZ6P0KhjD06n>U01_SY@0hjQX06n>U080
hjQX00<0MhN>0>>XJ01gQhh00`1lPX/00`3SZ6P0QgR308MhP`0208MhP`030>>XJ027N8<0QgR300<0
U6]i00@0hjQX09]TM02KI7@0VfAd0P2ZEVT00`3SZ6P0ZUIY0:YFJ@020:YFJ@80`45I00L0hjQX0<11
F@30@ET0hjQX0<11F@3==4l0hjQX00D0cCA?00<0fBU70>>XJ03I:DL0103I:DL20=`VA@80hjQX0`3L
9TD40=H/B@030>>XJ03F;4T0eRa90080cCA?00@0hjQX0<ddC`35?5D0hjQX0P35?5D30;U8GP050>>X
J02iB5h0^DQN0;U8GP3SZ6P00P2ZEVT20:5NL0070>>XJ02QGW00U6]i09A[N@3SZ6P0U6]i0>>XJ002
09A[N@<0QgR300@0P7j80>>XJ020OXP0hjQX0`1gQhh01@3SZ6P0MhN>07N7SP1gQhh0hjQX00<0K96G
00<0hjQX06bAU`3SZ6P0101WUYX00`3SZ6P0IiJJ06NFVP0206>JW@030>>XJ01SVYd0HiZM0080HiZM
00@0HIbN0>>XJ03SZ6P0hjQX0`1QW9h4062MW`040>>XJ01PWIl0H9fO062MWb<0h?oo0@3oool002l0
h?oo0`3SZ6P20>3oo`03062MW`3SZ6P0H9fO00@0H9fO00<0hjQX06:KWP1RVih00`1RVih00`3SZ6P0
HY^N06BIW00206BIW0030>>XJ01TVI`0I9VL0080JIBH00H0hjQX06VDV01YU9P0JIBH0>>XJ01YU9P3
06n>U0030>>XJ01_SY@0KhjD00<0hjQX0`1lPX/00`3SZ6P0O8:;08MhP`0208MhP`030>>XJ027N8<0
QgR300<0VfAd00<0hjQX09]TM02KI7@00P2KI7@0102ZEVT0hjQX0:YFJ@2ZEVT30;1@I@040<11F@3S
Z6P0hjQX0>>XJ0<0`45I00@0cCA?0>>XJ03==4l0cCA?0`3@<Dd00`3I:DL0hjQX0=TYA`040=TYA`03
0=`VA@3SZ6P0g2I500@0fBU70`3F;4T01@3SZ6P0eRa90=H/B@3F;4T0hjQX00<0aCaE00H0hjQX0<Dl
E@35?5D0aCaE0;U8GP3SZ6P40;U8GP050>>XJ02QGW00XEi`0:5NL03SZ6P00P2QGW0309A[N@80hjQX
0P2DJgT4081nR0070>>XJ020OXP0P7j80>>XJ01gQhh0hjQX07N7SP0307:<TP030>>XJ01/TIL0K96G
0080K96G00<0hjQX06bAU`1/TIL00P1WUYX00`3SZ6P0IIRK06FHV`0206FHV`030>>XJ01SVYd0hjQX
00<0HiZM00D0hjQX066LWP1QW9h0HIbN0>>XJ003066LW`05062MW`3SZ6P0hjQX062MW`3SZ6P00P1P
WIlS0>3oo`40oooo000`0>3oo`030>>XJ03Pool0h?oo0080h?oo00@0hjQX062MW`1PWIl0H9fO0P1Q
W9l00`3SZ6P0HIbO06:KWP0206:KWPD0hjQX00<0I9VL0>>XJ01UV9/00P1UV9/00`1YU9P0hjQX06VD
V00206VDV0030>>XJ01YU9P0JIBH0080KhjD00H0hjQX07:;TP1bRi80LX^B0>>XJ01lPX/30>>XJ003
07b2R`3SZ6P0O8:;0080QgR300@0hjQX08abO`2<LWl0S79o0P2KI7@00`3SZ6P0VfAd09]TM00309]T
M0030;1@I@3SZ6P0/51U00<0/51U0P3SZ6P60<11F@030>>XJ03@<Dd0d35=00@0d35=00<0hjQX0=TY
A`3I:DL00`3I:DL20>>XJ0H0fBU70P3F;4T01@3SZ6P0eRa90<ddC`3SZ6P0cCA?00<0aCaE00<0hjQX
0<DlE@35?5D00P35?5D00`3SZ6P0^DQN0;U8GP020:iBIP050>>XJ02QGW00XEi`0:5NL03SZ6P00`2Q
GW0209A[N@030>>XJ02;Lh00Rg>00080Rg>00P20OXP01`3SZ6P0P7j8081nR020OXP0hjQX07:<TP3S
Z6P00`1bS9800`3SZ6P0LXbB07:<TP0206bAU`060>>XJ01/TIL0hjQX06bAU`1UV9/0hjQX101UV9/0
1@3SZ6P0HiZM06>JW@3SZ6P0HiZM0080hjQX00D0HiZM066LW`1QW9l0HIbO0>>XJ002066LW`80hjQX
0`1PWIl0103SZ6P0GifP05nMX01OWJ0R0>3oo`40oooo000`0>3oo`030>>XJ03Pool0h?oo00<0h?oo
00@0hjQX066LW`1QW9l0HIbO1P3SZ6P206:KWP030>>XJ01RVih0IIRK00D0hjQX00<0IIRK06VDV03S
Z6P00`1YU9P01@3SZ6P0JIBH07:;TP1bRi80hjQX00@0LX^B00@0hjQX07b2R`1lPX/0O8:;103SZ6P2
08abO`040>>XJ02<LWl0S79o08abO`80VfAd00<0hjQX09]TM02OH7400`2OH7400`3SZ6P0/51U0>>X
J0020>>XJ0030;1@I@3SZ6P0`45I0080`45I0`32?UL00`3SZ6P0d35=0=0aC@040=0aC@090>>XJ03I
:DL0fBU70=TYA`3F;4T0hjQX0=H/B@3I:DL0hjQX00H0fBU700D0cCA?0>>XJ03==4l0cCA?0>>XJ002
0<ddC`<0aCaE00@0hjQX0<DlE@35?5D0hjQX1P2^DVH00`3SZ6P0XEi`0>>XJ0040:5NL080Rg>00P3S
Z6P408]cP004081nR03SZ6P0P7j8081nR080NXB=00<0hjQX07:<TP1bS9800P1bS9801@3SZ6P0LXbB
07:<TP1bS980hjQX0080K96G00@0JIBI0>>XJ01YU9T0hjQX0`1UV9/00`3SZ6P0IIRK06FHV`0206>J
W@030>>XJ01RVih0HY^N0080HY^N0`1QW9l20>>XJ080HIbO101OWJ000`3SZ6P0GifP05nMX00R0>3o
o`40oooo000a0>3oo`040>>XJ03Pool0h?oo0>3oo`D0hjQX0`1QW9l00`3SZ6P0HIbO06:KWP0206:K
WP0306>JW@3SZ6P0HiZM0080IIRK00<0hjQX06FHV`1UV9/0103SZ6P206VDV0050>>XJ01/TYL0K9:G
07:;TP3SZ6P0101bRi800`3SZ6P0LX^B07moR00207moR0030>>XJ01oOhP0Ogn800D0hjQX0P2<LWl0
0`2OH740hjQX09mPL@0209mPL@@0hjQX102`D6D00`3SZ6P0`SiG0<8nE`040<8nE`030>>XJ032?UL0
d35=00@0d35=00D0hjQX0=H/B@3F;4T0eRa90>>XJ0030=H/B@040>>XJ03I:DL0fBU70=TYA`@0d35=
00<0cCA?0>>XJ03SZ6P0103==4l20<DlE@050>>XJ02iB5h0^DQN0>>XJ02iB5h01@2^DVH00`3SZ6P0
[U9V0>>XJ0020:5NL0<0UfUg00<0hjQX08]cP03SZ6P0102;Lh000`3SZ6P0NXB=07Z4S@0307Z4S@80
hjQX0P1bS9800`3SZ6P0LXbB07:<TP0207:<TP030>>XJ01YU9T0JIBI0080JIBI00D0hjQX06VDV@1U
V9/0IIRK0>>XJ00306FHV`0406:KWP3SZ6P0HY^N0>>XJ0@0HY^N0P3SZ6P00`1QW9l0hjQX062MW`02
062MW`0505nMX03SZ6P0hjQX05nMX03SZ6P00P1OWJ0Q0>3oo`40oooo000b0>3oo`<0hjQX0`3Pool0
0`3SZ6P0HIbO066LW`03066LW`030>>XJ01SVYd0HiZM0080HiZM00<0hjQX06>JW@1SVYd00P1UV9/0
1P3SZ6P0IIRK06FHV`1UV9/0hjQX06bBU`80hjQX00H0K9:G0>>XJ01/TYL0K9:G07:;TP3SZ6P207:;
TP0407F9T03SZ6P0MHV@07F9T080Ogn800H0hjQX07moR01oOhP0Ogn808abO`3SZ6P208abO`L0hjQX
0P2OH7400`3SZ6P0Wf1a0;1@I@020;1@I@80/TiS00<0hjQX0<8nE`32?UL00`32?UL00`3SZ6P0`SiG
0<8nE`030=0aC@030<ddC`3SZ6P0cCA?0080eRa900D0hjQX0=H/B@3F;4T0eRa90>>XJ0080=0aC@80
hjQX103==4l20;U8GP030>>XJ02iB5h0hjQX0080^DQN1P2^DVH00`3SZ6P0UfUg09MYM`0409MYM`05
0>>XJ02;Lh00Rg>00>>XJ02;Lh000P22O8H00`3SZ6P0PWb607Z4S@0207Z4S@070>>XJ01jQ8d0NXB=
0>>XJ01bS980hjQX07:<TP0206f@UP030>>XJ01]T9H0JIBI0080JIBI00D0hjQX06VDV@3SZ6P0JIBI
0>>XJ00206FHV`80I9ZM00@0hjQX06:KWP1RVih0hjQX0P1RVih20>>XJ0@0H9fO00@0hjQX062MW`3S
Z6P0hjQX0`1OWJ000`3SZ6P0GifP05nMX00Q0>3oo`40oooo000c0>3oo`030>>XJ03Pool0h?oo00<0
h?oo00@0hjQX066LW`1QW9l0HIbO0P1QW9h00`3SZ6P0HiZM06>JW@0206>JW@050>>XJ01SVYd0HiZM
06FHV`3SZ6P00P1UV9/206NGVP030>>XJ01/TYL0K9:G0080hjQX0`1/TYL01@3SZ6P0MHV@07F9T01e
RI00hjQX00<0MHV@0P1oOhP01@3SZ6P0Ogn807moR01oOhP0hjQX00D0T6ml00<0hjQX09mPL@2OH740
0`2OH7400`3SZ6P0Wf1a0;9>H`040;9>H`030>>XJ02bCV<0`SiG00<0`SiG00<0hjQX0<8nE`32?UL0
1@3==4l00`3SZ6P0cCA?0>>XJ0030=H/B@030<ddC`3SZ6P0cCA?00L0d35=00@0hjQX0<ddC`3==4l0
cCA?0`30@ET0102iB5h0hjQX0;U8GP3SZ6P30;U8GP<0[U9V0P2QGW000`3SZ6P0XEi`09MYM`0309MY
M`050>>XJ02GJGL0UfUg089lQP3SZ6P00P22O8H00`3SZ6P0PWb6089lQP0307Z4S@050>>XJ01jQ8d0
NXB=07Z4S@3SZ6P00`1]T9H00`3SZ6P0KI2F06f@UP0206VDV@050>>XJ01YU9T0JIBI06VDV@3SZ6P0
0`1TVYd20>>XJ080I9ZM0P1RVih20>>XJ0<0HIbO101PWIl0103SZ6P0H9fO062MW`1PWIl305nMX003
0>>XJ01OWZ00GijP0200h?oo0@3oool003@0h?oo00<0hjQX0>3oo`3Pool00`3Pool0103SZ6P0HIbN
066LWP1QW9h50>>XJ00306>JW@3SZ6P0HiZM0080HiZM00<0IiNJ0>>XJ01WUiX00P1WUiX0103SZ6P0
IiNJ06bBU`1/TYL30>>XJ00306f@UP3SZ6P0MHV@00<0MHV@00L0hjQX07F9T01eRI00MHV@07moR03S
Z6P0Ogn800<0PWb600<0hjQX091_O02@Kg`00P2@Kg`00`3SZ6P0T6ml09mPL@0309mPL@030:5NL03S
Z6P0XEi`00@0/TiS00<0hjQX0;9>H`2bCV<01030@ET00`3SZ6P0`45I0<11F@040<ddC`80hjQX1P3=
=4l00`3SZ6P0cCA?0=0aC@040=0aC@80hjQX1`30@ET00`2iB5h0hjQX0;U8GP030;U8GPD0XEi`00<0
hjQX0:5NL02QGW000`2GJGL0203SZ6P0Rg>008]cP02;Lh00PWb60>>XJ022O8H0hjQX0`22O8H00`1j
Q8d0hjQX07Z4S@0207>;T@050>>XJ01cRi40hjQX06f@UP3SZ6P0101]T9H02@3SZ6P0JIBI06VDV@1V
Ui/0hjQX06JGV`3SZ6P0I9ZM0>>XJ00506BJW@030>>XJ01QW9l0hjQX00@0HIbO00D0H9fO0>>XJ03S
Z6P0H9fO0>>XJ002062MW`<0GijP0P3SZ6P205nNX1l0h?oo0@3oool003D0h?oo00@0hjQX0>3oo`3P
ool0h?oo1@3SZ6P3066LWP030>>XJ01SVYd0hjQX00@0hjQX00<0I9ZM0>>XJ01WUiX00`1WUiX01P3S
Z6P0IiNJ06f@UP1]T9H0hjQX06f@UP<0hjQX0`1eRI001P3SZ6P0MHV@07F9T01eRI00PWb60>>XJ0@0
PWb600<0hjQX091_O02@Kg`00`2@Kg`00`3SZ6P0T6ml0:5NL0030:5NL0030>>XJ02QGW00XEi`00<0
/TiS00@0hjQX0;1@I@2`D6D0/51U0`30@ET0103SZ6P0`45I0<11F@30@ET30<ddC`040>>XJ035?5D0
aCaE0<DlE@@0cCA?00<0hjQX0<ddC`3==4l00`3@<Dd01032?UL0hjQX0>>XJ032?UL70<11F@030>>X
J02iB5h0^DQN00<0ZUIY0`2QGW000`3SZ6P0XEi`0>>XJ0020:5NL080Rg>000<0hjQX08]cP02;Lh00
0P2;Lh020>>XJ0@0PWb600<0Lh^A0>>XJ01cRi400P1cRi401@3SZ6P0Lh^A0>>XJ01]T9H0hjQX00@0
KI2F00D0hjQX06JGV`1VUi/0IYNK0>>XJ00206JGV`050>>XJ01TVYd0I9ZM06BJW@1RVih00P3SZ6P0
101RVih0HIbO066LW`3SZ6P2066LW`80hjQX0`1PWIl00`3SZ6P0GifO05nMW`030>>XJ080GijP00<0
hjQX05nNX01OWZ007P3Pool10?ooo`00=P3Pool30>>XJ0<0h?oo00<0hjQX066LWP1QW9h00P1QW9h0
0`3SZ6P0HIbN06BJW@0206BJW@030>>XJ01TVYd0hjQX00<0hjQX0P1WUiX01@3SZ6P0J9JJ06RFVP1]
T9H0hjQX00<0KI2F00H0hjQX06f@UP1eRI00MHV@0>>XJ01eRI0307N7SP030>>XJ022O8H0PWb60080
PWb600<0hjQX089lQP2@Kg`00P2@Kg`0102AKW/0hjQX095^N`2AKW/30:5NL0040>>XJ02QGW00XEi`
0:5NL080/51U00<0hjQX0;1@I@2`D6D00P2`D6D20<11F@030>>XJ030@ET0`45I0080`45I00<0aCaE
0>>XJ03SZ6P01035?5D30<ddC`030>>XJ03==4l0cCA?00<0`SiG00D0hjQX0<8nE`32?UL0hjQX0<8n
E`050<11F@80hjQX1P2ZEVT20:5NL0030>>XJ02QGW00hjQX00<0U6]i00<0hjQX08]cP02;Lh00102;
Lh000`3SZ6P0PWb6089lQP0207Z4S@050>>XJ01cRi40Lh^A07>;T@3SZ6P00`1cRi400`3SZ6P0KI2F
06f@UP0206VDV@050>>XJ01YU9T0IYNK06JGV`3SZ6P00P1VUi/01P3SZ6P0IYNK0>>XJ03SZ6P0HY^N
0>>XJ0<0HY^N0`1QW9l20>>XJ080HIbO101OWIl20>>XJ00305nMW`1OWZ00GijP0080GijP00<0hjQX
05nNX01OWZ007P3Pool10?ooo`00=`3Pool00`3SZ6P0h?oo0>3oo`020>3oo`040>>XJ01QW9h0HIbN
066LWP80HYbN00D0hjQX06:LWP1TVYd0I9ZM0>>XJ00306BJW@060>>XJ01XUYX0hjQX0>>XJ01XUYX0
hjQX0P1XUYX0103SZ6P0KI2F06f@UP1]T9H30>>XJ00307N7SP3SZ6P0MhN>00@0MhN>00H0hjQX089l
QP22O8H0PWb60>>XJ022O8H4095^N`040>>XJ02AKW/0TFik095^N`80XEi`00<0hjQX0:5NL02OH740
0P2OH7400`2`D6D0hjQX0;1@I@040;1@I@030<11F@3SZ6P0`45I00<0^DQN00<0hjQX0<DlE@3SZ6P0
1@35?5D20<ddC`040>>XJ030@ET0`45I0<11F@80`SiG00D0hjQX0<8nE`32?UL0hjQX0<8nE`050;1@
I@030>>XJ02`D6D0hjQX00H0ZUIY00@0hjQX09A[N@2DJgT0hjQX0`2DJgT00`3SZ6P0Rg>008]cP004
08]cP080hjQX0`1jQ8d01@3SZ6P0NXB=07>;T@1cRi40hjQX00<0Lh^A0`3SZ6P00`1YU9T0hjQX06VD
V@0206VDV@040>>XJ01VUi/0IYNK0>>XJ0<0I9VM00<0HY^N0>>XJ01RVih0101RVih20>>XJ003066L
W`3SZ6P0H9fO0080H9fO00@0GifO0>>XJ03SZ6P0hjQX0`1OWIl405nNX0030>>XJ01OWZ00GijP01d0
h?oo0@3oool003L0h?oo00<0hjQX0>3oo`3Pool00`3Pool00`3SZ6P0HYbN06:LWP0206:LWP030>>X
J01RW9h0HYbN0080I9ZM00D0hjQX06BJW@1TVI`0I9VL0>>XJ00206RFVP80hjQX0`1XUYX01P3SZ6P0
KI2F06f@UP1]T9H0hjQX06n?U@<0hjQX101gQhh01@3SZ6P0PWb6089lQP22O8H0hjQX0080Pg^60`2A
KW/00`3SZ6P0TFik095^N`02095^N`0309mPL@3SZ6P0Wf1a00@0Wf1a00<0/51U0>>XJ02`D6D00`2`
D6D00`2iB5h0hjQX0;U8GP020;U8GP050>>XJ02iB5h0aCaE0<DlE@3SZ6P01035?5D30<11F@050>>X
J030@ET0`45I0<11F@3SZ6P00`32?UL00`3SZ6P0/TiS0;9>H`030;1@I@040>>XJ02`D6D0/51U0>>X
J0@0ZUIY0P2KI7@01@3SZ6P0U6]i09A[N@2DJgT0hjQX0080U6]i00@0hjQX08]cP02;Lh00Rg>00P20
OXP00`3SZ6P0P7j80>>XJ00207Z4S@050>>XJ01jQ8d0NXB=07Z4S@3SZ6P00`1]T9H01@3SZ6P0KI2F
06VDV@1YU9T0hjQX00<0JIBI00@0hjQX06BIW@1TVId0hjQX101TVId00`3SZ6P0HY^N0>>XJ00206:K
WP80hjQX0`1PWIl00`3SZ6P0H9fO062MW`020>>XJ0<0GifO00<0hjQX05nMW`1OWIl00P1OWZ030>>X
J0<0GijP703Pool10?ooo`00>03Pool0103SZ6P0h?oo0>3oo`3Pool:0>>XJ00306BIW03SZ6P0I9VL
0080I9VL00@0hjQX06BIW01XUYX0J9JJ0P3SZ6P206RFVP050>>XJ01_SiD0KhnE06n?U@3SZ6P00`1_
SiD00`3SZ6P0MhN>07N7SP0207N7SP030>>XJ023NhH0Pg^60080Pg^600<0hjQX08=kQP23NhH00P2A
KW/00`3SZ6P0TFik091_O003091_O0030>>XJ02OH740Wf1a00@0Wf1a00<0hjQX0;1@I@2`D6D00`2Z
EVT0102iB5h0hjQX0;U8GP3SZ6P30;U8GP030<DlE@3SZ6P0aCaE00@0^DQN0P30@ET01@3SZ6P0`45I
0<11F@3SZ6P0`45I00<0/TiS00@0hjQX0;9>H`2bCV<0/TiS0P2`D6D01@3SZ6P0/51U0;1@I@3SZ6P0
/51U00@0VfAd00<0hjQX09]TM02KI7@00P2DJgT0103SZ6P0U6]i0>>XJ02DJgT5081nR0060>>XJ020
OXP0P7j80>>XJ01jQ8d0hjQX0`1bS9801@3SZ6P0KI2F06f@UP1]T9H0hjQX0080KI2F00T0JIBI0>>X
J03SZ6P0hjQX06JGV`3SZ6P0IYNK06BIW@3SZ6P00`1TVId0103SZ6P0I9VM06BIW@1RVih20>>XJ0<0
HIbO0`1PWIl20>>XJ080H9fO0`1OWZ000`3SZ6P0GijP05nNX0020>>XJ0<0GijP00<0hjQX05nNX01O
WZ00703Pool10?ooo`00>@3Pool30>>XJ0<0h?oo00<0hjQX06:LWP1RW9h00P1RW9h00`3SZ6P0HY^N
0>>XJ0030>>XJ080I9VL00@0hjQX06BIW01XUYX0J9JJ103SZ6P0101XUIT0KhnE06n?U@3SZ6P306n?
U@<0hjQX00@0MhN>07R6SP3SZ6P0N8J>0`23NhH01P3SZ6P0Pg^608=kQP23NhH0T6ml0>>XJ0H0T6ml
00<0hjQX09mPL@2OH7400`2OH7400`3SZ6P0ZUIY0:YFJ@040:YFJ@80hjQX1@2iB5h00`3SZ6P0^DQN
0;U8GP040;U8GP050<11F@3SZ6P0`45I0<11F@3SZ6P00P2`D6D20;9>H`030>>XJ02bCV<0/TiS0080
/TiS00<0hjQX0;1@I@2`D6D00P2OH7400`3SZ6P0Wf1a09]TM00209]TM0080>>XJ02KI7@0VfAd09]T
M02DJgT0hjQX09A[N@3SZ6P208MhP`<0P7j800@0hjQX081nR020OXP0P7j80P3SZ6P307:<TP050>>X
J01bS980KI2F06f@UP3SZ6P00`1]T9H01@3SZ6P0IYNK06JGV`1VUi/0hjQX0080IYNK00<0hjQX06BI
W@1TVId00P3SZ6P306BIW@030>>XJ01QW9l0hjQX00@0HIbO0P3SZ6P00`1PWIl0hjQX05nMW`0205nM
W`80GijP0`3SZ6P505nNX0040>>XJ01OWZ00GijP05nNX1/0h?oo0@3oool003X0h?oo00<0hjQX0>3o
o`3Pool00`3Pool00`3SZ6P0HY^N06:KWP0206:KWP040>>XJ01RVih0HY^N06BIW0@0hjQX00@0I9VL
06REV@1XUIT0hjQX0P1XUIT20>>XJ00306REV@1_SiD0hjQX00<0KhnE00@0hjQX07R6SP1hQXh0hjQX
0P1hQXh01P3SZ6P0N8J>08=kQP23NhH0hjQX08=kQP<0PWb600<0T6ml0>>XJ02@Kg`0102@Kg`0103S
Z6P0Wf1a09mPL@2OH74209]TM0030>>XJ02ZEVT0ZUIY00@0ZUIY00@0hjQX0;U8GP2iB5h0^DQN0`2^
DVH00`3SZ6P0^DQN0;U8GP050;U8GP030>>XJ02`D6D0hjQX00@0/51U0P2bCV<01@3SZ6P0/TiS0;9>
H`2bCV<0hjQX00@0Wf1a00<0hjQX09mPL@2KI7@00P2KI7@0103SZ6P0VfAd09]TM02KI7@208MhP`03
0>>XJ027N8<0QgR30080QgR30P20OXP00`3SZ6P0P7j807N7SP0207N7SP050>>XJ01bS980LXbB07:<
TP3SZ6P00P1bS9800`1]T9H0hjQX06f@UP0206VDV@050>>XJ01YU9T0IYNK0>>XJ01VUi/00P3SZ6P2
06JGV`030>>XJ01TVId0I9VM0080HY^N00@0hjQX06:KWP1QW9l0hjQX0P1QW9l20>>XJ0<0GifO00<0
hjQX05nMW`1OWIl00`3SZ6P205nNX0030>>XJ01OWZ00GijP00<0GijP0P3SZ6P205nNX1/0h?oo0@3o
ool003/0h?oo00<0hjQX0>3oo`3Pool00`3Pool01@3SZ6P0HY^N06:KWP1RVih0hjQX00<0HY^N00<0
I9VL0>>XJ01TVI`00P3SZ6P206FIW0050>>XJ01XUIT0J9FI06REV@3SZ6P00P1XUIT00`1_Si@0hjQX
06n?U00206n?U0030>>XJ01hQXh0N8J>00<0hjQX0P1hQXh00`22O8H0hjQX089lQP04089lQP030>>X
J02@Kg`0T6ml00<0T6ml00<0hjQX09]TM02KI7@00`2KI7@00`3SZ6P0VfAd0:YFJ@030:YFJ@80hjQX
1`2^DVH0103SZ6P0^DQN0;U8GP2iB5h40:YFJ@80hjQX1@2`D6D01P2bCV<0hjQX0;9>H`2QGW00hjQX
0:5NL0@0Wf1a00H0hjQX09mPL@2OH740VfAd0>>XJ02KI7@408abO`0308MhP`3SZ6P0QgR300@0QgR3
00<0hjQX07N7SP1gQhh00`1gQhh0103SZ6P0LXbB07:<TP3SZ6P307:<TP050>>XJ01YU9T0JIBI06VD
V@3SZ6P00P1YU9T01@1VUi/0hjQX06JGV`3SZ6P0IYNK0080hjQX101RVih01@3SZ6P0HY^N06:KWP1R
Vih0HIbO0080hjQX0`1PWIl305nMW`80hjQX0P1OWIl305nNX0030>>XJ01OWZ00GijP00<0hjQX0P1O
WZ000`3SZ6P0GijP05nNX00J0>3oo`40oooo000l0>3oo`040>>XJ03Pool0h?oo0>3oo`D0hjQX00H0
HY^N0>>XJ01RVih0HY^N06FIW03SZ6P306FIW0040>>XJ01UVI`0IIVL0>>XJ080J9FI0P3SZ6P206VD
V@060>>XJ01_Si@0KhnD06n?U03SZ6P0KhnD0`1hQXh01@3SZ6P0MhN>07N7SP1gQhh0hjQX00D0PWb6
00<0hjQX091_O02@Kg`00P2@Kg`00`2<LWl0hjQX08abO`0409]TM0030>>XJ02KI7@0VfAd0080XEi`
00@0hjQX0:5NL03SZ6P0XEi`1P2^DVH00`3SZ6P0ZUIY0:YFJ@050:YFJ@030>>XJ02`D6D0/51U00@0
/51U00D0XEi`0>>XJ02QGW00XEi`0>>XJ0020:5NL0@0Wf1a00@0hjQX09mPL@2<LWl0hjQX1P2<LWl0
0`3SZ6P0QgR308MhP`0307b2R`030>>XJ01gQhh0MhN>0080MhN>00H0hjQX07N7SP3SZ6P0LXbB0>>X
J01bS98206bAU`050>>XJ01YU9T0JIBI06VDV@3SZ6P00P1YU9T01`3SZ6P0IYNK06JGV`3SZ6P0I9ZM
0>>XJ01TVYd00P3SZ6P00`1RVih0hjQX06:KWP0206:KWP80hjQX00<0H9fO0>>XJ01PWIl00`1PWIl2
0>>XJ00405nMW`3SZ6P0GifO05nMW`<0GijP0`3SZ6P505nNX0030>>XJ01OWZ00GijP01X0h?oo0@3o
ool003d0h?oo0`3SZ6P30>3oo`030>>XJ01RVih0hjQX00@0hjQX00@0HY^N0>>XJ01UVI`0IIVL103S
Z6P306VDV@@0hjQX0`1_Si@00`3SZ6P0KhnD06n?U00207N7SP<0hjQX0P1gQhh00`3SZ6P0PWb6089l
QP02089lQP030>>XJ022O8H0S79o00<0S79o00<0hjQX08abO`2<LWl0102KI7@0103SZ6P0U6]i0>>X
J03SZ6P20:5NL0030>>XJ02QGW00XEi`00@0[U9V00<0XEi`0>>XJ02QGW001@2ZEVT20>>XJ0040:YF
J@2`D6D0/51U0;1@I@<0Wf1a00<0hjQX0:5NL03SZ6P0102QGW03091_O0030>>XJ02@Kg`0hjQX00H0
S79o00<0hjQX07b2R`3SZ6P0101lPX/00`3SZ6P0MhN>07N7SP0207N7SP040>>XJ01gQhh0hjQX0>>X
J0@0K96G00@0hjQX06bAU`1YU9T0hjQX0P1YU9T0103SZ6P0JIBI06BJW@3SZ6P206BJW@050>>XJ01T
VYd0I9ZM06BJW@3SZ6P00P1RVih20>>XJ080HIbO0P1PWIl01@3SZ6P0H9fO0>>XJ03SZ6P0H9fO00<0
GifO00<0hjQX05nNX01OWZ000P3SZ6P205nNX0030>>XJ01OWZ00GijP00<0GijP0P3SZ6P205nNX1T0
h?oo0@3oool003h0h?oo00<0hjQX0>3oo`3Pool00P3Pool00`3SZ6P0HY^N06:KWP0206:KWP030>>X
J01RVih0hjQX0080hjQX0P1UVI`0103SZ6P0IIVL0>>XJ03SZ6P206VDV@030>>XJ01YU9T0JIBI0080
hjQX0P1_Si@01P3SZ6P0KhnE06n?U@1_SiD0MhN>0>>XJ080MhN>0`3SZ6P3089lQP0407moR03SZ6P0
Ogn807moR0<0S79o00@0hjQX08abO`2<LWl0S79o0`2DJgT20>>XJ080U6]i0`2QGW000`3SZ6P0XEi`
0:5NL0040:5NL0030>>XJ02QGW00XEi`00@0ZUIY0P3SZ6P00`2ZEVT0Wf1a09mPL@0509mPL@80hjQX
0P2QGW03095^N`80T6ml00@0hjQX091_O03SZ6P0T6ml102<LWl0101oOhP0hjQX07moR03SZ6P307b2
R`030>>XJ01lPX/0O8:;0080MhN>00D0hjQX06n>U01_SY@0KhjD0>>XJ00306bAU`050>>XJ01/TIL0
K96G06bAU`3SZ6P00P1UV9/00`3SZ6P0IIRK0>>XJ00206BJW@060>>XJ01TVYd0I9ZM06BJW@3SZ6P0
HIbO0P3SZ6P4066LW`80H9fO0P3SZ6P3062MW`<0GijP0`3SZ6P505nNX0030>>XJ01OWZ00GijP0080
hjQX0P1OWZ000`3SZ6P0GijP05nNX00H0>3oo`40oooo000n0>3oo`030>>XJ03Pool0h?oo00<0h?oo
00D0hjQX0>3oo`1RVih0HY^N0>>XJ00406:KWP80hjQX00L0IIVL0>>XJ01UVI`0hjQX06FIW01YU9T0
hjQX00<0JIBI00D0hjQX06n?U@1_SiD0KhnE0>>XJ00306n?U@0307N7SP3SZ6P0MhN>0080MhN>0P3S
Z6P407moR0030>>XJ01oOhP0Ogn800<0S79o00D0hjQX08MhP`27N8<0QgR309A[N@020>>XJ0@0U6]i
0P2QGW00103SZ6P0UfUg09MYM`2GJGL30:5NL0040>>XJ02QGW00XEi`0:5NL080ZUIY00D0hjQX09]T
M02KI7@0hjQX09]TM00609mPL@030>>XJ02AKW/0TFik00D0TFik0P2@Kg`0103SZ6P0T6ml091_O02@
Kg`307moR0040>>XJ01oOhP0Ogn80>>XJ0<0O8:;00<0hjQX07b2R`1lPX/00P1_SY@0103SZ6P0KhjD
06n>U01_SY@20>>XJ080K96G00L0hjQX06NFVP1WUYX0hjQX06NFVP1UV9/0hjQX0080IIRK00<0hjQX
06FHV`3SZ6P00`1TVYd01P3SZ6P0HY^N0>>XJ03SZ6P0HIbO0>>XJ080HIbO0`3SZ6P2062MW`030>>X
J01OWIl0GifO00<0hjQX0P1OWZ000`3SZ6P0GijP05nNX00305nNX0<0hjQX101OWZ000`3SZ6P0GijP
05nNX00H0>3oo`40oooo000o0>3oo`040>>XJ03Pool0h?oo0>3oo`D0hjQX00<0HY^N0>>XJ01RVih0
0P1RVih0103SZ6P0IIVL0>>XJ03SZ6P206FIW0060>>XJ01UVI`0JIBI0>>XJ01YU9T0J9FI0P3SZ6P2
06n?U@030>>XJ01_SiD0KhnE0080KhnE00H0hjQX07F9T01eRI00MHV@0>>XJ01eRI030>>XJ00307mo
R03SZ6P0Ogn80080Ogn80P27N8<00`3SZ6P0QgR30>>XJ0020>>XJ00309A[N@3SZ6P0U6]i00<0U6]i
0P2GJGL00`3SZ6P0UfUg09MYM`0209MYM`<0XEi`00<0hjQX0:5NL02QGW000P2KI7@0103SZ6P0VfAd
09]TM03SZ6P209]TM0<0Wf1a0P2@Kg`00`3SZ6P0T6ml095^N`06095^N`03091_O03SZ6P0T6ml00<0
PWb60P1oOhP0203SZ6P0Ogn807moR01oOhP0hjQX07b2R`3SZ6P0O8:;0`1bRi801@1_SY@0hjQX06n>
U01_SY@0hjQX0080KhjD0P3SZ6P306NFVP030>>XJ01WUYX0hjQX0080IIRK00D0hjQX06FHV`3SZ6P0
IIRK06:KWP020>>XJ00406:KWP3SZ6P0HY^N06:KWP80HIbO0P3SZ6P2066LW`@0GifO0P3SZ6P205nM
W`<0GijP00<0hjQX05nNX01OWZ000`3SZ6P00`1OWZ00hjQX05nNX00405nNX0030>3oo`3SZ6P0h?oo
01P0h?oo0@3oool00400h?oo0`3SZ6P30>3oo`030>>XJ03Pool0hjQX00<0hjQX0P1RVih01@3SZ6P0
IIVL06FIW03SZ6P0IIVL0080hjQX00T0J9FI0>>XJ01XUIT0J9FI0>>XJ01XUIT0hjQX06n?U@3SZ6P0
0P1_SiD206f@UP050>>XJ01eRI00MHV@07F9T03SZ6P00P1eRI0207moR0T0hjQX1027N8<00`3SZ6P0
U6]i09A[N@0308]cP00309MYM`3SZ6P0UfUg00@0UfUg0P2DJgT01@3SZ6P0U6]i09A[N@2DJgT0hjQX
00<0VfAd00<0hjQX09]TM02KI7@01@2@Kg`00`3SZ6P0T6ml095^N`06095^N`03089lQP3SZ6P0PWb6
00@0PWb600<0Ogn80>>XJ01oOhP00P1oOhP00`3SZ6P0LX^B0>>XJ00407:;TP050>>XJ01_SY@0KhjD
06n>U03SZ6P00`1YU9P20>>XJ00506NFVP3SZ6P0IiJJ06NFVP3SZ6P00P1UV9/01P3SZ6P0HiZM0>>X
J01SVYd0hjQX06:KWP80hjQX101RVih00`3SZ6P0HIbO0>>XJ003062MW`0505nMW`3SZ6P0hjQX05nM
W`3SZ6P00P1OWIl305nNX0<0hjQX1@1OWZ000`3SZ6P0GijP0>3oo`030>3oo`80hjQX603Pool10?oo
o`00@@3Pool00`3SZ6P0h?oo0>3oo`030>3oo`040>>XJ03Pool0HY^N06:KWP@0hjQX00D0HY^N06FI
W03SZ6P0hjQX06FIW0030>>XJ0<0J9FI0P3SZ6P00`1XUIT0hjQX06f@UP0306f@UP030>>XJ01]T9H0
MHV@0080MHV@00<0hjQX07F9T01eRI000P1lPX/00`3SZ6P0O8:;07b2R`0307b2R`030>>XJ027N8<0
QgR300<0QgR300<0hjQX08]cP02;Lh00102;Lh00103SZ6P0UfUg09MYM`2GJGL308]cP00609A[N@3S
Z6P0U6]i09A[N@3SZ6P0U6]i0`2KI7@0103SZ6P0S79o08abO`2<LWl3091_O0040>>XJ02@Kg`0hjQX
091_O0<0TFik0`23NhH00`3SZ6P0PWb60>>XJ004089lQP030>>XJ01eRI00MHV@00<0MHV@00<0hjQX
07:;TP1bRi800`1bRi801@3SZ6P0LX^B06VDV01YU9P0hjQX00<0JIBH00<0hjQX06NFVP3SZ6P0303S
Z6P406:KWP80hjQX0`1PWIl0103SZ6P0H9fO0>>XJ03SZ6P305nMW`030>>XJ01OWZ00GijP00<0hjQX
0P1OWZ000`3SZ6P0GijP05nNX00305nNX0030>>XJ03Pool0h?oo00<0hjQX0P3Pool00`3SZ6P0h?oo
0>3oo`0E0>3oo`40oooo00120>3oo`80hjQX103Pool01P3SZ6P0h?oo06:KWP1RVih0hjQX06:KWP80
hjQX0P1UVI`30>>XJ00306FIW03SZ6P0hjQX0080J9FI00D0hjQX06RFVP3SZ6P0J9JJ0>>XJ00306f@
UP030>>XJ01]T9H0KI2F0080MHV@00H0hjQX07:;TP1bRi80LX^B07b2R`3SZ6P507b2R`030>>XJ020
OXP0P7j800@0P7j800<0hjQX08]cP02;Lh000`2;Lh000`3SZ6P0Rg>008]cP00508]cP0040>>XJ02D
JgT0U6]i0>>XJ080U6]i0P2<LWl00`3SZ6P0S79o08abO`0208abO`80T6ml00@0hjQX091_O03SZ6P0
T6ml1P23NhH00`3SZ6P0Pg^60>>XJ002089lQP80MhN>00<0hjQX07N7SP1eRI000`1eRI000`3SZ6P0
MHV@07:;TP0207:;TP050>>XJ01/TYL0K9:G06bBU`3SZ6P00`1YU9P0103SZ6P0JIBH06VDV03SZ6P2
06NFVP0:0>>XJ01TVI`0hjQX06>JW@3SZ6P0HiZM0>>XJ01SVYd0hjQX06>JW@80hjQX00<0HIbO0>>X
J01QW9l00P1QW9l3062MW`040>>XJ01PWIl0H9fO062MW`<0GijP0P3SZ6P505nNX0030>>XJ01OWZ00
GijP0080h?oo103SZ6P50>3oo`030>>XJ03Pool0h?oo01D0h?oo0@3oool004@0h?oo203SZ6P0201R
Vih0hjQX06:KWP1RVih0hjQX06FIW03SZ6P0IIVL0P3SZ6P01@1UVI`0hjQX06RFVP1XUYX0hjQX0080
J9JJ0P3SZ6P406f@UP050>>XJ01]T9H0LX^B07:;TP3SZ6P0101bRi80103SZ6P0O8:;07b2R`1lPX/2
07N7SP030>>XJ01gQhh0P7j800@0P7j800<0hjQX08]cP02;Lh000P2;Lh02089lQP030>>XJ02;Lh00
Rg>000D0Rg>00P3SZ6P01P2DJgT0QgR308MhP`27N8<0S79o0>>XJ0D0S79o00@0hjQX089lQP22O8H0
hjQX0P22O8H408=kQP040>>XJ023NhH0Pg^60>>XJ0@0MhN>00<0hjQX07N7SP1eRI000`1eRI000`3S
Z6P0MHV@07F9T00206bBU`050>>XJ01/TYL0K9:G06bBU`3SZ6P00`1YU9P01P3SZ6P0JIBH06VDV03S
Z6P0I9VL0>>XJ080I9VL0P3SZ6P0101SVYd0hjQX06>JW@3SZ6P3066LWP03066LW`3SZ6P0HIbO00@0
HIbO0P3SZ6P00`1PWIl0hjQX05nMX00205nMX080hjQX00<0GijP0>>XJ01OWZ00101OWZ050>>XJ0<0
h?oo00<0hjQX0>3oo`3Pool00`3Pool20>>XJ1H0h?oo0@3oool004D0h?oo00<0hjQX0>3oo`3Pool0
0P3Pool00`3SZ6P0h?oo0>>XJ0020>>XJ00306:KWP3SZ6P0hjQX0080hjQX00<0IIVL0>>XJ01TVI`0
0P3SZ6P00`1XUYX0hjQX06RFVP0206RFVP030>>XJ01XUYX0KI2F0080KI2F00D0hjQX06bBU`1/TYL0
LX^B0>>XJ00507:;TP030>>XJ01gQhh0MhN>00<0MhN>00<0hjQX07N7SP20OXP00`20OXP00`3SZ6P0
P7j8089lQP04089lQP030>>XJ022O8H0Rg>000D0Rg>00P3SZ6P508MhP`0408abO`3SZ6P0S79o08ab
O`80Ogn800@0hjQX089lQP22O8H0hjQX0`22O8H308=kQP040>>XJ01hQXh0N8J>0>>XJ0<0MhN>00@0
hjQX07N7SP1gQhh0MhN>0P1eRI000`3SZ6P0KI2F0>>XJ00206f@UP0306bBU`3SZ6P0K9:G0080K9:G
00/0hjQX06bBU`1UV9/0IIRK0>>XJ01UV9/0hjQX06FHV`1TVI`0hjQX06BIW0020>>XJ00406BIW03S
Z6P0HIbN0>>XJ0<0HIbN0P3SZ6P0101QW9l0hjQX066LW`1QW9l20>>XJ0<0GifP00D0hjQX05nMX03S
Z6P0hjQX05nMX00305nNX0030>>XJ01OWZ00h?oo0080hjQX00<0h?oo0>>XJ03Pool01@3Pool00`3S
Z6P0h?oo0>3oo`030>>XJ1P0h?oo0@3oool004D0h?oo00<0hjQX0>3oo`3Pool00P3Pool00`3SZ6P0
h?oo0>3oo`0206:KWP050>>XJ01RVih0hjQX06:KWP3SZ6P00P1TVI`01P3SZ6P0I9VL0>>XJ01TVI`0
J9JJ0>>XJ080J9JJ0P3SZ6P306bBU`050>>XJ01/TYL0K9:G06bBU`3SZ6P00`1bRi8206n>U0030>>X
J01gQhh0MhN>00<0MhN>00<0hjQX07N7SP1gQhh00`20OXP00`3SZ6P0NXB=07Z4S@04089lQP030>>X
J022O8H0PWb600<0Rg>00P20OXP00`3SZ6P0QgR308MhP`0508MhP`050>>XJ01oOhP0Ogn807moR03S
Z6P00P1oOhP2089lQP040>>XJ022O8H0PWb6089lQP80N8J>00D0hjQX07R6SP1hQXh0N8J>0>>XJ002
07N7SP040>>XJ01gQhh0MhN>07N7SP80KI2F00<0hjQX06f@UP3SZ6P00P1]T9H01@3SZ6P0K9:G06bB
U`1/TYL0hjQX00<0IiNJ00/0hjQX06FHV`1UV9/0hjQX06FHV`3SZ6P0I9VL0>>XJ01TVI`0hjQX06:K
WP020>>XJ080HIbN0P3SZ6P3066LWP03066LW`3SZ6P0hjQX00<0H9fO0P1OWJ020>>XJ0<0GifP0`3P
ool30>>XJ0@0h?oo00<0hjQX0>3oo`3Pool00`3Pool30>>XJ1/0h?oo0@3oool004H0h?oo00<0hjQX
0>3oo`3Pool00P3Pool0103SZ6P0h?oo0>3oo`1RVih30>>XJ080HY^N00<0hjQX06BIW03SZ6P00`3S
Z6P01`1TVI`0hjQX06NGVP1WUiX0hjQX06NGVP3SZ6P00P1/TYL01@3SZ6P0K9:G06bBU`1/TYL0hjQX
00D0KhjD00<0hjQX06n>U01gQhh00`1gQhh00`3SZ6P0MhN>07N7SP0307Z4S@040>>XJ01jQ8d0NXB=
07Z4S@<0PWb600<0hjQX089lQP22O8H01020OXP20>>XJ003081nR027N8<0QgR30080QgR30P1lPX/0
1@3SZ6P0Ogn807moR01oOhP0hjQX00<0Ogn800<0PWb60>>XJ022O8H00`1gQhh00`3SZ6P0N8J>07R6
SP0207R6SP030>>XJ01hQXh0hjQX0080MhN>0`1_SiD01`1]T9H0hjQX06f@UP1]T9H0hjQX06f@UP3S
Z6P00`1WUiX01`3SZ6P0IiNJ06NGVP1WUiX0hjQX06FHV`3SZ6P00P1UV9/01@3SZ6P0HY^N0>>XJ03S
Z6P0HY^N00D0hjQX101QW9h20>>XJ004062MW`3SZ6P0H9fO062MW`<0hjQX0P1OWJ000`3SZ6P0h?oo
0>3oo`030>>XJ0030>3oo`3SZ6P0h?oo00@0h?oo00<0hjQX0>3oo`3Pool00`3SZ6PN0>3oo`40oooo
00170>3oo`P0hjQX00@0HY^N0>>XJ01RVih0hjQX0P1RVih01@3SZ6P0I9VL0>>XJ03SZ6P0I9ZM0080
hjQX0`1WUiX01@3SZ6P0IiNJ0>>XJ01/TYL0hjQX0080K9:G0P1YU9P00`3SZ6P0KhjD06n>U00206n>
U0030>>XJ01_SY@0KhjD00<0MhN>00@0hjQX07:<TP1bS980LXbB0P1jQ8d00`3SZ6P0NXB=07Z4S@04
07Z4S@040>>XJ01jQ8d0NXB=07Z4S@80P7j800<0hjQX081nR03SZ6P00P20OXP507b2R`040>>XJ01l
PX/0Ogn80>>XJ0@0Ogn800<0MhN>0>>XJ01gQhh00`1gQhh00`3SZ6P0N8J>07R6SP0207R6SP030>>X
J01hQXh0hjQX00D0KhnE00@0hjQX06f@UP1]T9H0KI2F0P3SZ6P206RFVP80IiNJ00X0hjQX06NGVP1W
UiX0hjQX06NGVP1UV9/0hjQX06FHV`3SZ6P0HiZM1@3SZ6P00`1RVih0hjQX06:KWP020>>XJ003062M
W`3SZ6P0hjQX00<0H9fO0`3SZ6P2062MW`@0h?oo0P3SZ6P50>3oo`030>>XJ03Pool0h?oo0080h?oo
0`3SZ6PQ0>3oo`40oooo00180>3oo`030>>XJ03Pool0h?oo0080h?oo00<0hjQX0>3oo`3SZ6P00P3S
Z6P00`1RVih0hjQX06:KWP050>>XJ00306BJW@3SZ6P0I9ZM0080IiNJ00H0hjQX06NGVP1WUiX0hjQX
06VDV03SZ6P306VDV0030>>XJ01YU9P0KhjD0080KhjD00<0hjQX06n>U01_SY@00`1bS9800`3SZ6P0
LXbB07:<TP0207:<TP0307Z4S@3SZ6P0NXB=00@0Lh^A00<0NXB=0>>XJ01jQ8d00`1jQ8d0103SZ6P0
P7j8081nR03SZ6P307N7SP@0O8:;00@0hjQX07b2R`1lPX/0hjQX0P1oOhP307F9T0050>>XJ01gQhh0
MhN>07N7SP3SZ6P00P1gQhh306n?U0030>>XJ01_Si@0hjQX00D0KhnE00<0hjQX06n?U@1XUYX00P1X
UYX01@3SZ6P0J9JJ06RFVP1XUYX0hjQX00<0IiNJ00<0hjQX06NGVP3SZ6P00P1SVYd80>>XJ0<0HIbO
00<0H9fO0>>XJ01PWIl00P1PWIl20>>XJ080H9fO00<0hjQX0>3oo`3Pool00P3Pool30>>XJ0H0h?oo
00<0hjQX0>3oo`3Pool00P3SZ6PT0>3oo`40oooo00190>3oo`030>>XJ03Pool0h?oo0080h?oo00@0
hjQX0>3oo`1RVih0HY^N1@3SZ6P0101TVYd0hjQX0>>XJ01TVYd20>>XJ00406BJW@1WUiX0hjQX06NG
VP80IIRK0P3SZ6P306VDV0030>>XJ01YU9P0JIBH0080K96G00@0hjQX06bAU`1/TIL0K96G0P1bS980
0`3SZ6P0LXbB07:<TP0207:<TP80Lh^A00<0hjQX07>;T@1cRi400P1cRi4207Z4S@050>>XJ01jQ8d0
NXB=0>>XJ01jQ8d00`1gQhh0103SZ6P0MhN>07N7SP1gQhh307b2R`030>>XJ01lPX/0hjQX00L0MHV@
00@0hjQX07N7SP1gQhh0hjQX0`1_SiD306n?U0030>>XJ01_Si@0KhnD00@0KhnE00<0hjQX06REV@1X
UIT00P1XUYX20>>XJ080J9JJ00`0hjQX06NGVP1WUiX0IiNJ0>>XJ01TVYd0hjQX06>JW@3SZ6P0HiZM
0>>XJ01SVYd30>>XJ0@0HIbO0P3SZ6P0101PWIl0hjQX0>>XJ03SZ6P2062MW`<0h?oo00@0hjQX0>3o
o`3SZ6P0hjQX0`3Pool00`3SZ6P0h?oo0>3oo`030>3oo`<0hjQX9P3Pool10?ooo`00BP3Pool80>>X
J00306:LWP3SZ6P0hjQX00D0hjQX0P1TVYd0103SZ6P0I9ZM06FHV`3SZ6P406FHV`050>>XJ01YU9P0
JIBH06VDV03SZ6P00`1WUYX206bAU`060>>XJ01/TIL0K96G06bAU`1bS980hjQX0P1bS98306f@UP03
07>;T@3SZ6P0Lh^A00@0Lh^A00@0NXB=0>>XJ01jQ8d0hjQX0`1bS98207N7SP030>>XJ01gQhh0MhN>
0080MhN>0`1bRi820>>XJ00307:;TP1eRI00MHV@00@0MHV@00@0hjQX06n?U@1_SiD0hjQX0`1_SiD3
06n?U0040>>XJ01_Si@0KhnD06n?U080J9FI00<0hjQX06REV@1XUIT00P1XUIT00`3SZ6P0J9JJ0>>X
J00206RFVP060>>XJ01TVYd0I9ZM0>>XJ01TVYd0hjQX0P1TVYd60>>XJ003066LWP1QW9l0HIbO0080
hjQX0P1QW9l20>>XJ003062MW`3SZ6P0h?oo00@0h?oo0P3SZ6P50>3oo`030>>XJ03Pool0h?oo00<0
hjQX:@3Pool10?ooo`00B`3Pool00`3SZ6P0h?oo0>3oo`020>3oo`030>>XJ03Pool0hjQX0080hjQX
00<0HYbN0>>XJ03SZ6P00`3SZ6P01@1SVYd0hjQX0>>XJ01SVYd0hjQX00@0IIRK0P3SZ6P206NFVP03
0>>XJ01WUYX0IiJJ0080IiJJ00<0K96G0>>XJ01/TIL00`1/TIL00`1]T9H0hjQX06f@UP0406f@UP03
0>>XJ01cRi40Lh^A00<0Lh^A00<0LXbB0>>XJ03SZ6P01@1bS9800`1gQhh0hjQX07N7SP0406n>U080
LX^B00@0hjQX07:;TP1bRi80LX^B0`1eRI0206f@UP030>>XJ01]T9H0hjQX00D0KhnE0P1_Si@00`3S
Z6P0JIBI06VDV@0206VDV@0306REV@3SZ6P0J9FI00<0J9FI00<0hjQX06BIW01TVI`00P3SZ6P206BI
W00506BJW@3SZ6P0I9ZM0>>XJ01TVYd01P3SZ6P0101QW9h0hjQX0>>XJ03SZ6P2066LW`80hjQX00@0
HIbO0>3oo`3Pool0hjQX0P3Pool30>>XJ080h?oo00@0hjQX0>3oo`3Pool0h?oo103SZ6P/0>3oo`40
oooo001<0>3oo`80hjQX0`3Pool20>>XJ0030>3oo`1RW9h0hjQX00D0hjQX0P1SVYd0103SZ6P0HiZM
06>JW@3SZ6P306FHV`050>>XJ01TVI`0hjQX06NFVP3SZ6P01@1WUYX00`3SZ6P0K96G06bAU`0306VD
V@030>>XJ01]T9H0KI2F00<0KI2F00<0hjQX06f@UP1]T9H0101]T9H00`3SZ6P0LXbB07:<TP0407:<
TP0306n>U03SZ6P0KhjD00@0KhjD0P1bRi80103SZ6P0LX^B07:;TP1bRi8506f@UP030>>XJ01]T9H0
hjQX00D0KhnE00@0JIBI0>>XJ01YU9T0hjQX0`1YU9T0103SZ6P0J9FI06REV@1XUIT206FIW0050>>X
J01TVI`0I9VL06BIW03SZ6P00`1TVI`20>>XJ00306BJW@3SZ6P0hjQX00@0hjQX00@0HIbN0>>XJ03S
Z6P0HIbN0`3SZ6P50>3oo`<0hjQX1@3Pool40>>XJ300h?oo0@3oool004h0h?oo1`3SZ6P00`1QW9h0
hjQX0>>XJ0040>>XJ00506>JW@3SZ6P0hjQX06>JW@3SZ6P0101TVI`01@3SZ6P0I9VL0>>XJ01WUYX0
hjQX00@0IiJJ00<0hjQX06VDV@1YU9T00`1YU9T00`3SZ6P0KI2F06f@UP0206f@UP0306VDV@3SZ6P0
JIBI00@0KI2F0P3SZ6P407:<TP<0K96G00<0hjQX06n>U01_SY@0101_SY@20>>XJ00407:;TP1/TYL0
K9:G06bBU`D0KI2F00<0hjQX06f@UP1XUIT01@1XUIT00`3SZ6P0JIBI0>>XJ00306VDV@030>>XJ01U
VI`0IIVL00<0IIVL00@0hjQX06FIW01TVI`0I9VL103SZ6P0101RW9h0hjQX0>>XJ01RW9h60>>XJ005
066LWP3Pool0hjQX0>>XJ03Pool00P3SZ6P20>3oo`80hjQX0P3Pool00`3SZ6P0h?oo0>3oo`030>>X
J3@0h?oo0@3oool004l0h?oo00<0hjQX0>3oo`3Pool00P3Pool40>>XJ005066LWP3SZ6P0hjQX0>>X
J01SVYd00P3SZ6P00`1RVih0hjQX06:KWP0306BIW0030>>XJ01TVI`0I9VL0080hjQX101UV9/00`3S
Z6P0JIBI06VDV@0306VDV@030>>XJ01YU9T0JIBI00<0JIBI00<0hjQX06VDV@1YU9T00P1]T9H0103S
Z6P0KI2F0>>XJ01]T9H606bAU`030>>XJ01_SY@0KhjD00@0KhjD0P3SZ6P506bBU`@0KI2F00<0hjQX
06RFVP1XUYX01@1XUIT00`3SZ6P0JIBI0>>XJ00206VDV@0306FIW03SZ6P0IIVL00<0IIVL00D0hjQX
06FIW01UVI`0IIVL0>>XJ00306:KWP<0hjQX00<0HYbN0>>XJ03SZ6P00`3SZ6P20>3oo`80hjQX103P
ool30>>XJ0@0h?oo0`3SZ6Pg0>3oo`40oooo001@0>3oo`030>>XJ03Pool0h?oo0080h?oo00<0hjQX
0>3oo`1QW9h01P3SZ6P00`1RVih0hjQX0>>XJ00206:KWP80I9VL00D0hjQX06BIW01SVYd0HiZM0>>X
J00406FHV`030>>XJ01UV9/0JIBI00<0JIBI00<0hjQX06JGV`1VUi/0101YU9T0103SZ6P0JIBI06VD
V@3SZ6P206f@UP0306VDV@3SZ6P0JIBI00H0K96G00<0hjQX06VDV01YU9P00P1YU9P0103SZ6P0JIBH
06bBU`3SZ6P506bBU`<0J9JJ00@0hjQX06RFVP1XUYX0J9JJ0`1XUIT01`3SZ6P0J9FI06REV@1UVI`0
hjQX06FIW03SZ6P01@1UVI`01@3SZ6P0IIVL06:KWP1RVih0hjQX00<0HY^N0P3SZ6P00`1RVih0HYbN
0>>XJ0030>>XJ0030>3oo`3SZ6P0hjQX00<0h?oo0`3SZ6P20>3oo`030>>XJ03Pool0h?oo0080hjQX
>P3Pool10?ooo`00D@3Pool<0>>XJ003066LW`3SZ6P0HY^N0080hjQX0P1RVih00`1SVYd0hjQX06>J
W@0206>JW@<0hjQX0`1UV9/00`3SZ6P0IIRK06JGV`0206JGV`040>>XJ01VUi/0IYNK06JGV`<0JIBI
00<0hjQX06VDV@3SZ6P0101YU9T00`3SZ6P0JIBI06VDV@0406bAU`0306NFVP3SZ6P0IiJJ00<0JIBH
00@0hjQX06VDV01YU9P0hjQX0`1/TYL306NGVP0306RFVP3SZ6P0hjQX00@0J9JJ0P1UVI`01`3SZ6P0
IIVL06FIW01UVI`0hjQX06FIW03SZ6P0101UVI`00`1RVih0hjQX06:KWP0206:KWP070>>XJ01RVih0
HY^N0>>XJ01RVih0hjQX06:KWP030>>XJ0030>3oo`3SZ6P0hjQX0080h?oo0`3SZ6P50>3oo`<0hjQX
?03Pool10?ooo`00DP3Pool00`3SZ6P0h?oo0>3oo`020>3oo`030>>XJ03Pool0hjQX00D0hjQX00<0
HY^N0>>XJ03SZ6P00`1QW9h01@3SZ6P0HiZM06>JW@1SVYd0hjQX0080HiZM00@0hjQX06FHV`1UV9/0
hjQX0P1TVYd306JGV`030>>XJ01VUi/0IYNK00<0IYNK0P3SZ6P206JGV`<0JIBI00@0hjQX06VDV@1Y
U9T0JIBI101WUYX01@3SZ6P0IiJJ06NFVP1YU9P0hjQX00<0JIBH00<0hjQX06NGVP1WUiX01@1WUiX0
103SZ6P0J9JJ0>>XJ01XUYX306BIW00306FIW03SZ6P0IIVL0080IIVL00<0hjQX06FIW03SZ6P00P1U
VI`206:KWP030>>XJ01RVih0HY^N0080HY^N00D0hjQX06:KWP1RVih0hjQX06:KWP060>>XJ0<0h?oo
0P3SZ6P00`3Pool0hjQX0>>XJ0020>3oo`80hjQX?`3Pool10?ooo`00D`3Pool00`3SZ6P0h?oo0>3o
o`020>3oo`040>>XJ03Pool0HIbO066LW`<0hjQX00<0HIbO066LWP3SZ6P00`1QW9h01@3SZ6P0HiZM
06>JW@1SVYd0hjQX0080HiZM00@0I9ZM0>>XJ03SZ6P0hjQX0`1TVYd206JGV`030>>XJ01VUi/0I9VM
0080I9VM0P3SZ6P406JGV`80JIBI00<0hjQX06VDV@1UV9/00P1UV9/306NFVP050>>XJ01WUYX0IiJJ
06NFVP3SZ6P00`1UV9/00`3SZ6P0IIRK06NGVP0406NGVP040>>XJ01WUiX0I9VL0>>XJ0@0I9VL00<0
hjQX06FIW01UVI`00`1UVI`00`3SZ6P0HY^N06:KWP0306:KWP050>>XJ01RVih0HY^N06:KWP3SZ6P0
0P1RVih00`3Pool0hjQX0>>XJ0040>>XJ0030>3oo`3SZ6P0h?oo0080hjQX103Pool30>>XJ440h?oo
0@3oool005@0h?oo3`3SZ6P3066LWP050>>XJ01RVih0HY^N06:KWP3SZ6P00P1RVih206BJW@<0hjQX
0P1TVYd00`1TVId0hjQX06BIW@030>>XJ00306BIW@3SZ6P0IYNK00@0IYNK00<0IIRK0>>XJ01UV9/0
101UV9/206NFVP050>>XJ01WUYX0I9VL0>>XJ01TVI`0101UV9/00`3SZ6P0IIRK06NGVP0306NGVP04
0>>XJ01TVYd0I9ZM0>>XJ0@0I9VL00@0hjQX06FIW01UVI`0IIVL0P1RVih00`3SZ6P0HY^N06:KWP03
06:KWP050>>XJ01RVih0h?oo0>3oo`3SZ6P00P3Pool60>>XJ080h?oo0P3SZ6P30>3oo`<0hjQXA03P
ool10?ooo`00E@3Pool00`3SZ6P0h?oo0>3oo`020>3oo`030>>XJ03Pool0H9fO00H0hjQX0P1QW9h0
0`1QW9l0hjQX066LW`0206:KWP060>>XJ01RVih0HY^N06:KWP1TVYd0hjQX0P1TVYd50>>XJ0@0I9VM
00<0hjQX06BJW@1TVYd0101TVYd00`3SZ6P0IIRK06FHV`0406FHV`0506BIW03SZ6P0I9VL06BIW03S
Z6P00P1TVI`306FHV`030>>XJ01UV9/0IIRK00<0I9ZM00@0hjQX06BJW@1TVYd0hjQX0`1TVI`00`3S
Z6P0I9VL06:KWP0406:KWP80hjQX101RVih01@3SZ6P0h?oo0>3oo`3Pool0hjQX0080h?oo1@3SZ6P0
0`3Pool0hjQX0>>XJ0020>3oo`<0hjQXA`3Pool10?ooo`00EP3Pool00`3SZ6P0h?oo0>3oo`020>3o
o`030>>XJ03Pool0hjQX00H0hjQX0P1QW9l01@3SZ6P0HIbO066LW`1RVih0hjQX00@0HY^N00<0hjQX
06:KWP1RVih00`1RVih00`3SZ6P0I9VM06BIW@0206BIW@0306:KWP3SZ6P0HY^N00H0I9ZM00@0hjQX
06FHV`1UV9/0IIRK0`1SVYd00`1TVI`0hjQX0>>XJ00406BIW080IIRK00H0hjQX06>JW@1SVYd0HiZM
06BJW@3SZ6P406BJW@040>>XJ01RVih0HY^N0>>XJ0D0HY^N00@0hjQX06:KWP3SZ6P0HY^N0P3Pool0
1P3SZ6P0h?oo0>3oo`3Pool0hjQX0>3oo`P0hjQX0P3Pool20>>XJ4X0h?oo0@3oool005L0h?oo403S
Z6P3066LW`030>>XJ01QW9l0HIbO0080HIbO00<0hjQX06:KWP1RVih00`1RVih00`3SZ6P0HY^N06:K
WP0406:KWP030>>XJ01RVih0I9ZM00@0I9ZM00<0hjQX06>JW@1SVYd01@1SVYd20>>XJ0@0I9VL0P1S
VYd00`3SZ6P0HiZM06>JW@0206>JW@030>>XJ01TVYd0I9ZM0080HYbN00@0hjQX06:KWP1RVih0hjQX
1@1RVih0103SZ6P0HY^N0>3oo`3SZ6P20>3oo`030>>XJ03Pool0h?oo00T0hjQX00@0h?oo0>>XJ03S
Z6P0hjQXC03Pool10?ooo`00F03Pool00`3SZ6P0h?oo0>3oo`020>3oo`/0hjQX0P1PWIl00`3SZ6P0
HIbO066LW`03066LW`030>>XJ01RVih0HY^N0080HY^N00<0hjQX066LW`1QW9l0101RVih00`3SZ6P0
HY^N06:KWP0406:KWP030>>XJ01RVih0HiZM00D0HiZM00<0hjQX06:KWP1RVih0101RVih206>JW@04
0>>XJ01SVYd0HiZM0>>XJ0D0HYbN00<0hjQX06:LWP3SZ6P01@1RVih01@3Pool0hjQX0>3oo`3Pool0
hjQX0080h?oo3@3SZ6Q?0>3oo`40oooo001I0>3oo`040>>XJ03Pool0h?oo0>3oo`h0hjQX00<0H9fO
066LW`1QW9l00P1QW9l00`3SZ6P0HIbO066LW`03066LW`030>>XJ01QW9l0HIbO00<0HY^N00@0hjQX
066LW`1QW9l0HIbO0`1RVih00`3SZ6P0HY^N06:KWP0406>JW@03066LWP3SZ6P0HIbN00H0HY^N00H0
HiZM0>>XJ01SVYd0HIbN0>>XJ01QW9h406:LWP030>>XJ01RW9h0hjQX00H0h?oo00@0hjQX0>3oo`3P
ool0h?oo103SZ6P0103Pool0hjQX0>>XJ03Pool50>>XJ540h?oo0@3oool005X0h?oo0`3SZ6P20>3o
o`@0hjQX00<0H9fO0>>XJ03SZ6P00P3SZ6P00`1PWIl0hjQX0>>XJ0020>>XJ0<0H9fO00<0hjQX062M
W`1PWIl00`1QW9l00`3SZ6P0HIbO066LW`03066LW`030>>XJ01QW9l0HIbO0080HIbO0P1RVih0103S
Z6P0HY^N06:KWP1RVih3066LWP80hjQX0P1QW9h506:KWP05066LWP3SZ6P0HIbN066LWP3SZ6P00P1Q
W9h406:LWP80hjQX1@3Pool00`3SZ6P0h?oo0>>XJ0090>>XJ0030>3oo`3SZ6P0hjQX00<0hjQXD@3P
ool10?ooo`00F`3Pool00`3SZ6P0h?oo0>3oo`020>3oo`80hjQX00<0GifP0>>XJ01OWJ00303SZ6P3
062MW`80HIbO00<0hjQX066LW`1PWIl00P1PWIl00`1QW9l0hjQX066LW`04066LW`80HY^N00@0hjQX
066LW`1QW9l0HIbO0P1QW9h20>>XJ080HIbN1P1QW9l00`3SZ6P0HIbN0>>XJ004066LWP<0h?oo00<0
hjQX0>3oo`3Pool00P3Pool:0>>XJ080h?oo1`3SZ6QB0>3oo`40oooo001L0>3oo`040>>XJ03Pool0
h?oo0>3oo`H0hjQX00<0GifP0>>XJ03SZ6P00P1OWIl00`3SZ6P0GifO0>>XJ0060>>XJ080H9fO00<0
hjQX062MW`1PWIl00`1PWIl00`3SZ6P0HIbO066LW`05066LW`030>>XJ01QW9l0HIbO0080HIbO00<0
hjQX066LWP3SZ6P00`1PWIl6066LW`80hjQX0P1QW9h50>3oo`X0hjQX00<0h?oo0>>XJ03SZ6P01@3S
Z6P00`3Pool0hjQX0>>XJ0030>>XJ580h?oo0@3oool005d0h?oo0`3SZ6P00`3Pool0hjQX0>>XJ002
0>>XJ00305nMX03SZ6P0hjQX0080hjQX00<0GifO0>>XJ03SZ6P0403SZ6P6062MW`03066LW`3SZ6P0
HIbO00<0HIbO00@0hjQX062MW`1PWIl0hjQX0`1PWIl5066LW`030>>XJ03Pool0h?oo00D0h?oo2@3S
Z6P00`3Pool0hjQX0>>XJ0040>>XJ0040>3oo`3SZ6P0hjQX0>3oo`@0hjQXD`3Pool10?ooo`00GP3P
ool00`3SZ6P0h?oo0>3oo`040>>XJ00305nNX03SZ6P0GijP00L0hjQX00<0GijP0>>XJ03SZ6P00P1O
WIl30>>XJ003062MW`3SZ6P0hjQX00/0hjQX0P1QW9l00`1PWIl0hjQX062MW`02062MW`030>>XJ01P
WIl0H9fO0080H9fO0`3Pool>0>>XJ080h?oo103SZ6P20>3oo`030>>XJ03Pool0h?oo0080hjQX0P3P
ool40>>XJ5<0h?oo0@3oool005l0h?oo00<0hjQX0>3oo`3Pool02`3SZ6P00`1OWZ00hjQX05nNX00?
0>>XJ003062MW`3SZ6P0hjQX01@0hjQX00<0h?oo0>>XJ03SZ6P00P3SZ6P20>3oo`<0hjQX00<0h?oo
0>>XJ03SZ6P00`3SZ6P40>3oo`D0hjQX00<0h?oo0>>XJ03SZ6P00P3SZ6QD0>3oo`40oooo001P0>3o
o`T0hjQX00<0GijP0>>XJ03SZ6P0103SZ6P0101OWZ00hjQX0>>XJ03SZ6P205nNX0D0hjQX00<0GifO
0>>XJ03SZ6P02P3SZ6P00`1PWIl0hjQX0>>XJ0080>>XJ0030>3oo`3SZ6P0hjQX0080hjQX00@0h?oo
0>>XJ03SZ6P0h?oo1P3SZ6P20>3oo`80hjQX0`3Pool20>>XJ080h?oo1`3SZ6QD0>3oo`40oooo001Q
0>3oo`030>>XJ03Pool0hjQX0080hjQX00<0h?oo0>>XJ03SZ6P0103SZ6P01P1OWZ00hjQX0>>XJ01O
WZ00hjQX05nNX080hjQX0P1OWZ0<0>>XJ080GifP1P3SZ6P01P3Pool0hjQX0>>XJ03Pool0hjQX0>3o
o`d0hjQX0P3Pool01@3SZ6P0h?oo0>3oo`3Pool0hjQX00@0h?oo00H0hjQX0>3oo`3Pool0h?oo0>>X
J03Pool50>>XJ5@0h?oo0@3oool00680h?oo1@3SZ6P0103Pool0hjQX0>>XJ01OWZ020>>XJ080GijP
0`3SZ6P00`1OWZ00hjQX0>>XJ0030>>XJ00305nNX03SZ6P0GijP00<0hjQX0P1OWZ0:0>>XJ080h?oo
1@3SZ6P20>3oo`@0hjQX00H0h?oo0>>XJ03SZ6P0hjQX0>3oo`3SZ6P20>3oo`80hjQX0P3Pool20>>X
J080h?oo0`3SZ6P30>3oo`H0hjQXE@3Pool10?ooo`00H`3Pool40>>XJ0070>3oo`3SZ6P0hjQX0>>X
J01OWZ00hjQX05nNX0050>>XJ080GijP0`3SZ6P205nNX0H0hjQX00L0GijP0>>XJ03Pool0hjQX0>3o
o`3SZ6P0h?oo00H0hjQX00@0h?oo0>>XJ03SZ6P0hjQX0P3Pool50>>XJ080h?oo00<0hjQX0>3oo`3S
Z6P00P3Pool20>>XJ080h?oo00@0hjQX0>3oo`3SZ6P0hjQX0P3Pool00`3SZ6P0h?oo0>3oo`020>>X
J0050>3oo`3SZ6P0hjQX0>3oo`3SZ6P0E@3Pool10?ooo`00I03Pool30>>XJ080h?oo1@3SZ6P305nN
X0@0hjQX00<0GijP0>>XJ03SZ6P0103SZ6P0101OWZ00hjQX0>>XJ01OWZ020>3oo`D0hjQX0`3Pool2
0>>XJ0030>3oo`3SZ6P0hjQX00H0hjQX00L0h?oo0>>XJ03Pool0h?oo0>>XJ03Pool0hjQX00<0h?oo
00<0hjQX0>3oo`3SZ6P00`3SZ6P30>3oo`050>>XJ03Pool0h?oo0>3oo`3SZ6P00P3Pool40>>XJ5D0
h?oo0@3oool006@0h?oo1`3SZ6P0101OWZ00hjQX0>>XJ03SZ6P205nNX0L0hjQX00@0GijP0>>XJ01O
WZ00GijP1P3SZ6P00`3Pool0hjQX0>>XJ0020>>XJ0@0h?oo103SZ6P0203Pool0hjQX0>>XJ03SZ6P0
h?oo0>>XJ03Pool0hjQX0P3Pool00`3SZ6P0h?oo0>>XJ0020>3oo`060>>XJ03Pool0hjQX0>>XJ03P
ool0hjQX103Pool00`3SZ6P0h?oo0>3oo`020>>XJ080h?oo00<0hjQX0>3oo`3SZ6P0EP3Pool10?oo
o`00I03Pool70>>XJ0040>3oo`3SZ6P0hjQX05nNX0H0hjQX0P1OWZ00103SZ6P0GijP0>3oo`3SZ6P2
0>3oo`80hjQX00@0h?oo0>>XJ03SZ6P0hjQX0P3Pool20>>XJ080h?oo0P3SZ6P20>3oo`040>>XJ03P
ool0h?oo0>3oo`l0hjQX00@0h?oo0>>XJ03SZ6P0hjQX103Pool01P3SZ6P0h?oo0>>XJ03Pool0hjQX
0>3oo`@0hjQXEP3Pool10?ooo`00I@3Pool<0>>XJ00605nNX03SZ6P0hjQX05nNX03SZ6P0GijP1P3S
Z6P00`3Pool0hjQX0>3oo`020>>XJ080h?oo1@3SZ6P30>3oo`80hjQX0`3Pool00`3SZ6P0h?oo0>>X
J0030>3oo`80hjQX00<0h?oo0>>XJ03Pool00P3Pool01@3SZ6P0h?oo0>3oo`3Pool0hjQX00@0h?oo
0`3SZ6P0103Pool0hjQX0>>XJ03Pool40>>XJ5H0h?oo0@3oool006D0h?oo0P3SZ6P00`3Pool0hjQX
0>>XJ0020>>XJ0050>3oo`3SZ6P0hjQX0>>XJ01OWZ000P3SZ6P00`1OWZ00hjQX0>>XJ0040>>XJ004
0>3oo`3SZ6P0hjQX0>3oo`L0hjQX00@0h?oo0>>XJ03Pool0hjQX0`3Pool20>>XJ080h?oo00<0hjQX
0>3oo`3SZ6P0103Pool20>>XJ0050>3oo`3SZ6P0h?oo0>3oo`3SZ6P0103Pool00`3SZ6P0h?oo0>3o
o`020>3oo`060>>XJ03Pool0hjQX0>3oo`3SZ6P0h?oo103SZ6QG0>3oo`40oooo001V0>3oo`030>>X
J03Pool0hjQX0080hjQX00@0h?oo0>>XJ03SZ6P0h?oo0P3SZ6P0103Pool0hjQX0>>XJ03SZ6P20>3o
o`<0hjQX00<0h?oo0>>XJ03SZ6P0103SZ6P20>3oo`040>>XJ03Pool0h?oo0>>XJ080h?oo0`3SZ6P0
1`3Pool0hjQX0>3oo`3Pool0hjQX0>3oo`3SZ6P0103Pool0103SZ6P0h?oo0>3oo`3SZ6P20>3oo`03
0>>XJ03Pool0h?oo0080h?oo00<0hjQX0>3oo`3Pool00P3Pool20>>XJ080h?oo00<0hjQX0>3oo`3S
Z6P00`3SZ6QG0>3oo`40oooo001V0>3oo`P0hjQX00<0h?oo0>>XJ03SZ6P00P3SZ6P00`3Pool0hjQX
0>>XJ0030>>XJ0060>3oo`3SZ6P0hjQX0>>XJ03Pool0hjQX0P3Pool00`3SZ6P0h?oo0>>XJ0020>3o
o`030>>XJ03Pool0h?oo0080h?oo00<0hjQX0>3oo`3Pool00P3SZ6P00`3Pool0hjQX0>3oo`040>3o
o`030>>XJ03Pool0hjQX00<0h?oo00@0hjQX0>3oo`3Pool0h?oo0`3SZ6P20>3oo`80hjQX0`3Pool6
0>>XJ5L0h?oo0@3oool006H0h?oo0P3SZ6P0103Pool0hjQX0>>XJ03Pool30>>XJ0030>3oo`3SZ6P0
h?oo0080hjQX00<0h?oo0>>XJ03Pool00`3SZ6P01@3Pool0hjQX0>3oo`3Pool0hjQX00<0h?oo00D0
hjQX0>3oo`3Pool0h?oo0>>XJ0040>3oo`D0hjQX00<0h?oo0>>XJ03Pool0103Pool00`3SZ6P0h?oo
0>>XJ0020>3oo`030>>XJ03Pool0h?oo0080h?oo00@0hjQX0>3oo`3SZ6P0h?oo0`3SZ6P20>3oo`H0
hjQXF03Pool10?ooo`00I`3Pool0103SZ6P0h?oo0>>XJ03SZ6P20>3oo`050>>XJ03Pool0h?oo0>>X
J03Pool01@3SZ6P01@3Pool0hjQX0>3oo`3Pool0hjQX00<0h?oo00<0hjQX0>3oo`3Pool00P3SZ6P2
0>3oo`050>>XJ03Pool0h?oo0>3oo`3SZ6P00`3Pool30>>XJ0H0h?oo0`3SZ6P20>3oo`030>>XJ03P
ool0h?oo0080h?oo00H0hjQX0>3oo`3SZ6P0hjQX0>3oo`3SZ6P30>3oo`80hjQX00@0h?oo0>>XJ03S
Z6P0hjQXF03Pool10?ooo`00I`3Pool40>>XJ080h?oo0P3SZ6P20>3oo`<0hjQX0P3Pool00`3SZ6P0
h?oo0>>XJ0030>3oo`060>>XJ03Pool0h?oo0>>XJ03Pool0hjQX0P3Pool00`3SZ6P0h?oo0>>XJ003
0>3oo`060>>XJ03Pool0h?oo0>3oo`3SZ6P0h?oo0P3SZ6P40>3oo`030>>XJ03Pool0hjQX00<0h?oo
00@0hjQX0>3oo`3Pool0h?oo0`3SZ6P0103Pool0hjQX0>3oo`3SZ6P30>3oo`@0hjQX00<0h?oo0>>X
J03Pool0E`3Pool10?ooo`00I`3Pool20>>XJ0030>3oo`3SZ6P0hjQX0080h?oo103SZ6P00`3Pool0
hjQX0>3oo`020>3oo`80hjQX0`3Pool01P3SZ6P0h?oo0>3oo`3SZ6P0h?oo0>>XJ0<0h?oo00D0hjQX
0>3oo`3SZ6P0h?oo0>>XJ0030>3oo`80hjQX00<0h?oo0>>XJ03Pool00`3SZ6P0103Pool0hjQX0>3o
o`3SZ6P20>3oo`030>>XJ03Pool0hjQX00@0hjQX0`3Pool20>>XJ080h?oo0P3SZ6P0103Pool0hjQX
0>>XJ03SZ6QI0>3oo`40oooo001X0>3oo`@0hjQX0P3Pool0103SZ6P0h?oo0>3oo`3Pool20>>XJ080
h?oo0P3SZ6P00`3Pool0hjQX0>3oo`020>3oo`040>>XJ03Pool0hjQX0>>XJ0D0h?oo0P3SZ6P00`3P
ool0hjQX0>3oo`020>3oo`<0hjQX1@3Pool80>>XJ0<0h?oo00<0hjQX0>3oo`3Pool00P3Pool20>>X
J080h?oo0P3SZ6P0103Pool0hjQX0>>XJ03SZ6QI0>3oo`40oooo001X0>3oo`80hjQX00D0h?oo0>>X
J03SZ6P0h?oo0>>XJ0030>3oo`80hjQX00@0h?oo0>>XJ03Pool0h?oo0P3SZ6P40>3oo`<0hjQX1P3P
ool20>>XJ0<0h?oo00@0hjQX0>3oo`3Pool0hjQX1P3Pool20>>XJ0040>3oo`3SZ6P0h?oo0>>XJ0@0
h?oo00<0hjQX0>3oo`3Pool00P3Pool20>>XJ0030>3oo`3SZ6P0hjQX0080h?oo0`3SZ6QI0>3oo`40
oooo001X0>3oo`D0hjQX00<0h?oo0>>XJ03SZ6P00`3Pool20>>XJ0<0h?oo0P3SZ6P40>3oo`80hjQX
1`3Pool20>>XJ0<0h?oo00@0hjQX0>3oo`3Pool0hjQX1@3Pool01`3SZ6P0h?oo0>>XJ03Pool0hjQX
0>3oo`3SZ6P00`3Pool20>>XJ0<0h?oo103SZ6P00`3Pool0hjQX0>3oo`030>>XJ5X0h?oo0@3oool0
06T0h?oo0`3SZ6P0103Pool0hjQX0>>XJ03SZ6P30>3oo`030>>XJ03Pool0h?oo00<0h?oo00<0hjQX
0>3oo`3Pool00`3Pool20>>XJ0H0h?oo0`3SZ6P0103Pool0hjQX0>3oo`3Pool20>>XJ0D0h?oo00@0
hjQX0>3oo`3SZ6P0h?oo0P3SZ6P40>3oo`80hjQX0`3Pool20>>XJ0030>3oo`3SZ6P0hjQX00D0hjQX
FP3Pool10?ooo`00J@3Pool60>>XJ0030>3oo`3SZ6P0hjQX0080hjQX1@3Pool00`3SZ6P0h?oo0>3o
o`030>3oo`80hjQX1P3Pool00`3SZ6P0h?oo0>3oo`020>>XJ080h?oo0P3SZ6P50>3oo`80hjQX0P3P
ool20>>XJ0@0h?oo00<0hjQX0>3oo`3Pool00P3Pool30>>XJ0030>3oo`3SZ6P0hjQX00@0hjQXFP3P
ool10?ooo`00J@3Pool80>>XJ0<0h?oo00<0hjQX0>3oo`3Pool00P3Pool20>>XJ0<0h?oo00<0hjQX
0>3oo`3SZ6P01P3Pool00`3SZ6P0h?oo0>3oo`020>>XJ080h?oo00<0hjQX0>3oo`3SZ6P0103Pool2
0>>XJ0<0h?oo00@0hjQX0>3oo`3Pool0h?oo0P3SZ6P40>3oo`80hjQX0P3Pool01@3SZ6P0h?oo0>>X
J03Pool0hjQX05/0h?oo0@3oool006X0h?oo0`3SZ6P0103Pool0hjQX0>>XJ03SZ6P30>3oo`030>>X
J03Pool0h?oo0080h?oo0P3SZ6P30>3oo`040>>XJ03Pool0hjQX0>>XJ0D0h?oo0P3SZ6P00`3Pool0
hjQX0>3oo`020>>XJ080h?oo00L0hjQX0>3oo`3Pool0h?oo0>>XJ03Pool0hjQX00<0h?oo00@0hjQX
0>3oo`3Pool0h?oo0P3SZ6P30>3oo`80hjQX0P3Pool60>>XJ5/0h?oo0@3oool006X0h?oo103SZ6P0
103Pool0hjQX0>3oo`3SZ6P20>3oo`80hjQX0`3Pool01@3SZ6P0h?oo0>>XJ03Pool0hjQX0080h?oo
00<0hjQX0>3oo`3SZ6P00`3Pool0103SZ6P0h?oo0>>XJ03SZ6P30>3oo`040>>XJ03Pool0h?oo0>>X
J0<0h?oo0P3SZ6P40>3oo`040>>XJ03Pool0h?oo0>3oo`80hjQX0P3Pool30>>XJ080h?oo1P3SZ6QK
0>3oo`40oooo001Z0>3oo`@0hjQX00@0h?oo0>>XJ03Pool0hjQX0P3Pool20>>XJ0@0h?oo0P3SZ6P0
1@3Pool0hjQX0>3oo`3Pool0hjQX0080h?oo00D0hjQX0>3oo`3Pool0hjQX0>3oo`020>>XJ0<0h?oo
103SZ6P30>3oo`80hjQX103Pool20>>XJ0030>3oo`3SZ6P0hjQX0080h?oo00@0hjQX0>3oo`3SZ6P0
hjQX0P3Pool30>>XJ0030>3oo`3SZ6P0h?oo05/0h?oo0@3oool006/0h?oo0`3SZ6P0103Pool0hjQX
0>>XJ03SZ6P20>3oo`030>>XJ03Pool0hjQX00<0h?oo00<0hjQX0>3oo`3SZ6P0103Pool00`3SZ6P0
h?oo0>>XJ0020>3oo`030>>XJ03Pool0hjQX00<0h?oo00D0hjQX0>3oo`3Pool0h?oo0>>XJ0030>3o
o`030>>XJ03Pool0h?oo0080h?oo00@0hjQX0>3oo`3SZ6P0h?oo103SZ6P0103Pool0hjQX0>3oo`3S
Z6P20>3oo`<0hjQX00<0h?oo0>>XJ03Pool0F`3Pool10?ooo`00J`3Pool20>>XJ0040>3oo`3SZ6P0
hjQX0>3oo`80hjQX00@0h?oo0>>XJ03Pool0hjQX0`3Pool00`3SZ6P0h?oo0>>XJ0040>3oo`030>>X
J03Pool0h?oo0080hjQX00<0h?oo0>>XJ03SZ6P00`3Pool00`3SZ6P0h?oo0>3oo`020>3oo`@0hjQX
103Pool0103SZ6P0h?oo0>>XJ03Pool20>>XJ0<0h?oo0P3SZ6P20>3oo`80hjQX00<0h?oo0>>XJ03S
Z6P0G@3Pool10?ooo`00J`3Pool50>>XJ080h?oo00<0hjQX0>3oo`3SZ6P00P3Pool00`3SZ6P0h?oo
0>3oo`030>>XJ0@0h?oo00@0hjQX0>3oo`3Pool0h?oo0P3SZ6P00`3Pool0hjQX0>3oo`020>3oo`03
0>>XJ03Pool0h?oo0080h?oo00<0hjQX0>3oo`3SZ6P00P3SZ6P30>3oo`030>>XJ03Pool0hjQX00<0
hjQX0`3Pool20>>XJ080h?oo0P3SZ6P00`3Pool0hjQX0>>XJ01M0>3oo`40oooo001/0>3oo`80hjQX
00D0h?oo0>>XJ03SZ6P0h?oo0>>XJ0020>3oo`030>>XJ03Pool0hjQX0080h?oo0P3SZ6P00`3Pool0
hjQX0>3oo`020>3oo`040>>XJ03Pool0h?oo0>3oo`80hjQX0P3Pool0103SZ6P0h?oo0>3oo`3SZ6P4
0>3oo`030>>XJ03Pool0hjQX0080h?oo1@3SZ6P0103Pool0hjQX0>3oo`3SZ6P30>3oo`80hjQX0P3P
ool50>>XJ5d0h?oo0@3oool006`0h?oo0P3SZ6P00`3Pool0hjQX0>>XJ0020>3oo`030>>XJ03Pool0
hjQX0080h?oo00<0hjQX0>3oo`3SZ6P00P3Pool01@3SZ6P0h?oo0>3oo`3Pool0hjQX0080h?oo0`3S
Z6P20>3oo`030>>XJ03Pool0hjQX00D0h?oo00<0hjQX0>3oo`3SZ6P01@3Pool01P3SZ6P0h?oo0>3o
o`3SZ6P0h?oo0>>XJ080h?oo00@0hjQX0>3oo`3SZ6P0h?oo0P3SZ6P00`3Pool0hjQX0>>XJ01N0>3o
o`40oooo001/0>3oo`80hjQX00<0h?oo0>>XJ03SZ6P00P3Pool30>>XJ080h?oo00<0hjQX0>3oo`3S
Z6P00`3Pool0103SZ6P0h?oo0>3oo`3SZ6P20>3oo`080>>XJ03Pool0h?oo0>>XJ03Pool0hjQX0>3o
o`3SZ6P60>3oo`80hjQX1@3Pool00`3SZ6P0h?oo0>3oo`020>>XJ0<0h?oo00@0hjQX0>3oo`3SZ6P0
h?oo0P3SZ6P00`3Pool0hjQX0>>XJ01N0>3oo`40oooo001]0>3oo`80hjQX00L0h?oo0>>XJ03Pool0
h?oo0>>XJ03Pool0hjQX00<0h?oo0P3SZ6P30>3oo`040>>XJ03Pool0h?oo0>3oo`80hjQX0`3Pool0
1@3SZ6P0h?oo0>>XJ03Pool0hjQX00H0h?oo00<0hjQX0>3oo`3Pool00`3Pool01P3SZ6P0h?oo0>3o
o`3SZ6P0h?oo0>>XJ0<0h?oo00<0hjQX0>3oo`3SZ6P01P3SZ6QN0>3oo`40oooo001]0>3oo`80hjQX
00<0h?oo0>>XJ03Pool00P3Pool40>>XJ0040>3oo`3SZ6P0h?oo0>>XJ0<0h?oo00<0hjQX0>3oo`3P
ool00P3SZ6P40>3oo`80hjQX00<0h?oo0>>XJ03Pool01@3Pool00`3SZ6P0h?oo0>3oo`030>3oo`06
0>>XJ03Pool0h?oo0>>XJ03Pool0hjQX0P3Pool0103SZ6P0h?oo0>>XJ03Pool50>>XJ5l0h?oo0@3o
ool006d0h?oo103SZ6P30>3oo`80hjQX0P3Pool20>>XJ0030>3oo`3SZ6P0h?oo0080h?oo00<0hjQX
0>3oo`3SZ6P00P3SZ6P50>3oo`80hjQX1`3Pool00`3SZ6P0h?oo0>3oo`030>3oo`030>>XJ03Pool0
hjQX0080h?oo00D0hjQX0>3oo`3Pool0hjQX0>3oo`030>>XJ0040>3oo`3SZ6P0hjQX0>>XJ5l0h?oo
0@3oool006d0h?oo0`3SZ6P0103Pool0hjQX0>3oo`3Pool20>>XJ0030>3oo`3SZ6P0h?oo00<0hjQX
00<0h?oo0>>XJ03SZ6P00P3SZ6P00`3Pool0hjQX0>3oo`050>3oo`80hjQX1P3Pool20>>XJ0D0h?oo
00<0hjQX0>3oo`3SZ6P00P3Pool20>>XJ0030>3oo`3SZ6P0h?oo00<0hjQX00@0h?oo0>>XJ03SZ6P0
hjQXG`3Pool10?ooo`00KP3Pool40>>XJ0<0h?oo0P3SZ6P30>3oo`<0hjQX0`3Pool00`3SZ6P0h?oo
0>>XJ0070>3oo`030>>XJ03Pool0h?oo00@0h?oo00<0hjQX0>3oo`3SZ6P0103Pool00`3SZ6P0h?oo
0>>XJ0020>3oo`80hjQX00D0h?oo0>>XJ03Pool0hjQX0>3oo`040>>XJ600h?oo0@3oool006h0h?oo
1@3SZ6P0103Pool0hjQX0>>XJ03SZ6P30>3oo`80hjQX1@3Pool20>>XJ0L0h?oo0P3SZ6P40>3oo`80
hjQX00<0h?oo0>>XJ03Pool00P3Pool00`3SZ6P0h?oo0>>XJ0030>3oo`040>>XJ03Pool0hjQX0>3o
o`<0hjQX00@0h?oo0>>XJ03SZ6P0hjQXH03Pool10?ooo`00KP3Pool60>>XJ0030>3oo`3SZ6P0hjQX
00@0h?oo00<0hjQX0>3oo`3Pool00`3Pool00`3SZ6P0h?oo0>>XJ0050>3oo`80hjQX00<0h?oo0>>X
J03Pool00P3Pool20>>XJ0030>3oo`3SZ6P0h?oo0080h?oo00<0hjQX0>3oo`3SZ6P00`3Pool01@3S
Z6P0h?oo0>>XJ03SZ6P0h?oo0080hjQX00@0h?oo0>>XJ03SZ6P0hjQXH03Pool10?ooo`00K`3Pool4
0>>XJ0<0h?oo00<0hjQX0>3oo`3Pool00P3Pool20>>XJ0@0h?oo0`3SZ6P50>3oo`80hjQX0P3Pool4
0>>XJ080h?oo00@0hjQX0>3oo`3Pool0h?oo0P3SZ6P30>3oo`030>>XJ03Pool0h?oo00<0hjQX00<0
h?oo0>>XJ03Pool00P3SZ6QQ0>3oo`40oooo001_0>3oo`<0hjQX00D0h?oo0>>XJ03Pool0h?oo0>>X
J0040>3oo`80hjQX0`3Pool0103SZ6P0h?oo0>>XJ03SZ6P50>3oo`030>>XJ03Pool0hjQX00<0h?oo
0P3SZ6P20>3oo`040>>XJ03Pool0h?oo0>3oo`80hjQX0`3Pool0103SZ6P0h?oo0>>XJ03Pool20>>X
J0030>3oo`3SZ6P0hjQX0080hjQXH@3Pool10?ooo`00K`3Pool50>>XJ080h?oo00<0hjQX0>3oo`3P
ool00`3Pool01@3SZ6P0h?oo0>3oo`3Pool0hjQX0080h?oo00<0hjQX0>3oo`3Pool00`3Pool00`3S
Z6P0h?oo0>>XJ0030>3oo`80hjQX0`3Pool00`3SZ6P0h?oo0>3oo`020>>XJ0<0h?oo0`3SZ6P20>3o
o`H0hjQXH@3Pool10?ooo`00L03Pool40>>XJ080h?oo0P3SZ6P40>3oo`050>>XJ03Pool0h?oo0>3o
o`3SZ6P00P3Pool00`3SZ6P0h?oo0>3oo`020>3oo`040>>XJ03Pool0h?oo0>>XJ080h?oo00<0hjQX
0>3oo`3SZ6P00P3SZ6P00`3Pool0hjQX0>3oo`020>>XJ0<0h?oo0P3SZ6P0103Pool0hjQX0>3oo`3P
ool50>>XJ680h?oo0@3oool00700h?oo103SZ6P30>3oo`030>>XJ03Pool0h?oo0080h?oo0P3SZ6P0
0`3Pool0hjQX0>3oo`020>3oo`80hjQX0`3Pool0103SZ6P0h?oo0>3oo`3SZ6P20>3oo`030>>XJ03P
ool0hjQX0080h?oo0P3SZ6P00`3Pool0hjQX0>>XJ0030>>XJ0030>3oo`3SZ6P0hjQX0080h?oo00<0
hjQX0>3oo`3SZ6P00`3SZ6QR0>3oo`40oooo001`0>3oo`030>>XJ03Pool0hjQX0080hjQX0P3Pool2
0>>XJ0@0h?oo00<0hjQX0>3oo`3SZ6P00`3Pool00`3SZ6P0h?oo0>>XJ0020>3oo`080>>XJ03Pool0
h?oo0>>XJ03Pool0hjQX0>3oo`3SZ6P40>3oo`@0hjQX103Pool20>>XJ080h?oo0`3SZ6P00`3Pool0
hjQX0>3oo`1R0>3oo`40oooo001a0>3oo`@0hjQX0P3Pool20>>XJ0@0h?oo00<0hjQX0>3oo`3SZ6P0
103Pool20>>XJ080h?oo00@0hjQX0>3oo`3Pool0h?oo0P3SZ6P00`3Pool0hjQX0>3oo`030>3oo`03
0>>XJ03Pool0hjQX00@0h?oo00<0hjQX0>3oo`3SZ6P00P3Pool50>>XJ6<0h?oo0@3oool00740h?oo
103SZ6P20>3oo`80hjQX103Pool20>>XJ0D0h?oo00@0hjQX0>3oo`3SZ6P0hjQX103Pool0103SZ6P0
h?oo0>3oo`3SZ6P50>3oo`80hjQX103Pool00`3SZ6P0h?oo0>>XJ0020>3oo`80hjQX00<0h?oo0>>X
J03SZ6P0H`3Pool10?ooo`00LP3Pool20>>XJ0060>3oo`3SZ6P0h?oo0>>XJ03Pool0hjQX0`3Pool2
0>>XJ0D0h?oo00@0hjQX0>3oo`3SZ6P0hjQX103Pool0103SZ6P0h?oo0>3oo`3SZ6P50>3oo`030>>X
J03Pool0h?oo00<0h?oo0P3SZ6P30>3oo`80hjQX00<0h?oo0>>XJ03Pool0H`3Pool10?ooo`00LP3P
ool20>>XJ0060>3oo`3SZ6P0h?oo0>>XJ03Pool0hjQX0`3Pool20>>XJ0D0h?oo00@0hjQX0>3oo`3P
ool0hjQX0`3Pool20>>XJ080h?oo00<0hjQX0>3oo`3Pool00`3Pool00`3SZ6P0h?oo0>3oo`030>3o
o`80hjQX0P3Pool20>>XJ0030>3oo`3SZ6P0hjQX06@0h?oo0@3oool00780h?oo1@3SZ6P00`3Pool0
hjQX0>>XJ0030>3oo`030>>XJ03Pool0hjQX00@0h?oo00<0hjQX0>3oo`3Pool00P3SZ6P01P3Pool0
hjQX0>3oo`3SZ6P0h?oo0>>XJ0H0h?oo00<0hjQX0>3oo`3Pool00`3Pool20>>XJ080h?oo0P3SZ6P0
0`3Pool0hjQX0>>XJ01T0>3oo`40oooo001c0>3oo`80hjQX00T0h?oo0>>XJ03SZ6P0hjQX0>3oo`3S
Z6P0h?oo0>>XJ03Pool00P3SZ6P40>3oo`040>>XJ03Pool0hjQX0>3oo`80hjQX0`3Pool20>>XJ0D0
h?oo0`3SZ6P30>3oo`80hjQX0`3Pool20>>XJ0030>3oo`3SZ6P0h?oo06@0h?oo0@3oool007<0h?oo
0P3SZ6P0303Pool0hjQX0>>XJ03SZ6P0h?oo0>>XJ03Pool0hjQX0>3oo`3SZ6P0h?oo0>>XJ0<0h?oo
00@0hjQX0>3oo`3SZ6P0h?oo0P3SZ6P30>3oo`80hjQX1@3Pool30>>XJ0<0h?oo0P3SZ6P20>3oo`80
hjQX0P3Pool00`3SZ6P0h?oo0>3oo`1S0>3oo`40oooo001d0>3oo`<0hjQX00D0h?oo0>>XJ03Pool0
h?oo0>>XJ0020>3oo`030>>XJ03Pool0hjQX00@0h?oo0P3SZ6P0103Pool0hjQX0>3oo`3SZ6P20>3o
o`80hjQX103Pool20>>XJ080h?oo00<0hjQX0>3oo`3Pool00P3SZ6P01@3Pool0hjQX0>3oo`3SZ6P0
h?oo0080hjQXI@3Pool10?ooo`00M03Pool30>>XJ0030>3oo`3SZ6P0hjQX0080hjQX0P3Pool0103S
Z6P0h?oo0>3oo`3SZ6P30>3oo`<0hjQX0`3Pool0103SZ6P0h?oo0>>XJ03SZ6P40>3oo`80hjQX0P3P
ool01`3SZ6P0h?oo0>3oo`3SZ6P0h?oo0>>XJ03Pool00P3SZ6P00`3Pool0hjQX0>3oo`1U0>3oo`40
oooo001d0>3oo`P0hjQX0P3Pool0103SZ6P0h?oo0>3oo`3SZ6P30>3oo`80hjQX103Pool00`3SZ6P0
h?oo0>>XJ0050>3oo`80hjQX0P3Pool0203SZ6P0h?oo0>3oo`3SZ6P0h?oo0>>XJ03Pool0hjQX0P3P
ool00`3SZ6P0h?oo0>3oo`1T0>3oo`40oooo001e0>3oo`030>>XJ03Pool0hjQX0080hjQX0P3Pool0
103SZ6P0h?oo0>3oo`3SZ6P20>3oo`040>>XJ03Pool0hjQX0>>XJ0H0h?oo0P3SZ6P40>3oo`030>>X
J03Pool0hjQX00<0h?oo103SZ6P20>3oo`030>>XJ03Pool0hjQX06L0h?oo0@3oool007D0h?oo0`3S
Z6P0103Pool0hjQX0>3oo`3Pool40>>XJ0060>3oo`3SZ6P0hjQX0>>XJ03Pool0hjQX1`3Pool20>>X
J0<0h?oo00<0hjQX0>3oo`3SZ6P00`3Pool30>>XJ0<0h?oo00<0hjQX0>3oo`3SZ6P0I`3Pool10?oo
o`00MP3Pool0103SZ6P0h?oo0>>XJ03SZ6P20>3oo`030>>XJ03Pool0h?oo0080hjQX0P3Pool00`3S
Z6P0h?oo0>>XJ0070>3oo`<0hjQX00@0h?oo0>>XJ03Pool0hjQX103Pool20>>XJ0<0h?oo00@0hjQX
0>3oo`3SZ6P0hjQXI`3Pool10?ooo`00MP3Pool0103SZ6P0h?oo0>>XJ03SZ6P30>3oo`030>>XJ03P
ool0hjQX00<0h?oo0P3SZ6P00`3Pool0hjQX0>3oo`050>3oo`80hjQX00H0h?oo0>>XJ03SZ6P0h?oo
0>>XJ03Pool30>>XJ0030>3oo`3SZ6P0h?oo0080h?oo00<0hjQX0>3oo`3SZ6P0J03Pool10?ooo`00
MP3Pool20>>XJ0030>3oo`3SZ6P0hjQX0080h?oo00<0hjQX0>3oo`3SZ6P0103Pool00`3SZ6P0h?oo
0>>XJ0050>3oo`030>>XJ03Pool0hjQX0080h?oo103SZ6P40>3oo`80hjQX0P3Pool30>>XJ6P0h?oo
0@3oool007L0h?oo00@0hjQX0>3oo`3SZ6P0hjQX0P3Pool0103SZ6P0h?oo0>3oo`3SZ6P20>3oo`04
0>>XJ03Pool0hjQX0>>XJ0D0h?oo00D0hjQX0>3oo`3SZ6P0h?oo0>>XJ0020>3oo`030>>XJ03Pool0
h?oo0080h?oo00<0hjQX0>3oo`3SZ6P00P3Pool30>>XJ6P0h?oo0@3oool007L0h?oo103SZ6P30>3o
o`030>>XJ03Pool0hjQX0080h?oo00@0hjQX0>3oo`3SZ6P0hjQX1@3Pool00`3SZ6P0h?oo0>3oo`02
0>>XJ080h?oo00<0hjQX0>3oo`3Pool00P3Pool00`3SZ6P0h?oo0>3oo`040>>XJ6T0h?oo0@3oool0
07L0h?oo0P3SZ6P00`3Pool0hjQX0>3oo`020>3oo`050>>XJ03Pool0hjQX0>3oo`3SZ6P00`3Pool2
0>>XJ0@0h?oo00@0hjQX0>3oo`3Pool0hjQX0P3Pool00`3SZ6P0h?oo0>3oo`020>3oo`80hjQX0`3P
ool30>>XJ6T0h?oo0@3oool007P0h?oo103SZ6P30>3oo`80hjQX00<0h?oo0>>XJ03Pool00P3Pool2
0>>XJ0<0h?oo00D0hjQX0>3oo`3Pool0h?oo0>>XJ0020>3oo`030>>XJ03Pool0h?oo0080h?oo0P3S
Z6P30>3oo`80hjQXJP3Pool10?ooo`00N03Pool20>>XJ0030>3oo`3SZ6P0h?oo0080h?oo0`3SZ6P5
0>3oo`050>>XJ03Pool0h?oo0>3oo`3SZ6P00P3Pool20>>XJ080h?oo00<0hjQX0>3oo`3Pool00P3P
ool20>>XJ080h?oo0`3SZ6QZ0>3oo`40oooo001h0>3oo`040>>XJ03Pool0hjQX0>>XJ0<0h?oo0`3S
Z6P50>3oo`80hjQX0P3Pool0203SZ6P0h?oo0>3oo`3SZ6P0h?oo0>>XJ03Pool0hjQX0`3Pool20>>X
J0<0h?oo0P3SZ6Q[0>3oo`40oooo001i0>3oo`<0hjQX103Pool20>>XJ0D0h?oo0P3SZ6P20>3oo`03
0>>XJ03Pool0hjQX0080h?oo0P3SZ6P40>3oo`80hjQX0P3Pool30>>XJ6/0h?oo0@3oool007T0h?oo
00@0hjQX0>3oo`3SZ6P0hjQX0`3Pool20>>XJ0H0h?oo0`3SZ6P20>3oo`030>>XJ03Pool0h?oo0080
hjQX103Pool20>>XJ080h?oo0`3SZ6Q[0>3oo`40oooo001i0>3oo`@0hjQX0P3Pool30>>XJ0H0h?oo
0`3SZ6P00`3Pool0hjQX0>3oo`030>3oo`080>>XJ03Pool0h?oo0>3oo`3SZ6P0h?oo0>>XJ03Pool3
0>>XJ6`0h?oo0@3oool007X0h?oo1@3SZ6P20>3oo`030>>XJ03Pool0h?oo00@0h?oo00@0hjQX0>3o
o`3SZ6P0hjQX1@3Pool01P3SZ6P0h?oo0>3oo`3Pool0hjQX0>3oo`D0hjQXK03Pool10?ooo`00NP3P
ool0103SZ6P0h?oo0>>XJ03SZ6P30>3oo`030>>XJ03Pool0h?oo00@0h?oo00<0hjQX0>3oo`3SZ6P0
0P3SZ6P40>3oo`80hjQX00<0h?oo0>>XJ03Pool00P3SZ6P00`3Pool0hjQX0>>XJ01]0>3oo`40oooo
001k0>3oo`040>>XJ03Pool0hjQX0>>XJ080h?oo0P3SZ6P60>3oo`80hjQX0P3Pool02@3SZ6P0h?oo
0>3oo`3SZ6P0h?oo0>>XJ03Pool0hjQX0>3oo`030>>XJ0030>3oo`3SZ6P0h?oo06`0h?oo0@3oool0
07/0h?oo00<0hjQX0>3oo`3SZ6P00`3SZ6P00`3Pool0hjQX0>3oo`050>3oo`80hjQX0`3Pool30>>X
J0030>3oo`3SZ6P0h?oo00<0hjQX00<0h?oo0>>XJ03SZ6P0KP3Pool10?ooo`00O03Pool30>>XJ080
h?oo0`3SZ6P20>3oo`@0hjQX1P3Pool40>>XJ080h?oo00@0hjQX0>3oo`3SZ6P0hjQXKP3Pool10?oo
o`00O03Pool20>>XJ0040>3oo`3SZ6P0h?oo0>3oo`@0hjQX0P3Pool20>>XJ0H0h?oo00L0hjQX0>3o
o`3Pool0hjQX0>3oo`3SZ6P0h?oo0080hjQXK`3Pool10?ooo`00O@3Pool30>>XJ080h?oo00<0hjQX
0>3oo`3SZ6P00`3Pool00`3SZ6P0h?oo0>>XJ0040>3oo`050>>XJ03Pool0h?oo0>>XJ03Pool00P3S
Z6P00`3Pool0hjQX0>>XJ01_0>3oo`40oooo001m0>3oo`80hjQX00@0h?oo0>>XJ03Pool0h?oo0P3S
Z6P20>3oo`040>>XJ03Pool0h?oo0>>XJ0@0h?oo00@0hjQX0>3oo`3Pool0hjQX0P3Pool30>>XJ700
h?oo0@3oool007h0h?oo00<0hjQX0>3oo`3SZ6P00P3Pool01@3SZ6P0h?oo0>>XJ03Pool0hjQX0080
h?oo00<0hjQX0>3oo`3Pool00P3Pool00`3SZ6P0h?oo0>>XJ0020>3oo`030>>XJ03Pool0hjQX0740
h?oo0@3oool007h0h?oo0P3SZ6P01@3Pool0hjQX0>3oo`3SZ6P0h?oo0080hjQX0`3Pool00`3SZ6P0
h?oo0>3oo`020>3oo`80hjQX0`3Pool30>>XJ740h?oo0@3oool007l0h?oo00<0hjQX0>3oo`3SZ6P0
0P3Pool00`3SZ6P0h?oo0>>XJ0040>3oo`030>>XJ03Pool0h?oo0080hjQX103Pool20>>XJ780h?oo
0@3oool00800h?oo00@0hjQX0>3oo`3SZ6P0h?oo0P3SZ6P00`3Pool0hjQX0>>XJ0020>3oo`030>>X
J03Pool0h?oo0080hjQX103Pool00`3SZ6P0h?oo0>3oo`1a0>3oo`40oooo00210>3oo`80hjQX00<0
h?oo0>>XJ03SZ6P00`3Pool00`3SZ6P0h?oo0>>XJ0020>3oo`030>>XJ03Pool0h?oo0080h?oo0P3S
Z6Qc0>3oo`40oooo00220>3oo`@0hjQX103Pool20>>XJ0030>3oo`3SZ6P0hjQX00<0h?oo0P3SZ6Qd
0>3oo`40oooo00230>3oo`<0hjQX1@3Pool30>>XJ0030>3oo`3SZ6P0hjQX0080hjQXM@3Pool10?oo
o`00Q03Pool30>>XJ0<0h?oo1@3SZ6P30>3oo`030>>XJ03Pool0h?oo07<0h?oo0@3oool008D0h?oo
1@3SZ6P20>3oo`80hjQX0`3Pool00`3SZ6P0h?oo0>3oo`1d0>3oo`40oooo00260>3oo`80hjQX0`3P
ool00`3SZ6P0h?oo0>3oo`020>>XJ0030>3oo`3SZ6P0h?oo07D0h?oo0@3oool008P0h?oo00<0hjQX
0>3oo`3SZ6P00P3Pool40>>XJ7L0h?oo0@3oool008T0h?oo103SZ6Qk0>3oo`40oooo003o0>3oo`T0
h?oo0@3oool00?l0h?oo2@3Pool10?ooo`00o`3Pool90>3oo`40oooo003o0>3oo`T0h?oo0@3oool0
0?l0h?oo2@3Pool10?ooo`00o`3Pool90>3oo`40oooo003o0>3oo`T0h?oo0@3oool00?l0h?oo2@3P
ool10?ooo`00o`3Pool90>3oo`40oooo003o0>3oo`T0h?oo0@3oool00?l0h?oo2@3Pool10?ooo`00
o`3Pool90>3oo`40oooo003o0>3oo`T0h?oo0@3oool00?l0h?oo2@3Pool10?ooo`00o`3Pool90>3o
o`40oooo003o0>3oo`T0h?oo0@3oool00?l0h?oo2@3Pool10?ooo`00o`3Pool90>3oo`40oooo003o
0>3oo`T0h?oo0@3oool00?l0h?oo2@3Pool10?ooo`00o`3Pool90>3oo`40oooo003o0>3oo`T0h?oo
0@3oool00?l0h?oo2@3Pool10?ooo`00o`3Pool90>3oo`40oooo003o0>3oo`T0h?oo0@3oool00?l0
h?oo2@3Pool10?ooo`00o`3Pool90>3oo`40oooo003o0>3oo`T0h?oo0@3oool00?l0h?oo2@3Pool1
0?ooo`00o`3Pool90>3oo`40oooo003o0>3oo`T0h?oo0@3oool00?l0h?oo2@3Pool10?ooo`00o`3P
ool90>3oo`40oooo003o0>3oo`T0h?oo0@3oool00?l0h?oo2@3Pool10?ooo`00o`3Pool90>3oo`40
oooo003o0>3oo`T0h?oo0@3oool00?l0h?oo2@3Pool10?ooo`00o`3Pool90>3oo`40oooo003o0>3o
o`T0h?oo0@3oool00?l0h?oo2@3Pool10?ooo`00o`3Pool90>3oo`40oooo003o0>3oo`T0h?oo0@3o
ool00?l0h?oo2@3Pool10?ooo`00o`3Pool90>3oo`40oooo003o0>3oo`T0h?oo0@3oool00?l0h?oo
2@3Pool10?ooo`00o`3Pool90>3oo`40oooo003o0>3oo`T0h?oo0@3oool00?l0h?oo2@3Pool10?oo
o`00o`3Pool90>3oo`40oooo003o0>3oo`T0h?oo0@3oool00?l0h?oo2@3Pool10?ooo`00o`3Pool9
0>3oo`40oooo003o0>3oo`T0h?oo0@3oool00?l0h?oo2@3Pool10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 264.313}, {286.938, 0}} -> {0.0486402, \
-4.72903*^-05, 0.00324458, 0.00324458}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->{},
WindowSize->{528, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 61, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1840, 56, 369, 13, 50, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 622615, 21564}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 61, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1840, 56, 369, 13, 50, "Usage",
  CellTags->"Function?"],
Cell[2212, 71, 52, 0, 41, "MathCaption"],
Cell[2267, 73, 197, 4, 58, "MathCaption"],
Cell[2467, 79, 160, 6, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[2652, 89, 34, 0, 39, "ExampleSection"],
Cell[2689, 91, 168, 3, 49, "Input"],
Cell[2860, 96, 168, 3, 42, "Text"],

Cell[CellGroupData[{
Cell[3053, 103, 262, 4, 89, "Input"],
Cell[3318, 109, 64697, 1405, 294, 11723, 746, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[68030, 1517, 51, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[68106, 1521, 383, 6, 136, "Input"],
Cell[68492, 1529, 328455, 12050, 294, 191885, 10359, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[396962, 13582, 475, 7, 93, "Text"],

Cell[CellGroupData[{
Cell[397462, 13593, 1045, 18, 316, "Input"],
Cell[398510, 13613, 223414, 7929, 294, 131617, 6791, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

