(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5078,        173]*)
(*NotebookOutlinePosition[      6067,        208]*)
(*  CellTagsIndexPosition[      5993,        202]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawIndexedPoints", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["DrawIndexedPoints",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(pointlist, offset : {\(-1\), \(-1\)}\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will plot a list of points and label then with their index in the list. \
The labels are placed with the given offset."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
The purpose of DrawIndexedPoints is to label the points so that the point \
list can be easily edited.\
\>", "MathCaption"],

Cell[TextData[{
  "A pointlist can be edited with the following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands: \n",
  Cell[BoxData[
      \(pointlist = ReplacePart[pointlist, newpoint, index]\)]],
  " \n",
  Cell[BoxData[
      \(pointlist = Insert[pointlist, newpoint, index]\)]],
  " \n",
  Cell[BoxData[
      \(pointlist = Delete[pointlist, index]\)]]
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Spline",
    ButtonData:>{"Graphics`Spline`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["SplineToLine",
    ButtonData:>{"SplineToLine"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example ", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
The following points were clicked off a blank piece of drawing paper in an \
effort to draw a smooth spline curve.\
\>", "Text"],

Cell[BoxData[
    \(\(pts = {{\(-7.2823\), \(-5.85372\)}, {\(-5.33106\), \(-5.43559\)}, \
{\(-3.65857\), \(-3.90248\)}, {\(-2.19514\), \(-1.67249\)}, {\(-1.08015\), 
            1.53312}, {0.731714, 2.64811}, {2.47389, 4.8781}, {4.0767, 
            6.06278}, {6.16731, 6.62027}};\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(Show[
        Graphics[\n\t{Spline[pts, 
              Cubic], \[IndentingNewLine]DrawIndexedPoints[pts]}], \n\n
        AspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] {{\(-10\), 10}, {\(-10\), 10}}, 
        Background \[Rule] Linen, \n{}];\)\)], "Input",
  CellLabel->"In[3]:=",
  GeneratedCell->False],

Cell["\<\
Point 5 is not where I wish, so I click off a replacement point from the plot \
and edit the point list.\
\>", "Text"],

Cell[BoxData[
    \(\(pts = ReplacePart[pts, {\(-0.452967\), 1.11499}, 5];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["Now the curve is smoother.", "Text"],

Cell[BoxData[
    \(\(Show[
        Graphics[\n\t{Spline[pts, 
              Cubic], \[IndentingNewLine]DrawIndexedPoints[pts]}], \n\n
        AspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] {{\(-10\), 10}, {\(-10\), 10}}, 
        Background \[Rule] Linen, \n{}];\)\)], "Input",
  CellLabel->"In[5]:=",
  GeneratedCell->False],

Cell["\<\
In actual practice you can just keep reevaluating the original Show statement \
until you obtain an acceptable set of points. Then delete the \
DrawIndexedPoints statement.\
\>", "Text"],

Cell[BoxData[
    \(Clear[pts]\)], "Input",
  CellLabel->"In[6]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{571, 730},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 64, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1843, 56, 451, 15, 50, "Usage",
      CellTags->"Function?"],
    Cell[2297, 73, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5747, 191}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 64, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1843, 56, 451, 15, 50, "Usage",
  CellTags->"Function?"],
Cell[2297, 73, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2394, 78, 133, 3, 58, "MathCaption"],
Cell[2530, 83, 396, 13, 112, "MathCaption"],
Cell[2929, 98, 258, 10, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3212, 112, 34, 0, 39, "ExampleSection"],
Cell[3249, 114, 97, 2, 29, "Input"],
Cell[3349, 118, 138, 3, 25, "Text"],
Cell[3490, 123, 319, 5, 69, "Input"],
Cell[3812, 130, 337, 8, 149, "Input"],
Cell[4152, 140, 128, 3, 25, "Text"],
Cell[4283, 145, 113, 2, 29, "Input"],
Cell[4399, 149, 42, 0, 25, "Text"],
Cell[4444, 151, 337, 8, 149, "Input"],
Cell[4784, 161, 196, 4, 42, "Text"],
Cell[4983, 167, 67, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

