(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7941,        241]*)
(*NotebookOutlinePosition[      8837,        273]*)
(*  CellTagsIndexPosition[      8763,        267]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawLineLabels", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["DrawLineLabels",
            "MR"], 
          StyleBox["[",
            "MR"], \(function, \ position, \ options\), "]"}], "[", 
        "graphics", "]"}]]],
  " will label the Lines in the graphics expression according to function."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
function should be a function name or pure function of two variables, x and \
y, corresponding to the plot coordinates. function should be a constant on \
any given Line and determines the value of the label.\
\>", "MathCaption"],

Cell[TextData[{
  "position should be a pure function that generates a number between 0 and 1 \
when applied to a Line value. It specifies the fractional number of plot \
points along the line for the label placement. If the fractional number is \
less than 0 or greater than 1 it is reset to 0.5.  ",
  Cell[BoxData[
      \(0.5 &\)]],
  " will place the label at roughly the midpoint of each Line independent of \
the Line value. ",
  Cell[BoxData[
      \(Random[] &\)]],
  " will place the labels randomly."
}], "MathCaption"],

Cell[TextData[{
  "The options are ",
  Cell[BoxData[
      \(DrawLLFormat\)]],
  " and ",
  Cell[BoxData[
      \(DrawLLTextOptions\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  Cell[BoxData[
      \(DrawLLFormat\)]],
  " supplies a formatting function for the value of the Line label. Its \
default value is ",
  Cell[BoxData[
      \(\((NumberForm[#, 2] &)\)\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  Cell[BoxData[
      \(DrawLLTextOptions\)]],
  " supplies options to the Text statements which display the label values. \
See ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  ". "
}], "MathCaption"],

Cell[TextData[{
  Cell[BoxData[
      \(DrawLineLabels\)]],
  " can be used to label any set of Lines which have an associated function \
constant on each Line. Its most common application may be in ContourPlots."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Here is a family of curves. Each curve is associated with a constant value c.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[2  x\^2 + 3  y \[Equal] c, y]\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \({{y \[Rule] 1\/3\ \((c - 2\ x\^2)\)}}\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["\<\
In the following, g is the set of Line primitives for 5 lines with various \
values of c. We draw the lines and then use DrawLineLabels on them.\
\>", "Text"],

Cell[BoxData[
    \(\(With[\[IndentingNewLine]{g = {\(Draw[
                    1\/3\ \((# - 2\ x\^2)\), {x, 0, 5}] &\) /@ 
                Range[0, 40, 
                  10]}}, \[IndentingNewLine]Draw2D[\[IndentingNewLine]{g, \
\[IndentingNewLine]g // 
              DrawLineLabels[2  #1\^2 + 3  #2 &, 
                0.7 &, \[IndentingNewLine]DrawLLFormat \[Rule] \((Round)\), 
                DrawLLTextOptions \[Rule] {Background \[Rule] 
                      White}]}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
              y}]];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[TextData[{
  "We can stagger the labels along the lines by designing a position function \
that puts ",
  Cell[BoxData[
      \(0\)]],
  " at a fraction of 0.4 along the line and puts ",
  Cell[BoxData[
      \(40\)]],
  " at a fraction of 0.95 along the line. There were many points concentrated \
at the beginning of the lines."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[{0\ a + b \[Equal] 0.4, 40  a + b \[Equal] 0.95}]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({{b \[Rule] 0.4`, a \[Rule] 0.013749999999999998`}}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[BoxData[
    \(\(With[\[IndentingNewLine]{g = {\(Draw[
                    1\/3\ \((# - 2\ x\^2)\), {x, 0, 5}] &\) /@ 
                Range[0, 40, 
                  10]}}, \[IndentingNewLine]Draw2D[\[IndentingNewLine]{g, \
\[IndentingNewLine]g // 
              DrawLineLabels[2  #1\^2 + 3  #2 &, 
                0.01375  # + 
                    0.4 &, \[IndentingNewLine]DrawLLFormat \[Rule] \
\((Round)\), DrawLLTextOptions \[Rule] {Background \[Rule] 
                      White}]}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
              y}, \[IndentingNewLine]PlotRange \[Rule] All]];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell["\<\
The following labels contours in a ContourPlot. The numbers were rounded to \
obtain a nice display for the zero contour.\
\>", "Text"],

Cell[BoxData[
    \(\(Module[\[IndentingNewLine]{g, contourlist, 
          f}, \[IndentingNewLine]contourlist = 
          Range[\(-1\), 1, 0.2]; \[IndentingNewLine]f[x_, 
            y_] := \(x\^2\) Cos[y] + \(y\^2\) Sin[x]; \[IndentingNewLine]g = 
          ContourDraw[f[x, y], {x, \(-1\), 1}, {y, \(-1\), 1}, 
            Contours \[Rule] contourlist, ColorFunction \[Rule] Hue, 
            PlotPoints \[Rule] 
              30]; \[IndentingNewLine]Draw2D[\[IndentingNewLine]{g, \
\[IndentingNewLine]g // 
              DrawLineLabels[f, 
                Random[Real, {0.1, 
                      0.9}] &, \[IndentingNewLine]DrawLLFormat \[Rule] \
\((NumberForm[N[Round[10  #]/10], 
                        1] &)\), \[IndentingNewLine]DrawLLTextOptions \[Rule] \
{Background \[Rule] Gold, 
                    TextStyle \[Rule] {FontSize \[Rule] 10, \ 
                        FontFamily \[Rule] "\<Helvetica\>"}}]}, \
\[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
              y}, \[IndentingNewLine]PlotLabel \[Rule] 
            f[x, y], \[IndentingNewLine]Background \[Rule] 
            Linen, \[IndentingNewLine]ImageSize \[Rule] 400]];\)\)], "Input",
  CellLabel->"In[6]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{563, 725},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 61, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1840, 56, 383, 12, 50, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 8592, 258}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 61, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1840, 56, 383, 12, 50, "Usage",
  CellTags->"Function?"],
Cell[2226, 70, 239, 4, 75, "MathCaption"],
Cell[2468, 76, 530, 12, 109, "MathCaption"],
Cell[3001, 90, 162, 8, 41, "MathCaption"],
Cell[3166, 100, 230, 8, 58, "MathCaption"],
Cell[3399, 110, 227, 8, 58, "MathCaption"],
Cell[3629, 120, 232, 5, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3886, 129, 34, 0, 39, "ExampleSection"],
Cell[3923, 131, 97, 2, 29, "Input"],
Cell[4023, 135, 103, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[4151, 142, 92, 2, 30, "Input"],
Cell[4246, 146, 95, 2, 36, "Output"]
}, Open  ]],
Cell[4356, 151, 168, 3, 42, "Text"],
Cell[4527, 156, 630, 12, 209, "Input"],
Cell[5160, 170, 347, 10, 59, "Text"],

Cell[CellGroupData[{
Cell[5532, 184, 112, 2, 29, "Input"],
Cell[5647, 188, 109, 2, 23, "Output"]
}, Open  ]],
Cell[5771, 193, 691, 13, 229, "Input"],
Cell[6465, 208, 145, 3, 42, "Text"],
Cell[6613, 213, 1300, 24, 371, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

