(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6331,        187]*)
(*NotebookOutlinePosition[      7320,        222]*)
(*  CellTagsIndexPosition[      7246,        216]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawListSurfaceOfRevolution", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{"DrawListSurfaceOfRevolution", 
        StyleBox["[",
          "MR"], 
        StyleBox[\(pts, {t, tmin, tmax}, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " extracts the graphics primitives from the corresponding \
ListSurfaceOfRevolution statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as ListSurfaceOfRevolution. Regular ListSurfaceOfRevolution \
options may be used. Basic Graphics3D options, such as PlotRange have no \
effect.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Draw3D",
    ButtonData:>{"Draw3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ParametricDraw3D",
    ButtonData:>{"ParametricDraw3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DrawSurfaceOfRevolution",
    ButtonData:>{"DrawSurfaceOfRevolution"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["ListSurfaceOfRevolution",
    ButtonData:>{"Graphics`SurfaceOfRevolution`", "1.12"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Let's go to pottery school. We can use the SplineDrawing routines to design a \
smooth set of points for the inner and outer surfaces of a vase. Then we can \
use the two point sets in DrawListSurfaceOf Revolution. First, I clicked off \
these points and made the last points the same for the inner and outer \
surfaces.\
\>", "Text"],

Cell[BoxData[{
    \(\(outerpoints = {{0.0217495, 0.0735042}, {0.849825, 
            0.114908}, {1.96773, 0.321927}, {3.04422, 0.942983}, {3.8309, 
            1.85387}, {4.12072, 3.09598}, {3.62388, 4.4623}, {3.16843, 
            5.66301}, {3.37545, 6.6567}, {3.8309, 
            7.60899}};\)\), "\[IndentingNewLine]", 
    \(\(innerpoints = {{0.0217495, 0.860176}, {0.891228, 0.901579}, {1.84351, 
            1.15}, {2.58878, 1.64685}, {3.25124, 2.39211}, {3.58247, 
            3.303}, {3.25124, 4.08967}, {2.8372, 5.12476}, {2.67159, 
            6.07705}, {2.92001, 7.02934}, {3.37545, 7.44337}, {3.8309, 
            7.60899}};\)\)}], "Input",
  CellLabel->"In[2]:=",
  GeneratedCell->False],

Cell["Then I made this one adjustment.", "Text"],

Cell[BoxData[
    \(\(innerpoints = 
        ReplacePart[innerpoints, {2.9766, 6.95117}, 10];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["This show our 2D cross section.", "Text"],

Cell[BoxData[
    \(\(Show[
        Graphics[\n\t{DrawIndexedPoints[
              outerpoints], \[IndentingNewLine]DrawIndexedPoints[
              innerpoints], \[IndentingNewLine]SplineToLine[innerpoints, 
              Cubic, 30], \[IndentingNewLine]SplineToLine[outerpoints, Cubic, 
              30]}], \n\nAspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] {{\(-1\), 10}, {\(-1\), 10}}, 
        Background \[Rule] Linen, \n{Frame \[Rule] True, 
          Axes \[Rule] True}];\)\)], "Input",
  CellLabel->"In[5]:=",
  GeneratedCell->False],

Cell["Now we extract the point lists...", "Text"],

Cell[BoxData[{
    \(\(inpts = 
        SplineToLine[innerpoints, Cubic, 60] // 
          First;\)\), "\[IndentingNewLine]", 
    \(\(outpts = SplineToLine[outerpoints, Cubic, 60] // First;\)\)}], "Input",\

  CellLabel->"In[6]:="],

Cell["...and use them in the 3D plot.", "Text"],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{EdgeForm[], 
          SurfaceColor[Carrot, LightBeige, 
            2], \[IndentingNewLine]DrawListSurfaceOfRevolution[outpts, 
            PlotPoints \[Rule] 100], \[IndentingNewLine]SurfaceColor[Black, 
            Green, 3], \[IndentingNewLine]DrawListSurfaceOfRevolution[inpts, 
            PlotPoints \[Rule] 100]}, \[IndentingNewLine]Boxed \[Rule] 
          False, \[IndentingNewLine]NeutralLighting[0.3, 0.4, 
          0.0], \[IndentingNewLine]ViewPoint -> {1.354, \ \(-2.922\), \ 
            1.040}, \[IndentingNewLine]Background \[Rule] 
          RoyalBlue, \[IndentingNewLine]PlotRegion \[Rule] {{0, 
              0.95}, {\(-0.1\), 0.9}}, \[IndentingNewLine]ImageSize \[Rule] 
          400];\)\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(Clear[innerpoints, outerpoints, inpts, outpts]\)], "Input",
  CellLabel->"In[9]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{576, 731},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 74, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1853, 56, 395, 13, 50, "Usage",
      CellTags->"Function?"],
    Cell[2251, 71, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7000, 205}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 74, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1853, 56, 395, 13, 50, "Usage",
  CellTags->"Function?"],
Cell[2251, 71, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2348, 76, 193, 4, 58, "MathCaption"],
Cell[2544, 82, 511, 18, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3080, 104, 33, 0, 39, "ExampleSection"],
Cell[3116, 106, 97, 2, 29, "Input"],
Cell[3216, 110, 344, 6, 59, "Text"],
Cell[3563, 118, 701, 12, 189, "Input"],
Cell[4267, 132, 48, 0, 25, "Text"],
Cell[4318, 134, 132, 3, 29, "Input"],
Cell[4453, 139, 47, 0, 25, "Text"],
Cell[4503, 141, 553, 11, 189, "Input"],
Cell[5059, 154, 49, 0, 25, "Text"],
Cell[5111, 156, 232, 6, 49, "Input"],
Cell[5346, 164, 47, 0, 25, "Text"],
Cell[5396, 166, 801, 13, 229, "Input"],
Cell[6200, 181, 103, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

