(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5489,        172]*)
(*NotebookOutlinePosition[      6478,        207]*)
(*  CellTagsIndexPosition[      6404,        201]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawPolarMap", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["DrawPolarMap",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(f, {r0 : 0, 
            r1, \ \((dr)\)}, {\[Phi]0, \[Phi]1, \((d\[Phi])\)}, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " extracts the graphics primitives from the corresponding PolarMap \
statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as PolarMap. Regular PolarMap options may be used. Basic \
Graphics options, such as PlotRange have no effect.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawCartesianMap",
    ButtonData:>{"DrawCartesianMap"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PolarMap",
    ButtonData:>{"Graphics`ComplexMap`", "1.3"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "The following two plots show how the complex map ",
  Cell[BoxData[
      \(z\^2\)]],
  " maps a half disk into a larger full circle."
}], "Text"],

Cell[BoxData[
    \(\(f = Function[z, z\^2];\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(plot1 = \[IndentingNewLine]DontShow[\[IndentingNewLine]Graphics[\
\[IndentingNewLine]{GrayLevel[0.9], 
              DrawPolarMap[
                Identity, {0, 2, 1/8}, {\[Pi], 2  \[Pi], \[Pi]/16}], 
              DrawPolarMap[
                Identity, {2, 4, 1/8}, {0, 
                  2  \[Pi], \[Pi]/16}], \[IndentingNewLine]AlizarinCrimson, 
              DrawPolarMap[
                Identity, {0, 2, 
                  1/8}, {0, \[Pi]/4, \[Pi]/
                    32}], \[IndentingNewLine]MediumBlue, 
              DrawPolarMap[
                Identity, {0, 2, 
                  1/8}, {\[Pi]/4, \[Pi], \[Pi]/
                    16}]}], \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]PlotRange \[Rule] 
            Automatic, \[IndentingNewLine]PlotLabel \[Rule] 
            z, \[IndentingNewLine]Background \[Rule] AliceBlue];\)\)], "Input",\

  CellLabel->"In[3]:="],

Cell[BoxData[
    \(\(plot2 = \[IndentingNewLine]DontShow[\[IndentingNewLine]Graphics[\
\[IndentingNewLine]{AlizarinCrimson, 
              DrawPolarMap[
                f, {0, 2, 
                  1/8}, {0, \[Pi]/4, \[Pi]/
                    32}], \[IndentingNewLine]MediumBlue, 
              DrawPolarMap[
                f, {0, 2, 
                  1/8}, {\[Pi]/4, \[Pi], \[Pi]/
                    16}]}], \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]PlotRange \[Rule] 
            Automatic, \[IndentingNewLine]PlotLabel \[Rule] 
            f[z], \[IndentingNewLine]Background \[Rule] 
            AliceBlue];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{plot1, 
            plot2}], \[IndentingNewLine]ImageSize \[Rule] {600, 
            320}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<f: z \
\[RightTeeArrow] \!\(z\^2\)\>\"", \[IndentingNewLine]Background \[Rule] 
          DarkSeaGreen, \[IndentingNewLine]PlotRegion \[Rule] {{0, 1}, {0.05, 
              0.98}}];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(Clear[f]\)], "Input",
  CellLabel->"In[6]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{628, 724},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 59, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1838, 56, 455, 16, 50, "Usage",
      CellTags->"Function?"],
    Cell[2296, 74, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6158, 190}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 59, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1838, 56, 455, 16, 50, "Usage",
  CellTags->"Function?"],
Cell[2296, 74, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2393, 79, 159, 3, 58, "MathCaption"],
Cell[2555, 84, 271, 10, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[2851, 98, 33, 0, 39, "ExampleSection"],
Cell[2887, 100, 97, 2, 29, "Input"],
Cell[2987, 104, 165, 5, 25, "Text"],
Cell[3155, 111, 83, 2, 30, "Input"],
Cell[3241, 115, 993, 21, 249, "Input"],
Cell[4237, 138, 747, 16, 209, "Input"],
Cell[4987, 156, 406, 8, 111, "Input"],
Cell[5396, 166, 65, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

