(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    361937,       9577]*)
(*NotebookOutlinePosition[    362929,       9612]*)
(*  CellTagsIndexPosition[    362852,       9606]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawSurfaceOfRevolution", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{"DrawSurfaceOfRevolution", 
        StyleBox["[",
          "MR"], 
        StyleBox[\(fun, {u, u0, u1}, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " extracts the graphics primitives from the corresponding \
SurfaceOfRevolution statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as SurfaceOfRevolution. Regular SurfaceOfRevolution options \
may be used. Basic Graphics3D options, such as PlotRange have no effect.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Draw3D",
    ButtonData:>{"Draw3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ParametricDraw3D",
    ButtonData:>{"ParametricDraw3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DrawListSurfaceOfRevolution",
    ButtonData:>{"DrawListSurfaceOfRevolution"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["SurfaceOfRevolution",
    ButtonData:>{"Graphics`SurfaceOfRevolution`", "1.3"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Do you like Krispy Kreme?", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{EdgeForm[], 
          SurfaceColor[Carrot, LightBeige, 
            2], \[IndentingNewLine]DrawSurfaceOfRevolution[\(\@Cos[
                    2  \[Theta]]\) {Cos[\[Theta]], Sin[\[Theta]]}, {\[Theta], 
              0, \[Pi]/4}, 
            PlotPoints \[Rule] 2 {10, 31}], \[IndentingNewLine]SurfaceColor[
            SaddleBrown, SaddleBrown, 
            2], \[IndentingNewLine]DrawSurfaceOfRevolution[\(-\@Cos[2  \
\[Theta]]\) {Cos[\[Theta]], Sin[\[Theta]]}, {\[Theta], 0, \[Pi]/4}, 
            PlotPoints \[Rule] 2 {10, 31}]}, \[IndentingNewLine]Boxed \[Rule] 
          False, \[IndentingNewLine]NeutralLighting[0.3, 0.5, 
          0.0], \[IndentingNewLine]ViewPoint -> {1.354, \ \(-2.922\), \ 
            1.040}, \[IndentingNewLine]Background \[Rule] 
          DarkSeaGreen, \[IndentingNewLine]ImageSize \[Rule] 
          400];\)\)], "Input",
  CellLabel->"In[309]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5652 
%%ImageSize: 400 226.078 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.561 .737 .561 r
MFill
% Scaling calculations
1.91904e-017 1.06953 -0.203954 1.06953 [
[ 0 0 0 0 ]
[ 1 .5652 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5652 L
0 .5652 L
closepath
clip
newpath
.775 .375 .106 r
.5336 .3878 m .5031 .37439 L .50253 .38731 L F
.5336 .3878 m .53362 .37488 L .5031 .37439 L F
.748 .359 .102 r
.53359 .40071 m .5336 .3878 L .50253 .38731 L F
.748 .362 .103 r
.56468 .38738 m .53362 .37488 L .5336 .3878 L F
.719 .345 .099 r
.56507 .40029 m .5336 .3878 L .53359 .40071 L F
.56507 .40029 m .56468 .38738 L .5336 .3878 L F
.748 .359 .102 r
.53359 .40071 m .50253 .38731 L .50211 .40022 L F
.719 .342 .097 r
.53358 .41349 m .53359 .40071 L .50211 .40022 L F
.69 .328 .094 r
.56533 .41307 m .53359 .40071 L .53358 .41349 L F
.56533 .41307 m .56507 .40029 L .53359 .40071 L F
.748 .362 .103 r
.56468 .38738 m .56416 .37446 L .53362 .37488 L F
.72 .349 .1 r
.59556 .38604 m .56416 .37446 L .56468 .38738 L F
.691 .332 .096 r
.59635 .39896 m .56468 .38738 L .56507 .40029 L F
.59635 .39896 m .59556 .38604 L .56468 .38738 L F
.661 .315 .091 r
.59687 .41175 m .56507 .40029 L .56533 .41307 L F
.59687 .41175 m .59635 .39896 L .56507 .40029 L F
.801 .391 .111 r
.53362 .37488 m .50381 .36159 L .5031 .37439 L F
.53362 .37488 m .53365 .36208 L .50381 .36159 L F
.775 .378 .108 r
.56416 .37446 m .53365 .36208 L .53362 .37488 L F
.803 .388 .11 r
.50253 .38731 m .47279 .37298 L .47169 .38591 L F
.50253 .38731 m .5031 .37439 L .47279 .37298 L F
.776 .372 .105 r
.50211 .40022 m .50253 .38731 L .47169 .38591 L F
.719 .342 .097 r
.53358 .41349 m .50211 .40022 L .50184 .413 L F
.688 .324 .092 r
.53357 .426 m .53358 .41349 L .50184 .413 L F
.659 .311 .089 r
.54154 .42589 m .53358 .42275 L .53357 .426 L F
.688 .324 .092 r
.50969 .42564 m .50174 .42227 L .50171 .42552 L F
.716 .337 .095 r
.49771 .42375 m .50184 .413 L .47032 .41162 L F
.50171 .42552 m .50174 .42227 L .49771 .42375 L F
.50174 .42227 m .50184 .413 L .49771 .42375 L F
1 .817 .462 r
.50969 .42564 m .48588 .43708 L .48586 .42808 L F
.49381 .42518 m .48586 .42808 L .48585 .42495 L F
.716 .337 .095 r
.50171 .42552 m .47032 .41162 L .47014 .4209 L F
.478 .42449 m .47014 .4209 L .47007 .42415 L F
.50171 .42552 m .47014 .4209 L .478 .42449 L F
.745 .35 .098 r
.46615 .42227 m .47032 .41162 L .43925 .40933 L F
.47007 .42415 m .47014 .4209 L .46615 .42227 L F
.47014 .4209 m .47032 .41162 L .46615 .42227 L F
1 .857 .488 r
.478 .42449 m .45446 .4353 L .45442 .42628 L F
.46229 .42359 m .45442 .42628 L .45441 .42314 L F
.745 .35 .098 r
.47007 .42415 m .43925 .40933 L .43898 .41864 L F
.4467 .42246 m .43898 .41864 L .43888 .4219 L F
.47007 .42415 m .43898 .41864 L .4467 .42246 L F
.773 .364 .101 r
.43507 .4199 m .43925 .40933 L .40885 .40616 L F
.43888 .4219 m .43898 .41864 L .43507 .4199 L F
.43898 .41864 m .43925 .40933 L .43507 .4199 L F
1 .897 .512 r
.4467 .42246 m .4236 .43266 L .42355 .4236 L F
.43127 .42112 m .42355 .4236 L .42353 .42044 L F
.773 .364 .101 r
.43888 .4219 m .40885 .40616 L .40849 .4155 L F
.41602 .41956 m .40849 .4155 L .40836 .41877 L F
.43888 .4219 m .40849 .4155 L .41602 .41956 L F
.802 .377 .104 r
.40468 .41666 m .40885 .40616 L .37935 .40211 L F
.40836 .41877 m .40849 .4155 L .40468 .41666 L F
.40849 .4155 m .40885 .40616 L .40468 .41666 L F
1 .936 .536 r
.41602 .41956 m .39352 .42916 L .39345 .42005 L F
.40098 .41777 m .39345 .42005 L .39342 .41688 L F
.802 .377 .104 r
.40836 .41877 m .37935 .40211 L .3789 .41149 L F
.38618 .41578 m .3789 .41149 L .37874 .41477 L F
.40836 .41877 m .3789 .41149 L .38618 .41578 L F
.83 .39 .106 r
.37522 .41255 m .37935 .40211 L .35096 .3972 L F
.37874 .41477 m .3789 .41149 L .37522 .41255 L F
.3789 .41149 m .37935 .40211 L .37522 .41255 L F
1 .974 .559 r
.38618 .41578 m .36445 .42481 L .36437 .41565 L F
.37165 .41357 m .36437 .41565 L .36434 .41246 L F
.83 .39 .106 r
.37874 .41477 m .35096 .3972 L .35043 .40663 L F
.35741 .41115 m .35043 .40663 L .35024 .40993 L F
.37874 .41477 m .35043 .40663 L .35741 .41115 L F
.857 .403 .109 r
.34691 .40758 m .35096 .3972 L .32394 .39144 L F
.35024 .40993 m .35043 .40663 L .34691 .40758 L F
.35043 .40663 m .35096 .3972 L .34691 .40758 L F
1 1 .58 r
.35741 .41115 m .33663 .41964 L .33653 .41041 L F
.34349 .40851 m .33653 .41041 L .33649 .40719 L F
.857 .403 .109 r
.35024 .40993 m .32394 .39144 L .32332 .40093 L F
.32994 .40568 m .32332 .40093 L .32311 .40425 L F
.35024 .40993 m .32332 .40093 L .32994 .40568 L F
.884 .415 .112 r
.32 .40179 m .32394 .39144 L .29852 .38487 L F
.32311 .40425 m .32332 .40093 L .32 .40179 L F
.32332 .40093 m .32394 .39144 L .32 .40179 L F
1 1 .598 r
.32994 .40568 m .31029 .41366 L .31017 .40435 L F
.31676 .40263 m .31017 .40435 L .31013 .4011 L F
.884 .415 .112 r
.32311 .40425 m .29852 .38487 L .29782 .39442 L F
.30401 .39939 m .29782 .39442 L .29758 .39776 L F
.32311 .40425 m .29782 .39442 L .30401 .39939 L F
.908 .427 .114 r
.29471 .3952 m .29852 .38487 L .27494 .3775 L F
.29758 .39776 m .29782 .39442 L .29471 .3952 L F
.29782 .39442 m .29852 .38487 L .29471 .3952 L F
1 1 .611 r
.30401 .39939 m .28567 .4069 L .28553 .3975 L F
.29169 .39595 m .28553 .3975 L .28549 .39422 L F
.908 .427 .114 r
.29758 .39776 m .27494 .3775 L .27416 .38712 L F
.27986 .39232 m .27416 .38712 L .27389 .39049 L F
.29758 .39776 m .27416 .38712 L .27986 .39232 L F
.926 .435 .115 r
.27131 .38782 m .27494 .3775 L .25346 .36938 L F
.27389 .39049 m .27416 .38712 L .27131 .38782 L F
.27416 .38712 m .27494 .3775 L .27131 .38782 L F
1 1 .616 r
.27986 .39232 m .26302 .39939 L .26287 .38989 L F
.26854 .3885 m .26287 .38989 L .26282 .38657 L F
.926 .435 .115 r
.27389 .39049 m .25346 .36938 L .25261 .37908 L F
.25775 .3845 m .25261 .37908 L .25231 .38248 L F
.27389 .39049 m .25261 .37908 L .25775 .3845 L F
.933 .44 .115 r
.25004 .37971 m .25346 .36938 L .23431 .36056 L F
.25231 .38248 m .25261 .37908 L .25004 .37971 L F
.25261 .37908 m .25346 .36938 L .25004 .37971 L F
1 1 .608 r
.25775 .3845 m .2426 .39117 L .24244 .38156 L F
.24754 .38032 m .24244 .38156 L .24238 .37821 L F
.933 .44 .115 r
.25231 .38248 m .23431 .36056 L .2334 .37035 L F
.23793 .37597 m .2334 .37035 L .23307 .37377 L F
.25231 .38248 m .2334 .37035 L .23793 .37597 L F
.921 .435 .113 r
.23114 .37091 m .23431 .36056 L .21777 .35108 L F
.23307 .37377 m .2334 .37035 L .23114 .37091 L F
.2334 .37035 m .23431 .36056 L .23114 .37091 L F
1 1 .578 r
.23793 .37597 m .22465 .3823 L .22448 .37256 L F
.22895 .37145 m .22448 .37256 L .22442 .36917 L F
.921 .435 .113 r
.23307 .37377 m .21777 .35108 L .21679 .36096 L F
.22064 .36678 m .21679 .36096 L .21645 .36442 L F
.23307 .37377 m .21679 .36096 L .22064 .36678 L F
.875 .415 .106 r
.21488 .36146 m .21777 .35108 L .20407 .34102 L F
.21645 .36442 m .21679 .36096 L .21488 .36146 L F
.21679 .36096 m .21777 .35108 L .21488 .36146 L F
1 1 .514 r
.22064 .36678 m .20943 .37282 L .20925 .36296 L F
.21303 .36195 m .20925 .36296 L .20919 .35952 L F
.875 .415 .106 r
.21645 .36442 m .20407 .34102 L .20303 .35099 L F
.20615 .35699 m .20303 .35099 L .20267 .35448 L F
.21645 .36442 m .20303 .35099 L .20615 .35699 L F
.777 .37 .094 r
.20151 .35145 m .20407 .34102 L .19346 .33044 L F
.20267 .35448 m .20303 .35099 L .20151 .35145 L F
.20303 .35099 m .20407 .34102 L .20151 .35145 L F
1 .883 .403 r
.20615 .35699 m .19719 .3628 L .197 .3528 L F
.20003 .35189 m .197 .3528 L .19693 .34932 L F
.777 .37 .094 r
.20267 .35448 m .19346 .33044 L .19237 .34051 L F
.19469 .34668 m .19237 .34051 L .192 .34404 L F
.20267 .35448 m .19237 .34051 L .19469 .34668 L F
.622 .299 .076 r
.19126 .34093 m .19346 .33044 L .18617 .31943 L F
.192 .34404 m .19237 .34051 L .19126 .34093 L F
.19237 .34051 m .19346 .33044 L .19126 .34093 L F
1 .669 .242 r
.19469 .34668 m .18816 .35232 L .18796 .34218 L F
.19018 .34134 m .18796 .34218 L .18789 .33865 L F
.622 .299 .076 r
.192 .34404 m .18617 .31943 L .18504 .32961 L F
.18651 .33591 m .18504 .32961 L .18465 .33317 L F
.192 .34404 m .18504 .32961 L .18651 .33591 L F
.471 .228 .058 r
.18437 .33001 m .18617 .31943 L .18241 .3081 L F
.18465 .33317 m .18504 .32961 L .18437 .33001 L F
.18504 .32961 m .18617 .31943 L .18437 .33001 L F
.771 .456 .098 r
.18651 .33591 m .18257 .34147 L .18237 .33119 L F
.18371 .3304 m .18237 .33119 L .1823 .3276 L F
.471 .228 .058 r
.18465 .33317 m .18241 .3081 L .18126 .31837 L F
.18182 .3248 m .18126 .31837 L .18086 .32197 L F
.18465 .33317 m .18126 .31837 L .18182 .3248 L F
.374 .182 .044 r
.18105 .31876 m .18241 .3081 L .18237 .29654 L F
.18086 .32197 m .18126 .31837 L .18105 .31876 L F
.18126 .31837 m .18241 .3081 L .18105 .31876 L F
.18086 .32197 m .18237 .29654 L .18121 .30692 L F
.18081 .31344 m .18121 .30692 L .1808 .31055 L F
.18086 .32197 m .18121 .30692 L .18081 .31344 L F
.497 .247 .063 r
.18577 .29448 m .19099 .26966 L .18578 .28285 L F
.443 .218 .055 r
.18241 .3081 m .18577 .29448 L .18578 .28285 L F
.18241 .3081 m .18578 .28285 L .18237 .29654 L F
.628 .313 .08 r
.18945 .3059 m .19091 .2813 L .18577 .29448 L F
.545 .268 .068 r
.18617 .31943 m .18945 .3059 L .18577 .29448 L F
.18617 .31943 m .18577 .29448 L .18241 .3081 L F
.705 .357 .091 r
.19446 .29273 m .19778 .26871 L .19091 .2813 L F
.628 .313 .08 r
.18945 .3059 m .19446 .29273 L .19091 .2813 L F
.55 .278 .072 r
.19091 .2813 m .19778 .26871 L .19795 .25713 L F
.87 .436 .112 r
.20147 .30383 m .20118 .28007 L .19446 .29273 L F
.801 .396 .101 r
.19663 .31699 m .20147 .30383 L .19446 .29273 L F
.19663 .31699 m .19446 .29273 L .18945 .3059 L F
.705 .357 .091 r
.19446 .29273 m .20118 .28007 L .19778 .26871 L F
.922 .468 .121 r
.20796 .29112 m .20954 .26809 L .20118 .28007 L F
.776 .397 .102 r
.20118 .28007 m .20954 .26809 L .20634 .25686 L F
.20118 .28007 m .20634 .25686 L .19778 .26871 L F
1 .51 .133 r
.21795 .30175 m .21606 .27902 L .20796 .29112 L F
.955 .49 .128 r
.21606 .27902 m .21952 .25695 L .20954 .26809 L F
.922 .468 .121 r
.20796 .29112 m .21606 .27902 L .20954 .26809 L F
.97 .502 .132 r
.22572 .26768 m .23105 .24679 L .21952 .25695 L F
.955 .49 .128 r
.21606 .27902 m .22572 .26768 L .21952 .25695 L F
.869 .454 .119 r
.21952 .25695 m .23105 .24679 L .22832 .23605 L F
.21952 .25695 m .22832 .23605 L .21654 .24592 L F
.832 .43 .111 r
.20954 .26809 m .21952 .25695 L .21654 .24592 L F
1 .531 .141 r
.23495 .27801 m .23689 .25725 L .22572 .26768 L F
1 .524 .138 r
.2257 .28953 m .23495 .27801 L .22572 .26768 L F
.2257 .28953 m .22572 .26768 L .21606 .27902 L F
.97 .502 .132 r
.22572 .26768 m .23689 .25725 L .23105 .24679 L F
1 .529 .142 r
.24566 .26734 m .24952 .2479 L .23689 .25725 L F
.968 .505 .135 r
.23689 .25725 m .24952 .2479 L .24408 .23778 L F
.23689 .25725 m .24408 .23778 L .23105 .24679 L F
1 .541 .146 r
.2572 .27697 m .25779 .25767 L .24566 .26734 L F
.994 .52 .141 r
.25779 .25767 m .26357 .23978 L .24952 .2479 L F
1 .529 .142 r
.24566 .26734 m .25779 .25767 L .24952 .2479 L F
1 .531 .141 r
.23495 .27801 m .24566 .26734 L .23689 .25725 L F
.994 .52 .141 r
.25779 .25767 m .27129 .24916 L .26357 .23978 L F
.953 .502 .138 r
.27129 .24916 m .279 .23308 L .26357 .23978 L F
.918 .486 .133 r
.26357 .23978 m .279 .23308 L .27442 .22387 L F
.26357 .23978 m .27442 .22387 L .25855 .23008 L F
.95 .5 .135 r
.24952 .2479 m .26357 .23978 L .25855 .23008 L F
1 .531 .145 r
.26872 .267 m .27129 .24916 L .25779 .25767 L F
.26872 .267 m .28156 .25813 L .27129 .24916 L F
.978 .513 .141 r
.28156 .25813 m .28613 .24199 L .27129 .24916 L F
.953 .502 .138 r
.27129 .24916 m .28613 .24199 L .279 .23308 L F
.898 .476 .132 r
.28613 .24199 m .29576 .22797 L .279 .23308 L F
.28613 .24199 m .30228 .23636 L .29576 .22797 L F
.872 .464 .129 r
.279 .23308 m .29576 .22797 L .29165 .21932 L F
.814 .435 .123 r
.29576 .22797 m .31022 .21666 L .29165 .21932 L F
.933 .492 .137 r
.30749 .25861 m .31107 .24439 L .29568 .25053 L F
.918 .485 .135 r
.29568 .25053 m .30228 .23636 L .28613 .24199 L F
.29568 .25053 m .31107 .24439 L .30228 .23636 L F
.842 .448 .127 r
.31107 .24439 m .31973 .23246 L .30228 .23636 L F
.829 .442 .125 r
.30228 .23636 m .31386 .22468 L .29576 .22797 L F
.30228 .23636 m .31973 .23246 L .31386 .22468 L F
.748 .401 .115 r
.31973 .23246 m .3333 .22345 L .31386 .22468 L F
.814 .435 .123 r
.29576 .22797 m .31386 .22468 L .31022 .21666 L F
.746 .4 .115 r
.31386 .22468 m .33014 .21613 L .31022 .21666 L F
.31386 .22468 m .3333 .22345 L .33014 .21613 L F
.744 .399 .114 r
.31022 .21666 m .33014 .21613 L .32911 .20868 L F
.752 .403 .115 r
.33771 .24702 m .34567 .2374 L .32772 .23993 L F
.75 .402 .115 r
.32772 .23993 m .33851 .23056 L .31973 .23246 L F
.32772 .23993 m .34567 .2374 L .33851 .23056 L F
.648 .347 .101 r
.34567 .2374 m .35869 .23099 L .33851 .23056 L F
.748 .401 .115 r
.31973 .23246 m .33851 .23056 L .3333 .22345 L F
.659 .353 .103 r
.33851 .23056 m .35416 .22462 L .3333 .22345 L F
.33851 .23056 m .35869 .23099 L .35416 .22462 L F
.671 .359 .105 r
.3333 .22345 m .35148 .21807 L .33014 .21613 L F
.3333 .22345 m .35416 .22462 L .35148 .21807 L F
.59 .315 .093 r
.35416 .22462 m .37444 .22293 L .35148 .21807 L F
.682 .365 .107 r
.33014 .21613 m .35148 .21807 L .35072 .21141 L F
.616 .328 .097 r
.35148 .21807 m .37391 .21714 L .35072 .21141 L F
.35148 .21807 m .37444 .22293 L .37391 .21714 L F
.64 .341 .101 r
.35072 .21141 m .37391 .21714 L .37511 .21133 L F
.35072 .21141 m .37511 .21133 L .35192 .20472 L F
.663 .352 .105 r
.35192 .20472 m .37511 .21133 L .37804 .20556 L F
.534 .286 .085 r
.36498 .23712 m .38047 .23419 L .35869 .23099 L F
.563 .3 .089 r
.35869 .23099 m .37664 .22863 L .35416 .22462 L F
.35869 .23099 m .38047 .23419 L .37664 .22863 L F
.59 .315 .093 r
.35416 .22462 m .37664 .22863 L .37444 .22293 L F
.5 .266 .08 r
.37664 .22863 m .39941 .23144 L .37444 .22293 L F
.542 .287 .087 r
.37444 .22293 m .3991 .22661 L .37391 .21714 L F
.37444 .22293 m .39941 .23144 L .3991 .22661 L F
.58 .307 .093 r
.37391 .21714 m .40024 .22176 L .37511 .21133 L F
.37391 .21714 m .3991 .22661 L .40024 .22176 L F
.613 .324 .098 r
.37511 .21133 m .40024 .22176 L .40284 .21696 L F
.37511 .21133 m .40284 .21696 L .37804 .20556 L F
.642 .339 .102 r
.37804 .20556 m .40284 .21696 L .40689 .21225 L F
.37804 .20556 m .40689 .21225 L .38271 .19989 L F
.67 .353 .106 r
.38271 .19989 m .40689 .21225 L .41238 .20769 L F
.38271 .19989 m .41238 .20769 L .38909 .19439 L F
.513 .27 .083 r
.3991 .22661 m .42827 .23741 L .40024 .22176 L F
.557 .292 .09 r
.40024 .22176 m .42827 .23741 L .43044 .23367 L F
.40024 .22176 m .43044 .23367 L .40284 .21696 L F
.594 .311 .095 r
.40284 .21696 m .43044 .23367 L .43375 .23002 L F
.40284 .21696 m .43375 .23002 L .40689 .21225 L F
.627 .328 .1 r
.40689 .21225 m .43375 .23002 L .43818 .22649 L F
.40689 .21225 m .43818 .22649 L .41238 .20769 L F
.657 .343 .104 r
.41238 .20769 m .43818 .22649 L .4437 .22313 L F
.41238 .20769 m .4437 .22313 L .41925 .20333 L F
.686 .357 .107 r
.41925 .20333 m .4437 .22313 L .45024 .21997 L F
.712 .369 .111 r
.42745 .19924 m .45024 .21997 L .45775 .21705 L F
.686 .357 .107 r
.41925 .20333 m .45024 .21997 L .42745 .19924 L F
.712 .369 .111 r
.42745 .19924 m .45775 .21705 L .4369 .19545 L F
.743 .389 .115 r
.40681 .18417 m .42745 .19924 L .4369 .19545 L F
.674 .347 .105 r
.45024 .21997 m .47736 .25028 L .48252 .24837 L F
.644 .333 .101 r
.4437 .22313 m .47736 .25028 L .45024 .21997 L F
.674 .347 .105 r
.45024 .21997 m .48252 .24837 L .45775 .21705 L F
.737 .381 .113 r
.4369 .19545 m .45775 .21705 L .46615 .21442 L F
.761 .392 .116 r
.44751 .19202 m .46615 .21442 L .47535 .21209 L F
.737 .381 .113 r
.4369 .19545 m .46615 .21442 L .44751 .19202 L F
.784 .403 .119 r
.45915 .18899 m .47535 .21209 L .48524 .21011 L F
.761 .392 .116 r
.44751 .19202 m .47535 .21209 L .45915 .18899 L F
.784 .403 .119 r
.45915 .18899 m .48524 .21011 L .47171 .1864 L F
.755 .384 .113 r
.47535 .21209 m .49453 .24513 L .50125 .24383 L F
.729 .372 .111 r
.46615 .21442 m .49453 .24513 L .47535 .21209 L F
.78 .396 .116 r
.48524 .21011 m .50125 .24383 L .50836 .24278 L F
.755 .384 .113 r
.47535 .21209 m .50125 .24383 L .48524 .21011 L F
.78 .396 .116 r
.48524 .21011 m .50836 .24278 L .49572 .2085 L F
.806 .414 .121 r
.47171 .1864 m .48524 .21011 L .49572 .2085 L F
.47171 .1864 m .49572 .2085 L .48503 .18429 L F
.827 .424 .123 r
.48503 .18429 m .49572 .2085 L .50667 .20727 L F
.848 .434 .126 r
.49896 .18269 m .50667 .20727 L .51794 .20645 L F
.827 .424 .123 r
.48503 .18429 m .50667 .20727 L .49896 .18269 L F
.869 .444 .128 r
.51332 .18161 m .51794 .20645 L .52942 .20604 L F
.848 .434 .126 r
.49896 .18269 m .51794 .20645 L .51332 .18161 L F
.828 .419 .121 r
.50667 .20727 m .51577 .24198 L .52339 .24145 L F
.804 .408 .119 r
.49572 .2085 m .51577 .24198 L .50667 .20727 L F
.852 .43 .124 r
.51794 .20645 m .52339 .24145 L .53115 .24119 L F
.828 .419 .121 r
.50667 .20727 m .52339 .24145 L .51794 .20645 L F
.875 .442 .127 r
.52942 .20604 m .53895 .2412 L .54096 .20606 L F
.52942 .20604 m .53115 .24119 L .53895 .2412 L F
.852 .43 .124 r
.51794 .20645 m .53115 .24119 L .52942 .20604 L F
.899 .454 .129 r
.54096 .20606 m .54671 .24148 L .55243 .2065 L F
.54096 .20606 m .53895 .2412 L .54671 .24148 L F
.929 .474 .135 r
.55728 .18168 m .55243 .2065 L .56369 .20735 L F
.909 .464 .133 r
.54267 .1811 m .55243 .2065 L .55728 .18168 L F
.54267 .1811 m .54096 .20606 L .55243 .2065 L F
.889 .454 .13 r
.52795 .18108 m .54096 .20606 L .54267 .1811 L F
.52795 .18108 m .52942 .20604 L .54096 .20606 L F
.869 .444 .128 r
.51332 .18161 m .52942 .20604 L .52795 .18108 L F
.968 .489 .137 r
.5746 .2086 m .56879 .24392 L .58504 .21025 L F
.5746 .2086 m .56171 .24285 L .56879 .24392 L F
.945 .477 .135 r
.56369 .20735 m .56171 .24285 L .5746 .2086 L F
.56369 .20735 m .55432 .24203 L .56171 .24285 L F
.922 .465 .132 r
.55243 .2065 m .55432 .24203 L .56369 .20735 L F
.55243 .2065 m .54671 .24148 L .55432 .24203 L F
.966 .493 .139 r
.58551 .18443 m .5746 .2086 L .58504 .21025 L F
.948 .484 .137 r
.57162 .18279 m .5746 .2086 L .58551 .18443 L F
.57162 .18279 m .56369 .20735 L .5746 .2086 L F
.929 .474 .135 r
.55728 .18168 m .56369 .20735 L .57162 .18279 L F
.998 .511 .143 r
.61127 .1892 m .59489 .21226 L .60403 .2146 L F
.983 .503 .141 r
.59878 .18658 m .59489 .21226 L .61127 .1892 L F
.59878 .18658 m .58504 .21025 L .59489 .21226 L F
.966 .493 .139 r
.58551 .18443 m .58504 .21025 L .59878 .18658 L F
1 .538 .147 r
.61981 .2202 m .59698 .25252 L .62628 .22337 L F
.61981 .2202 m .59252 .25043 L .59698 .25252 L F
1 .532 .146 r
.61237 .21726 m .59252 .25043 L .61981 .2202 L F
.61237 .21726 m .58741 .24851 L .59252 .25043 L F
1 .522 .145 r
.60403 .2146 m .58741 .24851 L .61237 .21726 L F
.60403 .2146 m .58171 .24677 L .58741 .24851 L F
1 .512 .142 r
.59489 .21226 m .58171 .24677 L .60403 .2146 L F
1 .525 .145 r
.63337 .19572 m .61237 .21726 L .61981 .2202 L F
1 .519 .144 r
.62285 .19226 m .61237 .21726 L .63337 .19572 L F
.62285 .19226 m .60403 .2146 L .61237 .21726 L F
.998 .511 .143 r
.61127 .1892 m .60403 .2146 L .62285 .19226 L F
1 .529 .146 r
.64273 .19953 m .62628 .22337 L .65084 .20365 L F
.64273 .19953 m .61981 .2202 L .62628 .22337 L F
1 .525 .145 r
.63337 .19572 m .61981 .2202 L .64273 .19953 L F
.978 .509 .142 r
.65242 .17991 m .63337 .19572 L .64273 .19953 L F
.883 .468 .126 r
.66942 .22212 m .64138 .23769 L .64231 .24146 L F
.941 .496 .134 r
.66693 .21731 m .64138 .23769 L .66942 .22212 L F
.66693 .21731 m .63929 .23395 L .64138 .23769 L F
.982 .514 .14 r
.66299 .21259 m .63929 .23395 L .66693 .21731 L F
.66299 .21259 m .63606 .23029 L .63929 .23395 L F
1 .525 .144 r
.65761 .20802 m .63606 .23029 L .66299 .21259 L F
.65761 .20802 m .63171 .22675 L .63606 .23029 L F
1 .529 .145 r
.65084 .20365 m .63171 .22675 L .65761 .20802 L F
.65084 .20365 m .62628 .22337 L .63171 .22675 L F
.903 .479 .132 r
.69177 .20599 m .66693 .21731 L .66942 .22212 L F
.934 .493 .136 r
.68723 .20031 m .66693 .21731 L .69177 .20599 L F
.68723 .20031 m .66299 .21259 L .66693 .21731 L F
.956 .503 .139 r
.68097 .19479 m .66299 .21259 L .68723 .20031 L F
.68097 .19479 m .65761 .20802 L .66299 .21259 L F
.686 .37 .103 r
.71042 .23145 m .68871 .2346 L .68321 .23994 L F
.725 .39 .108 r
.71509 .2251 m .68871 .2346 L .71042 .23145 L F
.686 .369 .1 r
.69266 .22905 m .66499 .24122 L .68871 .2346 L F
.725 .39 .108 r
.71509 .2251 m .69266 .22905 L .68871 .2346 L F
.686 .369 .1 r
.69266 .22905 m .6682 .23657 L .66499 .24122 L F
.762 .41 .114 r
.71791 .21856 m .69266 .22905 L .71509 .2251 L F
.751 .403 .11 r
.69498 .22336 m .6682 .23657 L .69266 .22905 L F
.762 .41 .114 r
.71791 .21856 m .69498 .22336 L .69266 .22905 L F
.751 .403 .11 r
.69498 .22336 m .67004 .2318 L .6682 .23657 L F
.797 .427 .119 r
.71882 .21191 m .69498 .22336 L .71791 .21856 L F
.81 .434 .119 r
.69563 .21758 m .67004 .2318 L .69498 .22336 L F
.797 .427 .119 r
.71882 .21191 m .69563 .21758 L .69498 .22336 L F
.81 .434 .119 r
.69563 .21758 m .67045 .22697 L .67004 .2318 L F
.862 .459 .126 r
.69457 .21176 m .67045 .22697 L .69563 .21758 L F
.69457 .21176 m .66942 .22212 L .67045 .22697 L F
.903 .479 .132 r
.69177 .20599 m .66942 .22212 L .69457 .21176 L F
.827 .442 .123 r
.71777 .20521 m .69563 .21758 L .71882 .21191 L F
.71777 .20521 m .69457 .21176 L .69563 .21758 L F
.852 .455 .127 r
.71472 .19854 m .69457 .21176 L .71777 .20521 L F
.737 .394 .114 r
.74113 .24047 m .72325 .23789 L .71413 .24437 L F
.734 .393 .113 r
.74927 .23303 m .72325 .23789 L .74113 .24047 L F
.725 .39 .11 r
.73055 .23108 m .70401 .23757 L .72325 .23789 L F
.734 .393 .113 r
.74927 .23303 m .73055 .23108 L .72325 .23789 L F
.725 .39 .11 r
.73055 .23108 m .71042 .23145 L .70401 .23757 L F
.732 .392 .113 r
.75531 .22527 m .73055 .23108 L .74927 .23303 L F
.74 .397 .112 r
.73591 .22399 m .71042 .23145 L .73055 .23108 L F
.732 .392 .113 r
.75531 .22527 m .73591 .22399 L .73055 .23108 L F
.74 .397 .112 r
.73591 .22399 m .71509 .2251 L .71042 .23145 L F
.754 .405 .115 r
.73922 .21668 m .71509 .2251 L .73591 .22399 L F
.73922 .21668 m .71791 .21856 L .71509 .2251 L F
.729 .391 .113 r
.75911 .21726 m .73591 .22399 L .75531 .22527 L F
.75911 .21726 m .73922 .21668 L .73591 .22399 L F
.727 .39 .112 r
.7606 .20909 m .73922 .21668 L .75911 .21726 L F
.7606 .20909 m .74041 .20924 L .73922 .21668 L F
.711 .376 .112 r
.77304 .25115 m .75771 .24497 L .74664 .25256 L F
.691 .366 .109 r
.78277 .24264 m .75771 .24497 L .77304 .25115 L F
.721 .384 .112 r
.76667 .23697 m .74113 .24047 L .75771 .24497 L F
.691 .366 .109 r
.78277 .24264 m .76667 .23697 L .75771 .24497 L F
.721 .384 .112 r
.76667 .23697 m .74927 .23303 L .74113 .24047 L F
.707 .377 .11 r
.77336 .22861 m .74927 .23303 L .76667 .23697 L F
.77336 .22861 m .75531 .22527 L .74927 .23303 L F
.67 .355 .106 r
.79008 .23376 m .76667 .23697 L .78277 .24264 L F
.79008 .23376 m .77336 .22861 L .76667 .23697 L F
.647 .343 .103 r
.79485 .22456 m .77336 .22861 L .79008 .23376 L F
.693 .37 .108 r
.77765 .21997 m .75531 .22527 L .77336 .22861 L F
.647 .343 .103 r
.79485 .22456 m .77765 .21997 L .77336 .22861 L F
.651 .342 .103 r
.79755 .24984 m .77304 .25115 L .78711 .25878 L F
.605 .316 .097 r
.81101 .25838 m .79755 .24984 L .78711 .25878 L F
.651 .342 .103 r
.79755 .24984 m .78277 .24264 L .77304 .25115 L F
.625 .329 .1 r
.80547 .2405 m .78277 .24264 L .79755 .24984 L F
.80547 .2405 m .79008 .23376 L .78277 .24264 L F
.575 .301 .093 r
.81949 .24864 m .80547 .2405 L .79755 .24984 L F
.596 .314 .095 r
.8107 .23081 m .79008 .23376 L .80547 .2405 L F
.8107 .23081 m .79485 .22456 L .79008 .23376 L F
.54 .283 .087 r
.82514 .23854 m .80547 .2405 L .81949 .24864 L F
.82514 .23854 m .8107 .23081 L .80547 .2405 L F
.556 .288 .089 r
.8231 .26807 m .81101 .25838 L .79989 .26767 L F
.575 .301 .093 r
.81949 .24864 m .79755 .24984 L .81101 .25838 L F
.522 .271 .085 r
.83209 .25802 m .81101 .25838 L .8231 .26807 L F
.83209 .25802 m .81949 .24864 L .81101 .25838 L F
.48 .25 .078 r
.83815 .24758 m .81949 .24864 L .83209 .25802 L F
.83815 .24758 m .82514 .23854 L .81949 .24864 L F
.428 .224 .071 r
.84111 .23686 m .82514 .23854 L .83815 .24758 L F
.468 .24 .076 r
.84322 .26846 m .8231 .26807 L .83377 .27877 L F
.84322 .26846 m .83209 .25802 L .8231 .26807 L F
.412 .21 .067 r
.85285 .27982 m .84322 .26846 L .83377 .27877 L F
.419 .216 .069 r
.84965 .25776 m .83209 .25802 L .84322 .26846 L F
.84965 .25776 m .83815 .24758 L .83209 .25802 L F
.357 .184 .059 r
.85961 .26892 m .84965 .25776 L .84322 .26846 L F
.359 .188 .06 r
.85288 .24675 m .83815 .24758 L .84965 .25776 L F
.357 .184 .059 r
.85961 .26892 m .84322 .26846 L .85285 .27982 L F
.296 .153 .05 r
.86796 .28091 m .85285 .27982 L .86093 .29193 L F
.86796 .28091 m .85961 .26892 L .85285 .27982 L F
.29 .153 .05 r
.86306 .25771 m .84965 .25776 L .85961 .26892 L F
.218 .117 .039 r
.87161 .26956 m .85961 .26892 L .86796 .28091 L F
.87161 .26956 m .86306 .25771 L .85961 .26892 L F
.233 .121 .04 r
.87466 .29357 m .86093 .29193 L .8674 .30464 L F
.87466 .29357 m .86796 .28091 L .86093 .29193 L F
.169 .088 .03 r
.87966 .30674 m .87466 .29357 L .8674 .30464 L F
.16 .085 .03 r
.87848 .28216 m .86796 .28091 L .87466 .29357 L F
.87848 .28216 m .87161 .26956 L .86796 .28091 L F
.116 .059 .022 r
.88361 .29534 m .87848 .28216 L .87466 .29357 L F
.119 .06 .023 r
.87867 .27053 m .87161 .26956 L .87848 .28216 L F
.116 .059 .022 r
.88361 .29534 m .87466 .29357 L .87966 .30674 L F
.09 .045 .018 r
.88696 .30895 m .87966 .30674 L .88294 .32027 L F
.88696 .30895 m .88361 .29534 L .87966 .30674 L F
.091 .045 .018 r
.88388 .28372 m .87848 .28216 L .88361 .29534 L F
.063 .031 .012 r
.88728 .2974 m .88361 .29534 L .88696 .30895 L F
.88728 .2974 m .88388 .28372 L .88361 .29534 L F
.065 .032 .013 r
.88779 .32248 m .88696 .30895 L .88294 .32027 L F
.88851 .32281 m .88811 .31922 L .88779 .32248 L F
.88811 .31922 m .88696 .30895 L .88779 .32248 L F
.88851 .32281 m .88294 .32027 L .88406 .33043 L F
.88545 .33122 m .88406 .33043 L .88445 .33399 L F
.88851 .32281 m .88406 .33043 L .88545 .33122 L F
.088 .044 .017 r
.87873 .34215 m .87647 .34131 L .87685 .34483 L F
.134 .066 .024 r
.86864 .35266 m .86557 .35175 L .86593 .35524 L F
.207 .101 .033 r
.85541 .36268 m .8516 .36168 L .85194 .36513 L F
.265 .129 .041 r
.83928 .37213 m .83479 .37102 L .83511 .37444 L F
.311 .151 .047 r
.8205 .38095 m .81539 .37971 L .81569 .3831 L F
.349 .169 .053 r
.79934 .38908 m .79367 .38769 L .79394 .39106 L F
.389 .187 .058 r
.77603 .39648 m .76987 .39493 L .77011 .39827 L F
.428 .205 .062 r
.75083 .4031 m .74424 .40138 L .74445 .4047 L F
.465 .222 .067 r
.72398 .40892 m .71702 .40702 L .7172 .41032 L F
.501 .239 .071 r
.69573 .41391 m .68846 .41182 L .68862 .4151 L F
.535 .254 .075 r
.66632 .41805 m .65879 .41577 L .65892 .41903 L F
.568 .269 .078 r
.63596 .42133 m .62825 .41884 L .62834 .4221 L F
.599 .283 .082 r
.6049 .42374 m .59705 .42104 L .59711 .42428 L F
.629 .297 .085 r
.57336 .42526 m .56542 .42234 L .56545 .42558 L F
.659 .311 .089 r
.55906 .42502 m .53358 .41349 L .53358 .42275 L F
.56545 .42558 m .56138 .42404 L .55906 .42502 L F
.56138 .42404 m .53358 .41349 L .55906 .42502 L F
1 .735 .408 r
.57336 .42526 m .54951 .43802 L .54952 .42904 L F
.55747 .42569 m .54952 .42904 L .54952 .4259 L F
.659 .311 .089 r
.56545 .42558 m .53358 .42275 L .54154 .42589 L F
.56545 .42558 m .56533 .41307 L .53358 .41349 L F
1 .735 .408 r
.57336 .42526 m .54952 .42904 L .55747 .42569 L F
.58132 .42504 m .57727 .4267 L .57336 .42526 L F
.57727 .4267 m .54951 .43802 L .57336 .42526 L F
.629 .297 .085 r
.58918 .42461 m .56533 .41307 L .56542 .42234 L F
.58918 .42461 m .56542 .42234 L .57336 .42526 L F
.59711 .42428 m .59305 .42285 L .58918 .42461 L F
.59305 .42285 m .56533 .41307 L .58918 .42461 L F
1 .692 .379 r
.6049 .42374 m .58129 .43718 L .58131 .42818 L F
.58918 .42461 m .58131 .42818 L .58132 .42504 L F
.629 .297 .085 r
.59711 .42428 m .59687 .41175 L .56533 .41307 L F
1 .692 .379 r
.6049 .42374 m .58131 .42818 L .58918 .42461 L F
.61279 .4233 m .60878 .42507 L .6049 .42374 L F
.60878 .42507 m .58129 .43718 L .6049 .42374 L F
.599 .283 .082 r
.62051 .42265 m .59687 .41175 L .59705 .42104 L F
.62051 .42265 m .59705 .42104 L .6049 .42374 L F
.62834 .4221 m .62432 .42077 L .62051 .42265 L F
.62432 .42077 m .59687 .41175 L .62051 .42265 L F
.945 .648 .349 r
.63596 .42133 m .61274 .43547 L .61278 .42645 L F
.62051 .42265 m .61278 .42645 L .61279 .4233 L F
.599 .283 .082 r
.62834 .4221 m .62798 .40953 L .59687 .41175 L F
.945 .648 .349 r
.63596 .42133 m .61278 .42645 L .62051 .42265 L F
.64372 .42067 m .63977 .42256 L .63596 .42133 L F
.63977 .42256 m .61274 .43547 L .63596 .42133 L F
.568 .269 .078 r
.65124 .4198 m .62798 .40953 L .62825 .41884 L F
.65124 .4198 m .62825 .41884 L .63596 .42133 L F
.65892 .41903 m .65496 .41782 L .65124 .4198 L F
.65496 .41782 m .62798 .40953 L .65124 .4198 L F
.888 .603 .319 r
.66632 .41805 m .64365 .43289 L .6437 .42383 L F
.65124 .4198 m .6437 .42383 L .64372 .42067 L F
.568 .269 .078 r
.65892 .41903 m .65844 .40643 L .62798 .40953 L F
.888 .603 .319 r
.66632 .41805 m .6437 .42383 L .65124 .4198 L F
.67389 .41717 m .67003 .41918 L .66632 .41805 L F
.67003 .41918 m .64365 .43289 L .66632 .41805 L F
.535 .254 .075 r
.68116 .41609 m .65844 .40643 L .65879 .41577 L F
.68116 .41609 m .65879 .41577 L .66632 .41805 L F
.68862 .4151 m .68475 .41399 L .68116 .41609 L F
.68475 .41399 m .65844 .40643 L .68116 .41609 L F
.828 .556 .286 r
.69573 .41391 m .67379 .42945 L .67387 .42035 L F
.68116 .41609 m .67387 .42035 L .67389 .41717 L F
.535 .254 .075 r
.68862 .4151 m .68802 .40244 L .65844 .40643 L F
.828 .556 .286 r
.69573 .41391 m .67387 .42035 L .68116 .41609 L F
.70306 .41281 m .69932 .41494 L .69573 .41391 L F
.69932 .41494 m .67379 .42945 L .69573 .41391 L F
.501 .239 .071 r
.71002 .41152 m .68802 .40244 L .68846 .41182 L F
.71002 .41152 m .68846 .41182 L .69573 .41391 L F
.7172 .41032 m .71346 .40931 L .71002 .41152 L F
.71346 .40931 m .68802 .40244 L .71002 .41152 L F
.766 .507 .253 r
.72398 .40892 m .70295 .42517 L .70303 .41601 L F
.71002 .41152 m .70303 .41601 L .70306 .41281 L F
.501 .239 .071 r
.7172 .41032 m .71649 .39759 L .68802 .40244 L F
.766 .507 .253 r
.72398 .40892 m .70303 .41601 L .71002 .41152 L F
.73101 .40761 m .72742 .40986 L .72398 .40892 L F
.72742 .40986 m .70295 .42517 L .72398 .40892 L F
.465 .222 .067 r
.73759 .40611 m .71649 .39759 L .71702 .40702 L F
.73759 .40611 m .71702 .40702 L .72398 .40892 L F
.74445 .4047 m .74086 .40379 L .73759 .40611 L F
.74086 .40379 m .71649 .39759 L .73759 .40611 L F
.7 .457 .219 r
.75083 .4031 m .73087 .42005 L .73097 .41083 L F
.73759 .40611 m .73097 .41083 L .73101 .40761 L F
.465 .222 .067 r
.74445 .4047 m .74362 .3919 L .71649 .39759 L F
.7 .457 .219 r
.75083 .4031 m .73097 .41083 L .73759 .40611 L F
.75749 .40158 m .75408 .40395 L .75083 .4031 L F
.75408 .40395 m .73087 .42005 L .75083 .4031 L F
.428 .205 .062 r
.76365 .39989 m .74362 .3919 L .74424 .40138 L F
.76365 .39989 m .74424 .40138 L .75083 .4031 L F
.77011 .39827 m .7667 .39745 L .76365 .39989 L F
.7667 .39745 m .74362 .3919 L .76365 .39989 L F
.633 .406 .185 r
.77603 .39648 m .75733 .41413 L .75745 .40483 L F
.76365 .39989 m .75745 .40483 L .75749 .40158 L F
.428 .205 .062 r
.77011 .39827 m .76917 .38538 L .74362 .3919 L F
.633 .406 .185 r
.77603 .39648 m .75745 .40483 L .76365 .39989 L F
.78227 .39476 m .77907 .39724 L .77603 .39648 L F
.77907 .39724 m .75733 .41413 L .77603 .39648 L F
.389 .187 .058 r
.78793 .39287 m .76917 .38538 L .76987 .39493 L F
.78793 .39287 m .76987 .39493 L .77603 .39648 L F
.79394 .39106 m .79075 .39033 L .78793 .39287 L F
.79075 .39033 m .76917 .38538 L .78793 .39287 L F
.564 .358 .153 r
.79934 .38908 m .78209 .40743 L .78222 .39803 L F
.78793 .39287 m .78222 .39803 L .78227 .39476 L F
.389 .187 .058 r
.79394 .39106 m .7929 .37808 L .76917 .38538 L F
.564 .358 .153 r
.79934 .38908 m .78222 .39803 L .78793 .39287 L F
.80509 .38717 m .80214 .38977 L .79934 .38908 L F
.80214 .38977 m .78209 .40743 L .79934 .38908 L F
.349 .169 .053 r
.8102 .38511 m .7929 .37808 L .79367 .38769 L F
.8102 .38511 m .79367 .38769 L .79934 .38908 L F
.81569 .3831 m .81275 .38245 L .8102 .38511 L F
.81275 .38245 m .7929 .37808 L .8102 .38511 L F
.496 .311 .125 r
.8205 .38095 m .80489 .39998 L .80504 .39048 L F
.8102 .38511 m .80504 .39048 L .80509 .38717 L F
.349 .169 .053 r
.81569 .3831 m .81455 .37001 L .7929 .37808 L F
.496 .311 .125 r
.8205 .38095 m .80504 .39048 L .8102 .38511 L F
.8257 .37886 m .82303 .38157 L .8205 .38095 L F
.82303 .38157 m .80489 .39998 L .8205 .38095 L F
.311 .151 .047 r
.83021 .37663 m .81455 .37001 L .81539 .37971 L F
.83021 .37663 m .81539 .37971 L .8205 .38095 L F
.83511 .37444 m .83246 .37387 L .83021 .37663 L F
.83246 .37387 m .81455 .37001 L .83021 .37663 L F
.42 .259 .096 r
.83928 .37213 m .82549 .39181 L .82565 .38221 L F
.83021 .37663 m .82565 .38221 L .8257 .37886 L F
.311 .151 .047 r
.83511 .37444 m .83387 .36124 L .81455 .37001 L F
.42 .259 .096 r
.83928 .37213 m .82565 .38221 L .83021 .37663 L F
.84386 .36987 m .8415 .37269 L .83928 .37213 L F
.8415 .37269 m .82549 .39181 L .83928 .37213 L F
.265 .129 .041 r
.84769 .36748 m .83387 .36124 L .83479 .37102 L F
.84769 .36748 m .83479 .37102 L .83928 .37213 L F
.85194 .36513 m .84961 .36463 L .84769 .36748 L F
.84961 .36463 m .83387 .36124 L .84769 .36748 L F
.324 .195 .064 r
.85541 .36268 m .84363 .38298 L .8438 .37326 L F
.84769 .36748 m .8438 .37326 L .84386 .36987 L F
.265 .129 .041 r
.85194 .36513 m .85062 .35181 L .83387 .36124 L F
.324 .195 .064 r
.85541 .36268 m .8438 .37326 L .84769 .36748 L F
.85931 .36026 m .85729 .36318 L .85541 .36268 L F
.85729 .36318 m .84363 .38298 L .85541 .36268 L F
.207 .101 .033 r
.8624 .35774 m .85062 .35181 L .8516 .36168 L F
.8624 .35774 m .8516 .36168 L .85541 .36268 L F
.86593 .35524 m .86396 .3548 L .8624 .35774 L F
.86396 .3548 m .85062 .35181 L .8624 .35774 L F
.205 .12 .037 r
.86864 .35266 m .85906 .37354 L .85924 .36369 L F
.8624 .35774 m .85924 .36369 L .85931 .36026 L F
.207 .101 .033 r
.86593 .35524 m .86454 .34179 L .85062 .35181 L F
.205 .12 .037 r
.86864 .35266 m .85924 .36369 L .8624 .35774 L F
.87179 .35009 m .87015 .35311 L .86864 .35266 L F
.87015 .35311 m .85906 .37354 L .86864 .35266 L F
.134 .066 .024 r
.87409 .34746 m .86454 .34179 L .86557 .35175 L F
.87409 .34746 m .86557 .35175 L .86864 .35266 L F
.87685 .34483 m .87526 .34444 L .87409 .34746 L F
.87526 .34444 m .86454 .34179 L .87409 .34746 L F
.13 .08 .026 r
.87873 .34215 m .87153 .36356 L .87172 .35358 L F
.87409 .34746 m .87172 .35358 L .87179 .35009 L F
.134 .066 .024 r
.87685 .34483 m .87539 .33124 L .86454 .34179 L F
.13 .08 .026 r
.87873 .34215 m .87172 .35358 L .87409 .34746 L F
.88108 .33946 m .87985 .34256 L .87873 .34215 L F
.87985 .34256 m .87153 .36356 L .87873 .34215 L F
.088 .044 .017 r
.88253 .33673 m .87539 .33124 L .87647 .34131 L F
.88253 .33673 m .87647 .34131 L .87873 .34215 L F
.88445 .33399 m .88328 .33364 L .88253 .33673 L F
.88328 .33364 m .87539 .33124 L .88253 .33673 L F
.88445 .33399 m .88294 .32027 L .87539 .33124 L F
.09 .055 .018 r
.88545 .33122 m .88081 .35312 L .88101 .34299 L F
.88253 .33673 m .88101 .34299 L .88108 .33946 L F
.88545 .33122 m .88101 .34299 L .88253 .33673 L F
.88694 .32844 m .88615 .33161 L .88545 .33122 L F
.88615 .33161 m .88081 .35312 L .88545 .33122 L F
.032 .016 .006 r
.88871 .31299 m .88696 .30895 L .88811 .31922 L F
.88861 .31109 m .88696 .30895 L .88871 .31299 L F
.8886 .31999 m .88811 .31922 L .88851 .32281 L F
.88886 .31141 m .88811 .31922 L .8886 .31999 L F
.031 .019 .006 r
.8887 .32015 m .88666 .34229 L .88686 .33202 L F
.88916 .31713 m .88884 .32037 L .8887 .32015 L F
.88884 .32037 m .88666 .34229 L .8887 .32015 L F
.88916 .31713 m .88686 .33202 L .88749 .32564 L F
.88916 .31713 m .88888 .33119 L .88666 .34229 L F
.032 .016 .006 r
.88886 .31141 m .88728 .2974 L .88696 .30895 L F
.346 .162 .039 r
.88531 .2999 m .88728 .2974 L .88845 .30778 L F
.88798 .30856 m .88845 .30778 L .88886 .31141 L F
.797 .476 .105 r
.88344 .29706 m .88729 .31992 L .8875 .30935 L F
.346 .162 .039 r
.88621 .30281 m .88845 .30778 L .88798 .30856 L F
.88595 .3015 m .88845 .30778 L .88621 .30281 L F
.797 .476 .105 r
.88621 .30281 m .8875 .30935 L .88758 .30566 L F
.88344 .29706 m .8875 .30935 L .88621 .30281 L F
.346 .162 .039 r
.88531 .2999 m .88595 .3015 L .88621 .30281 L F
.628 .373 .074 r
.88788 .30872 m .88888 .33119 L .88909 .32077 L F
.88758 .30566 m .88775 .30895 L .88788 .30872 L F
.88775 .30895 m .88888 .33119 L .88788 .30872 L F
.88877 .31429 m .88909 .32077 L .88916 .31713 L F
.88758 .30566 m .88909 .32077 L .88877 .31429 L F
.032 .016 .006 r
.88886 .31141 m .88861 .31109 L .88871 .31299 L F
.031 .019 .006 r
.88749 .32564 m .88686 .33202 L .88694 .32844 L F
.442 .208 .052 r
.87966 .29132 m .8849 .29623 L .88344 .29706 L F
.797 .476 .105 r
.88204 .29414 m .88272 .29746 L .88344 .29706 L F
.88272 .29746 m .88729 .31992 L .88344 .29706 L F
.442 .208 .052 r
.87966 .29132 m .88373 .28575 L .8849 .29623 L F
.88344 .29706 m .8849 .29623 L .88531 .2999 L F
.87775 .28841 m .87853 .28807 L .87966 .29132 L F
.87853 .28807 m .88373 .28575 L .87966 .29132 L F
1 .716 .271 r
.87487 .28561 m .88176 .30862 L .88197 .29789 L F
.87966 .29132 m .88197 .29789 L .88204 .29414 L F
.87487 .28561 m .88197 .29789 L .87966 .29132 L F
.597 .277 .071 r
.86905 .27995 m .87735 .28471 L .87487 .28561 L F
1 .716 .271 r
.87245 .28272 m .87364 .28606 L .87487 .28561 L F
.87364 .28606 m .88176 .30862 L .87487 .28561 L F
.597 .277 .071 r
.86905 .27995 m .87619 .27412 L .87735 .28471 L F
.87487 .28561 m .87735 .28471 L .87775 .28841 L F
.86611 .27709 m .86741 .27671 L .86905 .27995 L F
.86741 .27671 m .87619 .27412 L .86905 .27995 L F
1 .944 .444 r
.86221 .27437 m .87217 .2974 L .87237 .28652 L F
.86905 .27995 m .87237 .28652 L .87245 .28272 L F
.86221 .27437 m .87237 .28652 L .86905 .27995 L F
.728 .334 .086 r
.85435 .26887 m .86572 .27335 L .86221 .27437 L F
1 .944 .444 r
.85875 .27154 m .86048 .27487 L .86221 .27437 L F
.86048 .27487 m .87217 .2974 L .86221 .27437 L F
.728 .334 .086 r
.85435 .26887 m .86458 .26266 L .86572 .27335 L F
.86221 .27437 m .86572 .27335 L .86611 .27709 L F
.85037 .26609 m .85221 .26565 L .85435 .26887 L F
.85221 .26565 m .86458 .26266 L .85435 .26887 L F
1 1 .56 r
.84546 .26348 m .85848 .28642 L .85868 .27539 L F
.85435 .26887 m .85868 .27539 L .85875 .27154 L F
.84546 .26348 m .85868 .27539 L .85435 .26887 L F
.797 .365 .094 r
.83557 .25822 m .84999 .26231 L .84546 .26348 L F
1 1 .56 r
.84098 .26076 m .84323 .26406 L .84546 .26348 L F
.84323 .26406 m .85848 .28642 L .84546 .26348 L F
.797 .365 .094 r
.83557 .25822 m .84889 .25153 L .84999 .26231 L F
.84546 .26348 m .84999 .26231 L .85037 .26609 L F
.83058 .25556 m .83294 .25504 L .83557 .25822 L F
.83294 .25504 m .84889 .25153 L .83557 .25822 L F
1 1 .619 r
.82469 .25311 m .84072 .27583 L .84091 .26465 L F
.83557 .25822 m .84091 .26465 L .84098 .26076 L F
.82469 .25311 m .84091 .26465 L .83557 .25822 L F
.822 .377 .098 r
.81284 .24816 m .83021 .25175 L .82469 .25311 L F
1 1 .619 r
.8192 .25053 m .82196 .25378 L .82469 .25311 L F
.82196 .25378 m .84072 .27583 L .82469 .25311 L F
.822 .377 .098 r
.81284 .24816 m .82918 .24088 L .83021 .25175 L F
.82469 .25311 m .83021 .25175 L .83058 .25556 L F
.80685 .24567 m .80973 .24505 L .81284 .24816 L F
.80973 .24505 m .82918 .24088 L .81284 .24816 L F
1 1 .64 r
.80004 .24341 m .81895 .26578 L .81913 .25447 L F
.81284 .24816 m .81913 .25447 L .8192 .25053 L F
.80004 .24341 m .81913 .25447 L .81284 .24816 L F
.82 .376 .099 r
.78632 .23886 m .80652 .24183 L .80004 .24341 L F
1 1 .64 r
.79358 .24101 m .79684 .24419 L .80004 .24341 L F
.79684 .24419 m .81895 .26578 L .80004 .24341 L F
.82 .376 .099 r
.78632 .23886 m .80555 .23087 L .80652 .24183 L F
.80004 .24341 m .80652 .24183 L .80685 .24567 L F
.7794 .23657 m .78277 .23583 L .78632 .23886 L F
.78277 .23583 m .80555 .23087 L .78632 .23886 L F
1 1 .636 r
.77172 .23454 m .79335 .25644 L .79352 .245 L F
.78632 .23886 m .79352 .245 L .79358 .24101 L F
.77172 .23454 m .79352 .245 L .78632 .23886 L F
.803 .368 .098 r
.75627 .23047 m .77909 .2327 L .77172 .23454 L F
1 1 .636 r
.76435 .23237 m .76807 .23545 L .77172 .23454 L F
.76807 .23545 m .79335 .25644 L .77172 .23454 L F
.803 .368 .098 r
.75627 .23047 m .77821 .22166 L .77909 .2327 L F
.77172 .23454 m .77909 .2327 L .7794 .23657 L F
.74849 .22842 m .75231 .22755 L .75627 .23047 L F
.75231 .22755 m .77821 .22166 L .75627 .23047 L F
1 1 .62 r
.74003 .22667 m .76415 .24795 L .7643 .2364 L F
.75627 .23047 m .7643 .2364 L .76435 .23237 L F
.74003 .22667 m .7643 .2364 L .75627 .23047 L F
.777 .357 .096 r
.72304 .22314 m .74822 .22453 L .74003 .22667 L F
1 1 .62 r
.73185 .22475 m .73599 .22772 L .74003 .22667 L F
.73599 .22772 m .76415 .24795 L .74003 .22667 L F
.777 .357 .096 r
.72304 .22314 m .74744 .21342 L .74822 .22453 L F
.74003 .22667 m .74822 .22453 L .74849 .22842 L F
.71448 .22137 m .71872 .22035 L .72304 .22314 L F
.768 .412 .117 r
.74041 .20924 m .71791 .21856 L .73922 .21668 L F
.777 .357 .096 r
.71872 .22035 m .74744 .21342 L .72304 .22314 L F
1 1 .596 r
.70535 .21992 m .73167 .24047 L .7318 .22881 L F
.72304 .22314 m .7318 .22881 L .73185 .22475 L F
.70535 .21992 m .7318 .22881 L .72304 .22314 L F
.746 .343 .093 r
.68703 .217 m .71425 .21745 L .70535 .21992 L F
1 1 .596 r
.69645 .21829 m .70096 .22113 L .70535 .21992 L F
.70096 .22113 m .73167 .24047 L .70535 .21992 L F
.746 .343 .093 r
.68703 .217 m .7136 .20628 L .71425 .21745 L F
.70535 .21992 m .71425 .21745 L .71448 .22137 L F
.67782 .21554 m .68241 .21435 L .68703 .217 L F
.852 .455 .127 r
.71472 .19854 m .69177 .20599 L .69457 .21176 L F
.746 .343 .093 r
.68241 .21435 m .7136 .20628 L .68703 .217 L F
1 .98 .568 r
.66814 .21442 m .69631 .23413 L .69641 .22239 L F
.68703 .217 m .69641 .22239 L .69645 .21829 L F
.66814 .21442 m .69641 .22239 L .68703 .217 L F
.713 .328 .09 r
.64874 .21218 m .67763 .21161 L .66814 .21442 L F
1 .98 .568 r
.65864 .21312 m .66346 .21581 L .66814 .21442 L F
.66346 .21581 m .69631 .23413 L .66814 .21442 L F
.713 .328 .09 r
.64874 .21218 m .67711 .20039 L .67763 .21161 L F
.66814 .21442 m .67763 .21161 L .67782 .21554 L F
.63899 .21105 m .64388 .20968 L .64874 .21218 L F
.969 .508 .141 r
.67303 .18951 m .65761 .20802 L .68097 .19479 L F
.67303 .18951 m .65084 .20365 L .65761 .20802 L F
.713 .328 .09 r
.64388 .20968 m .67711 .20039 L .64874 .21218 L F
1 .93 .537 r
.62891 .21028 m .65853 .22905 L .65861 .21724 L F
.64874 .21218 m .65861 .21724 L .65864 .21312 L F
.62891 .21028 m .65861 .21724 L .64874 .21218 L F
.679 .313 .087 r
.60872 .20875 m .63886 .20711 L .62891 .21028 L F
1 .93 .537 r
.61895 .20933 m .624 .21185 L .62891 .21028 L F
.624 .21185 m .65853 .22905 L .62891 .21028 L F
.679 .313 .087 r
.60872 .20875 m .63848 .19585 L .63886 .20711 L F
.62891 .21028 m .63886 .20711 L .63899 .21105 L F
.59858 .20799 m .60369 .20643 L .60872 .20875 L F
.60369 .20643 m .63848 .19585 L .60872 .20875 L F
1 .878 .504 r
.58824 .20759 m .61888 .22534 L .61893 .21347 L F
.60872 .20875 m .61893 .21347 L .61895 .20933 L F
.58824 .20759 m .61893 .21347 L .60872 .20875 L F
.643 .297 .083 r
.56756 .2068 m .5985 .20403 L .58824 .20759 L F
1 .878 .504 r
.57797 .20701 m .58318 .20935 L .58824 .20759 L F
1 .512 .142 r
.59489 .21226 m .57548 .24523 L .58171 .24677 L F
.99 .501 .14 r
.58504 .21025 m .57548 .24523 L .59489 .21226 L F
1 .878 .504 r
.58318 .20935 m .61888 .22534 L .58824 .20759 L F
.643 .297 .083 r
.56756 .2068 m .59826 .19275 L .5985 .20403 L F
.58824 .20759 m .5985 .20403 L .59858 .20799 L F
.55719 .20641 m .56244 .20466 L .56756 .2068 L F
.56244 .20466 m .59826 .19275 L .56756 .2068 L F
1 .825 .47 r
.54675 .20639 m .57793 .22305 L .57796 .21116 L F
.56756 .2068 m .57796 .21116 L .57797 .20701 L F
.54675 .20639 m .57796 .21116 L .56756 .2068 L F
.605 .28 .079 r
.52589 .20637 m .55716 .20245 L .54675 .20639 L F
1 .825 .47 r
.53632 .20619 m .54162 .20834 L .54675 .20639 L F
.54162 .20834 m .57793 .22305 L .54675 .20639 L F
.605 .28 .079 r
.52589 .20637 m .55708 .19115 L .55716 .20245 L F
.54675 .20639 m .55716 .20245 L .55719 .20641 L F
.51544 .20635 m .52076 .20441 L .52589 .20637 L F
.52076 .20441 m .55708 .19115 L .52589 .20637 L F
1 .771 .434 r
.50506 .20672 m .53632 .22225 L .53632 .21034 L F
.52589 .20637 m .53632 .21034 L .53632 .20619 L F
.50506 .20672 m .53632 .21034 L .52589 .20637 L F
.567 .262 .075 r
.48436 .20745 m .51547 .20239 L .50506 .20672 L F
1 .771 .434 r
.49465 .2069 m .49994 .20885 L .50506 .20672 L F
.49994 .20885 m .53632 .22225 L .50506 .20672 L F
.567 .262 .075 r
.48436 .20745 m .51554 .1911 L .51547 .20239 L F
.50506 .20672 m .51547 .20239 L .51544 .20635 L F
.474 .20782 m .4793 .20568 L .48436 .20745 L F
.4793 .20568 m .51554 .1911 L .48436 .20745 L F
1 .715 .397 r
.46384 .20856 m .49468 .22294 L .49465 .21104 L F
.48436 .20745 m .49465 .21104 L .49465 .2069 L F
.46384 .20856 m .49465 .21104 L .48436 .20745 L F
.526 .244 .07 r
.4436 .21003 m .47408 .20386 L .46384 .20856 L F
1 .715 .397 r
.45359 .20911 m .45881 .21087 L .46384 .20856 L F
.45881 .21087 m .49468 .22294 L .46384 .20856 L F
.526 .244 .07 r
.4436 .21003 m .4743 .19258 L .47408 .20386 L F
.46384 .20856 m .47408 .20386 L .474 .20782 L F
.43349 .21077 m .43869 .20845 L .4436 .21003 L F
.43869 .20845 m .4743 .19258 L .4436 .21003 L F
.953 .658 .359 r
.42371 .21187 m .45366 .22512 L .45361 .21325 L F
.4436 .21003 m .45361 .21325 L .45359 .20911 L F
.42371 .21187 m .45361 .21325 L .4436 .21003 L F
.484 .225 .066 r
.40425 .21406 m .43363 .20683 L .42371 .21187 L F
.953 .658 .359 r
.41379 .21279 m .41884 .21435 L .42371 .21187 L F
.41884 .21435 m .45366 .22512 L .42371 .21187 L F
.484 .225 .066 r
.40425 .21406 m .434 .19557 L .43363 .20683 L F
.42371 .21187 m .43363 .20683 L .43349 .21077 L F
.39454 .21516 m .39955 .21267 L .40425 .21406 L F
.696 .366 .109 r
.38909 .19439 m .41238 .20769 L .41925 .20333 L F
.38909 .19439 m .41925 .20333 L .39715 .18913 L F
.72 .378 .113 r
.39715 .18913 m .41925 .20333 L .42745 .19924 L F
.39715 .18913 m .42745 .19924 L .40681 .18417 L F
.484 .225 .066 r
.39955 .21267 m .434 .19557 L .40425 .21406 L F
.879 .599 .318 r
.38528 .2166 m .41389 .22873 L .41381 .21691 L F
.40425 .21406 m .41381 .21691 L .41379 .21279 L F
.38528 .2166 m .41381 .21691 L .40425 .21406 L F
.44 .205 .061 r
.36687 .21946 m .39472 .21123 L .38528 .2166 L F
.879 .599 .318 r
.37582 .21786 m .38064 .21924 L .38528 .2166 L F
.38064 .21924 m .41389 .22873 L .38528 .2166 L F
.44 .205 .061 r
.36687 .21946 m .39523 .2 L .39472 .21123 L F
.38528 .2166 m .39472 .21123 L .39454 .21516 L F
.35769 .22089 m .36246 .21824 L .36687 .21946 L F
.36246 .21824 m .39523 .2 L .36687 .21946 L F
.801 .537 .276 r
.34908 .22264 m .37596 .23371 L .37585 .22196 L F
.36687 .21946 m .37585 .22196 L .37582 .21786 L F
.34908 .22264 m .37585 .22196 L .36687 .21946 L F
.394 .184 .055 r
.33198 .22612 m .35792 .21697 L .34908 .22264 L F
.801 .537 .276 r
.34022 .22423 m .34474 .22542 L .34908 .22264 L F
.34474 .22542 m .37596 .23371 L .34908 .22264 L F
.394 .184 .055 r
.33198 .22612 m .35856 .2058 L .35792 .21697 L F
.34908 .22264 m .35792 .21697 L .35769 .22089 L F
.32347 .22786 m .32792 .22506 L .33198 .22612 L F
.682 .365 .107 r
.33014 .21613 m .35072 .21141 L .32911 .20868 L F
.694 .371 .108 r
.32911 .20868 m .35072 .21141 L .35192 .20472 L F
.394 .184 .055 r
.32792 .22506 m .35856 .2058 L .33198 .22612 L F
.72 .474 .233 r
.31563 .22989 m .3404 .23996 L .34027 .22829 L F
.33198 .22612 m .34027 .22829 L .34022 .22423 L F
.31563 .22989 m .34027 .22829 L .33198 .22612 L F
.347 .163 .049 r
.30006 .23392 m .32374 .22396 L .31563 .22989 L F
.72 .474 .233 r
.30749 .23176 m .31164 .2328 L .31563 .22989 L F
.842 .448 .127 r
.31107 .24439 m .32772 .23993 L .31973 .23246 L F
.72 .474 .233 r
.31164 .2328 m .3404 .23996 L .31563 .22989 L F
.347 .163 .049 r
.30006 .23392 m .3245 .21285 L .32374 .22396 L F
.31563 .22989 m .32374 .22396 L .32347 .22786 L F
.29232 .23593 m .29639 .233 L .30006 .23392 L F
.29639 .233 m .3245 .21285 L .30006 .23392 L F
.636 .412 .191 r
.28533 .2382 m .30769 .24736 L .30754 .2358 L F
.30006 .23392 m .30754 .2358 L .30749 .23176 L F
.28533 .2382 m .30754 .2358 L .30006 .23392 L F
.3 .142 .044 r
.27148 .24272 m .29262 .23206 L .28533 .2382 L F
.636 .412 .191 r
.27801 .24033 m .28175 .24122 L .28533 .2382 L F
.978 .513 .141 r
.28156 .25813 m .29568 .25053 L .28613 .24199 L F
.636 .412 .191 r
.28175 .24122 m .30769 .24736 L .28533 .2382 L F
.3 .142 .044 r
.27148 .24272 m .29349 .22101 L .29262 .23206 L F
.28533 .2382 m .29262 .23206 L .29232 .23593 L F
.26459 .24496 m .26825 .24193 L .27148 .24272 L F
.872 .464 .129 r
.279 .23308 m .29165 .21932 L .27442 .22387 L F
.3 .142 .044 r
.26825 .24193 m .29349 .22101 L .27148 .24272 L F
.554 .353 .153 r
.25854 .24744 m .27823 .25577 L .27806 .24433 L F
.27148 .24272 m .27806 .24433 L .27801 .24033 L F
.25854 .24744 m .27806 .24433 L .27148 .24272 L F
.252 .119 .037 r
.24654 .25236 m .26493 .24112 L .25854 .24744 L F
.554 .353 .153 r
.25211 .24979 m .2554 .25054 L .25854 .24744 L F
.2554 .25054 m .27823 .25577 L .25854 .24744 L F
.252 .119 .037 r
.24654 .25236 m .26589 .23015 L .26493 .24112 L F
.25854 .24744 m .26493 .24112 L .26459 .24496 L F
.24058 .2548 m .24378 .25168 L .24654 .25236 L F
.95 .5 .135 r
.24952 .2479 m .25855 .23008 L .24408 .23778 L F
.252 .119 .037 r
.24378 .25168 m .26589 .23015 L .24654 .25236 L F
.472 .297 .119 r
.23551 .25745 m .25235 .26506 L .25217 .25374 L F
.24654 .25236 m .25217 .25374 L .25211 .24979 L F
.23551 .25745 m .25217 .25374 L .24654 .25236 L F
.196 .092 .03 r
.22547 .26269 m .24094 .25099 L .23551 .25745 L F
.472 .297 .119 r
.23004 .25997 m .23285 .26061 L .23551 .25745 L F
.23285 .26061 m .25235 .26506 L .23551 .25745 L F
.196 .092 .03 r
.22547 .26269 m .24198 .24011 L .24094 .25099 L F
.23551 .25745 m .24094 .25099 L .24058 .2548 L F
.22049 .26529 m .2232 .26211 L .22547 .26269 L F
.2232 .26211 m .24198 .24011 L .22547 .26269 L F
.37 .228 .082 r
.21644 .26806 m .23029 .27506 L .2301 .26387 L F
.22547 .26269 m .2301 .26387 L .23004 .25997 L F
.21644 .26806 m .2301 .26387 L .22547 .26269 L F
.127 .058 .021 r
.20842 .27354 m .22087 .26151 L .21644 .26806 L F
.37 .228 .082 r
.21196 .27072 m .21426 .27127 L .21644 .26806 L F
.21426 .27127 m .23029 .27506 L .21644 .26806 L F
.127 .058 .021 r
.20842 .27354 m .22196 .25072 L .22087 .26151 L F
.21644 .26806 m .22087 .26151 L .22049 .26529 L F
.20445 .27626 m .20666 .27304 L .20842 .27354 L F
.20666 .27304 m .22196 .25072 L .20842 .27354 L F
.242 .145 .045 r
.20143 .27912 m .21223 .28561 L .21203 .27457 L F
.20842 .27354 m .21203 .27457 L .21196 .27072 L F
.20143 .27912 m .21203 .27457 L .20842 .27354 L F
.07 .035 .014 r
.19546 .28476 m .20484 .27252 L .20143 .27912 L F
.242 .145 .045 r
.19796 .28188 m .19975 .28235 L .20143 .27912 L F
.87 .436 .112 r
.20147 .30383 m .20796 .29112 L .20118 .28007 L F
.242 .145 .045 r
.19975 .28235 m .21223 .28561 L .20143 .27912 L F
.07 .035 .014 r
.19546 .28476 m .20597 .26182 L .20484 .27252 L F
.20143 .27912 m .20484 .27252 L .20445 .27626 L F
.1925 .28756 m .1942 .28431 L .19546 .28476 L F
.1942 .28431 m .20597 .26182 L .19546 .28476 L F
.141 .086 .028 r
.19051 .29046 m .19824 .29657 L .19803 .28568 L F
.19546 .28476 m .19803 .28568 L .19796 .28188 L F
.19051 .29046 m .19803 .28568 L .19546 .28476 L F
.045 .023 .009 r
.18659 .2962 m .19406 .27326 L .1929 .28385 L F
.18659 .2962 m .1929 .28385 L .19051 .29046 L F
.141 .086 .028 r
.18806 .29329 m .18934 .2937 L .19051 .29046 L F
.18934 .2937 m .19824 .29657 L .19051 .29046 L F
.045 .023 .009 r
.19051 .29046 m .1929 .28385 L .1925 .28756 L F
.18464 .29904 m .18583 .29579 L .18659 .2962 L F
.18583 .29579 m .19406 .27326 L .18659 .2962 L F
.101 .062 .02 r
.18367 .30195 m .18834 .30777 L .18813 .29703 L F
.18659 .2962 m .18813 .29703 L .18806 .29329 L F
.18367 .30195 m .18813 .29703 L .18659 .2962 L F
.011 .005 .002 r
.18175 .3077 m .18622 .28488 L .18505 .29537 L F
.18175 .3077 m .18505 .29537 L .18367 .30195 L F
.18148 .30732 m .18622 .28488 L .18175 .3077 L F
.101 .062 .02 r
.18222 .3048 m .18299 .30518 L .18367 .30195 L F
.18299 .30518 m .18834 .30777 L .18367 .30195 L F
.011 .005 .002 r
.18367 .30195 m .18505 .29537 L .18464 .29904 L F
.1808 .31055 m .18148 .30732 L .18175 .3077 L F
.042 .026 .008 r
.18081 .31344 m .18251 .31908 L .1823 .30849 L F
.18175 .3077 m .1823 .30849 L .18222 .3048 L F
.18081 .31344 m .1823 .30849 L .18175 .3077 L F
.18035 .31628 m .18062 .31663 L .18081 .31344 L F
.18062 .31663 m .18251 .31908 L .18081 .31344 L F
.608 .358 .071 r
.18182 .3248 m .18063 .33036 L .18042 .31992 L F
.18084 .31914 m .18042 .31992 L .18035 .31628 L F
.18182 .3248 m .18042 .31992 L .18084 .31914 L F
.1823 .3276 m .18209 .32795 L .18182 .3248 L F
.18209 .32795 m .18063 .33036 L .18182 .3248 L F
.771 .456 .098 r
.18651 .33591 m .18237 .33119 L .18371 .3304 L F
.18789 .33865 m .18722 .339 L .18651 .33591 L F
.18722 .339 m .18257 .34147 L .18651 .33591 L F
1 .669 .242 r
.19469 .34668 m .18796 .34218 L .19018 .34134 L F
.19693 .34932 m .19583 .34969 L .19469 .34668 L F
.19583 .34969 m .18816 .35232 L .19469 .34668 L F
1 .883 .403 r
.20615 .35699 m .197 .3528 L .20003 .35189 L F
.20919 .35952 m .20768 .35993 L .20615 .35699 L F
.20768 .35993 m .19719 .3628 L .20615 .35699 L F
1 1 .514 r
.22064 .36678 m .20925 .36296 L .21303 .36195 L F
.22442 .36917 m .22253 .36963 L .22064 .36678 L F
.22253 .36963 m .20943 .37282 L .22064 .36678 L F
1 1 .578 r
.23793 .37597 m .22448 .37256 L .22895 .37145 L F
.24238 .37821 m .24015 .37872 L .23793 .37597 L F
.24015 .37872 m .22465 .3823 L .23793 .37597 L F
1 1 .608 r
.25775 .3845 m .24244 .38156 L .24754 .38032 L F
.26282 .38657 m .26027 .38715 L .25775 .3845 L F
.26027 .38715 m .2426 .39117 L .25775 .3845 L F
1 1 .616 r
.27986 .39232 m .26287 .38989 L .26854 .3885 L F
.28549 .39422 m .28266 .39487 L .27986 .39232 L F
.28266 .39487 m .26302 .39939 L .27986 .39232 L F
1 1 .611 r
.30401 .39939 m .28553 .3975 L .29169 .39595 L F
.31013 .4011 m .30704 .40183 L .30401 .39939 L F
.30704 .40183 m .28567 .4069 L .30401 .39939 L F
1 1 .598 r
.32994 .40568 m .31017 .40435 L .31676 .40263 L F
.33649 .40719 m .33318 .40801 L .32994 .40568 L F
.33318 .40801 m .31029 .41366 L .32994 .40568 L F
1 1 .58 r
.35741 .41115 m .33653 .41041 L .34349 .40851 L F
.36434 .41246 m .36083 .41336 L .35741 .41115 L F
.36083 .41336 m .33663 .41964 L .35741 .41115 L F
1 .974 .559 r
.38618 .41578 m .36437 .41565 L .37165 .41357 L F
.39342 .41688 m .38976 .41788 L .38618 .41578 L F
.38976 .41788 m .36445 .42481 L .38618 .41578 L F
1 .936 .536 r
.41602 .41956 m .39345 .42005 L .40098 .41777 L F
.42353 .42044 m .41973 .42155 L .41602 .41956 L F
.41973 .42155 m .39352 .42916 L .41602 .41956 L F
1 .897 .512 r
.4467 .42246 m .42355 .4236 L .43127 .42112 L F
.45441 .42314 m .4505 .42434 L .4467 .42246 L F
.4505 .42434 m .4236 .43266 L .4467 .42246 L F
1 .857 .488 r
.478 .42449 m .45442 .42628 L .46229 .42359 L F
.48585 .42495 m .48187 .42626 L .478 .42449 L F
.48187 .42626 m .45446 .4353 L .478 .42449 L F
1 .817 .462 r
.50969 .42564 m .48586 .42808 L .49381 .42518 L F
.51763 .42587 m .51359 .42729 L .50969 .42564 L F
.51359 .42729 m .48588 .43708 L .50969 .42564 L F
.688 .324 .092 r
.52561 .42588 m .50184 .413 L .50174 .42227 L F
.52561 .42588 m .50174 .42227 L .50969 .42564 L F
.53357 .426 m .52953 .42434 L .52561 .42588 L F
.52953 .42434 m .50184 .413 L .52561 .42588 L F
1 .777 .435 r
.54154 .42589 m .51764 .43799 L .51763 .429 L F
.52561 .42588 m .51763 .429 L .51763 .42587 L F
.54154 .42589 m .51763 .429 L .52561 .42588 L F
.54952 .4259 m .54547 .42744 L .54154 .42589 L F
.54547 .42744 m .51764 .43799 L .54154 .42589 L F
.776 .372 .105 r
.50211 .40022 m .47169 .38591 L .47086 .39883 L F
.747 .355 .1 r
.50184 .413 m .50211 .40022 L .47086 .39883 L F
.775 .378 .108 r
.56416 .37446 m .5635 .36165 L .53365 .36208 L F
.748 .366 .105 r
.59449 .37312 m .5635 .36165 L .56416 .37446 L F
.72 .349 .1 r
.59556 .38604 m .59449 .37312 L .56416 .37446 L F
.828 .404 .114 r
.5031 .37439 m .47418 .36019 L .47279 .37298 L F
.5031 .37439 m .50381 .36159 L .47418 .36019 L F
.747 .355 .1 r
.50184 .413 m .47086 .39883 L .47032 .41162 L F
.826 .406 .116 r
.53365 .36208 m .50466 .34904 L .50381 .36159 L F
.53365 .36208 m .53368 .34952 L .50466 .34904 L F
.801 .394 .113 r
.5635 .36165 m .53368 .34952 L .53365 .36208 L F
1 .777 .435 r
.54952 .4259 m .54951 .43802 L .51764 .43799 L F
1 .817 .462 r
.51763 .42587 m .51764 .43799 L .48588 .43708 L F
.692 .336 .097 r
.626 .3838 m .59449 .37312 L .59556 .38604 L F
.662 .319 .092 r
.6272 .39672 m .59556 .38604 L .59635 .39896 L F
.6272 .39672 m .626 .3838 L .59556 .38604 L F
.631 .301 .087 r
.62798 .40953 m .59635 .39896 L .59687 .41175 L F
.62798 .40953 m .6272 .39672 L .59635 .39896 L F
.801 .394 .113 r
.5635 .36165 m .56271 .34911 L .53368 .34952 L F
.776 .382 .11 r
.59315 .36033 m .56271 .34911 L .5635 .36165 L F
.748 .366 .105 r
.59449 .37312 m .59315 .36033 L .5635 .36165 L F
.83 .401 .113 r
.47169 .38591 m .44293 .37067 L .44128 .38359 L F
.47169 .38591 m .47279 .37298 L .44293 .37067 L F
.804 .385 .108 r
.47086 .39883 m .47169 .38591 L .44128 .38359 L F
.852 .419 .119 r
.50381 .36159 m .47585 .34766 L .47418 .36019 L F
.50381 .36159 m .50466 .34904 L .47585 .34766 L F
.804 .385 .108 r
.47086 .39883 m .44128 .38359 L .44005 .39652 L F
.776 .368 .103 r
.47032 .41162 m .47086 .39883 L .44005 .39652 L F
.722 .353 .102 r
.62439 .37088 m .59315 .36033 L .59449 .37312 L F
.692 .336 .097 r
.626 .3838 m .62439 .37088 L .59449 .37312 L F
.855 .417 .117 r
.47279 .37298 m .445 .35789 L .44293 .37067 L F
.47279 .37298 m .47418 .36019 L .445 .35789 L F
.776 .368 .103 r
.47032 .41162 m .44005 .39652 L .43925 .40933 L F
1 .735 .408 r
.58132 .42504 m .58129 .43718 L .54951 .43802 L F
1 .857 .488 r
.48585 .42495 m .48588 .43708 L .45446 .4353 L F
.85 .422 .12 r
.53368 .34952 m .50565 .33688 L .50466 .34904 L F
.53368 .34952 m .53372 .33736 L .50565 .33688 L F
.826 .41 .118 r
.56271 .34911 m .53372 .33736 L .53368 .34952 L F
1 .714 .385 r
.54951 .43802 m .51773 .44959 L .51764 .43799 L F
.54951 .43802 m .54944 .44962 L .51773 .44959 L F
.989 .673 .358 r
.58129 .43718 m .54944 .44962 L .54951 .43802 L F
1 .753 .411 r
.51764 .43799 m .48614 .4487 L .48588 .43708 L F
.51764 .43799 m .51773 .44959 L .48614 .4487 L F
.776 .382 .11 r
.59315 .36033 m .59154 .34779 L .56271 .34911 L F
.75 .371 .107 r
.62238 .3581 m .59154 .34779 L .59315 .36033 L F
.722 .353 .102 r
.62439 .37088 m .62238 .3581 L .59315 .36033 L F
.878 .431 .122 r
.47418 .36019 m .44747 .34539 L .445 .35789 L F
.47418 .36019 m .47585 .34766 L .44747 .34539 L F
.826 .41 .118 r
.56271 .34911 m .56179 .33695 L .53372 .33736 L F
.802 .399 .115 r
.59154 .34779 m .56179 .33695 L .56271 .34911 L F
.874 .434 .123 r
.50466 .34904 m .47779 .33553 L .47585 .34766 L F
.50466 .34904 m .50565 .33688 L .47779 .33553 L F
.989 .673 .358 r
.58129 .43718 m .58104 .4488 L .54944 .44962 L F
.935 .631 .33 r
.61274 .43547 m .58104 .4488 L .58129 .43718 L F
1 .692 .379 r
.61279 .4233 m .61274 .43547 L .58129 .43718 L F
1 .792 .435 r
.48588 .43708 m .45489 .44696 L .45446 .4353 L F
.48588 .43708 m .48614 .4487 L .45489 .44696 L F
.664 .323 .094 r
.6558 .38065 m .62439 .37088 L .626 .3838 L F
.633 .305 .089 r
.6574 .39359 m .626 .3838 L .6272 .39672 L F
.6574 .39359 m .6558 .38065 L .626 .3838 L F
.601 .288 .084 r
.65844 .40643 m .6272 .39672 L .62798 .40953 L F
.65844 .40643 m .6574 .39359 L .6272 .39672 L F
.859 .415 .116 r
.44128 .38359 m .41372 .36746 L .41154 .38038 L F
.44128 .38359 m .44293 .37067 L .41372 .36746 L F
.833 .399 .111 r
.44005 .39652 m .44128 .38359 L .41154 .38038 L F
.44005 .39652 m .41154 .38038 L .40991 .39332 L F
.804 .382 .106 r
.43925 .40933 m .44005 .39652 L .40991 .39332 L F
.695 .341 .1 r
.65366 .36773 m .62238 .3581 L .62439 .37088 L F
.664 .323 .094 r
.6558 .38065 m .65366 .36773 L .62439 .37088 L F
1 .897 .512 r
.45441 .42314 m .45446 .4353 L .4236 .43266 L F
.802 .399 .115 r
.59154 .34779 m .58967 .33566 L .56179 .33695 L F
.779 .388 .113 r
.61996 .34559 m .58967 .33566 L .59154 .34779 L F
.75 .371 .107 r
.62238 .3581 m .61996 .34559 L .59154 .34779 L F
.882 .43 .12 r
.44293 .37067 m .41645 .3547 L .41372 .36746 L F
.44293 .37067 m .445 .35789 L .41645 .3547 L F
.898 .446 .126 r
.47585 .34766 m .45035 .3333 L .44747 .34539 L F
.47585 .34766 m .47779 .33553 L .45035 .3333 L F
.804 .382 .106 r
.43925 .40933 m .40991 .39332 L .40885 .40616 L F
.968 .646 .331 r
.54944 .44962 m .5179 .46054 L .51773 .44959 L F
.54944 .44962 m .54929 .46057 L .5179 .46054 L F
.918 .606 .305 r
.58104 .4488 m .54929 .46057 L .54944 .44962 L F
1 .684 .356 r
.51773 .44959 m .48662 .45968 L .48614 .4487 L F
.51773 .44959 m .5179 .46054 L .48662 .45968 L F
.871 .437 .125 r
.53372 .33736 m .50677 .32526 L .50565 .33688 L F
.53372 .33736 m .53376 .32572 L .50677 .32526 L F
.85 .426 .122 r
.56179 .33695 m .53376 .32572 L .53372 .33736 L F
.56179 .33695 m .56075 .32533 L .53376 .32572 L F
.828 .415 .12 r
.58967 .33566 m .56075 .32533 L .56179 .33695 L F
.725 .359 .105 r
.65097 .35497 m .61996 .34559 L .62238 .3581 L F
.695 .341 .1 r
.65366 .36773 m .65097 .35497 L .62238 .3581 L F
.894 .447 .127 r
.50565 .33688 m .48 .32394 L .47779 .33553 L F
.50565 .33688 m .50677 .32526 L .48 .32394 L F
.904 .444 .125 r
.445 .35789 m .41973 .34224 L .41645 .3547 L F
.445 .35789 m .44747 .34539 L .41973 .34224 L F
.935 .631 .33 r
.61274 .43547 m .61233 .44712 L .58104 .4488 L F
.88 .587 .3 r
.64365 .43289 m .61233 .44712 L .61274 .43547 L F
.945 .648 .349 r
.64372 .42067 m .64365 .43289 L .61274 .43547 L F
.918 .606 .305 r
.58104 .4488 m .58058 .45977 L .54929 .46057 L F
.864 .565 .278 r
.61233 .44712 m .58058 .45977 L .58104 .4488 L F
1 .72 .379 r
.48614 .4487 m .45568 .45798 L .45489 .44696 L F
.48614 .4487 m .48662 .45968 L .45568 .45798 L F
1 .83 .459 r
.45446 .4353 m .42419 .44438 L .4236 .43266 L F
.45446 .4353 m .45489 .44696 L .42419 .44438 L F
.828 .415 .12 r
.58967 .33566 m .58754 .32407 L .56075 .32533 L F
.806 .405 .118 r
.61715 .3335 m .58754 .32407 L .58967 .33566 L F
.779 .388 .113 r
.61996 .34559 m .61715 .3335 L .58967 .33566 L F
.916 .459 .13 r
.47779 .33553 m .45364 .32177 L .45035 .3333 L F
.47779 .33553 m .48 .32394 L .45364 .32177 L F
.755 .377 .11 r
.64775 .3425 m .61715 .3335 L .61996 .34559 L F
.725 .359 .105 r
.65097 .35497 m .64775 .3425 L .61996 .34559 L F
.923 .458 .129 r
.44747 .34539 m .42354 .33021 L .41973 .34224 L F
.44747 .34539 m .45035 .3333 L .42354 .33021 L F
.888 .572 .275 r
.54929 .46057 m .51814 .47071 L .5179 .46054 L F
.54929 .46057 m .54908 .47074 L .51814 .47071 L F
.838 .535 .25 r
.58058 .45977 m .54908 .47074 L .54929 .46057 L F
.935 .608 .298 r
.5179 .46054 m .48733 .46988 L .48662 .45968 L F
.5179 .46054 m .51814 .47071 L .48733 .46988 L F
.636 .31 .091 r
.68473 .37661 m .65366 .36773 L .6558 .38065 L F
.603 .292 .086 r
.68672 .38957 m .6558 .38065 L .6574 .39359 L F
.68672 .38957 m .68473 .37661 L .6558 .38065 L F
.57 .273 .08 r
.68802 .40244 m .6574 .39359 L .65844 .40643 L F
.68802 .40244 m .68672 .38957 L .6574 .39359 L F
1 .936 .536 r
.42353 .42044 m .4236 .43266 L .39352 .42916 L F
.889 .45 .129 r
.53376 .32572 m .50804 .31433 L .50677 .32526 L F
.53376 .32572 m .5338 .31478 L .50804 .31433 L F
.87 .441 .127 r
.56075 .32533 m .5338 .31478 L .53376 .32572 L F
.887 .429 .119 r
.41154 .38038 m .38539 .36336 L .38268 .37628 L F
.41154 .38038 m .41372 .36746 L .38539 .36336 L F
.862 .413 .114 r
.40991 .39332 m .41154 .38038 L .38268 .37628 L F
.668 .328 .097 r
.68206 .3637 m .65097 .35497 L .65366 .36773 L F
.636 .31 .091 r
.68473 .37661 m .68206 .3637 L .65366 .36773 L F
.862 .413 .114 r
.40991 .39332 m .38268 .37628 L .38066 .38924 L F
.833 .395 .109 r
.40885 .40616 m .40991 .39332 L .38066 .38924 L F
.864 .565 .278 r
.61233 .44712 m .61156 .45814 L .58058 .45977 L F
.809 .522 .249 r
.64307 .4446 m .61156 .45814 L .61233 .44712 L F
.88 .587 .3 r
.64365 .43289 m .64307 .4446 L .61233 .44712 L F
1 .755 .401 r
.45489 .44696 m .42529 .45546 L .42419 .44438 L F
.45489 .44696 m .45568 .45798 L .42529 .45546 L F
.87 .441 .127 r
.56075 .32533 m .55957 .31439 L .5338 .31478 L F
.85 .431 .124 r
.58754 .32407 m .55957 .31439 L .56075 .32533 L F
.91 .444 .123 r
.41372 .36746 m .38878 .35063 L .38539 .36336 L F
.41372 .36746 m .41645 .3547 L .38878 .35063 L F
.909 .46 .131 r
.50677 .32526 m .48248 .31305 L .48 .32394 L F
.50677 .32526 m .50804 .31433 L .48248 .31305 L F
.838 .535 .25 r
.58058 .45977 m .57991 .46997 L .54908 .47074 L F
.786 .496 .224 r
.61156 .45814 m .57991 .46997 L .58058 .45977 L F
.833 .395 .109 r
.40885 .40616 m .38066 .38924 L .37935 .40211 L F
.979 .641 .319 r
.48662 .45968 m .45684 .46823 L .45568 .45798 L F
.48662 .45968 m .48733 .46988 L .45684 .46823 L F
.699 .347 .102 r
.67872 .35096 m .64775 .3425 L .65097 .35497 L F
.668 .328 .097 r
.68206 .3637 m .67872 .35096 L .65097 .35497 L F
.822 .541 .269 r
.67379 .42945 m .64307 .4446 L .64365 .43289 L F
.888 .603 .319 r
.67389 .41717 m .67379 .42945 L .64365 .43289 L F
.806 .405 .118 r
.61715 .3335 m .61394 .32196 L .58754 .32407 L F
.784 .395 .115 r
.64401 .33047 m .61394 .32196 L .61715 .3335 L F
.755 .377 .11 r
.64775 .3425 m .64401 .33047 L .61715 .3335 L F
.931 .458 .128 r
.41645 .3547 m .39284 .33822 L .38878 .35063 L F
.41645 .3547 m .41973 .34224 L .39284 .33822 L F
.938 .47 .132 r
.45035 .3333 m .42789 .31875 L .42354 .33021 L F
.45035 .3333 m .45364 .32177 L .42789 .31875 L F
1 .866 .481 r
.4236 .43266 m .39427 .44095 L .39352 .42916 L F
.4236 .43266 m .42419 .44438 L .39427 .44095 L F
.85 .431 .124 r
.58754 .32407 m .58515 .31317 L .55957 .31439 L F
.831 .422 .122 r
.61394 .32196 m .58515 .31317 L .58754 .32407 L F
.928 .47 .133 r
.48 .32394 m .45732 .31095 L .45364 .32177 L F
.48 .32394 m .48248 .31305 L .45732 .31095 L F
.731 .366 .107 r
.67471 .33855 m .64401 .33047 L .64775 .3425 L F
.699 .347 .102 r
.67872 .35096 m .67471 .33855 L .64775 .3425 L F
.797 .493 .217 r
.54908 .47074 m .51847 .47997 L .51814 .47071 L F
.54908 .47074 m .5488 .48 L .51847 .47997 L F
.75 .459 .195 r
.57991 .46997 m .5488 .48 L .54908 .47074 L F
.786 .496 .224 r
.61156 .45814 m .61043 .46838 L .57991 .46997 L F
.731 .455 .197 r
.642 .45568 m .61043 .46838 L .61156 .45814 L F
.809 .522 .249 r
.64307 .4446 m .642 .45568 L .61156 .45814 L F
.841 .525 .237 r
.51814 .47071 m .48826 .47916 L .48733 .46988 L F
.51814 .47071 m .51847 .47997 L .48826 .47916 L F
.948 .471 .131 r
.41973 .34224 m .39757 .32626 L .39284 .33822 L F
.41973 .34224 m .42354 .33021 L .39757 .32626 L F
1 .673 .338 r
.45568 .45798 m .4269 .46579 L .42529 .45546 L F
.45568 .45798 m .45684 .46823 L .4269 .46579 L F
.75 .478 .219 r
.67306 .44124 m .642 .45568 L .64307 .4446 L F
.822 .541 .269 r
.67379 .42945 m .67306 .44124 L .64307 .4446 L F
.899 .461 .132 r
.5338 .31478 m .50944 .30425 L .50804 .31433 L F
.5338 .31478 m .53385 .30467 L .50944 .30425 L F
.883 .452 .13 r
.55957 .31439 m .53385 .30467 L .5338 .31478 L F
1 .788 .42 r
.42419 .44438 m .39568 .45213 L .39427 .44095 L F
.42419 .44438 m .42529 .45546 L .39568 .45213 L F
.75 .459 .195 r
.57991 .46997 m .57903 .47925 L .5488 .48 L F
.7 .423 .172 r
.61043 .46838 m .57903 .47925 L .57991 .46997 L F
.883 .452 .13 r
.55957 .31439 m .55827 .3043 L .53385 .30467 L F
.866 .444 .128 r
.58515 .31317 m .55827 .3043 L .55957 .31439 L F
.882 .555 .256 r
.48733 .46988 m .45837 .47757 L .45684 .46823 L F
.48733 .46988 m .48826 .47916 L .45837 .47757 L F
.915 .469 .134 r
.50804 .31433 m .48522 .30302 L .48248 .31305 L F
.50804 .31433 m .50944 .30425 L .48522 .30302 L F
.831 .422 .122 r
.61394 .32196 m .61035 .31113 L .58515 .31317 L F
.811 .412 .12 r
.63975 .31901 m .61035 .31113 L .61394 .32196 L F
.784 .395 .115 r
.64401 .33047 m .63975 .31901 L .61394 .32196 L F
1 .974 .559 r
.39342 .41688 m .39352 .42916 L .36445 .42481 L F
.947 .48 .135 r
.45364 .32177 m .43275 .30803 L .42789 .31875 L F
.45364 .32177 m .45732 .31095 L .43275 .30803 L F
.606 .296 .088 r
.71257 .3717 m .68206 .3637 L .68473 .37661 L F
.572 .277 .082 r
.71494 .38468 m .68473 .37661 L .68672 .38957 L F
.71494 .38468 m .71257 .3717 L .68473 .37661 L F
.537 .258 .077 r
.71649 .39759 m .68672 .38957 L .68802 .40244 L F
.71649 .39759 m .71494 .38468 L .68672 .38957 L F
.762 .384 .113 r
.67005 .32658 m .63975 .31901 L .64401 .33047 L F
.731 .366 .107 r
.67471 .33855 m .67005 .32658 L .64401 .33047 L F
.64 .315 .094 r
.70939 .35879 m .67872 .35096 L .68206 .3637 L F
.606 .296 .088 r
.71257 .3717 m .70939 .35879 L .68206 .3637 L F
.917 .443 .122 r
.38268 .37628 m .35815 .35839 L .35493 .3713 L F
.38268 .37628 m .38539 .36336 L .35815 .35839 L F
.891 .427 .117 r
.38066 .38924 m .38268 .37628 L .35493 .3713 L F
.96 .481 .135 r
.42354 .33021 m .40295 .31491 L .39757 .32626 L F
.42354 .33021 m .42789 .31875 L .40295 .31491 L F
.891 .427 .117 r
.38066 .38924 m .35493 .3713 L .35253 .38428 L F
.862 .409 .112 r
.37935 .40211 m .38066 .38924 L .35253 .38428 L F
.939 .458 .127 r
.38539 .36336 m .36219 .34569 L .35815 .35839 L F
.38539 .36336 m .38878 .35063 L .36219 .34569 L F
.866 .444 .128 r
.58515 .31317 m .58251 .30314 L .55827 .3043 L F
.85 .436 .126 r
.61035 .31113 m .58251 .30314 L .58515 .31317 L F
.931 .477 .136 r
.48248 .31305 m .46139 .301 L .45732 .31095 L F
.48248 .31305 m .48522 .30302 L .46139 .301 L F
.761 .494 .237 r
.70295 .42517 m .67306 .44124 L .67379 .42945 L F
.828 .556 .286 r
.70306 .41281 m .70295 .42517 L .67379 .42945 L F
.673 .335 .099 r
.7054 .34609 m .67471 .33855 L .67872 .35096 L F
.64 .315 .094 r
.70939 .35879 m .7054 .34609 L .67872 .35096 L F
.862 .409 .112 r
.37935 .40211 m .35253 .38428 L .35096 .3972 L F
1 .9 .501 r
.39352 .42916 m .36536 .4367 L .36445 .42481 L F
.39352 .42916 m .39427 .44095 L .36536 .4367 L F
.7 .423 .172 r
.61043 .46838 m .60894 .47771 L .57903 .47925 L F
.648 .387 .148 r
.64042 .466 m .60894 .47771 L .61043 .46838 L F
.731 .455 .197 r
.642 .45568 m .64042 .466 L .61043 .46838 L F
.958 .472 .131 r
.38878 .35063 m .36702 .33334 L .36219 .34569 L F
.38878 .35063 m .39284 .33822 L .36702 .33334 L F
.674 .413 .17 r
.67167 .4524 m .64042 .466 L .642 .45568 L F
.75 .478 .219 r
.67306 .44124 m .67167 .4524 L .642 .45568 L F
.919 .582 .272 r
.45684 .46823 m .42904 .47521 L .4269 .46579 L F
.45684 .46823 m .45837 .47757 L .42904 .47521 L F
1 .701 .355 r
.42529 .45546 m .39774 .46255 L .39568 .45213 L F
.42529 .45546 m .4269 .46579 L .39774 .46255 L F
.696 .413 .163 r
.5488 .48 m .51888 .48817 L .51847 .47997 L F
.5488 .48 m .54845 .4882 L .51888 .48817 L F
.653 .384 .145 r
.57903 .47925 m .54845 .4882 L .5488 .48 L F
.735 .44 .18 r
.51847 .47997 m .48942 .48739 L .48826 .47916 L F
.51847 .47997 m .51888 .48817 L .48942 .48739 L F
.707 .354 .105 r
.70062 .33373 m .67005 .32658 L .67471 .33855 L F
.673 .335 .099 r
.7054 .34609 m .70062 .33373 L .67471 .33855 L F
.811 .412 .12 r
.63975 .31901 m .63497 .30828 L .61035 .31113 L F
.791 .403 .118 r
.66475 .31522 m .63497 .30828 L .63975 .31901 L F
.762 .384 .113 r
.67005 .32658 m .66475 .31522 L .63975 .31901 L F
.973 .483 .134 r
.39284 .33822 m .37264 .32148 L .36702 .33334 L F
.39284 .33822 m .39757 .32626 L .37264 .32148 L F
.85 .436 .126 r
.61035 .31113 m .60638 .30118 L .58251 .30314 L F
.833 .428 .125 r
.63497 .30828 m .60638 .30118 L .61035 .31113 L F
.653 .384 .145 r
.57903 .47925 m .57792 .48747 L .54845 .4882 L F
.608 .354 .127 r
.60894 .47771 m .57792 .48747 L .57903 .47925 L F
.966 .489 .138 r
.42789 .31875 m .40898 .30431 L .40295 .31491 L F
.42789 .31875 m .43275 .30803 L .40898 .30431 L F
.771 .464 .195 r
.48826 .47916 m .46028 .48586 L .45837 .47757 L F
.48826 .47916 m .48942 .48739 L .46028 .48586 L F
.946 .485 .137 r
.45732 .31095 m .43813 .29821 L .43275 .30803 L F
.45732 .31095 m .46139 .301 L .43813 .29821 L F
.689 .432 .188 r
.70205 .43705 m .67167 .4524 L .67306 .44124 L F
.761 .494 .237 r
.70295 .42517 m .70205 .43705 L .67306 .44124 L F
.894 .464 .133 r
.53385 .30467 m .51098 .2952 L .50944 .30425 L F
.53385 .30467 m .53391 .2956 L .51098 .2952 L F
.881 .458 .132 r
.55827 .3043 m .53391 .2956 L .53385 .30467 L F
1 .818 .437 r
.39427 .44095 m .36707 .44799 L .36536 .4367 L F
.39427 .44095 m .39568 .45213 L .36707 .44799 L F
.881 .458 .132 r
.55827 .3043 m .55685 .29525 L .53391 .2956 L F
.869 .451 .13 r
.58251 .30314 m .55685 .29525 L .55827 .3043 L F
.905 .47 .134 r
.50944 .30425 m .48823 .29403 L .48522 .30302 L F
.50944 .30425 m .51098 .2952 L .48823 .29403 L F
.74 .374 .11 r
.69507 .32186 m .66475 .31522 L .67005 .32658 L F
.707 .354 .105 r
.70062 .33373 m .69507 .32186 L .67005 .32658 L F
.648 .387 .148 r
.64042 .466 m .63833 .47541 L .60894 .47771 L F
.593 .349 .125 r
.66965 .46282 m .63833 .47541 L .64042 .466 L F
.674 .413 .17 r
.67167 .4524 m .66965 .46282 L .64042 .466 L F
.982 .493 .138 r
.39757 .32626 m .37904 .31025 L .37264 .32148 L F
.39757 .32626 m .40295 .31491 L .37904 .31025 L F
.869 .451 .13 r
.58251 .30314 m .57961 .29414 L .55685 .29525 L F
.856 .445 .129 r
.60638 .30118 m .57961 .29414 L .58251 .30314 L F
.952 .605 .286 r
.4269 .46579 m .40046 .47208 L .39774 .46255 L F
.4269 .46579 m .42904 .47521 L .40046 .47208 L F
.916 .475 .136 r
.48522 .30302 m .46586 .29212 L .46139 .301 L F
.48522 .30302 m .48823 .29403 L .46586 .29212 L F
.608 .354 .127 r
.60894 .47771 m .60709 .486 L .57792 .48747 L F
.559 .322 .108 r
.63833 .47541 m .60709 .486 L .60894 .47771 L F
1 1 .58 r
.36434 .41246 m .36445 .42481 L .33663 .41964 L F
.803 .486 .209 r
.45837 .47757 m .43168 .48358 L .42904 .47521 L F
.45837 .47757 m .46028 .48586 L .43168 .48358 L F
.575 .282 .084 r
.73908 .36593 m .70939 .35879 L .71257 .3717 L F
.539 .262 .079 r
.74183 .37893 m .71257 .3717 L .71494 .38468 L F
.74183 .37893 m .73908 .36593 L .71257 .3717 L F
.614 .37 .142 r
.70037 .44832 m .66965 .46282 L .67167 .4524 L F
.689 .432 .188 r
.70205 .43705 m .70037 .44832 L .67167 .4524 L F
.611 .302 .09 r
.7354 .35303 m .7054 .34609 L .70939 .35879 L F
.575 .282 .084 r
.73908 .36593 m .7354 .35303 L .70939 .35879 L F
.503 .242 .073 r
.74362 .3919 m .71494 .38468 L .71649 .39759 L F
.74362 .3919 m .74183 .37893 L .71494 .38468 L F
.833 .428 .125 r
.63497 .30828 m .62968 .29844 L .60638 .30118 L F
.815 .42 .123 r
.65881 .30462 m .62968 .29844 L .63497 .30828 L F
.791 .403 .118 r
.66475 .31522 m .65881 .30462 L .63497 .30828 L F
.584 .335 .121 r
.54845 .4882 m .51936 .49516 L .51888 .48817 L F
.54845 .4882 m .54803 .49519 L .51936 .49516 L F
.546 .31 .107 r
.57792 .48747 m .54803 .49519 L .54845 .4882 L F
.946 .458 .125 r
.35493 .3713 m .33225 .35257 L .32853 .36547 L F
.35493 .3713 m .35815 .35839 L .33225 .35257 L F
.921 .441 .12 r
.35253 .38428 m .35493 .3713 L .32853 .36547 L F
.618 .357 .134 r
.51888 .48817 m .4908 .49441 L .48942 .48739 L F
.51888 .48817 m .51936 .49516 L .4908 .49441 L F
1 .726 .369 r
.39568 .45213 m .36957 .45853 L .36707 .44799 L F
.39568 .45213 m .39774 .46255 L .36957 .45853 L F
.96 .492 .139 r
.43275 .30803 m .41564 .29464 L .40898 .30431 L F
.43275 .30803 m .43813 .29821 L .41564 .29464 L F
.967 .472 .13 r
.35815 .35839 m .33691 .33992 L .33225 .35257 L F
.35815 .35839 m .36219 .34569 L .33691 .33992 L F
.921 .441 .12 r
.35253 .38428 m .32853 .36547 L .32575 .37847 L F
.891 .423 .115 r
.35096 .3972 m .35253 .38428 L .32575 .37847 L F
.697 .446 .204 r
.73087 .42005 m .70205 .43705 L .70295 .42517 L F
.766 .507 .253 r
.73101 .40761 m .73087 .42005 L .70295 .42517 L F
.646 .322 .096 r
.73078 .34037 m .70062 .33373 L .7054 .34609 L F
.611 .302 .09 r
.7354 .35303 m .73078 .34037 L .7054 .34609 L F
1 .933 .518 r
.36445 .42481 m .3377 .43164 L .33663 .41964 L F
.36445 .42481 m .36536 .4367 L .3377 .43164 L F
.771 .394 .116 r
.68875 .31062 m .65881 .30462 L .66475 .31522 L F
.74 .374 .11 r
.69507 .32186 m .68875 .31062 L .66475 .31522 L F
.856 .445 .129 r
.60638 .30118 m .60202 .29229 L .57961 .29414 L F
.842 .438 .127 r
.62968 .29844 m .60202 .29229 L .60638 .30118 L F
.985 .485 .134 r
.36219 .34569 m .34249 .32764 L .33691 .33992 L F
.36219 .34569 m .36702 .33334 L .34249 .32764 L F
.546 .31 .107 r
.57792 .48747 m .57661 .49449 L .54803 .49519 L F
.503 .282 .092 r
.60709 .486 m .57661 .49449 L .57792 .48747 L F
.891 .423 .115 r
.35096 .3972 m .32575 .37847 L .32394 .39144 L F
.925 .481 .137 r
.46139 .301 m .44404 .28946 L .43813 .29821 L F
.46139 .301 m .46586 .29212 L .44404 .28946 L F
.647 .375 .145 r
.48942 .48739 m .46256 .49294 L .46028 .48586 L F
.48942 .48739 m .4908 .49441 L .46256 .49294 L F
.984 .499 .14 r
.40295 .31491 m .3862 .29981 L .37904 .31025 L F
.40295 .31491 m .40898 .30431 L .3862 .29981 L F
.682 .343 .102 r
.72525 .32809 m .69507 .32186 L .70062 .33373 L F
.646 .322 .096 r
.73078 .34037 m .72525 .32809 L .70062 .33373 L F
.856 .451 .13 r
.53391 .2956 m .51265 .28739 L .51098 .2952 L F
.53391 .2956 m .53397 .28777 L .51265 .28739 L F
.849 .447 .129 r
.55685 .29525 m .53397 .28777 L .53391 .2956 L F
.559 .322 .108 r
.63833 .47541 m .63574 .48378 L .60709 .486 L F
.507 .288 .09 r
.66697 .47234 m .63574 .48378 L .63833 .47541 L F
.593 .349 .125 r
.66965 .46282 m .66697 .47234 L .63833 .47541 L F
.997 .496 .137 r
.36702 .33334 m .34898 .31589 L .34249 .32764 L F
.36702 .33334 m .37264 .32148 L .34898 .31589 L F
.849 .447 .129 r
.55685 .29525 m .55529 .28744 L .53397 .28777 L F
.841 .444 .128 r
.57961 .29414 m .55529 .28744 L .55685 .29525 L F
.829 .504 .221 r
.42904 .47521 m .40384 .48057 L .40046 .47208 L F
.42904 .47521 m .43168 .48358 L .40384 .48057 L F
.862 .454 .13 r
.51098 .2952 m .49152 .2863 L .48823 .29403 L F
.51098 .2952 m .51265 .28739 L .49152 .2863 L F
.626 .386 .158 r
.72982 .43205 m .70037 .44832 L .70205 .43705 L F
.697 .446 .204 r
.73087 .42005 m .72982 .43205 L .70205 .43705 L F
.536 .311 .102 r
.6979 .45886 m .66697 .47234 L .66965 .46282 L F
.614 .37 .142 r
.70037 .44832 m .6979 .45886 L .66965 .46282 L F
1 .845 .451 r
.36536 .4367 m .33969 .44306 L .3377 .43164 L F
.36536 .4367 m .36707 .44799 L .33969 .44306 L F
.503 .282 .092 r
.60709 .486 m .60488 .49308 L .57661 .49449 L F
.456 .252 .077 r
.63574 .48378 m .60488 .49308 L .60709 .486 L F
.979 .624 .297 r
.39774 .46255 m .37287 .4682 L .36957 .45853 L F
.39774 .46255 m .40046 .47208 L .37287 .4682 L F
.669 .389 .154 r
.46028 .48586 m .43485 .49076 L .43168 .48358 L F
.46028 .48586 m .46256 .49294 L .43485 .49076 L F
.717 .364 .108 r
.71883 .31633 m .68875 .31062 L .69507 .32186 L F
.682 .343 .102 r
.72525 .32809 m .71883 .31633 L .69507 .32186 L F
.841 .444 .128 r
.57961 .29414 m .57644 .2864 L .55529 .28744 L F
.833 .439 .127 r
.60202 .29229 m .57644 .2864 L .57961 .29414 L F
.867 .457 .131 r
.48823 .29403 m .47074 .2845 L .46586 .29212 L F
.48823 .29403 m .49152 .2863 L .47074 .2845 L F
.842 .438 .127 r
.62968 .29844 m .62388 .28969 L .60202 .29229 L F
.828 .431 .126 r
.65224 .29494 m .62388 .28969 L .62968 .29844 L F
.815 .42 .123 r
.65881 .30462 m .65224 .29494 L .62968 .29844 L F
.797 .411 .121 r
.68167 .30017 m .65224 .29494 L .65881 .30462 L F
.771 .394 .116 r
.68875 .31062 m .68167 .30017 L .65881 .30462 L F
1 .505 .14 r
.37264 .32148 m .35635 .30481 L .34898 .31589 L F
.37264 .32148 m .37904 .31025 L .35635 .30481 L F
.934 .486 .138 r
.43813 .29821 m .42295 .28609 L .41564 .29464 L F
.43813 .29821 m .44404 .28946 L .42295 .28609 L F
.973 .5 .141 r
.40898 .30431 m .39411 .29033 L .3862 .29981 L F
.40898 .30431 m .41564 .29464 L .39411 .29033 L F
.434 .233 .072 r
.54803 .49519 m .51992 .50079 L .51936 .49516 L F
.54803 .49519 m .54755 .50081 L .51992 .50079 L F
.402 .212 .062 r
.57661 .49449 m .54755 .50081 L .54803 .49519 L F
.461 .25 .08 r
.51936 .49516 m .49241 .50007 L .4908 .49441 L F
.51936 .49516 m .51992 .50079 L .49241 .50007 L F
.553 .328 .116 r
.72784 .44345 m .6979 .45886 L .70037 .44832 L F
.626 .386 .158 r
.72982 .43205 m .72784 .44345 L .70037 .44832 L F
1 .746 .378 r
.36707 .44799 m .34262 .45375 L .33969 .44306 L F
.36707 .44799 m .36957 .45853 L .34262 .45375 L F
.833 .439 .127 r
.60202 .29229 m .59726 .28466 L .57644 .2864 L F
.824 .435 .126 r
.62388 .28969 m .59726 .28466 L .60202 .29229 L F
.402 .212 .062 r
.57661 .49449 m .57508 .50015 L .54755 .50081 L F
.364 .189 .052 r
.60488 .49308 m .57508 .50015 L .57661 .49449 L F
1 1 .598 r
.33649 .40719 m .33663 .41964 L .31029 .41366 L F
.481 .262 .087 r
.4908 .49441 m .46521 .49867 L .46256 .49294 L F
.4908 .49441 m .49241 .50007 L .46521 .49867 L F
.871 .459 .131 r
.46586 .29212 m .45048 .28201 L .44404 .28946 L F
.46586 .29212 m .47074 .2845 L .45048 .28201 L F
.75 .384 .114 r
.71153 .30524 m .68167 .30017 L .68875 .31062 L F
.717 .364 .108 r
.71883 .31633 m .71153 .30524 L .68875 .31062 L F
.456 .252 .077 r
.63574 .48378 m .63264 .49095 L .60488 .49308 L F
.406 .22 .062 r
.66365 .48082 m .63264 .49095 L .63574 .48378 L F
.507 .288 .09 r
.66697 .47234 m .66365 .48082 L .63574 .48378 L F
1 .509 .142 r
.37904 .31025 m .36461 .29455 L .35635 .30481 L F
.37904 .31025 m .3862 .29981 L .36461 .29455 L F
.452 .252 .073 r
.69464 .46851 m .66365 .48082 L .66697 .47234 L F
.536 .311 .102 r
.6979 .45886 m .69464 .46851 L .66697 .47234 L F
.543 .267 .081 r
.76404 .35934 m .7354 .35303 L .73908 .36593 L F
.505 .246 .075 r
.76714 .37236 m .73908 .36593 L .74183 .37893 L F
.76714 .37236 m .76404 .35934 L .73908 .36593 L F
.685 .399 .16 r
.43168 .48358 m .40787 .48788 L .40384 .48057 L F
.43168 .48358 m .43485 .49076 L .40787 .48788 L F
.58 .288 .087 r
.75986 .34645 m .73078 .34037 L .7354 .35303 L F
.543 .267 .081 r
.76404 .35934 m .75986 .34645 L .7354 .35303 L F
.849 .516 .229 r
.40046 .47208 m .37696 .47684 L .37287 .4682 L F
.40046 .47208 m .40384 .48057 L .37696 .47684 L F
.467 .226 .069 r
.76917 .38538 m .74183 .37893 L .74362 .3919 L F
.76917 .38538 m .76714 .37236 L .74183 .37893 L F
.631 .397 .172 r
.75733 .41413 m .72982 .43205 L .73087 .42005 L F
.7 .457 .219 r
.75749 .40158 m .75733 .41413 L .73087 .42005 L F
.975 .472 .128 r
.32853 .36547 m .30791 .34593 L .3037 .35881 L F
.32853 .36547 m .33225 .35257 L .30791 .34593 L F
.95 .456 .123 r
.32575 .37847 m .32853 .36547 L .3037 .35881 L F
.995 .487 .133 r
.33225 .35257 m .31317 .33332 L .30791 .34593 L F
.33225 .35257 m .33691 .33992 L .31317 .33332 L F
.618 .309 .093 r
.75464 .33384 m .72525 .32809 L .73078 .34037 L F
.58 .288 .087 r
.75986 .34645 m .75464 .33384 L .73078 .34037 L F
.95 .456 .123 r
.32575 .37847 m .3037 .35881 L .30057 .37184 L F
.919 .437 .118 r
.32394 .39144 m .32575 .37847 L .30057 .37184 L F
1 .961 .532 r
.33663 .41964 m .3115 .4258 L .31029 .41366 L F
.33663 .41964 m .3377 .43164 L .3115 .4258 L F
.364 .189 .052 r
.60488 .49308 m .60231 .4988 L .57508 .50015 L F
.323 .163 .042 r
.63264 .49095 m .60231 .4988 L .60488 .49308 L F
1 .499 .137 r
.33691 .33992 m .31947 .32113 L .31317 .33332 L F
.33691 .33992 m .34249 .32764 L .31947 .32113 L F
.758 .405 .116 r
.53397 .28777 m .51448 .28107 L .51265 .28739 L F
.53397 .28777 m .53403 .28142 L .51448 .28107 L F
.757 .405 .116 r
.55529 .28744 m .53403 .28142 L .53397 .28777 L F
.828 .431 .126 r
.65224 .29494 m .64503 .28636 L .62388 .28969 L F
.813 .424 .124 r
.67385 .29068 m .64503 .28636 L .65224 .29494 L F
.797 .411 .121 r
.68167 .30017 m .67385 .29068 L .65224 .29494 L F
.493 .269 .09 r
.46256 .49294 m .43852 .49659 L .43485 .49076 L F
.46256 .49294 m .46521 .49867 L .43852 .49659 L F
.941 .49 .139 r
.41564 .29464 m .40278 .282 L .39411 .29033 L F
.41564 .29464 m .42295 .28609 L .40278 .282 L F
.757 .405 .116 r
.55529 .28744 m .5536 .28111 L .53403 .28142 L F
.756 .404 .116 r
.57644 .2864 m .5536 .28111 L .55529 .28744 L F
.758 .406 .117 r
.51265 .28739 m .49509 .28006 L .49152 .2863 L F
.51265 .28739 m .51448 .28107 L .49509 .28006 L F
.919 .437 .118 r
.32394 .39144 m .30057 .37184 L .29852 .38487 L F
.475 .271 .08 r
.72495 .45414 m .69464 .46851 L .6979 .45886 L F
.553 .328 .116 r
.72784 .44345 m .72495 .45414 L .6979 .45886 L F
.656 .331 .099 r
.74839 .32164 m .71883 .31633 L .72525 .32809 L F
.618 .309 .093 r
.75464 .33384 m .74839 .32164 L .72525 .32809 L F
.824 .435 .126 r
.62388 .28969 m .61756 .28222 L .59726 .28466 L F
.815 .43 .125 r
.64503 .28636 m .61756 .28222 L .62388 .28969 L F
1 .637 .303 r
.36957 .45853 m .34648 .46358 L .34262 .45375 L F
.36957 .45853 m .37287 .4682 L .34648 .46358 L F
.874 .461 .132 r
.44404 .28946 m .43092 .27885 L .42295 .28609 L F
.44404 .28946 m .45048 .28201 L .43092 .27885 L F
1 .509 .14 r
.34249 .32764 m .32679 .30951 L .31947 .32113 L F
.34249 .32764 m .34898 .31589 L .32679 .30951 L F
.779 .403 .119 r
.70336 .29497 m .67385 .29068 L .68167 .30017 L F
.75 .384 .114 r
.71153 .30524 m .70336 .29497 L .68167 .30017 L F
.561 .341 .128 r
.75613 .42626 m .72784 .44345 L .72982 .43205 L F
.631 .397 .172 r
.75733 .41413 m .75613 .42626 L .72982 .43205 L F
.756 .404 .116 r
.57644 .2864 m .573 .28015 L .5536 .28111 L F
.755 .404 .116 r
.59726 .28466 m .573 .28015 L .57644 .2864 L F
.984 .506 .142 r
.3862 .29981 m .37373 .2853 L .36461 .29455 L F
.3862 .29981 m .39411 .29033 L .37373 .2853 L F
.759 .406 .117 r
.49152 .2863 m .47603 .2784 L .47074 .2845 L F
.49152 .2863 m .49509 .28006 L .47603 .2784 L F
1 .866 .46 r
.3377 .43164 m .31378 .43737 L .3115 .4258 L F
.3377 .43164 m .33969 .44306 L .31378 .43737 L F
.244 .107 .025 r
.54755 .50081 m .52057 .50488 L .51992 .50079 L F
.54755 .50081 m .54699 .50491 L .52057 .50488 L F
.226 .097 .022 r
.57508 .50015 m .54699 .50491 L .54755 .50081 L F
.26 .117 .027 r
.51992 .50079 m .49424 .5042 L .49241 .50007 L F
.51992 .50079 m .52057 .50488 L .49424 .5042 L F
.693 .353 .106 r
.74114 .31001 m .71153 .30524 L .71883 .31633 L F
.656 .331 .099 r
.74839 .32164 m .74114 .31001 L .71883 .31633 L F
1 .516 .143 r
.34898 .31589 m .33511 .2986 L .32679 .30951 L F
.34898 .31589 m .35635 .30481 L .33511 .2986 L F
.406 .22 .062 r
.66365 .48082 m .65967 .48811 L .63264 .49095 L F
.353 .186 .048 r
.6906 .47714 m .65967 .48811 L .66365 .48082 L F
.452 .252 .073 r
.69464 .46851 m .6906 .47714 L .66365 .48082 L F
.226 .097 .022 r
.57508 .50015 m .57333 .50428 L .54699 .50491 L F
.208 .089 .02 r
.60231 .4988 m .57333 .50428 L .57508 .50015 L F
.323 .163 .042 r
.63264 .49095 m .62904 .49677 L .60231 .4988 L F
.279 .135 .033 r
.65967 .48811 m .62904 .49677 L .63264 .49095 L F
.691 .401 .162 r
.40384 .48057 m .38185 .4843 L .37696 .47684 L F
.40384 .48057 m .40787 .48788 L .38185 .4843 L F
.271 .123 .028 r
.49241 .50007 m .46823 .50287 L .46521 .49867 L F
.49241 .50007 m .49424 .5042 L .46823 .50287 L F
.496 .27 .091 r
.43485 .49076 m .41256 .49384 L .40787 .48788 L F
.43485 .49076 m .43852 .49659 L .41256 .49384 L F
.755 .404 .116 r
.59726 .28466 m .59209 .27854 L .573 .28015 L F
.753 .403 .116 r
.61756 .28222 m .59209 .27854 L .59726 .28466 L F
.759 .406 .117 r
.47074 .2845 m .45747 .2761 L .45048 .28201 L F
.47074 .2845 m .47603 .2784 L .45747 .2761 L F
.488 .285 .09 r
.75387 .43782 m .72495 .45414 L .72784 .44345 L F
.561 .341 .128 r
.75613 .42626 m .75387 .43782 L .72784 .44345 L F
.395 .216 .057 r
.72112 .46395 m .6906 .47714 L .69464 .46851 L F
.475 .271 .08 r
.72495 .45414 m .72112 .46395 L .69464 .46851 L F
.729 .374 .111 r
.73289 .29909 m .70336 .29497 L .71153 .30524 L F
.693 .353 .106 r
.74114 .31001 m .73289 .29909 L .71153 .30524 L F
.815 .43 .125 r
.64503 .28636 m .63718 .27911 L .61756 .28222 L F
.805 .425 .124 r
.66528 .28233 m .63718 .27911 L .64503 .28636 L F
.813 .424 .124 r
.67385 .29068 m .66528 .28233 L .64503 .28636 L F
.858 .522 .232 r
.37287 .4682 m .35128 .4724 L .34648 .46358 L F
.37287 .4682 m .37696 .47684 L .35128 .4724 L F
1 .759 .383 r
.33969 .44306 m .31713 .44823 L .31378 .43737 L F
.33969 .44306 m .34262 .45375 L .31713 .44823 L F
.798 .417 .122 r
.69433 .2857 m .66528 .28233 L .67385 .29068 L F
.779 .403 .119 r
.70336 .29497 m .69433 .2857 L .67385 .29068 L F
.876 .462 .132 r
.42295 .28609 m .41222 .27502 L .40278 .282 L F
.42295 .28609 m .43092 .27885 L .41222 .27502 L F
1 .517 .144 r
.35635 .30481 m .34441 .28857 L .33511 .2986 L F
.35635 .30481 m .36461 .29455 L .34441 .28857 L F
.208 .089 .02 r
.60231 .4988 m .59937 .50299 L .57333 .50428 L F
.19 .082 .019 r
.62904 .49677 m .59937 .50299 L .60231 .4988 L F
.947 .493 .139 r
.39411 .29033 m .38371 .27723 L .37373 .2853 L F
.39411 .29033 m .40278 .282 L .38371 .27723 L F
.28 .127 .029 r
.46521 .49867 m .44272 .50089 L .43852 .49659 L F
.46521 .49867 m .46823 .50287 L .44272 .50089 L F
1 1 .611 r
.31013 .4011 m .31029 .41366 L .28567 .4069 L F
.753 .403 .116 r
.61756 .28222 m .6107 .27629 L .59209 .27854 L F
.751 .402 .116 r
.63718 .27911 m .6107 .27629 L .61756 .28222 L F
.759 .406 .117 r
.45048 .28201 m .43956 .27318 L .43092 .27885 L F
.45048 .28201 m .45747 .2761 L .43956 .27318 L F
.579 .311 .089 r
.53403 .28142 m .51646 .27654 L .51448 .28107 L F
.53403 .28142 m .5341 .27686 L .51646 .27654 L F
.583 .313 .09 r
.5536 .28111 m .5341 .27686 L .53403 .28142 L F
.549 .273 .083 r
.78255 .33907 m .75464 .33384 L .75986 .34645 L F
.509 .251 .077 r
.78719 .35194 m .75986 .34645 L .76404 .35934 L F
.78719 .35194 m .78255 .33907 L .75986 .34645 L F
.469 .23 .07 r
.79064 .36499 m .76404 .35934 L .76714 .37236 L F
.79064 .36499 m .78719 .35194 L .76404 .35934 L F
.583 .313 .09 r
.5536 .28111 m .55176 .27658 L .5341 .27686 L F
.588 .316 .09 r
.573 .28015 m .55176 .27658 L .5536 .28111 L F
.564 .35 .141 r
.78209 .40743 m .75613 .42626 L .75733 .41413 L F
.633 .406 .185 r
.78227 .39476 m .78209 .40743 L .75733 .41413 L F
.577 .31 .089 r
.51448 .28107 m .49897 .27562 L .49509 .28006 L F
.51448 .28107 m .51646 .27654 L .49897 .27562 L F
.76 .394 .117 r
.72366 .28904 m .69433 .2857 L .70336 .29497 L F
.729 .374 .111 r
.73289 .29909 m .72366 .28904 L .70336 .29497 L F
.413 .231 .061 r
.75055 .44867 m .72112 .46395 L .72495 .45414 L F
.488 .285 .09 r
.75387 .43782 m .75055 .44867 L .72495 .45414 L F
.589 .296 .09 r
.77675 .32652 m .74839 .32164 L .75464 .33384 L F
.549 .273 .083 r
.78255 .33907 m .77675 .32652 L .75464 .33384 L F
.279 .135 .033 r
.65967 .48811 m .65506 .49406 L .62904 .49677 L F
.234 .108 .027 r
.68577 .48459 m .65506 .49406 L .65967 .48811 L F
.353 .186 .048 r
.6906 .47714 m .68577 .48459 L .65967 .48811 L F
.429 .208 .064 r
.7929 .37808 m .76714 .37236 L .76917 .38538 L F
.7929 .37808 m .79064 .36499 L .76714 .37236 L F
1 .501 .136 r
.30791 .34593 m .29121 .32594 L .28536 .33849 L F
.30791 .34593 m .31317 .33332 L .29121 .32594 L F
1 .487 .131 r
.3037 .35881 m .30791 .34593 L .28536 .33849 L F
.3037 .35881 m .28536 .33849 L .28069 .35136 L F
.977 .47 .126 r
.30057 .37184 m .3037 .35881 L .28069 .35136 L F
.994 .512 .143 r
.36461 .29455 m .35468 .27957 L .34441 .28857 L F
.36461 .29455 m .37373 .2853 L .35468 .27957 L F
.488 .264 .087 r
.40787 .48788 m .38754 .49042 L .38185 .4843 L F
.40787 .48788 m .41256 .49384 L .38754 .49042 L F
1 .983 .54 r
.31029 .41366 m .28703 .41918 L .28567 .4069 L F
.31029 .41366 m .3115 .4258 L .28703 .41918 L F
1 .642 .305 r
.34262 .45375 m .32154 .45825 L .31713 .44823 L F
.34262 .45375 m .34648 .46358 L .32154 .45825 L F
.16 .069 .016 r
.54699 .50491 m .52129 .50726 L .52057 .50488 L F
.54699 .50491 m .54637 .50729 L .52129 .50726 L F
.148 .063 .014 r
.57333 .50428 m .54637 .50729 L .54699 .50491 L F
.17 .073 .017 r
.52057 .50488 m .49631 .50662 L .49424 .5042 L F
.52057 .50488 m .52129 .50726 L .49631 .50662 L F
1 .513 .14 r
.31317 .33332 m .29819 .31386 L .29121 .32594 L F
.31317 .33332 m .31947 .32113 L .29819 .31386 L F
.977 .47 .126 r
.30057 .37184 m .28069 .35136 L .27721 .36441 L F
.946 .45 .12 r
.29852 .38487 m .30057 .37184 L .27721 .36441 L F
.588 .316 .09 r
.573 .28015 m .56926 .27571 L .55176 .27658 L F
.595 .32 .091 r
.59209 .27854 m .56926 .27571 L .573 .28015 L F
.299 .152 .038 r
.71638 .47275 m .68577 .48459 L .6906 .47714 L F
.395 .216 .057 r
.72112 .46395 m .71638 .47275 L .6906 .47714 L F
.629 .319 .096 r
.76981 .31443 m .74114 .31001 L .74839 .32164 L F
.589 .296 .09 r
.77675 .32652 m .76981 .31443 L .74839 .32164 L F
.19 .082 .019 r
.62904 .49677 m .62493 .50106 L .59937 .50299 L F
.169 .073 .017 r
.65506 .49406 m .62493 .50106 L .62904 .49677 L F
.577 .31 .089 r
.49509 .28006 m .48178 .27412 L .47603 .2784 L F
.49509 .28006 m .49897 .27562 L .48178 .27412 L F
.283 .128 .029 r
.43852 .49659 m .41791 .49828 L .41256 .49384 L F
.43852 .49659 m .44272 .50089 L .41791 .49828 L F
.685 .396 .158 r
.37696 .47684 m .357 .48004 L .35128 .4724 L F
.37696 .47684 m .38185 .4843 L .357 .48004 L F
.148 .063 .014 r
.57333 .50428 m .57137 .50669 L .54637 .50729 L F
.132 .057 .013 r
.59937 .50299 m .57137 .50669 L .57333 .50428 L F
1 .522 .143 r
.31947 .32113 m .3063 .30238 L .29819 .31386 L F
.31947 .32113 m .32679 .30951 L .3063 .30238 L F
.177 .076 .017 r
.49424 .5042 m .47162 .50536 L .46823 .50287 L F
.49424 .5042 m .49631 .50662 L .47162 .50536 L F
.946 .45 .12 r
.29852 .38487 m .27721 .36441 L .27494 .3775 L F
.805 .425 .124 r
.66528 .28233 m .65594 .27533 L .63718 .27911 L F
.794 .42 .122 r
.68444 .27761 m .65594 .27533 L .66528 .28233 L F
.798 .417 .122 r
.69433 .2857 m .68444 .27761 L .66528 .28233 L F
.494 .295 .101 r
.78074 .4197 m .75387 .43782 L .75613 .42626 L F
.564 .35 .141 r
.78209 .40743 m .78074 .4197 L .75613 .42626 L F
.876 .463 .132 r
.40278 .282 m .39457 .27056 L .38371 .27723 L F
.40278 .282 m .41222 .27502 L .39457 .27056 L F
.669 .342 .103 r
.76176 .30294 m .73289 .29909 L .74114 .31001 L F
.629 .319 .096 r
.76981 .31443 m .76176 .30294 L .74114 .31001 L F
.751 .402 .116 r
.63718 .27911 m .62866 .27342 L .6107 .27629 L F
.75 .401 .115 r
.65594 .27533 m .62866 .27342 L .63718 .27911 L F
1 .879 .463 r
.3115 .4258 m .28958 .43093 L .28703 .41918 L F
.3115 .4258 m .31378 .43737 L .28958 .43093 L F
.595 .32 .091 r
.59209 .27854 m .58648 .27425 L .56926 .27571 L F
.603 .324 .092 r
.6107 .27629 m .58648 .27425 L .59209 .27854 L F
.759 .406 .117 r
.43092 .27885 m .42246 .26965 L .41222 .27502 L F
.43092 .27885 m .43956 .27318 L .42246 .26965 L F
.579 .311 .089 r
.47603 .2784 m .46506 .27204 L .45747 .2761 L F
.47603 .2784 m .48178 .27412 L .46506 .27204 L F
1 .526 .145 r
.32679 .30951 m .31552 .29167 L .3063 .30238 L F
.32679 .30951 m .33511 .2986 L .31552 .29167 L F
.782 .41 .12 r
.71348 .28002 m .68444 .27761 L .69433 .2857 L F
.76 .394 .117 r
.72366 .28904 m .71348 .28002 L .69433 .2857 L F
.336 .179 .045 r
.74618 .45867 m .71638 .47275 L .72112 .46395 L F
.413 .231 .061 r
.75055 .44867 m .74618 .45867 L .72112 .46395 L F
.132 .057 .013 r
.59937 .50299 m .59608 .50548 L .57137 .50669 L F
.113 .048 .011 r
.62493 .50106 m .59608 .50548 L .59937 .50299 L F
.181 .078 .018 r
.46823 .50287 m .44743 .50349 L .44272 .50089 L F
.46823 .50287 m .47162 .50536 L .44743 .50349 L F
.95 .496 .14 r
.37373 .2853 m .36592 .27181 L .35468 .27957 L F
.37373 .2853 m .38371 .27723 L .36592 .27181 L F
.854 .516 .228 r
.34648 .46358 m .32701 .46727 L .32154 .45825 L F
.34648 .46358 m .35128 .4724 L .32701 .46727 L F
.707 .364 .109 r
.75261 .29221 m .72366 .28904 L .73289 .29909 L F
.669 .342 .103 r
.76176 .30294 m .75261 .29221 L .73289 .29909 L F
.422 .241 .067 r
.7782 .43143 m .75055 .44867 L .75387 .43782 L F
.494 .295 .101 r
.78074 .4197 m .7782 .43143 L .75387 .43782 L F
1 .525 .145 r
.33511 .2986 m .32581 .28188 L .31552 .29167 L F
.33511 .2986 m .34441 .28857 L .32581 .28188 L F
.169 .073 .017 r
.65506 .49406 m .6498 .4985 L .62493 .50106 L F
.144 .062 .014 r
.68016 .4907 m .6498 .4985 L .65506 .49406 L F
.234 .108 .027 r
.68577 .48459 m .68016 .4907 L .65506 .49406 L F
.603 .324 .092 r
.6107 .27629 m .60324 .27221 L .58648 .27425 L F
.613 .33 .094 r
.62866 .27342 m .60324 .27221 L .6107 .27629 L F
1 .762 .381 r
.31378 .43737 m .29333 .44199 L .28958 .43093 L F
.31378 .43737 m .31713 .44823 L .29333 .44199 L F
.195 .089 .022 r
.71072 .48038 m .68016 .4907 L .68577 .48459 L F
.299 .152 .038 r
.71638 .47275 m .71072 .48038 L .68577 .48459 L F
.281 .126 .028 r
.41256 .49384 m .39401 .49504 L .38754 .49042 L F
.41256 .49384 m .41791 .49828 L .39401 .49504 L F
.582 .312 .09 r
.45747 .2761 m .44893 .26939 L .43956 .27318 L F
.45747 .2761 m .46506 .27204 L .44893 .26939 L F
.466 .248 .078 r
.38185 .4843 m .36365 .48637 L .357 .48004 L F
.38185 .4843 m .38754 .49042 L .36365 .48637 L F
.113 .048 .011 r
.62493 .50106 m .62032 .50365 L .59608 .50548 L F
.09 .039 .009 r
.6498 .4985 m .62032 .50365 L .62493 .50106 L F
.033 .014 .003 r
.54637 .50729 m .52209 .50771 L .52129 .50726 L F
.54637 .50729 m .54568 .50773 L .52209 .50771 L F
.022 .01 .002 r
.57137 .50669 m .54568 .50773 L .54637 .50729 L F
.181 .078 .018 r
.44272 .50089 m .42391 .50102 L .41791 .49828 L F
.44272 .50089 m .44743 .50349 L .42391 .50102 L F
.04 .017 .004 r
.52129 .50726 m .4986 .50711 L .49631 .50662 L F
.52129 .50726 m .52209 .50771 L .4986 .50711 L F
.741 .385 .115 r
.74239 .28241 m .71348 .28002 L .72366 .28904 L F
.707 .364 .109 r
.75261 .29221 m .74239 .28241 L .72366 .28904 L F
.75 .401 .115 r
.65594 .27533 m .64582 .26993 L .62866 .27342 L F
.748 .4 .115 r
.67368 .27092 m .64582 .26993 L .65594 .27533 L F
.794 .42 .122 r
.68444 .27761 m .67368 .27092 L .65594 .27533 L F
.383 .21 .06 r
.5341 .27686 m .51862 .27422 L .51646 .27654 L F
.5341 .27686 m .53418 .2745 L .51862 .27422 L F
.39 .213 .061 r
.55176 .27658 m .53418 .2745 L .5341 .27686 L F
.758 .406 .116 r
.41222 .27502 m .40634 .26554 L .39457 .27056 L F
.41222 .27502 m .42246 .26965 L .40634 .26554 L F
.783 .415 .121 r
.70233 .27224 m .67368 .27092 L .68444 .27761 L F
.782 .41 .12 r
.71348 .28002 m .70233 .27224 L .68444 .27761 L F
1 .517 .144 r
.34441 .28857 m .33717 .27319 L .32581 .28188 L F
.34441 .28857 m .35468 .27957 L .33717 .27319 L F
.239 .115 .03 r
.74076 .46767 m .71072 .48038 L .71638 .47275 L F
.336 .179 .045 r
.74618 .45867 m .74076 .46767 L .71638 .47275 L F
.399 .217 .062 r
.55302 .2745 m .56518 .27349 L .54975 .27426 L F
.56926 .27571 m .56518 .27349 L .55302 .2745 L F
.409 .222 .063 r
.56875 .27361 m .58035 .27219 L .56518 .27349 L F
.58648 .27425 m .58035 .27219 L .56875 .27361 L F
.281 .162 .045 r
.59511 .27039 m .59289 .27066 L .58035 .27219 L F
0 0 0 r
.58035 .27219 m .57832 .27239 L .56518 .27349 L F
.409 .222 .063 r
.58648 .27425 m .56518 .27349 L .56926 .27571 L F
0 0 0 r
.56394 .27378 m .57357 .273 L .56067 .27409 L F
.58035 .27219 m .57357 .273 L .56394 .27378 L F
.281 .162 .045 r
.59289 .27066 m .57357 .273 L .58035 .27219 L F
.421 .228 .064 r
.60324 .27221 m .58035 .27219 L .58648 .27425 L F
.60324 .27221 m .59511 .27039 L .58035 .27219 L F
.281 .162 .045 r
.57715 .27256 m .58613 .27146 L .57357 .273 L F
.59511 .27039 m .58613 .27146 L .57715 .27256 L F
.31 .176 .049 r
.60934 .26809 m .58613 .27146 L .59511 .27039 L F
.58998 .2709 m .59821 .26951 L .58613 .27146 L F
.60934 .26809 m .59821 .26951 L .58998 .2709 L F
.341 .191 .053 r
.6023 .26881 m .60971 .26715 L .59821 .26951 L F
.62289 .26531 m .60971 .26715 L .6023 .26881 L F
.374 .206 .057 r
.61401 .26631 m .62051 .2644 L .60971 .26715 L F
.63565 .26207 m .62051 .2644 L .61401 .26631 L F
.407 .221 .061 r
.62498 .2634 m .63051 .26128 L .62051 .2644 L F
.64748 .25839 m .63051 .26128 L .62498 .2634 L F
.342 .19 .051 r
.63959 .25782 m .63644 .259 L .63051 .26128 L F
0 0 0 r
.63051 .26128 m .62749 .26235 L .62051 .2644 L F
.437 .236 .066 r
.61942 .26961 m .60934 .26809 L .59511 .27039 L F
.456 .246 .069 r
.63485 .26645 m .60934 .26809 L .61942 .26961 L F
.63485 .26645 m .62289 .26531 L .60934 .26809 L F
.341 .191 .053 r
.62289 .26531 m .59821 .26951 L .60934 .26809 L F
.374 .206 .057 r
.63565 .26207 m .60971 .26715 L .62289 .26531 L F
.407 .221 .061 r
.64748 .25839 m .62051 .2644 L .63565 .26207 L F
.437 .236 .066 r
.61942 .26961 m .59511 .27039 L .60324 .27221 L F
0 0 0 r
.60713 .26956 m .61125 .26844 L .60331 .27091 L F
.63051 .26128 m .61125 .26844 L .60713 .26956 L F
.342 .19 .051 r
.63644 .259 m .61125 .26844 L .63051 .26128 L F
0 0 0 r
.62749 .26235 m .60331 .27091 L .62051 .2644 L F
.342 .19 .051 r
.61522 .26695 m .61844 .2657 L .61125 .26844 L F
.63959 .25782 m .61844 .2657 L .61522 .26695 L F
.397 .216 .059 r
.64767 .25405 m .61844 .2657 L .63959 .25782 L F
.62253 .26407 m .62481 .26272 L .61844 .2657 L F
.64767 .25405 m .62481 .26272 L .62253 .26407 L F
.368 .2 .053 r
.63029 .25953 m .62724 .26128 L .62481 .26272 L F
0 0 0 r
.62481 .26272 m .62186 .26437 L .61844 .2657 L F
.613 .33 .094 r
.62866 .27342 m .61942 .26961 L .60324 .27221 L F
0 0 0 r
.59521 .27929 m .59684 .27878 L .59251 .2808 L F
.62481 .26272 m .59684 .27878 L .59521 .27929 L F
.368 .2 .053 r
.62724 .26128 m .59684 .27878 L .62481 .26272 L F
.59964 .27718 m .60055 .27662 L .59684 .27878 L F
.63029 .25953 m .60055 .27662 L .59964 .27718 L F
0 0 0 r
.62186 .26437 m .59251 .2808 L .61844 .2657 L F
.61844 .2657 m .59251 .2808 L .5876 .28266 L F
.61844 .2657 m .61563 .26724 L .61125 .26844 L F
.44 .234 .063 r
.6034 .27492 m .60358 .27435 L .60055 .27662 L F
.63481 .25615 m .60358 .27435 L .6034 .27492 L F
0 0 0 r
.61563 .26724 m .5876 .28266 L .61125 .26844 L F
.443 .233 .061 r
.6059 .27197 m .60376 .27374 L .60358 .27435 L F
0 0 0 r
.60358 .27435 m .60152 .27604 L .60055 .27662 L F
.44 .234 .063 r
.63481 .25615 m .60055 .27662 L .63029 .25953 L F
0 0 0 r
.60152 .27604 m .53476 .33081 L .60055 .27662 L F
.60055 .27662 m .59858 .27824 L .59684 .27878 L F
.59858 .27824 m .53476 .33081 L .59684 .27878 L F
.60055 .27662 m .53476 .33081 L .53476 .33081 L F
.443 .233 .061 r
.60376 .27374 m .53476 .33081 L .60358 .27435 L F
0 0 0 r
.62051 .2644 m .61765 .26536 L .60971 .26715 L F
.61765 .26536 m .59471 .27309 L .60971 .26715 L F
.008 .003 .001 r
.60971 .26715 m .60703 .26801 L .59821 .26951 L F
.60703 .26801 m .58554 .27497 L .59821 .26951 L F
.029 .01 .003 r
.59821 .26951 m .59574 .27029 L .58613 .27146 L F
.59574 .27029 m .57589 .27652 L .58613 .27146 L F
.047 .016 .004 r
.58613 .27146 m .58388 .27216 L .57357 .273 L F
.399 .217 .062 r
.56926 .27571 m .54975 .27426 L .55176 .27658 L F
.047 .016 .004 r
.58388 .27216 m .56585 .27774 L .57357 .273 L F
0 0 0 r
.57832 .27239 m .56067 .27409 L .56518 .27349 L F
.56518 .27349 m .56337 .27362 L .54975 .27426 L F
.39 .213 .061 r
.55176 .27658 m .54975 .27426 L .53713 .27485 L F
0 0 0 r
.56337 .27362 m .54753 .27475 L .54975 .27426 L F
.39 .213 .061 r
.53713 .27485 m .54975 .27426 L .53418 .2745 L F
.379 .208 .059 r
.51646 .27654 m .5032 .27341 L .49897 .27562 L F
.51646 .27654 m .51862 .27422 L .5032 .27341 L F
.022 .01 .002 r
.57137 .50669 m .56918 .50717 L .54568 .50773 L F
.009 .004 .001 r
.59608 .50548 m .56918 .50717 L .57137 .50669 L F
.875 .463 .131 r
.38371 .27723 m .37813 .26549 L .36592 .27181 L F
.38371 .27723 m .39457 .27056 L .37813 .26549 L F
.353 .193 .049 r
.77449 .44248 m .74618 .45867 L .75055 .44867 L F
.422 .241 .067 r
.7782 .43143 m .77449 .44248 L .75055 .44867 L F
1 1 .616 r
.28549 .39422 m .28567 .4069 L .26302 .39939 L F
.044 .019 .004 r
.49631 .50662 m .47539 .50592 L .47162 .50536 L F
.49631 .50662 m .4986 .50711 L .47539 .50592 L F
.662 .38 .147 r
.35128 .4724 m .33354 .47514 L .32701 .46727 L F
.35128 .4724 m .357 .48004 L .33354 .47514 L F
1 .636 .3 r
.31713 .44823 m .29826 .45223 L .29333 .44199 L F
.31713 .44823 m .32154 .45825 L .29826 .45223 L F
.624 .336 .095 r
.64582 .26993 m .61942 .26961 L .62866 .27342 L F
.377 .207 .059 r
.49897 .27562 m .48806 .27208 L .48178 .27412 L F
.49897 .27562 m .5032 .27341 L .48806 .27208 L F
.515 .258 .08 r
.80322 .33094 m .77675 .32652 L .78255 .33907 L F
.473 .235 .073 r
.80829 .34379 m .78255 .33907 L .78719 .35194 L F
.80829 .34379 m .80322 .33094 L .78255 .33907 L F
.431 .212 .066 r
.81208 .35686 m .78719 .35194 L .79064 .36499 L F
.81208 .35686 m .80829 .34379 L .78719 .35194 L F
.586 .315 .091 r
.43956 .27318 m .43356 .2662 L .42246 .26965 L F
.43956 .27318 m .44893 .26939 L .43356 .2662 L F
.496 .303 .112 r
.80489 .39998 m .78074 .4197 L .78209 .40743 L F
.564 .358 .153 r
.80509 .38717 m .80489 .39998 L .78209 .40743 L F
.558 .281 .086 r
.79687 .31845 m .76981 .31443 L .77675 .32652 L F
.515 .258 .08 r
.80322 .33094 m .79687 .31845 L .77675 .32652 L F
1 .514 .139 r
.28536 .33849 m .27124 .31782 L .26486 .3303 L F
.28536 .33849 m .29121 .32594 L .27124 .31782 L F
1 .5 .134 r
.28069 .35136 m .28536 .33849 L .26486 .3303 L F
.39 .19 .059 r
.81455 .37001 m .79064 .36499 L .7929 .37808 L F
.81455 .37001 m .81208 .35686 L .79064 .36499 L F
.601 .305 .093 r
.78928 .30648 m .76176 .30294 L .76981 .31443 L F
.558 .281 .086 r
.79687 .31845 m .78928 .30648 L .76981 .31443 L F
.009 .004 .001 r
.59608 .50548 m .59242 .50603 L .56918 .50717 L F
0 0 0 r
.62032 .50365 m .59242 .50603 L .59608 .50548 L F
1 .5 .134 r
.28069 .35136 m .26486 .3303 L .25975 .34315 L F
1 .482 .129 r
.27721 .36441 m .28069 .35136 L .25975 .34315 L F
1 .525 .142 r
.29121 .32594 m .27887 .30586 L .27124 .31782 L F
.29121 .32594 m .29819 .31386 L .27887 .30586 L F
1 .995 .539 r
.28567 .4069 m .26452 .41184 L .26302 .39939 L F
.28567 .4069 m .28703 .41918 L .26452 .41184 L F
.046 .02 .004 r
.47162 .50536 m .45265 .50417 L .44743 .50349 L F
.47162 .50536 m .47539 .50592 L .45265 .50417 L F
.766 .402 .118 r
.73111 .27369 m .70233 .27224 L .71348 .28002 L F
.741 .385 .115 r
.74239 .28241 m .73111 .27369 L .71348 .28002 L F
.144 .062 .014 r
.68016 .4907 m .67377 .4953 L .6498 .4985 L F
.115 .049 .011 r
.70414 .48669 m .67377 .4953 L .68016 .4907 L F
.195 .089 .022 r
.71072 .48038 m .70414 .48669 L .68016 .4907 L F
1 .482 .129 r
.27721 .36441 m .25975 .34315 L .25594 .35623 L F
.967 .461 .122 r
.27494 .3775 m .27721 .36441 L .25594 .35623 L F
1 .533 .145 r
.29819 .31386 m .28773 .29455 L .27887 .30586 L F
.29819 .31386 m .3063 .30238 L .28773 .29455 L F
.377 .207 .059 r
.48178 .27412 m .47333 .27024 L .46506 .27204 L F
.48178 .27412 m .48806 .27208 L .47333 .27024 L F
.951 .497 .14 r
.35468 .27957 m .34958 .26577 L .33717 .27319 L F
.35468 .27957 m .36592 .27181 L .34958 .26577 L F
.09 .039 .009 r
.6498 .4985 m .64389 .50122 L .62032 .50365 L F
.064 .027 .006 r
.67377 .4953 m .64389 .50122 L .6498 .4985 L F
.275 .121 .027 r
.38754 .49042 m .37122 .49119 L .36365 .48637 L F
.38754 .49042 m .39401 .49504 L .37122 .49119 L F
.643 .33 .1 r
.78048 .29516 m .75261 .29221 L .76176 .30294 L F
.601 .305 .093 r
.78928 .30648 m .78048 .29516 L .76176 .30294 L F
.178 .076 .017 r
.41791 .49828 m .40127 .49796 L .39401 .49504 L F
.41791 .49828 m .42391 .50102 L .40127 .49796 L F
.426 .249 .076 r
.8034 .41241 m .7782 .43143 L .78074 .4197 L F
.496 .303 .112 r
.80489 .39998 m .8034 .41241 L .78074 .4197 L F
.273 .14 .037 r
.76959 .4527 m .74076 .46767 L .74618 .45867 L F
.353 .193 .049 r
.77449 .44248 m .76959 .4527 L .74618 .45867 L F
.967 .461 .122 r
.27494 .3775 m .25594 .35623 L .25346 .36938 L F
1 .535 .146 r
.3063 .30238 m .29778 .28406 L .28773 .29455 L F
.3063 .30238 m .31552 .29167 L .29778 .28406 L F
.148 .065 .016 r
.73429 .47552 m .70414 .48669 L .71072 .48038 L F
.239 .115 .03 r
.74076 .46767 m .73429 .47552 L .71072 .48038 L F
.83 .496 .214 r
.32154 .45825 m .30439 .46148 L .29826 .45223 L F
.32154 .45825 m .32701 .46727 L .30439 .46148 L F
1 .879 .455 r
.28703 .41918 m .26734 .42378 L .26452 .41184 L F
.28703 .41918 m .28958 .43093 L .26734 .42378 L F
.748 .4 .115 r
.67368 .27092 m .66202 .26586 L .64582 .26993 L F
.746 .399 .115 r
.69022 .26589 m .66202 .26586 L .67368 .27092 L F
.783 .415 .121 r
.70233 .27224 m .69022 .26589 L .67368 .27092 L F
.43 .223 .064 r
.357 .48004 m .34112 .48169 L .33354 .47514 L F
.357 .48004 m .36365 .48637 L .34112 .48169 L F
.757 .405 .116 r
.39457 .27056 m .39135 .26087 L .37813 .26549 L F
.39457 .27056 m .40634 .26554 L .39135 .26087 L F
.684 .353 .106 r
.77049 .28465 m .74239 .28241 L .75261 .29221 L F
.643 .33 .1 r
.78048 .29516 m .77049 .28465 L .75261 .29221 L F
0 0 0 r
.62032 .50365 m .6152 .50432 L .59242 .50603 L F
.64389 .50122 m .6152 .50432 L .62032 .50365 L F
.624 .336 .095 r
.64582 .26993 m .63485 .26645 L .61942 .26961 L F
.636 .343 .097 r
.66202 .26586 m .63485 .26645 L .64582 .26993 L F
.044 .019 .004 r
.44743 .50349 m .43057 .50185 L .42391 .50102 L F
.44743 .50349 m .45265 .50417 L .43057 .50185 L F
.379 .208 .06 r
.46506 .27204 m .45915 .2679 L .44893 .26939 L F
.46506 .27204 m .47333 .27024 L .45915 .2679 L F
.592 .318 .092 r
.42246 .26965 m .41909 .26248 L .40634 .26554 L F
.42246 .26965 m .43356 .2662 L .41909 .26248 L F
1 .531 .146 r
.31552 .29167 m .309 .27455 L .29778 .28406 L F
.31552 .29167 m .32581 .28188 L .309 .27455 L F
.647 .439 .103 r
.54568 .50773 m .52297 .50598 L .52209 .50771 L F
.54568 .50773 m .54492 .506 L .52297 .50598 L F
.655 .444 .104 r
.56918 .50717 m .54492 .506 L .54568 .50773 L F
.641 .435 .103 r
.52209 .50771 m .50112 .50542 L .4986 .50711 L F
.52209 .50771 m .52297 .50598 L .50112 .50542 L F
.772 .409 .119 r
.71878 .26624 m .69022 .26589 L .70233 .27224 L F
.766 .402 .118 r
.73111 .27369 m .71878 .26624 L .70233 .27224 L F
.357 .2 .052 r
.80061 .42434 m .77449 .44248 L .7782 .43143 L F
.426 .249 .076 r
.8034 .41241 m .80061 .42434 L .7782 .43143 L F
.872 .462 .131 r
.36592 .27181 m .36306 .25985 L .34958 .26577 L F
.36592 .27181 m .37813 .26549 L .36306 .25985 L F
.655 .444 .104 r
.56918 .50717 m .56678 .50548 L .54492 .506 L F
.666 .45 .106 r
.59242 .50603 m .56678 .50548 L .56918 .50717 L F
.637 .433 .102 r
.4986 .50711 m .47954 .50432 L .47539 .50592 L F
.4986 .50711 m .50112 .50542 L .47954 .50432 L F
1 .751 .369 r
.28958 .43093 m .27146 .43507 L .26734 .42378 L F
.28958 .43093 m .29333 .44199 L .27146 .43507 L F
.72 .376 .112 r
.75934 .27512 m .73111 .27369 L .74239 .28241 L F
.684 .353 .106 r
.77049 .28465 m .75934 .27512 L .74239 .28241 L F
.189 .09 .023 r
.76352 .46193 m .73429 .47552 L .74076 .46767 L F
.273 .14 .037 r
.76959 .4527 m .76352 .46193 L .74076 .46767 L F
1 .52 .144 r
.32581 .28188 m .32137 .26619 L .309 .27455 L F
.32581 .28188 m .33717 .27319 L .32137 .26619 L F
.064 .027 .006 r
.67377 .4953 m .6666 .49821 L .64389 .50122 L F
.034 .015 .003 r
.69665 .4915 m .6666 .49821 L .67377 .4953 L F
.115 .049 .011 r
.70414 .48669 m .69665 .4915 L .67377 .4953 L F
.619 .349 .127 r
.32701 .46727 m .31169 .4696 L .30439 .46148 L F
.32701 .46727 m .33354 .47514 L .31169 .4696 L F
.386 .211 .061 r
.44893 .26939 m .44565 .26508 L .43356 .2662 L F
.44893 .26939 m .45915 .2679 L .44565 .26508 L F
.171 .073 .017 r
.39401 .49504 m .37971 .49433 L .37122 .49119 L F
.39401 .49504 m .40127 .49796 L .37971 .49433 L F
.016 .006 .002 r
.53418 .2745 m .52102 .27472 L .51862 .27422 L F
.53418 .2745 m .53427 .27496 L .52102 .27472 L F
.009 .003 .001 r
.54975 .27426 m .53427 .27496 L .53418 .2745 L F
.666 .45 .106 r
.59242 .50603 m .58839 .50442 L .56678 .50548 L F
.678 .457 .107 r
.6152 .50432 m .58839 .50442 L .59242 .50603 L F
.636 .432 .102 r
.47539 .50592 m .45841 .50268 L .45265 .50417 L F
.47539 .50592 m .47954 .50432 L .45841 .50268 L F
0 0 0 r
.64389 .50122 m .63734 .50204 L .6152 .50432 L F
.49 .348 .08 r
.6666 .49821 m .63734 .50204 L .64389 .50122 L F
.009 .003 .001 r
.54975 .27426 m .54753 .27475 L .53427 .27496 L F
.021 .007 .002 r
.51862 .27422 m .50789 .27403 L .5032 .27341 L F
.51862 .27422 m .52102 .27472 L .50789 .27403 L F
.081 .035 .008 r
.72678 .48206 m .69665 .4915 L .70414 .48669 L F
.148 .065 .016 r
.73429 .47552 m .72678 .48206 L .70414 .48669 L F
.395 .285 .069 r
.42391 .50102 m .40933 .49898 L .40127 .49796 L F
.42391 .50102 m .43057 .50185 L .40933 .49898 L F
.286 .152 .04 r
.79651 .43561 m .76959 .4527 L .77449 .44248 L F
.357 .2 .052 r
.80061 .42434 m .79651 .43561 L .77449 .44248 L F
.263 .113 .026 r
.36365 .48637 m .34974 .48675 L .34112 .48169 L F
.36365 .48637 m .37122 .49119 L .34974 .48675 L F
.748 .394 .116 r
.74704 .26673 m .71878 .26624 L .73111 .27369 L F
.72 .376 .112 r
.75934 .27512 m .74704 .26673 L .73111 .27369 L F
0 0 0 r
.56518 .27349 m .56067 .27409 L .54753 .27475 L F
.636 .343 .097 r
.66202 .26586 m .64939 .26277 L .63485 .26645 L F
.65 .35 .099 r
.6771 .26124 m .64939 .26277 L .66202 .26586 L F
.746 .399 .115 r
.69022 .26589 m .6771 .26124 L .66202 .26586 L F
.023 .008 .002 r
.5032 .27341 m .495 .2729 L .48806 .27208 L F
.5032 .27341 m .50789 .27403 L .495 .2729 L F
.979 .612 .281 r
.29333 .44199 m .2769 .44554 L .27146 .43507 L F
.29333 .44199 m .29826 .45223 L .2769 .44554 L F
.599 .322 .093 r
.40634 .26554 m .40565 .25826 L .39135 .26087 L F
.40634 .26554 m .41909 .26248 L .40565 .25826 L F
.743 .398 .115 r
.70539 .26029 m .6771 .26124 L .69022 .26589 L F
.772 .409 .119 r
.71878 .26624 m .70539 .26029 L .69022 .26589 L F
.949 .497 .139 r
.33717 .27319 m .33488 .25916 L .32137 .26619 L F
.33717 .27319 m .34958 .26577 L .33488 .25916 L F
1 1 .608 r
.26282 .38657 m .26302 .39939 L .2426 .39117 L F
.756 .405 .116 r
.37813 .26549 m .37764 .25568 L .36306 .25985 L F
.37813 .26549 m .39135 .26087 L .37764 .25568 L F
.481 .241 .075 r
.82163 .3221 m .79687 .31845 L .80322 .33094 L F
.436 .217 .068 r
.82711 .33492 m .80322 .33094 L .80829 .34379 L F
.82711 .33492 m .82163 .3221 L .80322 .33094 L F
.526 .266 .083 r
.81477 .30969 m .78928 .30648 L .79687 .31845 L F
.481 .241 .075 r
.82163 .3221 m .81477 .30969 L .79687 .31845 L F
.678 .457 .107 r
.6152 .50432 m .60956 .50282 L .58839 .50442 L F
.693 .466 .109 r
.63734 .50204 m .60956 .50282 L .6152 .50432 L F
.231 .135 .039 r
.48806 .27208 m .48248 .27133 L .47333 .27024 L F
.48806 .27208 m .495 .2729 L .48248 .27133 L F
.637 .433 .103 r
.45265 .50417 m .4379 .50052 L .43057 .50185 L F
.45265 .50417 m .45841 .50268 L .4379 .50052 L F
.426 .256 .087 r
.82549 .39181 m .8034 .41241 L .80489 .39998 L F
.496 .311 .125 r
.8257 .37886 m .82549 .39181 L .80489 .39998 L F
.1 .043 .01 r
.75627 .47003 m .72678 .48206 L .73429 .47552 L F
.189 .09 .023 r
.76352 .46193 m .75627 .47003 L .73429 .47552 L F
.479 .257 .072 r
.64939 .26277 m .62289 .26531 L .63485 .26645 L F
.393 .194 .061 r
.8312 .34802 m .80829 .34379 L .81208 .35686 L F
.8312 .34802 m .82711 .33492 L .80829 .34379 L F
.571 .291 .09 r
.80658 .29784 m .78048 .29516 L .78928 .30648 L F
.526 .266 .083 r
.81477 .30969 m .80658 .29784 L .78928 .30648 L F
.396 .216 .063 r
.43356 .2662 m .43296 .26181 L .41909 .26248 L F
.43356 .2662 m .44565 .26508 L .43296 .26181 L F
1 .536 .144 r
.27124 .31782 m .26175 .29718 L .25351 .30901 L F
.27124 .31782 m .27887 .30586 L .26175 .29718 L F
1 .525 .14 r
.26486 .3303 m .27124 .31782 L .25351 .30901 L F
.26486 .3303 m .25351 .30901 L .24663 .32141 L F
1 .51 .136 r
.25975 .34315 m .26486 .3303 L .24663 .32141 L F
.391 .196 .048 r
.33354 .47514 m .32016 .47641 L .31169 .4696 L F
.33354 .47514 m .34112 .48169 L .32016 .47641 L F
1 .988 .523 r
.26302 .39939 m .24423 .40381 L .2426 .39117 L F
.26302 .39939 m .26452 .41184 L .24423 .40381 L F
1 .541 .146 r
.27887 .30586 m .27129 .28606 L .26175 .29718 L F
.27887 .30586 m .28773 .29455 L .27129 .28606 L F
.207 .103 .028 r
.79111 .44606 m .76352 .46193 L .76959 .4527 L F
.286 .152 .04 r
.79651 .43561 m .79111 .44606 L .76959 .4527 L F
.351 .172 .054 r
.83387 .36124 m .81208 .35686 L .81455 .37001 L F
.83387 .36124 m .8312 .34802 L .81208 .35686 L F
1 .51 .136 r
.25975 .34315 m .24663 .32141 L .24111 .33424 L F
1 .491 .13 r
.25594 .35623 m .25975 .34315 L .24111 .33424 L F
.616 .317 .097 r
.79709 .28671 m .77049 .28465 L .78048 .29516 L F
.571 .291 .09 r
.80658 .29784 m .79709 .28671 L .78048 .29516 L F
.983 .736 .329 r
.54492 .506 m .52394 .50177 L .52297 .50598 L F
.54492 .506 m .54408 .50179 L .52394 .50177 L F
.985 .737 .33 r
.56678 .50548 m .54408 .50179 L .54492 .506 L F
.76 .403 .118 r
.73361 .25967 m .70539 .26029 L .71878 .26624 L F
.748 .394 .116 r
.74704 .26673 m .73361 .25967 L .71878 .26624 L F
.982 .735 .329 r
.52297 .50598 m .50389 .50125 L .50112 .50542 L F
.52297 .50598 m .52394 .50177 L .50389 .50125 L F
.779 .458 .187 r
.29826 .45223 m .28363 .45506 L .2769 .44554 L F
.29826 .45223 m .30439 .46148 L .28363 .45506 L F
1 .542 .148 r
.28773 .29455 m .28211 .27582 L .27129 .28606 L F
.28773 .29455 m .29778 .28406 L .28211 .27582 L F
1 .491 .13 r
.25594 .35623 m .24111 .33424 L .237 .34733 L F
.981 .468 .123 r
.25346 .36938 m .25594 .35623 L .237 .34733 L F
.867 .46 .13 r
.34958 .26577 m .34954 .25368 L .33488 .25916 L F
.34958 .26577 m .36306 .25985 L .34954 .25368 L F
.238 .139 .041 r
.47333 .27024 m .47044 .26935 L .45915 .2679 L F
.47333 .27024 m .48248 .27133 L .47044 .26935 L F
.49 .348 .08 r
.6666 .49821 m .65865 .49921 L .63734 .50204 L F
.034 .015 .003 r
.69665 .4915 m .68825 .49462 L .6666 .49821 L F
.535 .374 .086 r
.68825 .49462 m .65865 .49921 L .6666 .49821 L F
.985 .737 .33 r
.56678 .50548 m .56415 .50131 L .54408 .50179 L F
.987 .739 .331 r
.58839 .50442 m .56415 .50131 L .56678 .50548 L F
.355 .203 .057 r
.82387 .40443 m .80061 .42434 L .8034 .41241 L F
.426 .256 .087 r
.82549 .39181 m .82387 .40443 L .8034 .41241 L F
.982 .735 .329 r
.50112 .50542 m .48409 .50023 L .47954 .50432 L F
.50112 .50542 m .50389 .50125 L .48409 .50023 L F
.659 .342 .104 r
.78632 .27645 m .75934 .27512 L .77049 .28465 L F
.616 .317 .097 r
.79709 .28671 m .78632 .27645 L .77049 .28465 L F
0 0 0 r
.71823 .4871 m .68825 .49462 L .69665 .4915 L F
.081 .035 .008 r
.72678 .48206 m .71823 .4871 L .69665 .4915 L F
.409 .295 .072 r
.40127 .49796 m .38912 .49557 L .37971 .49433 L F
.40127 .49796 m .40933 .49898 L .38912 .49557 L F
.159 .068 .016 r
.37122 .49119 m .35941 .49014 L .34974 .48675 L F
.37122 .49119 m .37971 .49433 L .35941 .49014 L F
.981 .468 .123 r
.25346 .36938 m .237 .34733 L .23431 .36056 L F
1 .535 .147 r
.29778 .28406 m .29419 .26661 L .28211 .27582 L F
.29778 .28406 m .309 .27455 L .29419 .26661 L F
1 .859 .433 r
.26452 .41184 m .24729 .41597 L .24423 .40381 L F
.26452 .41184 m .26734 .42378 L .24729 .41597 L F
.693 .466 .109 r
.63734 .50204 m .63012 .5007 L .60956 .50282 L F
.709 .476 .111 r
.65865 .49921 m .63012 .5007 L .63734 .50204 L F
.65 .35 .099 r
.6771 .26124 m .66291 .25859 L .64939 .26277 L F
.664 .357 .101 r
.69091 .25609 m .66291 .25859 L .6771 .26124 L F
.743 .398 .115 r
.70539 .26029 m .69091 .25609 L .6771 .26124 L F
.641 .435 .103 r
.43057 .50185 m .41819 .49784 L .40933 .49898 L F
.43057 .50185 m .4379 .50052 L .41819 .49784 L F
.987 .739 .331 r
.58839 .50442 m .58397 .50033 L .56415 .50131 L F
.99 .741 .333 r
.60956 .50282 m .58397 .50033 L .58839 .50442 L F
.608 .326 .095 r
.39135 .26087 m .3934 .25358 L .37764 .25568 L F
.39135 .26087 m .40565 .25826 L .3934 .25358 L F
.699 .365 .11 r
.77431 .26722 m .74704 .26673 L .75934 .27512 L F
.659 .342 .104 r
.78632 .27645 m .77431 .26722 L .75934 .27512 L F
.982 .735 .33 r
.47954 .50432 m .46471 .49872 L .45841 .50268 L F
.47954 .50432 m .48409 .50023 L .46471 .49872 L F
.479 .257 .072 r
.64939 .26277 m .63565 .26207 L .62289 .26531 L F
.507 .272 .076 r
.66291 .25859 m .63565 .26207 L .64939 .26277 L F
.04 .017 .004 r
.74787 .47682 m .71823 .4871 L .72678 .48206 L F
.1 .043 .01 r
.75627 .47003 m .74787 .47682 L .72678 .48206 L F
.127 .059 .015 r
.78442 .45556 m .75627 .47003 L .76352 .46193 L F
.207 .103 .028 r
.79111 .44606 m .78442 .45556 L .76352 .46193 L F
.246 .143 .042 r
.45915 .2679 m .45899 .26696 L .44565 .26508 L F
.45915 .2679 m .46811 .26905 L .45899 .26696 L F
.255 .148 .044 r
.44565 .26508 m .45623 .26657 L .44824 .26418 L F
.45623 .26657 m .45899 .26696 L .44824 .26418 L F
.44565 .26508 m .44824 .26418 L .43296 .26181 L F
.267 .154 .046 r
.43296 .26181 m .44509 .26369 L .43831 .26103 L F
.44509 .26369 m .44824 .26418 L .43831 .26103 L F
.079 .028 .008 r
.44824 .26418 m .45772 .26824 L .44067 .26191 L F
.44824 .26418 m .44067 .26191 L .43831 .26103 L F
.195 .111 .034 r
.43831 .26103 m .45058 .26548 L .43188 .25852 L F
.43831 .26103 m .43188 .25852 L .42929 .25755 L F
.091 .032 .009 r
.45899 .26696 m .4656 .27073 L .45035 .26497 L F
.45899 .26696 m .45035 .26497 L .44824 .26418 L F
.246 .143 .042 r
.46811 .26905 m .47044 .26935 L .45899 .26696 L F
1 .521 .144 r
.309 .27455 m .30749 .25861 L .29419 .26661 L F
.309 .27455 m .32137 .26619 L .30749 .25861 L F
.284 .154 .041 r
.82083 .41657 m .79651 .43561 L .80061 .42434 L F
.355 .203 .057 r
.82387 .40443 m .82083 .41657 L .80061 .42434 L F
.411 .223 .065 r
.41909 .26248 m .4212 .2581 L .40565 .25826 L F
.41909 .26248 m .43296 .26181 L .4212 .2581 L F
.252 .108 .025 r
.34112 .48169 m .32979 .48175 L .32016 .47641 L F
.34112 .48169 m .34974 .48675 L .32979 .48175 L F
.741 .397 .114 r
.71904 .25416 m .69091 .25609 L .70539 .26029 L F
.76 .403 .118 r
.73361 .25967 m .71904 .25416 L .70539 .26029 L F
.552 .303 .098 r
.30439 .46148 m .29167 .46346 L .28363 .45506 L F
.30439 .46148 m .31169 .4696 L .29167 .46346 L F
1 .718 .342 r
.26734 .42378 m .25177 .42749 L .24729 .41597 L F
.26734 .42378 m .27146 .43507 L .25177 .42749 L F
.755 .404 .116 r
.36306 .25985 m .36536 .25001 L .34954 .25368 L F
.36306 .25985 m .37764 .25568 L .36536 .25001 L F
.73 .385 .114 r
.76108 .2592 m .73361 .25967 L .74704 .26673 L F
.699 .365 .11 r
.77431 .26722 m .76108 .2592 L .74704 .26673 L F
.99 .741 .333 r
.60956 .50282 m .60339 .49885 L .58397 .50033 L F
.993 .745 .335 r
.63012 .5007 m .60339 .49885 L .60956 .50282 L F
.983 .737 .332 r
.45841 .50268 m .44592 .49673 L .4379 .50052 L F
.45841 .50268 m .46471 .49872 L .44592 .49673 L F
.943 .496 .139 r
.32137 .26619 m .32199 .25201 L .30749 .25861 L F
.32137 .26619 m .33488 .25916 L .32199 .25201 L F
.093 .032 .009 r
.53427 .27496 m .52375 .27911 L .52102 .27472 L F
.53427 .27496 m .53437 .27931 L .52375 .27911 L F
.085 .03 .008 r
.54753 .27475 m .53437 .27931 L .53427 .27496 L F
.54753 .27475 m .54499 .27914 L .53437 .27931 L F
.075 .026 .007 r
.56067 .27409 m .54499 .27914 L .54753 .27475 L F
.099 .034 .009 r
.52102 .27472 m .51323 .27857 L .50789 .27403 L F
.52102 .27472 m .52375 .27911 L .51323 .27857 L F
.209 .107 .03 r
.81637 .42808 m .79111 .44606 L .79651 .43561 L F
.284 .154 .041 r
.82083 .41657 m .81637 .42808 L .79651 .43561 L F
.535 .374 .086 r
.68825 .49462 m .67894 .49584 L .65865 .49921 L F
0 0 0 r
.71823 .4871 m .70865 .49047 L .68825 .49462 L F
.583 .402 .093 r
.70865 .49047 m .67894 .49584 L .68825 .49462 L F
.709 .476 .111 r
.65865 .49921 m .6499 .49806 L .63012 .5007 L F
.729 .489 .116 r
.67894 .49584 m .6499 .49806 L .65865 .49921 L F
.424 .305 .074 r
.37971 .49433 m .37011 .49165 L .35941 .49014 L F
.37971 .49433 m .38912 .49557 L .37011 .49165 L F
.648 .439 .106 r
.40933 .49898 m .39946 .49467 L .38912 .49557 L F
.40933 .49898 m .41819 .49784 L .39946 .49467 L F
.075 .026 .007 r
.56067 .27409 m .55552 .27862 L .54499 .27914 L F
.062 .022 .006 r
.57357 .273 m .55552 .27862 L .56067 .27409 L F
.916 .56 .243 r
.27146 .43507 m .25767 .43824 L .25177 .42749 L F
.27146 .43507 m .2769 .44554 L .25767 .43824 L F
.103 .036 .01 r
.50789 .27403 m .50292 .27766 L .495 .2729 L F
.50789 .27403 m .51323 .27857 L .50292 .27766 L F
.055 .023 .005 r
.77644 .46393 m .74787 .47682 L .75627 .47003 L F
.127 .059 .015 r
.78442 .45556 m .77644 .46393 L .75627 .47003 L F
1 1 .631 r
.54408 .50179 m .525 .49468 L .52394 .50177 L F
.54408 .50179 m .54317 .4947 L .525 .49468 L F
1 1 .626 r
.56415 .50131 m .54317 .4947 L .54408 .50179 L F
1 1 .634 r
.52394 .50177 m .50691 .49421 L .50389 .50125 L F
.52394 .50177 m .525 .49468 L .50691 .49421 L F
.747 .397 .116 r
.74664 .25256 m .71904 .25416 L .73361 .25967 L F
.73 .385 .114 r
.76108 .2592 m .74664 .25256 L .73361 .25967 L F
.358 .173 .037 r
.31169 .4696 m .30098 .47057 L .29167 .46346 L F
.31169 .4696 m .32016 .47641 L .30098 .47057 L F
.507 .272 .076 r
.66291 .25859 m .64748 .25839 L .63565 .26207 L F
.538 .289 .08 r
.67526 .25394 m .64748 .25839 L .66291 .25859 L F
.664 .357 .101 r
.69091 .25609 m .67526 .25394 L .66291 .25859 L F
0 0 0 r
.73831 .48214 m .70865 .49047 L .71823 .4871 L F
.04 .017 .004 r
.74787 .47682 m .73831 .48214 L .71823 .4871 L F
1 1 .626 r
.56415 .50131 m .56127 .49426 L .54317 .4947 L F
1 1 .619 r
.58397 .50033 m .56127 .49426 L .56415 .50131 L F
.678 .365 .103 r
.7033 .25045 m .67526 .25394 L .69091 .25609 L F
.741 .397 .114 r
.71904 .25416 m .7033 .25045 L .69091 .25609 L F
.861 .457 .129 r
.33488 .25916 m .33771 .24702 L .32199 .25201 L F
.33488 .25916 m .34954 .25368 L .33771 .24702 L F
.062 .022 .006 r
.57357 .273 m .56585 .27774 L .55552 .27862 L F
1 1 .635 r
.50389 .50125 m .48906 .49328 L .48409 .50023 L F
.50389 .50125 m .50691 .49421 L .48906 .49328 L F
.43 .232 .068 r
.40565 .25826 m .4105 .25398 L .3934 .25358 L F
.40565 .25826 m .4212 .2581 L .4105 .25398 L F
.104 .036 .01 r
.495 .2729 m .4929 .27642 L .48248 .27133 L F
.495 .2729 m .50292 .27766 L .4929 .27642 L F
.142 .061 .014 r
.34974 .48675 m .34057 .48543 L .32979 .48175 L F
.34974 .48675 m .35941 .49014 L .34057 .48543 L F
.993 .745 .335 r
.63012 .5007 m .62223 .49689 L .60339 .49885 L F
.996 .748 .338 r
.6499 .49806 m .62223 .49689 L .63012 .5007 L F
.617 .331 .096 r
.37764 .25568 m .38245 .24847 L .36536 .25001 L F
.37764 .25568 m .3934 .25358 L .38245 .24847 L F
.985 .738 .334 r
.4379 .50052 m .42788 .49426 L .41819 .49784 L F
.4379 .50052 m .44592 .49673 L .42788 .49426 L F
1 1 .578 r
.24238 .37821 m .2426 .39117 L .22465 .3823 L F
.492 .25 .078 r
.83022 .30028 m .80658 .29784 L .81477 .30969 L F
.445 .224 .071 r
.83754 .3126 m .81477 .30969 L .82163 .3221 L F
.83754 .3126 m .83022 .30028 L .81477 .30969 L F
.54 .276 .086 r
.82149 .28858 m .79709 .28671 L .80658 .29784 L F
.492 .25 .078 r
.83022 .30028 m .82149 .28858 L .80658 .29784 L F
.139 .069 .019 r
.8105 .4388 m .78442 .45556 L .79111 .44606 L F
.209 .107 .03 r
.81637 .42808 m .8105 .4388 L .79111 .44606 L F
.399 .199 .063 r
.84339 .3254 m .82163 .3221 L .82711 .33492 L F
.84339 .3254 m .83754 .3126 L .82163 .3221 L F
1 1 .619 r
.58397 .50033 m .57914 .49336 L .56127 .49426 L F
1 1 .61 r
.60339 .49885 m .57914 .49336 L .58397 .50033 L F
.587 .303 .093 r
.81136 .27766 m .78632 .27645 L .79709 .28671 L F
.54 .276 .086 r
.82149 .28858 m .81136 .27766 L .79709 .28671 L F
.344 .201 .062 r
.84363 .38298 m .82387 .40443 L .82549 .39181 L F
.42 .259 .096 r
.84386 .36987 m .84363 .38298 L .82549 .39181 L F
1 1 .634 r
.48409 .50023 m .4716 .4919 L .46471 .49872 L F
.48409 .50023 m .48906 .49328 L .4716 .4919 L F
1 .541 .144 r
.25351 .30901 m .24703 .28787 L .23826 .29956 L F
.25351 .30901 m .26175 .29718 L .24703 .28787 L F
1 .531 .141 r
.24663 .32141 m .25351 .30901 L .23826 .29956 L F
.047 .016 .004 r
.58613 .27146 m .57589 .27652 L .56585 .27774 L F
.354 .175 .056 r
.84776 .33852 m .82711 .33492 L .8312 .34802 L F
.84776 .33852 m .84339 .3254 L .82711 .33492 L F
1 .546 .147 r
.26175 .29718 m .2572 .27697 L .24703 .28787 L F
.26175 .29718 m .27129 .28606 L .2572 .27697 L F
.696 .399 .145 r
.2769 .44554 m .26499 .44805 L .25767 .43824 L F
.2769 .44554 m .28363 .45506 L .26499 .44805 L F
.103 .036 .01 r
.48248 .27133 m .48328 .27484 L .47044 .26935 L F
.48248 .27133 m .4929 .27642 L .48328 .27484 L F
1 .531 .141 r
.24663 .32141 m .23826 .29956 L .23091 .31187 L F
1 .515 .136 r
.24111 .33424 m .24663 .32141 L .23091 .31187 L F
.267 .154 .046 r
.43296 .26181 m .43831 .26103 L .4212 .2581 L F
1 .544 .147 r
.27129 .28606 m .26872 .267 L .2572 .27697 L F
.27129 .28606 m .28211 .27582 L .26872 .267 L F
.633 .329 .1 r
.79989 .26767 m .77431 .26722 L .78632 .27645 L F
.587 .303 .093 r
.81136 .27766 m .79989 .26767 L .78632 .27645 L F
1 .952 .485 r
.2426 .39117 m .2264 .39513 L .22465 .3823 L F
.2426 .39117 m .24423 .40381 L .2264 .39513 L F
.739 .395 .114 r
.731 .24753 m .7033 .25045 L .71904 .25416 L F
.747 .397 .116 r
.74664 .25256 m .731 .24753 L .71904 .25416 L F
1 .515 .136 r
.24111 .33424 m .23091 .31187 L .22503 .32466 L F
1 .494 .129 r
.237 .34733 m .24111 .33424 L .22503 .32466 L F
.311 .152 .049 r
.85062 .35181 m .8312 .34802 L .83387 .36124 L F
.85062 .35181 m .84776 .33852 L .8312 .34802 L F
0 0 0 r
.76718 .47102 m .73831 .48214 L .74787 .47682 L F
.055 .023 .005 r
.77644 .46393 m .76718 .47102 L .74787 .47682 L F
1 .535 .146 r
.28211 .27582 m .28156 .25813 L .26872 .267 L F
.28211 .27582 m .29419 .26661 L .28156 .25813 L F
.754 .404 .116 r
.34954 .25368 m .35466 .2439 L .33771 .24702 L F
.34954 .25368 m .36536 .25001 L .35466 .2439 L F
1 .494 .129 r
.237 .34733 m .22503 .32466 L .22064 .33778 L F
.977 .468 .122 r
.23431 .36056 m .237 .34733 L .22064 .33778 L F
.729 .489 .116 r
.67894 .49584 m .66871 .49492 L .6499 .49806 L F
.753 .506 .125 r
.69804 .49196 m .66871 .49492 L .67894 .49584 L F
.583 .402 .093 r
.70865 .49047 m .69804 .49196 L .67894 .49584 L F
.235 .101 .023 r
.32016 .47641 m .31156 .47622 L .30098 .47057 L F
.32016 .47641 m .32979 .48175 L .31156 .47622 L F
.676 .354 .107 r
.78711 .25878 m .76108 .2592 L .77431 .26722 L F
.633 .329 .1 r
.79989 .26767 m .78711 .25878 L .77431 .26722 L F
.269 .149 .041 r
.84189 .3958 m .82083 .41657 L .82387 .40443 L F
.344 .201 .062 r
.84363 .38298 m .84189 .3958 L .82387 .40443 L F
1 1 .61 r
.60339 .49885 m .59664 .49202 L .57914 .49336 L F
1 1 .599 r
.62223 .49689 m .59664 .49202 L .60339 .49885 L F
1 1 .631 r
.46471 .49872 m .45468 .49008 L .44592 .49673 L F
.46471 .49872 m .4716 .4919 L .45468 .49008 L F
.029 .01 .003 r
.59821 .26951 m .58554 .27497 L .57589 .27652 L F
.659 .446 .111 r
.38912 .49557 m .38187 .49102 L .37011 .49165 L F
.38912 .49557 m .39946 .49467 L .38187 .49102 L F
.099 .034 .009 r
.47044 .26935 m .47415 .27294 L .45899 .26696 L F
.47044 .26935 m .48328 .27484 L .47415 .27294 L F
.993 .518 .143 r
.29419 .26661 m .29568 .25053 L .28156 .25813 L F
.29419 .26661 m .30749 .25861 L .29568 .25053 L F
.996 .748 .338 r
.6499 .49806 m .64033 .49446 L .62223 .49689 L F
1 .752 .341 r
.66871 .49492 m .64033 .49446 L .6499 .49806 L F
.05 .021 .005 r
.80323 .44859 m .77644 .46393 L .78442 .45556 L F
.139 .069 .019 r
.8105 .4388 m .80323 .44859 L .78442 .45556 L F
1 .807 .389 r
.24423 .40381 m .22969 .40752 L .2264 .39513 L F
.24423 .40381 m .24729 .41597 L .22969 .40752 L F
0 0 0 r
.73831 .48214 m .7276 .4858 L .70865 .49047 L F
.632 .431 .099 r
.7276 .4858 m .69804 .49196 L .70865 .49047 L F
.987 .741 .336 r
.41819 .49784 m .41076 .49134 L .39946 .49467 L F
.41819 .49784 m .42788 .49426 L .41076 .49134 L F
.977 .468 .122 r
.23431 .36056 m .22064 .33778 L .21777 .35108 L F
.538 .289 .08 r
.67526 .25394 m .65827 .2543 L .64748 .25839 L F
.573 .308 .085 r
.68631 .24886 m .65827 .2543 L .67526 .25394 L F
.678 .365 .103 r
.7033 .25045 m .68631 .24886 L .67526 .25394 L F
.441 .317 .077 r
.35941 .49014 m .35251 .48723 L .34057 .48543 L F
.35941 .49014 m .37011 .49165 L .35251 .48723 L F
.468 .246 .063 r
.28363 .45506 m .2737 .45675 L .26499 .44805 L F
.28363 .45506 m .29167 .46346 L .2737 .45675 L F
.711 .376 .112 r
.77304 .25115 m .74664 .25256 L .76108 .2592 L F
.676 .354 .107 r
.78711 .25878 m .77304 .25115 L .76108 .2592 L F
.453 .244 .072 r
.3934 .25358 m .40097 .24949 L .38245 .24847 L F
.3934 .25358 m .4105 .25398 L .40097 .24949 L F
.933 .492 .137 r
.30749 .25861 m .32199 .25201 L .31107 .24439 L F
.438 .236 .065 r
.65827 .2543 m .63051 .26128 L .64748 .25839 L F
.198 .104 .03 r
.83862 .40817 m .81637 .42808 L .82083 .41657 L F
.269 .149 .041 r
.84189 .3958 m .83862 .40817 L .82083 .41657 L F
.694 .373 .106 r
.71413 .24437 m .68631 .24886 L .7033 .25045 L F
.739 .395 .114 r
.731 .24753 m .71413 .24437 L .7033 .25045 L F
.287 .164 .048 r
.4212 .2581 m .42929 .25755 L .4105 .25398 L F
.4212 .2581 m .43831 .26103 L .42929 .25755 L F
1 1 .788 r
.54317 .4947 m .52616 .48414 L .525 .49468 L F
.54317 .4947 m .54217 .48416 L .52616 .48414 L F
1 1 .777 r
.56127 .49426 m .54217 .48416 L .54317 .4947 L F
1 1 .798 r
.525 .49468 m .51023 .48372 L .50691 .49421 L F
.525 .49468 m .52616 .48414 L .51023 .48372 L F
.008 .003 .001 r
.60971 .26715 m .59471 .27309 L .58554 .27497 L F
.627 .336 .098 r
.36536 .25001 m .37294 .24297 L .35466 .2439 L F
.36536 .25001 m .38245 .24847 L .37294 .24297 L F
1 1 .599 r
.62223 .49689 m .6136 .49023 L .59664 .49202 L F
1 1 .587 r
.64033 .49446 m .6136 .49023 L .62223 .49689 L F
1 .647 .288 r
.24729 .41597 m .2345 .41932 L .22969 .40752 L F
.24729 .41597 m .25177 .42749 L .2345 .41932 L F
.091 .032 .009 r
.45899 .26696 m .47415 .27294 L .4656 .27073 L F
1 1 .625 r
.44592 .49673 m .43846 .48784 L .42788 .49426 L F
.44592 .49673 m .45468 .49008 L .43846 .48784 L F
0 0 0 r
.75667 .47665 m .7276 .4858 L .73831 .48214 L F
.76718 .47102 m .75667 .47665 L .73831 .48214 L F
1 1 .777 r
.56127 .49426 m .55811 .48376 L .54217 .48416 L F
1 1 .763 r
.57914 .49336 m .55811 .48376 L .56127 .49426 L F
.734 .39 .114 r
.75771 .24497 m .731 .24753 L .74664 .25256 L F
1 1 .805 r
.50691 .49421 m .49452 .48289 L .48906 .49328 L F
.50691 .49421 m .51023 .48372 L .49452 .48289 L F
.12 .051 .012 r
.32979 .48175 m .3234 .48022 L .31156 .47622 L F
.32979 .48175 m .34057 .48543 L .3234 .48022 L F
.001 0 0 r
.79456 .45727 m .76718 .47102 L .77644 .46393 L F
.05 .021 .005 r
.80323 .44859 m .79456 .45727 L .77644 .46393 L F
.852 .453 .128 r
.32199 .25201 m .32772 .23993 L .31107 .24439 L F
.32199 .25201 m .33771 .24702 L .32772 .23993 L F
.325 .151 .033 r
.29167 .46346 m .2838 .46419 L .2737 .45675 L F
.29167 .46346 m .30098 .47057 L .2838 .46419 L F
.133 .07 .02 r
.83383 .41995 m .8105 .4388 L .81637 .42808 L F
.198 .104 .03 r
.83862 .40817 m .83383 .41995 L .81637 .42808 L F
1 1 .763 r
.57914 .49336 m .57385 .48296 L .55811 .48376 L F
1 1 .747 r
.59664 .49202 m .57385 .48296 L .57914 .49336 L F
1 1 .81 r
.48906 .49328 m .47915 .48165 L .4716 .4919 L F
.48906 .49328 m .49452 .48289 L .47915 .48165 L F
1 .752 .341 r
.66871 .49492 m .65753 .49157 L .64033 .49446 L F
1 .757 .345 r
.68639 .49131 m .65753 .49157 L .66871 .49492 L F
.753 .506 .125 r
.69804 .49196 m .68639 .49131 L .66871 .49492 L F
.806 .476 .182 r
.25177 .42749 m .24083 .43036 L .2345 .41932 L F
.25177 .42749 m .25767 .43824 L .24083 .43036 L F
.781 .528 .138 r
.71576 .48758 m .68639 .49131 L .69804 .49196 L F
.632 .431 .099 r
.7276 .4858 m .71576 .48758 L .69804 .49196 L F
.99 .743 .339 r
.39946 .49467 m .3947 .48798 L .38187 .49102 L F
.39946 .49467 m .41076 .49134 L .3947 .48798 L F
.142 .05 .014 r
.53437 .27931 m .52712 .28994 L .52375 .27911 L F
.53437 .27931 m .53449 .29007 L .52712 .28994 L F
.132 .046 .013 r
.54499 .27914 m .53449 .29007 L .53437 .27931 L F
0 0 0 r
.62051 .2644 m .60331 .27091 L .59471 .27309 L F
.132 .046 .013 r
.54499 .27914 m .54186 .28996 L .53449 .29007 L F
.122 .042 .012 r
.55552 .27862 m .54186 .28996 L .54499 .27914 L F
.153 .055 .015 r
.52375 .27911 m .51983 .28957 L .51323 .27857 L F
.52375 .27911 m .52712 .28994 L .51983 .28957 L F
.737 .394 .114 r
.74113 .24047 m .71413 .24437 L .731 .24753 L F
.734 .39 .114 r
.75771 .24497 m .74113 .24047 L .731 .24753 L F
.674 .458 .12 r
.37011 .49165 m .3656 .48692 L .35251 .48723 L F
.37011 .49165 m .38187 .49102 L .3656 .48692 L F
.079 .028 .008 r
.44824 .26418 m .4656 .27073 L .45772 .26824 L F
.122 .042 .012 r
.55552 .27862 m .54915 .2896 L .54186 .28996 L F
.11 .038 .011 r
.56585 .27774 m .54915 .2896 L .55552 .27862 L F
.16 .058 .016 r
.51323 .27857 m .51269 .28895 L .50292 .27766 L F
.51323 .27857 m .51983 .28957 L .51269 .28895 L F
1 1 .587 r
.64033 .49446 m .62989 .48802 L .6136 .49023 L F
1 .984 .572 r
.65753 .49157 m .62989 .48802 L .64033 .49446 L F
.752 .403 .115 r
.33771 .24702 m .35466 .2439 L .34567 .2374 L F
.573 .308 .085 r
.68631 .24886 m .66789 .24984 L .65827 .2543 L F
.61 .328 .091 r
.69593 .24339 m .66789 .24984 L .68631 .24886 L F
.694 .373 .106 r
.71413 .24437 m .69593 .24339 L .68631 .24886 L F
.438 .236 .065 r
.65827 .2543 m .63959 .25782 L .63051 .26128 L F
.47 .251 .069 r
.66789 .24984 m .63959 .25782 L .65827 .2543 L F
1 1 .747 r
.59664 .49202 m .58924 .48176 L .57385 .48296 L F
1 1 .729 r
.6136 .49023 m .58924 .48176 L .59664 .49202 L F
1 1 .616 r
.42788 .49426 m .42308 .48518 L .41076 .49134 L F
.42788 .49426 m .43846 .48784 L .42308 .48518 L F
.308 .173 .051 r
.4105 .25398 m .42129 .25376 L .40097 .24949 L F
.4105 .25398 m .42929 .25755 L .42129 .25376 L F
1 1 .812 r
.4716 .4919 m .46428 .48003 L .45468 .49008 L F
.4716 .4919 m .47915 .48165 L .46428 .48003 L F
.479 .257 .076 r
.38245 .24847 m .39272 .24467 L .37294 .24297 L F
.38245 .24847 m .40097 .24949 L .39272 .24467 L F
.11 .038 .011 r
.56585 .27774 m .55631 .289 L .54915 .2896 L F
.096 .033 .009 r
.57589 .27652 m .55631 .289 L .56585 .27774 L F
.051 .026 .007 r
.82753 .43096 m .80323 .44859 L .8105 .4388 L F
.133 .07 .02 r
.83383 .41995 m .82753 .43096 L .8105 .4388 L F
.164 .06 .016 r
.50292 .27766 m .50576 .2881 L .4929 .27642 L F
.50292 .27766 m .51269 .28895 L .50576 .2881 L F
0 0 0 r
.78452 .46468 m .75667 .47665 L .76718 .47102 L F
.001 0 0 r
.79456 .45727 m .78452 .46468 L .76718 .47102 L F
0 0 0 r
.75667 .47665 m .74491 .48062 L .7276 .4858 L F
.681 .459 .105 r
.74491 .48062 m .71576 .48758 L .7276 .4858 L F
.506 .26 .082 r
.83377 .27877 m .81136 .27766 L .82149 .28858 L F
.456 .232 .074 r
.84299 .2903 m .82149 .28858 L .83022 .30028 L F
.84299 .2903 m .83377 .27877 L .82149 .28858 L F
.556 .288 .089 r
.8231 .26807 m .79989 .26767 L .81136 .27766 L F
.506 .26 .082 r
.83377 .27877 m .8231 .26807 L .81136 .27766 L F
.406 .205 .065 r
.85071 .30252 m .83022 .30028 L .83754 .3126 L F
.85071 .30252 m .84299 .2903 L .83022 .30028 L F
.468 .334 .081 r
.34057 .48543 m .33649 .48236 L .3234 .48022 L F
.34057 .48543 m .35251 .48723 L .33649 .48236 L F
.581 .321 .093 r
.25767 .43824 m .24868 .44048 L .24083 .43036 L F
.25767 .43824 m .26499 .44805 L .24868 .44048 L F
.209 .09 .02 r
.30098 .47057 m .29526 .47018 L .2838 .46419 L F
.30098 .47057 m .31156 .47622 L .29526 .47018 L F
1 1 .514 r
.22442 .36917 m .22465 .3823 L .20943 .37282 L F
.605 .316 .097 r
.81101 .25838 m .78711 .25878 L .79989 .26767 L F
.357 .179 .057 r
.8569 .31528 m .83754 .3126 L .84339 .3254 L F
.8569 .31528 m .85071 .30252 L .83754 .3126 L F
1 .544 .145 r
.24703 .28787 m .24566 .26734 L .23495 .27801 L F
.24703 .28787 m .2572 .27697 L .24566 .26734 L F
1 .539 .143 r
.23826 .29956 m .24703 .28787 L .23495 .27801 L F
1 .541 .146 r
.2572 .27697 m .26872 .267 L .25779 .25767 L F
.096 .033 .009 r
.57589 .27652 m .56326 .28817 L .55631 .289 L F
.08 .028 .008 r
.58554 .27497 m .56326 .28817 L .57589 .27652 L F
.165 .06 .016 r
.4929 .27642 m .49912 .28702 L .48328 .27484 L F
.4929 .27642 m .50576 .2881 L .49912 .28702 L F
1 .539 .143 r
.23826 .29956 m .23495 .27801 L .2257 .28953 L F
1 .528 .139 r
.23091 .31187 m .23826 .29956 L .2257 .28953 L F
.709 .382 .108 r
.72325 .23789 m .69593 .24339 L .71413 .24437 L F
.242 .138 .04 r
.85906 .37354 m .84189 .3958 L .84363 .38298 L F
.324 .195 .064 r
.85931 .36026 m .85906 .37354 L .84363 .38298 L F
.308 .153 .05 r
.86152 .32842 m .84339 .3254 L .84776 .33852 L F
.86152 .32842 m .8569 .31528 L .84339 .3254 L F
1 1 .729 r
.6136 .49023 m .60416 .48016 L .58924 .48176 L F
1 1 .709 r
.62989 .48802 m .60416 .48016 L .6136 .49023 L F
1 .528 .139 r
.23091 .31187 m .2257 .28953 L .21795 .30175 L F
1 .51 .133 r
.22503 .32466 m .23091 .31187 L .21795 .30175 L F
.637 .341 .099 r
.35466 .2439 m .36498 .23712 L .34567 .2374 L F
.35466 .2439 m .37294 .24297 L .36498 .23712 L F
.195 .111 .034 r
.43831 .26103 m .4544 .26701 L .45058 .26548 L F
.217 .124 .038 r
.42929 .25755 m .44695 .26413 L .44427 .26249 L F
.44695 .26413 m .45058 .26548 L .44427 .26249 L F
.117 .041 .011 r
.45058 .26548 m .47238 .27863 L .44701 .26406 L F
.45058 .26548 m .44701 .26406 L .44427 .26249 L F
.162 .09 .029 r
.44427 .26249 m .46873 .27646 L .44177 .26095 L F
.44427 .26249 m .44177 .26095 L .43887 .25928 L F
.195 .111 .034 r
.4544 .26701 m .45772 .26824 L .45058 .26548 L F
1 1 .81 r
.45468 .49008 m .45003 .47802 L .43846 .48784 L F
.45468 .49008 m .46428 .48003 L .45003 .47802 L F
1 .868 .414 r
.22465 .3823 m .21129 .38587 L .20943 .37282 L F
.22465 .3823 m .2264 .39513 L .21129 .38587 L F
1 .51 .133 r
.22503 .32466 m .21795 .30175 L .21174 .3145 L F
.996 .485 .126 r
.22064 .33778 m .22503 .32466 L .21174 .3145 L F
1 1 .837 r
.54217 .48416 m .52745 .46924 L .52616 .48414 L F
.54217 .48416 m .54106 .46926 L .52745 .46924 L F
1 1 .82 r
.55811 .48376 m .54106 .46926 L .54217 .48416 L F
1 1 .853 r
.52616 .48414 m .51391 .46887 L .51023 .48372 L F
.52616 .48414 m .52745 .46924 L .51391 .46887 L F
0 0 0 r
.81972 .44106 m .79456 .45727 L .80323 .44859 L F
.051 .026 .007 r
.82753 .43096 m .81972 .44106 L .80323 .44859 L F
.258 .127 .041 r
.86454 .34179 m .84776 .33852 L .85062 .35181 L F
.86454 .34179 m .86152 .32842 L .84776 .33852 L F
.08 .028 .008 r
.58554 .27497 m .56993 .28711 L .56326 .28817 L F
.06 .021 .006 r
.59471 .27309 m .56993 .28711 L .58554 .27497 L F
1 .757 .345 r
.68639 .49131 m .67367 .48824 L .65753 .49157 L F
1 .762 .349 r
.70276 .48725 m .67367 .48824 L .68639 .49131 L F
.781 .528 .138 r
.71576 .48758 m .70276 .48725 L .68639 .49131 L F
.162 .057 .016 r
.48328 .27484 m .49282 .28572 L .47415 .27294 L F
.48328 .27484 m .49912 .28702 L .49282 .28572 L F
1 .984 .572 r
.65753 .49157 m .64533 .48539 L .62989 .48802 L F
1 .965 .557 r
.67367 .48824 m .64533 .48539 L .65753 .49157 L F
1 1 .82 r
.55811 .48376 m .55461 .46891 L .54106 .46926 L F
1 1 .802 r
.57385 .48296 m .55461 .46891 L .55811 .48376 L F
1 1 .867 r
.51023 .48372 m .50056 .46815 L .49452 .48289 L F
.51023 .48372 m .51391 .46887 L .50056 .46815 L F
.993 .747 .343 r
.38187 .49102 m .37989 .48421 L .3656 .48692 L F
.38187 .49102 m .3947 .48798 L .37989 .48421 L F
.174 .096 .029 r
.85721 .38658 m .83862 .40817 L .84189 .3958 L F
.242 .138 .04 r
.85906 .37354 m .85721 .38658 L .84189 .3958 L F
.411 .207 .043 r
.26499 .44805 m .25802 .44953 L .24868 .44048 L F
.26499 .44805 m .2737 .45675 L .25802 .44953 L F
1 1 .605 r
.41076 .49134 m .40869 .48213 L .3947 .48798 L F
.41076 .49134 m .42308 .48518 L .40869 .48213 L F
.996 .485 .126 r
.22064 .33778 m .21174 .3145 L .2071 .32764 L F
.943 .453 .117 r
.21777 .35108 m .22064 .33778 L .2071 .32764 L F
0 0 0 r
.78452 .46468 m .77312 .47065 L .75667 .47665 L F
.594 .407 .092 r
.77312 .47065 m .74491 .48062 L .75667 .47665 L F
.47 .251 .069 r
.66789 .24984 m .64767 .25405 L .63959 .25782 L F
.511 .272 .075 r
.67624 .24504 m .64767 .25405 L .66789 .24984 L F
.61 .328 .091 r
.69593 .24339 m .67624 .24504 L .66789 .24984 L F
.334 .184 .055 r
.40097 .24949 m .4144 .24969 L .39272 .24467 L F
.40097 .24949 m .42129 .25376 L .4144 .24969 L F
1 .704 .31 r
.2264 .39513 m .21478 .39851 L .21129 .38587 L F
.2264 .39513 m .22969 .40752 L .21478 .39851 L F
.352 .248 .063 r
.31156 .47622 m .30807 .47454 L .29526 .47018 L F
.31156 .47622 m .3234 .48022 L .30807 .47454 L F
1 1 .802 r
.57385 .48296 m .56798 .46822 L .55461 .46891 L F
1 1 .782 r
.58924 .48176 m .56798 .46822 L .57385 .48296 L F
.813 .556 .157 r
.7319 .48274 m .70276 .48725 L .71576 .48758 L F
.681 .459 .105 r
.74491 .48062 m .7319 .48274 L .71576 .48758 L F
1 1 .88 r
.49452 .48289 m .48752 .46708 L .47915 .48165 L F
.49452 .48289 m .50056 .46815 L .48752 .46708 L F
.647 .349 .097 r
.70401 .23757 m .67624 .24504 L .69593 .24339 L F
.709 .382 .108 r
.72325 .23789 m .70401 .23757 L .69593 .24339 L F
.695 .475 .134 r
.35251 .48723 m .35083 .4824 L .33649 .48236 L F
.35251 .48723 m .3656 .48692 L .35083 .4824 L F
.06 .021 .006 r
.59471 .27309 m .57625 .28583 L .56993 .28711 L F
.036 .012 .003 r
.60331 .27091 m .57625 .28583 L .59471 .27309 L F
.943 .453 .117 r
.21777 .35108 m .2071 .32764 L .20407 .34102 L F
1 1 .709 r
.62989 .48802 m .61845 .47818 L .60416 .48016 L F
1 1 .687 r
.64533 .48539 m .61845 .47818 L .62989 .48802 L F
.155 .054 .015 r
.47415 .27294 m .48694 .28422 L .4656 .27073 L F
.47415 .27294 m .49282 .28572 L .48694 .28422 L F
.506 .271 .08 r
.37294 .24297 m .38586 .23955 L .36498 .23712 L F
.37294 .24297 m .39272 .24467 L .38586 .23955 L F
1 1 .804 r
.43846 .48784 m .43655 .47565 L .42308 .48518 L F
.43846 .48784 m .45003 .47802 L .43655 .47565 L F
.11 .062 .019 r
.85373 .3992 m .83383 .41995 L .83862 .40817 L F
.174 .096 .029 r
.85721 .38658 m .85373 .3992 L .83862 .40817 L F
.217 .124 .038 r
.42929 .25755 m .44427 .26249 L .42129 .25376 L F
0 0 0 r
.81042 .45008 m .78452 .46468 L .79456 .45727 L F
.81972 .44106 m .81042 .45008 L .79456 .45727 L F
1 1 .782 r
.58924 .48176 m .58105 .46717 L .56798 .46822 L F
1 1 .761 r
.60416 .48016 m .58105 .46717 L .58924 .48176 L F
1 1 .89 r
.47915 .48165 m .47491 .46567 L .46428 .48003 L F
.47915 .48165 m .48752 .46708 L .47491 .46567 L F
.874 .529 .201 r
.22969 .40752 m .21989 .41059 L .21478 .39851 L F
.22969 .40752 m .2345 .41932 L .21989 .41059 L F
.276 .121 .027 r
.2737 .45675 m .26883 .45732 L .25802 .44953 L F
.2737 .45675 m .2838 .46419 L .26883 .45732 L F
.036 .012 .003 r
.60331 .27091 m .58216 .28434 L .57625 .28583 L F
.008 .003 .001 r
.61125 .26844 m .58216 .28434 L .60331 .27091 L F
.147 .051 .014 r
.4656 .27073 m .48154 .28253 L .45772 .26824 L F
.4656 .27073 m .48694 .28422 L .48154 .28253 L F
.727 .486 .111 r
.76038 .47498 m .7319 .48274 L .74491 .48062 L F
.594 .407 .092 r
.77312 .47065 m .76038 .47498 L .74491 .48062 L F
.035 .022 .007 r
.84865 .41126 m .82753 .43096 L .83383 .41995 L F
.11 .062 .019 r
.85373 .3992 m .84865 .41126 L .83383 .41995 L F
1 .965 .557 r
.67367 .48824 m .6598 .48237 L .64533 .48539 L F
1 .944 .539 r
.68858 .4845 m .6598 .48237 L .67367 .48824 L F
1 .762 .349 r
.70276 .48725 m .68858 .4845 L .67367 .48824 L F
.503 .353 .086 r
.3234 .48022 m .32223 .47705 L .30807 .47454 L F
.3234 .48022 m .33649 .48236 L .32223 .47705 L F
1 1 .591 r
.3947 .48798 m .39543 .4787 L .37989 .48421 L F
.3947 .48798 m .40869 .48213 L .39543 .4787 L F
1 1 .761 r
.60416 .48016 m .5937 .46579 L .58105 .46717 L F
1 1 .739 r
.61845 .47818 m .5937 .46579 L .60416 .48016 L F
1 1 .896 r
.46428 .48003 m .46284 .46393 L .45003 .47802 L F
.46428 .48003 m .47491 .46567 L .46284 .46393 L F
.648 .347 .101 r
.34567 .2374 m .36498 .23712 L .35869 .23099 L F
.655 .37 .108 r
.2345 .41932 m .22661 .42195 L .21989 .41059 L F
.2345 .41932 m .24083 .43036 L .22661 .42195 L F
1 1 .687 r
.64533 .48539 m .632 .47584 L .61845 .47818 L F
1 1 .662 r
.6598 .48237 m .632 .47584 L .64533 .48539 L F
.511 .272 .075 r
.67624 .24504 m .65465 .25 L .64767 .25405 L F
.563 .301 .082 r
.68321 .23994 m .65465 .25 L .67624 .24504 L F
.647 .349 .097 r
.70401 .23757 m .68321 .23994 L .67624 .24504 L F
1 .767 .353 r
.71765 .48275 m .68858 .4845 L .70276 .48725 L F
.813 .556 .157 r
.7319 .48274 m .71765 .48275 L .70276 .48725 L F
0 0 0 r
.79966 .45785 m .77312 .47065 L .78452 .46468 L F
.81042 .45008 m .79966 .45785 L .78452 .46468 L F
1 1 .793 r
.42308 .48518 m .42396 .47293 L .40869 .48213 L F
.42308 .48518 m .43655 .47565 L .42396 .47293 L F
.368 .2 .06 r
.39272 .24467 m .40869 .24539 L .38586 .23955 L F
.39272 .24467 m .4144 .24969 L .40869 .24539 L F
.997 .751 .346 r
.3656 .48692 m .36646 .48005 L .35083 .4824 L F
.3656 .48692 m .37989 .48421 L .36646 .48005 L F
.448 .24 .065 r
.65465 .25 m .62481 .26272 L .64767 .25405 L F
.174 .075 .017 r
.2838 .46419 m .28109 .46369 L .26883 .45732 L F
.2838 .46419 m .29526 .47018 L .28109 .46369 L F
.238 .136 .042 r
.42129 .25376 m .43887 .25928 L .4144 .24969 L F
.42129 .25376 m .44427 .26249 L .43887 .25928 L F
.008 .003 .001 r
.61125 .26844 m .5876 .28266 L .58216 .28434 L F
.135 .047 .013 r
.45772 .26824 m .47667 .28066 L .45058 .26548 L F
.45772 .26824 m .48154 .28253 L .47667 .28066 L F
0 0 0 r
.84195 .42259 m .81972 .44106 L .82753 .43096 L F
.035 .022 .007 r
.84865 .41126 m .84195 .42259 L .82753 .43096 L F
1 1 .833 r
.54106 .46926 m .52892 .44828 L .52745 .46924 L F
.54106 .46926 m .53979 .44829 L .52892 .44828 L F
1 1 .812 r
.55461 .46891 m .53979 .44829 L .54106 .46926 L F
1 1 .854 r
.52745 .46924 m .51811 .44797 L .51391 .46887 L F
.52745 .46924 m .52892 .44828 L .51811 .44797 L F
1 1 .812 r
.55461 .46891 m .55061 .44801 L .53979 .44829 L F
1 1 .791 r
.56798 .46822 m .55061 .44801 L .55461 .46891 L F
.686 .37 .103 r
.71042 .23145 m .68321 .23994 L .70401 .23757 L F
1 1 .873 r
.51391 .46887 m .50745 .44738 L .50056 .46815 L F
.51391 .46887 m .51811 .44797 L .50745 .44738 L F
.412 .21 .067 r
.85285 .27982 m .83377 .27877 L .84299 .2903 L F
.476 .251 .052 r
.24083 .43036 m .23493 .43242 L .22661 .42195 L F
.24083 .43036 m .24868 .44048 L .23493 .43242 L F
1 1 .739 r
.61845 .47818 m .60581 .46407 L .5937 .46579 L F
1 1 .714 r
.632 .47584 m .60581 .46407 L .61845 .47818 L F
.534 .286 .085 r
.36498 .23712 m .38586 .23955 L .38047 .23419 L F
.85 .59 .181 r
.7463 .47746 m .71765 .48275 L .7319 .48274 L F
.727 .486 .111 r
.76038 .47498 m .7463 .47746 L .7319 .48274 L F
1 1 .899 r
.45003 .47802 m .45144 .46187 L .43655 .47565 L F
.45003 .47802 m .46284 .46393 L .45144 .46187 L F
.357 .182 .059 r
.86093 .29193 m .84299 .2903 L .85071 .30252 L F
.86093 .29193 m .85285 .27982 L .84299 .2903 L F
1 1 .791 r
.56798 .46822 m .56129 .44743 L .55061 .44801 L F
1 1 .769 r
.58105 .46717 m .56129 .44743 L .56798 .46822 L F
.72 .497 .152 r
.33649 .48236 m .33772 .47748 L .32223 .47705 L F
.33649 .48236 m .35083 .4824 L .33772 .47748 L F
1 1 .892 r
.50056 .46815 m .49705 .4465 L .48752 .46708 L F
.50056 .46815 m .50745 .44738 L .49705 .4465 L F
0 0 0 r
.79966 .45785 m .78745 .46419 L .77312 .47065 L F
.678 .456 .103 r
.78745 .46419 m .76038 .47498 L .77312 .47065 L F
1 .883 .403 r
.20919 .35952 m .20943 .37282 L .19719 .3628 L F
.303 .154 .05 r
.8674 .30464 m .85071 .30252 L .8569 .31528 L F
.8674 .30464 m .86093 .29193 L .85071 .30252 L F
1 .51 .133 r
.21795 .30175 m .2257 .28953 L .21606 .27902 L F
.271 .113 .031 r
.53449 .29007 m .53476 .33081 L .52712 .28994 L F
.53449 .29007 m .53476 .33081 L .53476 .33081 L F
.251 .104 .029 r
.54186 .28996 m .53476 .33081 L .53449 .29007 L F
.54186 .28996 m .53476 .33081 L .53476 .33081 L F
.227 .094 .027 r
.54915 .2896 m .53476 .33081 L .54186 .28996 L F
.287 .12 .033 r
.52712 .28994 m .53476 .33081 L .51983 .28957 L F
.52712 .28994 m .53476 .33081 L .53476 .33081 L F
.388 .274 .069 r
.29526 .47018 m .29479 .46844 L .28109 .46369 L F
.29526 .47018 m .30807 .47454 L .29479 .46844 L F
0 0 0 r
.83367 .43303 m .81042 .45008 L .81972 .44106 L F
.84195 .42259 m .83367 .43303 L .81972 .44106 L F
.227 .094 .027 r
.54915 .2896 m .53476 .33081 L .53476 .33081 L F
.2 .082 .024 r
.55631 .289 m .53476 .33081 L .54915 .2896 L F
.298 .124 .034 r
.51983 .28957 m .53476 .33081 L .51269 .28895 L F
.51983 .28957 m .53476 .33081 L .53476 .33081 L F
.117 .041 .011 r
.45058 .26548 m .47667 .28066 L .47238 .27863 L F
1 1 .662 r
.6598 .48237 m .64466 .47314 L .632 .47584 L F
1 1 .635 r
.67315 .47897 m .64466 .47314 L .6598 .48237 L F
1 .944 .539 r
.68858 .4845 m .67315 .47897 L .6598 .48237 L F
.139 .083 .026 r
.87153 .36356 m .85721 .38658 L .85906 .37354 L F
.205 .12 .037 r
.87179 .35009 m .87153 .36356 L .85906 .37354 L F
.98 .487 .126 r
.21174 .3145 m .21795 .30175 L .20796 .29112 L F
1 1 .769 r
.58105 .46717 m .57171 .44657 L .56129 .44743 L F
1 1 .746 r
.5937 .46579 m .57171 .44657 L .58105 .46717 L F
.247 .125 .041 r
.87223 .31779 m .8569 .31528 L .86152 .32842 L F
.87223 .31779 m .8674 .30464 L .8569 .31528 L F
1 .922 .52 r
.70212 .48037 m .67315 .47897 L .68858 .4845 L F
1 .767 .353 r
.71765 .48275 m .70212 .48037 L .68858 .4845 L F
1 1 .909 r
.48752 .46708 m .487 .44534 L .47491 .46567 L F
.48752 .46708 m .49705 .4465 L .487 .44534 L F
1 1 .777 r
.40869 .48213 m .41238 .46988 L .39543 .4787 L F
.40869 .48213 m .42396 .47293 L .41238 .46988 L F
.448 .24 .065 r
.65465 .25 m .63029 .25953 L .62481 .26272 L F
.493 .261 .071 r
.66045 .24571 m .63029 .25953 L .65465 .25 L F
.563 .301 .082 r
.68321 .23994 m .66045 .24571 L .65465 .25 L F
.357 .173 .037 r
.24868 .44048 m .24483 .44183 L .23493 .43242 L F
.24868 .44048 m .25802 .44953 L .24483 .44183 L F
.2 .082 .024 r
.55631 .289 m .53476 .33081 L .53476 .33081 L F
.171 .068 .02 r
.56326 .28817 m .53476 .33081 L .55631 .289 L F
.304 .126 .034 r
.51269 .28895 m .53476 .33081 L .50576 .2881 L F
.51269 .28895 m .53476 .33081 L .53476 .33081 L F
1 1 .575 r
.37989 .48421 m .38345 .47493 L .36646 .48005 L F
.37989 .48421 m .39543 .4787 L .38345 .47493 L F
.255 .146 .044 r
.4144 .24969 m .43442 .25589 L .40869 .24539 L F
.4144 .24969 m .43887 .25928 L .43442 .25589 L F
1 .716 .298 r
.20943 .37282 m .19915 .37608 L .19719 .3628 L F
.20943 .37282 m .21129 .38587 L .19915 .37608 L F
.622 .334 .091 r
.68871 .2346 m .66045 .24571 L .68321 .23994 L F
.98 .487 .126 r
.21174 .3145 m .20796 .29112 L .20147 .30383 L F
.929 .456 .117 r
.2071 .32764 m .21174 .3145 L .20147 .30383 L F
1 1 .714 r
.632 .47584 m .61726 .46204 L .60581 .46407 L F
1 1 .687 r
.64466 .47314 m .61726 .46204 L .632 .47584 L F
.41 .22 .066 r
.38586 .23955 m .40425 .24088 L .38047 .23419 L F
.38586 .23955 m .40869 .24539 L .40425 .24088 L F
.19 .095 .032 r
.87539 .33124 m .86152 .32842 L .86454 .34179 L F
.87539 .33124 m .87223 .31779 L .86152 .32842 L F
.171 .068 .02 r
.56326 .28817 m .53476 .33081 L .53476 .33081 L F
.141 .053 .016 r
.56993 .28711 m .53476 .33081 L .56326 .28817 L F
.302 .125 .033 r
.50576 .2881 m .53476 .33081 L .49912 .28702 L F
.50576 .2881 m .53476 .33081 L .53476 .33081 L F
1 1 .897 r
.43655 .47565 m .44081 .45952 L .42396 .47293 L F
.43655 .47565 m .45144 .46187 L .44081 .45952 L F
.088 .054 .018 r
.86958 .37682 m .85373 .3992 L .85721 .38658 L F
.139 .083 .026 r
.87153 .36356 m .86958 .37682 L .85721 .38658 L F
1 1 .746 r
.5937 .46579 m .58179 .44543 L .57171 .44657 L F
1 1 .721 r
.60581 .46407 m .58179 .44543 L .5937 .46579 L F
1 .773 .358 r
.73089 .47786 m .70212 .48037 L .71765 .48275 L F
.85 .59 .181 r
.7463 .47746 m .73089 .47786 L .71765 .48275 L F
1 1 .924 r
.47491 .46567 m .47741 .44391 L .46284 .46393 L F
.47491 .46567 m .487 .44534 L .47741 .44391 L F
.929 .456 .117 r
.2071 .32764 m .20147 .30383 L .19663 .31699 L F
.861 .416 .106 r
.20407 .34102 m .2071 .32764 L .19663 .31699 L F
.771 .512 .118 r
.77382 .46891 m .7463 .47746 L .76038 .47498 L F
.678 .456 .103 r
.78745 .46419 m .77382 .46891 L .76038 .47498 L F
0 0 0 r
.82381 .44242 m .79966 .45785 L .81042 .45008 L F
.83367 .43303 m .82381 .44242 L .81042 .45008 L F
1 .755 .351 r
.35083 .4824 m .35458 .47554 L .33772 .47748 L F
.35083 .4824 m .36646 .48005 L .35458 .47554 L F
.141 .053 .016 r
.56993 .28711 m .53476 .33081 L .53476 .33081 L F
.116 .043 .013 r
.57625 .28583 m .53476 .33081 L .56993 .28711 L F
.888 .541 .19 r
.21129 .38587 m .20281 .38899 L .19915 .37608 L F
.21129 .38587 m .21478 .39851 L .20281 .38899 L F
.29 .119 .031 r
.49912 .28702 m .53476 .33081 L .49282 .28572 L F
.49912 .28702 m .53476 .33081 L .53476 .33081 L F
.538 .373 .091 r
.30807 .47454 m .3099 .47136 L .29479 .46844 L F
.30807 .47454 m .32223 .47705 L .3099 .47136 L F
.162 .09 .029 r
.44427 .26249 m .4697 .27709 L .46873 .27646 L F
.194 .108 .035 r
.43887 .25928 m .46589 .27482 L .46575 .27417 L F
.46589 .27482 m .46873 .27646 L .46575 .27417 L F
.131 .045 .012 r
.46873 .27646 m .53476 .33081 L .46782 .27587 L F
.46873 .27646 m .46782 .27587 L .46575 .27417 L F
.162 .09 .029 r
.4697 .27709 m .47238 .27863 L .46873 .27646 L F
.166 .06 .016 r
.47238 .27863 m .53476 .33081 L .46873 .27646 L F
.131 .045 .012 r
.46873 .27646 m .53476 .33081 L .53476 .33081 L F
.152 .082 .028 r
.46575 .27417 m .53476 .33081 L .46562 .27356 L F
.46575 .27417 m .46562 .27356 L .46348 .27179 L F
.231 .099 .023 r
.25802 .44953 m .25628 .45001 L .24483 .44183 L F
.25802 .44953 m .26883 .45732 L .25628 .45001 L F
.861 .416 .106 r
.20407 .34102 m .19663 .31699 L .19346 .33044 L F
.043 .026 .009 r
.86593 .38972 m .84865 .41126 L .85373 .3992 L F
.088 .054 .018 r
.86958 .37682 m .86593 .38972 L .85373 .3992 L F
.116 .043 .013 r
.57625 .28583 m .53476 .33081 L .53476 .33081 L F
.085 .031 .009 r
.58216 .28434 m .53476 .33081 L .57625 .28583 L F
.269 .109 .028 r
.49282 .28572 m .53476 .33081 L .48694 .28422 L F
.49282 .28572 m .53476 .33081 L .53476 .33081 L F
1 1 .721 r
.60581 .46407 m .59142 .44402 L .58179 .44543 L F
1 1 .696 r
.61726 .46204 m .59142 .44402 L .60581 .46407 L F
1 1 .935 r
.46284 .46393 m .46835 .44222 L .45144 .46187 L F
.46284 .46393 m .47741 .44391 L .46835 .44222 L F
.682 .389 .103 r
.21478 .39851 m .20818 .40138 L .20281 .38899 L F
.21478 .39851 m .21989 .41059 L .20818 .40138 L F
1 1 .635 r
.67315 .47897 m .65632 .47012 L .64466 .47314 L F
1 .983 .605 r
.68523 .47523 m .65632 .47012 L .67315 .47897 L F
1 .922 .52 r
.70212 .48037 m .68523 .47523 L .67315 .47897 L F
.493 .261 .071 r
.66045 .24571 m .63481 .25615 L .63029 .25953 L F
.55 .292 .079 r
.66499 .24122 m .63481 .25615 L .66045 .24571 L F
.622 .334 .091 r
.68871 .2346 m .66499 .24122 L .66045 .24571 L F
1 1 .687 r
.64466 .47314 m .62795 .4597 L .61726 .46204 L F
1 1 .658 r
.65632 .47012 m .62795 .4597 L .64466 .47314 L F
1 1 .755 r
.39543 .4787 m .40195 .46652 L .38345 .47493 L F
.39543 .4787 m .41238 .46988 L .40195 .46652 L F
0 0 0 r
.82381 .44242 m .8124 .45057 L .79966 .45785 L F
.655 .439 .097 r
.8124 .45057 m .78745 .46419 L .79966 .45785 L F
.294 .164 .05 r
.40869 .24539 m .43099 .25235 L .40425 .24088 L F
.40869 .24539 m .43442 .25589 L .43099 .25235 L F
1 1 .805 r
.53979 .44829 m .53074 .41693 L .52892 .44828 L F
.53979 .44829 m .53823 .41694 L .53074 .41693 L F
1 1 .781 r
.55061 .44801 m .53823 .41694 L .53979 .44829 L F
1 1 .829 r
.52892 .44828 m .52328 .41671 L .51811 .44797 L F
.52892 .44828 m .53074 .41693 L .52328 .41671 L F
1 1 .888 r
.42396 .47293 m .43107 .45688 L .41238 .46988 L F
.42396 .47293 m .44081 .45952 L .43107 .45688 L F
.085 .031 .009 r
.58216 .28434 m .53476 .33081 L .53476 .33081 L F
.051 .018 .005 r
.5876 .28266 m .53476 .33081 L .58216 .28434 L F
.89 .628 .21 r
.75878 .4718 m .73089 .47786 L .7463 .47746 L F
.771 .512 .118 r
.77382 .46891 m .75878 .4718 L .7463 .47746 L F
1 1 .781 r
.55061 .44801 m .54569 .41674 L .53823 .41694 L F
1 1 .757 r
.56129 .44743 m .54569 .41674 L .55061 .44801 L F
.242 .097 .025 r
.48694 .28422 m .53476 .33081 L .48154 .28253 L F
.48694 .28422 m .53476 .33081 L .53476 .33081 L F
1 1 .852 r
.51811 .44797 m .51593 .41629 L .50745 .44738 L F
.51811 .44797 m .52328 .41671 L .51593 .41629 L F
.309 .213 .056 r
.26883 .45732 m .26925 .45679 L .25628 .45001 L F
.26883 .45732 m .28109 .46369 L .26925 .45679 L F
0 0 0 r
.86058 .40208 m .84195 .42259 L .84865 .41126 L F
.043 .026 .009 r
.86593 .38972 m .86058 .40208 L .84865 .41126 L F
1 .898 .5 r
.71412 .47588 m .68523 .47523 L .70212 .48037 L F
1 .773 .358 r
.73089 .47786 m .71412 .47588 L .70212 .48037 L F
.749 .523 .175 r
.32223 .47705 m .32642 .47221 L .3099 .47136 L F
.32223 .47705 m .33772 .47748 L .32642 .47221 L F
1 1 .757 r
.56129 .44743 m .55305 .41632 L .54569 .41674 L F
1 1 .733 r
.57171 .44657 m .55305 .41632 L .56129 .44743 L F
1 1 .556 r
.36646 .48005 m .37288 .47085 L .35458 .47554 L F
.36646 .48005 m .38345 .47493 L .37288 .47085 L F
.194 .108 .035 r
.43887 .25928 m .46575 .27417 L .43442 .25589 L F
1 1 .876 r
.50745 .44738 m .50877 .41565 L .49705 .4465 L F
.50745 .44738 m .51593 .41629 L .50877 .41565 L F
.518 .279 .056 r
.21989 .41059 m .21524 .41308 L .20818 .40138 L F
.21989 .41059 m .22661 .42195 L .21524 .41308 L F
.455 .243 .073 r
.38047 .23419 m .40114 .23622 L .37664 .22863 L F
.38047 .23419 m .40425 .24088 L .40114 .23622 L F
1 1 .696 r
.61726 .46204 m .60052 .44235 L .59142 .44402 L F
1 1 .668 r
.62795 .4597 m .60052 .44235 L .61726 .46204 L F
1 1 .943 r
.45144 .46187 m .45994 .44029 L .44081 .45952 L F
.45144 .46187 m .46835 .44222 L .45994 .44029 L F
.051 .018 .005 r
.5876 .28266 m .53476 .33081 L .53476 .33081 L F
.02 .007 .002 r
.59251 .2808 m .53476 .33081 L .5876 .28266 L F
.22 .087 .022 r
.48154 .28253 m .53476 .33081 L .47667 .28066 L F
.48154 .28253 m .53476 .33081 L .53476 .33081 L F
1 1 .733 r
.57171 .44657 m .56023 .4157 L .55305 .41632 L F
1 1 .708 r
.58179 .44543 m .56023 .4157 L .57171 .44657 L F
1 1 .898 r
.49705 .4465 m .50186 .41482 L .487 .44534 L F
.49705 .4465 m .50877 .41565 L .50186 .41482 L F
.754 .5 .113 r
.79948 .45732 m .77382 .46891 L .78745 .46419 L F
.655 .439 .097 r
.8124 .45057 m .79948 .45732 L .78745 .46419 L F
0 0 0 r
.85355 .41375 m .83367 .43303 L .84195 .42259 L F
.86058 .40208 m .85355 .41375 L .84195 .42259 L F
.693 .37 .108 r
.77765 .21997 m .75911 .21726 L .75531 .22527 L F
.421 .298 .075 r
.28109 .46369 m .28373 .46196 L .26925 .45679 L F
.28109 .46369 m .29479 .46844 L .28373 .46196 L F
.411 .21 .043 r
.22661 .42195 m .22397 .42391 L .21524 .41308 L F
.22661 .42195 m .23493 .43242 L .22397 .42391 L F
1 .778 .363 r
.74233 .47261 m .71412 .47588 L .73089 .47786 L F
.89 .628 .21 r
.75878 .4718 m .74233 .47261 L .73089 .47786 L F
1 1 .708 r
.58179 .44543 m .56716 .41488 L .56023 .4157 L F
1 1 .683 r
.59142 .44402 m .56716 .41488 L .58179 .44543 L F
1 1 .919 r
.487 .44534 m .49528 .41379 L .47741 .44391 L F
.487 .44534 m .50186 .41482 L .49528 .41379 L F
1 1 .658 r
.65632 .47012 m .63776 .45709 L .62795 .4597 L F
1 .978 .625 r
.66684 .46678 m .63776 .45709 L .65632 .47012 L F
1 .983 .605 r
.68523 .47523 m .66684 .46678 L .65632 .47012 L F
.02 .007 .002 r
.59251 .2808 m .53476 .33081 L .53476 .33081 L F
0 0 0 r
.59684 .27878 m .53476 .33081 L .59251 .2808 L F
1 .76 .355 r
.33772 .47748 m .34438 .4707 L .32642 .47221 L F
.33772 .47748 m .35458 .47554 L .34438 .4707 L F
.55 .292 .079 r
.66499 .24122 m .63832 .25262 L .63481 .25615 L F
.627 .335 .09 r
.6682 .23657 m .63832 .25262 L .66499 .24122 L F
.199 .076 .02 r
.47667 .28066 m .53476 .33081 L .47238 .27863 L F
.47667 .28066 m .53476 .33081 L .53476 .33081 L F
1 1 .871 r
.41238 .46988 m .42232 .45399 L .40195 .46652 L F
.41238 .46988 m .43107 .45688 L .42232 .45399 L F
.498 .261 .07 r
.63832 .25262 m .60358 .27435 L .63481 .25615 L F
.346 .187 .057 r
.40425 .24088 m .42863 .24869 L .40114 .23622 L F
.40425 .24088 m .43099 .25235 L .42863 .24869 L F
1 .944 .572 r
.69591 .47116 m .66684 .46678 L .68523 .47523 L F
1 .898 .5 r
.71412 .47588 m .69591 .47116 L .68523 .47523 L F
.221 .124 .039 r
.43442 .25589 m .46348 .27179 L .43099 .25235 L F
.43442 .25589 m .46575 .27417 L .46348 .27179 L F
0 0 0 r
.84484 .42456 m .82381 .44242 L .83367 .43303 L F
.85355 .41375 m .84484 .42456 L .83367 .43303 L F
1 1 .668 r
.62795 .4597 m .60898 .44044 L .60052 .44235 L F
1 .978 .638 r
.63776 .45709 m .60898 .44044 L .62795 .4597 L F
1 1 .726 r
.38345 .47493 m .39278 .46289 L .37288 .47085 L F
.38345 .47493 m .40195 .46652 L .39278 .46289 L F
1 1 .943 r
.44081 .45952 m .45225 .43813 L .43107 .45688 L F
.44081 .45952 m .45994 .44029 L .45225 .43813 L F
.824 .552 .137 r
.78506 .46245 m .75878 .4718 L .77382 .46891 L F
.754 .5 .113 r
.79948 .45732 m .78506 .46245 L .77382 .46891 L F
1 1 .683 r
.59142 .44402 m .57377 .41387 L .56716 .41488 L F
1 1 .656 r
.60052 .44235 m .57377 .41387 L .59142 .44402 L F
.277 .125 .028 r
.23493 .43242 m .23434 .43372 L .22397 .42391 L F
.23493 .43242 m .24483 .44183 L .23434 .43372 L F
1 1 .938 r
.47741 .44391 m .48908 .41258 L .46835 .44222 L F
.47741 .44391 m .49528 .41379 L .48908 .41258 L F
1 .669 .242 r
.19693 .34932 m .19719 .3628 L .18816 .35232 L F
.576 .395 .1 r
.29479 .46844 m .29968 .46532 L .28373 .46196 L F
.29479 .46844 m .3099 .47136 L .29968 .46532 L F
0 0 0 r
.59684 .27878 m .53476 .33081 L .53476 .33081 L F
.166 .06 .016 r
.47238 .27863 m .53476 .33081 L .53476 .33081 L F
.091 .056 .018 r
.88081 .35312 m .86958 .37682 L .87153 .36356 L F
.13 .08 .026 r
.88108 .33946 m .88081 .35312 L .87153 .36356 L F
.169 .088 .03 r
.87966 .30674 m .8674 .30464 L .87223 .31779 L F
1 .873 .479 r
.72445 .47107 m .69591 .47116 L .71412 .47588 L F
1 .778 .363 r
.74233 .47261 m .72445 .47107 L .71412 .47588 L F
.5 .266 .08 r
.37664 .22863 m .40114 .23622 L .39941 .23144 L F
0 0 0 r
.84484 .42456 m .8345 .43434 L .82381 .44242 L F
.667 .442 .096 r
.8345 .43434 m .8124 .45057 L .82381 .44242 L F
1 .99 .535 r
.35458 .47554 m .36384 .46648 L .34438 .4707 L F
.35458 .47554 m .37288 .47085 L .36384 .46648 L F
.841 .507 .146 r
.19719 .3628 m .1902 .36584 L .18816 .35232 L F
.19719 .3628 m .19915 .37608 L .1902 .36584 L F
1 1 .656 r
.60052 .44235 m .58 .41267 L .57377 .41387 L F
1 .96 .628 r
.60898 .44044 m .58 .41267 L .60052 .44235 L F
.249 .166 .047 r
.24483 .44183 m .24634 .44232 L .23434 .43372 L F
.24483 .44183 m .25628 .45001 L .24634 .44232 L F
1 1 .953 r
.46835 .44222 m .48334 .41119 L .45994 .44029 L F
.46835 .44222 m .48908 .41258 L .48334 .41119 L F
.115 .059 .022 r
.88294 .32027 m .87223 .31779 L .87539 .33124 L F
.88294 .32027 m .87966 .30674 L .87223 .31779 L F
.498 .261 .07 r
.63832 .25262 m .6059 .27197 L .60358 .27435 L F
.565 .298 .079 r
.64076 .24897 m .6059 .27197 L .63832 .25262 L F
.627 .335 .09 r
.6682 .23657 m .64076 .24897 L .63832 .25262 L F
.933 .67 .244 r
.76916 .46578 m .74233 .47261 L .75878 .4718 L F
.824 .552 .137 r
.78506 .46245 m .76916 .46578 L .75878 .4718 L F
.044 .027 .009 r
.87878 .36662 m .86593 .38972 L .86958 .37682 L F
.091 .056 .018 r
.88081 .35312 m .87878 .36662 L .86958 .37682 L F
.245 .138 .043 r
.43099 .25235 m .46195 .26934 L .42863 .24869 L F
.43099 .25235 m .46348 .27179 L .46195 .26934 L F
1 .978 .625 r
.66684 .46678 m .64659 .45421 L .63776 .45709 L F
1 .933 .588 r
.67611 .46317 m .64659 .45421 L .66684 .46678 L F
1 .944 .572 r
.69591 .47116 m .67611 .46317 L .66684 .46678 L F
1 .978 .638 r
.63776 .45709 m .61673 .4383 L .60898 .44044 L F
1 .934 .605 r
.64659 .45421 m .61673 .4383 L .63776 .45709 L F
.783 .554 .202 r
.3099 .47136 m .31709 .46662 L .29968 .46532 L F
.3099 .47136 m .32642 .47221 L .31709 .46662 L F
1 1 .935 r
.43107 .45688 m .44536 .43577 L .42232 .45399 L F
.43107 .45688 m .45225 .43813 L .44536 .43577 L F
1 1 .843 r
.40195 .46652 m .41466 .45086 L .39278 .46289 L F
.40195 .46652 m .42232 .45399 L .41466 .45086 L F
.717 .384 .103 r
.67004 .2318 m .64076 .24897 L .6682 .23657 L F
.717 .35 .089 r
.19346 .33044 m .19663 .31699 L .18945 .3059 L F
1 1 .761 r
.53823 .41694 m .53476 .33081 L .53074 .41693 L F
.53823 .41694 m .53476 .33081 L .53476 .33081 L F
1 1 .735 r
.54569 .41674 m .53476 .33081 L .53823 .41694 L F
1 1 .788 r
.53074 .41693 m .53476 .33081 L .52328 .41671 L F
.53074 .41693 m .53476 .33081 L .53476 .33081 L F
.67 .383 .083 r
.19915 .37608 m .19401 .37904 L .1902 .36584 L F
.19915 .37608 m .20281 .38899 L .19401 .37904 L F
.403 .215 .066 r
.40114 .23622 m .42737 .24496 L .39941 .23144 L F
.40114 .23622 m .42863 .24869 L .42737 .24496 L F
1 1 .735 r
.54569 .41674 m .53476 .33081 L .53476 .33081 L F
1 1 .709 r
.55305 .41632 m .53476 .33081 L .54569 .41674 L F
1 1 .814 r
.52328 .41671 m .53476 .33081 L .51593 .41629 L F
.52328 .41671 m .53476 .33081 L .53476 .33081 L F
.762 .501 .112 r
.82254 .4429 m .79948 .45732 L .8124 .45057 L F
.667 .442 .096 r
.8345 .43434 m .82254 .4429 L .8124 .45057 L F
1 1 .709 r
.55305 .41632 m .53476 .33081 L .53476 .33081 L F
1 1 .683 r
.56023 .4157 m .53476 .33081 L .55305 .41632 L F
1 1 .841 r
.51593 .41629 m .53476 .33081 L .50877 .41565 L F
.51593 .41629 m .53476 .33081 L .53476 .33081 L F
0 0 0 r
.87497 .37979 m .86058 .40208 L .86593 .38972 L F
.044 .027 .009 r
.87878 .36662 m .87497 .37979 L .86593 .38972 L F
1 .903 .536 r
.70507 .46681 m .67611 .46317 L .69591 .47116 L F
1 .873 .479 r
.72445 .47107 m .70507 .46681 L .69591 .47116 L F
.36 .25 .065 r
.25628 .45001 m .25992 .44953 L .24634 .44232 L F
.25628 .45001 m .26925 .45679 L .25992 .44953 L F
1 .96 .628 r
.60898 .44044 m .58578 .4113 L .58 .41267 L F
1 .917 .597 r
.61673 .4383 m .58578 .4113 L .60898 .44044 L F
.717 .35 .089 r
.19346 .33044 m .18945 .3059 L .18617 .31943 L F
1 1 .962 r
.45994 .44029 m .47811 .40965 L .45225 .43813 L F
.45994 .44029 m .48334 .41119 L .47811 .40965 L F
1 1 .689 r
.37288 .47085 m .38498 .45902 L .36384 .46648 L F
.37288 .47085 m .39278 .46289 L .38498 .45902 L F
1 1 .683 r
.56023 .4157 m .53476 .33081 L .53476 .33081 L F
1 1 .656 r
.56716 .41488 m .53476 .33081 L .56023 .4157 L F
1 1 .867 r
.50877 .41565 m .53476 .33081 L .50186 .41482 L F
.50877 .41565 m .53476 .33081 L .53476 .33081 L F
1 .784 .368 r
.75181 .46705 m .72445 .47107 L .74233 .47261 L F
.933 .67 .244 r
.76916 .46578 m .75181 .46705 L .74233 .47261 L F
0 0 0 r
.60358 .27435 m .53476 .33081 L .53476 .33081 L F
.678 .362 .106 r
.77944 .21115 m .75911 .21726 L .77765 .21997 L F
.77944 .21115 m .7606 .20909 L .75911 .21726 L F
.54 .298 .059 r
.20281 .38899 m .19959 .39175 L .19401 .37904 L F
.20281 .38899 m .20818 .40138 L .19959 .39175 L F
.624 .331 .099 r
.79694 .21515 m .77765 .21997 L .79485 .22456 L F
.79694 .21515 m .77944 .21115 L .77765 .21997 L F
.152 .082 .028 r
.46575 .27417 m .53476 .33081 L .53476 .33081 L F
.563 .297 .09 r
.81309 .22089 m .79485 .22456 L .8107 .23081 L F
.81309 .22089 m .79694 .21515 L .79485 .22456 L F
1 .765 .36 r
.32642 .47221 m .336 .46559 L .31709 .46662 L F
.32642 .47221 m .34438 .4707 L .336 .46559 L F
.744 .399 .114 r
.31022 .21666 m .32911 .20868 L .30891 .20848 L F
.797 .427 .12 r
.29165 .21932 m .31022 .21666 L .30891 .20848 L F
.768 .412 .117 r
.74041 .20924 m .71882 .21191 L .71791 .21856 L F
1 1 .656 r
.56716 .41488 m .53476 .33081 L .53476 .33081 L F
1 .971 .629 r
.57377 .41387 m .53476 .33081 L .56716 .41488 L F
.797 .427 .12 r
.29165 .21932 m .30891 .20848 L .29006 .21048 L F
.841 .449 .124 r
.27442 .22387 m .29165 .21932 L .29006 .21048 L F
1 1 .893 r
.50186 .41482 m .53476 .33081 L .49528 .41379 L F
.50186 .41482 m .53476 .33081 L .53476 .33081 L F
.565 .298 .079 r
.64076 .24897 m .60748 .26952 L .6059 .27197 L F
.665 .353 .093 r
.6421 .24524 m .60748 .26952 L .64076 .24897 L F
.717 .384 .103 r
.67004 .2318 m .6421 .24524 L .64076 .24897 L F
.821 .54 .124 r
.809 .45008 m .78506 .46245 L .79948 .45732 L F
.762 .501 .112 r
.82254 .4429 m .809 .45008 L .79948 .45732 L F
.497 .261 .081 r
.82783 .22819 m .8107 .23081 L .82514 .23854 L F
.82783 .22819 m .81309 .22089 L .8107 .23081 L F
0 0 0 r
.86941 .39248 m .85355 .41375 L .86058 .40208 L F
.87497 .37979 m .86941 .39248 L .86058 .40208 L F
.841 .449 .124 r
.27442 .22387 m .29006 .21048 L .27254 .21444 L F
.872 .464 .127 r
.25855 .23008 m .27442 .22387 L .27254 .21444 L F
.309 .168 .053 r
.42863 .24869 m .46119 .26684 L .42737 .24496 L F
.42863 .24869 m .46195 .26934 L .46119 .26684 L F
1 .934 .605 r
.64659 .45421 m .62368 .43595 L .61673 .4383 L F
1 .886 .567 r
.65434 .4511 m .62368 .43595 L .64659 .45421 L F
1 .933 .588 r
.67611 .46317 m .65434 .4511 L .64659 .45421 L F
.458 .323 .081 r
.26925 .45679 m .27506 .45515 L .25992 .44953 L F
.26925 .45679 m .28373 .46196 L .27506 .45515 L F
1 1 .914 r
.42232 .45399 m .43935 .43322 L .41466 .45086 L F
.42232 .45399 m .44536 .43577 L .43935 .43322 L F
.872 .464 .127 r
.25855 .23008 m .27254 .21444 L .25638 .22015 L F
.888 .47 .126 r
.24408 .23778 m .25855 .23008 L .25638 .22015 L F
.428 .224 .071 r
.84111 .23686 m .82783 .22819 L .82514 .23854 L F
.437 .231 .047 r
.20818 .40138 m .20693 .40381 L .19959 .39175 L F
.20818 .40138 m .21524 .41308 L .20693 .40381 L F
1 .971 .629 r
.57377 .41387 m .53476 .33081 L .53476 .33081 L F
1 .928 .6 r
.58 .41267 m .53476 .33081 L .57377 .41387 L F
1 1 .917 r
.49528 .41379 m .53476 .33081 L .48908 .41258 L F
.49528 .41379 m .53476 .33081 L .53476 .33081 L F
1 .917 .597 r
.61673 .4383 m .59105 .40977 L .58578 .4113 L F
1 .87 .563 r
.62368 .43595 m .59105 .40977 L .61673 .4383 L F
1 1 .962 r
.45225 .43813 m .47344 .40796 L .44536 .43577 L F
.45225 .43813 m .47811 .40965 L .47344 .40796 L F
1 .883 .546 r
.68402 .45932 m .65434 .4511 L .67611 .46317 L F
1 .903 .536 r
.70507 .46681 m .68402 .45932 L .67611 .46317 L F
.443 .233 .061 r
.6059 .27197 m .53476 .33081 L .53476 .33081 L F
.514 .267 .071 r
.60748 .26952 m .53476 .33081 L .6059 .27197 L F
.888 .47 .126 r
.24408 .23778 m .25638 .22015 L .24162 .22741 L F
.888 .467 .124 r
.23105 .24679 m .24408 .23778 L .24162 .22741 L F
1 .848 .456 r
.73297 .46598 m .70507 .46681 L .72445 .47107 L F
1 .784 .368 r
.75181 .46705 m .73297 .46598 L .72445 .47107 L F
.188 .103 .034 r
.46348 .27179 m .53476 .33081 L .46195 .26934 L F
.46348 .27179 m .53476 .33081 L .53476 .33081 L F
.359 .188 .06 r
.85288 .24675 m .84111 .23686 L .83815 .24758 L F
.806 .43 .116 r
.67045 .22697 m .6421 .24524 L .67004 .2318 L F
1 1 .803 r
.39278 .46289 m .40817 .44753 L .38498 .45902 L F
.39278 .46289 m .41466 .45086 L .40817 .44753 L F
0 0 0 r
.86209 .40451 m .84484 .42456 L .85355 .41375 L F
.86941 .39248 m .86209 .40451 L .85355 .41375 L F
1 .965 .511 r
.34438 .4707 m .35646 .46186 L .336 .46559 L F
.34438 .4707 m .36384 .46648 L .35646 .46186 L F
.461 .244 .075 r
.39941 .23144 m .42724 .24118 L .3991 .22661 L F
.39941 .23144 m .42737 .24496 L .42724 .24118 L F
.892 .615 .18 r
.79391 .45567 m .76916 .46578 L .78506 .46245 L F
.821 .54 .124 r
.809 .45008 m .79391 .45567 L .78506 .46245 L F
.888 .467 .124 r
.23105 .24679 m .24162 .22741 L .22832 .23605 L F
1 .928 .6 r
.58 .41267 m .53476 .33081 L .53476 .33081 L F
1 .884 .57 r
.58578 .4113 m .53476 .33081 L .58 .41267 L F
1 1 .939 r
.48908 .41258 m .53476 .33081 L .48334 .41119 L F
.48908 .41258 m .53476 .33081 L .53476 .33081 L F
.29 .153 .05 r
.86306 .25771 m .85288 .24675 L .84965 .25776 L F
.625 .43 .125 r
.28373 .46196 m .29171 .45898 L .27506 .45515 L F
.28373 .46196 m .29968 .46532 L .29171 .45898 L F
.313 .151 .032 r
.21524 .41308 m .216 .41504 L .20693 .40381 L F
.21524 .41308 m .22397 .42391 L .216 .41504 L F
.665 .353 .093 r
.6421 .24524 m .60831 .26702 L .60748 .26952 L F
.783 .415 .11 r
.64231 .24146 m .60831 .26702 L .6421 .24524 L F
.806 .43 .116 r
.67045 .22697 m .64231 .24146 L .6421 .24524 L F
0 0 0 r
.86209 .40451 m .85304 .41571 L .84484 .42456 L F
.715 .465 .1 r
.85304 .41571 m .8345 .43434 L .84484 .42456 L F
.377 .2 .063 r
.42737 .24496 m .4612 .26432 L .42724 .24118 L F
.42737 .24496 m .46119 .26684 L .4612 .26432 L F
.514 .267 .071 r
.60748 .26952 m .53476 .33081 L .53476 .33081 L F
.598 .314 .082 r
.60831 .26702 m .53476 .33081 L .60748 .26952 L F
1 .859 .497 r
.71258 .46221 m .68402 .45932 L .70507 .46681 L F
1 .848 .456 r
.73297 .46598 m .71258 .46221 L .70507 .46681 L F
.219 .122 .039 r
.46195 .26934 m .53476 .33081 L .46119 .26684 L F
.46195 .26934 m .53476 .33081 L .53476 .33081 L F
1 .87 .563 r
.62368 .43595 m .59576 .40809 L .59105 .40977 L F
1 .82 .525 r
.62976 .43341 m .59576 .40809 L .62368 .43595 L F
1 .886 .567 r
.65434 .4511 m .62976 .43341 L .62368 .43595 L F
1 .884 .57 r
.58578 .4113 m .53476 .33081 L .53476 .33081 L F
1 .838 .538 r
.59105 .40977 m .53476 .33081 L .58578 .4113 L F
.978 .716 .281 r
.7773 .45946 m .75181 .46705 L .76916 .46578 L F
.892 .615 .18 r
.79391 .45567 m .7773 .45946 L .76916 .46578 L F
1 1 .955 r
.48334 .41119 m .53476 .33081 L .47811 .40965 L F
.48334 .41119 m .53476 .33081 L .53476 .33081 L F
1 1 .948 r
.44536 .43577 m .4694 .40615 L .43935 .43322 L F
.44536 .43577 m .47344 .40796 L .4694 .40615 L F
1 .833 .524 r
.66092 .44778 m .62976 .43341 L .65434 .4511 L F
1 .883 .546 r
.68402 .45932 m .66092 .44778 L .65434 .4511 L F
1 1 .645 r
.36384 .46648 m .37864 .45493 L .35646 .46186 L F
.36384 .46648 m .38498 .45902 L .37864 .45493 L F
.209 .134 .04 r
.22397 .42391 m .22677 .42526 L .216 .41504 L F
.22397 .42391 m .23434 .43372 L .22677 .42526 L F
1 1 .876 r
.41466 .45086 m .4343 .4305 L .40817 .44753 L F
.41466 .45086 m .43935 .43322 L .4343 .4305 L F
.832 .43 .111 r
.20954 .26809 m .21654 .24592 L .20634 .25686 L F
.82 .589 .233 r
.29968 .46532 m .30988 .46077 L .29171 .45898 L F
.29968 .46532 m .31709 .46662 L .30988 .46077 L F
.798 .518 .114 r
.8423 .4259 m .82254 .4429 L .8345 .43434 L F
.715 .465 .1 r
.85304 .41571 m .8423 .4259 L .8345 .43434 L F
.771 .456 .098 r
.18789 .33865 m .18816 .35232 L .18257 .34147 L F
1 .838 .538 r
.59105 .40977 m .53476 .33081 L .53476 .33081 L F
1 .789 .503 r
.59576 .40809 m .53476 .33081 L .59105 .40977 L F
.78 .418 .118 r
.73941 .20173 m .71882 .21191 L .74041 .20924 L F
.73941 .20173 m .71777 .20521 L .71882 .21191 L F
1 1 .962 r
.47811 .40965 m .53476 .33081 L .47344 .40796 L F
.47811 .40965 m .53476 .33081 L .53476 .33081 L F
.725 .388 .112 r
.75968 .20083 m .74041 .20924 L .7606 .20909 L F
.75968 .20083 m .73941 .20173 L .74041 .20924 L F
1 .79 .373 r
.75918 .46121 m .73297 .46598 L .75181 .46705 L F
.978 .716 .281 r
.7773 .45946 m .75918 .46121 L .75181 .46705 L F
.883 .468 .126 r
.66942 .22212 m .64231 .24146 L .67045 .22697 L F
.315 .214 .058 r
.23434 .43372 m .23921 .4343 L .22677 .42526 L F
.23434 .43372 m .24634 .44232 L .23921 .4343 L F
1 .83 .5 r
.69047 .45524 m .66092 .44778 L .68402 .45932 L F
1 .859 .497 r
.71258 .46221 m .69047 .45524 L .68402 .45932 L F
.598 .314 .082 r
.60831 .26702 m .53476 .33081 L .53476 .33081 L F
.734 .386 .101 r
.60835 .26451 m .53476 .33081 L .60831 .26702 L F
.783 .415 .11 r
.64231 .24146 m .60835 .26451 L .60831 .26702 L F
.286 .154 .049 r
.46119 .26684 m .53476 .33081 L .4612 .26432 L F
.46119 .26684 m .53476 .33081 L .53476 .33081 L F
.04 .025 .008 r
.88666 .34229 m .87878 .36662 L .88081 .35312 L F
.09 .055 .018 r
.88694 .32844 m .88666 .34229 L .88081 .35312 L F
.513 .27 .083 r
.3991 .22661 m .42724 .24118 L .42827 .23741 L F
1 1 .748 r
.38498 .45902 m .40293 .44402 L .37864 .45493 L F
.38498 .45902 m .40817 .44753 L .40293 .44402 L F
.694 .371 .108 r
.32911 .20868 m .35192 .20472 L .33028 .20117 L F
.741 .397 .114 r
.30891 .20848 m .32911 .20868 L .33028 .20117 L F
.664 .355 .104 r
.77862 .20221 m .7606 .20909 L .77944 .21115 L F
.77862 .20221 m .75968 .20083 L .7606 .20909 L F
1 .77 .365 r
.31709 .46662 m .32957 .46024 L .30988 .46077 L F
.31709 .46662 m .336 .46559 L .32957 .46024 L F
.887 .467 .124 r
.64138 .23769 m .60835 .26451 L .64231 .24146 L F
1 .82 .525 r
.62976 .43341 m .59985 .40628 L .59576 .40809 L F
.988 .765 .482 r
.63488 .43071 m .59985 .40628 L .62976 .43341 L F
1 .833 .524 r
.66092 .44778 m .63488 .43071 L .62976 .43341 L F
.741 .397 .114 r
.30891 .20848 m .33028 .20117 L .31002 .20022 L F
.779 .418 .118 r
.29006 .21048 m .30891 .20848 L .31002 .20022 L F
.851 .555 .126 r
.82988 .43491 m .809 .45008 L .82254 .4429 L F
.798 .518 .114 r
.8423 .4259 m .82988 .43491 L .82254 .4429 L F
.653 .378 .076 r
.18816 .35232 m .18467 .35524 L .18257 .34147 L F
.18816 .35232 m .1902 .36584 L .18467 .35524 L F
1 1 .916 r
.43935 .43322 m .46602 .40422 L .4343 .4305 L F
.43935 .43322 m .4694 .40615 L .46602 .40422 L F
.441 .231 .073 r
.42724 .24118 m .462 .26181 L .42827 .23741 L F
.42724 .24118 m .4612 .26432 L .462 .26181 L F
.598 .318 .095 r
.79625 .20561 m .77944 .21115 L .79694 .21515 L F
.79625 .20561 m .77862 .20221 L .77944 .21115 L F
1 .789 .503 r
.59576 .40809 m .53476 .33081 L .53476 .33081 L F
.963 .735 .464 r
.59985 .40628 m .53476 .33081 L .59576 .40809 L F
1 1 .956 r
.47344 .40796 m .53476 .33081 L .4694 .40615 L F
.47344 .40796 m .53476 .33081 L .53476 .33081 L F
.403 .282 .073 r
.24634 .44232 m .25328 .44197 L .23921 .4343 L F
.24634 .44232 m .25992 .44953 L .25328 .44197 L F
.779 .418 .118 r
.29006 .21048 m .31002 .20022 L .29107 .20155 L F
.804 .431 .119 r
.27254 .21444 m .29006 .21048 L .29107 .20155 L F
1 .821 .432 r
.73955 .46065 m .71258 .46221 L .73297 .46598 L F
1 .79 .373 r
.75918 .46121 m .73955 .46065 L .73297 .46598 L F
0 0 0 r
.88456 .35604 m .87497 .37979 L .87878 .36662 L F
.04 .025 .008 r
.88666 .34229 m .88456 .35604 L .87878 .36662 L F
.525 .278 .085 r
.81253 .21083 m .79694 .21515 L .81309 .22089 L F
.81253 .21083 m .79625 .20561 L .79694 .21515 L F
.996 .774 .475 r
.66625 .44428 m .63488 .43071 L .66092 .44778 L F
1 .83 .5 r
.69047 .45524 m .66625 .44428 L .66092 .44778 L F
1 .938 .486 r
.336 .46559 m .35084 .45704 L .32957 .46024 L F
.336 .46559 m .35646 .46186 L .35084 .45704 L F
1 1 .817 r
.40817 .44753 m .43026 .42765 L .40293 .44402 L F
.40817 .44753 m .4343 .4305 L .43026 .42765 L F
.734 .386 .101 r
.60835 .26451 m .53476 .33081 L .53476 .33081 L F
.871 .455 .119 r
.60762 .26199 m .53476 .33081 L .60835 .26451 L F
.887 .467 .124 r
.64138 .23769 m .60762 .26199 L .60835 .26451 L F
.535 .301 .059 r
.1902 .36584 m .1886 .36874 L .18467 .35524 L F
.1902 .36584 m .19401 .37904 L .1886 .36874 L F
.36 .189 .06 r
.4612 .26432 m .53476 .33081 L .462 .26181 L F
.4612 .26432 m .53476 .33081 L .53476 .33081 L F
.804 .431 .119 r
.27254 .21444 m .29107 .20155 L .27344 .2049 L F
.814 .435 .119 r
.25638 .22015 m .27254 .21444 L .27344 .2049 L F
.906 .614 .164 r
.81584 .44254 m .79391 .45567 L .809 .45008 L F
.851 .555 .126 r
.82988 .43491 m .81584 .44254 L .809 .45008 L F
.447 .236 .073 r
.82741 .21767 m .81309 .22089 L .82783 .22819 L F
.82741 .21767 m .81253 .21083 L .81309 .22089 L F
0 0 0 r
.88065 .36952 m .86941 .39248 L .87497 .37979 L F
.88456 .35604 m .88065 .36952 L .87497 .37979 L F
.524 .363 .099 r
.25992 .44953 m .26894 .44807 L .25328 .44197 L F
.25992 .44953 m .27506 .45515 L .26894 .44807 L F
1 .811 .455 r
.71833 .4574 m .69047 .45524 L .71258 .46221 L F
1 .821 .432 r
.73955 .46065 m .71833 .4574 L .71258 .46221 L F
.963 .735 .464 r
.59985 .40628 m .53476 .33081 L .53476 .33081 L F
.898 .678 .422 r
.60328 .40436 m .53476 .33081 L .59985 .40628 L F
.988 .765 .482 r
.63488 .43071 m .60328 .40436 L .59985 .40628 L F
.814 .435 .119 r
.25638 .22015 m .27344 .2049 L .25716 .21007 L F
.807 .43 .115 r
.24162 .22741 m .25638 .22015 L .25716 .21007 L F
1 1 .927 r
.4694 .40615 m .53476 .33081 L .46602 .40422 L F
.4694 .40615 m .53476 .33081 L .53476 .33081 L F
1 1 .593 r
.35646 .46186 m .37386 .45067 L .35084 .45704 L F
.35646 .46186 m .37864 .45493 L .37386 .45067 L F
.921 .703 .432 r
.639 .42787 m .60328 .40436 L .63488 .43071 L F
.996 .774 .475 r
.66625 .44428 m .639 .42787 L .63488 .43071 L F
.432 .234 .047 r
.19401 .37904 m .19434 .38179 L .1886 .36874 L F
.19401 .37904 m .19959 .39175 L .19434 .38179 L F
.368 .195 .061 r
.84083 .22596 m .82783 .22819 L .84111 .23686 L F
.84083 .22596 m .82741 .21767 L .82783 .22819 L F
.972 .695 .241 r
.80022 .44861 m .7773 .45946 L .79391 .45567 L F
.906 .614 .164 r
.81584 .44254 m .80022 .44861 L .79391 .45567 L F
1 1 .855 r
.4343 .4305 m .46334 .4022 L .43026 .42765 L F
.4343 .4305 m .46602 .40422 L .46334 .4022 L F
.965 .505 .135 r
.63929 .23395 m .60762 .26199 L .64138 .23769 L F
.496 .259 .081 r
.42827 .23741 m .46357 .25933 L .43044 .23367 L F
.42827 .23741 m .462 .26181 L .46357 .25933 L F
0 0 0 r
.88065 .36952 m .87491 .38255 L .86941 .39248 L F
.69 .438 .092 r
.87491 .38255 m .86209 .40451 L .86941 .39248 L F
.871 .455 .119 r
.60762 .26199 m .53476 .33081 L .53476 .33081 L F
.973 .504 .133 r
.6061 .25951 m .53476 .33081 L .60762 .26199 L F
.965 .505 .135 r
.63929 .23395 m .6061 .25951 L .60762 .26199 L F
.686 .48 .167 r
.27506 .45515 m .28616 .4524 L .26894 .44807 L F
.27506 .45515 m .29171 .45898 L .28616 .4524 L F
.807 .43 .115 r
.24162 .22741 m .25716 .21007 L .24228 .21688 L F
.781 .414 .109 r
.22832 .23605 m .24162 .22741 L .24228 .21688 L F
.992 .769 .446 r
.69536 .45099 m .66625 .44428 L .69047 .45524 L F
1 .811 .455 r
.71833 .4574 m .69536 .45099 L .69047 .45524 L F
.425 .22 .07 r
.462 .26181 m .53476 .33081 L .46357 .25933 L F
.462 .26181 m .53476 .33081 L .53476 .33081 L F
1 1 .677 r
.37864 .45493 m .39903 .44036 L .37386 .45067 L F
.37864 .45493 m .40293 .44402 L .39903 .44036 L F
.29 .156 .05 r
.85273 .23556 m .84111 .23686 L .85288 .24675 L F
.85273 .23556 m .84083 .22596 L .84111 .23686 L F
.792 .424 .12 r
.73618 .19423 m .71777 .20521 L .73941 .20173 L F
.73618 .19423 m .71472 .19854 L .71777 .20521 L F
.133 .081 .027 r
.19959 .39175 m .20189 .39423 L .19434 .38179 L F
.19959 .39175 m .20693 .40381 L .20189 .39423 L F
1 .763 .32 r
.78304 .45289 m .75918 .46121 L .7773 .45946 L F
.972 .695 .241 r
.80022 .44861 m .78304 .45289 L .7773 .45946 L F
.898 .678 .422 r
.60328 .40436 m .53476 .33081 L .53476 .33081 L F
.824 .614 .371 r
.60601 .40235 m .53476 .33081 L .60328 .40436 L F
.921 .703 .432 r
.639 .42787 m .60601 .40235 L .60328 .40436 L F
1 1 .865 r
.46602 .40422 m .53476 .33081 L .46334 .4022 L F
.46602 .40422 m .53476 .33081 L .53476 .33081 L F
.663 .352 .105 r
.35192 .20472 m .37804 .20556 L .35511 .19805 L F
.706 .377 .11 r
.33028 .20117 m .35192 .20472 L .35511 .19805 L F
.781 .414 .109 r
.22832 .23605 m .24228 .21688 L .22885 .22515 L F
.736 .387 .101 r
.21654 .24592 m .22832 .23605 L .22885 .22515 L F
.786 .501 .108 r
.86738 .39495 m .85304 .41571 L .86209 .40451 L F
.69 .438 .092 r
.87491 .38255 m .86738 .39495 L .86209 .40451 L F
.923 .706 .415 r
.67025 .44064 m .639 .42787 L .66625 .44428 L F
.992 .769 .446 r
.69536 .45099 m .67025 .44064 L .66625 .44428 L F
.859 .626 .267 r
.29171 .45898 m .3049 .4547 L .28616 .4524 L F
.29171 .45898 m .30988 .46077 L .3049 .4547 L F
.723 .387 .112 r
.7563 .19259 m .73941 .20173 L .75968 .20083 L F
.7563 .19259 m .73618 .19423 L .73941 .20173 L F
1 1 .733 r
.40293 .44402 m .42728 .42469 L .39903 .44036 L F
.40293 .44402 m .43026 .42765 L .42728 .42469 L F
.213 .117 .039 r
.86305 .24629 m .85288 .24675 L .86306 .25771 L F
.86305 .24629 m .85273 .23556 L .85288 .24675 L F
.706 .377 .11 r
.33028 .20117 m .35511 .19805 L .33368 .19368 L F
.739 .396 .114 r
.31002 .20022 m .33028 .20117 L .33368 .19368 L F
1 .796 .379 r
.76433 .45516 m .73955 .46065 L .75918 .46121 L F
1 .763 .32 r
.78304 .45289 m .76433 .45516 L .75918 .46121 L F
.188 .116 .037 r
.20693 .40381 m .21122 .40587 L .20189 .39423 L F
.20693 .40381 m .216 .41504 L .21122 .40587 L F
.973 .504 .133 r
.6061 .25951 m .53476 .33081 L .53476 .33081 L F
1 .532 .141 r
.6038 .25709 m .53476 .33081 L .6061 .25951 L F
1 .527 .142 r
.63606 .23029 m .6061 .25951 L .63929 .23395 L F
.63606 .23029 m .6038 .25709 L .6061 .25951 L F
.838 .629 .369 r
.64206 .42491 m .60601 .40235 L .639 .42787 L F
.923 .706 .415 r
.67025 .44064 m .64206 .42491 L .639 .42787 L F
.479 .246 .078 r
.46357 .25933 m .53476 .33081 L .46592 .25691 L F
.46357 .25933 m .53476 .33081 L .53476 .33081 L F
.541 .281 .087 r
.43044 .23367 m .46357 .25933 L .46592 .25691 L F
1 1 .76 r
.43026 .42765 m .46141 .4001 L .42728 .42469 L F
.43026 .42765 m .46334 .4022 L .46141 .4001 L F
.736 .387 .101 r
.21654 .24592 m .22885 .22515 L .21694 .23472 L F
.677 .352 .091 r
.20634 .25686 m .21654 .24592 L .21694 .23472 L F
1 .776 .37 r
.30988 .46077 m .32519 .4547 L .3049 .4547 L F
.30988 .46077 m .32957 .46024 L .32519 .4547 L F
.824 .614 .371 r
.60601 .40235 m .53476 .33081 L .53476 .33081 L F
1 .532 .141 r
.6038 .25709 m .53476 .33081 L .53476 .33081 L F
.731 .535 .305 r
.608 .40026 m .53476 .33081 L .60601 .40235 L F
.608 .40026 m .53476 .33081 L .53476 .33081 L F
1 1 .756 r
.46334 .4022 m .53476 .33081 L .53476 .33081 L F
1 .544 .146 r
.60076 .25475 m .53476 .33081 L .6038 .25709 L F
.60076 .25475 m .53476 .33081 L .53476 .33081 L F
.521 .268 .084 r
.46592 .25691 m .53476 .33081 L .53476 .33081 L F
.618 .443 .225 r
.60923 .39812 m .53476 .33081 L .608 .40026 L F
.60923 .39812 m .53476 .33081 L .53476 .33081 L F
1 .546 .147 r
.59698 .25252 m .53476 .33081 L .60076 .25475 L F
.59698 .25252 m .53476 .33081 L .53476 .33081 L F
1 1 .593 r
.46141 .4001 m .53476 .33081 L .53476 .33081 L F
1 1 .756 r
.46334 .4022 m .53476 .33081 L .46141 .4001 L F
.559 .287 .089 r
.46903 .25458 m .53476 .33081 L .53476 .33081 L F
.521 .268 .084 r
.46592 .25691 m .53476 .33081 L .46903 .25458 L F
1 .54 .147 r
.59252 .25043 m .53476 .33081 L .59698 .25252 L F
.59252 .25043 m .53476 .33081 L .53476 .33081 L F
.594 .304 .093 r
.47285 .25236 m .53476 .33081 L .53476 .33081 L F
.559 .287 .089 r
.46903 .25458 m .53476 .33081 L .47285 .25236 L F
.49 .345 .142 r
.60968 .39595 m .53476 .33081 L .60923 .39812 L F
.60968 .39595 m .53476 .33081 L .53476 .33081 L F
1 .946 .386 r
.46023 .39796 m .53476 .33081 L .53476 .33081 L F
1 1 .593 r
.46141 .4001 m .53476 .33081 L .46023 .39796 L F
1 .53 .145 r
.58741 .24851 m .53476 .33081 L .59252 .25043 L F
.58741 .24851 m .53476 .33081 L .53476 .33081 L F
.627 .319 .097 r
.47736 .25028 m .53476 .33081 L .53476 .33081 L F
.594 .304 .093 r
.47285 .25236 m .53476 .33081 L .47736 .25028 L F
.374 .259 .075 r
.60933 .39377 m .53476 .33081 L .60968 .39595 L F
.60933 .39377 m .53476 .33081 L .53476 .33081 L F
1 .702 .201 r
.45985 .39579 m .53476 .33081 L .53476 .33081 L F
1 .946 .386 r
.46023 .39796 m .53476 .33081 L .45985 .39579 L F
1 .518 .143 r
.58171 .24677 m .53476 .33081 L .58741 .24851 L F
.58171 .24677 m .53476 .33081 L .53476 .33081 L F
.659 .334 .101 r
.48252 .24837 m .53476 .33081 L .53476 .33081 L F
.627 .319 .097 r
.47736 .25028 m .53476 .33081 L .48252 .24837 L F
.321 .218 .059 r
.60819 .3916 m .53476 .33081 L .60933 .39377 L F
.60819 .3916 m .53476 .33081 L .53476 .33081 L F
.876 .563 .125 r
.46025 .39361 m .53476 .33081 L .53476 .33081 L F
1 .702 .201 r
.45985 .39579 m .53476 .33081 L .46025 .39361 L F
1 .505 .14 r
.57548 .24523 m .53476 .33081 L .58171 .24677 L F
.57548 .24523 m .53476 .33081 L .53476 .33081 L F
.689 .348 .104 r
.48826 .24665 m .53476 .33081 L .53476 .33081 L F
.659 .334 .101 r
.48252 .24837 m .53476 .33081 L .48826 .24665 L F
.984 .492 .137 r
.56879 .24392 m .53476 .33081 L .57548 .24523 L F
.56879 .24392 m .53476 .33081 L .53476 .33081 L F
.717 .361 .107 r
.49453 .24513 m .53476 .33081 L .53476 .33081 L F
.689 .348 .104 r
.48826 .24665 m .53476 .33081 L .49453 .24513 L F
.317 .218 .058 r
.63634 .40658 m .60661 .38921 L .60625 .38948 L F
.259 .172 .049 r
.60625 .38948 m .53476 .33081 L .60592 .38972 L F
.60625 .38948 m .53476 .33081 L .53476 .33081 L F
.223 .096 .022 r
.60353 .38742 m .53476 .33081 L .60403 .38766 L F
.60353 .38742 m .60403 .38766 L .60625 .38948 L F
.317 .218 .058 r
.60661 .38921 m .60353 .38742 L .60625 .38948 L F
.17 .073 .017 r
.63134 .40373 m .60299 .38715 L .60353 .38742 L F
.60299 .38715 m .60007 .38544 L .60353 .38742 L F
.259 .172 .049 r
.60625 .38948 m .60592 .38972 L .60819 .3916 L F
.755 .491 .107 r
.46146 .39144 m .53476 .33081 L .53476 .33081 L F
.876 .563 .125 r
.46025 .39361 m .53476 .33081 L .46146 .39144 L F
.958 .478 .134 r
.56171 .24285 m .53476 .33081 L .56879 .24392 L F
.56171 .24285 m .53476 .33081 L .53476 .33081 L F
.745 .374 .11 r
.50125 .24383 m .53476 .33081 L .53476 .33081 L F
.717 .361 .107 r
.49453 .24513 m .53476 .33081 L .50125 .24383 L F
.931 .465 .131 r
.55432 .24203 m .53476 .33081 L .56171 .24285 L F
.55432 .24203 m .53476 .33081 L .53476 .33081 L F
.772 .387 .113 r
.50836 .24278 m .53476 .33081 L .53476 .33081 L F
.745 .374 .11 r
.50125 .24383 m .53476 .33081 L .50836 .24278 L F
.905 .451 .128 r
.54671 .24148 m .53476 .33081 L .55432 .24203 L F
.54671 .24148 m .53476 .33081 L .53476 .33081 L F
.799 .4 .116 r
.51577 .24198 m .53476 .33081 L .53476 .33081 L F
.772 .387 .113 r
.50836 .24278 m .53476 .33081 L .51577 .24198 L F
.223 .096 .022 r
.60353 .38742 m .53476 .33081 L .53476 .33081 L F
0 0 0 r
.46345 .38932 m .53476 .33081 L .53476 .33081 L F
.755 .491 .107 r
.46372 .38957 m .53476 .33081 L .46345 .38932 L F
0 0 0 r
.46345 .38932 m .46566 .38751 L .46622 .38726 L F
.46566 .38751 m .53476 .33081 L .46622 .38726 L F
.46676 .38703 m .46622 .38726 L .46975 .38529 L F
.726 .479 .106 r
.46319 .38909 m .46345 .38932 L .46622 .38726 L F
.42956 .40932 m .46345 .38932 L .46319 .38909 L F
.42956 .40932 m .43294 .40728 L .43352 .40636 L F
.43294 .40728 m .46622 .38726 L .43352 .40636 L F
0 0 0 r
.43352 .40636 m .46622 .38726 L .46676 .38703 L F
.43352 .40636 m .43686 .40441 L .4386 .40352 L F
.43686 .40441 m .46975 .38529 L .4386 .40352 L F
.831 .539 .12 r
.42676 .41236 m .46345 .38932 L .42956 .40932 L F
.755 .491 .107 r
.46146 .39144 m .46372 .38957 L .46345 .38932 L F
.831 .539 .12 r
.42676 .41236 m .46146 .39144 L .46345 .38932 L F
0 0 0 r
.4386 .40352 m .44188 .40166 L .44477 .40083 L F
.44188 .40166 m .47399 .38343 L .44477 .40083 L F
.939 .628 .16 r
.42514 .41545 m .46025 .39361 L .46146 .39144 L F
.42514 .41545 m .46146 .39144 L .42676 .41236 L F
0 0 0 r
.44754 .40004 m .44477 .40083 L .45197 .39833 L F
.619 .42 .094 r
.44027 .40266 m .4386 .40352 L .44477 .40083 L F
0 0 0 r
.4386 .40352 m .46975 .38529 L .47399 .38343 L F
.619 .42 .094 r
.41237 .41401 m .4386 .40352 L .44027 .40266 L F
.41237 .41401 m .41601 .41253 L .42011 .41063 L F
.41601 .41253 m .44477 .40083 L .42011 .41063 L F
0 0 0 r
.42011 .41063 m .44477 .40083 L .44754 .40004 L F
.715 .476 .107 r
.40604 .41757 m .4386 .40352 L .41237 .41401 L F
.43407 .40548 m .43352 .40636 L .4386 .40352 L F
.40604 .41757 m .43352 .40636 L .43407 .40548 L F
0 0 0 r
.42011 .41063 m .42369 .40925 L .42918 .40748 L F
.42369 .40925 m .45197 .39833 L .42918 .40748 L F
1 1 .453 r
.42542 .42165 m .46023 .39796 L .45985 .39579 L F
.42542 .42165 m .45985 .39579 L .42469 .41856 L F
1 .797 .279 r
.42469 .41856 m .45985 .39579 L .46025 .39361 L F
.42469 .41856 m .46025 .39361 L .42514 .41545 L F
0 0 0 r
.42918 .40748 m .43266 .4062 L .43949 .4046 L F
.43266 .4062 m .46012 .39604 L .43949 .4046 L F
.43949 .4046 m .44282 .40341 L .45093 .40202 L F
.44282 .40341 m .46913 .39399 L .45093 .40202 L F
1 1 .624 r
.42728 .42469 m .46141 .4001 L .46023 .39796 L F
.42728 .42469 m .46023 .39796 L .42542 .42165 L F
0 0 0 r
.45862 .4007 m .45093 .40202 L .46338 .39977 L F
.54 .376 .086 r
.44597 .40308 m .43949 .4046 L .45093 .40202 L F
0 0 0 r
.42918 .40748 m .45197 .39833 L .46012 .39604 L F
.43949 .4046 m .46012 .39604 L .46913 .39399 L F
.54 .376 .086 r
.42074 .4085 m .43949 .4046 L .44597 .40308 L F
.42074 .4085 m .42389 .40782 L .43436 .40542 L F
.42389 .40782 m .45093 .40202 L .43436 .40542 L F
0 0 0 r
.43436 .40542 m .45093 .40202 L .45862 .4007 L F
.43436 .40542 m .43739 .40483 L .44922 .40275 L F
.43739 .40483 m .46338 .39977 L .44922 .40275 L F
.44922 .40275 m .45209 .40224 L .46515 .4005 L F
.45209 .40224 m .4767 .39789 L .46515 .4005 L F
.006 .003 .001 r
.46515 .4005 m .46782 .40008 L .48194 .39873 L F
.46782 .40008 m .49072 .39641 L .48194 .39873 L F
.028 .012 .003 r
.48194 .39873 m .48438 .39837 L .4994 .39745 L F
.48438 .39837 m .50529 .39534 L .4994 .39745 L F
.047 .02 .005 r
.4994 .39745 m .50158 .39716 L .51731 .39668 L F
.50158 .39716 m .52022 .3947 L .51731 .39668 L F
.062 .027 .006 r
.51731 .39668 m .53533 .39449 L .53544 .39644 L F
.55 .383 .09 r
.532 .39623 m .51731 .39668 L .53544 .39644 L F
.047 .02 .005 r
.4994 .39745 m .50529 .39534 L .52022 .3947 L F
.062 .027 .006 r
.51731 .39668 m .52022 .3947 L .53533 .39449 L F
.55 .383 .09 r
.51458 .3952 m .51731 .39668 L .532 .39623 L F
.566 .393 .092 r
.51344 .39658 m .4994 .39745 L .51731 .39668 L F
.127 .055 .012 r
.49072 .39641 m .51173 .38872 L .50529 .39534 L F
.028 .012 .003 r
.48194 .39873 m .49072 .39641 L .50529 .39534 L F
.566 .393 .092 r
.49389 .39609 m .4994 .39745 L .51344 .39658 L F
.587 .405 .095 r
.49516 .39747 m .48194 .39873 L .4994 .39745 L F
.103 .044 .01 r
.4767 .39789 m .48936 .39074 L .50034 .38956 L F
.073 .032 .007 r
.46338 .39977 m .48936 .39074 L .4767 .39789 L F
.103 .044 .01 r
.4767 .39789 m .50034 .38956 L .49072 .39641 L F
0 0 0 r
.44922 .40275 m .46338 .39977 L .4767 .39789 L F
.006 .003 .001 r
.46515 .4005 m .4767 .39789 L .49072 .39641 L F
.587 .405 .095 r
.47372 .39757 m .48194 .39873 L .49516 .39747 L F
.611 .419 .098 r
.47738 .39888 m .46515 .4005 L .48194 .39873 L F
.039 .017 .004 r
.45093 .40202 m .46913 .39399 L .47892 .39222 L F
.073 .032 .007 r
.46338 .39977 m .47892 .39222 L .48936 .39074 L F
.039 .017 .004 r
.45093 .40202 m .47892 .39222 L .46338 .39977 L F
.611 .419 .098 r
.45434 .39963 m .46515 .4005 L .47738 .39888 L F
.639 .435 .101 r
.46032 .40079 m .44922 .40275 L .46515 .4005 L F
.436 .40222 m .44922 .40275 L .46032 .40079 L F
.669 .453 .105 r
.4442 .40317 m .43436 .40542 L .44922 .40275 L F
.4189 .40531 m .43436 .40542 L .4442 .40317 L F
.604 .414 .094 r
.4344 .4058 m .42918 .40748 L .43949 .4046 L F
.4085 .41193 m .42918 .40748 L .4344 .4058 L F
.669 .452 .103 r
.42401 .40883 m .42011 .41063 L .42918 .40748 L F
.39777 .41567 m .42011 .41063 L .42401 .40883 L F
.878 .438 .125 r
.53895 .2412 m .53476 .33081 L .54671 .24148 L F
.53895 .2412 m .53476 .33081 L .53476 .33081 L F
.825 .412 .119 r
.52339 .24145 m .53476 .33081 L .53476 .33081 L F
.799 .4 .116 r
.51577 .24198 m .53476 .33081 L .52339 .24145 L F
.852 .425 .122 r
.53115 .24119 m .53476 .33081 L .53895 .2412 L F
.53115 .24119 m .53476 .33081 L .53476 .33081 L F
.825 .412 .119 r
.52339 .24145 m .53476 .33081 L .53115 .24119 L F
.283 .126 .028 r
.60007 .38544 m .53476 .33081 L .60353 .38742 L F
.60007 .38544 m .53476 .33081 L .53476 .33081 L F
0 0 0 r
.46622 .38726 m .53476 .33081 L .53476 .33081 L F
.339 .161 .035 r
.59587 .38357 m .53476 .33081 L .60007 .38544 L F
.59587 .38357 m .53476 .33081 L .53476 .33081 L F
0 0 0 r
.46975 .38529 m .53476 .33081 L .53476 .33081 L F
.46622 .38726 m .53476 .33081 L .46975 .38529 L F
.376 .184 .039 r
.591 .38183 m .53476 .33081 L .59587 .38357 L F
.591 .38183 m .53476 .33081 L .53476 .33081 L F
.034 .015 .003 r
.47399 .38343 m .53476 .33081 L .53476 .33081 L F
0 0 0 r
.46975 .38529 m .53476 .33081 L .47399 .38343 L F
.414 .21 .053 r
.5855 .38024 m .53476 .33081 L .591 .38183 L F
.5855 .38024 m .53476 .33081 L .53476 .33081 L F
.087 .037 .008 r
.47891 .38171 m .53476 .33081 L .53476 .33081 L F
.034 .015 .003 r
.47399 .38343 m .53476 .33081 L .47891 .38171 L F
.46 .242 .072 r
.57942 .37882 m .53476 .33081 L .5855 .38024 L F
.57942 .37882 m .53476 .33081 L .53476 .33081 L F
.145 .065 .016 r
.48446 .38013 m .53476 .33081 L .53476 .33081 L F
.087 .037 .008 r
.47891 .38171 m .53476 .33081 L .48446 .38013 L F
.497 .269 .088 r
.57284 .37759 m .53476 .33081 L .57942 .37882 L F
.57284 .37759 m .53476 .33081 L .53476 .33081 L F
.198 .091 .023 r
.49058 .37872 m .53476 .33081 L .53476 .33081 L F
.145 .065 .016 r
.48446 .38013 m .53476 .33081 L .49058 .37872 L F
.517 .283 .097 r
.56583 .37655 m .53476 .33081 L .57284 .37759 L F
.56583 .37655 m .53476 .33081 L .53476 .33081 L F
.24 .112 .028 r
.49719 .3775 m .53476 .33081 L .53476 .33081 L F
.198 .091 .023 r
.49058 .37872 m .53476 .33081 L .49719 .3775 L F
.521 .287 .099 r
.55845 .37574 m .53476 .33081 L .56583 .37655 L F
.55845 .37574 m .53476 .33081 L .53476 .33081 L F
.292 .144 .036 r
.50424 .37649 m .53476 .33081 L .53476 .33081 L F
.24 .112 .028 r
.49719 .3775 m .53476 .33081 L .50424 .37649 L F
.511 .282 .097 r
.55081 .37514 m .53476 .33081 L .55845 .37574 L F
.55081 .37514 m .53476 .33081 L .53476 .33081 L F
.342 .175 .046 r
.51163 .37568 m .53476 .33081 L .53476 .33081 L F
.292 .144 .036 r
.50424 .37649 m .53476 .33081 L .51163 .37568 L F
.492 .27 .09 r
.54298 .37478 m .53476 .33081 L .55081 .37514 L F
.54298 .37478 m .53476 .33081 L .53476 .33081 L F
.387 .204 .058 r
.51929 .37511 m .53476 .33081 L .53476 .33081 L F
.342 .175 .046 r
.51163 .37568 m .53476 .33081 L .51929 .37511 L F
.464 .252 .081 r
.53506 .37465 m .53476 .33081 L .54298 .37478 L F
.53506 .37465 m .53476 .33081 L .53476 .33081 L F
.429 .23 .07 r
.52713 .37476 m .53476 .33081 L .53476 .33081 L F
.387 .204 .058 r
.51929 .37511 m .53476 .33081 L .52713 .37476 L F
.429 .23 .07 r
.52713 .37476 m .53476 .33081 L .53506 .37465 L F
.649 .347 .102 r
.77514 .19328 m .75968 .20083 L .77862 .20221 L F
.77514 .19328 m .7563 .19259 L .75968 .20083 L F
.853 .546 .119 r
.85807 .40656 m .8423 .4259 L .85304 .41571 L F
.786 .501 .108 r
.86738 .39495 m .85807 .40656 L .85304 .41571 L F
.838 .629 .369 r
.64206 .42491 m .608 .40026 L .60601 .40235 L F
.541 .281 .087 r
.43044 .23367 m .46592 .25691 L .43375 .23002 L F
.165 .088 .03 r
.87171 .258 m .86306 .25771 L .87161 .26956 L F
.87171 .258 m .86305 .24629 L .86306 .25771 L F
.739 .396 .114 r
.31002 .20022 m .33368 .19368 L .31358 .19197 L F
.759 .408 .115 r
.29107 .20155 m .31002 .20022 L .31358 .19197 L F
1 .794 .407 r
.74408 .45512 m .71833 .4574 L .73955 .46065 L F
1 .796 .379 r
.76433 .45516 m .74408 .45512 L .73955 .46065 L F
.285 .19 .053 r
.216 .41504 m .22229 .41653 L .21122 .40587 L F
.216 .41504 m .22677 .42526 L .22229 .41653 L F
1 .909 .459 r
.32957 .46024 m .34707 .45206 L .32519 .4547 L F
.32957 .46024 m .35084 .45704 L .34707 .45206 L F
.57 .304 .091 r
.79269 .19606 m .77862 .20221 L .79625 .20561 L F
.79269 .19606 m .77514 .19328 L .77862 .20221 L F
.677 .352 .091 r
.20634 .25686 m .21694 .23472 L .20662 .24543 L F
.612 .314 .081 r
.19778 .26871 m .20634 .25686 L .20662 .24543 L F
.907 .593 .14 r
.84702 .41719 m .82988 .43491 L .8423 .4259 L F
.853 .546 .119 r
.85807 .40656 m .84702 .41719 L .8423 .4259 L F
.988 .759 .408 r
.72224 .45243 m .69536 .45099 L .71833 .4574 L F
1 .794 .407 r
.74408 .45512 m .72224 .45243 L .71833 .4574 L F
1 .539 .146 r
.63171 .22675 m .6038 .25709 L .63606 .23029 L F
.63171 .22675 m .60076 .25475 L .6038 .25709 L F
.578 .3 .093 r
.43375 .23002 m .46592 .25691 L .46903 .25458 L F
.759 .408 .115 r
.29107 .20155 m .31358 .19197 L .29476 .19261 L F
.763 .41 .113 r
.27344 .2049 m .29107 .20155 L .29476 .19261 L F
.119 .06 .023 r
.87867 .27053 m .87171 .258 L .87161 .26956 L F
1 1 .535 r
.35084 .45704 m .37072 .44627 L .34707 .45206 L F
.35084 .45704 m .37386 .45067 L .37072 .44627 L F
.368 .254 .067 r
.22677 .42526 m .23506 .42604 L .22229 .41653 L F
.22677 .42526 m .23921 .4343 L .23506 .42604 L F
.874 .465 .13 r
.70967 .19198 m .69177 .20599 L .71472 .19854 L F
.70967 .19198 m .68723 .20031 L .69177 .20599 L F
.921 .701 .385 r
.69863 .44661 m .67025 .44064 L .69536 .45099 L F
.988 .759 .408 r
.72224 .45243 m .69863 .44661 L .69536 .45099 L F
.738 .541 .291 r
.64401 .42188 m .608 .40026 L .64206 .42491 L F
.64401 .42188 m .60923 .39812 L .608 .40026 L F
.684 .364 .108 r
.35511 .19805 m .37804 .20556 L .38271 .19989 L F
.962 .657 .182 r
.83426 .42666 m .81584 .44254 L .82988 .43491 L F
.907 .593 .14 r
.84702 .41719 m .83426 .42666 L .82988 .43491 L F
.483 .257 .078 r
.80892 .20073 m .79625 .20561 L .81253 .21083 L F
.80892 .20073 m .79269 .19606 L .79625 .20561 L F
1 1 .59 r
.37386 .45067 m .39652 .4366 L .37072 .44627 L F
.37386 .45067 m .39903 .44036 L .39652 .4366 L F
.612 .314 .081 r
.19778 .26871 m .20662 .24543 L .19795 .25713 L F
.836 .626 .344 r
.67287 .43689 m .64206 .42491 L .67025 .44064 L F
.921 .701 .385 r
.69863 .44661 m .67287 .43689 L .67025 .44064 L F
.836 .626 .344 r
.67287 .43689 m .64401 .42188 L .64206 .42491 L F
.608 .358 .071 r
.1823 .3276 m .18257 .34147 L .18063 .33036 L F
1 1 .62 r
.39903 .44036 m .42542 .42165 L .39652 .4366 L F
.39903 .44036 m .42728 .42469 L .42542 .42165 L F
.763 .41 .113 r
.27344 .2049 m .29476 .19261 L .27722 .19535 L F
.749 .402 .109 r
.25716 .21007 m .27344 .2049 L .27722 .19535 L F
.462 .323 .091 r
.23921 .4343 m .24949 .43419 L .23506 .42604 L F
.23921 .4343 m .25328 .44197 L .24949 .43419 L F
.091 .045 .018 r
.88388 .28372 m .87867 .27053 L .87848 .28216 L F
.578 .3 .093 r
.43375 .23002 m .46903 .25458 L .43818 .22649 L F
.802 .429 .122 r
.73069 .18684 m .71472 .19854 L .73618 .19423 L F
.73069 .18684 m .70967 .19198 L .71472 .19854 L F
0 0 0 r
.88888 .33119 m .88456 .35604 L .88666 .34229 L F
1 .541 .147 r
.62628 .22337 m .60076 .25475 L .63171 .22675 L F
.62628 .22337 m .59698 .25252 L .60076 .25475 L F
1 .729 .248 r
.81986 .43478 m .80022 .44861 L .81584 .44254 L F
.962 .657 .182 r
.83426 .42666 m .81986 .43478 L .81584 .44254 L F
.612 .317 .097 r
.43818 .22649 m .46903 .25458 L .47285 .25236 L F
.684 .364 .108 r
.35511 .19805 m .38271 .19989 L .36031 .19149 L F
.717 .383 .112 r
.33368 .19368 m .35511 .19805 L .36031 .19149 L F
.392 .209 .065 r
.82378 .2071 m .81253 .21083 L .82741 .21767 L F
.82378 .2071 m .80892 .20073 L .81253 .21083 L F
.55 .278 .072 r
.19091 .2813 m .19795 .25713 L .19099 .26966 L F
.497 .247 .063 r
.18577 .29448 m .19091 .2813 L .19099 .26966 L F
.606 .423 .145 r
.25328 .44197 m .26553 .44079 L .24949 .43419 L F
.25328 .44197 m .26894 .44807 L .26553 .44079 L F
.493 .283 .055 r
.18257 .34147 m .18277 .34438 L .18063 .33036 L F
.18257 .34147 m .18467 .35524 L .18277 .34438 L F
.749 .402 .109 r
.25716 .21007 m .27722 .19535 L .261 .19998 L F
.714 .382 .102 r
.24228 .21688 m .25716 .21007 L .261 .19998 L F
1 .784 .313 r
.80384 .44134 m .78304 .45289 L .80022 .44861 L F
1 .729 .248 r
.81986 .43478 m .80384 .44134 L .80022 .44861 L F
.623 .445 .205 r
.64482 .41879 m .60923 .39812 L .64401 .42188 L F
.64482 .41879 m .60968 .39595 L .60923 .39812 L F
0 0 0 r
.88888 .33119 m .88674 .3452 L .88456 .35604 L F
.671 .413 .084 r
.88674 .3452 m .88065 .36952 L .88456 .35604 L F
.721 .386 .111 r
.75043 .18444 m .73618 .19423 L .7563 .19259 L F
.75043 .18444 m .73069 .18684 L .73618 .19423 L F
.755 .541 .22 r
.26894 .44807 m .28313 .44563 L .26553 .44079 L F
.26894 .44807 m .28616 .4524 L .28313 .44563 L F
.717 .383 .112 r
.33368 .19368 m .36031 .19149 L .33933 .1863 L F
.736 .395 .113 r
.31358 .19197 m .33368 .19368 L .33933 .1863 L F
1 .81 .361 r
.78626 .44614 m .76433 .45516 L .78304 .45289 L F
1 .784 .313 r
.80384 .44134 m .78626 .44614 L .78304 .45289 L F
.304 .165 .052 r
.8372 .215 m .82741 .21767 L .84083 .22596 L F
.8372 .215 m .82378 .2071 L .82741 .21767 L F
.086 .053 .017 r
.18467 .35524 m .18677 .35819 L .18277 .34438 L F
.18467 .35524 m .1886 .36874 L .18677 .35819 L F
.644 .333 .101 r
.4437 .22313 m .47285 .25236 L .47736 .25028 L F
.612 .317 .097 r
.43818 .22649 m .47285 .25236 L .4437 .22313 L F
.899 .665 .302 r
.28616 .4524 m .30228 .44847 L .28313 .44563 L F
.28616 .4524 m .3049 .4547 L .30228 .44847 L F
.737 .537 .263 r
.67405 .43306 m .64401 .42188 L .67287 .43689 L F
.67405 .43306 m .64482 .41879 L .64401 .42188 L F
.714 .382 .102 r
.24228 .21688 m .261 .19998 L .24615 .20631 L F
.663 .352 .093 r
.22885 .22515 m .24228 .21688 L .24615 .20631 L F
.778 .483 .101 r
.88275 .35898 m .87491 .38255 L .88065 .36952 L F
.671 .413 .084 r
.88674 .3452 m .88275 .35898 L .88065 .36952 L F
1 .802 .384 r
.76713 .44894 m .74408 .45512 L .76433 .45516 L F
1 .81 .361 r
.78626 .44614 m .76713 .44894 L .76433 .45516 L F
1 1 .485 r
.39652 .4366 m .42542 .42165 L .42469 .41856 L F
.635 .34 .1 r
.76894 .18444 m .7563 .19259 L .77514 .19328 L F
.76894 .18444 m .75043 .18444 L .7563 .19259 L F
1 .781 .375 r
.3049 .4547 m .32297 .44903 L .30228 .44847 L F
.3049 .4547 m .32519 .4547 L .32297 .44903 L F
1 .766 .382 r
.74647 .44946 m .72224 .45243 L .74408 .45512 L F
1 .802 .384 r
.76713 .44894 m .74647 .44946 L .74408 .45512 L F
.89 .472 .132 r
.70264 .18559 m .68723 .20031 L .70967 .19198 L F
.70264 .18559 m .68097 .19479 L .68723 .20031 L F
.842 .626 .317 r
.7002 .44212 m .67287 .43689 L .69863 .44661 L F
.7002 .44212 m .67405 .43306 L .67287 .43689 L F
.505 .354 .126 r
.64446 .41568 m .60968 .39595 L .64482 .41879 L F
.64446 .41568 m .60933 .39377 L .60968 .39595 L F
.138 .085 .028 r
.1886 .36874 m .19263 .3716 L .18677 .35819 L F
.1886 .36874 m .19434 .38179 L .19263 .3716 L F
.932 .705 .358 r
.72421 .44734 m .69863 .44661 L .72224 .45243 L F
1 .766 .382 r
.74647 .44946 m .72421 .44734 L .72224 .45243 L F
.932 .705 .358 r
.72421 .44734 m .7002 .44212 L .69863 .44661 L F
.705 .374 .111 r
.36031 .19149 m .38271 .19989 L .38909 .19439 L F
.225 .125 .04 r
.8491 .22429 m .84083 .22596 L .85273 .23556 L F
.8491 .22429 m .8372 .215 L .84083 .22596 L F
1 1 .485 r
.39652 .4366 m .42469 .41856 L .39545 .43277 L F
1 1 .49 r
.37072 .44627 m .39652 .4366 L .39545 .43277 L F
.736 .395 .113 r
.31358 .19197 m .33933 .1863 L .31963 .18384 L F
.739 .397 .112 r
.29476 .19261 m .31358 .19197 L .31963 .18384 L F
1 .878 .431 r
.32519 .4547 m .34525 .44696 L .32297 .44903 L F
.32519 .4547 m .34707 .45206 L .34525 .44696 L F
.858 .536 .115 r
.8769 .37236 m .86738 .39495 L .87491 .38255 L F
.778 .483 .101 r
.88275 .35898 m .8769 .37236 L .87491 .38255 L F
1 1 .49 r
.37072 .44627 m .39545 .43277 L .36928 .44179 L F
1 .956 .471 r
.34707 .45206 m .37072 .44627 L .36928 .44179 L F
.34707 .45206 m .36928 .44179 L .34525 .44696 L F
.663 .352 .093 r
.22885 .22515 m .24615 .20631 L .23274 .21419 L F
.604 .317 .083 r
.21694 .23472 m .22885 .22515 L .23274 .21419 L F
.184 .113 .037 r
.19434 .38179 m .20031 .38443 L .19263 .3716 L F
.19434 .38179 m .20189 .39423 L .20031 .38443 L F
.541 .289 .086 r
.78622 .18659 m .77514 .19328 L .79269 .19606 L F
.78622 .18659 m .76894 .18444 L .77514 .19328 L F
.928 .596 .139 r
.86922 .38516 m .85807 .40656 L .86738 .39495 L F
.858 .536 .115 r
.8769 .37236 m .86922 .38516 L .86738 .39495 L F
.178 .096 .032 r
.85943 .23479 m .85273 .23556 L .86305 .24629 L F
.85943 .23479 m .8491 .22429 L .85273 .23556 L F
.81 .433 .123 r
.72296 .17964 m .70967 .19198 L .73069 .18684 L F
.72296 .17964 m .70264 .18559 L .70967 .19198 L F
.739 .397 .112 r
.29476 .19261 m .31963 .18384 L .30115 .18378 L F
.72 .387 .107 r
.27722 .19535 m .29476 .19261 L .30115 .18378 L F
.702 .36 .108 r
.45775 .21705 m .48252 .24837 L .48826 .24665 L F
.407 .284 .076 r
.64292 .41259 m .60933 .39377 L .64446 .41568 L F
.64292 .41259 m .60819 .3916 L .60933 .39377 L F
.705 .374 .111 r
.36031 .19149 m .38909 .19439 L .36749 .18512 L F
.728 .389 .113 r
.33933 .1863 m .36031 .19149 L .36749 .18512 L F
.268 .176 .051 r
.20189 .39423 m .2098 .39649 L .20031 .38443 L F
.20189 .39423 m .21122 .40587 L .2098 .39649 L F
.633 .448 .183 r
.67375 .4292 m .64482 .41879 L .67405 .43306 L F
.67375 .4292 m .64446 .41568 L .64482 .41879 L F
.604 .317 .083 r
.21694 .23472 m .23274 .21419 L .22084 .22345 L F
.554 .286 .075 r
.20662 .24543 m .21694 .23472 L .22084 .22345 L F
1 .857 .341 r
.39545 .43277 m .42469 .41856 L .42514 .41545 L F
.995 .669 .179 r
.85974 .3972 m .84702 .41719 L .85807 .40656 L F
.928 .596 .139 r
.86922 .38516 m .85974 .3972 L .85807 .40656 L F
.127 .065 .024 r
.86811 .24635 m .86305 .24629 L .87171 .258 L F
.86811 .24635 m .85943 .23479 L .86305 .24629 L F
.439 .235 .071 r
.80221 .19071 m .79269 .19606 L .80892 .20073 L F
.80221 .19071 m .78622 .18659 L .79269 .19606 L F
.345 .236 .065 r
.21122 .40587 m .22106 .40761 L .2098 .39649 L F
.21122 .40587 m .22229 .41653 L .22106 .40761 L F
.729 .372 .111 r
.46615 .21442 m .48826 .24665 L .49453 .24513 L F
.702 .36 .108 r
.45775 .21705 m .48826 .24665 L .46615 .21442 L F
1 .751 .239 r
.84849 .40828 m .83426 .42666 L .84702 .41719 L F
.995 .669 .179 r
.85974 .3972 m .84849 .40828 L .84702 .41719 L F
.72 .387 .107 r
.27722 .19535 m .30115 .18378 L .28391 .1859 L F
.679 .365 .099 r
.261 .19998 m .27722 .19535 L .28391 .1859 L F
.758 .549 .246 r
.70002 .43759 m .67405 .43306 L .7002 .44212 L F
.70002 .43759 m .67375 .4292 L .67405 .43306 L F
.719 .385 .111 r
.74209 .17649 m .73069 .18684 L .75043 .18444 L F
.74209 .17649 m .72296 .17964 L .73069 .18684 L F
.554 .286 .075 r
.20662 .24543 m .22084 .22345 L .21051 .23393 L F
.509 .259 .068 r
.19795 .25713 m .20662 .24543 L .21051 .23393 L F
.902 .477 .134 r
.69366 .17946 m .68097 .19479 L .70264 .18559 L F
.69366 .17946 m .67303 .18951 L .68097 .19479 L F
1 .857 .341 r
.39545 .43277 m .42514 .41545 L .39585 .42891 L F
1 .885 .384 r
.36928 .44179 m .39545 .43277 L .39585 .42891 L F
.439 .309 .1 r
.22229 .41653 m .23403 .4176 L .22106 .40761 L F
.22229 .41653 m .23506 .42604 L .23403 .4176 L F
.366 .254 .067 r
.64021 .40954 m .60819 .3916 L .64292 .41259 L F
.64021 .40954 m .60625 .38948 L .60819 .3916 L F
.728 .389 .113 r
.33933 .1863 m .36749 .18512 L .34723 .17912 L F
.734 .394 .113 r
.31963 .18384 m .33933 .1863 L .34723 .17912 L F
1 .822 .306 r
.83553 .41823 m .81986 .43478 L .83426 .42666 L F
1 .751 .239 r
.84849 .40828 m .83553 .41823 L .83426 .42666 L F
.725 .384 .113 r
.36749 .18512 m .38909 .19439 L .39715 .18913 L F
.99 .501 .14 r
.58504 .21025 m .56879 .24392 L .57548 .24523 L F
.09 .045 .018 r
.87509 .2588 m .87171 .258 L .87867 .27053 L F
.87509 .2588 m .86811 .24635 L .87171 .258 L F
.874 .648 .307 r
.72418 .44219 m .7002 .44212 L .72421 .44734 L F
.72418 .44219 m .70002 .43759 L .7002 .44212 L F
.571 .401 .152 r
.23506 .42604 m .24867 .42626 L .23403 .4176 L F
.23506 .42604 m .24949 .43419 L .24867 .42626 L F
1 .865 .359 r
.8209 .42685 m .80384 .44134 L .81986 .43478 L F
1 .822 .306 r
.83553 .41823 m .8209 .42685 L .81986 .43478 L F
.976 .51 .142 r
.66349 .18453 m .65084 .20365 L .67303 .18951 L F
.66349 .18453 m .64273 .19953 L .65084 .20365 L F
.337 .183 .056 r
.81687 .1966 m .80892 .20073 L .82378 .2071 L F
.81687 .1966 m .80221 .19071 L .80892 .20073 L F
1 .885 .384 r
.36928 .44179 m .39585 .42891 L .36959 .43726 L F
1 .881 .405 r
.34525 .44696 m .36928 .44179 L .36959 .43726 L F
.534 .372 .117 r
.67197 .42535 m .64446 .41568 L .67375 .4292 L F
.67197 .42535 m .64292 .41259 L .64446 .41568 L F
1 .876 .392 r
.80465 .43394 m .78626 .44614 L .80384 .44134 L F
1 .865 .359 r
.8209 .42685 m .80465 .43394 L .80384 .44134 L F
.975 .737 .356 r
.74662 .44371 m .72421 .44734 L .74647 .44946 L F
.74662 .44371 m .72418 .44219 L .72421 .44734 L F
.509 .259 .068 r
.19795 .25713 m .21051 .23393 L .20183 .24548 L F
.461 .234 .06 r
.19099 .26966 m .19795 .25713 L .20183 .24548 L F
.702 .502 .215 r
.24949 .43419 m .26493 .43338 L .24867 .42626 L F
.24949 .43419 m .26553 .44079 L .26493 .43338 L F
.679 .365 .099 r
.261 .19998 m .28391 .1859 L .26794 .18997 L F
.622 .332 .089 r
.24615 .20631 m .261 .19998 L .26794 .18997 L F
.998 .7 .218 r
.39585 .42891 m .42514 .41545 L .42676 .41236 L F
1 .856 .401 r
.78684 .43927 m .76713 .44894 L .78626 .44614 L F
1 .876 .392 r
.80465 .43394 m .78684 .43927 L .78626 .44614 L F
1 .808 .389 r
.76749 .44262 m .74647 .44946 L .76713 .44894 L F
.76749 .44262 m .74662 .44371 L .74647 .44946 L F
1 .881 .405 r
.34525 .44696 m .36959 .43726 L .34543 .44181 L F
1 .847 .403 r
.32297 .44903 m .34525 .44696 L .34543 .44181 L F
1 .856 .401 r
.78684 .43927 m .76749 .44262 L .76713 .44894 L F
.621 .332 .097 r
.76004 .1758 m .75043 .18444 L .76894 .18444 L F
.76004 .1758 m .74209 .17649 L .75043 .18444 L F
.828 .607 .28 r
.26553 .44079 m .28275 .43876 L .26493 .43338 L F
.26553 .44079 m .28313 .44563 L .28275 .43876 L F
.317 .218 .058 r
.63634 .40658 m .60625 .38948 L .64021 .40954 L F
1 .847 .403 r
.32297 .44903 m .34543 .44181 L .32298 .44328 L F
1 .787 .38 r
.30228 .44847 m .32297 .44903 L .32298 .44328 L F
.94 .705 .338 r
.28313 .44563 m .3021 .44215 L .28275 .43876 L F
.28313 .44563 m .30228 .44847 L .3021 .44215 L F
.06 .03 .012 r
.88031 .27199 m .87867 .27053 L .88388 .28372 L F
.88031 .27199 m .87509 .2588 L .87867 .27053 L F
.042 .026 .008 r
.18035 .31628 m .18063 .33036 L .18251 .31908 L F
1 .787 .38 r
.30228 .44847 m .32298 .44328 L .3021 .44215 L F
.734 .394 .113 r
.31963 .18384 m .34723 .17912 L .32816 .1759 L F
.717 .386 .109 r
.30115 .18378 m .31963 .18384 L .32816 .1759 L F
.804 .408 .119 r
.49572 .2085 m .50836 .24278 L .51577 .24198 L F
.818 .436 .124 r
.71304 .17272 m .70264 .18559 L .72296 .17964 L F
.71304 .17272 m .69366 .17946 L .70264 .18559 L F
.748 .451 .093 r
.88729 .31992 m .88674 .3452 L .88888 .33119 L F
.628 .373 .074 r
.88758 .30566 m .88729 .31992 L .88888 .33119 L F
.244 .138 .043 r
.83012 .20411 m .82378 .2071 L .8372 .215 L F
.83012 .20411 m .81687 .1966 L .82378 .2071 L F
.725 .384 .113 r
.36749 .18512 m .39715 .18913 L .37661 .17902 L F
.739 .394 .115 r
.34723 .17912 m .36749 .18512 L .37661 .17902 L F
.461 .234 .06 r
.19099 .26966 m .20183 .24548 L .19485 .25793 L F
.397 .2 .05 r
.18578 .28285 m .19099 .26966 L .19485 .25793 L F
.622 .332 .089 r
.24615 .20631 m .26794 .18997 L .2533 .19583 L F
.564 .297 .079 r
.23274 .21419 m .24615 .20631 L .2533 .19583 L F
.095 .058 .019 r
.18063 .33036 m .18467 .33337 L .18251 .31908 L F
.18063 .33036 m .18277 .34438 L .18467 .33337 L F
.675 .476 .18 r
.69806 .43306 m .67375 .4292 L .70002 .43759 L F
.69806 .43306 m .67197 .42535 L .67375 .4292 L F
.282 .129 .03 r
.88373 .28575 m .88388 .28372 L .88728 .2974 L F
.88373 .28575 m .88031 .27199 L .88388 .28372 L F
.844 .516 .11 r
.88514 .3342 m .88275 .35898 L .88674 .3452 L F
.748 .451 .093 r
.88729 .31992 m .88514 .3342 L .88674 .3452 L F
.998 .7 .218 r
.39585 .42891 m .42676 .41236 L .39775 .42506 L F
1 .765 .284 r
.36959 .43726 m .39585 .42891 L .39775 .42506 L F
.911 .481 .135 r
.68281 .17367 m .67303 .18951 L .69366 .17946 L F
.68281 .17367 m .66349 .18453 L .67303 .18951 L F
.978 .509 .142 r
.65242 .17991 m .64273 .19953 L .66349 .18453 L F
.512 .273 .081 r
.77682 .17733 m .76894 .18444 L .78622 .18659 L F
.77682 .17733 m .76004 .1758 L .76894 .18444 L F
.17 .073 .017 r
.63134 .40373 m .60353 .38742 L .6331 .40468 L F
.211 .09 .021 r
.62525 .40103 m .60007 .38544 L .62825 .40192 L F
.62525 .40103 m .62825 .40192 L .63134 .40373 L F
.338 .237 .061 r
.65004 .41088 m .62942 .40268 L .63134 .40373 L F
.62942 .40268 m .62525 .40103 L .63134 .40373 L F
.17 .073 .017 r
.63134 .40373 m .6331 .40468 L .63634 .40658 L F
.378 .265 .068 r
.65767 .41427 m .63134 .40373 L .63634 .40658 L F
.338 .237 .061 r
.65004 .41088 m .63134 .40373 L .65443 .41297 L F
.65004 .41088 m .65443 .41297 L .65767 .41427 L F
.426 .304 .075 r
.66188 .4122 m .64531 .40863 L .65004 .41088 L F
.137 .059 .013 r
.64106 .40771 m .62525 .40103 L .64698 .40966 L F
.64106 .40771 m .64698 .40966 L .65004 .41088 L F
.64106 .40771 m .62198 .40005 L .62525 .40103 L F
.162 .069 .016 r
.63084 .4048 m .61813 .39851 L .63823 .40657 L F
.63084 .4048 m .63823 .40657 L .64106 .40771 L F
.63084 .4048 m .61005 .3962 L .61813 .39851 L F
.179 .077 .018 r
.61948 .4022 m .61005 .3962 L .63084 .4048 L F
.381 .273 .067 r
.63622 .40564 m .62289 .4029 L .63084 .4048 L F
.62289 .4029 m .61948 .4022 L .63084 .4048 L F
.403 .288 .071 r
.64975 .40874 m .63469 .40561 L .64106 .40771 L F
.63469 .40561 m .63084 .4048 L .64106 .40771 L F
.426 .304 .075 r
.64531 .40863 m .64106 .40771 L .65004 .41088 L F
.137 .059 .013 r
.62198 .40005 m .61813 .39851 L .62525 .40103 L F
.744 .393 .116 r
.37661 .17902 m .39715 .18913 L .40681 .18417 L F
.451 .316 .081 r
.66868 .42155 m .64292 .41259 L .67197 .42535 L F
.66868 .42155 m .64021 .40954 L .64292 .41259 L F
.397 .2 .05 r
.18578 .28285 m .19485 .25793 L .18963 .27112 L F
0 0 0 r
.18237 .29654 m .18578 .28285 L .18963 .27112 L F
.717 .386 .109 r
.30115 .18378 m .32816 .1759 L .31025 .17516 L F
.675 .364 .101 r
.28391 .1859 m .30115 .18378 L .31025 .17516 L F
.88 .584 .142 r
.39775 .42506 m .42676 .41236 L .42956 .40932 L F
.143 .088 .029 r
.18277 .34438 m .1887 .3475 L .18467 .33337 L F
.18277 .34438 m .18677 .35819 L .1887 .3475 L F
.197 .109 .035 r
.84189 .21307 m .8372 .215 L .8491 .22429 L F
.84189 .21307 m .83012 .20411 L .8372 .215 L F
.946 .605 .151 r
.8811 .34829 m .8769 .37236 L .88275 .35898 L F
.844 .516 .11 r
.88514 .3342 m .8811 .34829 L .88275 .35898 L F
.346 .162 .039 r
.88531 .2999 m .88373 .28575 L .88728 .2974 L F
.717 .385 .111 r
.73129 .16883 m .72296 .17964 L .74209 .17649 L F
.73129 .16883 m .71304 .17272 L .72296 .17964 L F
.564 .297 .079 r
.23274 .21419 m .2533 .19583 L .24007 .2033 L F
.519 .269 .072 r
.22084 .22345 m .23274 .21419 L .24007 .2033 L F
.816 .593 .256 r
.72212 .43703 m .70002 .43759 L .72418 .44219 L F
.72212 .43703 m .69806 .43306 L .70002 .43759 L F
.739 .394 .115 r
.34723 .17912 m .37661 .17902 L .35731 .17222 L F
.731 .392 .112 r
.32816 .1759 m .34723 .17912 L .35731 .17222 L F
1 .765 .284 r
.36959 .43726 m .39775 .42506 L .37168 .43273 L F
1 .805 .34 r
.34543 .44181 m .36959 .43726 L .37168 .43273 L F
.184 .113 .037 r
.18677 .35819 m .1946 .36127 L .1887 .3475 L F
.18677 .35819 m .19263 .3716 L .1946 .36127 L F
0 0 0 r
.18237 .29654 m .18963 .27112 L .18622 .28488 L F
.011 .005 .002 r
.1808 .31055 m .18237 .29654 L .18622 .28488 L F
.211 .09 .021 r
.62525 .40103 m .59587 .38357 L .60007 .38544 L F
1 .714 .213 r
.8752 .36204 m .86922 .38516 L .8769 .37236 L F
.946 .605 .151 r
.8811 .34829 m .8752 .36204 L .8769 .37236 L F
.395 .213 .064 r
.79238 .18089 m .78622 .18659 L .80221 .19071 L F
.79238 .18089 m .77682 .17733 L .78622 .18659 L F
.142 .075 .026 r
.85211 .22333 m .8491 .22429 L .85943 .23479 L F
.85211 .22333 m .84189 .21307 L .8491 .22429 L F
.948 .709 .331 r
.7445 .43794 m .72418 .44219 L .74662 .44371 L F
.7445 .43794 m .72212 .43703 L .72418 .44219 L F
.259 .17 .05 r
.19263 .3716 m .20234 .3745 L .1946 .36127 L F
.19263 .3716 m .20031 .38443 L .20234 .3745 L F
.675 .364 .101 r
.28391 .1859 m .31025 .17516 L .29352 .17665 L F
.612 .328 .089 r
.26794 .18997 m .28391 .1859 L .29352 .17665 L F
1 .823 .286 r
.86746 .37524 m .85974 .3972 L .86922 .38516 L F
1 .714 .213 r
.8752 .36204 m .86746 .37524 L .86922 .38516 L F
.975 .507 .142 r
.63994 .17571 m .63337 .19572 L .65242 .17991 L F
.63994 .17571 m .62285 .19226 L .63337 .19572 L F
1 .805 .34 r
.34543 .44181 m .37168 .43273 L .34765 .43664 L F
1 .814 .375 r
.32298 .44328 m .34543 .44181 L .34765 .43664 L F
.823 .439 .125 r
.70098 .16617 m .69366 .17946 L .71304 .17272 L F
.70098 .16617 m .68281 .17367 L .69366 .17946 L F
.764 .399 .118 r
.41799 .17958 m .4369 .19545 L .44751 .19202 L F
.743 .389 .115 r
.40681 .18417 m .4369 .19545 L .41799 .17958 L F
.519 .269 .072 r
.22084 .22345 m .24007 .2033 L .22832 .21224 L F
.477 .247 .065 r
.21051 .23393 m .22084 .22345 L .22832 .21224 L F
.413 .291 .074 r
.6639 .41784 m .64021 .40954 L .66868 .42155 L F
.6639 .41784 m .63634 .40658 L .64021 .40954 L F
.744 .393 .116 r
.37661 .17902 m .40681 .18417 L .3876 .17325 L F
.749 .399 .116 r
.35731 .17222 m .37661 .17902 L .3876 .17325 L F
.599 .414 .127 r
.69431 .42858 m .67197 .42535 L .69806 .43306 L F
.69431 .42858 m .66868 .42155 L .67197 .42535 L F
.34 .235 .078 r
.20031 .38443 m .2119 .38701 L .20234 .3745 L F
.20031 .38443 m .2098 .39649 L .2119 .38701 L F
.798 .523 .118 r
.40115 .42127 m .42956 .40932 L .43352 .40636 L F
.88 .584 .142 r
.39775 .42506 m .42956 .40932 L .40115 .42127 L F
1 .918 .362 r
.85791 .38771 m .84849 .40828 L .85974 .3972 L F
1 .823 .286 r
.86746 .37524 m .85791 .38771 L .85974 .3972 L F
1 .814 .394 r
.76535 .43627 m .74662 .44371 L .76749 .44262 L F
.76535 .43627 m .7445 .43794 L .74662 .44371 L F
.915 .482 .136 r
.67017 .16829 m .66349 .18453 L .68281 .17367 L F
.67017 .16829 m .65242 .17991 L .66349 .18453 L F
.24 .103 .023 r
.61813 .39851 m .59587 .38357 L .62525 .40103 L F
.61813 .39851 m .591 .38183 L .59587 .38357 L F
.942 .656 .201 r
.37168 .43273 m .39775 .42506 L .40115 .42127 L F
.607 .325 .095 r
.74846 .16747 m .74209 .17649 L .76004 .1758 L F
.74846 .16747 m .73129 .16883 L .74209 .17649 L F
0 0 0 r
.44477 .40083 m .47399 .38343 L .47891 .38171 L F
.761 .402 .118 r
.3876 .17325 m .40681 .18417 L .41799 .17958 L F
1 .814 .375 r
.32298 .44328 m .34765 .43664 L .32528 .43751 L F
1 .793 .385 r
.3021 .44215 m .32298 .44328 L .32528 .43751 L F
1 .983 .424 r
.84659 .39927 m .83553 .41823 L .84849 .40828 L F
1 .918 .362 r
.85791 .38771 m .84659 .39927 L .84849 .40828 L F
.731 .392 .112 r
.32816 .1759 m .35731 .17222 L .33913 .16828 L F
.696 .375 .106 r
.31025 .17516 m .32816 .1759 L .33913 .16828 L F
.451 .318 .125 r
.2098 .39649 m .22322 .3986 L .2119 .38701 L F
.2098 .39649 m .22106 .40761 L .22322 .3986 L F
1 .9 .441 r
.7847 .43236 m .76749 .44262 L .78684 .43927 L F
.7847 .43236 m .76535 .43627 L .76749 .44262 L F
.092 .045 .018 r
.86071 .23473 m .85943 .23479 L .86811 .24635 L F
.86071 .23473 m .85211 .22333 L .85943 .23479 L F
.289 .161 .049 r
.80665 .18631 m .80221 .19071 L .81687 .1966 L F
.80665 .18631 m .79238 .18089 L .80221 .19071 L F
1 1 .465 r
.83355 .40971 m .8209 .42685 L .83553 .41823 L F
1 .983 .424 r
.84659 .39927 m .83355 .40971 L .83553 .41823 L F
1 .966 .471 r
.80255 .42647 m .78684 .43927 L .80465 .43394 L F
.80255 .42647 m .7847 .43236 L .78684 .43927 L F
1 .793 .385 r
.3021 .44215 m .32528 .43751 L .30444 .4358 L F
.98 .745 .373 r
.28275 .43876 m .3021 .44215 L .30444 .4358 L F
.572 .406 .179 r
.22106 .40761 m .23625 .40908 L .22322 .3986 L F
.22106 .40761 m .23403 .4176 L .23625 .40908 L F
1 1 .48 r
.81885 .41885 m .80465 .43394 L .8209 .42685 L F
1 1 .465 r
.83355 .40971 m .81885 .41885 L .8209 .42685 L F
1 1 .48 r
.81885 .41885 m .80255 .42647 L .80465 .43394 L F
.477 .247 .065 r
.21051 .23393 m .22832 .21224 L .21811 .22248 L F
.419 .217 .056 r
.20183 .24548 m .21051 .23393 L .21811 .22248 L F
.612 .328 .089 r
.26794 .18997 m .29352 .17665 L .278 .18017 L F
.546 .289 .078 r
.2533 .19583 m .26794 .18997 L .278 .18017 L F
.689 .497 .236 r
.23403 .4176 m .25095 .41825 L .23625 .40908 L F
.23403 .4176 m .24867 .42626 L .25095 .41825 L F
.98 .745 .373 r
.28275 .43876 m .30444 .4358 L .28509 .43184 L F
.899 .675 .341 r
.26493 .43338 m .28275 .43876 L .28509 .43184 L F
.259 .111 .025 r
.61005 .3962 m .591 .38183 L .61813 .39851 L F
.61005 .3962 m .5855 .38024 L .591 .38183 L F
.801 .59 .293 r
.24867 .42626 m .26725 .42591 L .25095 .41825 L F
.24867 .42626 m .26493 .43338 L .26725 .42591 L F
.899 .675 .341 r
.26493 .43338 m .28509 .43184 L .26725 .42591 L F
.025 .011 .002 r
.45197 .39833 m .47891 .38171 L .48446 .38013 L F
0 0 0 r
.44477 .40083 m .47891 .38171 L .45197 .39833 L F
.968 .502 .141 r
.62618 .17198 m .62285 .19226 L .63994 .17571 L F
.62618 .17198 m .61127 .1892 L .62285 .19226 L F
.785 .409 .12 r
.43057 .17541 m .44751 .19202 L .45915 .18899 L F
.764 .399 .118 r
.41799 .17958 m .44751 .19202 L .43057 .17541 L F
.759 .54 .208 r
.71798 .43191 m .69806 .43306 L .72212 .43703 L F
.71798 .43191 m .69431 .42858 L .69806 .43306 L F
.228 .097 .024 r
.86762 .24711 m .86811 .24635 L .87509 .2588 L F
.86762 .24711 m .86071 .23473 L .86811 .24635 L F
.378 .265 .068 r
.65767 .41427 m .63634 .40658 L .6639 .41784 L F
.716 .384 .111 r
.71813 .16158 m .71304 .17272 L .73129 .16883 L F
.71813 .16158 m .70098 .16617 L .71304 .17272 L F
.942 .656 .201 r
.37168 .43273 m .40115 .42127 L .37557 .42825 L F
1 .731 .278 r
.34765 .43664 m .37168 .43273 L .37557 .42825 L F
.798 .523 .118 r
.40115 .42127 m .43352 .40636 L .40604 .41757 L F
.482 .259 .077 r
.76453 .16839 m .76004 .1758 L .77682 .17733 L F
.76453 .16839 m .74846 .16747 L .76004 .1758 L F
.749 .399 .116 r
.35731 .17222 m .3876 .17325 L .36952 .1657 L F
.729 .391 .112 r
.33913 .16828 m .35731 .17222 L .36952 .1657 L F
.419 .217 .056 r
.20183 .24548 m .21811 .22248 L .20952 .23387 L F
0 0 0 r
.19485 .25793 m .20183 .24548 L .20952 .23387 L F
.222 .125 .039 r
.81957 .19341 m .81687 .1966 L .83012 .20411 L F
.81957 .19341 m .80665 .18631 L .81687 .1966 L F
.275 .12 .027 r
.60109 .39414 m .5855 .38024 L .61005 .3962 L F
.60109 .39414 m .57942 .37882 L .5855 .38024 L F
.696 .375 .106 r
.31025 .17516 m .33913 .16828 L .32203 .16686 L F
.632 .34 .094 r
.29352 .17665 m .31025 .17516 L .32203 .16686 L F
.071 .031 .007 r
.46012 .39604 m .48446 .38013 L .49058 .37872 L F
.025 .011 .002 r
.45197 .39833 m .48446 .38013 L .46012 .39604 L F
.917 .482 .136 r
.65589 .16339 m .65242 .17991 L .67017 .16829 L F
.65589 .16339 m .63994 .17571 L .65242 .17991 L F
.539 .372 .095 r
.68877 .42421 m .66868 .42155 L .69431 .42858 L F
.68877 .42421 m .6639 .41784 L .66868 .42155 L F
.546 .289 .078 r
.2533 .19583 m .278 .18017 L .26377 .18555 L F
.497 .261 .07 r
.24007 .2033 m .2533 .19583 L .26377 .18555 L F
.828 .441 .125 r
.6869 .16008 m .68281 .17367 L .70098 .16617 L F
.6869 .16008 m .67017 .16829 L .68281 .17367 L F
.778 .41 .12 r
.40036 .1679 m .41799 .17958 L .43057 .17541 L F
.761 .402 .118 r
.3876 .17325 m .41799 .17958 L .40036 .1679 L F
.853 .571 .143 r
.37557 .42825 m .40115 .42127 L .40604 .41757 L F
.759 .404 .117 r
.36952 .1657 m .3876 .17325 L .40036 .1679 L F
.296 .132 .032 r
.8728 .26029 m .87509 .2588 L .88031 .27199 L F
.8728 .26029 m .86762 .24711 L .87509 .2588 L F
.959 .497 .14 r
.61129 .16879 m .61127 .1892 L .62618 .17198 L F
.61129 .16879 m .59878 .18658 L .61127 .1892 L F
.92 .682 .306 r
.74005 .43222 m .72212 .43703 L .7445 .43794 L F
.74005 .43222 m .71798 .43191 L .72212 .43703 L F
.804 .418 .122 r
.44442 .17173 m .45915 .18899 L .47171 .1864 L F
.785 .409 .12 r
.43057 .17541 m .45915 .18899 L .44442 .17173 L F
.101 .062 .02 r
.18222 .3048 m .18251 .31908 L .18834 .30777 L F
.287 .129 .029 r
.59136 .39234 m .57942 .37882 L .60109 .39414 L F
.59136 .39234 m .57284 .37759 L .57942 .37882 L F
.11 .047 .011 r
.46913 .39399 m .49058 .37872 L .49719 .3775 L F
.071 .031 .007 r
.46012 .39604 m .49058 .37872 L .46913 .39399 L F
1 .731 .278 r
.34765 .43664 m .37557 .42825 L .35193 .43153 L F
1 .781 .346 r
.32528 .43751 m .34765 .43664 L .35193 .43153 L F
0 0 0 r
.19485 .25793 m .20952 .23387 L .20262 .24624 L F
.18963 .27112 m .19485 .25793 L .20262 .24624 L F
.952 .604 .173 r
.88176 .30862 m .88514 .3342 L .88729 .31992 L F
.797 .476 .105 r
.88204 .29414 m .88176 .30862 L .88729 .31992 L F
.165 .09 .03 r
.83105 .20205 m .83012 .20411 L .84189 .21307 L F
.83105 .20205 m .81957 .19341 L .83012 .20411 L F
.357 .195 .058 r
.77944 .17141 m .77682 .17733 L .79238 .18089 L F
.77944 .17141 m .76453 .16839 L .77682 .17733 L F
.144 .088 .029 r
.18251 .31908 m .1905 .32233 L .18834 .30777 L F
.18251 .31908 m .18467 .33337 L .1905 .32233 L F
.292 .133 .03 r
.58096 .39084 m .57284 .37759 L .59136 .39234 L F
.58096 .39084 m .56583 .37655 L .57284 .37759 L F
.362 .167 .04 r
.87619 .27412 m .88031 .27199 L .88373 .28575 L F
.87619 .27412 m .8728 .26029 L .88031 .27199 L F
.143 .061 .014 r
.47892 .39222 m .49719 .3775 L .50424 .37649 L F
.11 .047 .011 r
.46913 .39399 m .49719 .3775 L .47892 .39222 L F
.594 .318 .093 r
.73428 .15956 m .73129 .16883 L .74846 .16747 L F
.73428 .15956 m .71813 .16158 L .73129 .16883 L F
1 .819 .399 r
.76064 .42996 m .7445 .43794 L .76535 .43627 L F
.76064 .42996 m .74005 .43222 L .7445 .43794 L F
.497 .261 .07 r
.24007 .2033 m .26377 .18555 L .25088 .19263 L F
.451 .238 .063 r
.22832 .21224 m .24007 .2033 L .25088 .19263 L F
.632 .34 .094 r
.29352 .17665 m .32203 .16686 L .30603 .16774 L F
.552 .295 .08 r
.278 .18017 m .29352 .17665 L .30603 .16774 L F
1 .753 .261 r
.8796 .32315 m .8811 .34829 L .88514 .3342 L F
.952 .604 .173 r
.88176 .30862 m .8796 .32315 L .88514 .3342 L F
.948 .49 .139 r
.59546 .16618 m .59878 .18658 L .61129 .16879 L F
.59546 .16618 m .58551 .18443 L .59878 .18658 L F
.729 .391 .112 r
.33913 .16828 m .36952 .1657 L .35247 .16106 L F
.675 .363 .102 r
.32203 .16686 m .33913 .16828 L .35247 .16106 L F
.823 .427 .125 r
.45938 .16858 m .47171 .1864 L .48503 .18429 L F
.804 .418 .122 r
.44442 .17173 m .47171 .1864 L .45938 .16858 L F
1 .781 .346 r
.32528 .43751 m .35193 .43153 L .3299 .4318 L F
1 .799 .391 r
.30444 .4358 m .32528 .43751 L .3299 .4318 L F
0 0 0 r
.18963 .27112 m .20262 .24624 L .19745 .25943 L F
.015 .007 .003 r
.18622 .28488 m .18963 .27112 L .19745 .25943 L F
.916 .481 .136 r
.6401 .15905 m .63994 .17571 L .65589 .16339 L F
.6401 .15905 m .62618 .17198 L .63994 .17571 L F
.292 .134 .031 r
.57002 .38964 m .56583 .37655 L .58096 .39084 L F
.57002 .38964 m .55845 .37574 L .56583 .37655 L F
.171 .073 .017 r
.48936 .39074 m .50424 .37649 L .51163 .37568 L F
.143 .061 .014 r
.47892 .39222 m .50424 .37649 L .48936 .39074 L F
.184 .114 .037 r
.18467 .33337 m .19452 .33678 L .1905 .32233 L F
.18467 .33337 m .1887 .3475 L .19452 .33678 L F
.707 .493 .166 r
.71179 .4269 m .69431 .42858 L .71798 .43191 L F
.71179 .4269 m .68877 .42421 L .69431 .42858 L F
.794 .418 .122 r
.41476 .16305 m .43057 .17541 L .44442 .17173 L F
.778 .41 .12 r
.40036 .1679 m .43057 .17541 L .41476 .16305 L F
1 .895 .352 r
.87558 .33757 m .8752 .36204 L .8811 .34829 L F
1 .753 .261 r
.8796 .32315 m .87558 .33757 L .8811 .34829 L F
1 .942 .48 r
.77979 .42547 m .76535 .43627 L .7847 .43236 L F
.77979 .42547 m .76064 .42996 L .76535 .43627 L F
.853 .571 .143 r
.37557 .42825 m .40604 .41757 L .38124 .42389 L F
.932 .661 .223 r
.35193 .43153 m .37557 .42825 L .38124 .42389 L F
.442 .208 .052 r
.87775 .28841 m .87619 .27412 L .88373 .28575 L F
.492 .345 .085 r
.68148 .41998 m .6639 .41784 L .68877 .42421 L F
.68148 .41998 m .65767 .41427 L .6639 .41784 L F
.715 .383 .11 r
.70271 .15482 m .70098 .16617 L .71813 .16158 L F
.70271 .15482 m .6869 .16008 L .70098 .16617 L F
.285 .131 .03 r
.55865 .38877 m .55845 .37574 L .57002 .38964 L F
.55865 .38877 m .55081 .37514 L .55845 .37574 L F
.194 .083 .019 r
.50034 .38956 m .51163 .37568 L .51929 .37511 L F
.171 .073 .017 r
.48936 .39074 m .51163 .37568 L .50034 .38956 L F
.097 .048 .019 r
.84103 .21207 m .84189 .21307 L .85211 .22333 L F
.84103 .21207 m .83105 .20205 L .84189 .21307 L F
.787 .52 .119 r
.38124 .42389 m .40604 .41757 L .41237 .41401 L F
1 .799 .391 r
.30444 .4358 m .3299 .4318 L .30934 .42949 L F
1 .784 .408 r
.28509 .43184 m .30444 .4358 L .30934 .42949 L F
.831 .442 .126 r
.67094 .15453 m .67017 .16829 L .6869 .16008 L F
.67094 .15453 m .65589 .16339 L .67017 .16829 L F
.936 .484 .137 r
.57886 .16418 m .58551 .18443 L .59546 .16618 L F
.57886 .16418 m .57162 .18279 L .58551 .18443 L F
.759 .404 .117 r
.36952 .1657 m .40036 .1679 L .38375 .15965 L F
.727 .39 .112 r
.35247 .16106 m .36952 .1657 L .38375 .15965 L F
.261 .174 .058 r
.1887 .3475 m .2004 .35092 L .19452 .33678 L F
.1887 .3475 m .1946 .36127 L .2004 .35092 L F
.841 .436 .127 r
.47528 .16601 m .48503 .18429 L .49896 .18269 L F
.823 .427 .125 r
.45938 .16858 m .48503 .18429 L .47528 .16601 L F
1 1 .445 r
.8697 .35168 m .86746 .37524 L .8752 .36204 L F
1 .895 .352 r
.87558 .33757 m .8697 .35168 L .8752 .36204 L F
.015 .007 .003 r
.18622 .28488 m .19745 .25943 L .19406 .27326 L F
.045 .023 .009 r
.18464 .29904 m .18622 .28488 L .19406 .27326 L F
.769 .409 .119 r
.38375 .15965 m .40036 .1679 L .41476 .16305 L F
.274 .125 .029 r
.547 .38824 m .55081 .37514 L .55865 .38877 L F
.547 .38824 m .54298 .37478 L .55081 .37514 L F
.216 .093 .021 r
.51173 .38872 m .51929 .37511 L .52713 .37476 L F
.194 .083 .019 r
.50034 .38956 m .51929 .37511 L .51173 .38872 L F
1 1 .547 r
.79747 .41902 m .7847 .43236 L .80255 .42647 L F
.79747 .41902 m .77979 .42547 L .7847 .43236 L F
.451 .238 .063 r
.22832 .21224 m .25088 .19263 L .23942 .20124 L F
0 0 0 r
.21811 .22248 m .22832 .21224 L .23942 .20124 L F
.255 .146 .044 r
.79314 .17635 m .79238 .18089 L .80665 .18631 L F
.79314 .17635 m .77944 .17141 L .79238 .18089 L F
.258 .116 .027 r
.5352 .38805 m .54298 .37478 L .547 .38824 L F
.5352 .38805 m .53506 .37465 L .54298 .37478 L F
.235 .102 .024 r
.5234 .38821 m .52713 .37476 L .53506 .37465 L F
.216 .093 .021 r
.51173 .38872 m .52713 .37476 L .5234 .38821 L F
.235 .102 .024 r
.5234 .38821 m .53506 .37465 L .5352 .38805 L F
1 1 .525 r
.86198 .3653 m .85791 .38771 L .86746 .37524 L F
1 1 .445 r
.8697 .35168 m .86198 .3653 L .86746 .37524 L F
1 .784 .408 r
.28509 .43184 m .30934 .42949 L .29022 .42496 L F
.967 .74 .399 r
.26725 .42591 m .28509 .43184 L .29022 .42496 L F
.366 .253 .102 r
.1946 .36127 m .20811 .36456 L .2004 .35092 L F
.1946 .36127 m .20234 .3745 L .20811 .36456 L F
1 1 .594 r
.81364 .41086 m .80255 .42647 L .81885 .41885 L F
.81364 .41086 m .79747 .41902 L .80255 .42647 L F
.552 .295 .08 r
.278 .18017 m .30603 .16774 L .29117 .17072 L F
.489 .259 .07 r
.26377 .18555 m .278 .18017 L .29117 .17072 L F
.922 .476 .136 r
.56171 .16282 m .57162 .18279 L .57886 .16418 L F
.56171 .16282 m .55728 .18168 L .57162 .18279 L F
.455 .245 .072 r
.74941 .1599 m .74846 .16747 L .76453 .16839 L F
.74941 .1599 m .73428 .15956 L .74846 .16747 L F
1 1 .582 r
.85247 .37822 m .84659 .39927 L .85791 .38771 L F
1 1 .525 r
.86198 .3653 m .85247 .37822 L .85791 .38771 L F
.858 .444 .129 r
.49193 .16405 m .49896 .18269 L .51332 .18161 L F
.841 .436 .127 r
.47528 .16601 m .49896 .18269 L .49193 .16405 L F
1 1 .617 r
.82824 .4012 m .81885 .41885 L .83355 .40971 L F
.82824 .4012 m .81364 .41086 L .81885 .41885 L F
.484 .34 .156 r
.20234 .3745 m .21761 .37751 L .20811 .36456 L F
.20234 .3745 m .2119 .38701 L .21761 .37751 L F
1 1 .613 r
.8412 .39025 m .83355 .40971 L .84659 .39927 L F
1 1 .582 r
.85247 .37822 m .8412 .39025 L .84659 .39927 L F
.967 .74 .399 r
.26725 .42591 m .29022 .42496 L .27255 .41847 L F
.893 .676 .37 r
.25095 .41825 m .26725 .42591 L .27255 .41847 L F
1 1 .613 r
.8412 .39025 m .82824 .4012 L .83355 .40971 L F
.913 .479 .136 r
.62299 .15532 m .62618 .17198 L .6401 .15905 L F
.62299 .15532 m .61129 .16879 L .62618 .17198 L F
.675 .363 .102 r
.32203 .16686 m .35247 .16106 L .3364 .15899 L F
.591 .317 .088 r
.30603 .16774 m .32203 .16686 L .3364 .15899 L F
.894 .656 .282 r
.73328 .4266 m .71798 .43191 L .74005 .43222 L F
.73328 .4266 m .71179 .4269 L .71798 .43191 L F
.809 .425 .124 r
.43065 .15875 m .44442 .17173 L .45938 .16858 L F
.794 .418 .122 r
.41476 .16305 m .44442 .17173 L .43065 .15875 L F
.218 .089 .022 r
.84944 .2233 m .85211 .22333 L .86071 .23473 L F
.84944 .2233 m .84103 .21207 L .85211 .22333 L F
.594 .424 .212 r
.2119 .38701 m .22887 .38958 L .21761 .37751 L F
.2119 .38701 m .22322 .3986 L .22887 .38958 L F
.893 .676 .37 r
.25095 .41825 m .27255 .41847 L .2564 .41027 L F
.803 .596 .325 r
.23625 .40908 m .25095 .41825 L .2564 .41027 L F
.907 .468 .134 r
.54422 .16212 m .55728 .18168 L .56171 .16282 L F
.54422 .16212 m .54267 .1811 L .55728 .18168 L F
.932 .661 .223 r
.35193 .43153 m .38124 .42389 L .35828 .42654 L F
1 .749 .319 r
.3299 .4318 m .35193 .43153 L .35828 .42654 L F
.875 .452 .13 r
.50911 .16274 m .51332 .18161 L .52795 .18108 L F
.858 .444 .129 r
.49193 .16405 m .51332 .18161 L .50911 .16274 L F
.701 .51 .27 r
.22322 .3986 m .24182 .40057 L .22887 .38958 L F
.22322 .3986 m .23625 .40908 L .24182 .40057 L F
.803 .596 .325 r
.23625 .40908 m .2564 .41027 L .24182 .40057 L F
.891 .46 .132 r
.52661 .1621 m .54267 .1811 L .54422 .16212 L F
.52661 .1621 m .52795 .18108 L .54267 .1811 L F
.875 .452 .13 r
.50911 .16274 m .52795 .18108 L .52661 .1621 L F
0 0 0 r
.21811 .22248 m .23942 .20124 L .22947 .21124 L F
.20952 .23387 m .21811 .22248 L .22947 .21124 L F
.448 .32 .079 r
.67249 .41596 m .65767 .41427 L .68148 .41998 L F
.67249 .41596 m .65004 .41088 L .65767 .41427 L F
.198 .111 .035 r
.80555 .18305 m .80665 .18631 L .81957 .19341 L F
.80555 .18305 m .79314 .17635 L .80665 .18631 L F
.73 .487 .111 r
.38865 .41967 m .41237 .41401 L .42011 .41063 L F
.787 .52 .119 r
.38124 .42389 m .41237 .41401 L .38865 .41967 L F
.582 .312 .091 r
.71761 .15219 m .71813 .16158 L .73428 .15956 L F
.71761 .15219 m .70271 .15482 L .71813 .16158 L F
.662 .455 .133 r
.70356 .42206 m .68877 .42421 L .71179 .4269 L F
.70356 .42206 m .68148 .41998 L .68877 .42421 L F
.833 .443 .126 r
.65326 .1496 m .65589 .16339 L .67094 .15453 L F
.65326 .1496 m .6401 .15905 L .65589 .16339 L F
.489 .259 .07 r
.26377 .18555 m .29117 .17072 L .27752 .17562 L F
.439 .234 .063 r
.25088 .19263 m .26377 .18555 L .27752 .17562 L F
.727 .39 .112 r
.35247 .16106 m .38375 .15965 L .36805 .15434 L F
.655 .353 .099 r
.3364 .15899 m .35247 .16106 L .36805 .15434 L F
.868 .599 .176 r
.35828 .42654 m .38124 .42389 L .38865 .41967 L F
.778 .414 .12 r
.39985 .15414 m .41476 .16305 L .43065 .15875 L F
.769 .409 .119 r
.38375 .15965 m .41476 .16305 L .39985 .15414 L F
.288 .125 .03 r
.8562 .23559 m .86071 .23473 L .86762 .24711 L F
.8562 .23559 m .84944 .2233 L .86071 .23473 L F
1 .825 .404 r
.75337 .42376 m .74005 .43222 L .76064 .42996 L F
.75337 .42376 m .73328 .4266 L .74005 .43222 L F
.908 .476 .135 r
.60477 .15226 m .61129 .16879 L .62299 .15532 L F
.60477 .15226 m .59546 .16618 L .61129 .16879 L F
.823 .432 .126 r
.44785 .15507 m .45938 .16858 L .47528 .16601 L F
.809 .425 .124 r
.43065 .15875 m .45938 .16858 L .44785 .15507 L F
.714 .383 .11 r
.68517 .14866 m .6869 .16008 L .70271 .15482 L F
.68517 .14866 m .67094 .15453 L .6869 .16008 L F
1 .749 .319 r
.3299 .4318 m .35828 .42654 L .33684 .42619 L F
1 .805 .396 r
.30934 .42949 m .3299 .4318 L .33684 .42619 L F
.326 .181 .054 r
.76348 .16238 m .76453 .16839 L .77944 .17141 L F
.76348 .16238 m .74941 .1599 L .76453 .16839 L F
.724 .389 .111 r
.36805 .15434 m .38375 .15965 L .39985 .15414 L F
0 0 0 r
.20952 .23387 m .22947 .21124 L .22108 .22246 L F
.20262 .24624 m .20952 .23387 L .22108 .22246 L F
.591 .317 .088 r
.30603 .16774 m .3364 .15899 L .32135 .15928 L F
.501 .267 .073 r
.29117 .17072 m .30603 .16774 L .32135 .15928 L F
.179 .077 .018 r
.61948 .4022 m .60109 .39414 L .61005 .3962 L F
.118 .041 .011 r
.8166 .19137 m .81957 .19341 L .83105 .20205 L F
.8166 .19137 m .80555 .18305 L .81957 .19341 L F
1 .98 .516 r
.77207 .41869 m .76064 .42996 L .77979 .42547 L F
.77207 .41869 m .75337 .42376 L .76064 .42996 L F
.359 .162 .04 r
.86126 .24877 m .86762 .24711 L .8728 .26029 L F
.86126 .24877 m .8562 .23559 L .86762 .24711 L F
.901 .472 .135 r
.58564 .14992 m .59546 .16618 L .60477 .15226 L F
.58564 .14992 m .57886 .16418 L .59546 .16618 L F
.837 .439 .127 r
.46616 .15206 m .47528 .16601 L .49193 .16405 L F
.823 .432 .126 r
.44785 .15507 m .47528 .16601 L .46616 .15206 L F
1 .805 .396 r
.30934 .42949 m .33684 .42619 L .3168 .4233 L F
1 .821 .44 r
.29022 .42496 m .30934 .42949 L .3168 .4233 L F
.439 .234 .063 r
.25088 .19263 m .27752 .17562 L .26516 .1823 L F
0 0 0 r
.23942 .20124 m .25088 .19263 L .26516 .1823 L F
.426 .304 .075 r
.66188 .4122 m .65004 .41088 L .67249 .41596 L F
.141 .086 .028 r
.18806 .29329 m .18834 .30777 L .19824 .29657 L F
0 0 0 r
.20262 .24624 m .22108 .22246 L .21434 .23474 L F
.015 .007 .003 r
.19745 .25943 m .20262 .24624 L .21434 .23474 L F
.73 .487 .111 r
.38865 .41967 m .42011 .41063 L .39777 .41567 L F
.833 .443 .126 r
.63406 .14536 m .6401 .15905 L .65326 .1496 L F
.63406 .14536 m .62299 .15532 L .6401 .15905 L F
.87 .632 .259 r
.72421 .42117 m .71179 .4269 L .73328 .4266 L F
.72421 .42117 m .70356 .42206 L .71179 .4269 L F
.191 .082 .019 r
.6071 .39993 m .60109 .39414 L .61948 .4022 L F
.6071 .39993 m .59136 .39234 L .60109 .39414 L F
.787 .418 .121 r
.41765 .14926 m .43065 .15875 L .44785 .15507 L F
.778 .414 .12 r
.39985 .15414 m .43065 .15875 L .41765 .14926 L F
1 .888 .378 r
.87217 .2974 m .8796 .32315 L .88176 .30862 L F
1 .716 .271 r
.87245 .28272 m .87217 .2974 L .88176 .30862 L F
.431 .232 .068 r
.73159 .15196 m .73428 .15956 L .74941 .1599 L F
.73159 .15196 m .71761 .15219 L .73428 .15956 L F
.868 .599 .176 r
.35828 .42654 m .38865 .41967 L .36666 .42171 L F
.975 .717 .292 r
.33684 .42619 m .35828 .42654 L .36666 .42171 L F
1 1 .614 r
.78937 .41169 m .77979 .42547 L .79747 .41902 L F
.78937 .41169 m .77207 .41869 L .77979 .42547 L F
.893 .467 .134 r
.56586 .14833 m .57886 .16418 L .58564 .14992 L F
.56586 .14833 m .56171 .16282 L .57886 .16418 L F
.655 .353 .099 r
.3364 .15899 m .36805 .15434 L .35325 .15167 L F
.552 .296 .082 r
.32135 .15928 m .3364 .15899 L .35325 .15167 L F
.85 .445 .129 r
.48534 .14978 m .49193 .16405 L .50911 .16274 L F
.837 .439 .127 r
.46616 .15206 m .49193 .16405 L .48534 .14978 L F
.239 .137 .042 r
.77641 .16686 m .77944 .17141 L .79314 .17635 L F
.77641 .16686 m .76348 .16238 L .77944 .17141 L F
.471 .215 .054 r
.86458 .26266 m .8728 .26029 L .87619 .27412 L F
.86458 .26266 m .86126 .24877 L .8728 .26029 L F
.626 .427 .111 r
.69335 .41745 m .68148 .41998 L .70356 .42206 L F
.69335 .41745 m .67249 .41596 L .68148 .41998 L F
.192 .12 .038 r
.18834 .30777 m .20036 .31139 L .19824 .29657 L F
.18834 .30777 m .1905 .32233 L .20036 .31139 L F
1 .821 .44 r
.29022 .42496 m .3168 .4233 L .29814 .41819 L F
1 .801 .453 r
.27255 .41847 m .29022 .42496 L .29814 .41819 L F
.813 .549 .142 r
.36666 .42171 m .38865 .41967 L .39777 .41567 L F
.501 .267 .073 r
.29117 .17072 m .32135 .15928 L .30736 .16173 L F
.444 .238 .065 r
.27752 .17562 m .29117 .17072 L .30736 .16173 L F
1 1 .485 r
.87004 .3122 m .87558 .33757 L .8796 .32315 L F
1 .888 .378 r
.87217 .2974 m .87004 .3122 L .8796 .32315 L F
.713 .382 .11 r
.66571 .14317 m .67094 .15453 L .68517 .14866 L F
.66571 .14317 m .65326 .1496 L .67094 .15453 L F
.188 .072 .019 r
.8262 .20114 m .83105 .20205 L .84103 .21207 L F
.8262 .20114 m .8166 .19137 L .83105 .20205 L F
.015 .007 .003 r
.19745 .25943 m .21434 .23474 L .20928 .24792 L F
.045 .022 .009 r
.19406 .27326 m .19745 .25943 L .20928 .24792 L F
.571 .306 .089 r
.69861 .14546 m .70271 .15482 L .71761 .15219 L F
.69861 .14546 m .68517 .14866 L .70271 .15482 L F
.884 .462 .133 r
.54568 .14751 m .56171 .16282 L .56586 .14833 L F
.54568 .14751 m .54422 .16212 L .56171 .16282 L F
.862 .451 .13 r
.50516 .14824 m .50911 .16274 L .52661 .1621 L F
.85 .445 .129 r
.48534 .14978 m .50911 .16274 L .50516 .14824 L F
1 1 .69 r
.80522 .40298 m .79747 .41902 L .81364 .41086 L F
.80522 .40298 m .78937 .41169 L .79747 .41902 L F
.722 .387 .111 r
.38574 .14822 m .39985 .15414 L .41765 .14926 L F
.724 .389 .111 r
.36805 .15434 m .39985 .15414 L .38574 .14822 L F
.196 .084 .019 r
.59384 .39802 m .59136 .39234 L .6071 .39993 L F
.59384 .39802 m .58096 .39084 L .59136 .39234 L F
.636 .342 .097 r
.35325 .15167 m .36805 .15434 L .38574 .14822 L F
.3 .196 .073 r
.1905 .32233 m .20431 .32616 L .20036 .31139 L F
.1905 .32233 m .19452 .33678 L .20431 .32616 L F
0 0 0 r
.23942 .20124 m .26516 .1823 L .25415 .19059 L F
.22947 .21124 m .23942 .20124 L .25415 .19059 L F
.873 .457 .131 r
.52536 .14748 m .54422 .16212 L .54568 .14751 L F
.52536 .14748 m .52661 .1621 L .54422 .16212 L F
.862 .451 .13 r
.50516 .14824 m .52661 .1621 L .52536 .14748 L F
1 1 .585 r
.86608 .32694 m .8697 .35168 L .87558 .33757 L F
1 1 .485 r
.87004 .3122 m .86608 .32694 L .87558 .33757 L F
1 .801 .453 r
.27255 .41847 m .29814 .41819 L .28088 .41115 L F
.976 .754 .439 r
.2564 .41027 m .27255 .41847 L .28088 .41115 L F
.597 .277 .071 r
.86611 .27709 m .86458 .26266 L .87619 .27412 L F
1 1 .74 r
.81953 .39279 m .81364 .41086 L .82824 .4012 L F
.81953 .39279 m .80522 .40298 L .81364 .41086 L F
.833 .442 .126 r
.61358 .14189 m .62299 .15532 L .63406 .14536 L F
.61358 .14189 m .60477 .15226 L .62299 .15532 L F
.403 .288 .071 r
.64975 .40874 m .64106 .40771 L .66188 .4122 L F
1 .829 .409 r
.74354 .41774 m .73328 .4266 L .75337 .42376 L F
.74354 .41774 m .72421 .42117 L .73328 .4266 L F
1 1 .667 r
.86029 .34143 m .86198 .3653 L .8697 .35168 L F
1 1 .585 r
.86608 .32694 m .86029 .34143 L .8697 .35168 L F
.795 .422 .122 r
.43695 .14508 m .44785 .15507 L .46616 .15206 L F
.787 .418 .121 r
.41765 .14926 m .44785 .15507 L .43695 .14508 L F
.41 .278 .123 r
.19452 .33678 m .2101 .34067 L .20431 .32616 L F
.19452 .33678 m .2004 .35092 L .2101 .34067 L F
.669 .452 .103 r
.39777 .41567 m .42918 .40748 L .4085 .41193 L F
.045 .022 .009 r
.19406 .27326 m .20928 .24792 L .20597 .26182 L F
.07 .035 .014 r
.1925 .28756 m .19406 .27326 L .20597 .26182 L F
.976 .754 .439 r
.2564 .41027 m .28088 .41115 L .26507 .4024 L F
.902 .687 .404 r
.24182 .40057 m .2564 .41027 L .26507 .4024 L F
1 1 .762 r
.83226 .38134 m .82824 .4012 L .8412 .39025 L F
.83226 .38134 m .81953 .39279 L .82824 .4012 L F
.975 .717 .292 r
.33684 .42619 m .36666 .42171 L .34608 .42077 L F
1 .81 .4 r
.3168 .4233 m .33684 .42619 L .34608 .42077 L F
1 1 .725 r
.85269 .35545 m .85247 .37822 L .86198 .3653 L F
1 1 .667 r
.86029 .34143 m .85269 .35545 L .86198 .3653 L F
.198 .085 .019 r
.57987 .39651 m .58096 .39084 L .59384 .39802 L F
.57987 .39651 m .57002 .38964 L .58096 .39084 L F
1 1 .758 r
.84333 .36882 m .8412 .39025 L .85247 .37822 L F
.84333 .36882 m .83226 .38134 L .8412 .39025 L F
1 1 .725 r
.85269 .35545 m .84333 .36882 L .85247 .37822 L F
.517 .361 .18 r
.2004 .35092 m .21768 .35473 L .2101 .34067 L F
.2004 .35092 m .20811 .36456 L .21768 .35473 L F
.902 .687 .404 r
.24182 .40057 m .26507 .4024 L .25078 .39217 L F
.815 .608 .355 r
.22887 .38958 m .24182 .40057 L .25078 .39217 L F
.17 .094 .03 r
.78813 .17318 m .79314 .17635 L .80555 .18305 L F
.78813 .17318 m .77641 .16686 L .79314 .17635 L F
.263 .111 .027 r
.8343 .2122 m .84103 .21207 L .84944 .2233 L F
.8343 .2122 m .8262 .20114 L .84103 .21207 L F
.305 .171 .051 r
.7446 .15395 m .74941 .1599 L .76348 .16238 L F
.7446 .15395 m .73159 .15196 L .74941 .1599 L F
.619 .441 .238 r
.20811 .36456 m .22702 .36813 L .21768 .35473 L F
.20811 .36456 m .21761 .37751 L .22702 .36813 L F
.815 .608 .355 r
.22887 .38958 m .25078 .39217 L .23807 .38068 L F
.719 .524 .298 r
.21761 .37751 m .22887 .38958 L .23807 .38068 L F
.21761 .37751 m .23807 .38068 L .22702 .36813 L F
.552 .296 .082 r
.32135 .15928 m .35325 .15167 L .33936 .1514 L F
.462 .247 .068 r
.30736 .16173 m .32135 .15928 L .33936 .1514 L F
.444 .238 .065 r
.27752 .17562 m .30736 .16173 L .29449 .16618 L F
.369 .201 .054 r
.26516 .1823 m .27752 .17562 L .29449 .16618 L F
.195 .083 .019 r
.56534 .3954 m .57002 .38964 L .57987 .39651 L F
.56534 .3954 m .55865 .38877 L .57002 .38964 L F
0 0 0 r
.22947 .21124 m .25415 .19059 L .24458 .20034 L F
.22108 .22246 m .22947 .21124 L .24458 .20034 L F
.127 .055 .012 r
.49072 .39641 m .50034 .38956 L .51173 .38872 L F
.847 .61 .239 r
.71289 .41598 m .70356 .42206 L .72421 .42117 L F
.71289 .41598 m .69335 .41745 L .70356 .42206 L F
.831 .441 .126 r
.59206 .13922 m .60477 .15226 L .61358 .14189 L F
.59206 .13922 m .58564 .14992 L .60477 .15226 L F
.599 .409 .099 r
.68125 .41312 m .67249 .41596 L .69335 .41745 L F
.68125 .41312 m .66188 .4122 L .67249 .41596 L F
.712 .382 .11 r
.64455 .13846 m .65326 .1496 L .66571 .14317 L F
.64455 .13846 m .63406 .14536 L .65326 .1496 L F
.802 .426 .123 r
.45752 .14166 m .46616 .15206 L .48534 .14978 L F
.795 .422 .122 r
.43695 .14508 m .46616 .15206 L .45752 .14166 L F
.768 .512 .121 r
.37701 .41711 m .39777 .41567 L .4085 .41193 L F
.813 .549 .142 r
.36666 .42171 m .39777 .41567 L .37701 .41711 L F
.944 .687 .268 r
.34608 .42077 m .36666 .42171 L .37701 .41711 L F
1 1 .548 r
.76157 .41211 m .75337 .42376 L .77207 .41869 L F
.76157 .41211 m .74354 .41774 L .75337 .42376 L F
.72 .386 .111 r
.40533 .1428 m .41765 .14926 L .43695 .14508 L F
.722 .387 .111 r
.38574 .14822 m .41765 .14926 L .40533 .1428 L F
.188 .081 .018 r
.55043 .39473 m .55865 .38877 L .56534 .3954 L F
.55043 .39473 m .547 .38824 L .55865 .38877 L F
.148 .063 .014 r
.50529 .39534 m .51173 .38872 L .5234 .38821 L F
.381 .273 .067 r
.63622 .40564 m .63084 .4048 L .64975 .40874 L F
.411 .222 .065 r
.71123 .14471 m .71761 .15219 L .73159 .15196 L F
.71123 .14471 m .69861 .14546 L .71761 .15219 L F
1 .81 .4 r
.3168 .4233 m .34608 .42077 L .32682 .4173 L F
1 .856 .471 r
.29814 .41819 m .3168 .4233 L .32682 .4173 L F
.178 .076 .017 r
.53533 .39449 m .547 .38824 L .55043 .39473 L F
.53533 .39449 m .5352 .38805 L .547 .38824 L F
.165 .071 .016 r
.52022 .3947 m .5234 .38821 L .5352 .38805 L F
.148 .063 .014 r
.50529 .39534 m .5234 .38821 L .52022 .3947 L F
.604 .414 .094 r
.4085 .41193 m .43949 .4046 L .42074 .4085 L F
.165 .071 .016 r
.52022 .3947 m .5352 .38805 L .53533 .39449 L F
.562 .302 .087 r
.67748 .13946 m .68517 .14866 L .69861 .14546 L F
.67748 .13946 m .66571 .14317 L .68517 .14866 L F
.636 .342 .097 r
.35325 .15167 m .38574 .14822 L .37242 .14498 L F
.516 .277 .077 r
.33936 .1514 m .35325 .15167 L .37242 .14498 L F
.344 .151 .037 r
.84081 .22441 m .84944 .2233 L .8562 .23559 L F
.84081 .22441 m .8343 .2122 L .84944 .2233 L F
.618 .333 .094 r
.37242 .14498 m .38574 .14822 L .40533 .1428 L F
.828 .439 .126 r
.5698 .13741 m .58564 .14992 L .59206 .13922 L F
.5698 .13741 m .56586 .14833 L .58564 .14992 L F
.809 .429 .124 r
.4791 .13906 m .48534 .14978 L .50516 .14824 L F
.802 .426 .123 r
.45752 .14166 m .48534 .14978 L .4791 .13906 L F
0 0 0 r
.22108 .22246 m .24458 .20034 L .23651 .2114 L F
.01 .005 .002 r
.21434 .23474 m .22108 .22246 L .23651 .2114 L F
.145 .051 .014 r
.79858 .18117 m .80555 .18305 L .8166 .19137 L F
.79858 .18117 m .78813 .17318 L .80555 .18305 L F
1 1 .671 r
.77827 .40455 m .77207 .41869 L .78937 .41169 L F
.77827 .40455 m .76157 .41211 L .77207 .41869 L F
.369 .201 .054 r
.26516 .1823 m .29449 .16618 L .28282 .17246 L F
0 0 0 r
.25415 .19059 m .26516 .1823 L .28282 .17246 L F
.221 .126 .039 r
.75657 .15799 m .76348 .16238 L .77641 .16686 L F
.75657 .15799 m .7446 .15395 L .76348 .16238 L F
.824 .437 .126 r
.54706 .13648 m .56586 .14833 L .5698 .13741 L F
.54706 .13648 m .54568 .14751 L .56586 .14833 L F
1 .856 .471 r
.29814 .41819 m .32682 .4173 L .30885 .41163 L F
1 .856 .502 r
.28088 .41115 m .29814 .41819 L .30885 .41163 L F
.815 .432 .125 r
.50141 .13731 m .50516 .14824 L .52536 .14748 L F
.809 .429 .124 r
.4791 .13906 m .50516 .14824 L .50141 .13731 L F
.462 .247 .068 r
.30736 .16173 m .33936 .1514 L .32644 .15335 L F
.394 .215 .058 r
.29449 .16618 m .30736 .16173 L .32644 .15335 L F
.712 .382 .11 r
.62193 .13459 m .63406 .14536 L .64455 .13846 L F
.62193 .13459 m .61358 .14189 L .63406 .14536 L F
.072 .031 .007 r
.62145 .40293 m .61948 .4022 L .6343 .40525 L F
.62145 .40293 m .6071 .39993 L .61948 .4022 L F
.081 .035 .008 r
.6056 .40065 m .6071 .39993 L .62145 .40293 L F
.538 .376 .09 r
.61659 .3998 m .60784 .40048 L .62145 .40293 L F
.60784 .40048 m .6056 .40065 L .62145 .40293 L F
.072 .031 .007 r
.62145 .40293 m .6343 .40525 L .63622 .40564 L F
.471 .209 .053 r
.84569 .23757 m .8562 .23559 L .86126 .24877 L F
.84569 .23757 m .84081 .22441 L .8562 .23559 L F
.718 .385 .111 r
.42662 .13814 m .43695 .14508 L .45752 .14166 L F
.72 .386 .111 r
.40533 .1428 m .43695 .14508 L .42662 .13814 L F
1 .834 .413 r
.73121 .41199 m .72421 .42117 L .74354 .41774 L F
.73121 .41199 m .71289 .41598 L .72421 .42117 L F
.82 .435 .125 r
.52417 .13645 m .54568 .14751 L .54706 .13648 L F
.52417 .13645 m .52536 .14748 L .54568 .14751 L F
.815 .432 .125 r
.50141 .13731 m .52536 .14748 L .52417 .13645 L F
.58 .398 .096 r
.66736 .40914 m .66188 .4122 L .68125 .41312 L F
.66736 .40914 m .64975 .40874 L .66188 .4122 L F
.944 .687 .268 r
.34608 .42077 m .37701 .41711 L .35757 .4156 L F
1 .816 .405 r
.32682 .4173 m .34608 .42077 L .35757 .4156 L F
.01 .005 .002 r
.21434 .23474 m .23651 .2114 L .23002 .22359 L F
.041 .02 .008 r
.20928 .24792 m .21434 .23474 L .23002 .22359 L F
.732 .489 .113 r
.38925 .41281 m .4085 .41193 L .42074 .4085 L F
.768 .512 .121 r
.37701 .41711 m .4085 .41193 L .38925 .41281 L F
1 1 .765 r
.79358 .3953 m .78937 .41169 L .80522 .40298 L F
.79358 .3953 m .77827 .40455 L .78937 .41169 L F
.242 .145 .045 r
.19796 .28188 m .19824 .29657 L .21223 .28561 L F
.827 .59 .22 r
.69942 .41111 m .69335 .41745 L .71289 .41598 L F
.69942 .41111 m .68125 .41312 L .69335 .41745 L F
1 .856 .502 r
.28088 .41115 m .30885 .41163 L .29221 .40403 L F
1 .822 .498 r
.26507 .4024 m .28088 .41115 L .29221 .40403 L F
.224 .09 .023 r
.80767 .1907 m .8166 .19137 L .8262 .20114 L F
.80767 .1907 m .79858 .18117 L .8166 .19137 L F
.286 .163 .048 r
.72299 .14623 m .73159 .15196 L .7446 .15395 L F
.72299 .14623 m .71123 .14471 L .73159 .15196 L F
.916 .659 .245 r
.35757 .4156 m .37701 .41711 L .38925 .41281 L F
1 1 .556 r
.85848 .28642 m .87004 .3122 L .87217 .2974 L F
1 .944 .444 r
.85875 .27154 m .85848 .28642 L .87217 .2974 L F
.555 .298 .086 r
.65447 .13431 m .66571 .14317 L .67748 .13946 L F
.65447 .13431 m .64455 .13846 L .66571 .14317 L F
.516 .277 .077 r
.33936 .1514 m .37242 .14498 L .35991 .1442 L F
.43 .232 .064 r
.32644 .15335 m .33936 .1514 L .35991 .1442 L F
.607 .274 .07 r
.84889 .25153 m .86126 .24877 L .86458 .26266 L F
.84889 .25153 m .84569 .23757 L .86126 .24877 L F
0 0 0 r
.25415 .19059 m .28282 .17246 L .27243 .18044 L F
.24458 .20034 m .25415 .19059 L .27243 .18044 L F
.602 .324 .092 r
.3937 .13905 m .40533 .1428 L .42662 .13814 L F
.618 .333 .094 r
.37242 .14498 m .40533 .1428 L .3937 .13905 L F
1 1 .829 r
.80743 .38459 m .80522 .40298 L .81953 .39279 L F
.80743 .38459 m .79358 .3953 L .80522 .40298 L F
.081 .035 .008 r
.6056 .40065 m .59384 .39802 L .6071 .39993 L F
.395 .215 .062 r
.68855 .13825 m .69861 .14546 L .71123 .14471 L F
.68855 .13825 m .67748 .13946 L .69861 .14546 L F
.342 .217 .082 r
.19824 .29657 m .21428 .3007 L .21223 .28561 L F
.19824 .29657 m .20036 .31139 L .21428 .3007 L F
.712 .382 .11 r
.59816 .13162 m .61358 .14189 L .62193 .13459 L F
.59816 .13162 m .59206 .13922 L .61358 .14189 L F
.717 .385 .11 r
.44933 .13434 m .45752 .14166 L .4791 .13906 L F
.718 .385 .111 r
.42662 .13814 m .45752 .14166 L .44933 .13434 L F
.041 .02 .008 r
.20928 .24792 m .23002 .22359 L .22515 .23676 L F
.085 .039 .015 r
.20597 .26182 m .20928 .24792 L .22515 .23676 L F
1 .822 .498 r
.26507 .4024 m .29221 .40403 L .27695 .39474 L F
.986 .765 .47 r
.25078 .39217 m .26507 .4024 L .27695 .39474 L F
.108 .038 .01 r
.76744 .16392 m .77641 .16686 L .78813 .17318 L F
.76744 .16392 m .75657 .15799 L .77641 .16686 L F
.486 .261 .073 r
.35991 .1442 m .37242 .14498 L .3937 .13905 L F
1 1 .659 r
.85642 .30149 m .86608 .32694 L .87004 .3122 L F
1 1 .556 r
.85848 .28642 m .85642 .30149 L .87004 .3122 L F
1 1 .577 r
.74833 .40581 m .74354 .41774 L .76157 .41211 L F
.74833 .40581 m .73121 .41199 L .74354 .41774 L F
1 1 .864 r
.81976 .37264 m .81953 .39279 L .83226 .38134 L F
.81976 .37264 m .80743 .38459 L .81953 .39279 L F
.394 .215 .058 r
.29449 .16618 m .32644 .15335 L .31455 .15735 L F
0 0 0 r
.28282 .17246 m .29449 .16618 L .31455 .15735 L F
.443 .294 .132 r
.20036 .31139 m .21813 .31578 L .21428 .3007 L F
.20036 .31139 m .20431 .32616 L .21813 .31578 L F
1 1 .745 r
.85257 .31654 m .86029 .34143 L .86608 .32694 L F
1 1 .659 r
.85642 .30149 m .85257 .31654 L .86608 .32694 L F
1 .816 .405 r
.32682 .4173 m .35757 .4156 L .33933 .41158 L F
1 .889 .5 r
.30885 .41163 m .32682 .4173 L .33933 .41158 L F
.728 .334 .086 r
.85037 .26609 m .84889 .25153 L .86458 .26266 L F
.986 .765 .47 r
.25078 .39217 m .27695 .39474 L .26314 .384 L F
.909 .692 .425 r
.23807 .38068 m .25078 .39217 L .26314 .384 L F
1 1 .871 r
.83049 .35965 m .83226 .38134 L .84333 .36882 L F
.83049 .35965 m .81976 .37264 L .83226 .38134 L F
.563 .389 .093 r
.65184 .40556 m .64975 .40874 L .66736 .40914 L F
.65184 .40556 m .63622 .40564 L .64975 .40874 L F
1 1 .81 r
.84694 .33139 m .85269 .35545 L .86029 .34143 L F
1 1 .745 r
.85257 .31654 m .84694 .33139 L .86029 .34143 L F
.085 .036 .008 r
.58886 .39884 m .59384 .39802 L .6056 .40065 L F
.58886 .39884 m .57987 .39651 L .59384 .39802 L F
.7 .47 .109 r
.40327 .40886 m .42074 .4085 L .43436 .40542 L F
.732 .489 .113 r
.38925 .41281 m .42074 .4085 L .40327 .40886 L F
.302 .128 .032 r
.81534 .2016 m .8262 .20114 L .8343 .2122 L F
.81534 .2016 m .80767 .1907 L .8262 .20114 L F
1 1 .852 r
.83957 .34583 m .84333 .36882 L .85269 .35545 L F
.83957 .34583 m .83049 .35965 L .84333 .36882 L F
.541 .371 .189 r
.20431 .32616 m .22374 .33066 L .21813 .31578 L F
.20431 .32616 m .2101 .34067 L .22374 .33066 L F
1 1 .81 r
.84694 .33139 m .83957 .34583 L .85269 .35545 L F
.712 .382 .11 r
.57353 .1296 m .59206 .13922 L .59816 .13162 L F
.57353 .1296 m .5698 .13741 L .59206 .13922 L F
.085 .039 .015 r
.20597 .26182 m .22515 .23676 L .22196 .25072 L F
.127 .058 .021 r
.20445 .27626 m .20597 .26182 L .22196 .25072 L F
.909 .692 .425 r
.23807 .38068 m .26314 .384 L .25085 .372 L F
.822 .612 .37 r
.22702 .36813 m .23807 .38068 L .25085 .372 L F
.715 .384 .11 r
.47318 .13143 m .4791 .13906 L .50141 .13731 L F
.717 .385 .11 r
.44933 .13434 m .4791 .13906 L .47318 .13143 L F
.635 .447 .247 r
.2101 .34067 m .23109 .34512 L .22374 .33066 L F
.2101 .34067 m .21768 .35473 L .23109 .34512 L F
0 0 0 r
.24458 .20034 m .27243 .18044 L .26338 .18995 L F
.001 .001 0 r
.23651 .2114 m .24458 .20034 L .26338 .18995 L F
.822 .612 .37 r
.22702 .36813 m .25085 .372 L .24014 .35898 L F
.73 .529 .309 r
.21768 .35473 m .22702 .36813 L .24014 .35898 L F
.21768 .35473 m .24014 .35898 L .23109 .34512 L F
.549 .295 .085 r
.62984 .13006 m .64455 .13846 L .65447 .13431 L F
.62984 .13006 m .62193 .13459 L .64455 .13846 L F
1 .838 .417 r
.71648 .40658 m .71289 .41598 L .73121 .41199 L F
.71648 .40658 m .69942 .41111 L .71289 .41598 L F
.587 .316 .09 r
.41684 .13396 m .42662 .13814 L .44933 .13434 L F
.602 .324 .092 r
.3937 .13905 m .42662 .13814 L .41684 .13396 L F
.202 .116 .035 r
.73381 .14985 m .7446 .15395 L .75657 .15799 L F
.73381 .14985 m .72299 .14623 L .7446 .15395 L F
.085 .036 .008 r
.57145 .39753 m .57987 .39651 L .58886 .39884 L F
.57145 .39753 m .56534 .3954 L .57987 .39651 L F
.809 .572 .204 r
.68391 .40662 m .68125 .41312 L .69942 .41111 L F
.68391 .40662 m .66736 .40914 L .68125 .41312 L F
.712 .382 .11 r
.54837 .12856 m .5698 .13741 L .57353 .1296 L F
.54837 .12856 m .54706 .13648 L .5698 .13741 L F
1 1 .717 r
.76419 .39771 m .76157 .41211 L .77827 .40455 L F
.76419 .39771 m .74833 .40581 L .76157 .41211 L F
.916 .659 .245 r
.35757 .4156 m .38925 .41281 L .37119 .41076 L F
1 .821 .409 r
.33933 .41158 m .35757 .4156 L .37119 .41076 L F
.714 .383 .11 r
.49786 .12949 m .50141 .13731 L .52417 .13645 L F
.715 .384 .11 r
.47318 .13143 m .50141 .13731 L .49786 .12949 L F
.43 .232 .064 r
.32644 .15335 m .35991 .1442 L .34825 .14568 L F
.34 .189 .051 r
.31455 .15735 m .32644 .15335 L .34825 .14568 L F
.889 .633 .225 r
.37119 .41076 m .38925 .41281 L .40327 .40886 L F
.17 .061 .017 r
.77713 .17162 m .78813 .17318 L .79858 .18117 L F
.77713 .17162 m .76744 .16392 L .78813 .17318 L F
1 .889 .5 r
.30885 .41163 m .33933 .41158 L .32229 .40536 L F
1 .907 .545 r
.29221 .40403 m .30885 .41163 L .32229 .40536 L F
.713 .383 .11 r
.52304 .12852 m .54706 .13648 L .54837 .12856 L F
.52304 .12852 m .52417 .13645 L .54706 .13648 L F
.714 .383 .11 r
.49786 .12949 m .52417 .13645 L .52304 .12852 L F
0 0 0 r
.28282 .17246 m .31455 .15735 L .30376 .16326 L F
.27243 .18044 m .28282 .17246 L .30376 .16326 L F
.081 .035 .008 r
.55356 .39672 m .56534 .3954 L .57145 .39753 L F
.55356 .39672 m .55043 .39473 L .56534 .3954 L F
.435 .188 .048 r
.82151 .21371 m .8343 .2122 L .84081 .22441 L F
.82151 .21371 m .81534 .2016 L .8343 .2122 L F
.385 .21 .061 r
.6638 .13268 m .67748 .13946 L .68855 .13825 L F
.6638 .13268 m .65447 .13431 L .67748 .13946 L F
.269 .156 .046 r
.69886 .13934 m .71123 .14471 L .72299 .14623 L F
.69886 .13934 m .68855 .13825 L .71123 .14471 L F
.549 .382 .092 r
.63485 .40243 m .63622 .40564 L .65184 .40556 L F
.63485 .40243 m .62145 .40293 L .63622 .40564 L F
.46 .247 .069 r
.38276 .1378 m .3937 .13905 L .41684 .13396 L F
.486 .261 .073 r
.35991 .1442 m .3937 .13905 L .38276 .1378 L F
.7 .47 .109 r
.40327 .40886 m .43436 .40542 L .4189 .40531 L F
.398 .218 .06 r
.34825 .14568 m .35991 .1442 L .38276 .1378 L F
.001 .001 0 r
.23651 .2114 m .26338 .18995 L .25575 .20083 L F
.057 .025 .009 r
.23002 .22359 m .23651 .2114 L .25575 .20083 L F
.073 .031 .007 r
.53544 .39644 m .55043 .39473 L .55356 .39672 L F
.53544 .39644 m .53533 .39449 L .55043 .39473 L F
1 1 .82 r
.77876 .38794 m .77827 .40455 L .79358 .3953 L F
.77876 .38794 m .76419 .39771 L .77827 .40455 L F
.546 .293 .084 r
.60393 .12681 m .62193 .13459 L .62984 .13006 L F
.60393 .12681 m .59816 .13162 L .62193 .13459 L F
.575 .309 .088 r
.44157 .12979 m .44933 .13434 L .47318 .13143 L F
.587 .316 .09 r
.41684 .13396 m .44933 .13434 L .44157 .12979 L F
1 .907 .545 r
.29221 .40403 m .32229 .40536 L .3065 .39722 L F
1 .883 .549 r
.27695 .39474 m .29221 .40403 L .3065 .39722 L F
1 1 .602 r
.73244 .39988 m .73121 .41199 L .74833 .40581 L F
.73244 .39988 m .71648 .40658 L .73121 .41199 L F
.572 .252 .066 r
.82614 .22686 m .84081 .22441 L .84569 .23757 L F
.82614 .22686 m .82151 .21371 L .84081 .22441 L F
.249 .102 .026 r
.78557 .18091 m .79858 .18117 L .80767 .1907 L F
.78557 .18091 m .77713 .17162 L .79858 .18117 L F
1 .821 .409 r
.33933 .41158 m .37119 .41076 L .35424 .4062 L F
1 .92 .526 r
.32229 .40536 m .33933 .41158 L .35424 .4062 L F
.124 .043 .012 r
.74365 .15544 m .75657 .15799 L .76744 .16392 L F
.74365 .15544 m .73381 .14985 L .75657 .15799 L F
.794 .558 .19 r
.66653 .40257 m .66736 .40914 L .68391 .40662 L F
.66653 .40257 m .65184 .40556 L .66736 .40914 L F
.057 .025 .009 r
.23002 .22359 m .25575 .20083 L .2496 .21294 L F
.102 .044 .016 r
.22515 .23676 m .23002 .22359 L .2496 .21294 L F
1 1 .888 r
.79196 .37672 m .79358 .3953 L .80743 .38459 L F
.79196 .37672 m .77876 .38794 L .79358 .3953 L F
.538 .376 .09 r
.61659 .3998 m .62145 .40293 L .63485 .40243 L F
0 0 0 r
.27243 .18044 m .30376 .16326 L .29413 .17093 L F
.013 .005 .001 r
.26338 .18995 m .27243 .18044 L .29413 .17093 L F
.34 .189 .051 r
.31455 .15735 m .34825 .14568 L .33752 .14928 L F
0 0 0 r
.30376 .16326 m .31455 .15735 L .33752 .14928 L F
.669 .453 .105 r
.4189 .40531 m .44922 .40275 L .436 .40222 L F
.864 .61 .208 r
.38685 .4063 m .40327 .40886 L .4189 .40531 L F
.889 .633 .225 r
.37119 .41076 m .40327 .40886 L .38685 .4063 L F
.545 .293 .084 r
.57706 .12459 m .59816 .13162 L .60393 .12681 L F
.57706 .12459 m .57353 .1296 L .59816 .13162 L F
1 .883 .549 r
.27695 .39474 m .3065 .39722 L .29199 .38741 L F
1 .831 .525 r
.26314 .384 m .27695 .39474 L .29199 .38741 L F
1 .841 .42 r
.69947 .40159 m .69942 .41111 L .71648 .40658 L F
.69947 .40159 m .68391 .40662 L .69942 .41111 L F
.564 .303 .086 r
.46757 .12661 m .47318 .13143 L .49786 .12949 L F
.575 .309 .088 r
.44157 .12979 m .47318 .13143 L .46757 .12661 L F
.379 .207 .06 r
.63729 .1281 m .65447 .13431 L .6638 .13268 L F
.63729 .1281 m .62984 .13006 L .65447 .13431 L F
.37 .228 .082 r
.21196 .27072 m .21223 .28561 L .23029 .27506 L F
1 .826 .414 r
.35424 .4062 m .37119 .41076 L .38685 .4063 L F
.439 .237 .066 r
.40765 .1323 m .41684 .13396 L .44157 .12979 L F
.46 .247 .069 r
.38276 .1378 m .41684 .13396 L .40765 .1323 L F
.695 .312 .081 r
.82918 .24088 m .84569 .23757 L .84889 .25153 L F
.82918 .24088 m .82614 .22686 L .84569 .23757 L F
1 1 .924 r
.80371 .36427 m .80743 .38459 L .81976 .37264 L F
.80371 .36427 m .79196 .37672 L .80743 .38459 L F
1 1 .664 r
.84072 .27583 m .85642 .30149 L .85848 .28642 L F
1 1 .56 r
.84098 .26076 m .84072 .27583 L .85848 .28642 L F
.07 .024 .007 r
.70837 .1426 m .72299 .14623 L .73381 .14985 L F
.70837 .1426 m .69886 .13934 L .72299 .14623 L F
.258 .151 .044 r
.6725 .13341 m .68855 .13825 L .69886 .13934 L F
.6725 .13341 m .6638 .13268 L .68855 .13825 L F
.398 .218 .06 r
.34825 .14568 m .38276 .1378 L .37256 .13887 L F
0 0 0 r
.33752 .14928 m .34825 .14568 L .37256 .13887 L F
1 .831 .525 r
.26314 .384 m .29199 .38741 L .27885 .37615 L F
.986 .762 .481 r
.25085 .372 m .26314 .384 L .27885 .37615 L F
.546 .293 .084 r
.54962 .12346 m .57353 .1296 L .57706 .12459 L F
.54962 .12346 m .54837 .12856 L .57353 .1296 L F
.102 .044 .016 r
.22515 .23676 m .2496 .21294 L .245 .22609 L F
.146 .065 .022 r
.22196 .25072 m .22515 .23676 L .245 .22609 L F
.556 .299 .085 r
.49449 .12447 m .49786 .12949 L .52304 .12852 L F
.564 .303 .086 r
.46757 .12661 m .49786 .12949 L .49449 .12447 L F
.463 .299 .13 r
.21223 .28561 m .23226 .2904 L .23029 .27506 L F
.21223 .28561 m .21428 .3007 L .23226 .2904 L F
.366 .203 .056 r
.37256 .13887 m .38276 .1378 L .40765 .1323 L F
.531 .372 .089 r
.59728 .39771 m .6056 .40065 L .61659 .3998 L F
.59728 .39771 m .58886 .39884 L .6056 .40065 L F
1 1 .753 r
.74725 .39126 m .74833 .40581 L .76419 .39771 L F
.74725 .39126 m .73244 .39988 L .74833 .40581 L F
.639 .435 .101 r
.436 .40222 m .46515 .4005 L .45434 .39963 L F
1 1 .754 r
.83874 .29115 m .85257 .31654 L .85642 .30149 L F
1 1 .664 r
.84072 .27583 m .83874 .29115 L .85642 .30149 L F
1 1 .933 r
.81396 .35081 m .81976 .37264 L .83049 .35965 L F
.81396 .35081 m .80371 .36427 L .81976 .37264 L F
.37 .157 .04 r
.79269 .19165 m .80767 .1907 L .81534 .2016 L F
.79269 .19165 m .78557 .18091 L .80767 .1907 L F
.55 .295 .084 r
.52197 .12341 m .54837 .12856 L .54962 .12346 L F
.52197 .12341 m .52304 .12852 L .54837 .12856 L F
1 .92 .526 r
.32229 .40536 m .35424 .4062 L .33837 .39945 L F
1 .954 .584 r
.3065 .39722 m .32229 .40536 L .33837 .39945 L F
.556 .299 .085 r
.49449 .12447 m .52304 .12852 L .52197 .12341 L F
.986 .762 .481 r
.25085 .372 m .27885 .37615 L .26715 .36366 L F
.905 .685 .426 r
.24014 .35898 m .25085 .372 L .26715 .36366 L F
1 1 .827 r
.83506 .30652 m .84694 .33139 L .85257 .31654 L F
1 1 .754 r
.83874 .29115 m .83506 .30652 L .85257 .31654 L F
.553 .371 .184 r
.21428 .3007 m .23593 .30579 L .23226 .2904 L F
.21428 .3007 m .21813 .31578 L .23593 .30579 L F
.013 .005 .001 r
.26338 .18995 m .29413 .17093 L .28574 .18021 L F
.062 .025 .008 r
.25575 .20083 m .26338 .18995 L .28574 .18021 L F
1 1 .918 r
.82263 .33656 m .83049 .35965 L .83957 .34583 L F
.82263 .33656 m .81396 .35081 L .83049 .35965 L F
.797 .365 .094 r
.83058 .25556 m .82918 .24088 L .84889 .25153 L F
.19 .072 .019 r
.75243 .16285 m .76744 .16392 L .77713 .17162 L F
.75243 .16285 m .74365 .15544 L .76744 .16392 L F
1 1 .882 r
.82968 .32172 m .83957 .34583 L .84694 .33139 L F
1 1 .827 r
.83506 .30652 m .82968 .32172 L .84694 .33139 L F
1 1 .882 r
.82968 .32172 m .82263 .33656 L .83957 .34583 L F
.782 .546 .179 r
.64747 .39903 m .65184 .40556 L .66653 .40257 L F
.64747 .39903 m .63485 .40243 L .65184 .40556 L F
.905 .685 .426 r
.24014 .35898 m .26715 .36366 L .25694 .35017 L F
.819 .603 .366 r
.23109 .34512 m .24014 .35898 L .25694 .35017 L F
.641 .444 .241 r
.21813 .31578 m .24129 .32102 L .23593 .30579 L F
.21813 .31578 m .22374 .33066 L .24129 .32102 L F
.842 .59 .193 r
.40436 .40229 m .4189 .40531 L .436 .40222 L F
.864 .61 .208 r
.38685 .4063 m .4189 .40531 L .40436 .40229 L F
0 0 0 r
.30376 .16326 m .33752 .14928 L .32776 .15485 L F
.017 .006 .002 r
.29413 .17093 m .30376 .16326 L .32776 .15485 L F
.146 .065 .022 r
.22196 .25072 m .245 .22609 L .24198 .24011 L F
.196 .092 .03 r
.22049 .26529 m .22196 .25072 L .24198 .24011 L F
.377 .207 .059 r
.60936 .12458 m .62984 .13006 L .63729 .1281 L F
.60936 .12458 m .60393 .12681 L .62984 .13006 L F
.529 .371 .088 r
.57716 .39618 m .58886 .39884 L .59728 .39771 L F
.57716 .39618 m .57145 .39753 L .58886 .39884 L F
.422 .228 .064 r
.43427 .1278 m .44157 .12979 L .46757 .12661 L F
.439 .237 .066 r
.40765 .1323 m .44157 .12979 L .43427 .1278 L F
.819 .603 .366 r
.23109 .34512 m .25694 .35017 L .24831 .33589 L F
.73 .522 .303 r
.22374 .33066 m .23109 .34512 L .24831 .33589 L F
.22374 .33066 m .24831 .33589 L .24129 .32102 L F
.611 .419 .098 r
.45434 .39963 m .48194 .39873 L .47372 .39757 L F
1 1 .623 r
.71405 .3944 m .71648 .40658 L .73244 .39988 L F
.71405 .3944 m .69947 .40159 L .71648 .40658 L F
1 1 .858 r
.76087 .38099 m .76419 .39771 L .77876 .38794 L F
.76087 .38099 m .74725 .39126 L .76419 .39771 L F
1 .826 .414 r
.35424 .4062 m .38685 .4063 L .37141 .40124 L F
1 .949 .551 r
.33837 .39945 m .35424 .4062 L .37141 .40124 L F
1 .844 .423 r
.68036 .39709 m .68391 .40662 L .69947 .40159 L F
.68036 .39709 m .66653 .40257 L .68391 .40662 L F
.506 .218 .057 r
.79843 .20367 m .81534 .2016 L .82151 .21371 L F
.79843 .20367 m .79269 .19165 L .81534 .2016 L F
.531 .372 .088 r
.5565 .39525 m .57145 .39753 L .57716 .39618 L F
.5565 .39525 m .55356 .39672 L .57145 .39753 L F
1 .83 .417 r
.37141 .40124 m .38685 .4063 L .40436 .40229 L F
.587 .405 .095 r
.47372 .39757 m .4994 .39745 L .49389 .39609 L F
1 .954 .584 r
.3065 .39722 m .33837 .39945 L .32364 .3908 L F
1 .938 .594 r
.29199 .38741 m .3065 .39722 L .32364 .3908 L F
.134 .047 .013 r
.71702 .14787 m .73381 .14985 L .74365 .15544 L F
.71702 .14787 m .70837 .1426 L .73381 .14985 L F
.062 .025 .008 r
.25575 .20083 m .28574 .18021 L .27867 .19094 L F
.11 .046 .015 r
.2496 .21294 m .25575 .20083 L .27867 .19094 L F
.252 .147 .043 r
.64424 .12852 m .6638 .13268 L .6725 .13341 L F
.64424 .12852 m .63729 .1281 L .6638 .13268 L F
0 0 0 r
.33752 .14928 m .37256 .13887 L .36315 .14209 L F
.009 .003 .001 r
.32776 .15485 m .33752 .14928 L .36315 .14209 L F
.538 .376 .089 r
.53555 .39492 m .55356 .39672 L .5565 .39525 L F
.53555 .39492 m .53544 .39644 L .55356 .39672 L F
.566 .393 .092 r
.49389 .39609 m .51731 .39668 L .51458 .3952 L F
.335 .188 .052 r
.39907 .133 m .40765 .1323 L .43427 .1278 L F
.366 .203 .056 r
.37256 .13887 m .40765 .1323 L .39907 .133 L F
.378 .208 .059 r
.5804 .12218 m .60393 .12681 L .60936 .12458 L F
.5804 .12218 m .57706 .12459 L .60393 .12681 L F
.408 .222 .063 r
.46229 .12436 m .46757 .12661 L .49449 .12447 L F
.422 .228 .064 r
.43427 .1278 m .46757 .12661 L .46229 .12436 L F
.55 .383 .09 r
.51458 .3952 m .53544 .39644 L .53555 .39492 L F
.078 .027 .007 r
.68053 .13634 m .69886 .13934 L .70837 .1426 L F
.68053 .13634 m .6725 .13341 L .69886 .13934 L F
.773 .537 .17 r
.62695 .39606 m .63485 .40243 L .64747 .39903 L F
.62695 .39606 m .61659 .3998 L .63485 .40243 L F
.282 .116 .029 r
.76008 .17192 m .77713 .17162 L .78557 .18091 L F
.76008 .17192 m .75243 .16285 L .77713 .17162 L F
.823 .573 .181 r
.42354 .39879 m .436 .40222 L .45434 .39963 L F
.842 .59 .193 r
.40436 .40229 m .436 .40222 L .42354 .39879 L F
0 0 0 r
.36315 .14209 m .37256 .13887 L .39907 .133 L F
1 1 .923 r
.77322 .36928 m .77876 .38794 L .79196 .37672 L F
.77322 .36928 m .76087 .38099 L .77876 .38794 L F
.017 .006 .002 r
.29413 .17093 m .32776 .15485 L .31906 .16223 L F
.054 .019 .006 r
.28574 .18021 m .29413 .17093 L .31906 .16223 L F
1 .938 .594 r
.29199 .38741 m .32364 .3908 L .31011 .38049 L F
1 .891 .572 r
.27885 .37615 m .29199 .38741 L .31011 .38049 L F
.63 .277 .073 r
.80273 .2168 m .82151 .21371 L .82614 .22686 L F
.80273 .2168 m .79843 .20367 L .82151 .21371 L F
.382 .21 .06 r
.55079 .12095 m .57706 .12459 L .5804 .12218 L F
.55079 .12095 m .54962 .12346 L .57706 .12459 L F
.397 .217 .061 r
.49132 .12205 m .49449 .12447 L .52197 .12341 L F
.408 .222 .063 r
.46229 .12436 m .49449 .12447 L .49132 .12205 L F
1 1 .78 r
.72759 .3853 m .73244 .39988 L .74725 .39126 L F
.72759 .3853 m .71405 .3944 L .73244 .39988 L F
.11 .046 .015 r
.2496 .21294 m .27867 .19094 L .27297 .20295 L F
.156 .068 .022 r
.245 .22609 m .2496 .21294 L .27297 .20295 L F
1 .949 .551 r
.33837 .39945 m .37141 .40124 L .35695 .39401 L F
1 .997 .62 r
.32364 .3908 m .33837 .39945 L .35695 .39401 L F
.389 .213 .06 r
.52096 .12091 m .54962 .12346 L .55079 .12095 L F
.52096 .12091 m .52197 .12341 L .54962 .12346 L F
.397 .217 .061 r
.49132 .12205 m .52197 .12341 L .52096 .12091 L F
1 1 .954 r
.78423 .35636 m .79196 .37672 L .80371 .36427 L F
.78423 .35636 m .77322 .36928 L .79196 .37672 L F
1 .846 .426 r
.65936 .39316 m .66653 .40257 L .68036 .39709 L F
.65936 .39316 m .64747 .39903 L .66653 .40257 L F
.768 .531 .163 r
.60522 .39368 m .61659 .3998 L .62695 .39606 L F
.60522 .39368 m .59728 .39771 L .61659 .3998 L F
.247 .145 .042 r
.61444 .12476 m .63729 .1281 L .64424 .12852 L F
.61444 .12476 m .60936 .12458 L .63729 .1281 L F
1 .835 .421 r
.39066 .39678 m .40436 .40229 L .42354 .39879 L F
1 .83 .417 r
.37141 .40124 m .40436 .40229 L .39066 .39678 L F
.806 .558 .171 r
.44416 .39586 m .45434 .39963 L .47372 .39757 L F
.823 .573 .181 r
.42354 .39879 m .45434 .39963 L .44416 .39586 L F
.307 .175 .049 r
.42746 .1282 m .43427 .1278 L .46229 .12436 L F
.335 .188 .052 r
.39907 .133 m .43427 .1278 L .42746 .1282 L F
1 .891 .572 r
.27885 .37615 m .31011 .38049 L .29783 .36874 L F
1 .826 .53 r
.26715 .36366 m .27885 .37615 L .29783 .36874 L F
1 1 .64 r
.69333 .38945 m .69947 .40159 L .71405 .3944 L F
.69333 .38945 m .68036 .39709 L .69947 .40159 L F
.202 .078 .02 r
.72474 .15501 m .74365 .15544 L .75243 .16285 L F
.72474 .15501 m .71702 .14787 L .74365 .15544 L F
.472 .297 .119 r
.23004 .25997 m .23029 .27506 L .25235 .26506 L F
1 .977 .574 r
.35695 .39401 m .37141 .40124 L .39066 .39678 L F
.734 .329 .086 r
.80555 .23087 m .82614 .22686 L .82918 .24088 L F
.80555 .23087 m .80273 .2168 L .82614 .22686 L F
.42 .178 .047 r
.76654 .18251 m .78557 .18091 L .79269 .19165 L F
.76654 .18251 m .76008 .17192 L .78557 .18091 L F
.009 .003 .001 r
.32776 .15485 m .36315 .14209 L .3546 .14734 L F
.048 .017 .005 r
.31906 .16223 m .32776 .15485 L .3546 .14734 L F
1 1 .959 r
.79383 .34245 m .80371 .36427 L .81396 .35081 L F
.79383 .34245 m .78423 .35636 L .80371 .36427 L F
1 1 .712 r
.81895 .26578 m .83874 .29115 L .84072 .27583 L F
1 1 .619 r
.8192 .25053 m .81895 .26578 L .84072 .27583 L F
.054 .019 .006 r
.28574 .18021 m .31906 .16223 L .31148 .17129 L F
.109 .043 .014 r
.27867 .19094 m .28574 .18021 L .31148 .17129 L F
.156 .068 .022 r
.245 .22609 m .27297 .20295 L .26869 .21608 L F
.204 .094 .03 r
.24198 .24011 m .245 .22609 L .26869 .21608 L F
.083 .029 .008 r
.65066 .13118 m .6725 .13341 L .68053 .13634 L F
.65066 .13118 m .64424 .12852 L .6725 .13341 L F
1 .826 .53 r
.26715 .36366 m .29783 .36874 L .28688 .35579 L F
.98 .75 .475 r
.25694 .35017 m .26715 .36366 L .28688 .35579 L F
.14 .049 .013 r
.68784 .14133 m .70837 .1426 L .71702 .14787 L F
.68784 .14133 m .68053 .13634 L .70837 .1426 L F
.556 .364 .17 r
.23029 .27506 m .25419 .28064 L .25235 .26506 L F
.23029 .27506 m .23226 .2904 L .25419 .28064 L F
.008 .003 .001 r
.39115 .13591 m .39907 .133 L .42746 .1282 L F
0 0 0 r
.36315 .14209 m .39907 .133 L .39115 .13591 L F
1 1 .882 r
.74005 .37455 m .74725 .39126 L .76087 .38099 L F
.74005 .37455 m .72759 .3853 L .74725 .39126 L F
.765 .527 .158 r
.58256 .39196 m .59728 .39771 L .60522 .39368 L F
.58256 .39196 m .57716 .39618 L .59728 .39771 L F
1 1 .942 r
.80197 .32778 m .81396 .35081 L .82263 .33656 L F
.80197 .32778 m .79383 .34245 L .81396 .35081 L F
1 1 .791 r
.8171 .28135 m .83506 .30652 L .83874 .29115 L F
1 1 .712 r
.81895 .26578 m .8171 .28135 L .83874 .29115 L F
.036 .013 .003 r
.3546 .14734 m .36315 .14209 L .39115 .13591 L F
.792 .547 .164 r
.46596 .39353 m .47372 .39757 L .49389 .39609 L F
.806 .558 .171 r
.44416 .39586 m .47372 .39757 L .46596 .39353 L F
1 .997 .62 r
.32364 .3908 m .35695 .39401 L .3435 .38488 L F
1 .989 .635 r
.31011 .38049 m .32364 .3908 L .3435 .38488 L F
.245 .144 .042 r
.58351 .1222 m .60936 .12458 L .61444 .12476 L F
.58351 .1222 m .5804 .12218 L .60936 .12458 L F
.822 .377 .098 r
.80685 .24567 m .80555 .23087 L .82918 .24088 L F
1 1 .907 r
.80858 .31256 m .82263 .33656 L .82968 .32172 L F
.80858 .31256 m .80197 .32778 L .82263 .33656 L F
1 1 .857 r
.81364 .29701 m .82968 .32172 L .83506 .30652 L F
1 1 .791 r
.8171 .28135 m .81364 .29701 L .83506 .30652 L F
.283 .163 .046 r
.45736 .12453 m .46229 .12436 L .49132 .12205 L F
.307 .175 .049 r
.42746 .1282 m .46229 .12436 L .45736 .12453 L F
.98 .75 .475 r
.25694 .35017 m .28688 .35579 L .27733 .34185 L F
.897 .67 .414 r
.24831 .33589 m .25694 .35017 L .27733 .34185 L F
.638 .433 .225 r
.23226 .2904 m .25764 .29633 L .25419 .28064 L F
.23226 .2904 m .23593 .30579 L .25764 .29633 L F
1 1 .857 r
.81364 .29701 m .80858 .31256 L .82968 .32172 L F
.897 .67 .414 r
.24831 .33589 m .27733 .34185 L .26924 .32715 L F
.811 .589 .35 r
.24129 .32102 m .24831 .33589 L .26924 .32715 L F
.204 .094 .03 r
.24198 .24011 m .26869 .21608 L .26589 .23015 L F
.252 .119 .037 r
.24058 .2548 m .24198 .24011 L .26589 .23015 L F
1 .848 .428 r
.63672 .38984 m .64747 .39903 L .65936 .39316 L F
.63672 .38984 m .62695 .39606 L .64747 .39903 L F
.724 .509 .286 r
.23593 .30579 m .26266 .3119 L .25764 .29633 L F
.23593 .30579 m .24129 .32102 L .26266 .3119 L F
.811 .589 .35 r
.24129 .32102 m .26924 .32715 L .26266 .3119 L F
.765 .526 .155 r
.55927 .3909 m .57716 .39618 L .58256 .39196 L F
.55927 .3909 m .5565 .39525 L .57716 .39618 L F
1 .838 .424 r
.4118 .39289 m .42354 .39879 L .44416 .39586 L F
1 .835 .421 r
.39066 .39678 m .42354 .39879 L .4118 .39289 L F
.781 .538 .159 r
.48868 .39185 m .49389 .39609 L .51458 .3952 L F
.792 .547 .164 r
.46596 .39353 m .49389 .39609 L .48868 .39185 L F
.545 .235 .062 r
.77175 .19444 m .79269 .19165 L .79843 .20367 L F
.77175 .19444 m .76654 .18251 L .79269 .19165 L F
.318 .132 .034 r
.73147 .16388 m .75243 .16285 L .76008 .17192 L F
.73147 .16388 m .72474 .15501 L .75243 .16285 L F
.245 .144 .041 r
.55188 .12089 m .5804 .12218 L .58351 .1222 L F
.55188 .12089 m .55079 .12095 L .5804 .12218 L F
.109 .043 .014 r
.27867 .19094 m .31148 .17129 L .30507 .18186 L F
.158 .067 .021 r
.27297 .20295 m .27867 .19094 L .30507 .18186 L F
1 1 .799 r
.7054 .37991 m .71405 .3944 L .72759 .3853 L F
.7054 .37991 m .69333 .38945 L .71405 .3944 L F
.264 .154 .044 r
.48835 .12206 m .49132 .12205 L .52096 .12091 L F
.283 .163 .046 r
.45736 .12453 m .49132 .12205 L .48835 .12206 L F
.767 .528 .155 r
.53565 .39052 m .5565 .39525 L .55927 .3909 L F
.53565 .39052 m .53555 .39492 L .5565 .39525 L F
.773 .531 .156 r
.51201 .39084 m .51458 .3952 L .53555 .39492 L F
.781 .538 .159 r
.48868 .39185 m .51458 .3952 L .51201 .39084 L F
.048 .017 .005 r
.31906 .16223 m .3546 .14734 L .34696 .15447 L F
.096 .036 .011 r
.31148 .17129 m .31906 .16223 L .34696 .15447 L F
1 1 .94 r
.75137 .36238 m .76087 .38099 L .77322 .36928 L F
.75137 .36238 m .74005 .37455 L .76087 .38099 L F
1 .977 .574 r
.35695 .39401 m .39066 .39678 L .37782 .38911 L F
1 1 .652 r
.3435 .38488 m .35695 .39401 L .37782 .38911 L F
1 1 .653 r
.67053 .38511 m .68036 .39709 L .69333 .38945 L F
.67053 .38511 m .65936 .39316 L .68036 .39709 L F
.773 .531 .156 r
.51201 .39084 m .53555 .39492 L .53565 .39052 L F
1 1 .594 r
.37782 .38911 m .39066 .39678 L .4118 .39289 L F
1 .989 .635 r
.31011 .38049 m .3435 .38488 L .33114 .37409 L F
1 .946 .614 r
.29783 .36874 m .31011 .38049 L .33114 .37409 L F
.249 .147 .042 r
.52001 .12084 m .55079 .12095 L .55188 .12089 L F
.52001 .12084 m .52096 .12091 L .55079 .12095 L F
.084 .029 .008 r
.61913 .12721 m .64424 .12852 L .65066 .13118 L F
.61913 .12721 m .61444 .12476 L .64424 .12852 L F
.264 .154 .044 r
.48835 .12206 m .52096 .12091 L .52001 .12084 L F
.028 .01 .003 r
.42117 .13084 m .42746 .1282 L .45736 .12453 L F
.008 .003 .001 r
.39115 .13591 m .42746 .1282 L .42117 .13084 L F
.211 .082 .021 r
.69437 .14824 m .71702 .14787 L .72474 .15501 L F
.69437 .14824 m .68784 .14133 L .71702 .14787 L F
1 .849 .43 r
.61272 .38719 m .62695 .39606 L .63672 .38984 L F
.61272 .38719 m .60522 .39368 L .62695 .39606 L F
.141 .049 .013 r
.6565 .13593 m .68053 .13634 L .68784 .14133 L F
.6565 .13593 m .65066 .13118 L .68053 .13634 L F
.036 .013 .003 r
.3546 .14734 m .39115 .13591 L .38395 .14088 L F
.074 .026 .007 r
.34696 .15447 m .3546 .14734 L .38395 .14088 L F
.652 .287 .076 r
.77565 .20755 m .79843 .20367 L .80273 .2168 L F
.77565 .20755 m .77175 .19444 L .79843 .20367 L F
1 .842 .426 r
.43455 .38961 m .44416 .39586 L .46596 .39353 L F
1 .838 .424 r
.4118 .39289 m .44416 .39586 L .43455 .38961 L F
.06 .021 .006 r
.38395 .14088 m .39115 .13591 L .42117 .13084 L F
1 1 .963 r
.76146 .34902 m .77322 .36928 L .78423 .35636 L F
.76146 .34902 m .75137 .36238 L .77322 .36928 L F
.158 .067 .021 r
.27297 .20295 m .30507 .18186 L .29991 .19379 L F
.206 .093 .029 r
.26869 .21608 m .27297 .20295 L .29991 .19379 L F
1 .946 .614 r
.29783 .36874 m .33114 .37409 L .31991 .36189 L F
1 .884 .573 r
.28688 .35579 m .29783 .36874 L .31991 .36189 L F
.447 .19 .051 r
.73716 .17432 m .76008 .17192 L .76654 .18251 L F
.73716 .17432 m .73147 .16388 L .76008 .17192 L F
1 1 .895 r
.71651 .36873 m .72759 .3853 L .74005 .37455 L F
.71651 .36873 m .7054 .37991 L .72759 .3853 L F
.082 .028 .008 r
.58639 .12451 m .61444 .12476 L .61913 .12721 L F
.58639 .12451 m .58351 .1222 L .61444 .12476 L F
.044 .015 .004 r
.4528 .12696 m .45736 .12453 L .48835 .12206 L F
.028 .01 .003 r
.42117 .13084 m .45736 .12453 L .4528 .12696 L F
.096 .036 .011 r
.31148 .17129 m .34696 .15447 L .34031 .16332 L F
.148 .06 .019 r
.30507 .18186 m .31148 .17129 L .34031 .16332 L F
1 1 .652 r
.3435 .38488 m .37782 .38911 L .36588 .37954 L F
1 1 .671 r
.33114 .37409 m .3435 .38488 L .36588 .37954 L F
1 1 .962 r
.77027 .33469 m .78423 .35636 L .79383 .34245 L F
.77027 .33469 m .76146 .34902 L .78423 .35636 L F
1 .85 .431 r
.58766 .38526 m .60522 .39368 L .61272 .38719 L F
.58766 .38526 m .58256 .39196 L .60522 .39368 L F
1 1 .663 r
.6459 .38146 m .65936 .39316 L .67053 .38511 L F
.6459 .38146 m .63672 .38984 L .65936 .39316 L F
1 .844 .428 r
.45864 .38702 m .46596 .39353 L .48868 .39185 L F
1 .842 .426 r
.43455 .38961 m .46596 .39353 L .45864 .38702 L F
.742 .334 .088 r
.77821 .22166 m .80273 .2168 L .80555 .23087 L F
.77821 .22166 m .77565 .20755 L .80273 .2168 L F
1 1 .612 r
.40078 .38482 m .4118 .39289 L .43455 .38961 L F
1 1 .594 r
.37782 .38911 m .4118 .39289 L .40078 .38482 L F
.554 .353 .153 r
.25211 .24979 m .25235 .26506 L .27823 .25577 L F
1 .884 .573 r
.28688 .35579 m .31991 .36189 L .30989 .3485 L F
1 .812 .52 r
.27733 .34185 m .28688 .35579 L .30989 .3485 L F
1 1 .81 r
.68092 .37518 m .69333 .38945 L .7054 .37991 L F
.68092 .37518 m .67053 .38511 L .69333 .38945 L F
.206 .093 .029 r
.26869 .21608 m .29991 .19379 L .29603 .2069 L F
.252 .117 .036 r
.26589 .23015 m .26869 .21608 L .29603 .2069 L F
1 1 .681 r
.36588 .37954 m .37782 .38911 L .40078 .38482 L F
1 1 .723 r
.79335 .25644 m .8171 .28135 L .81895 .26578 L F
1 1 .64 r
.79358 .24101 m .79335 .25644 L .81895 .26578 L F
.076 .027 .007 r
.5529 .12312 m .58351 .1222 L .58639 .12451 L F
.5529 .12312 m .55188 .12089 L .58351 .1222 L F
1 1 .941 r
.77774 .31963 m .79383 .34245 L .80197 .32778 L F
.77774 .31963 m .77027 .33469 L .79383 .34245 L F
.058 .02 .006 r
.48562 .12436 m .48835 .12206 L .52001 .12084 L F
.044 .015 .004 r
.4528 .12696 m .48835 .12206 L .48562 .12436 L F
.339 .141 .038 r
.70007 .15693 m .72474 .15501 L .73147 .16388 L F
.70007 .15693 m .69437 .14824 L .72474 .15501 L F
.139 .048 .013 r
.6234 .13179 m .65066 .13118 L .6565 .13593 L F
.6234 .13179 m .61913 .12721 L .65066 .13118 L F
.636 .421 .207 r
.25235 .26506 m .27992 .27158 L .27823 .25577 L F
.25235 .26506 m .25419 .28064 L .27992 .27158 L F
1 .85 .431 r
.56189 .38408 m .58256 .39196 L .58766 .38526 L F
.56189 .38408 m .55927 .3909 L .58256 .39196 L F
.079 .027 .008 r
.41544 .13558 m .42117 .13084 L .4528 .12696 L F
.06 .021 .006 r
.38395 .14088 m .42117 .13084 L .41544 .13558 L F
1 .812 .52 r
.27733 .34185 m .30989 .3485 L .30114 .33414 L F
.972 .734 .46 r
.26924 .32715 m .27733 .34185 L .30114 .33414 L F
.074 .026 .007 r
.34696 .15447 m .38395 .14088 L .37751 .14778 L F
.129 .049 .015 r
.34031 .16332 m .34696 .15447 L .37751 .14778 L F
1 .847 .43 r
.48377 .38514 m .48868 .39185 L .51201 .39084 L F
1 .844 .428 r
.45864 .38702 m .48868 .39185 L .48377 .38514 L F
1 1 .795 r
.79165 .27223 m .81364 .29701 L .8171 .28135 L F
1 1 .723 r
.79335 .25644 m .79165 .27223 L .8171 .28135 L F
1 1 .905 r
.78382 .30404 m .80197 .32778 L .80858 .31256 L F
.78382 .30404 m .77774 .31963 L .80197 .32778 L F
.069 .024 .007 r
.51914 .12307 m .55188 .12089 L .5529 .12312 L F
.51914 .12307 m .52001 .12084 L .55188 .12089 L F
.058 .02 .006 r
.48562 .12436 m .52001 .12084 L .51914 .12307 L F
.559 .241 .064 r
.74174 .18618 m .76654 .18251 L .77175 .19444 L F
.74174 .18618 m .73716 .17432 L .76654 .18251 L F
.82 .376 .099 r
.7794 .23657 m .77821 .22166 L .80555 .23087 L F
.218 .086 .022 r
.66172 .14266 m .68784 .14133 L .69437 .14824 L F
.66172 .14266 m .6565 .13593 L .68784 .14133 L F
1 1 .944 r
.72661 .35614 m .74005 .37455 L .75137 .36238 L F
.72661 .35614 m .71651 .36873 L .74005 .37455 L F
1 1 .856 r
.78846 .28817 m .80858 .31256 L .81364 .29701 L F
1 1 .795 r
.79165 .27223 m .78846 .28817 L .81364 .29701 L F
1 1 .856 r
.78846 .28817 m .78382 .30404 L .80858 .31256 L F
.721 .496 .268 r
.25419 .28064 m .28308 .28754 L .27992 .27158 L F
.25419 .28064 m .25764 .29633 L .28308 .28754 L F
.099 .035 .01 r
.37751 .14778 m .38395 .14088 L .41544 .13558 L F
.972 .734 .46 r
.26924 .32715 m .30114 .33414 L .29372 .31905 L F
.89 .655 .397 r
.26266 .3119 m .26924 .32715 L .29372 .31905 L F
.148 .06 .019 r
.30507 .18186 m .34031 .16332 L .33468 .17376 L F
.202 .089 .027 r
.29991 .19379 m .30507 .18186 L .33468 .17376 L F
1 1 .671 r
.33114 .37409 m .36588 .37954 L .35487 .36832 L F
1 .997 .652 r
.31991 .36189 m .33114 .37409 L .35487 .36832 L F
1 .85 .431 r
.53574 .38366 m .55927 .3909 L .56189 .38408 L F
.53574 .38366 m .53565 .39052 L .55927 .3909 L F
.252 .117 .036 r
.26589 .23015 m .29603 .2069 L .29349 .22101 L F
.3 .142 .044 r
.26459 .24496 m .26589 .23015 L .29349 .22101 L F
1 .848 .431 r
.50958 .38402 m .51201 .39084 L .53565 .39052 L F
1 .847 .43 r
.48377 .38514 m .51201 .39084 L .50958 .38402 L F
.806 .575 .332 r
.25764 .29633 m .28769 .30344 L .28308 .28754 L F
.25764 .29633 m .26266 .3119 L .28769 .30344 L F
.89 .655 .397 r
.26266 .3119 m .29372 .31905 L .28769 .30344 L F
1 .848 .431 r
.50958 .38402 m .53565 .39052 L .53574 .38366 L F
1 1 .668 r
.61976 .37854 m .63672 .38984 L .6459 .38146 L F
.61976 .37854 m .61272 .38719 L .63672 .38984 L F
1 1 .628 r
.42553 .38121 m .43455 .38961 L .45864 .38702 L F
1 1 .612 r
.40078 .38482 m .43455 .38961 L .42553 .38121 L F
.135 .047 .013 r
.58901 .12896 m .61913 .12721 L .6234 .13179 L F
.58901 .12896 m .58639 .12451 L .61913 .12721 L F
1 1 .899 r
.6905 .36362 m .7054 .37991 L .71651 .36873 L F
.6905 .36362 m .68092 .37518 L .7054 .37991 L F
.095 .033 .009 r
.44865 .13153 m .4528 .12696 L .48562 .12436 L F
.079 .027 .008 r
.41544 .13558 m .4528 .12696 L .44865 .13153 L F
1 1 .959 r
.73562 .34237 m .75137 .36238 L .76146 .34902 L F
.73562 .34237 m .72661 .35614 L .75137 .36238 L F
1 1 .816 r
.65445 .37119 m .67053 .38511 L .68092 .37518 L F
.65445 .37119 m .6459 .38146 L .67053 .38511 L F
1 1 .681 r
.36588 .37954 m .40078 .38482 L .39051 .37486 L F
1 1 .703 r
.35487 .36832 m .36588 .37954 L .39051 .37486 L F
.652 .288 .077 r
.74518 .19927 m .77175 .19444 L .77565 .20755 L F
.74518 .19927 m .74174 .18618 L .77175 .19444 L F
.457 .194 .052 r
.70488 .16725 m .73147 .16388 L .73716 .17432 L F
.70488 .16725 m .70007 .15693 L .73147 .16388 L F
1 1 .707 r
.39051 .37486 m .40078 .38482 L .42553 .38121 L F
1 .997 .652 r
.31991 .36189 m .35487 .36832 L .34487 .3557 L F
1 .938 .612 r
.30989 .3485 m .31991 .36189 L .34487 .3557 L F
.129 .049 .015 r
.34031 .16332 m .37751 .14778 L .3719 .15646 L F
.19 .081 .024 r
.33468 .17376 m .34031 .16332 L .3719 .15646 L F
.202 .089 .027 r
.29991 .19379 m .33468 .17376 L .33014 .18561 L F
.249 .113 .034 r
.29603 .2069 m .29991 .19379 L .33014 .18561 L F
1 1 .671 r
.59245 .37641 m .61272 .38719 L .61976 .37854 L F
.59245 .37641 m .58766 .38526 L .61272 .38719 L F
1 1 .641 r
.45176 .37835 m .45864 .38702 L .48377 .38514 L F
1 1 .628 r
.42553 .38121 m .45864 .38702 L .45176 .37835 L F
.222 .088 .023 r
.62722 .13836 m .6565 .13593 L .66172 .14266 L F
.62722 .13836 m .6234 .13179 L .6565 .13593 L F
.128 .045 .012 r
.55382 .12751 m .58639 .12451 L .58901 .12896 L F
.55382 .12751 m .5529 .12312 L .58639 .12451 L F
.347 .145 .039 r
.66628 .1512 m .69437 .14824 L .70007 .15693 L F
.66628 .1512 m .66172 .14266 L .69437 .14824 L F
.124 .045 .013 r
.41032 .14229 m .41544 .13558 L .44865 .13153 L F
.099 .035 .01 r
.37751 .14778 m .41544 .13558 L .41032 .14229 L F
.109 .038 .01 r
.48312 .1288 m .48562 .12436 L .51914 .12307 L F
.095 .033 .009 r
.44865 .13153 m .48562 .12436 L .48312 .1288 L F
.163 .065 .02 r
.3719 .15646 m .37751 .14778 L .41032 .14229 L F
1 1 .95 r
.7435 .32766 m .76146 .34902 L .77027 .33469 L F
.7435 .32766 m .73562 .34237 L .76146 .34902 L F
1 .938 .612 r
.30989 .3485 m .34487 .3557 L .33594 .3419 L F
1 .869 .56 r
.30114 .33414 m .30989 .3485 L .33594 .3419 L F
.119 .041 .011 r
.51835 .12745 m .5529 .12312 L .55382 .12751 L F
.51835 .12745 m .51914 .12307 L .5529 .12312 L F
.109 .038 .01 r
.48312 .1288 m .51914 .12307 L .51835 .12745 L F
.733 .33 .088 r
.74744 .21342 m .77565 .20755 L .77821 .22166 L F
.74744 .21342 m .74518 .19927 L .77565 .20755 L F
1 1 .671 r
.56435 .3751 m .58766 .38526 L .59245 .37641 L F
.56435 .3751 m .56189 .38408 L .58766 .38526 L F
1 1 .938 r
.69922 .35065 m .71651 .36873 L .72661 .35614 L F
.69922 .35065 m .6905 .36362 L .71651 .36873 L F
1 1 .653 r
.47914 .37628 m .48377 .38514 L .50958 .38402 L F
1 1 .641 r
.45176 .37835 m .48377 .38514 L .47914 .37628 L F
.249 .113 .034 r
.29603 .2069 m .33014 .18561 L .32674 .1987 L F
.298 .139 .042 r
.29349 .22101 m .29603 .2069 L .32674 .1987 L F
.636 .412 .191 r
.27801 .24033 m .27823 .25577 L .30769 .24736 L F
1 1 .703 r
.35487 .36832 m .39051 .37486 L .38105 .36327 L F
1 1 .686 r
.34487 .3557 m .35487 .36832 L .38105 .36327 L F
1 1 .925 r
.75018 .31223 m .77027 .33469 L .77774 .31963 L F
.75018 .31223 m .7435 .32766 L .77027 .33469 L F
1 1 .817 r
.62633 .36801 m .6459 .38146 L .65445 .37119 L F
.62633 .36801 m .61976 .37854 L .6459 .38146 L F
.555 .24 .065 r
.70877 .17903 m .73716 .17432 L .74174 .18618 L F
.70877 .17903 m .70488 .16725 L .73716 .17432 L F
1 1 .73 r
.41712 .37093 m .42553 .38121 L .45176 .37835 L F
1 1 .707 r
.39051 .37486 m .42553 .38121 L .41712 .37093 L F
1 .869 .56 r
.30114 .33414 m .33594 .3419 L .32814 .32716 L F
1 .795 .502 r
.29372 .31905 m .30114 .33414 L .32814 .32716 L F
.19 .081 .024 r
.33468 .17376 m .3719 .15646 L .36715 .16677 L F
.243 .108 .032 r
.33014 .18561 m .33468 .17376 L .36715 .16677 L F
1 1 .713 r
.76415 .24795 m .79165 .27223 L .79335 .25644 L F
1 1 .636 r
.76435 .23237 m .76415 .24795 L .79335 .25644 L F
1 1 .667 r
.53583 .37464 m .56189 .38408 L .56435 .3751 L F
.53583 .37464 m .53574 .38366 L .56189 .38408 L F
1 1 .661 r
.50729 .37504 m .50958 .38402 L .53574 .38366 L F
1 1 .653 r
.47914 .37628 m .50958 .38402 L .50729 .37504 L F
1 1 .896 r
.66234 .3593 m .68092 .37518 L .6905 .36362 L F
.66234 .3593 m .65445 .37119 L .68092 .37518 L F
.218 .087 .023 r
.59135 .13543 m .6234 .13179 L .62722 .13836 L F
.59135 .13543 m .58901 .12896 L .6234 .13179 L F
1 1 .732 r
.38105 .36327 m .39051 .37486 L .41712 .37093 L F
1 1 .661 r
.50729 .37504 m .53574 .38366 L .53583 .37464 L F
1 1 .887 r
.75562 .29632 m .77774 .31963 L .78382 .30404 L F
.75562 .29632 m .75018 .31223 L .77774 .31963 L F
.145 .053 .015 r
.44494 .13809 m .44865 .13153 L .48312 .1288 L F
.124 .045 .013 r
.41032 .14229 m .44865 .13153 L .44494 .13809 L F
.721 .485 .251 r
.27823 .25577 m .3092 .26337 L .30769 .24736 L F
.27823 .25577 m .27992 .27158 L .3092 .26337 L F
.803 .368 .098 r
.74849 .22842 m .74744 .21342 L .77821 .22166 L F
1 1 .781 r
.76263 .26395 m .78846 .28817 L .79165 .27223 L F
1 1 .713 r
.76415 .24795 m .76263 .26395 L .79165 .27223 L F
1 .795 .502 r
.29372 .31905 m .32814 .32716 L .32153 .31171 L F
.967 .718 .44 r
.28769 .30344 m .29372 .31905 L .32153 .31171 L F
1 1 .839 r
.75978 .28015 m .78382 .30404 L .78846 .28817 L F
.75978 .28015 m .75562 .29632 L .78382 .30404 L F
1 1 .781 r
.76263 .26395 m .75978 .28015 L .78846 .28817 L F
.298 .139 .042 r
.29349 .22101 m .32674 .1987 L .3245 .21285 L F
.347 .163 .049 r
.29232 .23593 m .29349 .22101 L .3245 .21285 L F
.804 .562 .314 r
.27992 .27158 m .31202 .27959 L .3092 .26337 L F
.27992 .27158 m .28308 .28754 L .31202 .27959 L F
.453 .193 .052 r
.67013 .16141 m .70007 .15693 L .70488 .16725 L F
.67013 .16141 m .66628 .1512 L .70007 .15693 L F
.967 .718 .44 r
.28769 .30344 m .32153 .31171 L .31614 .29577 L F
.886 .64 .377 r
.28308 .28754 m .28769 .30344 L .31614 .29577 L F
.343 .144 .039 r
.63055 .14678 m .66172 .14266 L .66628 .1512 L F
.63055 .14678 m .62722 .13836 L .66172 .14266 L F
.886 .64 .377 r
.28308 .28754 m .31614 .29577 L .31202 .27959 L F
.163 .065 .02 r
.3719 .15646 m .41032 .14229 L .40585 .15082 L F
.229 .099 .029 r
.36715 .16677 m .3719 .15646 L .40585 .15082 L F
1 1 .945 r
.707 .33652 m .72661 .35614 L .73562 .34237 L F
.707 .33652 m .69922 .35065 L .72661 .35614 L F
.198 .082 .024 r
.40585 .15082 m .41032 .14229 L .44494 .13809 L F
1 1 .686 r
.34487 .3557 m .38105 .36327 L .37245 .35027 L F
1 .989 .647 r
.33594 .3419 m .34487 .3557 L .37245 .35027 L F
1 1 .814 r
.59693 .36568 m .61976 .37854 L .62633 .36801 L F
.59693 .36568 m .59245 .37641 L .61976 .37854 L F
.207 .082 .022 r
.55464 .13392 m .58901 .12896 L .59135 .13543 L F
.55464 .13392 m .55382 .12751 L .58901 .12896 L F
.169 .065 .018 r
.48089 .13527 m .48312 .1288 L .51835 .12745 L F
.145 .053 .015 r
.44494 .13809 m .48312 .1288 L .48089 .13527 L F
1 1 .75 r
.44535 .3678 m .45176 .37835 L .47914 .37628 L F
1 1 .73 r
.41712 .37093 m .45176 .37835 L .44535 .3678 L F
.639 .283 .076 r
.71168 .19211 m .74174 .18618 L .74518 .19927 L F
.71168 .19211 m .70877 .17903 L .74174 .18618 L F
.243 .108 .032 r
.33014 .18561 m .36715 .16677 L .36332 .17855 L F
.294 .134 .04 r
.32674 .1987 m .33014 .18561 L .36332 .17855 L F
.19 .075 .021 r
.51764 .13387 m .55382 .12751 L .55464 .13392 L F
.51764 .13387 m .51835 .12745 L .55382 .12751 L F
.169 .065 .018 r
.48089 .13527 m .51835 .12745 L .51764 .13387 L F
1 1 .927 r
.66952 .34601 m .6905 .36362 L .69922 .35065 L F
.66952 .34601 m .66234 .3593 L .6905 .36362 L F
1 1 .889 r
.63239 .35585 m .65445 .37119 L .66234 .3593 L F
.63239 .35585 m .62633 .36801 L .65445 .37119 L F
1 1 .931 r
.71381 .32146 m .73562 .34237 L .7435 .32766 L F
.71381 .32146 m .707 .33652 L .73562 .34237 L F
1 1 .732 r
.38105 .36327 m .41712 .37093 L .40936 .35901 L F
1 1 .717 r
.37245 .35027 m .38105 .36327 L .40936 .35901 L F
1 1 .759 r
.40936 .35901 m .41712 .37093 L .44535 .3678 L F
1 1 .807 r
.56664 .36425 m .59245 .37641 L .59693 .36568 L F
.56664 .36425 m .56435 .3751 L .59245 .37641 L F
1 1 .768 r
.47483 .36554 m .47914 .37628 L .50729 .37504 L F
1 1 .75 r
.44535 .3678 m .47914 .37628 L .47483 .36554 L F
1 .989 .647 r
.33594 .3419 m .37245 .35027 L .36476 .33612 L F
1 .923 .597 r
.32814 .32716 m .33594 .3419 L .36476 .33612 L F
.331 .139 .038 r
.5934 .14377 m .62722 .13836 L .63055 .14678 L F
.5934 .14377 m .59135 .13543 L .62722 .13836 L F
.54 .235 .064 r
.67324 .17313 m .70488 .16725 L .70877 .17903 L F
.67324 .17313 m .67013 .16141 L .70488 .16725 L F
.231 .097 .028 r
.4417 .14651 m .44494 .13809 L .48089 .13527 L F
.198 .082 .024 r
.40585 .15082 m .44494 .13809 L .4417 .14651 L F
.713 .322 .087 r
.7136 .20628 m .74518 .19927 L .74744 .21342 L F
.7136 .20628 m .71168 .19211 L .74518 .19927 L F
.229 .099 .029 r
.36715 .16677 m .40585 .15082 L .40207 .16103 L F
.284 .127 .037 r
.36332 .17855 m .36715 .16677 L .40207 .16103 L F
.294 .134 .04 r
.32674 .1987 m .36332 .17855 L .36045 .19162 L F
.344 .159 .047 r
.3245 .21285 m .32674 .1987 L .36045 .19162 L F
1 1 .797 r
.53591 .36375 m .56435 .3751 L .56664 .36425 L F
.53591 .36375 m .53583 .37464 L .56435 .3751 L F
.439 .188 .051 r
.63337 .15691 m .66628 .1512 L .67013 .16141 L F
.63337 .15691 m .63055 .14678 L .66628 .1512 L F
1 1 .784 r
.50516 .36418 m .50729 .37504 L .53583 .37464 L F
1 1 .768 r
.47483 .36554 m .50729 .37504 L .50516 .36418 L F
1 1 .901 r
.71958 .30571 m .7435 .32766 L .75018 .31223 L F
.71958 .30571 m .71381 .32146 L .7435 .32766 L F
.267 .116 .034 r
.40207 .16103 m .40585 .15082 L .4417 .14651 L F
1 1 .784 r
.50516 .36418 m .53583 .37464 L .53591 .36375 L F
.72 .474 .233 r
.30749 .23176 m .30769 .24736 L .3404 .23996 L F
1 .923 .597 r
.32814 .32716 m .36476 .33612 L .35804 .32104 L F
1 .852 .541 r
.32153 .31171 m .32814 .32716 L .35804 .32104 L F
1 1 .926 r
.67594 .33157 m .69922 .35065 L .707 .33652 L F
.67594 .33157 m .66952 .34601 L .69922 .35065 L F
.313 .132 .037 r
.55536 .14222 m .59135 .13543 L .5934 .14377 L F
.55536 .14222 m .55464 .13392 L .59135 .13543 L F
1 1 .877 r
.60106 .35333 m .62633 .36801 L .63239 .35585 L F
.60106 .35333 m .59693 .36568 L .62633 .36801 L F
1 1 .692 r
.73167 .24047 m .76263 .26395 L .76415 .24795 L F
1 1 .62 r
.73185 .22475 m .73167 .24047 L .76415 .24795 L F
.262 .111 .031 r
.47894 .14361 m .48089 .13527 L .51764 .13387 L F
.231 .097 .028 r
.4417 .14651 m .48089 .13527 L .47894 .14361 L F
1 1 .861 r
.72429 .28951 m .75018 .31223 L .75562 .29632 L F
.72429 .28951 m .71958 .30571 L .75018 .31223 L F
1 1 .783 r
.43942 .35563 m .44535 .3678 L .47483 .36554 L F
1 1 .759 r
.40936 .35901 m .44535 .3678 L .43942 .35563 L F
1 1 .717 r
.37245 .35027 m .40936 .35901 L .4023 .3457 L F
1 1 .68 r
.36476 .33612 m .37245 .35027 L .4023 .3457 L F
.777 .357 .096 r
.71448 .22137 m .7136 .20628 L .74744 .21342 L F
.803 .55 .295 r
.30769 .24736 m .3417 .25615 L .3404 .23996 L F
.30769 .24736 m .3092 .26337 L .3417 .25615 L F
1 .852 .541 r
.32153 .31171 m .35804 .32104 L .35233 .30527 L F
1 .778 .482 r
.31614 .29577 m .32153 .31171 L .35233 .30527 L F
.344 .159 .047 r
.3245 .21285 m .36045 .19162 L .35856 .2058 L F
.394 .184 .055 r
.32347 .22786 m .3245 .21285 L .35856 .2058 L F
1 1 .756 r
.73035 .25665 m .75978 .28015 L .76263 .26395 L F
1 1 .692 r
.73167 .24047 m .73035 .25665 L .76263 .26395 L F
1 1 .812 r
.72788 .27308 m .75562 .29632 L .75978 .28015 L F
.72788 .27308 m .72429 .28951 L .75562 .29632 L F
1 1 .911 r
.63791 .3423 m .66234 .3593 L .66952 .34601 L F
.63791 .3423 m .63239 .35585 L .66234 .3593 L F
.618 .274 .074 r
.67557 .18619 m .70877 .17903 L .71168 .19211 L F
.67557 .18619 m .67324 .17313 L .70877 .17903 L F
.289 .122 .034 r
.51702 .14217 m .55464 .13392 L .55536 .14222 L F
.51702 .14217 m .51764 .13387 L .55464 .13392 L F
1 1 .756 r
.73035 .25665 m .72788 .27308 L .75978 .28015 L F
.262 .111 .031 r
.47894 .14361 m .51764 .13387 L .51702 .14217 L F
1 1 .746 r
.4023 .3457 m .40936 .35901 L .43942 .35563 L F
.884 .627 .358 r
.3092 .26337 m .34414 .27259 L .3417 .25615 L F
.3092 .26337 m .31202 .27959 L .34414 .27259 L F
1 .778 .482 r
.31614 .29577 m .35233 .30527 L .34769 .28904 L F
.963 .703 .42 r
.31202 .27959 m .31614 .29577 L .34769 .28904 L F
.284 .127 .037 r
.36332 .17855 m .40207 .16103 L .39902 .17274 L F
.337 .153 .045 r
.36045 .19162 m .36332 .17855 L .39902 .17274 L F
.963 .703 .42 r
.31202 .27959 m .34769 .28904 L .34414 .27259 L F
.42 .18 .05 r
.59513 .15385 m .63055 .14678 L .63337 .15691 L F
.59513 .15385 m .5934 .14377 L .63055 .14678 L F
.303 .132 .038 r
.43896 .15663 m .4417 .14651 L .47894 .14361 L F
.267 .116 .034 r
.40207 .16103 m .4417 .14651 L .43896 .15663 L F
1 1 .862 r
.56877 .35178 m .59693 .36568 L .60106 .35333 L F
.56877 .35178 m .56664 .36425 L .59693 .36568 L F
.52 .226 .062 r
.63564 .16858 m .67013 .16141 L .67324 .17313 L F
.63564 .16858 m .63337 .15691 L .67013 .16141 L F
1 1 .806 r
.47085 .35318 m .47483 .36554 L .50516 .36418 L F
1 1 .783 r
.43942 .35563 m .47483 .36554 L .47085 .35318 L F
1 1 .906 r
.68156 .31622 m .707 .33652 L .71381 .32146 L F
.68156 .31622 m .67594 .33157 L .707 .33652 L F
.325 .144 .042 r
.39902 .17274 m .40207 .16103 L .43896 .15663 L F
1 1 .68 r
.36476 .33612 m .4023 .3457 L .39598 .33124 L F
1 .974 .632 r
.35804 .32104 m .36476 .33612 L .39598 .33124 L F
1 1 .845 r
.53599 .35124 m .56664 .36425 L .56877 .35178 L F
.53599 .35124 m .53591 .36375 L .56664 .36425 L F
1 1 .826 r
.50319 .3517 m .50516 .36418 L .53591 .36375 L F
1 1 .806 r
.47085 .35318 m .50516 .36418 L .50319 .3517 L F
.687 .311 .084 r
.67711 .20039 m .71168 .19211 L .7136 .20628 L F
.67711 .20039 m .67557 .18619 L .71168 .19211 L F
1 1 .826 r
.50319 .3517 m .53591 .36375 L .53599 .35124 L F
.337 .153 .045 r
.36045 .19162 m .39902 .17274 L .39673 .1858 L F
.389 .179 .053 r
.35856 .2058 m .36045 .19162 L .39673 .1858 L F
1 1 .892 r
.60482 .33959 m .63239 .35585 L .63791 .3423 L F
.60482 .33959 m .60106 .35333 L .63239 .35585 L F
.395 .17 .047 r
.55597 .15227 m .5934 .14377 L .59513 .15385 L F
.55597 .15227 m .55536 .14222 L .5934 .14377 L F
1 1 .903 r
.64285 .32762 m .66952 .34601 L .67594 .33157 L F
.64285 .32762 m .63791 .3423 L .66952 .34601 L F
.337 .146 .041 r
.47729 .15368 m .47894 .14361 L .51702 .14217 L F
.303 .132 .038 r
.43896 .15663 m .47894 .14361 L .47729 .15368 L F
1 1 .773 r
.43403 .34207 m .43942 .35563 L .47085 .35318 L F
1 1 .746 r
.4023 .3457 m .43942 .35563 L .43403 .34207 L F
1 1 .873 r
.68632 .3002 m .71381 .32146 L .71958 .30571 L F
.68632 .3002 m .68156 .31622 L .71381 .32146 L F
1 1 .711 r
.39598 .33124 m .4023 .3457 L .43403 .34207 L F
1 .974 .632 r
.35804 .32104 m .39598 .33124 L .39046 .31587 L F
1 .906 .578 r
.35233 .30527 m .35804 .32104 L .39046 .31587 L F
.368 .159 .044 r
.51649 .15221 m .55536 .14222 L .55597 .15227 L F
.51649 .15221 m .51702 .14217 L .55536 .14222 L F
.337 .146 .041 r
.47729 .15368 m .51702 .14217 L .51649 .15221 L F
.801 .537 .276 r
.34022 .22423 m .3404 .23996 L .37596 .23371 L F
.592 .263 .072 r
.63735 .18163 m .67324 .17313 L .67557 .18619 L F
.63735 .18163 m .63564 .16858 L .67324 .17313 L F
.494 .216 .059 r
.59653 .16548 m .63337 .15691 L .63564 .16858 L F
.59653 .16548 m .59513 .15385 L .63337 .15691 L F
.325 .144 .042 r
.39902 .17274 m .43896 .15663 L .43675 .1683 L F
.379 .171 .05 r
.39673 .1858 m .39902 .17274 L .43675 .1683 L F
1 1 .831 r
.69021 .28374 m .71958 .30571 L .72429 .28951 L F
.69021 .28374 m .68632 .3002 L .71958 .30571 L F
.363 .16 .046 r
.43675 .1683 m .43896 .15663 L .47729 .15368 L F
.746 .343 .093 r
.67782 .21554 m .67711 .20039 L .7136 .20628 L F
1 1 .664 r
.69631 .23413 m .73035 .25665 L .73167 .24047 L F
1 1 .596 r
.69645 .21829 m .69631 .23413 L .73167 .24047 L F
1 .906 .578 r
.35233 .30527 m .39046 .31587 L .38578 .29983 L F
1 .835 .521 r
.34769 .28904 m .35233 .30527 L .38578 .29983 L F
.389 .179 .053 r
.35856 .2058 m .39673 .1858 L .39523 .2 L F
.44 .205 .061 r
.35769 .22089 m .35856 .2058 L .39523 .2 L F
1 1 .87 r
.5707 .33793 m .60106 .35333 L .60482 .33959 L F
.5707 .33793 m .56877 .35178 L .60106 .35333 L F
.883 .614 .339 r
.3404 .23996 m .37703 .25006 L .37596 .23371 L F
.3404 .23996 m .3417 .25615 L .37703 .25006 L F
1 1 .799 r
.46722 .33943 m .47085 .35318 L .50319 .3517 L F
1 1 .773 r
.43403 .34207 m .47085 .35318 L .46722 .33943 L F
1 1 .781 r
.69318 .26709 m .72429 .28951 L .72788 .27308 L F
.69318 .26709 m .69021 .28374 L .72429 .28951 L F
1 1 .726 r
.69521 .25047 m .72788 .27308 L .73035 .25665 L F
1 1 .664 r
.69631 .23413 m .69521 .25047 L .73035 .25665 L F
1 1 .878 r
.64717 .31203 m .67594 .33157 L .68156 .31622 L F
.64717 .31203 m .64285 .32762 L .67594 .33157 L F
1 1 .726 r
.69521 .25047 m .69318 .26709 L .72788 .27308 L F
1 .835 .521 r
.34769 .28904 m .38578 .29983 L .38196 .28336 L F
1 .763 .461 r
.34414 .27259 m .34769 .28904 L .38196 .28336 L F
1 1 .711 r
.39598 .33124 m .43403 .34207 L .42921 .32737 L F
1 1 .665 r
.39046 .31587 m .39598 .33124 L .42921 .32737 L F
.961 .689 .4 r
.3417 .25615 m .37903 .26669 L .37703 .25006 L F
.3417 .25615 m .34414 .27259 L .37903 .26669 L F
1 .763 .461 r
.34414 .27259 m .38196 .28336 L .37903 .26669 L F
1 1 .878 r
.60818 .32473 m .63791 .3423 L .64285 .32762 L F
.60818 .32473 m .60482 .33959 L .63791 .3423 L F
1 1 .741 r
.42921 .32737 m .43403 .34207 L .46722 .33943 L F
1 1 .848 r
.53606 .33735 m .56877 .35178 L .5707 .33793 L F
.53606 .33735 m .53599 .35124 L .56877 .35178 L F
.465 .203 .057 r
.55646 .16389 m .59513 .15385 L .59653 .16548 L F
.55646 .16389 m .55597 .15227 L .59513 .15385 L F
1 1 .824 r
.5014 .33785 m .50319 .3517 L .53599 .35124 L F
1 1 .799 r
.46722 .33943 m .50319 .3517 L .5014 .33785 L F
.399 .176 .05 r
.47596 .16531 m .47729 .15368 L .51649 .15221 L F
.363 .16 .046 r
.43675 .1683 m .47729 .15368 L .47596 .16531 L F
.657 .297 .082 r
.63848 .19585 m .67557 .18619 L .67711 .20039 L F
.63848 .19585 m .63735 .18163 L .67557 .18619 L F
1 1 .824 r
.5014 .33785 m .53599 .35124 L .53606 .33735 L F
.379 .171 .05 r
.39673 .1858 m .43675 .1683 L .43509 .18134 L F
.433 .198 .058 r
.39523 .2 m .39673 .1858 L .43509 .18134 L F
.563 .251 .069 r
.59757 .17851 m .63564 .16858 L .63735 .18163 L F
.59757 .17851 m .59653 .16548 L .63564 .16858 L F
1 1 .842 r
.65084 .29579 m .68156 .31622 L .68632 .3002 L F
.65084 .29579 m .64717 .31203 L .68156 .31622 L F
.433 .19 .053 r
.51607 .16383 m .55597 .15227 L .55646 .16389 L F
.51607 .16383 m .51649 .15221 L .55597 .15227 L F
.42 .189 .054 r
.43509 .18134 m .43675 .1683 L .47596 .16531 L F
.399 .176 .05 r
.47596 .16531 m .51649 .15221 L .51607 .16383 L F
1 1 .665 r
.39046 .31587 m .42921 .32737 L .42499 .31176 L F
1 .958 .613 r
.38578 .29983 m .39046 .31587 L .42499 .31176 L F
1 1 .852 r
.57243 .32295 m .60482 .33959 L .60818 .32473 L F
.57243 .32295 m .5707 .33793 L .60482 .33959 L F
1 1 .77 r
.46398 .32455 m .46722 .33943 L .5014 .33785 L F
1 1 .741 r
.42921 .32737 m .46722 .33943 L .46398 .32455 L F
.879 .599 .318 r
.37582 .21786 m .37596 .23371 L .41389 .22873 L F
.713 .328 .09 r
.63899 .21105 m .63848 .19585 L .67711 .20039 L F
1 1 .849 r
.61113 .30897 m .64285 .32762 L .64717 .31203 L F
.61113 .30897 m .60818 .32473 L .64285 .32762 L F
1 1 .798 r
.65383 .27912 m .68632 .3002 L .69021 .28374 L F
.65383 .27912 m .65084 .29579 L .68632 .3002 L F
1 1 .697 r
.42499 .31176 m .42921 .32737 L .46398 .32455 L F
.433 .198 .058 r
.39523 .2 m .43509 .18134 L .434 .19557 L F
.484 .225 .066 r
.39454 .21516 m .39523 .2 L .434 .19557 L F
1 .958 .613 r
.38578 .29983 m .42499 .31176 L .4214 .2955 L F
1 .89 .558 r
.38196 .28336 m .38578 .29983 L .4214 .2955 L F
.531 .237 .066 r
.55683 .17691 m .59653 .16548 L .59757 .17851 L F
.55683 .17691 m .55646 .16389 L .59653 .16548 L F
1 1 .633 r
.65853 .22905 m .69521 .25047 L .69631 .23413 L F
1 .98 .568 r
.65864 .21312 m .65853 .22905 L .69631 .23413 L F
.459 .206 .058 r
.47496 .17834 m .47596 .16531 L .51607 .16383 L F
.42 .189 .054 r
.43509 .18134 m .47596 .16531 L .47496 .17834 L F
1 1 .825 r
.53612 .32233 m .5707 .33793 L .57243 .32295 L F
.53612 .32233 m .53606 .33735 L .5707 .33793 L F
.958 .675 .38 r
.37596 .23371 m .41472 .2452 L .41389 .22873 L F
.37596 .23371 m .37703 .25006 L .41472 .2452 L F
1 1 .748 r
.65612 .26229 m .69021 .28374 L .69318 .26709 L F
.65612 .26229 m .65383 .27912 L .69021 .28374 L F
1 1 .798 r
.49979 .32286 m .5014 .33785 L .53606 .33735 L F
1 1 .77 r
.46398 .32455 m .5014 .33785 L .49979 .32286 L F
.624 .283 .078 r
.59826 .19275 m .63735 .18163 L .63848 .19585 L F
.59826 .19275 m .59757 .17851 L .63735 .18163 L F
.475 .217 .062 r
.434 .19557 m .43509 .18134 L .47496 .17834 L F
1 1 .693 r
.65769 .24552 m .69318 .26709 L .69521 .25047 L F
1 1 .633 r
.65853 .22905 m .65769 .24552 L .69521 .25047 L F
1 .89 .558 r
.38196 .28336 m .4214 .2955 L .41848 .27883 L F
1 .82 .5 r
.37903 .26669 m .38196 .28336 L .41848 .27883 L F
1 1 .693 r
.65769 .24552 m .65612 .26229 L .69318 .26709 L F
1 1 .798 r
.49979 .32286 m .53606 .33735 L .53612 .32233 L F
1 .748 .441 r
.37703 .25006 m .41625 .26198 L .41472 .2452 L F
.37703 .25006 m .37903 .26669 L .41625 .26198 L F
1 .82 .5 r
.37903 .26669 m .41848 .27883 L .41625 .26198 L F
.496 .222 .062 r
.51575 .17686 m .55646 .16389 L .55683 .17691 L F
.51575 .17686 m .51607 .16383 L .55646 .16389 L F
.459 .206 .058 r
.47496 .17834 m .51607 .16383 L .51575 .17686 L F
1 1 .81 r
.61363 .29256 m .64717 .31203 L .65084 .29579 L F
.61363 .29256 m .61113 .30897 L .64717 .31203 L F
1 1 .697 r
.42499 .31176 m .46398 .32455 L .46114 .30878 L F
1 1 .647 r
.4214 .2955 m .42499 .31176 L .46114 .30878 L F
1 1 .819 r
.57394 .30708 m .60818 .32473 L .61113 .30897 L F
.57394 .30708 m .57243 .32295 L .60818 .32473 L F
1 1 .728 r
.46114 .30878 m .46398 .32455 L .49979 .32286 L F
.679 .313 .087 r
.59858 .20799 m .59826 .19275 L .63848 .19585 L F
.59 .268 .075 r
.55708 .19115 m .59757 .17851 L .59826 .19275 L F
.55708 .19115 m .55683 .17691 L .59757 .17851 L F
.515 .235 .067 r
.4743 .19258 m .47496 .17834 L .51575 .17686 L F
.475 .217 .062 r
.434 .19557 m .47496 .17834 L .4743 .19258 L F
.526 .244 .07 r
.43349 .21077 m .434 .19557 L .4743 .19258 L F
.953 .658 .359 r
.41379 .21279 m .41389 .22873 L .45366 .22512 L F
1 1 .764 r
.61567 .27575 m .65084 .29579 L .65383 .27912 L F
.61567 .27575 m .61363 .29256 L .65084 .29579 L F
1 1 .789 r
.53617 .30642 m .57243 .32295 L .57394 .30708 L F
.53617 .30642 m .53612 .32233 L .57243 .32295 L F
1 1 .647 r
.4214 .2955 m .46114 .30878 L .45872 .29237 L F
1 .944 .594 r
.41848 .27883 m .4214 .2955 L .45872 .29237 L F
1 1 .759 r
.49838 .30699 m .49979 .32286 L .53612 .32233 L F
1 1 .728 r
.46114 .30878 m .49979 .32286 L .49838 .30699 L F
1 1 .759 r
.49838 .30699 m .53612 .32233 L .53617 .30642 L F
.553 .252 .071 r
.51554 .1911 m .55683 .17691 L .55708 .19115 L F
.51554 .1911 m .51575 .17686 L .55683 .17691 L F
.515 .235 .067 r
.4743 .19258 m .51575 .17686 L .51554 .1911 L F
1 1 .6 r
.61888 .22534 m .65769 .24552 L .65853 .22905 L F
1 .93 .537 r
.61895 .20933 m .61888 .22534 L .65853 .22905 L F
1 1 .778 r
.57523 .29057 m .61113 .30897 L .61363 .29256 L F
.57523 .29057 m .57394 .30708 L .61113 .30897 L F
1 1 .714 r
.61723 .25878 m .65383 .27912 L .65612 .26229 L F
.61723 .25878 m .61567 .27575 L .65383 .27912 L F
1 .733 .42 r
.41389 .22873 m .45422 .24168 L .45366 .22512 L F
.41389 .22873 m .41472 .2452 L .45422 .24168 L F
1 1 .68 r
.45872 .29237 m .46114 .30878 L .49838 .30699 L F
1 .944 .594 r
.41848 .27883 m .45872 .29237 L .45676 .27555 L F
1 .876 .538 r
.41625 .26198 m .41848 .27883 L .45676 .27555 L F
1 1 .659 r
.6183 .24189 m .65612 .26229 L .65769 .24552 L F
1 1 .6 r
.61888 .22534 m .6183 .24189 L .65769 .24552 L F
1 1 .659 r
.6183 .24189 m .61723 .25878 L .65612 .26229 L F
1 .806 .48 r
.41472 .2452 m .45525 .25857 L .45422 .24168 L F
.41472 .2452 m .41625 .26198 L .45525 .25857 L F
1 .876 .538 r
.41625 .26198 m .45676 .27555 L .45525 .25857 L F
.643 .297 .083 r
.55719 .20641 m .55708 .19115 L .59826 .19275 L F
.567 .262 .075 r
.474 .20782 m .4743 .19258 L .51554 .1911 L F
1 1 .745 r
.53622 .28988 m .57394 .30708 L .57523 .29057 L F
.53622 .28988 m .53617 .30642 L .57394 .30708 L F
1 1 .713 r
.49719 .29048 m .49838 .30699 L .53617 .30642 L F
1 1 .68 r
.45872 .29237 m .49838 .30699 L .49719 .29048 L F
1 1 .731 r
.57628 .27367 m .61363 .29256 L .61567 .27575 L F
.57628 .27367 m .57523 .29057 L .61363 .29256 L F
1 .715 .397 r
.45359 .20911 m .45366 .22512 L .49468 .22294 L F
1 .996 .628 r
.45676 .27555 m .45872 .29237 L .49719 .29048 L F
.605 .28 .079 r
.51544 .20635 m .51554 .1911 L .55708 .19115 L F
1 1 .713 r
.49719 .29048 m .53617 .30642 L .53622 .28988 L F
1 .954 .566 r
.57793 .22305 m .6183 .24189 L .61888 .22534 L F
1 .878 .504 r
.57797 .20701 m .57793 .22305 L .61888 .22534 L F
1 1 .679 r
.57708 .25662 m .61567 .27575 L .61723 .25878 L F
.57708 .25662 m .57628 .27367 L .61567 .27575 L F
1 .79 .459 r
.45366 .22512 m .49496 .23956 L .49468 .22294 L F
.45366 .22512 m .45422 .24168 L .49496 .23956 L F
1 .996 .628 r
.45676 .27555 m .49719 .29048 L .49621 .27357 L F
1 .93 .574 r
.45525 .25857 m .45676 .27555 L .49621 .27357 L F
1 1 .625 r
.57763 .23967 m .61723 .25878 L .6183 .24189 L F
1 .954 .566 r
.57793 .22305 m .57763 .23967 L .6183 .24189 L F
1 1 .697 r
.53626 .27294 m .57523 .29057 L .57628 .27367 L F
.53626 .27294 m .53622 .28988 L .57523 .29057 L F
1 1 .625 r
.57763 .23967 m .57708 .25662 L .61723 .25878 L F
1 .771 .434 r
.49465 .2069 m .49468 .22294 L .53632 .22225 L F
1 1 .663 r
.49621 .27357 m .49719 .29048 L .53622 .28988 L F
1 .862 .517 r
.45422 .24168 m .49547 .25652 L .49496 .23956 L F
.45422 .24168 m .45525 .25857 L .49547 .25652 L F
1 .93 .574 r
.45525 .25857 m .49621 .27357 L .49547 .25652 L F
1 .825 .47 r
.53632 .20619 m .53632 .22225 L .57793 .22305 L F
1 1 .663 r
.49621 .27357 m .53622 .28988 L .53626 .27294 L F
1 .9 .531 r
.53632 .22225 m .57763 .23967 L .57793 .22305 L F
1 1 .645 r
.53629 .25586 m .57628 .27367 L .57708 .25662 L F
.53629 .25586 m .53626 .27294 L .57628 .27367 L F
1 .846 .496 r
.49468 .22294 m .53631 .23888 L .53632 .22225 L F
.49468 .22294 m .49496 .23956 L .53631 .23888 L F
1 .984 .61 r
.49547 .25652 m .49621 .27357 L .53626 .27294 L F
1 .971 .59 r
.53631 .23888 m .57708 .25662 L .57763 .23967 L F
1 .9 .531 r
.53632 .22225 m .53631 .23888 L .57763 .23967 L F
1 .971 .59 r
.53631 .23888 m .53629 .25586 L .57708 .25662 L F
1 .984 .61 r
.49547 .25652 m .53626 .27294 L .53629 .25586 L F
1 .916 .554 r
.49496 .23956 m .53629 .25586 L .53631 .23888 L F
.49496 .23956 m .49547 .25652 L .53629 .25586 L F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[309]:=",
  ImageSize->{400, 226.063},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000hR000`400?l00000o`00003oo`3ooonA
0?ooo`00o`2?_8n@08nlS`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00o`2?
_8n@08nlS`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nlS`40
oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nlS`40oooo003o08nl
Si00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nlS`40oooo003o08nlSi00Skb?0@3o
ool00?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nlS`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?
T02?_8l10?ooo`00o`2?_8n@08nlS`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?oo
o`00o`2?_8n@08nlS`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00o`2?_8n@
08nlS`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nlS`40oooo
003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nlS`40oooo003o08nlSi00
Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nlS`40oooo003o08nlSi00Skb?0@3oool0
0?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nlS`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?
_8l10?ooo`00o`2?_8n@08nlS`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00
o`2?_8n@08nlS`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nl
S`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00`P2?_8l=04<W2`h04@H1300C
1P6V08nlS`40oooo002f08nlS`/02`<13P0K2@8=01h:0Pd080/3300D1`:J08nlS`40oooo002Z08nl
S`X01`803@0H208=01/90Ph07PX23P0P2`<<028<0`D05@L20`0o9@ZA08nlS`40oooo002U08nlS`@0
0P001@070P0601@60P`060P23P0[40@?030C1@d0=1@53@0R30<602<<0`<05@L20`109@^<08nlS`40
oooo002O08nlS`T00P002`0D1P8=02D=0`h0:a043`0`4`D>03@D1@d0=aH52`0S30<301D70P80@2D;
Q`2?_8l10?ooo`00W02?_8l2000000@00P000`0?1@4=01l;0`d09@d33`0[40@?030C1@h0=1@53P0g
5PD603PF1@D08``31@0T30<301D70P03048V2`2?_8l0Skb?0800Skb?0@3oool009P0Skb?10000005
00l50@@06@P2300O2`<>03/H1`l0@a`73`197`P?050Q2@L0E2<91`0g5PD;03PF1@X090`30P0C1P40
0`129P/0Skb?08nlS`1k08nlS`40oooo002D08nlS`<0000010090`0200l50@L06@P21P0O2`<7038D
1Ph0>aP73`1370L?04TO20l0D2493P1D8`T<03PF1@H0=aH51@0T30<402<<0`0301<60@2?_8l0Skb?
07L0Skb?0@3oool00900Skb?00<0000000T300090`001P090`0:01T80Ph0<Q@63P0k60L?04<L1`l0
BAl83`1@8@T?05@S2@`0Eb@92`0g5PD802<<0gD0Skb?0@3oool008/0Skb?0`0000000`0200002@<0
00T3000200T300D04PH11@0I208602T@1@h0<Q@63P0k60L?05HU2Pl0GRP;3`1U:``?05@S2@d0Eb@9
1P1H9@T503LF1@D0=Q@5100S30<2028<0g40Skb?0@3oool008P0Skb?00<0Ec0=0000000200000P02
000901860@d0:A053@0b50H?04dQ2@l0ERD:3`1N:0/@06D[30h0Jbh<3@1G90T<05PU2@T0=Q@5100R
30=^08nlS`40oooo002508nlS`0305L`3@0200000P0000800P000P0<104601860@@08@`3300Y40D>
04@M20l0CB493`1F9@X?05hX2a00IB/<3`1[;P`6070`3@L0Eb@9301H9@T305HT2@H0=Q@50`0c4`D3
028<0f/0Skb?0@3oool00880Skb?00@0Ec0=0000000200000P001@0<104301860@L08@`32@0Y40D4
03XI1`h0A1d83`1=8@T?05HU2Pl0GRP;401U:``?06/^30d0L30=3@1H9@T605HT2@<0=Q@51P0c4`D0
0`0R30<07`/308nlS`1W08nlS`40oooo002008nlS`800000200<104;024<0`@0:A052@0j6@L>04@M
20h0CB49401V;@`?06h`3A00Mc<>3`1[;P`>070`3@H0Lc4=1`1H9@T905HT2@P0<a<50P0O2`=U08nl
S`40oooo001m08nlS`8000000P040@0600`40@8060T22`0Q30<=03XI1`h0A1d83`1L:0/@06H]30l0
KS0=401g<`h?07hg3`h0L30=3@1c<@d:05HT2@<0DB481P0c4`D00`0`4P@07`/301l;0`1R08nlS`40
oooo001k08nlS`03000000040@001040008010400`0<104501P90PH08@`31P0`50H=03XI1`L0A1d8
1`1C90X?05`X2a00IRd<3`1^<0d@07Lc3Q00OSL?1`25>@l7070`3@d0Lc4=0`1d<@d705HT2@H0DB48
0`0c4`D2030B10807`/3H02?_8l10?ooo`00N@2?_8l600@100P060T2300`50H=03XI1`l0Db@:3`1L
:0/@06H]30l0KS0=401g<`h@07hg3`h0QCT?3@1c<@d707@a3@@0ER@92@1A8@P3030B100301l;0`0K
2@80Skb?05d0Skb?0@3oool007L0Skb?00<0000000@100040@000`040@0200d40@H060T20P0U3`@<
030D1PH0>QT71`1880T?05<T2Ph0G2P;401V;@`@06h`3A00Mc<>401n=`l?08Di3`H0RS`@1`1c<@d:
07@a3@X0DB480P187@L2030B10806`T2G02?_8l10?ooo`00M@2?_8l2000000<01040100=104401P9
0PD09@l42`0`50H>04PP2@h0Db@:3`1[<0d@07Dd3Q40OSP?4027?10709104@P0OSL?3`25>@l=08Xl
40/0M34=0`1b<0d7054Q20<0B1d70P0`4P@00`0[3`@06`T208nlS`1I08nlS`40oooo001c08nlS`<0
00000P040@0500d40@8060T21`0U3`@8030D1P@0?Q/83P1880T705<T2PL0HB/<3`1[<0d@07Dd3Q40
OSP?4027?10?09104@l0QCT?3P2:?10308hm40L0M34=1`1b<0d4054Q20@0B1d700D0<18402/?100[
3`@0:`l401/90P1G08nlS`40oooo001a08nlS`@000001`0=104:02D?10@0<1@6200n6`P=04PP2@l0
HB/<3`1[<0d@07Dd3Q40OSP?4027?10@09104@h0Ud<B3P2:?10708hm40@0M34=2P1b<0d604PM1`D0
:`l4E@2?_8l10?ooo`00KP2?_8l0101N<`d0000000000000000200<100D03@@10`0K2`<902D?10d0
?Q/82@1880T405HW2`l0HB/<3`1[<0d@07Dd3Q40OSP?4027?10@09104@l0Ud<B102NAQ8908Xl40/0
SSd@2`1b<0d306/]30@0B1d700D0?aX602/?100[3`@0:`l402D=0`1C08nlS`40oooo001]08nlS`80
000010030@0300d40@D06`/31P0U3`@403<F1Pd0?Q/8101880T905HW2`l0HB/<3`1[<0d@07Dd3Q40
OSP?4027?10@09104@l0Ud<B2@2NAQ8408Xl40`0SSd@0`2??A07078`3@H0Jbd<0P187@L203lJ1P80
:`l40P0U3@=A08nlS`40oooo001[08nlS`03000000030@000`4000@00`40200K2`<302D?10L0<aH6
3@0n6`P>05HW2`l0HB/<1`1[<0d807Tg3a00Pc`A4@2=@18@09M44a00T40A3`2G@a8=09i64P`0SSd@
1`2??A04078`3@P0Jbd<0`0o6PH0100[3`@09@d302D=0`0U3@=?08nlS`40oooo001Y08nlS`<00000
10030@0200l60PL06`/32`0c5PH603hK20L0Bb8:3P1F9`/>064[3100NCL?4023?14A08e04Q00Ud@C
402OB1<?09M34Ph0WTHB102SB1<808hm40X0Scd@2@1[;@`205hX2P80?aX60`0U3@=>08nlS`40oooo
001X08nlS`<000000`030@0300l60PD06`/30`0X4@D:03<F1Ph0Bb8:3@1F9`/?06hb3Q00NCL?4023
?14A08e04Q00Ud@C402OB1<80:Q<50L0Ud<B3P2NAQ880:=84`@0SSd@2`2??A0208/l3`L0Jbd<0`1N
:0X203lJ1P809@d300<07PX208nlS`2?_8l0BP2?_8l10?ooo`00I`2?_8l3000000800`40100?1P83
01/;0`H0:1451`0c5PH303lL20d0Bb8:2@1F9`/506<]3@l0KS8>401i=`l@08<l4A40SD0B402GA1<@
09m84`l0Z4`D3P2NAQ8<0:=84`/0Scd@1@2;?0l406/]30D0GRP:00@0?aX603TG1@0U3@<07PX2B`2?
_8l10?ooo`00I@2?_8l4000000H03`H22@0X4@D503<F1PH0?a`83@1;8PX405HW2`X0Hbd=3`1^<Ph@
07Tg3a00Pc`A4@2=@18@09M44a00WdPC402XC1@60:m?5@L0WTHB3@2SB1<30:I94`P0Scd@1`2;?0l2
06/]30H0GRP:0P0i5`D00`0N2P80Skb?08nlS`1808nlS`40oooo001T08nlS`D00000100?1P8201`;
0`T0:1450P0c5PH903lL20`0Bb8:3`1S;@d?06hb3Q00NCL?4023?14A08e04Q00Ud@C402OB1<@0:Q<
50d0[dlE3@2SB1<70:I94`@0Scd@2@2;?0l705hX2P0304dP200i5`D07PX204T0Skb?0@3oool006<0
Skb?1@00000300l60P@070/3200X4@D<03lL20P0Bb8:101H:0`?06<]3@l0KS8>4026?Q4@09534a40
VTLD402TC1D@0:e@5Q00Z4`D3P2_CaD40;IB5PT0XdPC2P2VBA<:08/l3`80PCL>1@1N:0X0101=80P0
>AL5030B100N2P9708nlS`40oooo001R08nlS`D000000P0?1P8501`;0`H0:1450`0d5`L<03lL20@0
Bb8:201H:0`?06<]3@L0KS8>201k>A0@08Hn4A00TD<C4@2JAa@@0:A<5@d0[E0F00<0oh@T0:e@5P2]
D1H0202fDaL80:Q<50h0[dlE2@2fDQH40:=84`d0YTTC1`2;?0l4084g3P<0GRP:0`1=80P00`0`4P@0
7PX208nlS`1508nlS`40oooo001Q08nlS`D00000200L2`<302PA1@H0=1L72`0o70P=05PX30h0Hbd=
401k>A0@08Hn4A00TD<C4@2JAa@@0:A<5@X0[E0F00<0oh@T0:e@5P2]D1H00`2]D1H@0;IC5`h0[dlE
3@2fDQH@0:I94`D0Rc`?1@21=`h205hX2P<0CB080P0`4PA508nlS`40oooo001O08nlS`H0000000<0
3PH201`;0`0L2`<01@0L2`<:03@G1`L0?a`8101<8`X=05PX30L0Hbd=1`1`=0l@07/i4100QShA402A
@a<A09Y75100Y4`E1`2]D1H00`3oQ2@0[E0F0:e@5P060:e@5P`0]U<G00@0m80S0;IC5`2fDaL0]U<G
1@2nEaL90:m?5@h0]U8F0`2kE1H?0:I94`80Rc`?1`21=`h404dP2080<184A02?_8l10?ooo`00GP2?
_8l5000000803PH21P0L2`<202LA1@X0=1L70`0o70P804`S2Pd0F2P<3P1`=0l@07/i4100QShA402A
@a<A09Y75100Y4`E102]D1H00`3oPR@0[E0F0:e@5P090:e@5PP0]U<G00<0n88T0;IC5`2fDaL01@2f
DaL:0;iG5`@0[dlE3P2fDQH70;]D5Pd0YTTC2021=`h01P1_<0`0CB0804dP201=80P0@a`6030B14<0
Skb?0@3oool005d0Skb?1@00000300h60P<070/31@0W4@D903@G1``0C2<:2@1H:0`406@_3Ph0L3@?
401k>A0@08Hn4A00TD<C202JAa@50?oCN0@0VTLD402TC1D00`3kP2@0oh8T0:e@5P0=0:e@5P@0]U<G
0P3oQbD:0;IC5`h0_ULG3P2fDQH;0;]D5PX0YTTC0P2QAQ85084g3P<0Kc0<0P1=80P00`1370H0<184
08nlS`1108nlS`40oooo001L08nlS`@00000100>1P8201`;0`H09a451`0d5`L3040M2@`0C2<:101H
:0`906@_3Ph0L3@?401k>A0408Hn4@<0]UhL00<0_64L0?ngI@3o]fD03P3o]fD@0?o5K`<0om=h0`3V
M24;0?oCN0`0on21302]D1H20?n79@h0]U<G3P2nEaL70<IK60L0]U8F302kE1H20;eE5PL0YTTC102Q
AQ84084g3P@0Kc0<00<0CB0804<L1P1370H0@@2?_8l10?ooo`00F`2?_8l3000000D03PH22@0W4@D3
03@G1`L0@1d92`1<8`X:06@_3P040:iM6`1T;`h0I2l>06@_3Ph0L3@?301k>A0<0?>XF`@0okMU00<0
_64L0?ngI@3o]fD02@3o]fD@0?o5K`H0om=h00<0iW@Q0>ag8@3odgP0203odgP@0?oPP@`0onj9302f
DaL50;iG5`030>Mj8@2nEaL0_ULG00H0_ULG3P36FaP<0;]D5PD0_EDF1@2VBA<50:564P80PCL>1@1_
<0`304<L1T00Skb?0@3oool005X0Skb?0`00000010020@003PH200h60P0>1P8201X;10P09a452`10
7@T704`S2P@0F2T<3P1T;`h>070d3`@0NcT@103QVE4@0?>XF`L0okMU00<0^UlL0?ngI@3o]fD01P3o
]fD@0?o5K`T0om=h00<0k7LQ0?oCN03odgP01@3odgP@0?oPPA00onj9103onY440;IC5`80igXQ302n
EaL>0<IK60<0cEhI2@2kE1H80;eE5P80YTTC1`2QAQ8606l`300305PV2@1370H0@a`603l0Skb?0@3o
ool005T0Skb?0P000002008100803PH2100J2`@602LA1@80=1P72`107@T304`S2PP0F2T<3@1T;`h0
0`2MDaP0L3@?070d3`08070d3``0hIUA403cZ5/:0?ngI@030<5R703o]fD0okMU00<0okMU403oaFl<
0?oCN0030?5j8P3odgP0om=h0080om=h403oh84@0?o^R@/0ooZA2`2nEaL90<IK60030<AY7@36FaP0
aU/H0080aU/H1P3=GQT60;]D5PX0_EDF202QAQ800`2B@100Kc0<06l`300306l`300305PV2@1370H0
@a`603h0Skb?0@3oool005P0Skb?0P0000020081000300h60P0J2`@06P/400<06P/4100W4@D503@H
1`X0@1d9301H:@`=06@_3P@0L3@?103=RDH?0>6IDA00ljQK3@3o]fD00`31HQ`0okMU0?ngI@0@0?o5
Ka40om=h403oh84@0?o^R@D0ooZA00<0igXQ0?ojT@3onY401`3onY440?ooV0<0_ULG3P36FaP90<eN
6@<0^e@F2`2mEAH20;]D5PD0XDHB0`2B@10306l`30<0F2H900<0@a`608nlS`2?_8l0>`2?_8l10?oo
o`00E`2?_8l0100000000P40008100020@0701X;10809a451`0d60L8040M2@80C2@;301H:@`:06@_
3P/0cHU63`3QVE4@0?>XFa00okMU403oaFlA0?oCN100on21403okXT?0?ojT@/0oonH2P36FaP<0<eN
6@/0_EDF102kE1H40:564P@0TT0@0P1_<0`305PV2@0303LF1@2?_8l0Skb?03X0Skb?0@3oool005L0
Skb?00@00000008100020@002PD21P0J2`@:03@H1`D0@1d91@1<90/505PY30030=1_7`1H:@`0F2T<
00@0F2T<0`1T;`h20;mV7@030:QJ6P3=RDH0cHU600d0cHU63`3QVE4@0?>XFa00olYe403of7hA0?oV
Qa00ooB@403okXT?0?ojT@h0oonH00<0`FLM0<IK6036FaP01036FaP60<eN6@030;5N6`3=GQT0cEhI
00<0cEhI103AH1T70;eE5PH0^e@F0P2QAQ86099040@0F2H900<0=aH508nlS`2?_8l0>@2?_8l10?oo
o`00EP2?_8l00`0000000P400081000200X50PD06P/400<09A0503@H1`0d60L0200d60L2040M2@P0
C2@;301H:@`60;Qi>`D0cHU60P2XFQX80<f9APl0hIUA203cZ5/80?nkJa00olYe403of7hA0?oVQa00
ooB@203ooiT80?o^R@X0ooZA00<0`6LL0?ojT@3onY400P3onY4>0?ooV0@0oonN0`36FaP00`2kI1`0
cEhI0<eN6@090<eN6@P0dF0I0`2mEAH80;]D5PL0TT0@00D0N3D=05PV2@1H9PT0F2H903LF1@0j08nl
S`40oooo001E08nlS`80000000@00P4000X50P0:1@802PD2100J2`@202D@1@T0=1P72`1<90/205PY
30030=Aa7`1H:@`0F2T<00@0F2T<2@2hNC/:0<f9AP03091<5P3=RDH0cHU60080cHU63`3QVE4@0?nk
Ja00olYe403of7hA0?oVQa00ooB@403ooiT?0?ojT@h0oonH0`3ooih00`2kI1`0oonN0?ooWP040?oo
WPT0cEhI2`3AH1T90;]D5P030;5?502B@100TT0@00<0TT0@0P1h=@d205PV2@0304TO1`0g5PD0Skb?
03P0Skb?0@3oool005@0Skb?0P0000000`020@002PD200X50P0200X50P806P/4100U40D703@H1`80
@1h91@1<90/00`3UNB40C2@;04`T2`0204`T2`030>Ei8@1H:@`0F2T<00<0F2T<3@2hNC/?0<f9APl0
mJaQ403o^f/@0?o:MA00omQn4@3oiXL@0?odT100oonI203ooj870?ojT@h0oonH3@3ooih60<eN6@/0
dF0I0`3BH1T60;]D5P<0/DlD102B@10307Pe3@0305PV2@197`L0=aH503P0Skb?0@3oool005<0Skb?
0P00000600X50P0301X;100U40D09A0500<09A05100d60L5040N2@@0C2@;00<0lh0S04`T2`1<90/0
0`1<90/305PY30<0XVT`1@2hNC/00`3GLR00^7Tk0;Qi>`050;Qi>`X0cHU61@3RWEH?0?F/HA00ok][
403obWD@0?oHOQ40onJ7403om90@0?ooV@l0oonR3P3ooiP60?ooWP030;QR703ooih0oonN00@0oonN
0`3ooj830<eN6@/0dF0I1@3BH1T40;]D5PD0/DlD0P2B@10407Pe3@80BAl7>02?_8l10?ooo`00D`2?
_8l00`0000000`4000X50P0400X50PL09A050P0d60L7040N2@<0C2@;00<0lh0S04`T2`1<90/00P1<
90/80:9Y<0T0^7Tk00@0_fHM0;Qi>`2hNC/0^7Tk1@3=RDH:0>:MEPl0mJaQ403o^f/@0?o:MA00omQn
4@3oiXL@0?odT100oonI3`3ooj870?ooZ@L0oonH3@3ooih30?ooXP030:]J6`3ooj80oonR00/0dF0I
1`3BH1T20;]D5PL0/DlD1@1h=@d204TO1cL0Skb?0@3oool00580Skb?00<0000000<100030@00100:
1@800`0E2@<09A0502D@1@0402D@1@T0@1h900@0lh0S04`T2`1<90/0lh0S0P1<90/;0:9Y<0d0^7Tk
3`3RWEH?0?F/HA00ok][403obWD@0?oHOQ40onJ7403om90@0?ooV@l0oonR3P3oojT=0?ooWP@0oonR
00<0/5dK0?ooXP3ooj800P3ooj880=5P6@T0dV0I202aCa@01`2KAQ40N3D=07Pe3@1h=@d0FbT:04TO
1`0j60H0=P2?_8l10?ooo`00D@2?_8l00`0000000`4000<1000300X50P<05@T3100U40D2038G1`T0
@1h900<0oXDT04`T2`1<90/00`2=FRL40:9Y<0030>]l8P2RJC00XVT`00@0XVT`2@2hNC/50<f<B`h0
hYeF3`3e[64@0?nkJa00omb4403ojXdA0?ohUa00oonO403ooiT?0?ooXPh0oonY1@3ook480?ooWPD0
oonR00<0/5dK0?ooXP3ooj80103ooj820?ooX`<0dF0I2@3BH1T00`1j?a<0c5dH0;5?50050;5?5080
VdHA0`1h=@d00`1K:@X0BAl708nlS`0e08nlS`40oooo001@08nlS`05000000030@000`4000<1000:
1@80100E2@<302D@1@@0<QL72@107PT00`3nQB@0SEXW08eJ9`0308eJ9`/0XVT`1@2hNC/90<f<B`h0
hYeF3`3e[64@0?o>NQ00omb4403ojXdA0?ohUa00oonO403oojP?0?ooXPh0oonY2@3ook440?ooWPH0
oonR00<0/5dK0?ooXP3ooj800`3ooj850?ooX`0309==5`3BH1T0dV0I00H0dV0I00@0NSlC0<aM603<
GAP0c5dH102aCa@409]64@0407Pe3@1K:@X0FbT:03XH1SD0Skb?0@3oool00500Skb?00<0000000<1
00030@001P0E2@<00`0U40D0<QL7038G1`04038G1`L0@1h9202=FRL;0:9Y<0h0cHa;3P3RWEH80?F/
H@P0okm`3`3ocWX@0?oLQ100onZ=4@3on9L@0?ooWa00oonX203ook470?ooXPh0oonY3@3ook4<0?oo
XPP0oonS1P3BH1T00`1j?a<0c5dH0<aM60020<aM60<0/DlD1@2KAQ4205/Y2P0303XH1P2?_8l0Skb?
03<0Skb?0@3oool004l0Skb?0P00000200<100D05@T3200b5`L4040N2@/0SEXW202RJC040;Ql@0d0
cHa;3P3RWEH@0?noL0l0olij403og8@@0?oZSA40ooRG403ooil@0?ooZ0l0oona3P3oojT=0?oo/@<0
oonf2@3ooj8:0?ooX`@0dV0I00<0NSlC0<aM603<GAP0103<GAP00`2aCa@0VdHA09]64@0409]64@80
FbT:00<0>QP608nlS`2?_8l0<P2?_8l10?ooo`00C`2?_8l0100000000`4000<1000;1@8401D90`03
020>1@0b5`L0<QL70080<QL700@0n80Q038G1`0b5`L0<QL70P107PT207Q<7PH0SEXW00<0oXDT08eJ
9`2=FRL00P2=FRL40:9Y<0P0^7a03@3=S4/70>:MEPP0m[1V3`3o_g0?0?o>NQ00omb4403ojXdA0?oh
Ua00oonO403oojP?0?oo/@D0ooni2@3oojT=0?oo/@H0oonf1P3ooj8:0?ooX`80oonN0P3BH1T00`1j
?a<0c5dH0<aM60050<aM60H0VdHA00<0N3L=05/Y2P1;8@P0=02?_8l10?ooo`00CP2?_8l200000003
00<1000;1@802`D200<05@T30P0P3PD8038G1`@0N4`N2`2=FRL<0;Ql@0d0cHa;3`3f/6H?0?noL0l0
olij403og8@@0?oZSA40ooRG403ooil@0?ooZ0l0oona2P3ookT40?ooZ@d0oona2@3ookH30?ooXPX0
oonS1@3ooih00`1j?a<0c5dH0<aM60040<aM600305/`3`2jEAH0VdHA00<0VdHA0P1h=`d00`1K:@X0
Bb4808nlS`0b08nlS`40oooo001=08nlS`<000000`0;1@8201D90`<080h51P0b5`L607Q<7PT0SEXW
0P2RJc@<0;Ql@0T0cHa;1@3RX5/>0?J`IPl0okm`3`3ocWX@0?oLQ100oo^L4@3oojD@0?ooWa00oonX
3`3ook4>0?oo^@d0oona303ookH:0?ooX`L0oonN1@3<GAP00`1:9``0^UDF0;YE5P0309]64@<0N3L=
00<0Bb4808nlS`2?_8l0<@2?_8l10?ooo`00C@2?_8l2000000@02`D200<05@T3020>1@0P3PD00P0P
3PD4038G1`P0N4`N1P2=FRL50:9[=0`0^7a01@3=S4/90>:PF`h0m[1V3`3o_g080?o>NPP0on293`3o
kY8@0?okW140oonU403oojd80?oo]PP0oonX3`3ook4>0?oo^@D0ooo1203ook4<0?oo]P@0ooni1P3o
oj<90?ooWP<0c5dH00<0Fbl?0;YE5P2jEAH00P2jEAH0102KAQ40N3L=07Pg3@1h=`d204/Q2380Skb?
0@3oool004d0Skb?00<0000000<1000;1@800P0;1@86020>1@80<QL70P1N>Q@407Q<7P040?n7901h
C1h0N4`N07Q<7P<0SEXW202RJc@<0;Ql@0h0hZ1K3P3f/6H?0?noL100on293`3okY8@0?okW140oonU
403oojd?0?oo]Q00oona3P3ookT90?oo`@@0oona303ookH70?oo^@<0oonS2@3ooih20?ooS`030<aM
601K;`l0^UDF00@0^UDF101h=`d00`1;8@P0Skb?08nlS`0`08nlS`40oooo001<08nlS`0300000003
0@000`4000802`D200<04@P3020>1@0P3PD0100P3PD405hj50P0N4`N2`2RJc@90;Ql@0@0cHm@3@3R
X5/>0?J`IPP0okm`203odGl?0?oPR@l0onjB403oni`A0?ooYA00oon]3`3ookH80?oo_`P0oona3P3o
okT=0?oo`@`0oonf2P3ookT90?ooWP@0oon?1P2jEAH307Pg3@0305`Z2P0?1`<0Skb?0300Skb?0@3o
ool004`0Skb?0P030@0200/50P804@P3100P3PD605hj50H0N4`N0`2>GB/:0:9[=0H0^7a01`3=Se0=
0>:PF`h0m[1V403odGl?0?oPR@l0onjB403oni`A0?ooYA00oon]3`3ookH?0?oo_`l0ooni3@3ool44
0?ooa`P0oonf2P3ookT30?oo]PH0oonN1@3oohl50;YE5P0509Q64P1h=`d0N3L=05`Z2P1;8@P0<@2?
_8l10?ooo`00B`2?_8l300<1000400/50P0A20<04@P301480`<080h51`1N>Q@407Q<7PD0SUd[2P2R
Jc@30;Ql@0X0cHm@3@3RX5/70?J`IPP0ol=f3`3odGl?0?oPR@l0onjB403oni`A0?ooYA00oon]3`3o
okH?0?oo_`L0ooo7203ookT=0?oo`@P0ooo7103ookH:0?oo^@D0oonf103ooih60?ooS`@0^UDF0P2H
AQ8207Pg3@0305`Z2P2?_8l0Skb?02l0Skb?0@3oool004/0Skb?0P030@0401480`030<IU6P0P3PD0
?BD;00@0GSXD00@0m7dP05hj501N>Q@0GSXD0P1hC1h708iM:`X0XV/d3@3=Se0=0>:PF`l0ol=f3`3o
dGl?0?oPR@l0onjB403oni`@0?ooYA40oon]3`3ookH?0?oo_`h0ooo73@3ool4<0?ooa`/0ooni1`3o
okH20?ooWPL0oon?0`2jEAH309Q64P0307Pg3@1L:PX03`L30300Skb?0@3oool004/0Skb?0P030@04
01480`030<IU6P0m9@/0?BD;00P0GSXD2@2>GB/70:9[=0@0^7i4303=Se090>:PF`D0m[=[3P3o`gH?
0?oAO`l0on29403ooZ0?0?ooZA00oonb403ook/@0?oo]Pl0oono3P3oolL40?ooc`T0ooo1303oolL4
0?oob`L0ooni2@3ookH70?ooS`030?oaL@2jEAH0^UDF00@0V4HB0P1L:PX`08nlS`40oooo001;08nl
S`0300<1000;1@804@P300<04@P30`0m9@/605hj5080MT`Q2@2>GB/40:9[=0L0^7i4303=Se050>:P
F`T0m[=[3P3o`gH?0?oAOa00oo6H3`3ooZ0?0?ooZA00oonb403ook/80?oo``P0oonf3`3ookl>0?oo
a`P0ooo?1@3ool4<0?ooa`L0ooo;103ookT90?oo]P80oonY1@3oohl00`3olG40BbL<0?oaL@0409Q6
4P03074e3@1L:PX03`L302l0Skb?0@3oool004/0Skb?00<00`4000/50P0A20<00P0A20<403dU2`@0
GSXD101fC24908iM:`/0^7i4303=Se0>0?JcJ`h0ol=f203odGl80?oSSPl0oo6H3`3ooZ0?0?ooZA00
oonb403ook/?0?oo`a00oono3P3oolL<0?ooc`d0ooo72P3ool/:0?oo]P@0oonY0`3oohl40?oaL@<0
V4HB0P1a=@d00`1L:PX0Skb?08nlS`0]08nlS`40oooo001:08nlS`030000000;1@802`D200804@P3
1@0m9@/205hj50H0MT`Q1`2>GB/30:=^>@/0^7i4203=Se040>:SH0d0m[=[3P3o`gH@0?oSSPl0oo6H
3`3ooZ0?0?ooZA00oonb403ook/?0?oo``l0ooo<3P3oolL=0?ooc`@0oooF2@3oolL:0?oob`<0ooo:
1`3ookH60?ooZ@040?ooS`3olG40oo5a04/W3080oo5a0P2HAQ83074e3Bl0Skb?0@3oool004X0Skb?
0`0;1@800`0A20<091H703dU2`0403dU2`P0MT`Q1@2>GB/50:=^>@/0^7i4103=Se080>:SH0d0m[=[
2P3o`gH50?oEQ@l0on>>3`3olIP?0?onX0l0oonY403ook8@0?oo^`l0ooo33`3ool`50?ooe0T0ooo7
3@3ooll80?ooePD0ooo72P3ool/50?oobPD0oonf1`3oojT50?oaL@030?ngA@2HAQ80LCD=0080LCD=
00<0B24708nlS`2?_8l0;02?_8l10?ooo`00BP2?_8l300/50P8091H7100m9@/205Lg50L0MT`Q0`2>
GB/70:=^>@/0^7i4303RXf0=0?JcJ`D0ol=f2P3oeHD?0?oSSPl0oo6H3`3ooZ0?0?ooZA00oonb403o
ok/?0?oo``l0ooo<2@3oom@50?ooa`d0ooo?303oomH;0?oob`L0ooo:0`3ookH70?ooZ@080?ooSP3o
lG40oo5a03/N2P3olG40okM502PE1`0M3`D2074e3@0305PY2@2?_8l0Skb?02`0Skb?0@3oool004X0
Skb?0P0;1@8302@F1`<0?BD;0`1G=a@707I<8@X0Xfhi202hOT@40<jCE0`0hZ=P303f/f/?0?oEQ@l0
on>>3`3olIP?0?onX0l0oonY403ook8@0?oo^`l0ooo33`3ool`=0?ooe0h0ooo?303oomH30?oof`P0
ooo;2@3oolX80?ooZ@80oon>0`3olG430?ngA@80LCD=00<0F2T908nlS`2?_8l0;02?_8l10?ooo`00
BP2?_8l00`0;1@8091H702@F1`0202@F1`80?BD;101G=a@607I<8@80SEh_2@2SKST40;QnA0P0cY=D
303RXf060?JcJ`L0olMk3`3oeHD>0?oSSPl0oo6H3`3oojh?0?oo]Q00oonn3`3oolL@0?oo``h0ooo<
3P3oom@70?oog0L0ooo?303oomH50?oof`H0ooo;2@3oolX20?oo`@H0oonY0`3oohh00`3olG40>ah:
0?ngA@030?ngA@03074e3@1H:@T0Skb?02d0Skb?0@3oool004X0Skb?00<06@l502@F1`0T5PL00P0T
5PL00`0m9@/0EcLD05Lg500305Lg50@0MT`Q102=GRl90:=^>@`0cY=D303RXf0=0?o7N`l0omF53P3o
hhh@0?ooY@h0oon^3`3ookH@0?oo_Pl0ooo73`3ooll?0?ooc0h0oooD3@3oom`=0?ooePP0oooK0`3o
ol/90?oobP@0ooo1103oojT40?ooSP070?oaL@3o]dD0okM501d?1@3o]dD07@l505PY2@0^08nlS`40
oooo001908nlS`030081000I3`D091H700<091H71P1G=a@207I<8@H0SEh_1`2SKST30;V2B@/0cY=D
203RXf050?NgL0`0olMk3`3oeHD70?oSSPP0ooFL3`3oojD>0?oo[Pl0oonf403ookh?0?ooa`l0ooo?
1`3oomL80?ooc0d0oooD3P3oom`30?ooh`T0oooF2`3oom/90?oobPL0ooo10P3oojT50?ooSP@0okM5
00<0c7TJ05PY2@2?_8l0;@2?_8l10?ooo`00B@2?_8l00`020@006@l502@F1`0202@F1`80<Ah91@1G
=a@908eN;`@0Xfhi1@2iPTT;0<jCE0@0hZ=P2@3g]g0=0?o7N`h0omF53`3omI`?0?ooY@h0oon^3`3o
okH@0?oo_Pl0ooo73`3ooll>0?ooe`h0oooD3P3oom`60?ooh`H0oooF3P3oom/60?oobPP0ooo11P3o
ohh01`3ohf00okM50?ngA@3o]dD0c7TJ074e3@1H:@T0;@2?_8l10?ooo`00B@2?_8l201T?1@8091H7
0`0a7PT405Lg5080LD/Q202=GRl20:=^>@L0^H992`3>Te@=0?NgL0d0olMk1`3oeHD80?oWT`h0ooFL
3`3oojD>0?oo[Pl0oonf403ookh?0?ooa`l0ooo?3P3oomL70?oog`L0oooD3P3oom`90?ooh`<0oooF
4@3oom/30?oobPP0ooo100<0oonX0?ooSP3oohh00`3oohh20?oSH080okM50`3<NAX]08nlS`40oooo
001808nlS`0400X60P0I3`D06@l502@F1`@0<Ah90`1G=a@3075;8@P0SEh_2P2iPTT80<jCE0<0hjMU
3@3g]g0<0?o7N`l0onNC3P3omI`?0?ooY@h0oon^3`3ookH@0?oo_Pl0ooo73`3ooll>0?ooe`d0oooO
3P3oom`<0?ooha@0oooK2@3ool420?ooZ0@0oon>0`3ohf00103o]dD0c7TJ0<ai6P2PGa8]08nlS`40
oooo001808nlS`0300X60P0I3`D06@l500D0<Ah90P1G=a@4075;8@L0SEh_0P2TLCd90;V2B@D0cY=D
1P3SYfD=0?NgL0P0olMk1@3ofXX>0?oWT`h0ooFL3`3oojD>0?oo[Pl0ooo23`3oolT?0?ooaa00ooo?
3@3oomL>0?oog`D0oooV2@3oom`<0?ooh`@0oooW403oom/20?ood`H0ooo1103oojP30?ooSP@0on=P
0P3<NAX00`2PGa80Skb?08nlS`0[08nlS`40oooo001808nlS`0400X60P0I3`D06@l502@F1`@0<Ah9
1`1aBb4408eN;`@0Y74m2@2iPTT30<jCE0T0hjMU303g]g040?o7N`T0omZ:3P3oii<>0?oeW0P0oonU
203ook8>0?oo^Ph0ooo23`3oolT?0?ood@P0oooI203ooll=0?ooe`h0oooO2@3oonH50?oog0`0oooS
1`3oonL=0?oof`@0oooC103ool450?ooZ080oon>103ohf00103cVR`0c7TJ0:1O4P08104/08nlS`40
oooo001808nlS`0400X60P0I3`D091H702@F1`@0<Ah900<0C38B075;8@1aBb40101aBb4208eN;`H0
Y74m2@2iPTT<0>>WI@`0mkM`3@3ofXX>0?oWT`h0ooFL403ook8>0?oo^Ph0ooo23`3oolT?0?ood@l0
oooI3P3oomL=0?oog`h0oooV303oon<;0?ooi`X0oooK1P3oom<20?oo`@H0oonX1@3ohf00103cVR`0
c7TJ0:1O4P08104/08nlS`40oooo001808nlS`0409]K4P0I3`D091H702@F1`<0<Ah90P1<<Q86075;
8@T0Y74m1P2iPTT30<nFF@`0hjMU1P3g]g060?o;P0d0omZ:3@3oii<?0?ooZPl0oonb3P3ookX>0?oo
`Pl0ooo93`3oom4?0?oof@d0oooP3P3ooml>0?ooiP@0ooo/203oon<;0?ooi`80oooX1`3oom/80?oo
d`L0oonX00<0ooml0?oSH03ohf000P3ohf020?>J;080X5lB;02?_8l10?ooo`00B02?_8l0100:1P80
91H702@F1`0T5PL2034N2@<0C38B1@1aBb4208YN<0P0Y74m0`2iPTT60<nFF@`0hjMU303obh0=0?oJ
RPL0onNC1`3onJ4>0?ooZPl0oonb3P3ookX>0?oo`Pl0ooo93`3oom4?0?oof@d0oooP1`3oonL70?oo
g`d0oooV2@3oon`40?ooh`X0oooW1@3oonP50?oof`P0oooC0P3ookh50?ooZ080ooml0`3ohf020?>J
;080X5lB;02?_8l10?ooo`00B02?_8l01@0:1P8091H702@F1`0T5PL0<Ah900@0C38B0`1aBb4408YN
<0P0Y74m2P3?UUT90>>WI@<0n;]e303obh0<0?oJRPh0ooVQ3P3oojX?0?oo/Ph0oonj3P3ool8?0?oo
b@l0oooA3P3oomT>0?ooh0d0oooW3P3oonH<0?ook0/0oooW1`3oonP30?oof`P0oooC0`3ookh40?oo
Z0<0ooml0P3ohf020?>J;080X5lB;02?_8l10?ooo`00B02?_8l0100:1P8091H702@F1`0T5PL504`b
4P80LD/Q1@2:GS070:Aa?@80^XE=2@3?UUT60>>WI@H0n;]e303obh090?oJRP@0onbH3P3onJ4>0?oo
ZPh0oonb3P3ookX>0?oo`Pl0ooo93`3oom4>0?oof@d0oooP3P3oonL40?ookPT0oooV3@3oon`30?oo
l0L0oooW2P3oonP80?ood`D0oonn0`3oojP40?ooO0<0liX/00<0_g<G00P40@2?_8l0:`2?_8l10?oo
o`00B02?_8l01@0:1P8091H702@F1`0T5PL0;ad900@0C38B202:GS040:Aa?@@0^XE=2P3?UUT30>>W
I@T0n;]e303obh040?oJRPP0onbH3P3onJ4>0?ooZPh0oonb3`3oolD=0?ooc0l0oooC3P3oomX?0?oo
f@d0oooP3@3oonL90?ookPD0oooV303oon`70?ool0@0oooW2P3oonP30?ooh@D0oooC1P3ookh20?oo
Z0@0ooml00@0ol120?>J;03cVR`0_g<G;@2?_8l10?ooo`00B02?_8l00`0:1P8091H702@F1`0202lM
2@@0C38B00<0J4LO08YN<02:GS001@2:GS020:Aa?@L0^XE=2@3?UUT<0?RkM@`0ol^03@3ok9P>0?oi
X@d0oonZ3`3ookd>0?ooa@d0ooo<3`3oom<>0?oofQ`0oooP3@3oonL=0?ookPd0ooo/2P3ooo0:0?oo
j0H0oooQ0`3oom<70?oo_PD0ooml00@0ol120?>J;03cVR`0_g<G;@2?_8l10?ooo`00B02?_8l00`0H
3P@091H702lM2@0202lM2@<0C38B0P1XAal708YN<0T0^XE=1`3?UUT30>F[J@`0n;]e1P3obh060?oN
S``0onbH3P3onJ4>0?oo]Ph0oonm3P3oolD=0?ooc0l0oooC3P3oomX>0?ooh1X0oooW3P3oonh40?oo
l`P0ooo/2`3ooo030?ool@L0oooX203oon480?oo_P030?ooU@3oog`0ooml0080ooml0P3o`4800`3c
VR`0_g<G08nlS`0/08nlS`40oooo001908nlS`@0;ad90P1<<Q8406Q77`D0RUh`0P2RLSl90;Z5C@<0
ciII1P3UZfT<0?RkM@`0omj?3@3ok9P70?oiX@L0oon^3@3ookH>0?oo_@h0ooo53@3ool`?0?ood`h0
oooJ3P3oon0=0?ooi`H0ooo]1`3oonL=0?ookPT0oooc103oon`:0?ool0L0oooa0`3oonP90?ooh@80
ooo?1@3ookh30?ooU@<0ooml0P3o`4800`3cVR`0_g<G08nlS`0/08nlS`40oooo001908nlS`0502@F
1`0_7@T0;ad902lM2@1<<Q801@1XAal408YN<0<0XW8o2@2jQDd:0>F[J@T0n;]e0`3ochD<0?oNS``0
onbH3P3oojh=0?oo]Ph0oonm3P3oolD=0?ooc0l0oooC3P3oomX=0?ooh0h0oooW303oond>0?ookP`0
oooc2`3ooo090?ool@T0oooQ103ooll40?oo_P@0oonE0P3oog`20?o0@P80_g<G;@2?_8l10?ooo`00
B@2?_8l0100T5PL0;ad902lM2@0_7@T706Q77`80RUh`1@2RLSl70;Z5C@80dIYM2@3UZfT60?RkM@H0
oln5303ogXl90?o/V0@0oofU3@3oojh>0?oo]Pd0oonm3P3oolD=0?ooc0h0oooC3`3oomX=0?ooh0d0
oooW3@3oond40?ool@T0ooo^3@3ooo<30?oomPL0ooo`2P3ooo420?ooj`L0oooQ1@3ooll20?oo_PH0
oonE0`3o`4800`3HQ1`0_g<G08nlS`0/08nlS`40oooo001908nlS`0502@F1`0_7@T0;ad902lM2@12
;0h01P1XAal70:9b?`D0^XE=103AVUd:0>F[J@<0n;]e2@3ochD<0?oNS`@0onbH203ooJD>0?oo[Pd0
oonf3@3ookd>0?ooc0d0oooB3P3oomT>0?oogPh0oooP3@3oonL<0?ook@T0oooa1@3oonh<0?ool`L0
ooof103ooo090?ool@D0ooo[103oon470?ooc`L0oonE00D0onEJ0?o0@P3o`480f8@L0;mc5`0]08nl
S`40oooo001908nlS`8091H700@0;ad9048/3P12;0h0@R`>101XAal208AL;PL0XW8o0P2jQDd70=6J
G@T0iJ]Y303ochD<0?oNS`d0oofU3@3oojh=0?oo]Ph0ooo53@3ool`=0?oodPh0oooI3P3oomh=0?oo
i0h0oooW303oond=0?ool@`0oooc2`3oooH:0?ool@L0ooo[0P3oon470?ooc`030?ooZP3ooiD0oonE
00<0oonE0P3oiEX20?o0@P030=R4702oLaL0Skb?02`0Skb?0@3oool004T0Skb?0P0T5PL0100_7@T0
@R`>048/3P12;0h306Q77`<0Q5`^1`2RLSl90=6JG@L0iJ]Y0`3j_gT<0?o?Q@H0omj?1P3ol9`<0?om
Y@d0oon^3P3ookh=0?ooa@d0ooo<3@3oom8>0?oof@h0oooN3@3oon@=0?ooj@`0ooo]3P3ooo450?oo
m@H0oooc303oooH30?oom@H0oooa2@3oon/70?ooc`<0oonZ103ooiD30?oUFP030?o0@P3HQ1`0Skb?
02d0Skb?0@3oool004T0Skb?00<05Pd402@F1`12;0h01012;0h00`1XAal0Q5`^08AL;P0308AL;PD0
XW8o0P2jQdl90=6JG@<0iJ]Y1`3j_gT;0?o?Q@d0oo2L303ooJD60?oo[PL0oong3@3ookh=0?ooa@d0
ooo<3@3oom8>0?oof@d0oooN3P3oon@=0?ooj@`0ooo]3@3ooo4;0?oom@`0ooof1`3oooD30?ool@T0
ooo[0P3oomX50?ooc`@0oonZ0P3ooiD40?oUFP80f8@L;P2?_8l10?ooo`00B@2?_8l00`0F3@@091H7
02lL2@04048/3PH0Q5`^102RLSl40;Z7C`P0dIYM2`3j_gT70?o?Q@@0on:B303ol9`<0?omY@h0oong
3@3ookh<0?ooa@d0ooo<3@3oom8>0?oof@d0oooN3@3oon@=0?ooj@`0ooo]3@3ooo4<0?oom@/0ooof
2P3oooD90?ooj`@0oooJ0`3ooll60?ooZPD0onEJ0P3HQ1`^08nlS`40oooo001908nlS`0301H=100T
5PL0;a`900@0@R`>00<0GD0J08AL;P24G2h01024G2h20:9b?`H0^XM?1@3AVUd30>N_K@/0n[mi0`3o
chD80?oRTP`0oo2L1P3ooJD60?oo[`d0oong3@3ookh<0?ooa@h0ooo>303oom<=0?oof0d0oooN3P3o
on@=0?ooj@`0ooo]1P3ooo060?ool@`0oooe2`3oooH;0?oom@80ooo^1`3oon/50?oofP80ooo?1P3o
ojX01`3oog40onEJ0?oUFP3oiEX0lYXV0=R4702[JAD0;P2?_8l10?ooo`00B@2?_8l0100F3@@091H7
02lL2@0_70T2048/3P80GD0J1P24G2h90;Z7C`80dIYM1P3W[fd:0?ZoN@/0on:B303ol9`=0?oo[`d0
oong303ookh=0?oob0d0ooo>303oom<=0?oof0d0oooL3@3oon0=0?ooj@`0ooo]303ooo0<0?oom@/0
ooof2`3oooD50?ookP@0ooo[1`3oomX60?ooZP80ooma0`3oiEX00`3bVRH0f8@L0:]Y5@0^08nlS`40
oooo001:08nlS`<0;a`900<0@R`>05e06P1M@1X00P1M@1X408AL;P80WW0l202jQdl90>N_K@L0n[mi
0`3odhL;0?oRTPP0oo2L103oojH=0?oo[``0oong3@3ool8<0?oob0d0ooo>303oom<=0?oof0d0oooL
3@3oon060?ooh`L0oooY303oond<0?ool0@0oooa203oooD;0?oomP<0oood1`3oooD80?ookP80ooo[
1`3oomX00`3ookT0oonZ0?ooZP030?ooZP<0ooma00@0onEJ0?:J9P3bVRH0ZfTE;`2?_8l10?ooo`00
BP2?_8l00`0F3@@0;a`902lL2@0505e06P<0Q5`^102NL3`60;Z7C`80dYaN2@3W[fd30?ZoN@L0om>7
2`3ohY840?o`W0P0oonV3@3oojl60?oo]`H0oonk303ool8=0?oob0`0ooo>303oom<=0?oof0d0oooL
303oon0=0?ooh``0ooo]303ooo080?ool@@0oooe2`3oooH70?oom0<0oooe2P3oonh70?oofP<0ooni
0`3oojX40?ooL@040?oUFP3bVRH0lYXV0:]Y5Bl0Skb?0@3oool004/0Skb?00<08aD702lL2@12:``0
1@1M@1X00`24G2h0WW0l09i`?00309i`?0@0^XM?1@3BW5h80>N_K@/0om>72P3ohY8=0?ooYP`0oon_
3@3ook/<0?oo`P`0ooo8303oolh<0?ood`d0oooH3@3oom`<0?ooh0d0oooS2`3oonD<0?ool0`0oooa
2`3oooH:0?oom0X0ooo^0`3oomh50?oofP@0ooni0P3oojX40?ooL@<0lYXV00<0ZfTE08nlS`2?_8l0
;@2?_8l10?ooo`00B`2?_8l00`0S5@L0;a`9048[300505e06PL0WW0l0P2jQdl60=:LGPL0ijm]0P3l
`g/;0?oCQ`D0on:B1P3olYd<0?ooYPH0oon_1P3ook<<0?oo^``0ooo2303oolP=0?ooa0/0ooo83@3o
ol`<0?oocP`0oooP3@3oon<<0?ooi@D0oooV1P3ooo0=0?ool@D0ooo`1@3oooH:0?oom0<0ooo/1`3o
onh60?oogP80oooJ1P3ookT50?ooL@040?nf=P3bVRH0ag/I0:]Y5Bl0Skb?0@3oool004/0Skb?0P0S
5@L2048[30@0GD0J00<0NeLW09i`?02NL3`0102NL3`90=:LGP@0ijm]1@3l`g/:0?oCQ``0oo:M2`3o
ojH=0?oo/``0oonk2`3ool8=0?oo_``0ooo42`3oolP=0?ooc0`0ooo>2`3oom0=0?ooh``0oooU2`3o
onH=0?ool@X0ooo`2P3ooo@50?ook0D0ooo^203oomh70?oo^@040?ooQP3oog40ooma0?ooL@80okHf
00<0lYXV0<Mk6@2[JAD0;`2?_8l10?ooo`00C02?_8l00`0S5@L0@R/<048[300305e06P<0NeLW1@2N
L3`00`2hQT`0dYaN0=:LGP070=:LGP80ijm]1`3l`g/70?oCQ`<0onBB303olYd60?ooYPD0oon[303o
ok<<0?oo^``0oonj303ookl<0?ooa0/0ooo83@3ool`;0?oocP`0ooo@303oom4<0?ooi@`0oooV103o
onD80?ool@X0ooo`103oon`60?oom0P0ooo/0P3oonh80?oogP80ooo21@3ookT20?ooQP<0ooma0P3o
]SH00`3bVRH0ag/I08nlS`0_08nlS`40oooo001<08nlS`0502<E1`0_70T0@R/<048[301M@1X01@1k
EbL309i`?0<0^8I<203BW5h:0?c3N`@0om>71P3oi98<0?obW@/0oon[303ook<60?oo^`H0oond303o
okX<0?oo_`/0ooo42`3oolP=0?ooc0/0ooo>2`3oom0<0?ood@H0ooo@1P3oonD<0?ooiPP0oooU103o
oo4:0?ool0L0ooo/0`3ooo@:0?ook0P0oooN103ool830?oo^@@0oon600@0ooma0?nf=P3o]SH0okHf
0P37NaT`08nlS`40oooo001=08nlS`0302lL2@12:``0@R/<00L0NeLW00<0WW0l0;R6C02hQT`00`2h
QT`60=:LGP<0j;5/2@3l`g/:0?oTTPP0oo:M103ooJ8;0?ooZ`/0oonc3@3ook@<0?oo^P/0oono2`3o
ol@;0?oob0`0ooo<2`3oolh<0?ood0/0oooA303oom0<0?ooiP`0oooU2P3ooo0D0?ook0<0oooM1@3o
omh60?oo`P030?oo^@3oohH0oon600<0oon6103o]SH00`37NaT0Skb?08nlS`0_08nlS`40oooo001=
08nlS`80;a`900<0@R/<05Ll4`1kEbL01@1kEbL70;R6C0<0dYaN1P3X/F`60?c3N`<0omB62P3oi984
0?obW@P0oofR2`3ooj/60?oo/`D0oon^3@3ook@;0?oo^P`0oonT2`3oojL:0?ooZ@`0oonZ5P3ooj/;
0?ood@`0ooo@1P3ooll60?ooiP`0oooU1@3oon450?ool0X0ooo/0`3oon<70?ook0H0oooM0P3oomh7
0?oo`PH0oon600D0om990?nf=P3o]SH0fhTM0<Mk6@0a08nlS`40oooo001=08nlS`80;a`900<0@R/<
05Ll4`1G?1<01@1kEbL00`2HK3H0^8I<0;R6C0050;R6C0T0j;5/0`3l`g/60?oDQPX0onBB303ooJ8;
0?ooZ`/0oon^303ook@<0?ooX0/0oonT2`3oojL:0?ooZ@`0oonZ803ooj/<0?ood0`0ooo?303oonD:
0?ooh@X0ooo/1@3oon<50?ook0P0oooM203ool800`3ooi@0oon60?ooQP020?ooQP80om990P3o]SH0
0`3KRAd0Skb?08nlS`0`08nlS`40oooo001>08nlS`80;a`90`1G?1<307]G9`<0V6`f1@2hQT`20=2K
FPT0j;5/2@3oe8H70?oTTP@0oo2H2`3ooJ860?ooZ`H0oonV2P3oojh60?oo]0H0oonL303ooj0;0?oo
Y0X0oonW2P3oojT;0?ooZR00oon[1P3oojT60?ood0`0ooo?1P3ool`60?ooi@X0oooQ103oom/60?oo
k0P0oooS0P3oon`80?oog@80ooo31P3ool830?ooU0<0oon60P3odTT00`3o]SH0fhTM0000000b08nl
S`40oooo001>08nlS`03028D1P0_70T0Ec`C00<0Ec`C00<0NeLW09Q/=P2HK3H00`2HK3H30;R6C0@0
d9]J1`3X/F`20?c3N0T0omB6103oi9870?o`V0/0oofR303oojH:0?oo[P`0oonL303ooj0:0?ooY0/0
omQ^7P3ofFhE0?ooZ``0oonY303ooll;0?ooc0X0oooQ203oom/30?ook0X0oooS203oomd40?oo``@0
ooo21@3ooi@0103oohH0om990?oBB@3odTT20=^97C<0Skb?0@3oool004l0Skb?00<0;a`904@]3@1G
?1<00P1G?1<709Q/=P030;R6C03@VeX0d9]J00@0d9]J1@3X/F`40?c3N0T0omB6303ol9P50?omXPH0
oonN2`3oojH;0?ooV0/0oonL2`3ooj0;0?oHK@X0omQ^:03ofFh:0?ooZ``0oonY1P3oojL60?ooc`X0
ooo<1P3oolL50?ooh@/0oooK2P3oon<30?ooe0D0oooM1P3ool<20?oo`PH0oonD103odTT00`3KRAd0
000008nlS`0b08nlS`40oooo001?08nlS`03028D1P14;@d0A2d=0080Ec`C0P1cDAl509Q/=PP0d9]J
0`3X/F`60?c3N0H0omB6103ohX`;0?o`V0`0oonN1@3oojH60?ojTP/0oonH2P3ooi`;0?oGK@X0omQ]
2P3of6ha0?oIKP/0oonY303oojL:0?ooc0/0ooo7303oom/30?ood@L0oooS1P3oom@20?oog@P0ooo3
1P3ooi@01P3oje`0om990?oBB@3odTT0kIPS0=^97C@0Skb?0@3oool00500Skb?0`14;@d0101G?1<0
Le4O07=A7`1cDAl409Q/=P80/h951`3@VeX90?c3N0<0omB61`3ohX`80?o`V0@0ooBE2`3ooih<0?oj
TPX0oonH2`3oeV`:0?oGK@/0bX`Y2@37RBP80<F79`X0a8LW2@33QRLD0?oIKPX0omU]3@3oojL90?oo
X``0ooo7103ool070?oof`L0oooA103oon<80?ooe0P0ooo30P3ooi`40?ooU080on]L0P3odTT20>fH
8cD0Skb?0@3oool00540Skb?0P14;@d507=A7`80V6`f102cPTD50=2KFP<0iZmW203l`gP;0?oRS0@0
oo2H203om9D60?ooWPD0oo:=2`3onY8<0?oEJ`X0omI/2P3>SR/:0<Z<:@P0ahTX2035QbL90<B79`P0
`hHW2P33QRP:0<B7:@X0omU]1`3of6d60?ooY`T0oonS1@3ooil80?ooa`L0ooo0103oom/:0?ood@T0
oooD0`3ookd50?oo``@0oonL0P3ooi@30?o[G0040?oBB@3]V2<0kIPS0;1`5cD0Skb?0@3oool00540
Skb?00<0<1d904@]3@14;@d01@1cDAl60;>2A@<0d9]J1@3V[fL60?c3N0<0om9o2P3ohX`=0?odU@/0
oo:=1P3onY850?oDJP`0omE[2P3BTRh:0<j>:`/0UVLH0`3oon@20?oog@80oooG0`3oom020?oob@80
ooo20`3ook`20?oo]@80oon^0`3oojL20?ohX@030?o]V@27GQH0QehF00T0QehF2P34QbT:0<F9:`d0
omQ]2@3ooj<:0?ooW`@0ooo72P3ool0;0?ood@<0ooo31P3oom@50?oo_@<0ooo31@3ooi`50?o[G0<0
kIPS=P2?_8l10?ooo`00DP2?_8l00`0`7@T0A2d=05Pl400407=A7`80TVL]1@2cPTD80>J_I`<0o<=h
1`3odWl50?oRS0D0onR;2@3om9D40?o[QP/0oo:=2`3oe6X60?oEJ`L0eiLa2@3BTRh409a[6@040040
003oond0ooo]0?ook@80oood0P3oooH20?oom0<0ooo`0P3oonX30?ooi0040?oog@3oomL0oooG0?oo
e`80ooo@0`3oolT20?oo`P<0oonl0P3ookD30?oo[P80oonW0P3on:430?o]V@80on:A0P3oeXT20?o9
P0<0m[af0P3U[F`00`3BWEh0QelF08MO5P0208MO5P/0aHT[1P38Rbd60?oHK@X0omQ/3P3ooil:0?oo
`0@0oong1`3oom470?oo``<0oooD1`3ookd60?ooW080oo]/0`3oje`0103nZbd0kIPS0>fH8`2`L1Lf
08nlS`40oooo001B08nlS`80<1d90P1H?10307=A7`<0TVL]102cPTD20<fHD`L0iZmW2`3odWl:0?oX
R`D0ooBE203ojhH60?obS@H0om=Y2P3oe6X=0=NG<@D0XflI00H000000?ooW`3ooil0oonO0?oo`P3o
omd30?ook@80oood0`3oooH00`3ooo@0ooo`0?ool0020?ool0040?oojP3oon@0oooT0?ooi080oooM
0`3oomL20?ood0<0ooo90P3ool830?oo_080oone0`3oojh30?ooY`80ooRQ0P3okIT30?oRT@040?oF
R@3obH00olV00?o9P0<0m[af00<0iJe/0=:MGP3FXEh00P3FXEh20;b:BP0309ma=029H1L0RF0G00@0
RF0G3038Rbd:0?oHK0L0omM[1`3ooil60?ooVPD0ooo0203ookL40?ood@T0ooo3203ookd20?ooW@@0
oonL0`3onf`20?o[G080oZ/]00<0kIPS0<V06`2?_8l0=P2?_8l10?ooo`00D`2?_8l0100`7@T0F3`@
05Pl401H?10207=A7`@0TVL]0P2cPTD40<fHD`D0iZmW103i`G070?oBO`@0om^02@3oj8/=0?o[QPd0
om=Y3@3MW3D60:]c6P040000002:H1H0l:0X0?o<A`80oomc0`3ooil00`3ool80oooJ0?oojP020?oo
jP80oood0`3oooH20?oom0<0ooo`0P3oonX30?ooi080oooM0P3oomL30?ood0<0ooo90P3ool830?oo
_0<0oone0P3oojh30?ooY`80ooRQ0`3okIT20?oRT@80omJ90`3obH020?JlMP<0o<=k00<0jk=^0=JQ
GP3FXEh00P2lRTX309ma=003085J801QAA404PL100H0S64G3@3;SS0=0?oGJ`d0oonJ303ookL90?oo
``<0oon`1@3ookd40?ooW@<0oonL103onf`01@3oje`0oZ/]0?j[;@3nZbd0bH0K03P0Skb?0@3oool0
05@0Skb?00@0<1d905Pl401H?100F3`@1P2BIbd70<fHD`80iZmW1`3i`G040?oBO`L0om^01@3oj8/6
0?oSO`H0on^61`3odVP60?oCJ@T0hj8i1`2cN1/409YY60<0e8TN0P3oc4L0103oog<0oonO0?ooW`3o
oil20?oo`P040?oofP3oonX0oooZ0?oojP80ooob0`3oooH20?oom0@0ooo`00<0oooZ0?ooi03oon@0
0P3oon@0103oomd0oooG0?ooe`3oomL30?ood0<0ooo90P3ool830?oo_0<0oone0`3oojh20?ooY`<0
ooRQ0P3okIT30?oRT@80omJ90P3obH040?oAQP80o<=k00@0jk=^0=JQGP3FXEh0eZ5N0P2lRTX209ma
=080PEXP00<0GD4A06U:4P1YBQ800`1WBA87091S5`T0ci8d1`3oef/60?oFJPL0oonJ1@3ooi<80?oo
]`@0oon[1@3ool<60?oo/0<0oonm1P3ooid00`3ooi`0oo]/0?okK0030?okK0<0oZ/]00<0fX/N0<V0
6`2?_8l0=`2?_8l10?ooo`00E@2?_8l00`18<0d0F3`@05Pl4002071?6@@0TVL]0P2`Oc`60<fHD`X0
nL5`2`3ofh0<0?oSO`d0om9X2P3SXST50;]m70@0Zg<J0P2gNA/20>6E90030=B97P3`X2P0ola70080
oomc0`3ooil20?oo`P040?oofP3oonX0oooZ0?oojP80ooob0`3oooH20?oom0@0ooo`0P3oonX30?oo
i080oooM0`3oomL30?ood0<0ooo90P3ool830?oo_0<0oone0`3oojh30?ooY`80ooRQ0`3okIT20?oR
T@80omJ90`3ogY040?oAQP80o<=k00@0jk=^0=JQGP3FXEh0eZ5N0P2lRTX309ma=003085J801XB1<0
JDXB0080JDXB00<0H4<A06M94P1WBA80202DIAP90<nB=0d0omIZ2`3ooi<40?oo]`P0oon[2P3ook08
0?ooW@D0oo]/00D0ol0m0?j[;@3nZbd0fX/N0<V06`0i08nlS`40oooo001F08nlS`0304P`3@1H?100
L4lI0080L4lI0`2BIbd30;1o?0D0cIQC0P3T[Eh70?W1L0@0olec1`3ofh040?oKN0P0on=o1@3od6L6
0?oBJ0X0jZPn1P34Pah20:]c6P040;Yl702gNA/0]gTK0;Mi6`<0hIDT00@0l:0X0?o<A`3oc4L0oomc
0`3ooil20?oo`P80oooJ0`3oonX20?oolPH0ooof0`3ooo<20?oojP@0oooT0P3oomd30?ooe`<0ooo@
0`3oolT20?oo`P<0oonl0`3ookD30?oo[P<0oonW0P3on:430?o]V@<0ooFP0P3ojYP30?oNT0@0om66
0P3l`g/20>^cKP80eZ5N0`2lRTX209ma=080PEXP0P1cD1@206U:4P80H4<A00<0LU4D09AU602DIAP0
1P2DIAP:0=>G>0L0omIZ1@3oeFT:0?ooT`T0oon[0`3ooid70?oo/0<0oonH1@3ooid30?ooM`<0oo]/
0P3o`3d00`3nZbd0fX/N0=Z;7P0j08nlS`40oooo001F08nlS`80B30=101`CaT2099W;@D0/7ll0P3=
V5<50>B]GP@0nL5`1`3ocG<40?oKP0L0om]h103ohgl:0?o@I`/0jZPn1@34Pah30;Yl7080bHDN0P2g
NA/30>6E90030?nc=`3oc4L0ola70080oomc0`3ooil20?oo`P80oooJ0`3oonX20?oolPH0ooof103o
oo<20?ool0<0ooo[0P3oomd30?ooe`<0ooo@0`3oolT30?oo`P<0oonl0`3ookD30?oo[P<0oonW0`3o
ojh30?ooY`<0ooFP0P3ojYP30?oNT0@0om660P3l`g/20>^cKP<0eZ5N0P2lRTX309ma=003085J8028
Gad0R5lM0080Le0D00@0JDXB06134@1mF1D0OEPE0`1bDA@609UX6@X0diLh2`3oeFT50?ooT`D0oon<
1@3ooj/60?ooW@@0oon`1P3ooiP20?ooW@D0oomg0P3onf`30?o0?@80fX/N>`2?_8l10?ooo`00E`2?
_8l204P`3@0405i14@1`CaT0L4lI071?6@L0/7ll203T[Eh;0?o=L`/0om]h2P3od6L:0?6_A0L0d8`T
00<0^W`L0<V57P39QAh00P39QAh01@3<QAh0hIDT0>6E903QUB@0ok<g0080om]G0P3oog<40?ooW`80
ooo20P3oomX30?oojP80ooob1P3oooH40?ool`80ooo`103oon/20?ooi@<0oooP0`3oomX30?ooe0@0
ooo>0`3oolL30?oo`@<0oonk0`3ookD30?oo[P<0oonW0`3omJ020?oZV0<0omj@103odHH30?c3N`04
0>^cKP3FXEh0eZ5N0=JQGP<0_8Y:0P2OLC@30:9b;P0408QO7@1cD1@0Le0D07=@50@0OEPE0P1bDA@6
0:1]70X0f9`m2P3oeFT;0?ooS0X0oonM2@3ooiP70?ooM`@0ol0m0P3JRahl08nlS`40oooo001H08nl
S`0304P`3@1N@A40GT4A00<0L4lI00<0TVHV0;1o?02`Oc`00`2`Oc`20<fGB`H0i:eN0`3g_FH70?o=
L`D0om9`1@3ofgP:0?o?IPP0lJm42@3@S2@20<V57P<0fY8T0`3QUB@20?nc=`80om]G0P3oog`40?oo
W`80ooo20`3oomX30?oojP80ooob1P3oooH40?ool`<0ooo`0`3oon/30?ooi@<0oooP0`3oomX30?oo
e0@0ooo>0`3oolL30?oo`@<0oonk0`3ookD30?oo[P<0oonW0`3omJ030?oZV0<0omj@103odHH30?c3
N`80jk=^0`3FXEh20;b:BP<0_8U30`2RLRh01028Gad0Le0D07=@501cD1@308UO6080OEPE2@2PKA`8
0=RL?@X0omAX1P3ooh`40?ojQ0L0oonM0`3ooh`60?ooV0<0oomj103oogL20?oBCP<0ol0m00<0j9LS
0=Z;7P2?_8l0?02?_8l10?ooo`00F@2?_8l01@18<0d0GT4A05i14@1N@A40L4lI00<0TVHV0`2`Oc`4
0<fGB`<0i:eN1P3g_FH40?o=L`T0om9`2P3ocfH90?VgBPL0gYT]1@3JTR@20?6W<`80hIDT0P3o/cL2
0?oKE`<0ooml0P3ooih20?ooW`80ooo20`3oomX30?oojP80ooob1`3oooH30?ool`<0ooo`103oon/2
0?ooi@@0oooP0`3oomX30?ooe0@0ooo>0`3oolL30?oo`@@0oonk0`3ookD30?oo[P<0oonW0`3omJ03
0?oZV0<0omj@103odHH30?c3N`80jk=^0`3FXEh00`2lRTX0eZ1H0=JPF0030;b9@`<0XW8^00<0R5lM
07=@501cD1@00`2IJB0408UO60P0ZG@R203NXD8:0?oDJ0T0ooZ4103ooid60?ooS0<0oonH1@3oogX2
0?ooM`@0om9>00@0ol0m0>RG8`3XUb<0fX/N?P2?_8l10?ooo`00FP2?_8l405i14@D0TVHV1`3=Ud/9
0?NmIPX0om9`2@3ocVD90?VgBPP0kZTi0P3JTR@50?6W<`<0ok<g0P3ofeL30?ooO0@0oonN0`3ool83
0?oofP<0oooZ0P3ooo870?oomP@0oooc0`3ooo030?ooj`<0oooU103oon030?oofP<0oooD103oolh3
0?ooa`<0ooo1103ook/30?oo]@<0oon^103oojL30?oeX0<0onZH0`3ogY040?oAQP<0o<=k0P3[/fh3
0=JQGP@0eZ1H0`2lRD<30:9b;P0308QO7@2IJB00VFTP00@0VFTP0P29GaP80;An:PT0gZ522@3odfL9
0?ojQ0T0oon<203oogX50?oBCP<0j9LS00<0]gLI08nlS`2?_8l0?@2?_8l10?ooo`00F`2?_8l01@1@
=Ph0GT4A05i14@1N@A40MU8G00<0TVHV0P2cP3L50<fGB`@0iZaG103g_FH90?o8J0X0oliU2@3o_e47
0>jY>@H0lJLc0`3o`dP30?oKE`<0ooml1@3ooih20?oo^`@0oooJ0`3oonX20?oolPL0ooof103ooo<3
0?ool0@0ooo[0`3oonD30?ooh0@0oooJ0`3oom@40?oocP<0ooo7103ool440?oo^`<0oone0`3oojh3
0?ooY`@0ooFP0`3ojYP30?oNT0@0om660`3l`g/20>^cKP@0k;AZ103FX5P30;b9@`<0XW8^0`2/NBh5
09UY80T0]7hZ203TYdP90?oCI`D0ooZ4103olGX60?ooS0<0ooMh1@3oogX20?oMF`@0om9>00@0mZP^
0>RG8`3XUb<0]gLI@02?_8l10?ooo`00G02?_8l2050f3P0505i14@1fDQL0MU8G07IB5`2BIRH0102c
P3L30<fGB`L0iZaG2P3ob6P80?o<I0T0okmA2@3o^dL30?6W<`@0ol=80P3ohV80103ofeL0ooml0?oo
O03oog`50?ooWP<0oonk0`3oom440?oojP80ooob1`3oooH40?ool`<0ooo`103oon/30?ooi@@0oooP
103oomX30?ooe0@0ooo>0`3oolL40?oo`@@0oonk0`3ookD40?oo[P<0oonW0`3omJ040?oZV0<0omj@
103odHH30?c3N`<0o/Ii103/]6X40=JPF0<0_8U300@0XW8^0<:<?P32S3h0`X`n102/NBh209UY80T0
`XXe203TYdP90?oCI`T0oo5j0`3ooh`50?ogN0<0oomj103ogE/20?oBCP80mZP^0P3XUb<00`2gMaT0
Skb?08nlS`0o08nlS`40oooo001M08nlS`80D3H>101fDQL60;>0=`P0iZaG103j_Ul50?o8J0T0olaT
203oaeP90?nkA`D0ol=8103ohV830?ooO0D0oonN0`3ook/40?ood@<0oooP0`3ooo880?oomP<0oooc
103ooo040?ooj`<0oooU103oon030?oofP@0oooD103oolh40?ooa`<0ooo1103ook/40?oo]@<0oon^
103oojL30?oeX0@0onZH0`3ogY040?oAQP@0omF60`3naWT40>bdJP@0eZ1H0P2lRD<60<:<?P@0[7T^
2@32RSD80>^^CPT0om5V203olGX80?ogN0L0omeK00D0om9>0?JX;P3fZ2h0mZP^0>RG8`1308nlS`40
oooo001O08nlS`03050f3P1WB180MU8G0080MU8G0P2KK2D40;>0=`<0di]7103V[5L80?ZnG`T0olaT
203oaeP:0?o>E`80ol=8103ohV840?ooO@D0oonN0`3ook/40?ood@@0oooP0`3oonT80?oomP@0oooc
0`3ooo040?ooj`@0oooU103oon030?oofP@0oooD103oolh40?ooa`<0ooo11@3ook/30?oo]@@0oon^
0`3oojL40?oeX0@0onZH0`3ogY050?oRT@<0omF6103naWT40>bdJP@0eZ1H103GX5450<:<?P80[7T^
203@Ud490>^^CPT0om5V203oiW040?ogN0<0on1T1P3ogE/40?JX;P030<b47@2?_8l0Skb?0480Skb?
0@3oool00600Skb?00<0D3H>06M84P1WB1800P1fDQL309]/9@80/h0g1P3CVdL90?ZnG`P0ol]R2@3o
d5l90?o>E`@0on9R1@3oogd30?ooU`80oonN0`3ook/50?ood@@0oooP0`3oonT40?ook`@0ooof103o
oo<40?ool0@0ooo[0`3oonD40?ooh0@0oooJ103oom@40?oocP@0ooo7103ool440?oo^`@0oone0`3o
ojh40?ooY`@0ooFP0`3ojYP50?o_VP@0on:A103oeHH40?k6N@@0k;AZ0P3FX5P30>^cHPD0ej1A0`32
S3h90=2G@@P0l[ED2P3od6@70?oVL0L0on1T0`3ogE/30?nj?`<0mZP^00<0c8@M08nlS`2?_8l0@`2?
_8l10?ooo`00H@2?_8l0101@=Ph0IdPB06M84P1WB18509]/9@L0di]71`3`]5H90?o;HPP0om1O2P3o
hFL60?ooO@H0oonG0`3ook/50?ood@@0oooP103oonT40?ook`@0oooa103ooo<40?ool0@0ooo[103o
onD40?ooh0@0oooJ103oom@40?oocP@0ooo7103ool450?oo^`<0oone103oojh40?ooY`<0ooFP1@3o
nZ<40?o_VP@0on:A103oeHH50?k6N@<0k;AZ1P3[/f860=NPD@D0gjE>103@Ud490?:eE0T0om1T103o
iW030?oKIPL0on1T1P3o^Sl00`3fZ2h0fHhP0<b47@1608nlS`40oooo001R08nlS`@0IdPB00<0QU`I
09]/9@2KK2D00P2KK2D30<6:>0<0di]71`3`]5H90?o9H@P0omQW1@3ohFL60?odN0<0oomm1P3ooiL3
0?oo[@H0oooA103oon040?ooj@@0ooo_203ooo440?ool0D0ooo[103oonD40?ooh0@0oooJ103oom@4
0?oocP@0ooo7103ool450?oo^`@0oone0`3oojh40?ooY`D0oon[103onZ<40?o_VPD0on:A103oeHH4
0?k6N@D0oLAb1P3[/f830=NPD@<0k[AK1P3OYDh90?:eE0T0om1T1`3offH40?oPI0<0olQ@1@3o^Sl2
0=V>80030:Ya602?_8l0Skb?04D0Skb?0@3oool006@0Skb?00<0G3l@06M84P1WB1800P26G1T209]/
9@H0`HXh1`3`]5H90?o9H@P0omQW2`3om7P60?ooU`D0oon]0P3ookl30?ood@@0oooP103oonT50?oo
k`T0oooa103oonl40?ook0@0oooU1@3oon040?oofP@0oooD103oolh40?ooa`@0ooo11@3ook/40?oo
]@@0oonh103ook850?ooZ`@0ooZS1@3okiX40?oRT@@0omF60P3naWT30?oDO`D0oLAb1P3[/f870>jd
F`<0gjE>2@3i_5/90?o>H`L0om]V1`3ob5020?nj?`80iidY0P3ISR000`2ZLAP0Skb?08nlS`1608nl
S`40oooo001U08nlS`80G3l@1026G1T70<6:>0H0iZY=2@3obF490?oPKPD0ooAh1P3oohP30?ooU`D0
oon]1@3ookl50?ooh0@0oooY1@3oonl90?ool@@0ooo_1@3oon`40?ooj0@0oooT103oomX50?ooe0@0
ooo>103oolL40?oo`@H0ooo4103ookh40?oo^0@0oonb1@3ooj/50?ojX`@0onnJ103ohY440?oEQPH0
omAo1P3ma7830>^cHP<0o<9X1`3^]5/90?VlF`P0oliS203oce`60?o8D0@0iidY00<0fHhP0<>0702?
_8l0B@2?_8l10?ooo`00IP2?_8l305`o40<0QU`I0`2_NRX30<6:>0L0iZY=203oael90?oPKP/0oon8
1P3oojd50?oo_`D0ooo=1@3oonT50?ook`T0oooa103oonl50?ook0@0oooX1@3oon@40?oog`D0oooJ
103oomD50?ooc`@0ooo:1@3ool@40?oo_PD0oonh103ook850?ooZ`D0ooZS103okiX40?oRT@H0on:;
1@3oe7l60?g4LPL0o<9X103^]5/90?o4H@P0oleR203oce`30?o8D080n;4m103WWBT00`33P1`0Skb?
08nlS`1:08nlS`40oooo001X08nlS`0304lf3P1L?a00ME8D0080QU`I1@2_NRX70>JZC@P0olMO2P3o
j7D60?ooR0D0oonG0`3oojd50?oo_`H0ooo=103oomL60?ook`T0oooa103oonl60?ook0@0oooX1@3o
on@40?oog`D0oooJ103oomD50?ooc`@0ooo:1P3ool@40?oo_P@0oonh1@3ook850?ooZ`D0ooZS103o
kiX50?o^UPH0on:;1@3oe7l30?g4LP@0olmd1`3l`VP:0?o4H@P0oleR1`3oce`50?Ra?@80iidY0P3B
RQl00`33P1`0Skb?08nlS`1;08nlS`40oooo001Z08nlS`0304lf3P1eDQ@0ME8D00H0[gXZ1`3KX4@8
0?o6GPX0onQe2`3ooiL50?oo_`H0ooo=1@3oomL50?oogPX0oooa1@3oonl50?ook0@0oooX1@3oon@5
0?oog`D0oooJ103oomD50?ooc`D0ooo:1@3ool@40?oo_PD0oonh1@3ook850?ooZ`D0ooZS1@3onYl5
0?o^UPH0on:;1@3oe7l80?o?M0@0o<9X2@3obfP80?o=HPL0ol=A1@3h/Cd40=::7dl0Skb?0@3oool0
06/0Skb?0P1?=Ph00`1[C1<0ME8D09m^7`0409m^7`L0fj14203oaUh50?oXM@D0oo1l1P3ooiL60?oo
Y@L0ooo=1@3oomL60?oogP@0oooS1P3ooo450?ook`D0ooo/1@3oonP50?ooi0D0oooO1@3oomX40?oo
e@D0ooo?1@3oolX50?ooa0D0oonn1@3ookP50?oo/PD0oon[1P3oojP50?ojW`D0onjF1P3ohX/80?oK
O`H0olmd2@3obfP80?o;H@H0ol=A1P3TWBh30=::7e40Skb?0@3oool006h0Skb?00<0CcH>06]<4`1[
C1<0102OKQl60=6F>`P0olIN2`3ol7`90?ooY@@0oon`0`3oold60?ooe`H0oooN103oon<60?ooi@D0
ooo_1P3oon`40?ooj0H0oooT1@3ooml50?oofP@0oooE1P3ooll40?oobPH0ooo4103ookh60?oo^0D0
oonb1P3oojl50?ooZ0D0ooZO1P3okYH30?oRR`@0onN92@3ofgl:0?oBKPP0ol]Q1P3j]dL60>BM;P80
dXXOD`2?_8l10?ooo`00L02?_8l306]<4`0309=U6@2OKQl0WfhO00L0dIHk203oaEd50?o`O0H0ooN2
103oojD80?oo/0H0oooG1P3oomh50?ooh`H0oooU1@3oonH60?ook0D0oooX1@3oon@60?oog`D0oooJ
103oomD60?ooc`D0ooo:1@3ool@50?oo_PD0oonh1P3ookH60?oo[`D0oonX1P3onYl50?o^UPT0onN9
1@3ofgl50?oIM0D0om9^203obUl60?ZgA`H0i9d^00<0000008nlS`2?_8l0D`2?_8l10?ooo`00LP2?
_8l00`1SAQ40Jd`C09=U6@0209=U6@L0dIHk203oaEd;0?ogPPT0oon`1P3ookT70?oogPD0oooS1P3o
onD60?ooiPD0oooU1@3oonP60?ooi0H0oooO1@3oomX40?ooe@H0ooo?1@3oolX50?ooa0D0oonn1P3o
okd60?oo]PH0oon_1@3oojP60?ojW`L0oo6B2@3oihT;0?oIM0L0olYO1`3j]dL50=:=8`030:ed6P2?
_8l0Skb?05D0Skb?0@3oool007@0Skb?00<0HdHA09=U6@2CIAT00P2CIAT70<R=<`P0ol=L1@3omh86
0?omR0@0oon`203ookT30?oo`@@0oooN1@3oon<60?ooi@H0oooV1P3oonD50?ooh`D0oooQ1P3ooml5
0?oofPD0oooE1P3ooll50?oobPH0ooo81@3ool860?oo_@H0oonf1P3oojl50?ooZ0<0ooZO103oniX8
0?oaTP@0onN91P3oggX50?oIM0P0olQN1P3^Zch40=:=8`80[G@JF@2?_8l10?ooo`00M@2?_8l306=6
4@<0RElG1`38SC<70?o3G0/0oof82@3ookT70?oo`@H0oooS1P3oonD60?ooiPH0oooU1@3oon<60?oo
h@H0oooM1@3oomX60?ooePH0oooA1@3oold60?oob0D0ooo21P3ookd60?oo]PH0oon_1@3oojP80?ok
VPP0oo6B2`3oggX90?o8GPD0kZ/n1@35Pah00`2]M1X0Skb?08nlS`1I08nlS`40oooo001i08nlS`80
FSl@0`29GaL60;n5;0L0ol9J1P3ooHP60?ooSP@0ooni1`3ool470?ooaPH0oooU1P3oonH60?ooi@H0
oooS1P3oon460?oog@D0oooJ1P3oomH60?ood@D0ooo=1P3oolP50?oo`PL0oonm1P3ookH60?oo[`L0
oonR1`3oniX40?oaTPH0onEo1@3oggX90?o7G0H0hj0e1035Pah00`2]M1X0Skb?08nlS`1K08nlS`40
oooo001l08nlS`0405Xo4020FQH0P5XF081J5PD0_hD/203o`UX<0?ooSPL0ooo11`3oolH70?oob`H0
oooV1`3oonD50?ooh`H0oooQ1P3oomd60?oofPH0oooF1P3oom450?ooc@L0ooo81@3ool870?oo_@H0
oonf1`3oojT70?ooXPL0oo^J2`3oiGl90?o7G0H0hj0e1035PaiP08nlS`40oooo001o08nlS`<0P5XF
102hObH:0?o1F@H0oon>1`3ooi<80?ooaPP0ooo;1P3oold70?ooi@H0oooS1P3oon460?oog@H0oooJ
1P3oomH60?ood@H0ooo=1`3oolP50?oo`PH0oonm203oojl60?ooZ@P0oonR203ok8D60?oUO`T0olEK
1P3SX3D30;Yl76<0Skb?0@3oool00840Skb?0`20FQH50;Qo9PT0ol5I203ooi<90?ooU`P0ooo;1`3o
old70?ooc`H0oooS1`3oon460?oog@H0oooJ1P3oomH60?ood@H0ooo=1`3oolP50?oo`PP0oone1`3o
ojl70?ooZ@@0oonR1@3olHT80?o/Q@X0olEK1@3IUbh30;Yl76H0Skb?0@3oool008D0Skb?00<0MeDD
0;Qo9P2hObH0102hObH;0?o0F0X0oonG1@3ooiX40?oob`L0ooo=503ooll60?oog@H0oooJ1`3oomH6
0?ood@H0ooo=203ookl50?oo^PP0oone1`3oojl70?ooZ@/0oo69303oa5X50=VG;P<0[WDJJ@2?_8l1
0?ooo`00R02?_8l407ME50D0/GTR2@3n_eL50?ooU`T0oonJ203ooldE0?ooc`H0ooo>1P3ool`70?oo
b@L0ooo61P3ool<70?oo_`H0oonj203ookD70?oo[`T0ooN>1@3olHT90?o3F@P0d8hX0P2^MAY]08nl
S`40oooo002<08nlS`@0L54C1@2/MAh80?joE`T0oonJ203ooidF0?ooc`L0ooo>1P3ool`70?oob@L0
ooo61`3ool<70?oo_`H0oonj203ookD90?okTPP0ooN>2@3o`eT80<N78`030:5^6@2?_8l0Skb?06l0
Skb?0@3oool008l0Skb?101`DA<50:ae7P/0oKiF2@3ooid90?ooW`l0ooo?1`3oolh60?ooc0L0ooo9
1`3oolH80?oo``H0oono1`3ookX90?ooUPT0oo^B2`3o`EP50<N78`@0XFhIM@2?_8l10?ooo`00U`2?
_8l80:Qb70/0o;eF2@3ooil80?ooX@P0oonR1`3oolh70?ooc0L0ooo91`3oolH80?oo``L0oonL203o
oiT90?ooUPT0ol1G1P3o`EP40<217`80UFHGN`2?_8l10?ooo`00V`2?_8l80:E`6`D0o;eF2@3l_5D9
0?ooXAL0oonR203ooj470?ooX0P0oonN1`3ooi`90?ooV@T0o[mF2@3o`5L40<217h40Skb?0@3oool0
0:00Skb?0`1XBa830:E`6`X0o;aE2@3k_5@H0?ooXPP0oonQ203ooj070?ooWPP0oonL2P3n_UD90?jo
EP<0^WdM0`28GaJ608nlS`40oooo002Y08nlS`80IDPA0`2TKaXC0?^lE100oonR203ooj480?ooX0L0
oonN2P3m_ED90?jnE@<0]GTL0P1mFAB?08nlS`40oooo002b08nlS`802`@10P2SKQXS0?^lE0T0o;aD
203l_E@90?fmE@80/GLK00<0[G@K0000002?_8l0U`2?_8l10?ooo`00_02?_8l00`0;1@40XfhJ0:=^
6P080:=^6Q80nkaD2@3l_5@;0:Yc6`030081002?_8l0Skb?09l0Skb?0@3oool00=00Skb?2@2UL1Zf
08nlS`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nlS`40oooo
003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nlS`40oooo003o08nlSi00
Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nlS`40oooo003o08nlSi00Skb?0@3oool0
0?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nlS`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?
_8l10?ooo`00o`2?_8n@08nlS`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00
o`2?_8n@08nlS`40oooo003o08nlSi00Skb?0@3oool00?l0Skb?T02?_8l10?ooo`00o`2?_8n@08nl
S`40oooo003o08nlSi00Skb?0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {225.063, 0}} -> {-0.000944192, 0.190692, \
0.00234807, 0.00234807}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->{},
WindowSize->{494, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 70, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1849, 56, 383, 13, 50, "Usage",
      CellTags->"Function?"],
    Cell[2235, 71, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 362606, 9595}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 70, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1849, 56, 383, 13, 50, "Usage",
  CellTags->"Function?"],
Cell[2235, 71, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2332, 76, 183, 3, 58, "MathCaption"],
Cell[2518, 81, 514, 18, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3057, 103, 33, 0, 39, "ExampleSection"],
Cell[3093, 105, 97, 2, 29, "Input"],
Cell[3193, 109, 41, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[3259, 113, 936, 16, 280, "Input"],
Cell[4198, 131, 357699, 9441, 233, 313874, 8896, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

