(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6105,        183]*)
(*NotebookOutlinePosition[      7076,        217]*)
(*  CellTagsIndexPosition[      7002,        211]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawVectorField", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["DrawVectorField",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(f, {x, x0, x1, \ \((xu)\)}, {y, y0, y1, \((yu\)\),
                "TI"]}], 
            StyleBox["}",
              "TI"]}], 
          StyleBox[",",
            "TI"], 
          StyleBox[\(opts ... \),
            "TI"]}], 
        StyleBox["]",
          "MR"]}]]],
  " extracts the graphics primitives from the corresponding PlotVectorField \
statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as PlotVectorField. Regular PlotVectorField options may be \
used. Basic Graphics options, such as PlotRange have no effect.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawGradientField",
    ButtonData:>{"DrawGradientField"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DrawHamiltonianField",
    ButtonData:>{"DrawHamiltonianField"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DrawPolyaField",
    ButtonData:>{"DrawPolyaField"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ListDrawVectorField",
    ButtonData:>{"ListDrawVectorField"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["PlotVectorField",
    ButtonData:>{"Graphics`PlotField`", "1.3"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Here, the vector field from the Standard Packages example is plotted over an \
extended range and against a density plot which indicates the \"phase\" of \
the field by color. Again, the density plot is made over a wider range than \
the vector field plot.\
\>", "Text"],

Cell[BoxData[{
    \(\(field[x_, y_] := {Sin[x], Cos[y]};\)\), "\[IndentingNewLine]", 
    \(\(Draw2D[\[IndentingNewLine]{DensityDraw[
            ArcTan @@ field[x, y], {x, \(-1\), 4  \[Pi] + 1}, {y, \(-1\), 
              4  \[Pi] + 1}, Mesh \[Rule] False, PlotPoints \[Rule] 50, 
            ColorFunction \[Rule] 
              ColorMix[CornflowerBlue, 
                CadmiumRedDeep]], \
\[IndentingNewLine]\[IndentingNewLine]DrawVectorField[
            field[x, y], {x, 0, 4  \[Pi]}, {y, 0, 
              4  \[Pi]}]}, \[IndentingNewLine]\[IndentingNewLine]AspectRatio \
\[Rule] Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            y}, \[IndentingNewLine]PlotLabel \[Rule] 
          SequenceForm[
            field[x, 
              y], "\< and Phase\>"], \[IndentingNewLine]PlotRegion \[Rule] \
{{0, 0.96}, {0, 0.97}}, \[IndentingNewLine]Background \[Rule] 
          Antique, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
Here is a similar plot of the field against an amplitude density plot.\
\>", "Text"],

Cell[BoxData[{
    \(\(field[x_, y_] := {Sin[x], Cos[y]};\)\), "\[IndentingNewLine]", 
    \(\(Draw2D[\[IndentingNewLine]{DensityDraw[\@\(field[x, y] . field[x, \
y]\), {x, \(-1\), 4  \[Pi] + 1}, {y, \(-1\), 4  \[Pi] + 1}, 
            Mesh \[Rule] False, PlotPoints \[Rule] 50, 
            ColorFunction \[Rule] 
              ColorMix[Navy, 
                PaleTurquoise]], \
\[IndentingNewLine]\[IndentingNewLine]DrawVectorField[
            field[x, y], {x, 0, 4  \[Pi]}, {y, 0, 
              4  \[Pi]}]}, \[IndentingNewLine]\[IndentingNewLine]AspectRatio \
\[Rule] Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            y}, \[IndentingNewLine]PlotLabel \[Rule] 
          SequenceForm[
            field[x, 
              y], "\< and Amplitude\>"], \[IndentingNewLine]PlotRegion \
\[Rule] {{0, 0.96}, {0, 0.97}}, \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)}], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(Clear[field]\)], "Input",
  CellLabel->"In[6]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{527, 735},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 62, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1841, 56, 671, 24, 50, "Usage",
      CellTags->"Function?"],
    Cell[2515, 82, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6756, 200}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 62, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1841, 56, 671, 24, 50, "Usage",
  CellTags->"Function?"],
Cell[2515, 82, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2612, 87, 173, 3, 58, "MathCaption"],
Cell[2788, 92, 620, 22, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3433, 118, 34, 0, 39, "ExampleSection"],
Cell[3470, 120, 97, 2, 29, "Input"],
Cell[3570, 124, 280, 5, 59, "Text"],
Cell[3853, 131, 1032, 19, 309, "Input"],
Cell[4888, 152, 94, 2, 25, "Text"],
Cell[4985, 156, 1020, 19, 316, "Input"],
Cell[6008, 177, 69, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

