(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    789252,      31502]*)
(*NotebookOutlinePosition[    790227,      31536]*)
(*  CellTagsIndexPosition[    790149,      31530]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawVectorField3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["DrawVectorField",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\({xfunc, yfunc, zfunc}, {x, x0, x1, \ \((xu)\)}, {y, y0, 
            y1, \((yu)\)}, {z, z0, z1, \((zu)\)}, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  "\n extracts the graphics primitives from the corresponding \
PlotVectorField3D statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as PlotVectorField3D. Regular PlotVectorField3D options may \
be used. Basic Graphics3D options, such as PlotRange have no effect.\
\>", "MathCaption"],

Cell[TextData[{
  "Also consider using lists of ",
  ButtonBox["Arrow3D",
    ButtonData:>{"Arrow3D"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawGradientField3D",
    ButtonData:>{"DrawGradientField3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ListDrawVectorField3D",
    ButtonData:>{"ListDrawVectorField3D"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["PlotVectorField3D",
    ButtonData:>{"Graphics`PlotField3D`", "1.3"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[895]:="],

Cell["\<\
Here, a circulatory field is drawn around a cylinder. NeutralLighting is used \
to give a nice color to the cylinder. I decided to try a lighter color than \
SteelBlue, but LightSteelBlue was too light, so I used a ColorMix.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cylindercolor = \(ColorMix[SteelBlue, LightSteelBlue]\)[
          0.3];\)\), "\n", 
    \(\(Draw3DItems[\[IndentingNewLine]{SurfaceColor[cylindercolor, 
            cylindercolor, 2], \[IndentingNewLine]ParametricDraw3D[
            0.3 {Cos[\[Theta]], Sin[\[Theta]], z/0.3}, {\[Theta], 0, 
              2  \[Pi]}, {z, \(-1\), 
              1}], \[IndentingNewLine]IndianRed, \
\[IndentingNewLine]DrawVectorField3D[{y, \(-x\), 0}, {x, \(-1\), 
              1}, {y, \(-1\), 1}, {z, \(-1\), 1}, VectorHeads \[Rule] True, 
            PlotPoints \[Rule] 7]}, \[IndentingNewLine]NeutralLighting[0.3, 
          0.5, 0.1], \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]Boxed \[Rule] 
          False, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)}], "Input",
  CellLabel->"In[17]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0195 
%%ImageSize: 400 407.798 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-0.0284275 1.10873 6.79795e-017 1.10873 [
[ 0 0 0 0 ]
[ 1 1.0195 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0195 L
0 1.0195 L
closepath
clip
newpath
.69 .09 .12 r
.5 Mabswid
[ ] 0 setdash
.49081 .56887 m
.49357 .57147 L
s
.49375 .5546 m
.49081 .56887 L
s
.50768 .56546 m
.49081 .56887 L
s
.49653 .55712 m
.49375 .5546 L
s
.49375 .5546 m
.50768 .56546 L
s
.50768 .56546 m
.49357 .57147 L
s
.49653 .55712 m
.50768 .56546 L
s
.43717 .55317 m
.50768 .56546 L
s
.49357 .57147 m
.49653 .55712 L
s
.55081 .54034 m
.55177 .54224 L
s
.55165 .52779 m
.55081 .54034 L
s
.56426 .53569 m
.55081 .54034 L
s
.55262 .52962 m
.55165 .52779 L
s
.55165 .52779 m
.56426 .53569 L
s
.49014 .62894 m
.49295 .63197 L
s
.49313 .61445 m
.49014 .62894 L
s
.50733 .62558 m
.49014 .62894 L
s
.56426 .53569 m
.55177 .54224 L
s
.55262 .52962 m
.56426 .53569 L
s
.50143 .53223 m
.56426 .53569 L
s
.49597 .61739 m
.49313 .61445 L
s
.49313 .61445 m
.50733 .62558 L
s
.50733 .62558 m
.49295 .63197 L
s
.49597 .61739 m
.50733 .62558 L
s
.43547 .61351 m
.50733 .62558 L
s
.44117 .53322 m
.44498 .53568 L
s
.44535 .52121 m
.44117 .53322 L
s
.4565 .53198 m
.44117 .53322 L
s
.44918 .52362 m
.44535 .52121 L
s
.44535 .52121 m
.4565 .53198 L
s
.4565 .53198 m
.44498 .53568 L
s
.44918 .52362 m
.4565 .53198 L
s
.39934 .51411 m
.4565 .53198 L
s
.55177 .54224 m
.55262 .52962 L
s
.49295 .63197 m
.49597 .61739 L
s
.44498 .53568 m
.44918 .52362 L
s
.61289 .51082 m
.61191 .51242 L
s
.61155 .49966 m
.61289 .51082 L
s
.62288 .50484 m
.61289 .51082 L
s
.5673 .51077 m
.62288 .50484 L
s
.61057 .5012 m
.61155 .49966 L
s
.61155 .49966 m
.62288 .50484 L
s
.55129 .6009 m
.55227 .60317 L
s
.55215 .58815 m
.55129 .6009 L
s
.565 .59632 m
.55129 .6009 L
s
.55314 .59035 m
.55215 .58815 L
s
.55215 .58815 m
.565 .59632 L
s
.62288 .50484 m
.61191 .51242 L
s
.61057 .5012 m
.62288 .50484 L
s
.48945 .69133 m
.49231 .69482 L
s
.4925 .67661 m
.48945 .69133 L
s
.50697 .68804 m
.48945 .69133 L
s
.50161 .50345 m
.50356 .50497 L
s
.50364 .49353 m
.50161 .50345 L
s
.5133 .50099 m
.50161 .50345 L
s
.565 .59632 m
.55227 .60317 L
s
.55314 .59035 m
.565 .59632 L
s
.50095 .59293 m
.565 .59632 L
s
.49538 .68001 m
.4925 .67661 L
s
.4925 .67661 m
.50697 .68804 L
s
.50561 .49501 m
.50364 .49353 L
s
.50364 .49353 m
.5133 .50099 L
s
.61191 .51242 m
.61057 .5012 L
s
.5133 .50099 m
.50356 .50497 L
s
.50561 .49501 m
.5133 .50099 L
s
.46462 .49218 m
.5133 .50099 L
s
.50697 .68804 m
.49231 .69482 L
s
.49538 .68001 m
.50697 .68804 L
s
.4337 .67621 m
.50697 .68804 L
s
.43953 .59389 m
.44339 .59673 L
s
.44378 .58169 m
.43953 .59389 L
s
.45515 .59267 m
.43953 .59389 L
s
.44768 .58446 m
.44378 .58169 L
s
.44378 .58169 m
.45515 .59267 L
s
.45515 .59267 m
.44339 .59673 L
s
.44768 .58446 m
.45515 .59267 L
s
.39685 .5751 m
.45515 .59267 L
s
.55227 .60317 m
.55314 .59035 L
s
.40324 .49713 m
.39435 .49881 L
s
.3949 .486 m
.40324 .49713 L
s
.40324 .49713 m
.38937 .49601 L
s
.3999 .48876 m
.40324 .49713 L
s
.35972 .47319 m
.40324 .49713 L
s
.3949 .486 m
.38937 .49601 L
s
.3999 .48876 m
.3949 .486 L
s
.38937 .49601 m
.39435 .49881 L
s
.50356 .50497 m
.50561 .49501 L
s
.49231 .69482 m
.49538 .68001 L
s
.44339 .59673 m
.44768 .58446 L
s
.39435 .49881 m
.3999 .48876 L
s
.63484 .48876 m
.68365 .47285 L
s
.67715 .48026 m
.67411 .48217 L
s
.67353 .46997 m
.67715 .48026 L
s
.68365 .47285 m
.67715 .48026 L
s
.67047 .47183 m
.67353 .46997 L
s
.67353 .46997 m
.68365 .47285 L
s
.6146 .57187 m
.61361 .5738 L
s
.61324 .56053 m
.6146 .57187 L
s
.62479 .56598 m
.6146 .57187 L
s
.56811 .57182 m
.62479 .56598 L
s
.61224 .5624 m
.61324 .56053 L
s
.61324 .56053 m
.62479 .56598 L
s
.55179 .66384 m
.55279 .66651 L
s
.55267 .6509 m
.55179 .66384 L
s
.56577 .65935 m
.55179 .66384 L
s
.68365 .47285 m
.67411 .48217 L
s
.67047 .47183 m
.68365 .47285 L
s
.56418 .47263 m
.56412 .47359 L
s
.56401 .46448 m
.56418 .47263 L
s
.57219 .46887 m
.56418 .47263 L
s
.67411 .48217 m
.67047 .47183 L
s
.56395 .46542 m
.56401 .46448 L
s
.56401 .46448 m
.57219 .46887 L
s
.55368 .6535 m
.55267 .6509 L
s
.55267 .6509 m
.56577 .65935 L
s
.62479 .56598 m
.61361 .5738 L
s
.61224 .5624 m
.62479 .56598 L
s
.53158 .46969 m
.57219 .46887 L
s
.48873 .75619 m
.49164 .76017 L
s
.49184 .74124 m
.48873 .75619 L
s
.5066 .75298 m
.48873 .75619 L
s
.50112 .56461 m
.50312 .56643 L
s
.5032 .55453 m
.50112 .56461 L
s
.51305 .5622 m
.50112 .56461 L
s
.57219 .46887 m
.56412 .47359 L
s
.56395 .46542 m
.57219 .46887 L
s
.56577 .65935 m
.55279 .66651 L
s
.55368 .6535 m
.56577 .65935 L
s
.50046 .65602 m
.56577 .65935 L
s
.49477 .74512 m
.49184 .74124 L
s
.49184 .74124 m
.5066 .75298 L
s
.50521 .55631 m
.5032 .55453 L
s
.5032 .55453 m
.51305 .5622 L
s
.61361 .5738 m
.61224 .5624 L
s
.51305 .5622 m
.50312 .56643 L
s
.50521 .55631 m
.51305 .5622 L
s
.4634 .55353 m
.51305 .5622 L
s
.56412 .47359 m
.56395 .46542 L
s
.70413 .46618 m
.74671 .43967 L
s
.5066 .75298 m
.49164 .76017 L
s
.49477 .74512 m
.5066 .75298 L
s
.43186 .74141 m
.5066 .75298 L
s
.43782 .65697 m
.44175 .6602 L
s
.44216 .64456 m
.43782 .65697 L
s
.45375 .65578 m
.43782 .65697 L
s
.45022 .46492 m
.45333 .46652 L
s
.45355 .45739 m
.45022 .46492 L
s
.46023 .46486 m
.45022 .46492 L
s
.46023 .46486 m
.45333 .46652 L
s
.45355 .45739 m
.46023 .46486 L
s
.45666 .45897 m
.46023 .46486 L
s
.42605 .45021 m
.46023 .46486 L
s
.45666 .45897 m
.45355 .45739 L
s
.44612 .64772 m
.44216 .64456 L
s
.44216 .64456 m
.45375 .65578 L
s
.45375 .65578 m
.44175 .6602 L
s
.44612 .64772 m
.45375 .65578 L
s
.39427 .63853 m
.45375 .65578 L
s
.55279 .66651 m
.55368 .6535 L
s
.4008 .5584 m
.39173 .56041 L
s
.3923 .54709 m
.4008 .5584 L
s
.4008 .5584 m
.38666 .55729 L
s
.39739 .55016 m
.4008 .5584 L
s
.35638 .53483 m
.4008 .5584 L
s
.3923 .54709 m
.38666 .55729 L
s
.39739 .55016 m
.3923 .54709 L
s
.38666 .55729 m
.39173 .56041 L
s
.50312 .56643 m
.50521 .55631 L
s
.34776 .46084 m
.34155 .46095 L
s
.34229 .44869 m
.34776 .46084 L
s
.34776 .46084 m
.33527 .45715 L
s
.34859 .45247 m
.34776 .46084 L
s
.31818 .43029 m
.34776 .46084 L
s
.45333 .46652 m
.45666 .45897 L
s
.34229 .44869 m
.33527 .45715 L
s
.34859 .45247 m
.34229 .44869 L
s
.49164 .76017 m
.49477 .74512 L
s
.33527 .45715 m
.34155 .46095 L
s
.44175 .6602 m
.44612 .64772 L
s
.39173 .56041 m
.39739 .55016 L
s
.63702 .55016 m
.68682 .5345 L
s
.34155 .46095 m
.34859 .45247 L
s
.73764 .43857 m
.74373 .44861 L
s
.73243 .44145 m
.73764 .43857 L
s
.73764 .43857 m
.74671 .43967 L
s
.74373 .44861 m
.73854 .45153 L
s
.74671 .43967 m
.74373 .44861 L
s
.60029 .44662 m
.6333 .43553 L
s
.68018 .5418 m
.6771 .54401 L
s
.67648 .53132 m
.68018 .5418 L
s
.68682 .5345 m
.68018 .5418 L
s
.67338 .53349 m
.67648 .53132 L
s
.67648 .53132 m
.68682 .5345 L
s
.77522 .44302 m
.81217 .40522 L
s
.73854 .45153 m
.73243 .44145 L
s
.73243 .44145 m
.74671 .43967 L
s
.61638 .63537 m
.61538 .63766 L
s
.61499 .62384 m
.61638 .63537 L
s
.62678 .62959 m
.61638 .63537 L
s
.56896 .63531 m
.62678 .62959 L
s
.74671 .43967 m
.73854 .45153 L
s
.62901 .44069 m
.6268 .44187 L
s
.62653 .43366 m
.62901 .44069 L
s
.6333 .43553 m
.62901 .44069 L
s
.62431 .43482 m
.62653 .43366 L
s
.62653 .43366 m
.6333 .43553 L
s
.61398 .62608 m
.61499 .62384 L
s
.61499 .62384 m
.62678 .62959 L
s
.55231 .72932 m
.55334 .73242 L
s
.5532 .71618 m
.55231 .72932 L
s
.56657 .72493 m
.55231 .72932 L
s
.68682 .5345 m
.6771 .54401 L
s
.67338 .53349 m
.68682 .5345 L
s
.56495 .53428 m
.56489 .53548 L
s
.56478 .526 m
.56495 .53428 L
s
.57312 .53057 m
.56495 .53428 L
s
.6771 .54401 m
.67338 .53349 L
s
.56472 .52718 m
.56478 .526 L
s
.56478 .526 m
.57312 .53057 L
s
.55424 .7192 m
.5532 .71618 L
s
.5532 .71618 m
.56657 .72493 L
s
.6333 .43553 m
.6268 .44187 L
s
.62431 .43482 m
.6333 .43553 L
s
.6268 .44187 m
.62431 .43482 L
s
.62678 .62959 m
.61538 .63766 L
s
.61398 .62608 m
.62678 .62959 L
s
.5317 .53139 m
.57312 .53057 L
s
.48798 .82366 m
.49095 .82818 L
s
.49115 .80847 m
.48798 .82366 L
s
.50621 .82053 m
.48798 .82366 L
s
.50062 .62824 m
.50266 .63038 L
s
.50274 .618 m
.50062 .62824 L
s
.51279 .62587 m
.50062 .62824 L
s
.57312 .53057 m
.56489 .53548 L
s
.56472 .52718 m
.57312 .53057 L
s
.51328 .4327 m
.51432 .43333 L
s
.51434 .42752 m
.51328 .4327 L
s
.51937 .43137 m
.51328 .4327 L
s
.56657 .72493 m
.55334 .73242 L
s
.55424 .7192 m
.56657 .72493 L
s
.49994 .72167 m
.56657 .72493 L
s
.49414 .81288 m
.49115 .80847 L
s
.49115 .80847 m
.50621 .82053 L
s
.50479 .62009 m
.50274 .618 L
s
.50274 .618 m
.51279 .62587 L
s
.61538 .63766 m
.61398 .62608 L
s
.51539 .42814 m
.51434 .42752 L
s
.51434 .42752 m
.51937 .43137 L
s
.51937 .43137 m
.51432 .43333 L
s
.51539 .42814 m
.51937 .43137 L
s
.49413 .42662 m
.51937 .43137 L
s
.51279 .62587 m
.50266 .63038 L
s
.50479 .62009 m
.51279 .62587 L
s
.46213 .61736 m
.51279 .62587 L
s
.56489 .53548 m
.56472 .52718 L
s
.70773 .52793 m
.75123 .50182 L
s
.50621 .82053 m
.49095 .82818 L
s
.49414 .81288 m
.50621 .82053 L
s
.42994 .80927 m
.50621 .82053 L
s
.43604 .7226 m
.44004 .72625 L
s
.44046 .70997 m
.43604 .7226 L
s
.45229 .72143 m
.43604 .7226 L
s
.44869 .52669 m
.45186 .52852 L
s
.45208 .51902 m
.44869 .52669 L
s
.4589 .52663 m
.44869 .52669 L
s
.4589 .52663 m
.45186 .52852 L
s
.45208 .51902 m
.4589 .52663 L
s
.45526 .52083 m
.4589 .52663 L
s
.42402 .5122 m
.4589 .52663 L
s
.51432 .43333 m
.51539 .42814 L
s
.45526 .52083 m
.45208 .51902 L
s
.4445 .71355 m
.44046 .70997 L
s
.44046 .70997 m
.45229 .72143 L
s
.45229 .72143 m
.44004 .72625 L
s
.4445 .71355 m
.45229 .72143 L
s
.39158 .70456 m
.45229 .72143 L
s
.40491 .4272 m
.40091 .42715 L
s
.40125 .41892 m
.40491 .4272 L
s
.40491 .4272 m
.39651 .42465 L
s
.40566 .42141 m
.40491 .4272 L
s
.38559 .40617 m
.40491 .4272 L
s
.55334 .73242 m
.55424 .7192 L
s
.39827 .62214 m
.389 .62452 L
s
.38959 .61065 m
.39827 .62214 L
s
.39827 .62214 m
.38384 .62106 L
s
.39478 .61406 m
.39827 .62214 L
s
.3529 .599 m
.39827 .62214 L
s
.40125 .41892 m
.39651 .42465 L
s
.40566 .42141 m
.40125 .41892 L
s
.38959 .61065 m
.38384 .62106 L
s
.39478 .61406 m
.38959 .61065 L
s
.38384 .62106 m
.389 .62452 L
s
.50266 .63038 m
.50479 .62009 L
s
.34415 .52267 m
.3378 .52313 L
s
.33857 .51036 m
.34415 .52267 L
s
.34415 .52267 m
.3314 .51903 L
s
.34498 .51442 m
.34415 .52267 L
s
.3139 .49257 m
.34415 .52267 L
s
.39651 .42465 m
.40091 .42715 L
s
.45186 .52852 m
.45526 .52083 L
s
.28993 .423 m
.28639 .42211 L
s
.28742 .40907 m
.28993 .423 L
s
.28993 .423 m
.27871 .41652 L
s
.29511 .41464 m
.28993 .423 L
s
.27458 .38526 m
.28993 .423 L
s
.6708 .42294 m
.69674 .40092 L
s
.33857 .51036 m
.3314 .51903 L
s
.34498 .51442 m
.33857 .51036 L
s
.49095 .82818 m
.49414 .81288 L
s
.40091 .42715 m
.40566 .42141 L
s
.3314 .51903 m
.3378 .52313 L
s
.44004 .72625 m
.4445 .71355 L
s
.28742 .40907 m
.27871 .41652 L
s
.29511 .41464 m
.28742 .40907 L
s
.84818 .41924 m
.88018 .36943 L
s
.80397 .40549 m
.81274 .41579 L
s
.79655 .41001 m
.80397 .40549 L
s
.80397 .40549 m
.81217 .40522 L
s
.389 .62452 m
.39478 .61406 L
s
.63927 .61405 m
.69013 .59868 L
s
.27871 .41652 m
.28639 .42211 L
s
.3378 .52313 m
.34498 .51442 L
s
.81274 .41579 m
.80535 .42036 L
s
.81217 .40522 m
.81274 .41579 L
s
.28639 .42211 m
.29511 .41464 L
s
.74195 .50037 m
.74817 .51062 L
s
.73666 .50357 m
.74195 .50037 L
s
.74195 .50037 m
.75123 .50182 L
s
.74817 .51062 m
.7429 .51386 L
s
.75123 .50182 m
.74817 .51062 L
s
.80535 .42036 m
.79655 .41001 L
s
.79655 .41001 m
.81217 .40522 L
s
.6018 .50866 m
.6355 .49774 L
s
.81217 .40522 m
.80535 .42036 L
s
.69125 .40076 m
.69622 .40758 L
s
.68677 .40315 m
.69125 .40076 L
s
.69125 .40076 m
.69674 .40092 L
s
.68333 .60584 m
.6802 .6084 L
s
.67956 .59518 m
.68333 .60584 L
s
.69013 .59868 m
.68333 .60584 L
s
.69622 .40758 m
.69176 .40999 L
s
.69674 .40092 m
.69622 .40758 L
s
.67641 .59769 m
.67956 .59518 L
s
.67956 .59518 m
.69013 .59868 L
s
.78032 .50511 m
.81815 .46786 L
s
.7429 .51386 m
.73666 .50357 L
s
.73666 .50357 m
.75123 .50182 L
s
.61823 .70147 m
.61722 .70414 L
s
.61682 .68975 m
.61823 .70147 L
s
.62885 .69581 m
.61823 .70147 L
s
.56984 .70141 m
.62885 .69581 L
s
.75123 .50182 m
.7429 .51386 L
s
.63112 .50282 m
.62887 .50421 L
s
.62859 .49567 m
.63112 .50282 L
s
.6355 .49774 m
.63112 .50282 L
s
.62633 .49704 m
.62859 .49567 L
s
.62859 .49567 m
.6355 .49774 L
s
.48 .649 .84 r
.50346 .41393 m .51877 .416 L .5188 .40324 L p F P
0 0 0 r
s
.48 .649 .84 r
.5188 .40324 m .50355 .40118 L .50346 .41393 L p F P
0 0 0 r
s
.431 .583 .767 r
.53436 .40315 m .5188 .40324 L .51877 .416 L p F P
0 0 0 r
s
.431 .583 .767 r
.51877 .416 m .53439 .41591 L .53436 .40315 L p F P
0 0 0 r
s
.38 .517 .691 r
.54955 .40091 m .53436 .40315 L .53439 .41591 L p F P
0 0 0 r
s
.69 .09 .12 r
.69176 .40999 m
.68677 .40315 L
s
.68677 .40315 m
.69674 .40092 L
s
.6158 .69237 m
.61682 .68975 L
s
.61682 .68975 m
.62885 .69581 L
s
.69674 .40092 m
.69176 .40999 L
s
.56403 .40241 m
.58077 .3966 L
s
.53 .714 .909 r
.48912 .4098 m .50346 .41393 L .50355 .40118 L p F P
0 0 0 r
s
.53 .714 .909 r
.50355 .40118 m .48928 .39703 L .48912 .4098 L p F P
0 0 0 r
s
.38 .517 .691 r
.53439 .41591 m .54965 .41367 L .54955 .40091 L p F P
0 0 0 r
s
.327 .449 .611 r
.56371 .3966 m .54955 .40091 L .54965 .41367 L p F P
0 0 0 r
s
.69 .09 .12 r
.55285 .79749 m
.5539 .80105 L
s
.55376 .78413 m
.55285 .79749 L
s
.56741 .79321 m
.55285 .79749 L
s
.69013 .59868 m
.6802 .6084 L
s
.67641 .59769 m
.69013 .59868 L
s
.56575 .59846 m
.5657 .59993 L
s
.56557 .59005 m
.56575 .59846 L
s
.57409 .59482 m
.56575 .59846 L
s
.6802 .6084 m
.67641 .59769 L
s
.57866 .3993 m
.57745 .39984 L
s
.57738 .3957 m
.57866 .3993 L
s
.58077 .3966 m
.57866 .3993 L
s
.57738 .3957 m
.58077 .3966 L
s
.56552 .59149 m
.56557 .59005 L
s
.56557 .59005 m
.57409 .59482 L
s
.55482 .78762 m
.55376 .78413 L
s
.55376 .78413 m
.56741 .79321 L
s
.7432 .39862 m
.76266 .36496 L
s
.6355 .49774 m
.62887 .50421 L
s
.62633 .49704 m
.6355 .49774 L
s
.62887 .50421 m
.62633 .49704 L
s
.62885 .69581 m
.61722 .70414 L
s
.6158 .69237 m
.62885 .69581 L
s
.576 .776 .973 r
.47639 .40377 m .48912 .4098 L .48928 .39703 L p F P
0 0 0 r
s
.576 .776 .973 r
.48928 .39703 m .47661 .39098 L .47639 .40377 L p F P
0 0 0 r
s
.69 .09 .12 r
.53182 .59562 m
.57409 .59482 L
s
.4872 .89391 m
.49022 .899 L
s
.49043 .87846 m
.4872 .89391 L
s
.5058 .89087 m
.4872 .89391 L
s
.58077 .3966 m
.57745 .39984 L
s
.327 .449 .611 r
.54965 .41367 m .56387 .40937 L .56371 .3966 L p F P
0 0 0 r
s
.274 .382 .529 r
.57622 .3904 m .56371 .3966 L .56387 .40937 L p F P
0 0 0 r
s
.69 .09 .12 r
.57617 .39623 m
.58077 .3966 L
s
.57617 .39623 m
.57738 .3957 L
s
.57617 .39623 m
.57745 .39984 L
s
.5001 .6945 m
.50217 .69697 L
s
.50227 .68408 m
.5001 .6945 L
s
.51252 .69217 m
.5001 .6945 L
s
.57409 .59482 m
.5657 .59993 L
s
.56552 .59149 m
.57409 .59482 L
s
.51302 .49495 m
.51408 .49574 L
s
.5141 .48968 m
.51302 .49495 L
s
.51923 .49364 m
.51302 .49495 L
s
.48 .649 .84 r
.50336 .4268 m .51874 .42886 L .51877 .416 L p F P
0 0 0 r
s
.48 .649 .84 r
.51877 .416 m .50346 .41393 L .50336 .4268 L p F P
0 0 0 r
s
.431 .583 .767 r
.53439 .41591 m .51877 .416 L .51874 .42886 L p F P
0 0 0 r
s
.431 .583 .767 r
.51874 .42886 m .53443 .42877 L .53439 .41591 L p F P
0 0 0 r
s
.38 .517 .691 r
.54965 .41367 m .53439 .41591 L .53443 .42877 L p F P
0 0 0 r
s
.69 .09 .12 r
.56741 .79321 m
.5539 .80105 L
s
.55482 .78762 m
.56741 .79321 L
s
.49941 .79003 m
.56741 .79321 L
s
.49348 .88345 m
.49043 .87846 L
s
.49043 .87846 m
.5058 .89087 L
s
.50435 .68651 m
.50227 .68408 L
s
.50227 .68408 m
.51252 .69217 L
s
.61722 .70414 m
.6158 .69237 L
s
.51517 .49046 m
.5141 .48968 L
s
.5141 .48968 m
.51923 .49364 L
s
.51923 .49364 m
.51408 .49574 L
s
.51517 .49046 m
.51923 .49364 L
s
.49348 .48896 m
.51923 .49364 L
s
.53 .714 .909 r
.48896 .42268 m .50336 .4268 L .50346 .41393 L p F P
0 0 0 r
s
.53 .714 .909 r
.50346 .41393 m .48912 .4098 L .48896 .42268 L p F P
0 0 0 r
s
.69 .09 .12 r
.51252 .69217 m
.50217 .69697 L
s
.50435 .68651 m
.51252 .69217 L
s
.46081 .68384 m
.51252 .69217 L
s
.5657 .59993 m
.56552 .59149 L
s
.38 .517 .691 r
.53443 .42877 m .54975 .42654 L .54965 .41367 L p F P
0 0 0 r
s
.327 .449 .611 r
.56387 .40937 m .54965 .41367 L .54975 .42654 L p F P
0 0 0 r
s
.69 .09 .12 r
.71147 .59222 m
.75595 .56656 L
s
.5058 .89087 m
.49022 .899 L
s
.49348 .88345 m
.5058 .89087 L
s
.42795 .87994 m
.5058 .89087 L
s
.46426 .39227 m
.46234 .39218 L
s
.46242 .38803 m
.46426 .39227 L
s
.46426 .39227 m
.46003 .39094 L
s
.46474 .38927 m
.46426 .39227 L
s
.43418 .79094 m
.43826 .79504 L
s
.4387 .77808 m
.43418 .79094 L
s
.45077 .7898 m
.43418 .79094 L
s
.4471 .591 m
.45032 .59308 L
s
.45056 .58319 m
.4471 .591 L
s
.45752 .59095 m
.4471 .591 L
s
.45752 .59095 m
.45032 .59308 L
s
.45056 .58319 m
.45752 .59095 L
s
.4538 .58525 m
.45752 .59095 L
s
.4219 .57677 m
.45752 .59095 L
s
.46242 .38803 m
.46003 .39094 L
s
.46474 .38927 m
.46242 .38803 L
s
.51408 .49574 m
.51517 .49046 L
s
.4538 .58525 m
.45056 .58319 L
s
.44281 .78211 m
.4387 .77808 L
s
.4387 .77808 m
.45077 .7898 L
s
.61 .824 1 r
.46586 .39608 m .47639 .40377 L .47661 .39098 L p F P
0 0 0 r
s
.61 .824 1 r
.47661 .39098 m .46611 .38327 L .46586 .39608 L p F P
0 0 0 r
s
.69 .09 .12 r
.46003 .39094 m
.46234 .39218 L
s
.45077 .7898 m
.43826 .79504 L
s
.44281 .78211 m
.45077 .7898 L
s
.38877 .77335 m
.45077 .7898 L
s
.274 .382 .529 r
.56387 .40937 m .57644 .40319 L .57622 .3904 L p F P
0 0 0 r
s
.222 .311 .441 r
.58651 .38257 m .57622 .3904 L .57644 .40319 L p F P
0 0 0 r
s
.69 .09 .12 r
.40241 .48952 m
.39832 .48971 L
s
.39867 .48114 m
.40241 .48952 L
s
.40241 .48952 m
.39384 .48701 L
s
.40317 .48382 m
.40241 .48952 L
s
.38266 .4688 m
.40241 .48952 L
s
.5539 .80105 m
.55482 .78762 L
s
.46234 .39218 m
.46474 .38927 L
s
.576 .776 .973 r
.47618 .41666 m .48896 .42268 L .48912 .4098 L p F P
0 0 0 r
s
.576 .776 .973 r
.48912 .4098 m .47639 .40377 L .47618 .41666 L p F P
0 0 0 r
s
.69 .09 .12 r
.39563 .68852 m
.38616 .69128 L
s
.38677 .67683 m
.39563 .68852 L
s
.39563 .68852 m
.38091 .68746 L
s
.39205 .68061 m
.39563 .68852 L
s
.34927 .66587 m
.39563 .68852 L
s
.327 .449 .611 r
.54975 .42654 m .56404 .42225 L .56387 .40937 L p F P
0 0 0 r
s
.274 .382 .529 r
.57644 .40319 m .56387 .40937 L .56404 .42225 L p F P
0 0 0 r
s
.69 .09 .12 r
.39867 .48114 m
.39384 .48701 L
s
.40317 .48382 m
.39867 .48114 L
s
.3472 .38791 m
.34611 .38702 L
s
.34667 .37774 m
.3472 .38791 L
s
.3472 .38791 m
.34032 .38251 L
s
.35246 .38225 m
.3472 .38791 L
s
.34309 .35992 m
.3472 .38791 L
s
.38677 .67683 m
.38091 .68746 L
s
.39205 .68061 m
.38677 .67683 L
s
.38091 .68746 m
.38616 .69128 L
s
.50217 .69697 m
.50435 .68651 L
s
.48 .649 .84 r
.50326 .43978 m .51871 .44183 L .51874 .42886 L p F P
0 0 0 r
s
.48 .649 .84 r
.51874 .42886 m .50336 .4268 L .50326 .43978 L p F P
0 0 0 r
s
.431 .583 .767 r
.53443 .42877 m .51874 .42886 L .51871 .44183 L p F P
0 0 0 r
s
.431 .583 .767 r
.51871 .44183 m .53446 .44174 L .53443 .42877 L p F P
0 0 0 r
s
.38 .517 .691 r
.54975 .42654 m .53443 .42877 L .53446 .44174 L p F P
0 0 0 r
s
.69 .09 .12 r
.34039 .58705 m
.33388 .58788 L
s
.33469 .57459 m
.34039 .58705 L
s
.34039 .58705 m
.32737 .58348 L
s
.34122 .57895 m
.34039 .58705 L
s
.30944 .55748 m
.34039 .58705 L
s
.39384 .48701 m
.39832 .48971 L
s
.45032 .59308 m
.4538 .58525 L
s
.53 .714 .909 r
.4888 .43567 m .50326 .43978 L .50336 .4268 L p F P
0 0 0 r
s
.53 .714 .909 r
.50336 .4268 m .48896 .42268 L .4888 .43567 L p F P
0 0 0 r
s
.69 .09 .12 r
.28504 .48539 m
.2814 .48488 L
s
.28248 .47129 m
.28504 .48539 L
s
.28504 .48539 m
.27357 .47899 L
s
.29031 .47714 m
.28504 .48539 L
s
.26926 .44817 m
.28504 .48539 L
s
.34667 .37774 m
.34032 .38251 L
s
.35246 .38225 m
.34667 .37774 L
s
.6738 .48533 m
.70032 .46362 L
s
.38 .517 .691 r
.53446 .44174 m .54985 .43952 L .54975 .42654 L p F P
0 0 0 r
s
.327 .449 .611 r
.56404 .42225 m .54975 .42654 L .54985 .43952 L p F P
0 0 0 r
s
.69 .09 .12 r
.87261 .37082 m
.88431 .38176 L
s
.86294 .37746 m
.87261 .37082 L
s
.87261 .37082 m
.88018 .36943 L
s
.33469 .57459 m
.32737 .58348 L
s
.34122 .57895 m
.33469 .57459 L
s
.49022 .899 m
.49348 .88345 L
s
.39832 .48971 m
.40317 .48382 L
s
.22958 .38353 m
.22867 .3821 L
s
.23017 .36711 m
.22958 .38353 L
s
.22958 .38353 m
.21951 .37399 L
s
.23933 .37517 m
.22958 .38353 L
s
.22875 .33794 m
.22958 .38353 L
s
.603 .821 .995 r
.458 .38706 m .46586 .39608 L .46611 .38327 L p F P
0 0 0 r
s
.603 .821 .995 r
.46611 .38327 m .4583 .37423 L .458 .38706 L p F P
0 0 0 r
s
.69 .09 .12 r
.45482 .38141 m
.45805 .38512 L
s
.32737 .58348 m
.33388 .58788 L
s
.61 .824 1 r
.4656 .40899 m .47618 .41666 L .47639 .40377 L p F P
0 0 0 r
s
.61 .824 1 r
.47639 .40377 m .46586 .39608 L .4656 .40899 L p F P
0 0 0 r
s
.222 .311 .441 r
.57644 .40319 m .58677 .39538 L .58651 .38257 L p F P
0 0 0 r
s
.158 .22 .329 r
.59409 .37343 m .58651 .38257 L .58677 .39538 L p F P
0 0 0 r
s
.69 .09 .12 r
.34032 .38251 m
.34611 .38702 L
s
.274 .382 .529 r
.56404 .42225 m .57666 .41609 L .57644 .40319 L p F P
0 0 0 r
s
.222 .311 .441 r
.58677 .39538 m .57644 .40319 L .57666 .41609 L p F P
0 0 0 r
s
.69 .09 .12 r
.34611 .38702 m
.35246 .38225 L
s
.43826 .79504 m
.44281 .78211 L
s
.88431 .38176 m
.87468 .38845 L
s
.88018 .36943 m
.88431 .38176 L
s
.28248 .47129 m
.27357 .47899 L
s
.29031 .47714 m
.28248 .47129 L
s
.85487 .48168 m
.88773 .43255 L
s
.576 .776 .973 r
.47597 .42967 m .4888 .43567 L .48896 .42268 L p F P
0 0 0 r
s
.576 .776 .973 r
.48896 .42268 m .47618 .41666 L .47597 .42967 L p F P
0 0 0 r
s
.327 .449 .611 r
.54985 .43952 m .5642 .43525 L .56404 .42225 L p F P
0 0 0 r
s
.274 .382 .529 r
.57666 .41609 m .56404 .42225 L .5642 .43525 L p F P
0 0 0 r
s
.48 .649 .84 r
.50317 .45287 m .51868 .45492 L .51871 .44183 L p F P
0 0 0 r
s
.48 .649 .84 r
.51871 .44183 m .50326 .43978 L .50317 .45287 L p F P
0 0 0 r
s
.431 .583 .767 r
.53446 .44174 m .51871 .44183 L .51868 .45492 L p F P
0 0 0 r
s
.69 .09 .12 r
.80974 .46771 m
.81869 .47828 L
s
.80219 .47258 m
.80974 .46771 L
s
.80974 .46771 m
.81815 .46786 L
s
.38616 .69128 m
.39205 .68061 L
s
.64163 .6806 m
.69357 .66555 L
s
.431 .583 .767 r
.51868 .45492 m .5345 .45483 L .53446 .44174 L p F P
0 0 0 r
s
.38 .517 .691 r
.54985 .43952 m .53446 .44174 L .5345 .45483 L p F P
0 0 0 r
s
.69 .09 .12 r
.23017 .36711 m
.21951 .37399 L
s
.23933 .37517 m
.23017 .36711 L
s
.27357 .47899 m
.2814 .48488 L
s
.33388 .58788 m
.34122 .57895 L
s
.81869 .47828 m
.81118 .48321 L
s
.81815 .46786 m
.81869 .47828 L
s
.63581 .37754 m
.64458 .36047 L
s
.87468 .38845 m
.86294 .37746 L
s
.86294 .37746 m
.88018 .36943 L
s
.53 .714 .909 r
.48864 .44878 m .50317 .45287 L .50326 .43978 L p F P
0 0 0 r
s
.53 .714 .909 r
.50326 .43978 m .4888 .43567 L .48864 .44878 L p F P
0 0 0 r
s
.38 .517 .691 r
.5345 .45483 m .54995 .45261 L .54985 .43952 L p F P
0 0 0 r
s
.327 .449 .611 r
.5642 .43525 m .54985 .43952 L .54995 .45261 L p F P
0 0 0 r
s
.69 .09 .12 r
.2814 .48488 m
.29031 .47714 L
s
.75825 .36592 m
.76595 .37324 L
s
.75146 .37035 m
.75825 .36592 L
s
.75825 .36592 m
.76266 .36496 L
s
.603 .821 .995 r
.45771 .4 m .4656 .40899 L .46586 .39608 L p F P
0 0 0 r
s
.603 .821 .995 r
.46586 .39608 m .458 .38706 L .45771 .4 L p F P
0 0 0 r
s
.69 .09 .12 r
.22867 .3821 m
.23933 .37517 L
s
.61 .824 1 r
.46533 .42202 m .47597 .42967 L .47618 .41666 L p F P
0 0 0 r
s
.61 .824 1 r
.47618 .41666 m .4656 .40899 L .46533 .42202 L p F P
0 0 0 r
s
.222 .311 .441 r
.57666 .41609 m .58704 .4083 L .58677 .39538 L p F P
0 0 0 r
s
.158 .22 .329 r
.59439 .38627 m .58677 .39538 L .58704 .4083 L p F P
0 0 0 r
s
.158 .22 .329 r
.58677 .39538 m .59439 .38627 L .59409 .37343 L p F P
0 0 0 r
s
.274 .382 .529 r
.5642 .43525 m .57688 .4291 L .57666 .41609 L p F P
0 0 0 r
s
.222 .311 .441 r
.58704 .4083 m .57666 .41609 L .57688 .4291 L p F P
0 0 0 r
s
.491 .682 .818 r
.45323 .3771 m .458 .38706 L .4583 .37423 L p F P
0 0 0 r
s
.491 .682 .818 r
.4583 .37423 m .45355 .36424 L .45323 .3771 L p F P
0 0 0 r
s
.69 .09 .12 r
.74645 .56475 m
.7528 .57522 L
s
.74106 .56829 m
.74645 .56475 L
s
.74645 .56475 m
.75595 .56656 L
s
.88018 .36943 m
.87468 .38845 L
s
.21951 .37399 m
.22867 .3821 L
s
.7528 .57522 m
.74743 .5788 L
s
.75595 .56656 m
.7528 .57522 L
s
.81755 .37365 m
.83121 .32757 L
s
.092 .135 .215 r
.59857 .36339 m .59409 .37343 L .59439 .38627 L p F P
0 0 0 r
s
.69 .09 .12 r
.76595 .37324 m
.75918 .37769 L
s
.76266 .36496 m
.76595 .37324 L
s
.576 .776 .973 r
.47575 .44279 m .48864 .44878 L .4888 .43567 L p F P
0 0 0 r
s
.576 .776 .973 r
.4888 .43567 m .47597 .42967 L .47575 .44279 L p F P
0 0 0 r
s
.327 .449 .611 r
.54995 .45261 m .56437 .44835 L .5642 .43525 L p F P
0 0 0 r
s
.274 .382 .529 r
.57688 .4291 m .5642 .43525 L .56437 .44835 L p F P
0 0 0 r
s
.69 .09 .12 r
.81118 .48321 m
.80219 .47258 L
s
.80219 .47258 m
.81815 .46786 L
s
.60339 .57329 m
.6378 .56255 L
s
.48 .649 .84 r
.50307 .46608 m .51864 .46812 L .51868 .45492 L p F P
0 0 0 r
s
.48 .649 .84 r
.51868 .45492 m .50317 .45287 L .50307 .46608 L p F P
0 0 0 r
s
.431 .583 .767 r
.5345 .45483 m .51868 .45492 L .51864 .46812 L p F P
0 0 0 r
s
.431 .583 .767 r
.51864 .46812 m .53454 .46803 L .5345 .45483 L p F P
0 0 0 r
s
.38 .517 .691 r
.54995 .45261 m .5345 .45483 L .53454 .46803 L p F P
0 0 0 r
s
.69 .09 .12 r
.75918 .37769 m
.75146 .37035 L
s
.75146 .37035 m
.76266 .36496 L
s
.81815 .46786 m
.81118 .48321 L
s
.6947 .4632 m
.69978 .47019 L
s
.69014 .46581 m
.6947 .4632 L
s
.6947 .4632 m
.70032 .46362 L
s
.68662 .67257 m
.68343 .67549 L
s
.68277 .66171 m
.68662 .67257 L
s
.69357 .66555 m
.68662 .67257 L
s
.53 .714 .909 r
.48848 .46199 m .50307 .46608 L .50317 .45287 L p F P
0 0 0 r
s
.53 .714 .909 r
.50317 .45287 m .48864 .44878 L .48848 .46199 L p F P
0 0 0 r
s
.69 .09 .12 r
.69978 .47019 m
.69523 .47283 L
s
.70032 .46362 m
.69978 .47019 L
s
.67956 .66458 m
.68277 .66171 L
s
.68277 .66171 m
.69357 .66555 L
s
.38 .517 .691 r
.53454 .46803 m .55006 .46582 L .54995 .45261 L p F P
0 0 0 r
s
.327 .449 .611 r
.56437 .44835 m .54995 .45261 L .55006 .46582 L p F P
0 0 0 r
s
.69 .09 .12 r
.76266 .36496 m
.75918 .37769 L
s
.78563 .5698 m
.82439 .53317 L
s
.603 .821 .995 r
.45741 .41305 m .46533 .42202 L .4656 .40899 L p F P
0 0 0 r
s
.603 .821 .995 r
.4656 .40899 m .45771 .4 L .45741 .41305 L p F P
0 0 0 r
s
.61 .824 1 r
.46507 .43517 m .47575 .44279 L .47597 .42967 L p F P
0 0 0 r
s
.61 .824 1 r
.47597 .42967 m .46533 .42202 L .46507 .43517 L p F P
0 0 0 r
s
.222 .311 .441 r
.57688 .4291 m .5873 .42133 L .58704 .4083 L p F P
0 0 0 r
s
.158 .22 .329 r
.59468 .39921 m .58704 .4083 L .5873 .42133 L p F P
0 0 0 r
s
.158 .22 .329 r
.58704 .4083 m .59468 .39921 L .59439 .38627 L p F P
0 0 0 r
s
.274 .382 .529 r
.56437 .44835 m .5771 .44222 L .57688 .4291 L p F P
0 0 0 r
s
.222 .311 .441 r
.5873 .42133 m .57688 .4291 L .5771 .44222 L p F P
0 0 0 r
s
.491 .682 .818 r
.45292 .39006 m .45771 .4 L .458 .38706 L p F P
0 0 0 r
s
.491 .682 .818 r
.458 .38706 m .45323 .3771 L .45292 .39006 L p F P
0 0 0 r
s
.69 .09 .12 r
.74743 .5788 m
.74106 .56829 L
s
.74106 .56829 m
.75595 .56656 L
s
.62016 .77033 m
.61914 .77342 L
s
.61872 .75842 m
.62016 .77033 L
s
.63101 .76481 m
.62016 .77033 L
s
.57076 .77028 m
.63101 .76481 L
s
.75595 .56656 m
.74743 .5788 L
s
.6427 .36097 m
.6465 .36464 L
s
.63913 .36318 m
.6427 .36097 L
s
.6427 .36097 m
.64458 .36047 L
s
.092 .135 .215 r
.59889 .37625 m .59439 .38627 L .59468 .39921 L p F P
0 0 0 r
s
.092 .135 .215 r
.59439 .38627 m .59889 .37625 L .59857 .36339 L p F P
0 0 0 r
s
.69 .09 .12 r
.63332 .56755 m
.63103 .56917 L
s
.63074 .56027 m
.63332 .56755 L
s
.6378 .56255 m
.63332 .56755 L
s
.576 .776 .973 r
.47553 .45603 m .48848 .46199 L .48864 .44878 L p F P
0 0 0 r
s
.576 .776 .973 r
.48864 .44878 m .47575 .44279 L .47553 .45603 L p F P
0 0 0 r
s
.69 .09 .12 r
.62844 .56187 m
.63074 .56027 L
s
.63074 .56027 m
.6378 .56255 L
s
.6465 .36464 m
.64293 .36686 L
s
.64458 .36047 m
.6465 .36464 L
s
.69523 .47283 m
.69014 .46581 L
s
.69014 .46581 m
.70032 .46362 L
s
.327 .449 .611 r
.55006 .46582 m .56453 .46157 L .56437 .44835 L p F P
0 0 0 r
s
.274 .382 .529 r
.5771 .44222 m .56437 .44835 L .56453 .46157 L p F P
0 0 0 r
s
.69 .09 .12 r
.61769 .76146 m
.61872 .75842 L
s
.61872 .75842 m
.63101 .76481 L
s
.335 .477 .554 r
.45182 .36664 m .45323 .3771 L .45355 .36424 L p F P
0 0 0 r
s
.335 .477 .554 r
.45355 .36424 m .45214 .35376 L .45182 .36664 L p F P
0 0 0 r
s
.69 .09 .12 r
.70032 .46362 m
.69523 .47283 L
s
.06 .089 .131 r
.5997 .35288 m .59857 .36339 L .59889 .37625 L p F P
0 0 0 r
s
.48 .649 .84 r
.50297 .4794 m .51861 .48143 L .51864 .46812 L p F P
0 0 0 r
s
.48 .649 .84 r
.51864 .46812 m .50307 .46608 L .50297 .4794 L p F P
0 0 0 r
s
.431 .583 .767 r
.53454 .46803 m .51864 .46812 L .51861 .48143 L p F P
0 0 0 r
s
.431 .583 .767 r
.51861 .48143 m .53458 .48134 L .53454 .46803 L p F P
0 0 0 r
s
.38 .517 .691 r
.55006 .46582 m .53454 .46803 L .53458 .48134 L p F P
0 0 0 r
s
.69 .09 .12 r
.64293 .36686 m
.63913 .36318 L
s
.63913 .36318 m
.64458 .36047 L
s
.64458 .36047 m
.64293 .36686 L
s
.55341 .86851 m
.55449 .87258 L
s
.55435 .85494 m
.55341 .86851 L
s
.56828 .86435 m
.55341 .86851 L
s
.69357 .66555 m
.68343 .67549 L
s
.67956 .66458 m
.69357 .66555 L
s
.56658 .66533 m
.56653 .66708 L
s
.56641 .65679 m
.56658 .66533 L
s
.57511 .66177 m
.56658 .66533 L
s
.53 .714 .909 r
.48832 .47533 m .50297 .4794 L .50307 .46608 L p F P
0 0 0 r
s
.53 .714 .909 r
.50307 .46608 m .48848 .46199 L .48832 .47533 L p F P
0 0 0 r
s
.69 .09 .12 r
.68343 .67549 m
.67956 .66458 L
s
.38 .517 .691 r
.53458 .48134 m .55016 .47914 L .55006 .46582 L p F P
0 0 0 r
s
.327 .449 .611 r
.56453 .46157 m .55006 .46582 L .55016 .47914 L p F P
0 0 0 r
s
.69 .09 .12 r
.57976 .46202 m
.57853 .46267 L
s
.57846 .45835 m
.57976 .46202 L
s
.58192 .45936 m
.57976 .46202 L
s
.57846 .45835 m
.58192 .45936 L
s
.56635 .65851 m
.56641 .65679 L
s
.56641 .65679 m
.57511 .66177 L
s
.55543 .85893 m
.55435 .85494 L
s
.55435 .85494 m
.56828 .86435 L
s
.74775 .46135 m
.76772 .42814 L
s
.6378 .56255 m
.63103 .56917 L
s
.62844 .56187 m
.6378 .56255 L
s
.63103 .56917 m
.62844 .56187 L
s
.603 .821 .995 r
.45711 .42622 m .46507 .43517 L .46533 .42202 L p F P
0 0 0 r
s
.603 .821 .995 r
.46533 .42202 m .45741 .41305 L .45711 .42622 L p F P
0 0 0 r
s
.69 .09 .12 r
.63101 .76481 m
.61914 .77342 L
s
.61769 .76146 m
.63101 .76481 L
s
.61 .824 1 r
.4648 .44843 m .47553 .45603 L .47575 .44279 L p F P
0 0 0 r
s
.61 .824 1 r
.47575 .44279 m .46507 .43517 L .4648 .44843 L p F P
0 0 0 r
s
.222 .311 .441 r
.5771 .44222 m .58757 .43447 L .5873 .42133 L p F P
0 0 0 r
s
.158 .22 .329 r
.59498 .41227 m .5873 .42133 L .58757 .43447 L p F P
0 0 0 r
s
.158 .22 .329 r
.5873 .42133 m .59498 .41227 L .59468 .39921 L p F P
0 0 0 r
s
.274 .382 .529 r
.56453 .46157 m .57732 .45546 L .5771 .44222 L p F P
0 0 0 r
s
.69 .09 .12 r
.57723 .45899 m
.57846 .45835 L
s
.56482 .46508 m
.58192 .45936 L
s
.222 .311 .441 r
.58757 .43447 m .5771 .44222 L .57732 .45546 L p F P
0 0 0 r
s
.491 .682 .818 r
.4526 .40314 m .45741 .41305 L .45771 .4 L p F P
0 0 0 r
s
.491 .682 .818 r
.45771 .4 m .45292 .39006 L .4526 .40314 L p F P
0 0 0 r
s
.69 .09 .12 r
.53194 .66255 m
.57511 .66177 L
s
.48639 .96711 m
.48947 .97281 L
s
.48969 .95141 m
.48639 .96711 L
s
.50537 .96418 m
.48639 .96711 L
s
.58192 .45936 m
.57853 .46267 L
s
.57723 .45899 m
.58192 .45936 L
s
.57723 .45899 m
.57853 .46267 L
s
.49956 .76353 m
.50167 .76638 L
s
.50177 .75294 m
.49956 .76353 L
s
.51223 .76126 m
.49956 .76353 L
s
.092 .135 .215 r
.59921 .38922 m .59468 .39921 L .59498 .41227 L p F P
0 0 0 r
s
.092 .135 .215 r
.59468 .39921 m .59921 .38922 L .59889 .37625 L p F P
0 0 0 r
s
.69 .09 .12 r
.57511 .66177 m
.56653 .66708 L
s
.56635 .65851 m
.57511 .66177 L
s
.576 .776 .973 r
.47531 .46938 m .48832 .47533 L .48848 .46199 L p F P
0 0 0 r
s
.576 .776 .973 r
.48848 .46199 m .47553 .45603 L .47531 .46938 L p F P
0 0 0 r
s
.69 .09 .12 r
.51274 .55981 m
.51383 .56077 L
s
.51385 .55445 m
.51274 .55981 L
s
.51909 .55853 m
.51274 .55981 L
s
.327 .449 .611 r
.55016 .47914 m .5647 .4749 L .56453 .46157 L p F P
0 0 0 r
s
.274 .382 .529 r
.57732 .45546 m .56453 .46157 L .5647 .4749 L p F P
0 0 0 r
s
.69 .09 .12 r
.56828 .86435 m
.55449 .87258 L
s
.55543 .85893 m
.56828 .86435 L
s
.49885 .86127 m
.56828 .86435 L
s
.49279 .95701 m
.48969 .95141 L
s
.48969 .95141 m
.50537 .96418 L
s
.50389 .75574 m
.50177 .75294 L
s
.50177 .75294 m
.51223 .76126 L
s
.335 .477 .554 r
.45149 .37963 m .45292 .39006 L .45323 .3771 L p F P
0 0 0 r
s
.335 .477 .554 r
.45323 .3771 m .45182 .36664 L .45149 .37963 L p F P
0 0 0 r
s
.69 .09 .12 r
.61914 .77342 m
.61769 .76146 L
s
.51494 .55539 m
.51385 .55445 L
s
.51385 .55445 m
.51909 .55853 L
s
.06 .089 .131 r
.60002 .36577 m .59889 .37625 L .59921 .38922 L p F P
0 0 0 r
s
.06 .089 .131 r
.59889 .37625 m .60002 .36577 L .5997 .35288 L p F P
0 0 0 r
s
.48 .649 .84 r
.50287 .49283 m .51858 .49486 L .51861 .48143 L p F P
0 0 0 r
s
.48 .649 .84 r
.51861 .48143 m .50297 .4794 L .50287 .49283 L p F P
0 0 0 r
s
.431 .583 .767 r
.53458 .48134 m .51861 .48143 L .51858 .49486 L p F P
0 0 0 r
s
.69 .09 .12 r
.51909 .55853 m
.51383 .56077 L
s
.51494 .55539 m
.51909 .55853 L
s
.49279 .55392 m
.51909 .55853 L
s
.431 .583 .767 r
.51858 .49486 m .53461 .49477 L .53458 .48134 L p F P
0 0 0 r
s
.38 .517 .691 r
.55016 .47914 m .53458 .48134 L .53461 .49477 L p F P
0 0 0 r
s
.69 .09 .12 r
.51223 .76126 m
.50167 .76638 L
s
.50389 .75574 m
.51223 .76126 L
s
.45943 .75313 m
.51223 .76126 L
s
.56653 .66708 m
.56635 .65851 L
s
.71538 .65923 m
.76086 .63408 L
s
.06 .088 .13 r
.45387 .35617 m .45182 .36664 L .45214 .35376 L p F P
0 0 0 r
s
.06 .088 .13 r
.45214 .35376 m .45419 .34326 L .45387 .35617 L p F P
0 0 0 r
s
.69 .09 .12 r
.50537 .96418 m
.48947 .97281 L
s
.49279 .95701 m
.50537 .96418 L
s
.42587 .95362 m
.50537 .96418 L
s
.46296 .45508 m
.46099 .45511 L
s
.46109 .45079 m
.46296 .45508 L
s
.46296 .45508 m
.45864 .45377 L
s
.46345 .45212 m
.46296 .45508 L
s
.43225 .86215 m
.4364 .86674 L
s
.43686 .84905 m
.43225 .86215 L
s
.44918 .86104 m
.43225 .86215 L
s
.53 .714 .909 r
.48815 .48878 m .50287 .49283 L .50297 .4794 L p F P
0 0 0 r
s
.53 .714 .909 r
.50297 .4794 m .48832 .47533 L .48815 .48878 L p F P
0 0 0 r
s
.338 .478 .556 r
.59737 .34241 m .5997 .35288 L .60002 .36577 L p F P
0 0 0 r
s
.38 .517 .691 r
.53461 .49477 m .55027 .49257 L .55016 .47914 L p F P
0 0 0 r
s
.327 .449 .611 r
.5647 .4749 m .55016 .47914 L .55027 .49257 L p F P
0 0 0 r
s
.69 .09 .12 r
.44544 .65803 m
.44873 .66038 L
s
.44897 .65006 m
.44544 .65803 L
s
.45608 .65797 m
.44544 .65803 L
s
.45608 .65797 m
.44873 .66038 L
s
.44897 .65006 m
.45608 .65797 L
s
.45227 .65239 m
.45608 .65797 L
s
.41969 .64408 m
.45608 .65797 L
s
.46109 .45079 m
.45864 .45377 L
s
.46345 .45212 m
.46109 .45079 L
s
.51383 .56077 m
.51494 .55539 L
s
.45227 .65239 m
.44897 .65006 L
s
.44104 .85358 m
.43686 .84905 L
s
.43686 .84905 m
.44918 .86104 L
s
.70956 .35199 m
.71094 .3229 L
s
.45864 .45377 m
.46099 .45511 L
s
.44918 .86104 m
.4364 .86674 L
s
.44104 .85358 m
.44918 .86104 L
s
.38585 .84507 m
.44918 .86104 L
s
.40672 .35143 m
.40795 .3509 L
s
.40819 .34499 m
.40672 .35143 L
s
.40672 .35143 m
.40426 .34721 L
s
.41187 .34869 m
.40672 .35143 L
s
.4135 .33388 m
.40672 .35143 L
s
.603 .821 .995 r
.45681 .43951 m .4648 .44843 L .46507 .43517 L p F P
0 0 0 r
s
.603 .821 .995 r
.46507 .43517 m .45711 .42622 L .45681 .43951 L p F P
0 0 0 r
s
.69 .09 .12 r
.39981 .55448 m
.39562 .55492 L
s
.39599 .54598 m
.39981 .55448 L
s
.39981 .55448 m
.39105 .55201 L
s
.40057 .54887 m
.39981 .55448 L
s
.3796 .53409 m
.39981 .55448 L
s
.61 .824 1 r
.46453 .4618 m .47531 .46938 L .47553 .45603 L p F P
0 0 0 r
s
.61 .824 1 r
.47553 .45603 m .4648 .44843 L .46453 .4618 L p F P
0 0 0 r
s
.69 .09 .12 r
.55449 .87258 m
.55543 .85893 L
s
.46099 .45511 m
.46345 .45212 L
s
.222 .311 .441 r
.57732 .45546 m .58784 .44774 L .58757 .43447 L p F P
0 0 0 r
s
.158 .22 .329 r
.59529 .42544 m .58757 .43447 L .58784 .44774 L p F P
0 0 0 r
s
.158 .22 .329 r
.58757 .43447 m .59529 .42544 L .59498 .41227 L p F P
0 0 0 r
s
.274 .382 .529 r
.5647 .4749 m .57755 .46881 L .57732 .45546 L p F P
0 0 0 r
s
.222 .311 .441 r
.58784 .44774 m .57732 .45546 L .57755 .46881 L p F P
0 0 0 r
s
.69 .09 .12 r
.40819 .34499 m
.40426 .34721 L
s
.41187 .34869 m
.40819 .34499 L
s
.39288 .7577 m
.3832 .76088 L
s
.38384 .74581 m
.39288 .7577 L
s
.39288 .7577 m
.37784 .75667 L
s
.38921 .74998 m
.39288 .7577 L
s
.34549 .73559 m
.39288 .7577 L
s
.491 .682 .818 r
.45227 .41634 m .45711 .42622 L .45741 .41305 L p F P
0 0 0 r
s
.491 .682 .818 r
.45741 .41305 m .4526 .40314 L .45227 .41634 L p F P
0 0 0 r
s
.092 .135 .215 r
.59953 .4023 m .59498 .41227 L .59529 .42544 L p F P
0 0 0 r
s
.092 .135 .215 r
.59498 .41227 m .59953 .4023 L .59921 .38922 L p F P
0 0 0 r
s
.69 .09 .12 r
.39599 .54598 m
.39105 .55201 L
s
.40057 .54887 m
.39599 .54598 L
s
.34343 .45078 m
.34229 .45017 L
s
.34288 .44049 m
.34343 .45078 L
s
.34343 .45078 m
.33639 .44545 L
s
.34879 .4452 m
.34343 .45078 L
s
.33917 .42317 m
.34343 .45078 L
s
.40795 .3509 m
.41187 .34869 L
s
.576 .776 .973 r
.47509 .48285 m .48815 .48878 L .48832 .47533 L p F P
0 0 0 r
s
.576 .776 .973 r
.48832 .47533 m .47531 .46938 L .47509 .48285 L p F P
0 0 0 r
s
.69 .09 .12 r
.38384 .74581 m
.37784 .75667 L
s
.38921 .74998 m
.38384 .74581 L
s
.37784 .75667 m
.3832 .76088 L
s
.50167 .76638 m
.50389 .75574 L
s
.327 .449 .611 r
.55027 .49257 m .56487 .48835 L .5647 .4749 L p F P
0 0 0 r
s
.274 .382 .529 r
.57755 .46881 m .5647 .4749 L .56487 .48835 L p F P
0 0 0 r
s
.69 .09 .12 r
.33647 .65416 m
.32981 .65539 L
s
.33064 .64153 m
.33647 .65416 L
s
.33647 .65416 m
.32317 .65066 L
s
.3373 .64622 m
.33647 .65416 L
s
.30478 .62517 m
.33647 .65416 L
s
.39105 .55201 m
.39562 .55492 L
s
.335 .477 .554 r
.45116 .39274 m .4526 .40314 L .45292 .39006 L p F P
0 0 0 r
s
.335 .477 .554 r
.45292 .39006 m .45149 .37963 L .45116 .39274 L p F P
0 0 0 r
s
.69 .09 .12 r
.40426 .34721 m
.40795 .3509 L
s
.06 .089 .131 r
.60035 .37876 m .59921 .38922 L .59953 .4023 L p F P
0 0 0 r
s
.06 .089 .131 r
.59921 .38922 m .60035 .37876 L .60002 .36577 L p F P
0 0 0 r
s
.48 .649 .84 r
.50277 .50639 m .51855 .50841 L .51858 .49486 L p F P
0 0 0 r
s
.48 .649 .84 r
.51858 .49486 m .50287 .49283 L .50277 .50639 L p F P
0 0 0 r
s
.431 .583 .767 r
.53461 .49477 m .51858 .49486 L .51855 .50841 L p F P
0 0 0 r
s
.69 .09 .12 r
.28693 .34688 m
.28871 .34579 L
s
.28967 .33396 m
.28693 .34688 L
s
.28693 .34688 m
.28145 .33837 L
s
.29692 .34136 m
.28693 .34688 L
s
.29839 .31128 m
.28693 .34688 L
s
.431 .583 .767 r
.51855 .50841 m .53465 .50832 L .53461 .49477 L p F P
0 0 0 r
s
.38 .517 .691 r
.55027 .49257 m .53461 .49477 L .53465 .50832 L p F P
0 0 0 r
s
.69 .09 .12 r
.44873 .66038 m
.45227 .65239 L
s
.27995 .55041 m
.2762 .55031 L
s
.27732 .53615 m
.27995 .55041 L
s
.27995 .55041 m
.26822 .54412 L
s
.28531 .5423 m
.27995 .55041 L
s
.26372 .5138 m
.27995 .55041 L
s
.34288 .44049 m
.33639 .44545 L
s
.34879 .4452 m
.34288 .44049 L
s
.67692 .55035 m
.70405 .529 L
s
.87994 .43343 m
.8919 .44471 L
s
.8701 .44047 m
.87994 .43343 L
s
.87994 .43343 m
.88773 .43255 L
s
.06 .088 .13 r
.45355 .36919 m .45149 .37963 L .45182 .36664 L p F P
0 0 0 r
s
.06 .088 .13 r
.45182 .36664 m .45387 .35617 L .45355 .36919 L p F P
0 0 0 r
s
.69 .09 .12 r
.33064 .64153 m
.32317 .65066 L
s
.3373 .64622 m
.33064 .64153 L
s
.53 .714 .909 r
.48799 .50234 m .50277 .50639 L .50287 .49283 L p F P
0 0 0 r
s
.53 .714 .909 r
.50287 .49283 m .48815 .48878 L .48799 .50234 L p F P
0 0 0 r
s
.69 .09 .12 r
.48947 .97281 m
.49279 .95701 L
s
.338 .478 .556 r
.59768 .35532 m .60002 .36577 L .60035 .37876 L p F P
0 0 0 r
s
.338 .478 .556 r
.60002 .36577 m .59768 .35532 L .59737 .34241 L p F P
0 0 0 r
s
.38 .517 .691 r
.53465 .50832 m .55038 .50613 L .55027 .49257 L p F P
0 0 0 r
s
.327 .449 .611 r
.56487 .48835 m .55027 .49257 L .55038 .50613 L p F P
0 0 0 r
s
.69 .09 .12 r
.39562 .55492 m
.40057 .54887 L
s
.22332 .44646 m
.22233 .44547 L
s
.2239 .42984 m
.22332 .44646 L
s
.22332 .44646 m
.21299 .43705 L
s
.23323 .43822 m
.22332 .44646 L
s
.22231 .40146 m
.22332 .44646 L
s
.32317 .65066 m
.32981 .65539 L
s
.28967 .33396 m
.28145 .33837 L
s
.29692 .34136 m
.28967 .33396 L
s
.09 .133 .211 r
.45936 .34618 m .45387 .35617 L .45419 .34326 L p F P
0 0 0 r
s
.09 .133 .211 r
.45419 .34326 m .45965 .33325 L .45936 .34618 L p F P
0 0 0 r
s
.69 .09 .12 r
.33639 .44545 m
.34229 .45017 L
s
.34229 .45017 m
.34879 .4452 L
s
.603 .821 .995 r
.4565 .45291 m .46453 .4618 L .4648 .44843 L p F P
0 0 0 r
s
.603 .821 .995 r
.4648 .44843 m .45681 .43951 L .4565 .45291 L p F P
0 0 0 r
s
.69 .09 .12 r
.45331 .44437 m
.45661 .44803 L
s
.4364 .86674 m
.44104 .85358 L
s
.497 .683 .822 r
.59163 .33246 m .59737 .34241 L .59768 .35532 L p F P
0 0 0 r
s
.69 .09 .12 r
.8919 .44471 m
.88209 .45181 L
s
.88773 .43255 m
.8919 .44471 L
s
.16657 .3423 m
.16821 .34063 L
s
.17038 .32284 m
.16657 .3423 L
s
.16657 .3423 m
.15749 .32945 L
s
.18108 .33397 m
.16657 .3423 L
s
.18053 .28814 m
.16657 .3423 L
s
.27732 .53615 m
.26822 .54412 L
s
.28531 .5423 m
.27732 .53615 L
s
.61 .824 1 r
.46426 .47529 m .47509 .48285 L .47531 .46938 L p F P
0 0 0 r
s
.61 .824 1 r
.47531 .46938 m .46453 .4618 L .46426 .47529 L p F P
0 0 0 r
s
.69 .09 .12 r
.86183 .54676 m
.89561 .49842 L
s
.82765 .32944 m
.83833 .33758 L
s
.81851 .33635 m
.82765 .32944 L
s
.82765 .32944 m
.83121 .32757 L
s
.222 .311 .441 r
.57755 .46881 m .58811 .46111 L .58784 .44774 L p F P
0 0 0 r
s
.158 .22 .329 r
.59559 .43872 m .58784 .44774 L .58811 .46111 L p F P
0 0 0 r
s
.158 .22 .329 r
.58784 .44774 m .59559 .43872 L .59529 .42544 L p F P
0 0 0 r
s
.274 .382 .529 r
.56487 .48835 m .57777 .48228 L .57755 .46881 L p F P
0 0 0 r
s
.222 .311 .441 r
.58811 .46111 m .57755 .46881 L .57777 .48228 L p F P
0 0 0 r
s
.491 .682 .818 r
.45195 .42965 m .45681 .43951 L .45711 .42622 L p F P
0 0 0 r
s
.491 .682 .818 r
.45711 .42622 m .45227 .41634 L .45195 .42965 L p F P
0 0 0 r
s
.69 .09 .12 r
.28871 .34579 m
.29692 .34136 L
s
.092 .135 .215 r
.59985 .4155 m .59529 .42544 L .59559 .43872 L p F P
0 0 0 r
s
.092 .135 .215 r
.59529 .42544 m .59985 .4155 L .59953 .4023 L p F P
0 0 0 r
s
.576 .776 .973 r
.47486 .49644 m .48799 .50234 L .48815 .48878 L p F P
0 0 0 r
s
.576 .776 .973 r
.48815 .48878 m .47509 .48285 L .47486 .49644 L p F P
0 0 0 r
s
.69 .09 .12 r
.81575 .53256 m
.82491 .54342 L
s
.80807 .53782 m
.81575 .53256 L
s
.81575 .53256 m
.82439 .53317 L
s
.3832 .76088 m
.38921 .74998 L
s
.64408 .74997 m
.69716 .73528 L
s
.327 .449 .611 r
.55038 .50613 m .56504 .50192 L .56487 .48835 L p F P
0 0 0 r
s
.274 .382 .529 r
.57777 .48228 m .56487 .48835 L .56504 .50192 L p F P
0 0 0 r
s
.69 .09 .12 r
.2239 .42984 m
.21299 .43705 L
s
.23323 .43822 m
.2239 .42984 L
s
.335 .477 .554 r
.45083 .40597 m .45227 .41634 L .4526 .40314 L p F P
0 0 0 r
s
.335 .477 .554 r
.4526 .40314 m .45116 .39274 L .45083 .40597 L p F P
0 0 0 r
s
.69 .09 .12 r
.26822 .54412 m
.2762 .55031 L
s
.06 .089 .131 r
.60068 .39188 m .59953 .4023 L .59985 .4155 L p F P
0 0 0 r
s
.06 .089 .131 r
.59953 .4023 m .60068 .39188 L .60035 .37876 L p F P
0 0 0 r
s
.48 .649 .84 r
.50266 .52006 m .51852 .52207 L .51855 .50841 L p F P
0 0 0 r
s
.48 .649 .84 r
.51855 .50841 m .50277 .50639 L .50266 .52006 L p F P
0 0 0 r
s
.431 .583 .767 r
.53465 .50832 m .51855 .50841 L .51852 .52207 L p F P
0 0 0 r
s
.431 .583 .767 r
.51852 .52207 m .53469 .52199 L .53465 .50832 L p F P
0 0 0 r
s
.38 .517 .691 r
.55038 .50613 m .53465 .50832 L .53469 .52199 L p F P
0 0 0 r
s
.69 .09 .12 r
.32981 .65539 m
.3373 .64622 L
s
.28145 .33837 m
.28871 .34579 L
s
.82491 .54342 m
.81725 .54873 L
s
.82439 .53317 m
.82491 .54342 L
s
.63814 .44055 m
.64712 .42371 L
s
.88209 .45181 m
.8701 .44047 L
s
.8701 .44047 m
.88773 .43255 L
s
.83833 .33758 m
.82921 .34454 L
s
.83121 .32757 m
.83833 .33758 L
s
.17038 .32284 m
.15749 .32945 L
s
.18108 .33397 m
.17038 .32284 L
s
.06 .088 .13 r
.45323 .38232 m .45116 .39274 L .45149 .37963 L p F P
0 0 0 r
s
.06 .088 .13 r
.45149 .37963 m .45355 .36919 L .45323 .38232 L p F P
0 0 0 r
s
.69 .09 .12 r
.2762 .55031 m
.28531 .5423 L
s
.53 .714 .909 r
.48782 .51603 m .50266 .52006 L .50277 .50639 L p F P
0 0 0 r
s
.53 .714 .909 r
.50277 .50639 m .48799 .50234 L .48782 .51603 L p F P
0 0 0 r
s
.69 .09 .12 r
.82921 .34454 m
.81851 .33635 L
s
.81851 .33635 m
.83121 .32757 L
s
.338 .478 .556 r
.598 .36834 m .60035 .37876 L .60068 .39188 L p F P
0 0 0 r
s
.338 .478 .556 r
.60035 .37876 m .598 .36834 L .59768 .35532 L p F P
0 0 0 r
s
.38 .517 .691 r
.53469 .52199 m .55048 .5198 L .55038 .50613 L p F P
0 0 0 r
s
.327 .449 .611 r
.56504 .50192 m .55038 .50613 L .55048 .5198 L p F P
0 0 0 r
s
.69 .09 .12 r
.76319 .42876 m
.77105 .43631 L
s
.75627 .43345 m
.76319 .42876 L
s
.76319 .42876 m
.76772 .42814 L
s
.22233 .44547 m
.23323 .43822 L
s
.09 .133 .211 r
.45906 .35923 m .45355 .36919 L .45387 .35617 L p F P
0 0 0 r
s
.09 .133 .211 r
.45387 .35617 m .45936 .34618 L .45906 .35923 L p F P
0 0 0 r
s
.69 .09 .12 r
.75114 .63186 m
.75762 .64256 L
s
.74566 .63577 m
.75114 .63186 L
s
.75114 .63186 m
.76086 .63408 L
s
.88773 .43255 m
.88209 .45181 L
s
.21299 .43705 m
.22233 .44547 L
s
.603 .821 .995 r
.45619 .46643 m .46426 .47529 L .46453 .4618 L p F P
0 0 0 r
s
.603 .821 .995 r
.46453 .4618 m .4565 .45291 L .45619 .46643 L p F P
0 0 0 r
s
.69 .09 .12 r
.75762 .64256 m
.75217 .64652 L
s
.76086 .63408 m
.75762 .64256 L
s
.497 .683 .822 r
.59192 .34539 m .59768 .35532 L .598 .36834 L p F P
0 0 0 r
s
.497 .683 .822 r
.59768 .35532 m .59192 .34539 L .59163 .33246 L p F P
0 0 0 r
s
.69 .09 .12 r
.16821 .34063 m
.18108 .33397 L
s
.61 .824 1 r
.46399 .48891 m .47486 .49644 L .47509 .48285 L p F P
0 0 0 r
s
.61 .824 1 r
.47509 .48285 m .46426 .47529 L .46399 .48891 L p F P
0 0 0 r
s
.69 .09 .12 r
.82376 .43672 m
.83786 .39122 L
s
.77105 .43631 m
.76415 .44103 L
s
.76772 .42814 m
.77105 .43631 L
s
.222 .311 .441 r
.57777 .48228 m .58839 .47461 L .58811 .46111 L p F P
0 0 0 r
s
.158 .22 .329 r
.5959 .45213 m .58811 .46111 L .58839 .47461 L p F P
0 0 0 r
s
.158 .22 .329 r
.58811 .46111 m .5959 .45213 L .59559 .43872 L p F P
0 0 0 r
s
.274 .382 .529 r
.56504 .50192 m .578 .49587 L .57777 .48228 L p F P
0 0 0 r
s
.222 .311 .441 r
.58839 .47461 m .57777 .48228 L .578 .49587 L p F P
0 0 0 r
s
.164 .227 .334 r
.46807 .33717 m .45936 .34618 L .45965 .33325 L p F P
0 0 0 r
s
.164 .227 .334 r
.45965 .33325 m .46832 .32422 L .46807 .33717 L p F P
0 0 0 r
s
.491 .682 .818 r
.45162 .44309 m .4565 .45291 L .45681 .43951 L p F P
0 0 0 r
s
.491 .682 .818 r
.45681 .43951 m .45195 .42965 L .45162 .44309 L p F P
0 0 0 r
s
.589 .795 .968 r
.58271 .32353 m .59163 .33246 L .59192 .34539 L p F P
0 0 0 r
s
.092 .135 .215 r
.60018 .42881 m .59559 .43872 L .5959 .45213 L p F P
0 0 0 r
s
.092 .135 .215 r
.59559 .43872 m .60018 .42881 L .59985 .4155 L p F P
0 0 0 r
s
.69 .09 .12 r
.83121 .32757 m
.82921 .34454 L
s
.576 .776 .973 r
.47464 .51014 m .48782 .51603 L .48799 .50234 L p F P
0 0 0 r
s
.576 .776 .973 r
.48799 .50234 m .47486 .49644 L .47464 .51014 L p F P
0 0 0 r
s
.69 .09 .12 r
.81725 .54873 m
.80807 .53782 L
s
.80807 .53782 m
.82439 .53317 L
s
.71036 .32411 m
.71693 .32865 L
s
.70439 .32893 m
.71036 .32411 L
s
.71036 .32411 m
.71094 .3229 L
s
.60503 .64067 m
.6402 .63015 L
s
.327 .449 .611 r
.55048 .5198 m .56522 .51561 L .56504 .50192 L p F P
0 0 0 r
s
.274 .382 .529 r
.578 .49587 m .56504 .50192 L .56522 .51561 L p F P
0 0 0 r
s
.335 .477 .554 r
.4505 .41931 m .45195 .42965 L .45227 .41634 L p F P
0 0 0 r
s
.335 .477 .554 r
.45227 .41634 m .45083 .40597 L .4505 .41931 L p F P
0 0 0 r
s
.69 .09 .12 r
.76415 .44103 m
.75627 .43345 L
s
.75627 .43345 m
.76772 .42814 L
s
.06 .089 .131 r
.60101 .4051 m .59985 .4155 L .60018 .42881 L p F P
0 0 0 r
s
.06 .089 .131 r
.59985 .4155 m .60101 .4051 L .60068 .39188 L p F P
0 0 0 r
s
.48 .649 .84 r
.50256 .53386 m .51848 .53586 L .51852 .52207 L p F P
0 0 0 r
s
.48 .649 .84 r
.51852 .52207 m .50266 .52006 L .50256 .53386 L p F P
0 0 0 r
s
.431 .583 .767 r
.53469 .52199 m .51852 .52207 L .51848 .53586 L p F P
0 0 0 r
s
.69 .09 .12 r
.82439 .53317 m
.81725 .54873 L
s
.431 .583 .767 r
.51848 .53586 m .53473 .53577 L .53469 .52199 L p F P
0 0 0 r
s
.38 .517 .691 r
.55048 .5198 m .53469 .52199 L .53473 .53577 L p F P
0 0 0 r
s
.69 .09 .12 r
.69829 .5283 m
.70348 .53546 L
s
.69365 .53116 m
.69829 .5283 L
s
.69829 .5283 m
.70405 .529 L
s
.69004 .74213 m
.68681 .74544 L
s
.68611 .73107 m
.69004 .74213 L
s
.69716 .73528 m
.69004 .74213 L
s
.15749 .32945 m
.16821 .34063 L
s
.70348 .53546 m
.69885 .53834 L
s
.70405 .529 m
.70348 .53546 L
s
.68286 .73433 m
.68611 .73107 L
s
.68611 .73107 m
.69716 .73528 L
s
.71096 .33349 m
.70439 .32893 L
s
.70439 .32893 m
.71094 .3229 L
s
.06 .088 .13 r
.45291 .39558 m .45083 .40597 L .45116 .39274 L p F P
0 0 0 r
s
.06 .088 .13 r
.45116 .39274 m .45323 .38232 L .45291 .39558 L p F P
0 0 0 r
s
.69 .09 .12 r
.71693 .32865 m
.71096 .33349 L
s
.71094 .3229 m
.71693 .32865 L
s
.76772 .42814 m
.76415 .44103 L
s
.53 .714 .909 r
.48765 .52984 m .50256 .53386 L .50266 .52006 L p F P
0 0 0 r
s
.53 .714 .909 r
.50266 .52006 m .48782 .51603 L .48765 .52984 L p F P
0 0 0 r
s
.338 .478 .556 r
.59832 .38148 m .60068 .39188 L .60101 .4051 L p F P
0 0 0 r
s
.338 .478 .556 r
.60068 .39188 m .59832 .38148 L .598 .36834 L p F P
0 0 0 r
s
.69 .09 .12 r
.79117 .63725 m
.8309 .60133 L
s
.38 .517 .691 r
.53473 .53577 m .55059 .5336 L .55048 .5198 L p F P
0 0 0 r
s
.327 .449 .611 r
.56522 .51561 m .55048 .5198 L .55059 .5336 L p F P
0 0 0 r
s
.09 .133 .211 r
.45876 .37239 m .45323 .38232 L .45355 .36919 L p F P
0 0 0 r
s
.09 .133 .211 r
.45355 .36919 m .45906 .35923 L .45876 .37239 L p F P
0 0 0 r
s
.69 .09 .12 r
.75217 .64652 m
.74566 .63577 L
s
.74566 .63577 m
.76086 .63408 L
s
.62217 .84213 m
.62114 .84568 L
s
.6207 .83003 m
.62217 .84213 L
s
.63327 .83677 m
.62217 .84213 L
s
.603 .821 .995 r
.45588 .48007 m .46399 .48891 L .46426 .47529 L p F P
0 0 0 r
s
.603 .821 .995 r
.46426 .47529 m .45619 .46643 L .45588 .48007 L p F P
0 0 0 r
s
.69 .09 .12 r
.78535 .32573 m
.78 .2838 L
s
.57172 .84208 m
.63327 .83677 L
s
.71094 .3229 m
.71096 .33349 L
s
.76086 .63408 m
.75217 .64652 L
s
.64519 .42403 m
.64907 .42782 L
s
.64155 .42638 m
.64519 .42403 L
s
.64519 .42403 m
.64712 .42371 L
s
.497 .683 .822 r
.59221 .35844 m .598 .36834 L .59832 .38148 L p F P
0 0 0 r
s
.497 .683 .822 r
.598 .36834 m .59221 .35844 L .59192 .34539 L p F P
0 0 0 r
s
.61 .824 1 r
.46371 .50264 m .47464 .51014 L .47486 .49644 L p F P
0 0 0 r
s
.61 .824 1 r
.47486 .49644 m .46399 .48891 L .46371 .50264 L p F P
0 0 0 r
s
.69 .09 .12 r
.63562 .63505 m
.63328 .63692 L
s
.63297 .62763 m
.63562 .63505 L
s
.6402 .63015 m
.63562 .63505 L
s
.222 .311 .441 r
.578 .49587 m .58867 .48822 L .58839 .47461 L p F P
0 0 0 r
s
.158 .22 .329 r
.59621 .46565 m .58839 .47461 L .58867 .48822 L p F P
0 0 0 r
s
.158 .22 .329 r
.58839 .47461 m .59621 .46565 L .5959 .45213 L p F P
0 0 0 r
s
.274 .382 .529 r
.56522 .51561 m .57823 .50958 L .578 .49587 L p F P
0 0 0 r
s
.222 .311 .441 r
.58867 .48822 m .578 .49587 L .57823 .50958 L p F P
0 0 0 r
s
.164 .227 .334 r
.46781 .35024 m .45906 .35923 L .45936 .34618 L p F P
0 0 0 r
s
.164 .227 .334 r
.45936 .34618 m .46807 .33717 L .46781 .35024 L p F P
0 0 0 r
s
.491 .682 .818 r
.45129 .45664 m .45619 .46643 L .4565 .45291 L p F P
0 0 0 r
s
.491 .682 .818 r
.4565 .45291 m .45162 .44309 L .45129 .45664 L p F P
0 0 0 r
s
.69 .09 .12 r
.63063 .62947 m
.63297 .62763 L
s
.63297 .62763 m
.6402 .63015 L
s
.64907 .42782 m
.64544 .43018 L
s
.64712 .42371 m
.64907 .42782 L
s
.69885 .53834 m
.69365 .53116 L
s
.69365 .53116 m
.70405 .529 L
s
.61966 .83351 m
.6207 .83003 L
s
.6207 .83003 m
.63327 .83677 L
s
.225 .314 .442 r
.47961 .3296 m .46807 .33717 L .46832 .32422 L p F P
0 0 0 r
s
.225 .314 .442 r
.46832 .32422 m .47982 .31663 L .47961 .3296 L p F P
0 0 0 r
s
.589 .795 .968 r
.58296 .33649 m .59192 .34539 L .59221 .35844 L p F P
0 0 0 r
s
.589 .795 .968 r
.59192 .34539 m .58296 .33649 L .58271 .32353 L p F P
0 0 0 r
s
.69 .09 .12 r
.59008 .31821 m
.59903 .32981 L
s
.70405 .529 m
.69885 .53834 L
s
.092 .135 .215 r
.60051 .44225 m .5959 .45213 L .59621 .46565 L p F P
0 0 0 r
s
.092 .135 .215 r
.5959 .45213 m .60051 .44225 L .60018 .42881 L p F P
0 0 0 r
s
.585 .785 .972 r
.571 .31608 m .58271 .32353 L .58296 .33649 L p F P
0 0 0 r
s
.576 .776 .973 r
.47441 .52397 m .48765 .52984 L .48782 .51603 L p F P
0 0 0 r
s
.576 .776 .973 r
.48782 .51603 m .47464 .51014 L .47441 .52397 L p F P
0 0 0 r
s
.327 .449 .611 r
.55059 .5336 m .56539 .52942 L .56522 .51561 L p F P
0 0 0 r
s
.274 .382 .529 r
.57823 .50958 m .56522 .51561 L .56539 .52942 L p F P
0 0 0 r
s
.69 .09 .12 r
.56566 .53044 m
.58313 .52481 L
s
.64544 .43018 m
.64155 .42638 L
s
.64155 .42638 m
.64712 .42371 L
s
.335 .477 .554 r
.45016 .43277 m .45162 .44309 L .45195 .42965 L p F P
0 0 0 r
s
.335 .477 .554 r
.45195 .42965 m .4505 .41931 L .45016 .43277 L p F P
0 0 0 r
s
.69 .09 .12 r
.59183 .31844 m
.59439 .31964 L
s
.58938 .32144 m
.59183 .31844 L
s
.59183 .31844 m
.59008 .31821 L
s
.64712 .42371 m
.64544 .43018 L
s
.06 .089 .131 r
.60134 .41845 m .60018 .42881 L .60051 .44225 L p F P
0 0 0 r
s
.06 .089 .131 r
.60018 .42881 m .60134 .41845 L .60101 .4051 L p F P
0 0 0 r
s
.48 .649 .84 r
.50246 .54777 m .51845 .54977 L .51848 .53586 L p F P
0 0 0 r
s
.48 .649 .84 r
.51848 .53586 m .50256 .53386 L .50246 .54777 L p F P
0 0 0 r
s
.431 .583 .767 r
.53473 .53577 m .51848 .53586 L .51845 .54977 L p F P
0 0 0 r
s
.431 .583 .767 r
.51845 .54977 m .53477 .54969 L .53473 .53577 L p F P
0 0 0 r
s
.38 .517 .691 r
.55059 .5336 m .53473 .53577 L .53477 .54969 L p F P
0 0 0 r
s
.69 .09 .12 r
.554 .94257 m
.55511 .94719 L
s
.55496 .92878 m
.554 .94257 L
s
.56919 .93855 m
.554 .94257 L
s
.59193 .32264 m
.58938 .32144 L
s
.58938 .32144 m
.59008 .31821 L
s
.69716 .73528 m
.68681 .74544 L
s
.68286 .73433 m
.69716 .73528 L
s
.56745 .73507 m
.56741 .73712 L
s
.56727 .72638 m
.56745 .73507 L
s
.57616 .73159 m
.56745 .73507 L
s
.68681 .74544 m
.68286 .73433 L
s
.58092 .52742 m
.57966 .52819 L
s
.57958 .52369 m
.58092 .52742 L
s
.58313 .52481 m
.58092 .52742 L
s
.06 .088 .13 r
.45258 .40895 m .4505 .41931 L .45083 .40597 L p F P
0 0 0 r
s
.06 .088 .13 r
.45083 .40597 m .45291 .39558 L .45258 .40895 L p F P
0 0 0 r
s
.69 .09 .12 r
.57833 .52445 m
.57958 .52369 L
s
.57958 .52369 m
.58313 .52481 L
s
.56722 .7284 m
.56727 .72638 L
s
.56727 .72638 m
.57616 .73159 L
s
.55607 .93331 m
.55496 .92878 L
s
.55496 .92878 m
.56919 .93855 L
s
.59439 .31964 m
.59193 .32264 L
s
.59008 .31821 m
.59439 .31964 L
s
.75251 .52677 m
.773 .49408 L
s
.53 .714 .909 r
.48748 .54377 m .50246 .54777 L .50256 .53386 L p F P
0 0 0 r
s
.53 .714 .909 r
.50256 .53386 m .48765 .52984 L .48748 .54377 L p F P
0 0 0 r
s
.338 .478 .556 r
.59864 .39474 m .60101 .4051 L .60134 .41845 L p F P
0 0 0 r
s
.338 .478 .556 r
.60101 .4051 m .59864 .39474 L .59832 .38148 L p F P
0 0 0 r
s
.69 .09 .12 r
.6402 .63015 m
.63328 .63692 L
s
.63063 .62947 m
.6402 .63015 L
s
.38 .517 .691 r
.53477 .54969 m .5507 .54752 L .55059 .5336 L p F P
0 0 0 r
s
.327 .449 .611 r
.56539 .52942 m .55059 .5336 L .5507 .54752 L p F P
0 0 0 r
s
.69 .09 .12 r
.59008 .31821 m
.59193 .32264 L
s
.63328 .63692 m
.63063 .62947 L
s
.63327 .83677 m
.62114 .84568 L
s
.61966 .83351 m
.63327 .83677 L
s
.09 .133 .211 r
.45846 .38567 m .45291 .39558 L .45323 .38232 L p F P
0 0 0 r
s
.09 .133 .211 r
.45323 .38232 m .45876 .37239 L .45846 .38567 L p F P
0 0 0 r
s
.69 .09 .12 r
.53207 .73235 m
.57616 .73159 L
s
.58313 .52481 m
.57966 .52819 L
s
.57833 .52445 m
.58313 .52481 L
s
.57966 .52819 m
.57833 .52445 L
s
.603 .821 .995 r
.45557 .49384 m .46371 .50264 L .46399 .48891 L p F P
0 0 0 r
s
.603 .821 .995 r
.46399 .48891 m .45588 .48007 L .45557 .49384 L p F P
0 0 0 r
s
.497 .683 .822 r
.59251 .37161 m .59832 .38148 L .59864 .39474 L p F P
0 0 0 r
s
.497 .683 .822 r
.59832 .38148 m .59251 .37161 L .59221 .35844 L p F P
0 0 0 r
s
.61 .824 1 r
.46343 .5165 m .47441 .52397 L .47464 .51014 L p F P
0 0 0 r
s
.61 .824 1 r
.47464 .51014 m .46371 .50264 L .46343 .5165 L p F P
0 0 0 r
s
.69 .09 .12 r
.49899 .83553 m
.50115 .83878 L
s
.50125 .82475 m
.49899 .83553 L
s
.51194 .83332 m
.49899 .83553 L
s
.281 .388 .533 r
.49346 .32385 m .47961 .3296 L .47982 .31663 L p F P
0 0 0 r
s
.281 .388 .533 r
.47982 .31663 m .4936 .31086 L .49346 .32385 L p F P
0 0 0 r
s
.69 .09 .12 r
.57616 .73159 m
.56741 .73712 L
s
.56722 .7284 m
.57616 .73159 L
s
.222 .311 .441 r
.57823 .50958 m .58895 .50196 L .58867 .48822 L p F P
0 0 0 r
s
.158 .22 .329 r
.59652 .4793 m .58867 .48822 L .58895 .50196 L p F P
0 0 0 r
s
.158 .22 .329 r
.58867 .48822 m .59652 .4793 L .59621 .46565 L p F P
0 0 0 r
s
.274 .382 .529 r
.56539 .52942 m .57847 .52342 L .57823 .50958 L p F P
0 0 0 r
s
.222 .311 .441 r
.58895 .50196 m .57823 .50958 L .57847 .52342 L p F P
0 0 0 r
s
.164 .227 .334 r
.46755 .36343 m .45876 .37239 L .45906 .35923 L p F P
0 0 0 r
s
.164 .227 .334 r
.45906 .35923 m .46781 .35024 L .46755 .36343 L p F P
0 0 0 r
s
.491 .682 .818 r
.45095 .47031 m .45588 .48007 L .45619 .46643 L p F P
0 0 0 r
s
.491 .682 .818 r
.45619 .46643 m .45129 .45664 L .45095 .47031 L p F P
0 0 0 r
s
.69 .09 .12 r
.51246 .62746 m
.51357 .62859 L
s
.51359 .62201 m
.51246 .62746 L
s
.51894 .6262 m
.51246 .62746 L
s
.585 .785 .972 r
.58296 .33649 m .5712 .32905 L .571 .31608 L p F P
0 0 0 r
s
.546 .732 .922 r
.55705 .31048 m .571 .31608 L .5712 .32905 L p F P
0 0 0 r
s
.225 .314 .442 r
.4794 .34268 m .46781 .35024 L .46807 .33717 L p F P
0 0 0 r
s
.225 .314 .442 r
.46807 .33717 m .47961 .3296 L .4794 .34268 L p F P
0 0 0 r
s
.69 .09 .12 r
.56919 .93855 m
.55511 .94719 L
s
.55607 .93331 m
.56919 .93855 L
s
.49826 .93557 m
.56919 .93855 L
s
.50342 .82796 m
.50125 .82475 L
s
.50125 .82475 m
.51194 .83332 L
s
.62114 .84568 m
.61966 .83351 L
s
.5147 .62313 m
.51359 .62201 L
s
.51359 .62201 m
.51894 .6262 L
s
.589 .795 .968 r
.58321 .34956 m .59221 .35844 L .59251 .37161 L p F P
0 0 0 r
s
.589 .795 .968 r
.59221 .35844 m .58321 .34956 L .58296 .33649 L p F P
0 0 0 r
s
.092 .135 .215 r
.60084 .4558 m .59621 .46565 L .59652 .4793 L p F P
0 0 0 r
s
.092 .135 .215 r
.59621 .46565 m .60084 .4558 L .60051 .44225 L p F P
0 0 0 r
s
.585 .785 .972 r
.5712 .32905 m .58296 .33649 L .58321 .34956 L p F P
0 0 0 r
s
.576 .776 .973 r
.47418 .53793 m .48748 .54377 L .48765 .52984 L p F P
0 0 0 r
s
.576 .776 .973 r
.48765 .52984 m .47441 .52397 L .47418 .53793 L p F P
0 0 0 r
s
.69 .09 .12 r
.51894 .6262 m
.51357 .62859 L
s
.5147 .62313 m
.51894 .6262 L
s
.49208 .62168 m
.51894 .6262 L
s
.327 .449 .611 r
.5507 .54752 m .56557 .54336 L .56539 .52942 L p F P
0 0 0 r
s
.274 .382 .529 r
.57847 .52342 m .56539 .52942 L .56557 .54336 L p F P
0 0 0 r
s
.335 .477 .554 r
.44982 .44636 m .45129 .45664 L .45162 .44309 L p F P
0 0 0 r
s
.335 .477 .554 r
.45162 .44309 m .45016 .43277 L .44982 .44636 L p F P
0 0 0 r
s
.69 .09 .12 r
.47204 .31432 m
.47347 .3139 L
s
.47347 .3139 m
.47211 .31012 L
s
.47347 .3139 m
.46864 .31349 L
s
.51194 .83332 m
.50115 .83878 L
s
.50342 .82796 m
.51194 .83332 L
s
.458 .82542 m
.51194 .83332 L
s
.47211 .31012 m
.47068 .31054 L
s
.47211 .31012 m
.46864 .31349 L
s
.56741 .73712 m
.56722 .7284 L
s
.46864 .31349 m
.47204 .31432 L
s
.46864 .31349 m
.47068 .31054 L
s
.46864 .31349 m
.48588 .30712 L
s
.71945 .72911 m
.766 .70454 L
s
.06 .089 .131 r
.60168 .43192 m .60051 .44225 L .60084 .4558 L p F P
0 0 0 r
s
.06 .089 .131 r
.60051 .44225 m .60168 .43192 L .60134 .41845 L p F P
0 0 0 r
s
.48 .649 .84 r
.50235 .56182 m .51842 .56381 L .51845 .54977 L p F P
0 0 0 r
s
.48 .649 .84 r
.51845 .54977 m .50246 .54777 L .50235 .56182 L p F P
0 0 0 r
s
.431 .583 .767 r
.53477 .54969 m .51845 .54977 L .51842 .56381 L p F P
0 0 0 r
s
.431 .583 .767 r
.51842 .56381 m .53481 .56372 L .53477 .54969 L p F P
0 0 0 r
s
.38 .517 .691 r
.5507 .54752 m .53477 .54969 L .53481 .56372 L p F P
0 0 0 r
s
.69 .09 .12 r
.46161 .5206 m
.4596 .52076 L
s
.45969 .51625 m
.46161 .5206 L
s
.46161 .5206 m
.45719 .51931 L
s
.4621 .51769 m
.46161 .5206 L
s
.43023 .93642 m
.43447 .94155 L
s
.43495 .92309 m
.43023 .93642 L
s
.44753 .93535 m
.43023 .93642 L
s
.44371 .72794 m
.44706 .73058 L
s
.44732 .71982 m
.44371 .72794 L
s
.45457 .72788 m
.44371 .72794 L
s
.45457 .72788 m
.44706 .73058 L
s
.44732 .71982 m
.45457 .72788 L
s
.45068 .72243 m
.45457 .72788 L
s
.41738 .71431 m
.45457 .72788 L
s
.06 .088 .13 r
.45225 .42244 m .45016 .43277 L .4505 .41931 L p F P
0 0 0 r
s
.06 .088 .13 r
.4505 .41931 m .45258 .40895 L .45225 .42244 L p F P
0 0 0 r
s
.69 .09 .12 r
.45969 .51625 m
.45719 .51931 L
s
.4621 .51769 m
.45969 .51625 L
s
.51357 .62859 m
.5147 .62313 L
s
.45068 .72243 m
.44732 .71982 L
s
.43921 .92814 m
.43495 .92309 L
s
.43495 .92309 m
.44753 .93535 L
s
.71351 .41533 m
.71498 .3866 L
s
.45719 .51931 m
.4596 .52076 L
s
.44753 .93535 m
.43447 .94155 L
s
.43921 .92814 m
.44753 .93535 L
s
.3828 .91991 m
.44753 .93535 L
s
.53 .714 .909 r
.4873 .55783 m .50235 .56182 L .50246 .54777 L p F P
0 0 0 r
s
.53 .714 .909 r
.50246 .54777 m .48748 .54377 L .4873 .55783 L p F P
0 0 0 r
s
.336 .459 .619 r
.50893 .32023 m .49346 .32385 L .4936 .31086 L p F P
0 0 0 r
s
.336 .459 .619 r
.4936 .31086 m .50901 .30723 L .50893 .32023 L p F P
0 0 0 r
s
.69 .09 .12 r
.47068 .31054 m
.47204 .31432 L
s
.338 .478 .556 r
.59897 .40811 m .60134 .41845 L .60168 .43192 L p F P
0 0 0 r
s
.338 .478 .556 r
.60134 .41845 m .59897 .40811 L .59864 .39474 L p F P
0 0 0 r
s
.69 .09 .12 r
.40416 .41478 m
.4054 .41443 L
s
.40565 .40826 m
.40416 .41478 L
s
.40416 .41478 m
.40164 .41061 L
s
.40941 .41207 m
.40416 .41478 L
s
.41105 .39745 m
.40416 .41478 L
s
.38 .517 .691 r
.53481 .56372 m .55081 .56156 L .5507 .54752 L p F P
0 0 0 r
s
.327 .449 .611 r
.56557 .54336 m .5507 .54752 L .55081 .56156 L p F P
0 0 0 r
s
.546 .732 .922 r
.5712 .32905 m .55719 .32346 L .55705 .31048 L p F P
0 0 0 r
s
.497 .667 .854 r
.54155 .30704 m .55705 .31048 L .55719 .32346 L p F P
0 0 0 r
s
.69 .09 .12 r
.39709 .62223 m
.3928 .62294 L
s
.39319 .61361 m
.39709 .62223 L
s
.39709 .62223 m
.38814 .61981 L
s
.39786 .61673 m
.39709 .62223 L
s
.37641 .60224 m
.39709 .62223 L
s
.55511 .94719 m
.55607 .93331 L
s
.09 .133 .211 r
.45816 .39907 m .45258 .40895 L .45291 .39558 L p F P
0 0 0 r
s
.09 .133 .211 r
.45291 .39558 m .45846 .38567 L .45816 .39907 L p F P
0 0 0 r
s
.69 .09 .12 r
.4596 .52076 m
.4621 .51769 L
s
.40565 .40826 m
.40164 .41061 L
s
.40941 .41207 m
.40565 .40826 L
s
.39002 .82986 m
.3801 .8335 L
s
.38077 .81777 m
.39002 .82986 L
s
.39002 .82986 m
.37465 .82886 L
s
.38625 .82236 m
.39002 .82986 L
s
.34154 .80836 m
.39002 .82986 L
s
.34659 .30875 m
.35094 .30854 L
s
.35151 .29913 m
.34659 .30875 L
s
.34659 .30875 m
.3458 .30136 L
s
.35664 .30629 m
.34659 .30875 L
s
.37001 .28387 m
.34659 .30875 L
s
.603 .821 .995 r
.45525 .50772 m .46343 .5165 L .46371 .50264 L p F P
0 0 0 r
s
.69 .09 .12 r
.45174 .51005 m
.46161 .5206 L
s
.603 .821 .995 r
.46371 .50264 m .45557 .49384 L .45525 .50772 L p F P
0 0 0 r
s
.497 .683 .822 r
.59281 .38489 m .59864 .39474 L .59897 .40811 L p F P
0 0 0 r
s
.497 .683 .822 r
.59864 .39474 m .59281 .38489 L .59251 .37161 L p F P
0 0 0 r
s
.61 .824 1 r
.46315 .53048 m .47418 .53793 L .47441 .52397 L p F P
0 0 0 r
s
.61 .824 1 r
.47441 .52397 m .46343 .5165 L .46315 .53048 L p F P
0 0 0 r
s
.281 .388 .533 r
.49331 .33695 m .4794 .34268 L .47961 .3296 L p F P
0 0 0 r
s
.281 .388 .533 r
.47961 .3296 m .49346 .32385 L .49331 .33695 L p F P
0 0 0 r
s
.69 .09 .12 r
.39319 .61361 m
.38814 .61981 L
s
.39786 .61673 m
.39319 .61361 L
s
.33949 .51637 m
.33832 .51606 L
s
.33893 .50595 m
.33949 .51637 L
s
.33949 .51637 m
.33229 .51112 L
s
.34495 .51087 m
.33949 .51637 L
s
.33508 .48918 m
.33949 .51637 L
s
.222 .311 .441 r
.57847 .52342 m .58923 .51582 L .58895 .50196 L p F P
0 0 0 r
s
.158 .22 .329 r
.59684 .49306 m .58895 .50196 L .58923 .51582 L p F P
0 0 0 r
s
.158 .22 .329 r
.58895 .50196 m .59684 .49306 L .59652 .4793 L p F P
0 0 0 r
s
.69 .09 .12 r
.4054 .41443 m
.40941 .41207 L
s
.274 .382 .529 r
.56557 .54336 m .5787 .53737 L .57847 .52342 L p F P
0 0 0 r
s
.222 .311 .441 r
.58923 .51582 m .57847 .52342 L .5787 .53737 L p F P
0 0 0 r
s
.164 .227 .334 r
.46728 .37673 m .45846 .38567 L .45876 .37239 L p F P
0 0 0 r
s
.164 .227 .334 r
.45876 .37239 m .46755 .36343 L .46728 .37673 L p F P
0 0 0 r
s
.69 .09 .12 r
.38077 .81777 m
.37465 .82886 L
s
.38625 .82236 m
.38077 .81777 L
s
.37465 .82886 m
.3801 .8335 L
s
.50115 .83878 m
.50342 .82796 L
s
.491 .682 .818 r
.45061 .48411 m .45557 .49384 L .45588 .48007 L p F P
0 0 0 r
s
.491 .682 .818 r
.45588 .48007 m .45095 .47031 L .45061 .48411 L p F P
0 0 0 r
s
.585 .785 .972 r
.58321 .34956 m .5714 .34214 L .5712 .32905 L p F P
0 0 0 r
s
.546 .732 .922 r
.55719 .32346 m .5712 .32905 L .5714 .34214 L p F P
0 0 0 r
s
.391 .529 .701 r
.52526 .31893 m .50893 .32023 L .50901 .30723 L p F P
0 0 0 r
s
.391 .529 .701 r
.50901 .30723 m .52526 .30594 L .52526 .31893 L p F P
0 0 0 r
s
.225 .314 .442 r
.4792 .35589 m .46755 .36343 L .46781 .35024 L p F P
0 0 0 r
s
.225 .314 .442 r
.46781 .35024 m .4794 .34268 L .4792 .35589 L p F P
0 0 0 r
s
.69 .09 .12 r
.33239 .72416 m
.32555 .72583 L
s
.32643 .71136 m
.33239 .72416 L
s
.33239 .72416 m
.31879 .72074 L
s
.33321 .71641 m
.33239 .72416 L
s
.29992 .69584 m
.33239 .72416 L
s
.497 .667 .854 r
.55719 .32346 m .54162 .32003 L .54155 .30704 L p F P
0 0 0 r
s
.445 .599 .78 r
.52526 .30594 m .54155 .30704 L .54162 .32003 L p F P
0 0 0 r
s
.69 .09 .12 r
.35151 .29913 m
.3458 .30136 L
s
.35664 .30629 m
.35151 .29913 L
s
.38814 .61981 m
.3928 .62294 L
s
.589 .795 .968 r
.58347 .36274 m .59251 .37161 L .59281 .38489 L p F P
0 0 0 r
s
.589 .795 .968 r
.59251 .37161 m .58347 .36274 L .58321 .34956 L p F P
0 0 0 r
s
.092 .135 .215 r
.60118 .46948 m .59652 .4793 L .59684 .49306 L p F P
0 0 0 r
s
.092 .135 .215 r
.59652 .4793 m .60118 .46948 L .60084 .4558 L p F P
0 0 0 r
s
.585 .785 .972 r
.5714 .34214 m .58321 .34956 L .58347 .36274 L p F P
0 0 0 r
s
.576 .776 .973 r
.47394 .55201 m .4873 .55783 L .48748 .54377 L p F P
0 0 0 r
s
.576 .776 .973 r
.48748 .54377 m .47418 .53793 L .47394 .55201 L p F P
0 0 0 r
s
.69 .09 .12 r
.35094 .30854 m
.35664 .30629 L
s
.40164 .41061 m
.4054 .41443 L
s
.28178 .41029 m
.28356 .40955 L
s
.28456 .39719 m
.28178 .41029 L
s
.28178 .41029 m
.27615 .40188 L
s
.29196 .40483 m
.28178 .41029 L
s
.29339 .37512 m
.28178 .41029 L
s
.445 .599 .78 r
.54162 .32003 m .52526 .31893 L .52526 .30594 L p F P
0 0 0 r
s
.327 .449 .611 r
.55081 .56156 m .56575 .55742 L .56557 .54336 L p F P
0 0 0 r
s
.274 .382 .529 r
.5787 .53737 m .56557 .54336 L .56575 .55742 L p F P
0 0 0 r
s
.335 .477 .554 r
.44947 .46006 m .45095 .47031 L .45129 .45664 L p F P
0 0 0 r
s
.335 .477 .554 r
.45129 .45664 m .44982 .44636 L .44947 .46006 L p F P
0 0 0 r
s
.69 .09 .12 r
.44706 .73058 m
.45068 .72243 L
s
.27464 .61824 m
.27077 .61859 L
s
.27194 .60381 m
.27464 .61824 L
s
.27464 .61824 m
.26263 .61208 L
s
.28009 .61029 m
.27464 .61824 L
s
.25794 .58232 m
.27464 .61824 L
s
.33893 .50595 m
.33229 .51112 L
s
.34495 .51087 m
.33893 .50595 L
s
.68018 .61818 m
.70795 .59724 L
s
.88758 .49875 m
.89982 .51039 L
s
.87756 .50622 m
.88758 .49875 L
s
.88758 .49875 m
.89561 .49842 L
s
.06 .089 .131 r
.60202 .4455 m .60084 .4558 L .60118 .46948 L p F P
0 0 0 r
s
.06 .089 .131 r
.60084 .4558 m .60202 .4455 L .60168 .43192 L p F P
0 0 0 r
s
.48 .649 .84 r
.50224 .57599 m .51838 .57797 L .51842 .56381 L p F P
0 0 0 r
s
.48 .649 .84 r
.51842 .56381 m .50235 .56182 L .50224 .57599 L p F P
0 0 0 r
s
.431 .583 .767 r
.53481 .56372 m .51842 .56381 L .51838 .57797 L p F P
0 0 0 r
s
.431 .583 .767 r
.51838 .57797 m .53485 .57788 L .53481 .56372 L p F P
0 0 0 r
s
.38 .517 .691 r
.55081 .56156 m .53481 .56372 L .53485 .57788 L p F P
0 0 0 r
s
.69 .09 .12 r
.32643 .71136 m
.31879 .72074 L
s
.33321 .71641 m
.32643 .71136 L
s
.22395 .30399 m
.22854 .30299 L
s
.2301 .28778 m
.22395 .30399 L
s
.22395 .30399 m
.21973 .29208 L
s
.23889 .29863 m
.22395 .30399 L
s
.25133 .26006 m
.22395 .30399 L
s
.3928 .62294 m
.39786 .61673 L
s
.21678 .51211 m
.21572 .51161 L
s
.21735 .49529 m
.21678 .51211 L
s
.21678 .51211 m
.20619 .50285 L
s
.22688 .504 m
.21678 .51211 L
s
.21558 .46779 m
.21678 .51211 L
s
.06 .088 .13 r
.45192 .43606 m .44982 .44636 L .45016 .43277 L p F P
0 0 0 r
s
.06 .088 .13 r
.45016 .43277 m .45225 .42244 L .45192 .43606 L p F P
0 0 0 r
s
.69 .09 .12 r
.67417 .30293 m
.65685 .27891 L
s
.31879 .72074 m
.32555 .72583 L
s
.28456 .39719 m
.27615 .40188 L
s
.29196 .40483 m
.28456 .39719 L
s
.53 .714 .909 r
.48713 .57202 m .50224 .57599 L .50235 .56182 L p F P
0 0 0 r
s
.53 .714 .909 r
.50235 .56182 m .4873 .55783 L .48713 .57202 L p F P
0 0 0 r
s
.336 .459 .619 r
.50885 .33333 m .49331 .33695 L .49346 .32385 L p F P
0 0 0 r
s
.336 .459 .619 r
.49346 .32385 m .50893 .32023 L .50885 .33333 L p F P
0 0 0 r
s
.338 .478 .556 r
.5993 .42161 m .60168 .43192 L .60202 .4455 L p F P
0 0 0 r
s
.338 .478 .556 r
.60168 .43192 m .5993 .42161 L .59897 .40811 L p F P
0 0 0 r
s
.69 .09 .12 r
.33229 .51112 m
.33832 .51606 L
s
.38 .517 .691 r
.53485 .57788 m .55093 .57573 L .55081 .56156 L p F P
0 0 0 r
s
.327 .449 .611 r
.56575 .55742 m .55081 .56156 L .55093 .57573 L p F P
0 0 0 r
s
.546 .732 .922 r
.5714 .34214 m .55733 .33656 L .55719 .32346 L p F P
0 0 0 r
s
.497 .667 .854 r
.54162 .32003 m .55719 .32346 L .55733 .33656 L p F P
0 0 0 r
s
.69 .09 .12 r
.33832 .51606 m
.34495 .51087 L
s
.3458 .30136 m
.35094 .30854 L
s
.43447 .94155 m
.43921 .92814 L
s
.89982 .51039 m
.88983 .51793 L
s
.89561 .49842 m
.89982 .51039 L
s
.15879 .40577 m
.1604 .40462 L
s
.16267 .38605 m
.15879 .40577 L
s
.15879 .40577 m
.14947 .39307 L
s
.17358 .39754 m
.15879 .40577 L
s
.17284 .35225 m
.15879 .40577 L
s
.27194 .60381 m
.26263 .61208 L
s
.28009 .61029 m
.27194 .60381 L
s
.8691 .61467 m
.90384 .56722 L
s
.09 .133 .211 r
.45785 .41259 m .45225 .42244 L .45258 .40895 L p F P
0 0 0 r
s
.09 .133 .211 r
.45258 .40895 m .45816 .39907 L .45785 .41259 L p F P
0 0 0 r
s
.69 .09 .12 r
.83417 .39264 m
.84511 .40111 L
s
.82485 .39989 m
.83417 .39264 L
s
.83417 .39264 m
.83786 .39122 L
s
.2301 .28778 m
.21973 .29208 L
s
.23889 .29863 m
.2301 .28778 L
s
.28356 .40955 m
.29196 .40483 L
s
.603 .821 .995 r
.45493 .52174 m .46315 .53048 L .46343 .5165 L p F P
0 0 0 r
s
.603 .821 .995 r
.46343 .5165 m .45525 .50772 L .45493 .52174 L p F P
0 0 0 r
s
.497 .683 .822 r
.59311 .39829 m .59897 .40811 L .5993 .42161 L p F P
0 0 0 r
s
.497 .683 .822 r
.59897 .40811 m .59311 .39829 L .59281 .38489 L p F P
0 0 0 r
s
.61 .824 1 r
.46287 .54459 m .47394 .55201 L .47418 .53793 L p F P
0 0 0 r
s
.61 .824 1 r
.47418 .53793 m .46315 .53048 L .46287 .54459 L p F P
0 0 0 r
s
.281 .388 .533 r
.49317 .35016 m .4792 .35589 L .4794 .34268 L p F P
0 0 0 r
s
.281 .388 .533 r
.4794 .34268 m .49331 .33695 L .49317 .35016 L p F P
0 0 0 r
s
.222 .311 .441 r
.5787 .53737 m .58951 .5298 L .58923 .51582 L p F P
0 0 0 r
s
.158 .22 .329 r
.59716 .50695 m .58923 .51582 L .58951 .5298 L p F P
0 0 0 r
s
.158 .22 .329 r
.58923 .51582 m .59716 .50695 L .59684 .49306 L p F P
0 0 0 r
s
.274 .382 .529 r
.56575 .55742 m .57894 .55145 L .5787 .53737 L p F P
0 0 0 r
s
.222 .311 .441 r
.58951 .5298 m .5787 .53737 L .57894 .55145 L p F P
0 0 0 r
s
.164 .227 .334 r
.46702 .39015 m .45816 .39907 L .45846 .38567 L p F P
0 0 0 r
s
.164 .227 .334 r
.45846 .38567 m .46728 .37673 L .46702 .39015 L p F P
0 0 0 r
s
.491 .682 .818 r
.45027 .49803 m .45525 .50772 L .45557 .49384 L p F P
0 0 0 r
s
.491 .682 .818 r
.45557 .49384 m .45061 .48411 L .45027 .49803 L p F P
0 0 0 r
s
.585 .785 .972 r
.58347 .36274 m .57161 .35534 L .5714 .34214 L p F P
0 0 0 r
s
.546 .732 .922 r
.55733 .33656 m .5714 .34214 L .57161 .35534 L p F P
0 0 0 r
s
.69 .09 .12 r
.82203 .60023 m
.83139 .61139 L
s
.81421 .60589 m
.82203 .60023 L
s
.82203 .60023 m
.8309 .60133 L
s
.3801 .8335 m
.38625 .82236 L
s
.64664 .82235 m
.7009 .80806 L
s
.22854 .30299 m
.23889 .29863 L
s
.391 .529 .701 r
.52526 .33204 m .50885 .33333 L .50893 .32023 L p F P
0 0 0 r
s
.391 .529 .701 r
.50893 .32023 m .52526 .31893 L .52526 .33204 L p F P
0 0 0 r
s
.69 .09 .12 r
.21735 .49529 m
.20619 .50285 L
s
.22688 .504 m
.21735 .49529 L
s
.225 .314 .442 r
.47898 .36921 m .46728 .37673 L .46755 .36343 L p F P
0 0 0 r
s
.225 .314 .442 r
.46755 .36343 m .4792 .35589 L .47898 .36921 L p F P
0 0 0 r
s
.497 .667 .854 r
.55733 .33656 m .54169 .33314 L .54162 .32003 L p F P
0 0 0 r
s
.445 .599 .78 r
.52526 .31893 m .54162 .32003 L .54169 .33314 L p F P
0 0 0 r
s
.589 .795 .968 r
.58373 .37605 m .59281 .38489 L .59311 .39829 L p F P
0 0 0 r
s
.589 .795 .968 r
.59281 .38489 m .58373 .37605 L .58347 .36274 L p F P
0 0 0 r
s
.092 .135 .215 r
.60152 .48328 m .59684 .49306 L .59716 .50695 L p F P
0 0 0 r
s
.092 .135 .215 r
.59684 .49306 m .60152 .48328 L .60118 .46948 L p F P
0 0 0 r
s
.69 .09 .12 r
.26263 .61208 m
.27077 .61859 L
s
.585 .785 .972 r
.57161 .35534 m .58347 .36274 L .58373 .37605 L p F P
0 0 0 r
s
.576 .776 .973 r
.47371 .56622 m .48713 .57202 L .4873 .55783 L p F P
0 0 0 r
s
.576 .776 .973 r
.4873 .55783 m .47394 .55201 L .47371 .56622 L p F P
0 0 0 r
s
.445 .599 .78 r
.54169 .33314 m .52526 .33204 L .52526 .31893 L p F P
0 0 0 r
s
.327 .449 .611 r
.55093 .57573 m .56592 .5716 L .56575 .55742 L p F P
0 0 0 r
s
.274 .382 .529 r
.57894 .55145 m .56575 .55742 L .56592 .5716 L p F P
0 0 0 r
s
.69 .09 .12 r
.32555 .72583 m
.33321 .71641 L
s
.27615 .40188 m
.28356 .40955 L
s
.83139 .61139 m
.8236 .6171 L
s
.8309 .60133 m
.83139 .61139 L
s
.7805 .28567 m
.79012 .29126 L
s
.77207 .2934 m
.7805 .28567 L
s
.7805 .28567 m
.78 .2838 L
s
.335 .477 .554 r
.44913 .47389 m .45061 .48411 L .45095 .47031 L p F P
0 0 0 r
s
.335 .477 .554 r
.45095 .47031 m .44947 .46006 L .44913 .47389 L p F P
0 0 0 r
s
.69 .09 .12 r
.64057 .5063 m
.64978 .48971 L
s
.88983 .51793 m
.87756 .50622 L
s
.87756 .50622 m
.89561 .49842 L
s
.84511 .40111 m
.8358 .4084 L
s
.83786 .39122 m
.84511 .40111 L
s
.16267 .38605 m
.14947 .39307 L
s
.17358 .39754 m
.16267 .38605 L
s
.06 .089 .131 r
.60236 .45921 m .60118 .46948 L .60152 .48328 L p F P
0 0 0 r
s
.06 .089 .131 r
.60118 .46948 m .60236 .45921 L .60202 .4455 L p F P
0 0 0 r
s
.48 .649 .84 r
.50214 .59028 m .51835 .59226 L .51838 .57797 L p F P
0 0 0 r
s
.48 .649 .84 r
.51838 .57797 m .50224 .57599 L .50214 .59028 L p F P
0 0 0 r
s
.431 .583 .767 r
.53485 .57788 m .51838 .57797 L .51835 .59226 L p F P
0 0 0 r
s
.431 .583 .767 r
.51835 .59226 m .53489 .59217 L .53485 .57788 L p F P
0 0 0 r
s
.38 .517 .691 r
.55093 .57573 m .53485 .57788 L .53489 .59217 L p F P
0 0 0 r
s
.69 .09 .12 r
.27077 .61859 m
.28009 .61029 L
s
.8358 .4084 m
.82485 .39989 L
s
.82485 .39989 m
.83786 .39122 L
s
.76834 .49432 m
.77638 .50212 L
s
.76128 .49931 m
.76834 .49432 L
s
.76834 .49432 m
.773 .49408 L
s
.06 .088 .13 r
.45158 .4498 m .44947 .46006 L .44982 .44636 L p F P
0 0 0 r
s
.06 .088 .13 r
.44982 .44636 m .45192 .43606 L .45158 .4498 L p F P
0 0 0 r
s
.69 .09 .12 r
.21572 .51161 m
.22688 .504 L
s
.53 .714 .909 r
.48696 .58633 m .50214 .59028 L .50224 .57599 L p F P
0 0 0 r
s
.53 .714 .909 r
.50224 .57599 m .48713 .57202 L .48696 .58633 L p F P
0 0 0 r
s
.336 .459 .619 r
.50878 .34656 m .49317 .35016 L .49331 .33695 L p F P
0 0 0 r
s
.336 .459 .619 r
.49331 .33695 m .50885 .33333 L .50878 .34656 L p F P
0 0 0 r
s
.338 .478 .556 r
.59963 .43522 m .60202 .4455 L .60236 .45921 L p F P
0 0 0 r
s
.338 .478 .556 r
.60202 .4455 m .59963 .43522 L .5993 .42161 L p F P
0 0 0 r
s
.69 .09 .12 r
.78168 .29902 m
.77207 .2934 L
s
.77207 .2934 m
.78 .2838 L
s
.38 .517 .691 r
.53489 .59217 m .55104 .59003 L .55093 .57573 L p F P
0 0 0 r
s
.327 .449 .611 r
.56592 .5716 m .55093 .57573 L .55104 .59003 L p F P
0 0 0 r
s
.546 .732 .922 r
.57161 .35534 m .55748 .34978 L .55733 .33656 L p F P
0 0 0 r
s
.497 .667 .854 r
.54169 .33314 m .55733 .33656 L .55748 .34978 L p F P
0 0 0 r
s
.69 .09 .12 r
.75603 .70188 m
.76265 .71283 L
s
.75045 .7062 m
.75603 .70188 L
s
.75603 .70188 m
.766 .70454 L
s
.89561 .49842 m
.88983 .51793 L
s
.20619 .50285 m
.21572 .51161 L
s
.76265 .71283 m
.7571 .71719 L
s
.766 .70454 m
.76265 .71283 L
s
.1604 .40462 m
.17358 .39754 L
s
.83023 .50252 m
.84482 .4577 L
s
.21973 .29208 m
.22854 .30299 L
s
.09 .133 .211 r
.45754 .42623 m .45192 .43606 L .45225 .42244 L p F P
0 0 0 r
s
.09 .133 .211 r
.45225 .42244 m .45785 .41259 L .45754 .42623 L p F P
0 0 0 r
s
.69 .09 .12 r
.77638 .50212 m
.76934 .50713 L
s
.773 .49408 m
.77638 .50212 L
s
.79012 .29126 m
.78168 .29902 L
s
.78 .2838 m
.79012 .29126 L
s
.603 .821 .995 r
.45461 .53588 m .46287 .54459 L .46315 .53048 L p F P
0 0 0 r
s
.603 .821 .995 r
.46315 .53048 m .45493 .52174 L .45461 .53588 L p F P
0 0 0 r
s
.497 .683 .822 r
.59341 .41181 m .5993 .42161 L .59963 .43522 L p F P
0 0 0 r
s
.497 .683 .822 r
.5993 .42161 m .59341 .41181 L .59311 .39829 L p F P
0 0 0 r
s
.61 .824 1 r
.46258 .55882 m .47371 .56622 L .47394 .55201 L p F P
0 0 0 r
s
.61 .824 1 r
.47394 .55201 m .46287 .54459 L .46258 .55882 L p F P
0 0 0 r
s
.281 .388 .533 r
.49302 .3635 m .47898 .36921 L .4792 .35589 L p F P
0 0 0 r
s
.281 .388 .533 r
.4792 .35589 m .49317 .35016 L .49302 .3635 L p F P
0 0 0 r
s
.69 .09 .12 r
.83786 .39122 m
.8358 .4084 L
s
.222 .311 .441 r
.57894 .55145 m .5898 .54391 L .58951 .5298 L p F P
0 0 0 r
s
.158 .22 .329 r
.59748 .52097 m .58951 .5298 L .5898 .54391 L p F P
0 0 0 r
s
.158 .22 .329 r
.58951 .5298 m .59748 .52097 L .59716 .50695 L p F P
0 0 0 r
s
.69 .09 .12 r
.8236 .6171 m
.81421 .60589 L
s
.81421 .60589 m
.8309 .60133 L
s
.274 .382 .529 r
.56592 .5716 m .57918 .56566 L .57894 .55145 L p F P
0 0 0 r
s
.222 .311 .441 r
.5898 .54391 m .57894 .55145 L .57918 .56566 L p F P
0 0 0 r
s
.69 .09 .12 r
.71438 .38753 m
.72109 .39229 L
s
.70828 .39256 m
.71438 .38753 L
s
.71438 .38753 m
.71498 .3866 L
s
.60676 .71099 m
.6427 .7007 L
s
.164 .227 .334 r
.46675 .4037 m .45785 .41259 L .45816 .39907 L p F P
0 0 0 r
s
.164 .227 .334 r
.45816 .39907 m .46702 .39015 L .46675 .4037 L p F P
0 0 0 r
s
.491 .682 .818 r
.44993 .51208 m .45493 .52174 L .45525 .50772 L p F P
0 0 0 r
s
.491 .682 .818 r
.45525 .50772 m .45027 .49803 L .44993 .51208 L p F P
0 0 0 r
s
.585 .785 .972 r
.58373 .37605 m .57181 .36867 L .57161 .35534 L p F P
0 0 0 r
s
.546 .732 .922 r
.55748 .34978 m .57161 .35534 L .57181 .36867 L p F P
0 0 0 r
s
.391 .529 .701 r
.52525 .34527 m .50878 .34656 L .50885 .33333 L p F P
0 0 0 r
s
.391 .529 .701 r
.50885 .33333 m .52526 .33204 L .52525 .34527 L p F P
0 0 0 r
s
.225 .314 .442 r
.47877 .38265 m .46702 .39015 L .46728 .37673 L p F P
0 0 0 r
s
.225 .314 .442 r
.46728 .37673 m .47898 .36921 L .47877 .38265 L p F P
0 0 0 r
s
.497 .667 .854 r
.55748 .34978 m .54176 .34637 L .54169 .33314 L p F P
0 0 0 r
s
.445 .599 .78 r
.52526 .33204 m .54169 .33314 L .54176 .34637 L p F P
0 0 0 r
s
.589 .795 .968 r
.58399 .38948 m .59311 .39829 L .59341 .41181 L p F P
0 0 0 r
s
.589 .795 .968 r
.59311 .39829 m .58399 .38948 L .58373 .37605 L p F P
0 0 0 r
s
.092 .135 .215 r
.60186 .4972 m .59716 .50695 L .59748 .52097 L p F P
0 0 0 r
s
.092 .135 .215 r
.59716 .50695 m .60186 .4972 L .60152 .48328 L p F P
0 0 0 r
s
.585 .785 .972 r
.57181 .36867 m .58373 .37605 L .58399 .38948 L p F P
0 0 0 r
s
.576 .776 .973 r
.47347 .58055 m .48696 .58633 L .48713 .57202 L p F P
0 0 0 r
s
.576 .776 .973 r
.48713 .57202 m .47371 .56622 L .47347 .58055 L p F P
0 0 0 r
s
.69 .09 .12 r
.76934 .50713 m
.76128 .49931 L
s
.76128 .49931 m
.773 .49408 L
s
.8309 .60133 m
.8236 .6171 L
s
.445 .599 .78 r
.54176 .34637 m .52525 .34527 L .52526 .33204 L p F P
0 0 0 r
s
.327 .449 .611 r
.55104 .59003 m .56611 .58592 L .56592 .5716 L p F P
0 0 0 r
s
.274 .382 .529 r
.57918 .56566 m .56592 .5716 L .56611 .58592 L p F P
0 0 0 r
s
.69 .09 .12 r
.70205 .59624 m
.70735 .60358 L
s
.69731 .59936 m
.70205 .59624 L
s
.70205 .59624 m
.70795 .59724 L
s
.69362 .81472 m
.69033 .81846 L
s
.6896 .80345 m
.69362 .81472 L
s
.7009 .80806 m
.69362 .81472 L
s
.335 .477 .554 r
.44878 .48785 m .45027 .49803 L .45061 .48411 L p F P
0 0 0 r
s
.335 .477 .554 r
.45061 .48411 m .44913 .47389 L .44878 .48785 L p F P
0 0 0 r
s
.69 .09 .12 r
.78 .2838 m
.78168 .29902 L
s
.14947 .39307 m
.1604 .40462 L
s
.70735 .60358 m
.70263 .60672 L
s
.70795 .59724 m
.70735 .60358 L
s
.68629 .80714 m
.6896 .80345 L
s
.6896 .80345 m
.7009 .80806 L
s
.71499 .39733 m
.70828 .39256 L
s
.70828 .39256 m
.71498 .3866 L
s
.06 .089 .131 r
.60271 .47304 m .60152 .48328 L .60186 .4972 L p F P
0 0 0 r
s
.06 .089 .131 r
.60152 .48328 m .60271 .47304 L .60236 .45921 L p F P
0 0 0 r
s
.48 .649 .84 r
.50203 .60471 m .51831 .60667 L .51835 .59226 L p F P
0 0 0 r
s
.48 .649 .84 r
.51835 .59226 m .50214 .59028 L .50203 .60471 L p F P
0 0 0 r
s
.431 .583 .767 r
.53489 .59217 m .51835 .59226 L .51831 .60667 L p F P
0 0 0 r
s
.431 .583 .767 r
.51831 .60667 m .53493 .60659 L .53489 .59217 L p F P
0 0 0 r
s
.38 .517 .691 r
.55104 .59003 m .53489 .59217 L .53493 .60659 L p F P
0 0 0 r
s
.69 .09 .12 r
.72109 .39229 m
.71499 .39733 L
s
.71498 .3866 m
.72109 .39229 L
s
.66015 .27954 m
.66552 .28189 L
s
.65518 .28563 m
.66015 .27954 L
s
.66015 .27954 m
.65685 .27891 L
s
.773 .49408 m
.76934 .50713 L
s
.79696 .70765 m
.8377 .67253 L
s
.66054 .288 m
.65518 .28563 L
s
.65518 .28563 m
.65685 .27891 L
s
.06 .088 .13 r
.45124 .46366 m .44913 .47389 L .44947 .46006 L p F P
0 0 0 r
s
.06 .088 .13 r
.44947 .46006 m .45158 .4498 L .45124 .46366 L p F P
0 0 0 r
s
.53 .714 .909 r
.48678 .60077 m .50203 .60471 L .50214 .59028 L p F P
0 0 0 r
s
.53 .714 .909 r
.50214 .59028 m .48696 .58633 L .48678 .60077 L p F P
0 0 0 r
s
.336 .459 .619 r
.5087 .35991 m .49302 .3635 L .49317 .35016 L p F P
0 0 0 r
s
.336 .459 .619 r
.49317 .35016 m .50878 .34656 L .5087 .35991 L p F P
0 0 0 r
s
.338 .478 .556 r
.59996 .44896 m .60236 .45921 L .60271 .47304 L p F P
0 0 0 r
s
.338 .478 .556 r
.60236 .45921 m .59996 .44896 L .59963 .43522 L p F P
0 0 0 r
s
.38 .517 .691 r
.53493 .60659 m .55115 .60446 L .55104 .59003 L p F P
0 0 0 r
s
.327 .449 .611 r
.56611 .58592 m .55104 .59003 L .55115 .60446 L p F P
0 0 0 r
s
.546 .732 .922 r
.57181 .36867 m .55762 .36312 L .55748 .34978 L p F P
0 0 0 r
s
.497 .667 .854 r
.54176 .34637 m .55748 .34978 L .55762 .36312 L p F P
0 0 0 r
s
.69 .09 .12 r
.7571 .71719 m
.75045 .7062 L
s
.75045 .7062 m
.766 .70454 L
s
.62427 .91707 m
.62323 .9211 L
s
.62277 .90476 m
.62427 .91707 L
s
.63562 .91188 m
.62427 .91707 L
s
.79101 .3894 m
.78567 .34796 L
s
.57272 .91702 m
.63562 .91188 L
s
.71498 .3866 m
.71499 .39733 L
s
.766 .70454 m
.7571 .71719 L
s
.6478 .48985 m
.65176 .49376 L
s
.64408 .49235 m
.6478 .48985 L
s
.6478 .48985 m
.64978 .48971 L
s
.63801 .70549 m
.63563 .70763 L
s
.63531 .69793 m
.63801 .70549 L
s
.6427 .7007 m
.63801 .70549 L
s
.09 .133 .211 r
.45723 .44 m .45158 .4498 L .45192 .43606 L p F P
0 0 0 r
s
.09 .133 .211 r
.45192 .43606 m .45754 .42623 L .45723 .44 L p F P
0 0 0 r
s
.69 .09 .12 r
.63293 .70004 m
.63531 .69793 L
s
.63531 .69793 m
.6427 .7007 L
s
.65176 .49376 m
.64805 .49627 L
s
.64978 .48971 m
.65176 .49376 L
s
.70263 .60672 m
.69731 .59936 L
s
.69731 .59936 m
.70795 .59724 L
s
.603 .821 .995 r
.45428 .55015 m .46258 .55882 L .46287 .54459 L p F P
0 0 0 r
s
.603 .821 .995 r
.46287 .54459 m .45461 .53588 L .45428 .55015 L p F P
0 0 0 r
s
.69 .09 .12 r
.62172 .90873 m
.62277 .90476 L
s
.62277 .90476 m
.63562 .91188 L
s
.497 .683 .822 r
.59372 .42546 m .59963 .43522 L .59996 .44896 L p F P
0 0 0 r
s
.497 .683 .822 r
.59963 .43522 m .59372 .42546 L .59341 .41181 L p F P
0 0 0 r
s
.61 .824 1 r
.46229 .57319 m .47347 .58055 L .47371 .56622 L p F P
0 0 0 r
s
.61 .824 1 r
.47371 .56622 m .46258 .55882 L .46229 .57319 L p F P
0 0 0 r
s
.69 .09 .12 r
.66552 .28189 m
.66054 .288 L
s
.65685 .27891 m
.66552 .28189 L
s
.70795 .59724 m
.70263 .60672 L
s
.281 .388 .533 r
.49287 .37696 m .47877 .38265 L .47898 .36921 L p F P
0 0 0 r
s
.281 .388 .533 r
.47898 .36921 m .49302 .3635 L .49287 .37696 L p F P
0 0 0 r
s
.222 .311 .441 r
.57918 .56566 m .59009 .55815 L .5898 .54391 L p F P
0 0 0 r
s
.158 .22 .329 r
.59781 .53511 m .5898 .54391 L .59009 .55815 L p F P
0 0 0 r
s
.158 .22 .329 r
.5898 .54391 m .59781 .53511 L .59748 .52097 L p F P
0 0 0 r
s
.274 .382 .529 r
.56611 .58592 m .57942 .58 L .57918 .56566 L p F P
0 0 0 r
s
.222 .311 .441 r
.59009 .55815 m .57918 .56566 L .57942 .58 L p F P
0 0 0 r
s
.164 .227 .334 r
.46648 .41737 m .45754 .42623 L .45785 .41259 L p F P
0 0 0 r
s
.164 .227 .334 r
.45785 .41259 m .46675 .4037 L .46648 .41737 L p F P
0 0 0 r
s
.491 .682 .818 r
.44958 .52625 m .45461 .53588 L .45493 .52174 L p F P
0 0 0 r
s
.491 .682 .818 r
.45493 .52174 m .44993 .51208 L .44958 .52625 L p F P
0 0 0 r
s
.585 .785 .972 r
.58399 .38948 m .57202 .38211 L .57181 .36867 L p F P
0 0 0 r
s
.546 .732 .922 r
.55762 .36312 m .57181 .36867 L .57202 .38211 L p F P
0 0 0 r
s
.69 .09 .12 r
.64805 .49627 m
.64408 .49235 L
s
.64408 .49235 m
.64978 .48971 L
s
.391 .529 .701 r
.52525 .35862 m .5087 .35991 L .50878 .34656 L p F P
0 0 0 r
s
.391 .529 .701 r
.50878 .34656 m .52525 .34527 L .52525 .35862 L p F P
0 0 0 r
s
.69 .09 .12 r
.65685 .27891 m
.66054 .288 L
s
.225 .314 .442 r
.47856 .39622 m .46675 .4037 L .46702 .39015 L p F P
0 0 0 r
s
.225 .314 .442 r
.46702 .39015 m .47877 .38265 L .47856 .39622 L p F P
0 0 0 r
s
.497 .667 .854 r
.55762 .36312 m .54183 .35971 L .54176 .34637 L p F P
0 0 0 r
s
.445 .599 .78 r
.52525 .34527 m .54176 .34637 L .54183 .35971 L p F P
0 0 0 r
s
.589 .795 .968 r
.58426 .40302 m .59341 .41181 L .59372 .42546 L p F P
0 0 0 r
s
.589 .795 .968 r
.59341 .41181 m .58426 .40302 L .58399 .38948 L p F P
0 0 0 r
s
.69 .09 .12 r
.59149 .38197 m
.60062 .39343 L
s
.092 .135 .215 r
.60221 .51125 m .59748 .52097 L .59781 .53511 L p F P
0 0 0 r
s
.092 .135 .215 r
.59748 .52097 m .60221 .51125 L .60186 .4972 L p F P
0 0 0 r
s
.585 .785 .972 r
.57202 .38211 m .58399 .38948 L .58426 .40302 L p F P
0 0 0 r
s
.576 .776 .973 r
.47323 .59502 m .48678 .60077 L .48696 .58633 L p F P
0 0 0 r
s
.576 .776 .973 r
.48696 .58633 m .47347 .58055 L .47323 .59502 L p F P
0 0 0 r
s
.69 .09 .12 r
.59327 .38208 m
.59588 .38338 L
s
.59077 .38516 m
.59327 .38208 L
s
.59327 .38208 m
.59149 .38197 L
s
.64978 .48971 m
.64805 .49627 L
s
.445 .599 .78 r
.54183 .35971 m .52525 .35862 L .52525 .34527 L p F P
0 0 0 r
s
.327 .449 .611 r
.55115 .60446 m .56629 .60036 L .56611 .58592 L p F P
0 0 0 r
s
.274 .382 .529 r
.57942 .58 m .56611 .58592 L .56629 .60036 L p F P
0 0 0 r
s
.69 .09 .12 r
.56761 .59832 m
.58438 .59313 L
s
.56032 .27959 m
.53308 .274 L
s
.59337 .38647 m
.59077 .38516 L
s
.59077 .38516 m
.59149 .38197 L
s
.335 .477 .554 r
.44843 .50193 m .44993 .51208 L .45027 .49803 L p F P
0 0 0 r
s
.335 .477 .554 r
.45027 .49803 m .44878 .48785 L .44843 .50193 L p F P
0 0 0 r
s
.69 .09 .12 r
.7009 .80806 m
.69033 .81846 L
s
.68629 .80714 m
.7009 .80806 L
s
.56836 .80786 m
.56832 .81024 L
s
.56818 .79902 m
.56836 .80786 L
s
.57726 .80447 m
.56836 .80786 L
s
.69033 .81846 m
.68629 .80714 L
s
.06 .089 .131 r
.60306 .487 m .60186 .4972 L .60221 .51125 L p F P
0 0 0 r
s
.06 .089 .131 r
.60186 .4972 m .60306 .487 L .60271 .47304 L p F P
0 0 0 r
s
.48 .649 .84 r
.50192 .61927 m .51828 .62122 L .51831 .60667 L p F P
0 0 0 r
s
.48 .649 .84 r
.51831 .60667 m .50203 .60471 L .50192 .61927 L p F P
0 0 0 r
s
.431 .583 .767 r
.53493 .60659 m .51831 .60667 L .51828 .62122 L p F P
0 0 0 r
s
.69 .09 .12 r
.58212 .59569 m
.58084 .59659 L
s
.58076 .59189 m
.58212 .59569 L
s
.58438 .59313 m
.58212 .59569 L
s
.431 .583 .767 r
.51828 .62122 m .53497 .62114 L .53493 .60659 L p F P
0 0 0 r
s
.38 .517 .691 r
.55115 .60446 m .53493 .60659 L .53497 .62114 L p F P
0 0 0 r
s
.69 .09 .12 r
.57948 .59277 m
.58076 .59189 L
s
.58076 .59189 m
.58438 .59313 L
s
.53855 .27812 m
.53736 .27781 L
s
.53736 .27781 m
.53853 .27213 L
s
.53736 .27781 m
.53308 .274 L
s
.56813 .80138 m
.56818 .79902 L
s
.56818 .79902 m
.57726 .80447 L
s
.59588 .38338 m
.59337 .38647 L
s
.59149 .38197 m
.59588 .38338 L
s
.75747 .59505 m
.77852 .56296 L
s
.53853 .27213 m
.53972 .27243 L
s
.53853 .27213 m
.53308 .274 L
s
.6427 .7007 m
.63563 .70763 L
s
.63293 .70004 m
.6427 .7007 L
s
.59149 .38197 m
.59337 .38647 L
s
.63563 .70763 m
.63293 .70004 L
s
.06 .088 .13 r
.4509 .47765 m .44878 .48785 L .44913 .47389 L p F P
0 0 0 r
s
.06 .088 .13 r
.44913 .47389 m .45124 .46366 L .4509 .47765 L p F P
0 0 0 r
s
.69 .09 .12 r
.63562 .91188 m
.62323 .9211 L
s
.62172 .90873 m
.63562 .91188 L
s
.53 .714 .909 r
.4866 .61535 m .50192 .61927 L .50203 .60471 L p F P
0 0 0 r
s
.53 .714 .909 r
.50203 .60471 m .48678 .60077 L .4866 .61535 L p F P
0 0 0 r
s
.336 .459 .619 r
.50862 .37338 m .49287 .37696 L .49302 .3635 L p F P
0 0 0 r
s
.336 .459 .619 r
.49302 .3635 m .5087 .35991 L .50862 .37338 L p F P
0 0 0 r
s
.338 .478 .556 r
.6003 .46283 m .60271 .47304 L .60306 .487 L p F P
0 0 0 r
s
.338 .478 .556 r
.60271 .47304 m .6003 .46283 L .59996 .44896 L p F P
0 0 0 r
s
.38 .517 .691 r
.53497 .62114 m .55127 .61902 L .55115 .60446 L p F P
0 0 0 r
s
.327 .449 .611 r
.56629 .60036 m .55115 .60446 L .55127 .61902 L p F P
0 0 0 r
s
.546 .732 .922 r
.57202 .38211 m .55776 .37658 L .55762 .36312 L p F P
0 0 0 r
s
.497 .667 .854 r
.54183 .35971 m .55762 .36312 L .55776 .37658 L p F P
0 0 0 r
s
.69 .09 .12 r
.75146 .27528 m
.72639 .23798 L
s
.5322 .80522 m
.57726 .80447 L
s
.58438 .59313 m
.58084 .59659 L
s
.57948 .59277 m
.58438 .59313 L
s
.58084 .59659 m
.57948 .59277 L
s
.4984 .91068 m
.5006 .91437 L
s
.50071 .89972 m
.4984 .91068 L
s
.51163 .90855 m
.4984 .91068 L
s
.09 .133 .211 r
.45692 .4539 m .45124 .46366 L .45158 .4498 L p F P
0 0 0 r
s
.09 .133 .211 r
.45158 .4498 m .45723 .44 L .45692 .4539 L p F P
0 0 0 r
s
.69 .09 .12 r
.57726 .80447 m
.56832 .81024 L
s
.56813 .80138 m
.57726 .80447 L
s
.53308 .274 m
.53855 .27812 L
s
.53308 .274 m
.53972 .27243 L
s
.51217 .69808 m
.5133 .69941 L
s
.51332 .69253 m
.51217 .69808 L
s
.51879 .69684 m
.51217 .69808 L
s
.603 .821 .995 r
.45396 .56455 m .46229 .57319 L .46258 .55882 L p F P
0 0 0 r
s
.603 .821 .995 r
.46258 .55882 m .45428 .55015 L .45396 .56455 L p F P
0 0 0 r
s
.497 .683 .822 r
.59403 .43923 m .59996 .44896 L .6003 .46283 L p F P
0 0 0 r
s
.497 .683 .822 r
.59996 .44896 m .59403 .43923 L .59372 .42546 L p F P
0 0 0 r
s
.61 .824 1 r
.462 .58769 m .47323 .59502 L .47347 .58055 L p F P
0 0 0 r
s
.61 .824 1 r
.47347 .58055 m .46229 .57319 L .462 .58769 L p F P
0 0 0 r
s
.69 .09 .12 r
.50292 .90336 m
.50071 .89972 L
s
.50071 .89972 m
.51163 .90855 L
s
.62323 .9211 m
.62172 .90873 L
s
.51446 .69384 m
.51332 .69253 L
s
.51332 .69253 m
.51879 .69684 L
s
.53972 .27243 m
.53855 .27812 L
s
.281 .388 .533 r
.49272 .39054 m .47856 .39622 L .47877 .38265 L p F P
0 0 0 r
s
.281 .388 .533 r
.47877 .38265 m .49287 .37696 L .49272 .39054 L p F P
0 0 0 r
s
.222 .311 .441 r
.57942 .58 m .59038 .57252 L .59009 .55815 L p F P
0 0 0 r
s
.158 .22 .329 r
.59814 .54939 m .59009 .55815 L .59038 .57252 L p F P
0 0 0 r
s
.158 .22 .329 r
.59009 .55815 m .59814 .54939 L .59781 .53511 L p F P
0 0 0 r
s
.274 .382 .529 r
.56629 .60036 m .57967 .59447 L .57942 .58 L p F P
0 0 0 r
s
.222 .311 .441 r
.59038 .57252 m .57942 .58 L .57967 .59447 L p F P
0 0 0 r
s
.164 .227 .334 r
.46621 .43117 m .45723 .44 L .45754 .42623 L p F P
0 0 0 r
s
.164 .227 .334 r
.45754 .42623 m .46648 .41737 L .46621 .43117 L p F P
0 0 0 r
s
.491 .682 .818 r
.44923 .54056 m .45428 .55015 L .45461 .53588 L p F P
0 0 0 r
s
.491 .682 .818 r
.45461 .53588 m .44958 .52625 L .44923 .54056 L p F P
0 0 0 r
s
.585 .785 .972 r
.58426 .40302 m .57223 .39568 L .57202 .38211 L p F P
0 0 0 r
s
.546 .732 .922 r
.55776 .37658 m .57202 .38211 L .57223 .39568 L p F P
0 0 0 r
s
.69 .09 .12 r
.51879 .69684 m
.5133 .69941 L
s
.51446 .69384 m
.51879 .69684 L
s
.49133 .69243 m
.51879 .69684 L
s
.391 .529 .701 r
.52525 .3721 m .50862 .37338 L .5087 .35991 L p F P
0 0 0 r
s
.391 .529 .701 r
.5087 .35991 m .52525 .35862 L .52525 .3721 L p F P
0 0 0 r
s
.225 .314 .442 r
.47834 .40991 m .46648 .41737 L .46675 .4037 L p F P
0 0 0 r
s
.225 .314 .442 r
.46675 .4037 m .47856 .39622 L .47834 .40991 L p F P
0 0 0 r
s
.497 .667 .854 r
.55776 .37658 m .54191 .37318 L .54183 .35971 L p F P
0 0 0 r
s
.445 .599 .78 r
.52525 .35862 m .54183 .35971 L .54191 .37318 L p F P
0 0 0 r
s
.589 .795 .968 r
.58452 .4167 m .59372 .42546 L .59403 .43923 L p F P
0 0 0 r
s
.589 .795 .968 r
.59372 .42546 m .58452 .4167 L .58426 .40302 L p F P
0 0 0 r
s
.69 .09 .12 r
.47085 .37825 m
.47231 .37771 L
s
.47231 .37771 m
.47093 .37386 L
s
.47231 .37771 m
.46738 .37731 L
s
.092 .135 .215 r
.60256 .52543 m .59781 .53511 L .59814 .54939 L p F P
0 0 0 r
s
.092 .135 .215 r
.59781 .53511 m .60256 .52543 L .60221 .51125 L p F P
0 0 0 r
s
.69 .09 .12 r
.51163 .90855 m
.5006 .91437 L
s
.50292 .90336 m
.51163 .90855 L
s
.4565 .9009 m
.51163 .90855 L
s
.47093 .37386 m
.46947 .37439 L
s
.47093 .37386 m
.46738 .37731 L
s
.56832 .81024 m
.56813 .80138 L
s
.585 .785 .972 r
.57223 .39568 m .58426 .40302 L .58452 .4167 L p F P
0 0 0 r
s
.576 .776 .973 r
.47299 .60962 m .4866 .61535 L .48678 .60077 L p F P
0 0 0 r
s
.576 .776 .973 r
.48678 .60077 m .47323 .59502 L .47299 .60962 L p F P
0 0 0 r
s
.69 .09 .12 r
.46738 .37731 m
.47085 .37825 L
s
.46738 .37731 m
.46947 .37439 L
s
.46738 .37731 m
.48499 .37101 L
s
.7237 .80206 m
.77136 .77816 L
s
.445 .599 .78 r
.54191 .37318 m .52525 .3721 L .52525 .35862 L p F P
0 0 0 r
s
.327 .449 .611 r
.55127 .61902 m .56647 .61494 L .56629 .60036 L p F P
0 0 0 r
s
.274 .382 .529 r
.57967 .59447 m .56629 .60036 L .56647 .61494 L p F P
0 0 0 r
s
.335 .477 .554 r
.44807 .51615 m .44958 .52625 L .44993 .51208 L p F P
0 0 0 r
s
.335 .477 .554 r
.44993 .51208 m .44843 .50193 L .44807 .51615 L p F P
0 0 0 r
s
.69 .09 .12 r
.46019 .58899 m
.45813 .58929 L
s
.45824 .58458 m
.46019 .58899 L
s
.46019 .58899 m
.45568 .58773 L
s
.46069 .58614 m
.46019 .58899 L
s
.41549 .27065 m
.4186 .26991 L
s
.4186 .26991 m
.41582 .26217 L
s
.4186 .26991 m
.40869 .26907 L
s
.4419 .80092 m
.44532 .80388 L
s
.44559 .79263 m
.4419 .80092 L
s
.453 .80087 m
.4419 .80092 L
s
.453 .80087 m
.44532 .80388 L
s
.44559 .79263 m
.453 .80087 L
s
.44902 .79556 m
.453 .80087 L
s
.41497 .78767 m
.453 .80087 L
s
.41582 .26217 m
.4127 .26288 L
s
.41582 .26217 m
.40869 .26907 L
s
.06 .089 .131 r
.60341 .50109 m .60221 .51125 L .60256 .52543 L p F P
0 0 0 r
s
.06 .089 .131 r
.60221 .51125 m .60341 .50109 L .60306 .487 L p F P
0 0 0 r
s
.48 .649 .84 r
.50181 .63396 m .51824 .63591 L .51828 .62122 L p F P
0 0 0 r
s
.48 .649 .84 r
.51828 .62122 m .50192 .61927 L .50181 .63396 L p F P
0 0 0 r
s
.431 .583 .767 r
.53497 .62114 m .51828 .62122 L .51824 .63591 L p F P
0 0 0 r
s
.69 .09 .12 r
.45824 .58458 m
.45568 .58773 L
s
.46069 .58614 m
.45824 .58458 L
s
.431 .583 .767 r
.51824 .63591 m .53501 .63582 L .53497 .62114 L p F P
0 0 0 r
s
.38 .517 .691 r
.55127 .61902 m .53497 .62114 L .53501 .63582 L p F P
0 0 0 r
s
.69 .09 .12 r
.40869 .26907 m
.41549 .27065 L
s
.40869 .26907 m
.4127 .26288 L
s
.44369 .25567 m
.40869 .26907 L
s
.5133 .69941 m
.51446 .69384 L
s
.44902 .79556 m
.44559 .79263 L
s
.71763 .48146 m
.71921 .45316 L
s
.45568 .58773 m
.45813 .58929 L
s
.46947 .37439 m
.47085 .37825 L
s
.40148 .48092 m
.40274 .48076 L
s
.403 .47431 m
.40148 .48092 L
s
.40148 .48092 m
.3989 .47681 L
s
.40684 .47825 m
.40148 .48092 L
s
.4085 .46385 m
.40148 .48092 L
s
.06 .088 .13 r
.45055 .49177 m .44843 .50193 L .44878 .48785 L p F P
0 0 0 r
s
.06 .088 .13 r
.44878 .48785 m .4509 .47765 L .45055 .49177 L p F P
0 0 0 r
s
.69 .09 .12 r
.39425 .69297 m
.38986 .69398 L
s
.39026 .68423 m
.39425 .69297 L
s
.39425 .69297 m
.3851 .6906 L
s
.39503 .68759 m
.39425 .69297 L
s
.37308 .67342 m
.39425 .69297 L
s
.53 .714 .909 r
.48642 .63006 m .50181 .63396 L .50192 .61927 L p F P
0 0 0 r
s
.53 .714 .909 r
.50192 .61927 m .4866 .61535 L .48642 .63006 L p F P
0 0 0 r
s
.336 .459 .619 r
.50854 .38697 m .49272 .39054 L .49287 .37696 L p F P
0 0 0 r
s
.336 .459 .619 r
.49287 .37696 m .50862 .37338 L .50854 .38697 L p F P
0 0 0 r
s
.69 .09 .12 r
.45813 .58929 m
.46069 .58614 L
s
.338 .478 .556 r
.60064 .47682 m .60306 .487 L .60341 .50109 L p F P
0 0 0 r
s
.338 .478 .556 r
.60306 .487 m .60064 .47682 L .6003 .46283 L p F P
0 0 0 r
s
.38 .517 .691 r
.53501 .63582 m .55138 .63371 L .55127 .61902 L p F P
0 0 0 r
s
.327 .449 .611 r
.56647 .61494 m .55127 .61902 L .55138 .63371 L p F P
0 0 0 r
s
.69 .09 .12 r
.403 .47431 m
.3989 .47681 L
s
.40684 .47825 m
.403 .47431 L
s
.546 .732 .922 r
.57223 .39568 m .55791 .39017 L .55776 .37658 L p F P
0 0 0 r
s
.497 .667 .854 r
.54191 .37318 m .55776 .37658 L .55791 .39017 L p F P
0 0 0 r
s
.69 .09 .12 r
.38703 .9052 m
.37688 .90932 L
s
.37757 .8929 m
.38703 .9052 L
s
.38703 .9052 m
.37132 .90423 L
s
.38316 .89794 m
.38703 .9052 L
s
.33742 .88439 m
.38703 .9052 L
s
.34264 .37263 m
.34707 .37269 L
s
.34767 .36285 m
.34264 .37263 L
s
.34264 .37263 m
.34182 .36531 L
s
.35291 .37019 m
.34264 .37263 L
s
.36653 .34803 m
.34264 .37263 L
s
.09 .133 .211 r
.4566 .46792 m .4509 .47765 L .45124 .46366 L p F P
0 0 0 r
s
.09 .133 .211 r
.45124 .46366 m .45692 .4539 L .4566 .46792 L p F P
0 0 0 r
s
.69 .09 .12 r
.39026 .68423 m
.3851 .6906 L
s
.39503 .68759 m
.39026 .68423 L
s
.33538 .58484 m
.33416 .58486 L
s
.3348 .5743 m
.33538 .58484 L
s
.33538 .58484 m
.32801 .57969 L
s
.34095 .57945 m
.33538 .58484 L
s
.33081 .55815 m
.33538 .58484 L
s
.40274 .48076 m
.40684 .47825 L
s
.37757 .8929 m
.37132 .90423 L
s
.38316 .89794 m
.37757 .8929 L
s
.37132 .90423 m
.37688 .90932 L
s
.5006 .91437 m
.50292 .90336 L
s
.603 .821 .995 r
.45362 .57908 m .462 .58769 L .46229 .57319 L p F P
0 0 0 r
s
.603 .821 .995 r
.46229 .57319 m .45396 .56455 L .45362 .57908 L p F P
0 0 0 r
s
.69 .09 .12 r
.4501 .57865 m
.46019 .58899 L
s
.497 .683 .822 r
.59434 .45313 m .6003 .46283 L .60064 .47682 L p F P
0 0 0 r
s
.497 .683 .822 r
.6003 .46283 m .59434 .45313 L .59403 .43923 L p F P
0 0 0 r
s
.69 .09 .12 r
.32812 .79725 m
.32111 .79939 L
s
.32202 .78427 m
.32812 .79725 L
s
.32812 .79725 m
.31421 .79392 L
s
.32894 .7897 m
.32812 .79725 L
s
.29485 .76968 m
.32812 .79725 L
s
.34767 .36285 m
.34182 .36531 L
s
.35291 .37019 m
.34767 .36285 L
s
.3851 .6906 m
.38986 .69398 L
s
.61 .824 1 r
.46171 .60232 m .47299 .60962 L .47323 .59502 L p F P
0 0 0 r
s
.61 .824 1 r
.47323 .59502 m .462 .58769 L .46171 .60232 L p F P
0 0 0 r
s
.69 .09 .12 r
.28368 .26411 m
.29112 .26433 L
s
.29223 .25091 m
.28368 .26411 L
s
.28368 .26411 m
.28444 .25323 L
s
.29888 .26196 m
.28368 .26411 L
s
.32419 .23117 m
.28368 .26411 L
s
.281 .388 .533 r
.49256 .40425 m .47834 .40991 L .47856 .39622 L p F P
0 0 0 r
s
.281 .388 .533 r
.47856 .39622 m .49272 .39054 L .49256 .40425 L p F P
0 0 0 r
s
.222 .311 .441 r
.57967 .59447 m .59068 .58702 L .59038 .57252 L p F P
0 0 0 r
s
.158 .22 .329 r
.59847 .56379 m .59038 .57252 L .59068 .58702 L p F P
0 0 0 r
s
.158 .22 .329 r
.59038 .57252 m .59847 .56379 L .59814 .54939 L p F P
0 0 0 r
s
.274 .382 .529 r
.56647 .61494 m .57991 .60907 L .57967 .59447 L p F P
0 0 0 r
s
.222 .311 .441 r
.59068 .58702 m .57967 .59447 L .57991 .60907 L p F P
0 0 0 r
s
.69 .09 .12 r
.34707 .37269 m
.35291 .37019 L
s
.3989 .47681 m
.40274 .48076 L
s
.164 .227 .334 r
.46593 .44509 m .45692 .4539 L .45723 .44 L p F P
0 0 0 r
s
.164 .227 .334 r
.45723 .44 m .46621 .43117 L .46593 .44509 L p F P
0 0 0 r
s
.69 .09 .12 r
.4127 .26288 m
.41549 .27065 L
s
.491 .682 .818 r
.44888 .555 m .45396 .56455 L .45428 .55015 L p F P
0 0 0 r
s
.491 .682 .818 r
.45428 .55015 m .44923 .54056 L .44888 .555 L p F P
0 0 0 r
s
.585 .785 .972 r
.58452 .4167 m .57245 .40937 L .57223 .39568 L p F P
0 0 0 r
s
.546 .732 .922 r
.55791 .39017 m .57223 .39568 L .57245 .40937 L p F P
0 0 0 r
s
.69 .09 .12 r
.27639 .47649 m
.27819 .47614 L
s
.27923 .46323 m
.27639 .47649 L
s
.27639 .47649 m
.27062 .46821 L
s
.28679 .47112 m
.27639 .47649 L
s
.28816 .44184 m
.27639 .47649 L
s
.391 .529 .701 r
.52524 .38569 m .50854 .38697 L .50862 .37338 L p F P
0 0 0 r
s
.391 .529 .701 r
.50862 .37338 m .52525 .3721 L .52524 .38569 L p F P
0 0 0 r
s
.225 .314 .442 r
.47812 .42373 m .46621 .43117 L .46648 .41737 L p F P
0 0 0 r
s
.225 .314 .442 r
.46648 .41737 m .47834 .40991 L .47812 .42373 L p F P
0 0 0 r
s
.497 .667 .854 r
.55791 .39017 m .54198 .38678 L .54191 .37318 L p F P
0 0 0 r
s
.445 .599 .78 r
.52525 .3721 m .54191 .37318 L .54198 .38678 L p F P
0 0 0 r
s
.589 .795 .968 r
.58479 .43049 m .59403 .43923 L .59434 .45313 L p F P
0 0 0 r
s
.589 .795 .968 r
.59403 .43923 m .58479 .43049 L .58452 .4167 L p F P
0 0 0 r
s
.092 .135 .215 r
.60291 .53974 m .59814 .54939 L .59847 .56379 L p F P
0 0 0 r
s
.092 .135 .215 r
.59814 .54939 m .60291 .53974 L .60256 .52543 L p F P
0 0 0 r
s
.69 .09 .12 r
.44532 .80388 m
.44902 .79556 L
s
.26909 .68907 m
.2651 .68991 L
s
.26633 .67446 m
.26909 .68907 L
s
.26909 .68907 m
.2568 .68304 L
s
.27464 .68129 m
.26909 .68907 L
s
.25189 .65393 m
.26909 .68907 L
s
.29223 .25091 m
.28444 .25323 L
s
.29888 .26196 m
.29223 .25091 L
s
.3348 .5743 m
.32801 .57969 L
s
.34095 .57945 m
.3348 .5743 L
s
.68359 .68901 m
.71202 .66853 L
s
.585 .785 .972 r
.57245 .40937 m .58452 .4167 L .58479 .43049 L p F P
0 0 0 r
s
.576 .776 .973 r
.47275 .62435 m .48642 .63006 L .4866 .61535 L p F P
0 0 0 r
s
.576 .776 .973 r
.4866 .61535 m .47299 .60962 L .47275 .62435 L p F P
0 0 0 r
s
.69 .09 .12 r
.89556 .56694 m
.90809 .57898 L
s
.88535 .57488 m
.89556 .56694 L
s
.89556 .56694 m
.90384 .56722 L
s
.29112 .26433 m
.29888 .26196 L
s
.445 .599 .78 r
.54198 .38678 m .52524 .38569 L .52525 .3721 L p F P
0 0 0 r
s
.327 .449 .611 r
.55138 .63371 m .56666 .62965 L .56647 .61494 L p F P
0 0 0 r
s
.274 .382 .529 r
.57991 .60907 m .56647 .61494 L .56666 .62965 L p F P
0 0 0 r
s
.69 .09 .12 r
.32202 .78427 m
.31421 .79392 L
s
.32894 .7897 m
.32202 .78427 L
s
.335 .477 .554 r
.44771 .53049 m .44923 .54056 L .44958 .52625 L p F P
0 0 0 r
s
.335 .477 .554 r
.44958 .52625 m .44807 .51615 L .44771 .53049 L p F P
0 0 0 r
s
.69 .09 .12 r
.21728 .36792 m
.22193 .36736 L
s
.22356 .35146 m
.21728 .36792 L
s
.21728 .36792 m
.21293 .35615 L
s
.23253 .36262 m
.21728 .36792 L
s
.24513 .32448 m
.21728 .36792 L
s
.38986 .69398 m
.39503 .68759 L
s
.06 .089 .131 r
.60377 .51531 m .60256 .52543 L .60291 .53974 L p F P
0 0 0 r
s
.06 .089 .131 r
.60256 .52543 m .60377 .51531 L .60341 .50109 L p F P
0 0 0 r
s
.48 .649 .84 r
.5017 .64878 m .51821 .65072 L .51824 .63591 L p F P
0 0 0 r
s
.48 .649 .84 r
.51824 .63591 m .50181 .63396 L .5017 .64878 L p F P
0 0 0 r
s
.431 .583 .767 r
.53501 .63582 m .51824 .63591 L .51821 .65072 L p F P
0 0 0 r
s
.69 .09 .12 r
.20995 .58067 m
.20882 .58069 L
s
.21052 .56363 m
.20995 .58067 L
s
.20995 .58067 m
.19909 .57158 L
s
.22024 .5727 m
.20995 .58067 L
s
.20854 .53714 m
.20995 .58067 L
s
.431 .583 .767 r
.51821 .65072 m .53505 .65064 L .53501 .63582 L p F P
0 0 0 r
s
.38 .517 .691 r
.55138 .63371 m .53501 .63582 L .53505 .65064 L p F P
0 0 0 r
s
.69 .09 .12 r
.67745 .36687 m
.65978 .34312 L
s
.31421 .79392 m
.32111 .79939 L
s
.27923 .46323 m
.27062 .46821 L
s
.28679 .47112 m
.27923 .46323 L
s
.32801 .57969 m
.33416 .58486 L
s
.33416 .58486 m
.34095 .57945 L
s
.06 .088 .13 r
.45021 .50602 m .44807 .51615 L .44843 .50193 L p F P
0 0 0 r
s
.06 .088 .13 r
.44843 .50193 m .45055 .49177 L .45021 .50602 L p F P
0 0 0 r
s
.69 .09 .12 r
.34182 .36531 m
.34707 .37269 L
s
.90809 .57898 m
.89791 .58698 L
s
.90384 .56722 m
.90809 .57898 L
s
.15068 .47204 m
.15225 .47146 L
s
.15462 .45206 m
.15068 .47204 L
s
.15068 .47204 m
.14108 .45953 L
s
.16576 .46393 m
.15068 .47204 L
s
.1648 .41928 m
.15068 .47204 L
s
.26633 .67446 m
.2568 .68304 L
s
.27464 .68129 m
.26633 .67446 L
s
.53 .714 .909 r
.48624 .6449 m .5017 .64878 L .50181 .63396 L p F P
0 0 0 r
s
.53 .714 .909 r
.50181 .63396 m .48642 .63006 L .48624 .6449 L p F P
0 0 0 r
s
.69 .09 .12 r
.87669 .68557 m
.91245 .63916 L
s
.336 .459 .619 r
.50846 .40069 m .49256 .40425 L .49272 .39054 L p F P
0 0 0 r
s
.336 .459 .619 r
.49272 .39054 m .50854 .38697 L .50846 .40069 L p F P
0 0 0 r
s
.69 .09 .12 r
.84099 .45864 m
.85219 .46745 L
s
.83149 .46625 m
.84099 .45864 L
s
.84099 .45864 m
.84482 .4577 L
s
.338 .478 .556 r
.60098 .49095 m .60341 .50109 L .60377 .51531 L p F P
0 0 0 r
s
.338 .478 .556 r
.60341 .50109 m .60098 .49095 L .60064 .47682 L p F P
0 0 0 r
s
.38 .517 .691 r
.53505 .65064 m .5515 .64854 L .55138 .63371 L p F P
0 0 0 r
s
.327 .449 .611 r
.56666 .62965 m .55138 .63371 L .5515 .64854 L p F P
0 0 0 r
s
.69 .09 .12 r
.22356 .35146 m
.21293 .35615 L
s
.23253 .36262 m
.22356 .35146 L
s
.546 .732 .922 r
.57245 .40937 m .55806 .40388 L .55791 .39017 L p F P
0 0 0 r
s
.497 .667 .854 r
.54198 .38678 m .55791 .39017 L .55806 .40388 L p F P
0 0 0 r
s
.69 .09 .12 r
.27819 .47614 m
.28679 .47112 L
s
.09 .133 .211 r
.45628 .48207 m .45055 .49177 L .4509 .47765 L p F P
0 0 0 r
s
.09 .133 .211 r
.4509 .47765 m .4566 .46792 L .45628 .48207 L p F P
0 0 0 r
s
.69 .09 .12 r
.82859 .67089 m
.83816 .68237 L
s
.82062 .67699 m
.82859 .67089 L
s
.82859 .67089 m
.8377 .67253 L
s
.37688 .90932 m
.38316 .89794 L
s
.64931 .89793 m
.70482 .8841 L
s
.22193 .36736 m
.23253 .36262 L
s
.21052 .56363 m
.19909 .57158 L
s
.22024 .5727 m
.21052 .56363 L
s
.603 .821 .995 r
.45329 .59375 m .46171 .60232 L .462 .58769 L p F P
0 0 0 r
s
.603 .821 .995 r
.462 .58769 m .45362 .57908 L .45329 .59375 L p F P
0 0 0 r
s
.497 .683 .822 r
.59465 .46715 m .60064 .47682 L .60098 .49095 L p F P
0 0 0 r
s
.497 .683 .822 r
.60064 .47682 m .59465 .46715 L .59434 .45313 L p F P
0 0 0 r
s
.61 .824 1 r
.46141 .61709 m .47275 .62435 L .47299 .60962 L p F P
0 0 0 r
s
.61 .824 1 r
.47299 .60962 m .46171 .60232 L .46141 .61709 L p F P
0 0 0 r
s
.281 .388 .533 r
.49241 .41809 m .47812 .42373 L .47834 .40991 L p F P
0 0 0 r
s
.281 .388 .533 r
.47834 .40991 m .49256 .40425 L .49241 .41809 L p F P
0 0 0 r
s
.222 .311 .441 r
.57991 .60907 m .59098 .60166 L .59068 .58702 L p F P
0 0 0 r
s
.158 .22 .329 r
.5988 .57833 m .59068 .58702 L .59098 .60166 L p F P
0 0 0 r
s
.158 .22 .329 r
.59068 .58702 m .5988 .57833 L .59847 .56379 L p F P
0 0 0 r
s
.69 .09 .12 r
.2568 .68304 m
.2651 .68991 L
s
.274 .382 .529 r
.56666 .62965 m .58016 .62381 L .57991 .60907 L p F P
0 0 0 r
s
.222 .311 .441 r
.59098 .60166 m .57991 .60907 L .58016 .62381 L p F P
0 0 0 r
s
.164 .227 .334 r
.46565 .45914 m .4566 .46792 L .45692 .4539 L p F P
0 0 0 r
s
.164 .227 .334 r
.45692 .4539 m .46593 .44509 L .46565 .45914 L p F P
0 0 0 r
s
.491 .682 .818 r
.44852 .56957 m .45362 .57908 L .45396 .56455 L p F P
0 0 0 r
s
.491 .682 .818 r
.45396 .56455 m .44888 .555 L .44852 .56957 L p F P
0 0 0 r
s
.585 .785 .972 r
.58479 .43049 m .57266 .42319 L .57245 .40937 L p F P
0 0 0 r
s
.546 .732 .922 r
.55806 .40388 m .57245 .40937 L .57266 .42319 L p F P
0 0 0 r
s
.69 .09 .12 r
.32111 .79939 m
.32894 .7897 L
s
.391 .529 .701 r
.52524 .39941 m .50846 .40069 L .50854 .38697 L p F P
0 0 0 r
s
.391 .529 .701 r
.50854 .38697 m .52524 .38569 L .52524 .39941 L p F P
0 0 0 r
s
.69 .09 .12 r
.27062 .46821 m
.27819 .47614 L
s
.225 .314 .442 r
.4779 .43768 m .46593 .44509 L .46621 .43117 L p F P
0 0 0 r
s
.225 .314 .442 r
.46621 .43117 m .47812 .42373 L .4779 .43768 L p F P
0 0 0 r
s
.69 .09 .12 r
.83816 .68237 m
.83022 .68852 L
s
.8377 .67253 m
.83816 .68237 L
s
.497 .667 .854 r
.55806 .40388 m .54205 .4005 L .54198 .38678 L p F P
0 0 0 r
s
.445 .599 .78 r
.52524 .38569 m .54198 .38678 L .54205 .4005 L p F P
0 0 0 r
s
.69 .09 .12 r
.78614 .34943 m
.79599 .35533 L
s
.77753 .35745 m
.78614 .34943 L
s
.78614 .34943 m
.78567 .34796 L
s
.589 .795 .968 r
.58506 .44442 m .59434 .45313 L .59465 .46715 L p F P
0 0 0 r
s
.589 .795 .968 r
.59434 .45313 m .58506 .44442 L .58479 .43049 L p F P
0 0 0 r
s
.69 .09 .12 r
.64311 .57496 m
.65255 .55867 L
s
.89791 .58698 m
.88535 .57488 L
s
.88535 .57488 m
.90384 .56722 L
s
.092 .135 .215 r
.60326 .55418 m .59847 .56379 L .5988 .57833 L p F P
0 0 0 r
s
.092 .135 .215 r
.59847 .56379 m .60326 .55418 L .60291 .53974 L p F P
0 0 0 r
s
.69 .09 .12 r
.28444 .25323 m
.29112 .26433 L
s
.585 .785 .972 r
.57266 .42319 m .58479 .43049 L .58506 .44442 L p F P
0 0 0 r
s
.69 .09 .12 r
.85219 .46745 m
.84269 .47511 L
s
.84482 .4577 m
.85219 .46745 L
s
.576 .776 .973 r
.4725 .63923 m .48624 .6449 L .48642 .63006 L p F P
0 0 0 r
s
.576 .776 .973 r
.48642 .63006 m .47275 .62435 L .4725 .63923 L p F P
0 0 0 r
s
.69 .09 .12 r
.15462 .45206 m
.14108 .45953 L
s
.16576 .46393 m
.15462 .45206 L
s
.445 .599 .78 r
.54205 .4005 m .52524 .39941 L .52524 .38569 L p F P
0 0 0 r
s
.327 .449 .611 r
.5515 .64854 m .56685 .6445 L .56666 .62965 L p F P
0 0 0 r
s
.274 .382 .529 r
.58016 .62381 m .56666 .62965 L .56685 .6445 L p F P
0 0 0 r
s
.69 .09 .12 r
.2651 .68991 m
.27464 .68129 L
s
.335 .477 .554 r
.44735 .54497 m .44888 .555 L .44923 .54056 L p F P
0 0 0 r
s
.335 .477 .554 r
.44923 .54056 m .44771 .53049 L .44735 .54497 L p F P
0 0 0 r
s
.69 .09 .12 r
.84269 .47511 m
.83149 .46625 L
s
.83149 .46625 m
.84482 .4577 L
s
.6369 .25126 m
.60022 .23286 L
s
.06 .089 .131 r
.60413 .52965 m .60291 .53974 L .60326 .55418 L p F P
0 0 0 r
s
.06 .089 .131 r
.60291 .53974 m .60413 .52965 L .60377 .51531 L p F P
0 0 0 r
s
.48 .649 .84 r
.50159 .66375 m .51817 .66568 L .51821 .65072 L p F P
0 0 0 r
s
.48 .649 .84 r
.51821 .65072 m .5017 .64878 L .50159 .66375 L p F P
0 0 0 r
s
.431 .583 .767 r
.53505 .65064 m .51821 .65072 L .51817 .66568 L p F P
0 0 0 r
s
.69 .09 .12 r
.77372 .5628 m
.78195 .57085 L
s
.76652 .5681 m
.77372 .5628 L
s
.77372 .5628 m
.77852 .56296 L
s
.431 .583 .767 r
.51817 .66568 m .53509 .66559 L .53505 .65064 L p F P
0 0 0 r
s
.38 .517 .691 r
.5515 .64854 m .53505 .65064 L .53509 .66559 L p F P
0 0 0 r
s
.69 .09 .12 r
.20882 .58069 m
.22024 .5727 L
s
.78737 .36338 m
.77753 .35745 L
s
.77753 .35745 m
.78567 .34796 L
s
.73102 .23919 m
.7395 .24263 L
s
.72348 .24847 m
.73102 .23919 L
s
.73102 .23919 m
.72639 .23798 L
s
.76114 .77502 m
.76791 .78622 L
s
.75546 .77976 m
.76114 .77502 L
s
.76114 .77502 m
.77136 .77816 L
s
.06 .088 .13 r
.44985 .5204 m .44771 .53049 L .44807 .51615 L p F P
0 0 0 r
s
.06 .088 .13 r
.44807 .51615 m .45021 .50602 L .44985 .5204 L p F P
0 0 0 r
s
.69 .09 .12 r
.90384 .56722 m
.89791 .58698 L
s
.19909 .57158 m
.20882 .58069 L
s
.76791 .78622 m
.76226 .79102 L
s
.77136 .77816 m
.76791 .78622 L
s
.15225 .47146 m
.16576 .46393 L
s
.83699 .57125 m
.85209 .52722 L
s
.53 .714 .909 r
.48605 .65988 m .50159 .66375 L .5017 .64878 L p F P
0 0 0 r
s
.53 .714 .909 r
.5017 .64878 m .48624 .6449 L .48605 .65988 L p F P
0 0 0 r
s
.69 .09 .12 r
.21293 .35615 m
.22193 .36736 L
s
.336 .459 .619 r
.50838 .41453 m .49241 .41809 L .49256 .40425 L p F P
0 0 0 r
s
.336 .459 .619 r
.49256 .40425 m .50846 .40069 L .50838 .41453 L p F P
0 0 0 r
s
.338 .478 .556 r
.60133 .5052 m .60377 .51531 L .60413 .52965 L p F P
0 0 0 r
s
.338 .478 .556 r
.60377 .51531 m .60133 .5052 L .60098 .49095 L p F P
0 0 0 r
s
.69 .09 .12 r
.78195 .57085 m
.77477 .57618 L
s
.77852 .56296 m
.78195 .57085 L
s
.73195 .25194 m
.72348 .24847 L
s
.72348 .24847 m
.72639 .23798 L
s
.38 .517 .691 r
.53509 .66559 m .55162 .6635 L .5515 .64854 L p F P
0 0 0 r
s
.327 .449 .611 r
.56685 .6445 m .5515 .64854 L .55162 .6635 L p F P
0 0 0 r
s
.546 .732 .922 r
.57266 .42319 m .5582 .41771 L .55806 .40388 L p F P
0 0 0 r
s
.497 .667 .854 r
.54205 .4005 m .55806 .40388 L .5582 .41771 L p F P
0 0 0 r
s
.69 .09 .12 r
.79599 .35533 m
.78737 .36338 L
s
.78567 .34796 m
.79599 .35533 L
s
.09 .133 .211 r
.45595 .49636 m .45021 .50602 L .45055 .49177 L p F P
0 0 0 r
s
.09 .133 .211 r
.45055 .49177 m .45628 .48207 L .45595 .49636 L p F P
0 0 0 r
s
.69 .09 .12 r
.84482 .4577 m
.84269 .47511 L
s
.83022 .68852 m
.82062 .67699 L
s
.82062 .67699 m
.8377 .67253 L
s
.71857 .45378 m
.72544 .45876 L
s
.71234 .45902 m
.71857 .45378 L
s
.71857 .45378 m
.71921 .45316 L
s
.60855 .78443 m
.64532 .77442 L
s
.603 .821 .995 r
.45295 .60855 m .46141 .61709 L .46171 .60232 L p F P
0 0 0 r
s
.603 .821 .995 r
.46171 .60232 m .45329 .59375 L .45295 .60855 L p F P
0 0 0 r
s
.497 .683 .822 r
.59497 .48131 m .60098 .49095 L .60133 .5052 L p F P
0 0 0 r
s
.497 .683 .822 r
.60098 .49095 m .59497 .48131 L .59465 .46715 L p F P
0 0 0 r
s
.61 .824 1 r
.46111 .63199 m .4725 .63923 L .47275 .62435 L p F P
0 0 0 r
s
.61 .824 1 r
.47275 .62435 m .46141 .61709 L .46111 .63199 L p F P
0 0 0 r
s
.281 .388 .533 r
.49225 .43205 m .4779 .43768 L .47812 .42373 L p F P
0 0 0 r
s
.281 .388 .533 r
.47812 .42373 m .49241 .41809 L .49225 .43205 L p F P
0 0 0 r
s
.222 .311 .441 r
.58016 .62381 m .59128 .61643 L .59098 .60166 L p F P
0 0 0 r
s
.158 .22 .329 r
.59914 .593 m .59098 .60166 L .59128 .61643 L p F P
0 0 0 r
s
.158 .22 .329 r
.59098 .60166 m .59914 .593 L .5988 .57833 L p F P
0 0 0 r
s
.274 .382 .529 r
.56685 .6445 m .58041 .63868 L .58016 .62381 L p F P
0 0 0 r
s
.222 .311 .441 r
.59128 .61643 m .58016 .62381 L .58041 .63868 L p F P
0 0 0 r
s
.164 .227 .334 r
.46537 .47332 m .45628 .48207 L .4566 .46792 L p F P
0 0 0 r
s
.164 .227 .334 r
.4566 .46792 m .46565 .45914 L .46537 .47332 L p F P
0 0 0 r
s
.69 .09 .12 r
.77477 .57618 m
.76652 .5681 L
s
.76652 .5681 m
.77852 .56296 L
s
.491 .682 .818 r
.44816 .58428 m .45329 .59375 L .45362 .57908 L p F P
0 0 0 r
s
.491 .682 .818 r
.45362 .57908 m .44852 .56957 L .44816 .58428 L p F P
0 0 0 r
s
.585 .785 .972 r
.58506 .44442 m .57288 .43714 L .57266 .42319 L p F P
0 0 0 r
s
.546 .732 .922 r
.5582 .41771 m .57266 .42319 L .57288 .43714 L p F P
0 0 0 r
s
.69 .09 .12 r
.8377 .67253 m
.83022 .68852 L
s
.391 .529 .701 r
.52524 .41326 m .50838 .41453 L .50846 .40069 L p F P
0 0 0 r
s
.391 .529 .701 r
.50846 .40069 m .52524 .39941 L .52524 .41326 L p F P
0 0 0 r
s
.69 .09 .12 r
.70597 .6672 m
.71139 .67473 L
s
.70114 .6706 m
.70597 .6672 L
s
.70597 .6672 m
.71202 .66853 L
s
.69735 .89055 m
.694 .89475 L
s
.69325 .87906 m
.69735 .89055 L
s
.70482 .8841 m
.69735 .89055 L
s
.225 .314 .442 r
.47768 .45175 m .46565 .45914 L .46593 .44509 L p F P
0 0 0 r
s
.225 .314 .442 r
.46593 .44509 m .4779 .43768 L .47768 .45175 L p F P
0 0 0 r
s
.497 .667 .854 r
.5582 .41771 m .54213 .41434 L .54205 .4005 L p F P
0 0 0 r
s
.445 .599 .78 r
.52524 .39941 m .54205 .4005 L .54213 .41434 L p F P
0 0 0 r
s
.589 .795 .968 r
.58534 .45847 m .59465 .46715 L .59497 .48131 L p F P
0 0 0 r
s
.589 .795 .968 r
.59465 .46715 m .58534 .45847 L .58506 .44442 L p F P
0 0 0 r
s
.69 .09 .12 r
.78567 .34796 m
.78737 .36338 L
s
.092 .135 .215 r
.60362 .56876 m .5988 .57833 L .59914 .593 L p F P
0 0 0 r
s
.092 .135 .215 r
.5988 .57833 m .60362 .56876 L .60326 .55418 L p F P
0 0 0 r
s
.69 .09 .12 r
.14108 .45953 m
.15225 .47146 L
s
.71139 .67473 m
.70657 .67816 L
s
.71202 .66853 m
.71139 .67473 L
s
.585 .785 .972 r
.57288 .43714 m .58506 .44442 L .58534 .45847 L p F P
0 0 0 r
s
.576 .776 .973 r
.47225 .65423 m .48605 .65988 L .48624 .6449 L p F P
0 0 0 r
s
.576 .776 .973 r
.48624 .6449 m .4725 .63923 L .47225 .65423 L p F P
0 0 0 r
s
.69 .09 .12 r
.68988 .88321 m
.69325 .87906 L
s
.69325 .87906 m
.70482 .8841 L
s
.71921 .46401 m
.71234 .45902 L
s
.71234 .45902 m
.71921 .45316 L
s
.445 .599 .78 r
.54213 .41434 m .52524 .41326 L .52524 .39941 L p F P
0 0 0 r
s
.327 .449 .611 r
.55162 .6635 m .56704 .65948 L .56685 .6445 L p F P
0 0 0 r
s
.274 .382 .529 r
.58041 .63868 m .56685 .6445 L .56704 .65948 L p F P
0 0 0 r
s
.69 .09 .12 r
.72544 .45876 m
.71921 .46401 L
s
.71921 .45316 m
.72544 .45876 L
s
.66314 .34351 m
.66864 .34607 L
s
.65806 .34977 m
.66314 .34351 L
s
.66314 .34351 m
.65978 .34312 L
s
.335 .477 .554 r
.44698 .55958 m .44852 .56957 L .44888 .555 L p F P
0 0 0 r
s
.335 .477 .554 r
.44888 .555 m .44735 .54497 L .44698 .55958 L p F P
0 0 0 r
s
.69 .09 .12 r
.77852 .56296 m
.77477 .57618 L
s
.7395 .24263 m
.73195 .25194 L
s
.72639 .23798 m
.7395 .24263 L
s
.803 .78118 m
.84481 .74698 L
s
.06 .089 .131 r
.60449 .54413 m .60326 .55418 L .60362 .56876 L p F P
0 0 0 r
s
.06 .089 .131 r
.60326 .55418 m .60449 .54413 L .60413 .52965 L p F P
0 0 0 r
s
.69 .09 .12 r
.66355 .35234 m
.65806 .34977 L
s
.65806 .34977 m
.65978 .34312 L
s
.48 .649 .84 r
.50147 .67885 m .51814 .68077 L .51817 .66568 L p F P
0 0 0 r
s
.48 .649 .84 r
.51817 .66568 m .50159 .66375 L .50147 .67885 L p F P
0 0 0 r
s
.431 .583 .767 r
.53509 .66559 m .51817 .66568 L .51814 .68077 L p F P
0 0 0 r
s
.431 .583 .767 r
.51814 .68077 m .53514 .68068 L .53509 .66559 L p F P
0 0 0 r
s
.38 .517 .691 r
.55162 .6635 m .53509 .66559 L .53514 .68068 L p F P
0 0 0 r
s
.69 .09 .12 r
.72639 .23798 m
.73195 .25194 L
s
.76226 .79102 m
.75546 .77976 L
s
.75546 .77976 m
.77136 .77816 L
s
.06 .088 .13 r
.4495 .53492 m .44735 .54497 L .44771 .53049 L p F P
0 0 0 r
s
.06 .088 .13 r
.44771 .53049 m .44985 .5204 L .4495 .53492 L p F P
0 0 0 r
s
.69 .09 .12 r
.60775 .24134 m
.6037 .24034 L
s
.6037 .24034 m
.60747 .23182 L
s
.6037 .24034 m
.60022 .23286 L
s
.79693 .45591 m
.79159 .41504 L
s
.71921 .45316 m
.71921 .46401 L
s
.77136 .77816 m
.76226 .79102 L
s
.65051 .5586 m
.65457 .56265 L
s
.64672 .56126 m
.65051 .5586 L
s
.65051 .5586 m
.65255 .55867 L
s
.60747 .23182 m
.61154 .23278 L
s
.60747 .23182 m
.60022 .23286 L
s
.53 .714 .909 r
.48587 .675 m .50147 .67885 L .50159 .66375 L p F P
0 0 0 r
s
.53 .714 .909 r
.50159 .66375 m .48605 .65988 L .48587 .675 L p F P
0 0 0 r
s
.69 .09 .12 r
.64051 .77908 m
.63809 .78151 L
s
.63775 .77137 m
.64051 .77908 L
s
.64532 .77442 m
.64051 .77908 L
s
.336 .459 .619 r
.5083 .42851 m .49225 .43205 L .49241 .41809 L p F P
0 0 0 r
s
.336 .459 .619 r
.49241 .41809 m .50838 .41453 L .5083 .42851 L p F P
0 0 0 r
s
.338 .478 .556 r
.60168 .51958 m .60413 .52965 L .60449 .54413 L p F P
0 0 0 r
s
.338 .478 .556 r
.60413 .52965 m .60168 .51958 L .60133 .5052 L p F P
0 0 0 r
s
.38 .517 .691 r
.53514 .68068 m .55174 .6786 L .55162 .6635 L p F P
0 0 0 r
s
.327 .449 .611 r
.56704 .65948 m .55162 .6635 L .55174 .6786 L p F P
0 0 0 r
s
.546 .732 .922 r
.57288 .43714 m .55835 .43168 L .5582 .41771 L p F P
0 0 0 r
s
.497 .667 .854 r
.54213 .41434 m .5582 .41771 L .55835 .43168 L p F P
0 0 0 r
s
.69 .09 .12 r
.63532 .77378 m
.63775 .77137 L
s
.63775 .77137 m
.64532 .77442 L
s
.65457 .56265 m
.65078 .56531 L
s
.65255 .55867 m
.65457 .56265 L
s
.70657 .67816 m
.70114 .6706 L
s
.70114 .6706 m
.71202 .66853 L
s
.66864 .34607 m
.66355 .35234 L
s
.65978 .34312 m
.66864 .34607 L
s
.71202 .66853 m
.70657 .67816 L
s
.09 .133 .211 r
.45563 .51077 m .44985 .5204 L .45021 .50602 L p F P
0 0 0 r
s
.09 .133 .211 r
.45021 .50602 m .45595 .49636 L .45563 .51077 L p F P
0 0 0 r
s
.69 .09 .12 r
.65078 .56531 m
.64672 .56126 L
s
.64672 .56126 m
.65255 .55867 L
s
.603 .821 .995 r
.45261 .6235 m .46111 .63199 L .46141 .61709 L p F P
0 0 0 r
s
.603 .821 .995 r
.46141 .61709 m .45295 .60855 L .45261 .6235 L p F P
0 0 0 r
s
.69 .09 .12 r
.65978 .34312 m
.66355 .35234 L
s
.497 .683 .822 r
.59529 .4956 m .60133 .5052 L .60168 .51958 L p F P
0 0 0 r
s
.497 .683 .822 r
.60133 .5052 m .59529 .4956 L .59497 .48131 L p F P
0 0 0 r
s
.61 .824 1 r
.46081 .64703 m .47225 .65423 L .4725 .63923 L p F P
0 0 0 r
s
.61 .824 1 r
.4725 .63923 m .46111 .63199 L .46081 .64703 L p F P
0 0 0 r
s
.281 .388 .533 r
.4921 .44614 m .47768 .45175 L .4779 .43768 L p F P
0 0 0 r
s
.281 .388 .533 r
.4779 .43768 m .49225 .43205 L .4921 .44614 L p F P
0 0 0 r
s
.222 .311 .441 r
.58041 .63868 m .59158 .63133 L .59128 .61643 L p F P
0 0 0 r
s
.158 .22 .329 r
.59948 .60781 m .59128 .61643 L .59158 .63133 L p F P
0 0 0 r
s
.158 .22 .329 r
.59128 .61643 m .59948 .60781 L .59914 .593 L p F P
0 0 0 r
s
.274 .382 .529 r
.56704 .65948 m .58066 .6537 L .58041 .63868 L p F P
0 0 0 r
s
.222 .311 .441 r
.59158 .63133 m .58041 .63868 L .58066 .6537 L p F P
0 0 0 r
s
.164 .227 .334 r
.46509 .48763 m .45595 .49636 L .45628 .48207 L p F P
0 0 0 r
s
.164 .227 .334 r
.45628 .48207 m .46537 .47332 L .46509 .48763 L p F P
0 0 0 r
s
.69 .09 .12 r
.59478 .44857 m
.59745 .44998 L
s
.59222 .45173 m
.59478 .44857 L
s
.59296 .44859 m
.59478 .44857 L
s
.491 .682 .818 r
.4478 .59913 m .45295 .60855 L .45329 .59375 L p F P
0 0 0 r
s
.491 .682 .818 r
.45329 .59375 m .44816 .58428 L .4478 .59913 L p F P
0 0 0 r
s
.69 .09 .12 r
.65255 .55867 m
.65078 .56531 L
s
.585 .785 .972 r
.58534 .45847 m .57309 .45122 L .57288 .43714 L p F P
0 0 0 r
s
.546 .732 .922 r
.55835 .43168 m .57288 .43714 L .57309 .45122 L p F P
0 0 0 r
s
.69 .09 .12 r
.56109 .34379 m
.53324 .33827 L
s
.391 .529 .701 r
.52523 .42724 m .5083 .42851 L .50838 .41453 L p F P
0 0 0 r
s
.391 .529 .701 r
.50838 .41453 m .52524 .41326 L .52523 .42724 L p F P
0 0 0 r
s
.69 .09 .12 r
.59222 .45173 m
.59488 .45315 L
s
.59222 .45173 m
.59296 .44859 L
s
.225 .314 .442 r
.47745 .46596 m .46537 .47332 L .46565 .45914 L p F P
0 0 0 r
s
.225 .314 .442 r
.46565 .45914 m .47768 .45175 L .47745 .46596 L p F P
0 0 0 r
s
.497 .667 .854 r
.55835 .43168 m .5422 .42831 L .54213 .41434 L p F P
0 0 0 r
s
.445 .599 .78 r
.52524 .41326 m .54213 .41434 L .5422 .42831 L p F P
0 0 0 r
s
.69 .09 .12 r
.70482 .8841 m
.694 .89475 L
s
.68988 .88321 m
.70482 .8841 L
s
.589 .795 .968 r
.58561 .47265 m .59497 .48131 L .59529 .4956 L p F P
0 0 0 r
s
.589 .795 .968 r
.59497 .48131 m .58561 .47265 L .58534 .45847 L p F P
0 0 0 r
s
.69 .09 .12 r
.59296 .44859 m
.60228 .45989 L
s
.092 .135 .215 r
.60398 .58347 m .59914 .593 L .59948 .60781 L p F P
0 0 0 r
s
.092 .135 .215 r
.59914 .593 m .60398 .58347 L .60362 .56876 L p F P
0 0 0 r
s
.69 .09 .12 r
.56931 .8839 m
.56927 .88664 L
s
.56912 .87492 m
.56931 .8839 L
s
.57841 .88063 m
.56931 .8839 L
s
.694 .89475 m
.68988 .88321 L
s
.585 .785 .972 r
.57309 .45122 m .58534 .45847 L .58561 .47265 L p F P
0 0 0 r
s
.576 .776 .973 r
.472 .66938 m .48587 .675 L .48605 .65988 L p F P
0 0 0 r
s
.576 .776 .973 r
.48605 .65988 m .47225 .65423 L .472 .66938 L p F P
0 0 0 r
s
.69 .09 .12 r
.58338 .66702 m
.58207 .66805 L
s
.58199 .66314 m
.58338 .66702 L
s
.58569 .66451 m
.58338 .66702 L
s
.445 .599 .78 r
.5422 .42831 m .52523 .42724 L .52524 .41326 L p F P
0 0 0 r
s
.327 .449 .611 r
.55174 .6786 m .56723 .6746 L .56704 .65948 L p F P
0 0 0 r
s
.274 .382 .529 r
.58066 .6537 m .56704 .65948 L .56723 .6746 L p F P
0 0 0 r
s
.69 .09 .12 r
.5709 .66888 m
.58569 .66451 L
s
.58068 .66416 m
.58199 .66314 L
s
.58199 .66314 m
.58569 .66451 L
s
.53884 .34251 m
.53762 .34203 L
s
.53762 .34203 m
.53881 .33625 L
s
.53762 .34203 m
.53324 .33827 L
s
.56908 .87763 m
.56912 .87492 L
s
.56912 .87492 m
.57841 .88063 L
s
.335 .477 .554 r
.44661 .57433 m .44816 .58428 L .44852 .56957 L p F P
0 0 0 r
s
.335 .477 .554 r
.44852 .56957 m .44698 .55958 L .44661 .57433 L p F P
0 0 0 r
s
.69 .09 .12 r
.59745 .44998 m
.59488 .45315 L
s
.59296 .44859 m
.59745 .44998 L
s
.76265 .66639 m
.78428 .63499 L
s
.61154 .23278 m
.60775 .24134 L
s
.60022 .23286 m
.60775 .24134 L
s
.53881 .33625 m
.54003 .33671 L
s
.53881 .33625 m
.53324 .33827 L
s
.64532 .77442 m
.63809 .78151 L
s
.63532 .77378 m
.64532 .77442 L
s
.59296 .44859 m
.59488 .45315 L
s
.63809 .78151 m
.63532 .77378 L
s
.60022 .23286 m
.61154 .23278 L
s
.06 .089 .131 r
.60486 .55875 m .60362 .56876 L .60398 .58347 L p F P
0 0 0 r
s
.06 .089 .131 r
.60362 .56876 m .60486 .55875 L .60449 .54413 L p F P
0 0 0 r
s
.48 .649 .84 r
.50136 .69409 m .5181 .696 L .51814 .68077 L p F P
0 0 0 r
s
.48 .649 .84 r
.51814 .68077 m .50147 .67885 L .50136 .69409 L p F P
0 0 0 r
s
.431 .583 .767 r
.53514 .68068 m .51814 .68077 L .5181 .696 L p F P
0 0 0 r
s
.431 .583 .767 r
.5181 .696 m .53518 .69592 L .53514 .68068 L p F P
0 0 0 r
s
.38 .517 .691 r
.55174 .6786 m .53514 .68068 L .53518 .69592 L p F P
0 0 0 r
s
.69 .09 .12 r
.48255 .23228 m
.48293 .23214 L
s
.48293 .23214 m
.48269 .22275 L
s
.48293 .23214 m
.4734 .22772 L
s
.75651 .33953 m
.73097 .30262 L
s
.53234 .88135 m
.57841 .88063 L
s
.06 .088 .13 r
.44914 .54957 m .44698 .55958 L .44735 .54497 L p F P
0 0 0 r
s
.06 .088 .13 r
.44735 .54497 m .4495 .53492 L .44914 .54957 L p F P
0 0 0 r
s
.69 .09 .12 r
.58569 .66451 m
.58207 .66805 L
s
.58068 .66416 m
.58569 .66451 L
s
.48269 .22275 m
.4823 .22284 L
s
.48269 .22275 m
.4734 .22772 L
s
.58207 .66805 m
.58068 .66416 L
s
.53 .714 .909 r
.48568 .69026 m .50136 .69409 L .50147 .67885 L p F P
0 0 0 r
s
.53 .714 .909 r
.50147 .67885 m .48587 .675 L .48568 .69026 L p F P
0 0 0 r
s
.336 .459 .619 r
.50822 .44261 m .4921 .44614 L .49225 .43205 L p F P
0 0 0 r
s
.336 .459 .619 r
.49225 .43205 m .5083 .42851 L .50822 .44261 L p F P
0 0 0 r
s
.69 .09 .12 r
.57841 .88063 m
.56927 .88664 L
s
.56908 .87763 m
.57841 .88063 L
s
.338 .478 .556 r
.60203 .5341 m .60449 .54413 L .60486 .55875 L p F P
0 0 0 r
s
.338 .478 .556 r
.60449 .54413 m .60203 .5341 L .60168 .51958 L p F P
0 0 0 r
s
.38 .517 .691 r
.53518 .69592 m .55186 .69385 L .55174 .6786 L p F P
0 0 0 r
s
.327 .449 .611 r
.56723 .6746 m .55174 .6786 L .55186 .69385 L p F P
0 0 0 r
s
.69 .09 .12 r
.53324 .33827 m
.53884 .34251 L
s
.53324 .33827 m
.54003 .33671 L
s
.546 .732 .922 r
.57309 .45122 m .5585 .44577 L .55835 .43168 L p F P
0 0 0 r
s
.497 .667 .854 r
.5422 .42831 m .55835 .43168 L .5585 .44577 L p F P
0 0 0 r
s
.69 .09 .12 r
.51186 .77186 m
.51301 .7734 L
s
.51304 .76621 m
.51186 .77186 L
s
.51863 .77066 m
.51186 .77186 L
s
.5142 .76774 m
.51304 .76621 L
s
.51304 .76621 m
.51863 .77066 L
s
.54003 .33671 m
.53884 .34251 L
s
.09 .133 .211 r
.4553 .52533 m .4495 .53492 L .44985 .5204 L p F P
0 0 0 r
s
.09 .133 .211 r
.44985 .5204 m .45563 .51077 L .4553 .52533 L p F P
0 0 0 r
s
.69 .09 .12 r
.51863 .77066 m
.51301 .7734 L
s
.5142 .76774 m
.51863 .77066 L
s
.49055 .76636 m
.51863 .77066 L
s
.603 .821 .995 r
.45227 .63858 m .46081 .64703 L .46111 .63199 L p F P
0 0 0 r
s
.603 .821 .995 r
.46111 .63199 m .45261 .6235 L .45227 .63858 L p F P
0 0 0 r
s
.69 .09 .12 r
.4734 .22772 m
.48255 .23228 L
s
.4734 .22772 m
.4823 .22284 L
s
.51952 .22665 m
.4734 .22772 L
s
.497 .683 .822 r
.59562 .51002 m .60168 .51958 L .60203 .5341 L p F P
0 0 0 r
s
.497 .683 .822 r
.60168 .51958 m .59562 .51002 L .59529 .4956 L p F P
0 0 0 r
s
.61 .824 1 r
.4605 .66222 m .472 .66938 L .47225 .65423 L p F P
0 0 0 r
s
.61 .824 1 r
.47225 .65423 m .46081 .64703 L .4605 .66222 L p F P
0 0 0 r
s
.69 .09 .12 r
.46961 .44505 m
.47111 .44439 L
s
.4697 .44046 m
.47111 .44439 L
s
.46606 .44399 m
.47111 .44439 L
s
.281 .388 .533 r
.49194 .46037 m .47745 .46596 L .47768 .45175 L p F P
0 0 0 r
s
.281 .388 .533 r
.47768 .45175 m .4921 .44614 L .49194 .46037 L p F P
0 0 0 r
s
.69 .09 .12 r
.4697 .44046 m
.4682 .44112 L
s
.4697 .44046 m
.46606 .44399 L
s
.222 .311 .441 r
.58066 .6537 m .59189 .64638 L .59158 .63133 L p F P
0 0 0 r
s
.158 .22 .329 r
.59982 .62275 m .59158 .63133 L .59189 .64638 L p F P
0 0 0 r
s
.158 .22 .329 r
.59158 .63133 m .59982 .62275 L .59948 .60781 L p F P
0 0 0 r
s
.69 .09 .12 r
.56927 .88664 m
.56908 .87763 L
s
.46606 .44399 m
.46961 .44505 L
s
.46606 .44399 m
.4682 .44112 L
s
.46606 .44399 m
.48407 .43778 L
s
.274 .382 .529 r
.56723 .6746 m .58092 .66885 L .58066 .6537 L p F P
0 0 0 r
s
.222 .311 .441 r
.59189 .64638 m .58066 .6537 L .58092 .66885 L p F P
0 0 0 r
s
.164 .227 .334 r
.46481 .50208 m .45563 .51077 L .45595 .49636 L p F P
0 0 0 r
s
.164 .227 .334 r
.45595 .49636 m .46509 .48763 L .46481 .50208 L p F P
0 0 0 r
s
.69 .09 .12 r
.72814 .87829 m
.77696 .85513 L
s
.491 .682 .818 r
.44743 .61411 m .45261 .6235 L .45295 .60855 L p F P
0 0 0 r
s
.491 .682 .818 r
.45295 .60855 m .4478 .59913 L .44743 .61411 L p F P
0 0 0 r
s
.585 .785 .972 r
.58561 .47265 m .57331 .46542 L .57309 .45122 L p F P
0 0 0 r
s
.546 .732 .922 r
.5585 .44577 m .57309 .45122 L .57331 .46542 L p F P
0 0 0 r
s
.391 .529 .701 r
.52523 .44135 m .50822 .44261 L .5083 .42851 L p F P
0 0 0 r
s
.391 .529 .701 r
.5083 .42851 m .52523 .42724 L .52523 .44135 L p F P
0 0 0 r
s
.225 .314 .442 r
.47722 .4803 m .46509 .48763 L .46537 .47332 L p F P
0 0 0 r
s
.225 .314 .442 r
.46537 .47332 m .47745 .46596 L .47722 .4803 L p F P
0 0 0 r
s
.497 .667 .854 r
.5585 .44577 m .54228 .44242 L .5422 .42831 L p F P
0 0 0 r
s
.445 .599 .78 r
.52523 .42724 m .5422 .42831 L .54228 .44242 L p F P
0 0 0 r
s
.69 .09 .12 r
.45872 .66046 m
.45661 .66091 L
s
.45671 .65599 m
.45872 .66046 L
s
.45872 .66046 m
.4541 .65923 L
s
.45923 .65767 m
.45872 .66046 L
s
.589 .795 .968 r
.58589 .48697 m .59529 .4956 L .59562 .51002 L p F P
0 0 0 r
s
.589 .795 .968 r
.59529 .4956 m .58589 .48697 L .58561 .47265 L p F P
0 0 0 r
s
.092 .135 .215 r
.60435 .59832 m .59948 .60781 L .59982 .62275 L p F P
0 0 0 r
s
.092 .135 .215 r
.59948 .60781 m .60435 .59832 L .60398 .58347 L p F P
0 0 0 r
s
.69 .09 .12 r
.413 .33519 m
.41619 .33422 L
s
.41619 .33422 m
.41334 .32633 L
s
.41619 .33422 m
.40606 .33339 L
s
.585 .785 .972 r
.57331 .46542 m .58561 .47265 L .58589 .48697 L p F P
0 0 0 r
s
.576 .776 .973 r
.47175 .68467 m .48568 .69026 L .48587 .675 L p F P
0 0 0 r
s
.576 .776 .973 r
.48587 .675 m .472 .66938 L .47175 .68467 L p F P
0 0 0 r
s
.69 .09 .12 r
.44001 .87719 m
.4435 .88048 L
s
.44378 .86873 m
.44001 .87719 L
s
.45136 .87714 m
.44001 .87719 L
s
.45136 .87714 m
.4435 .88048 L
s
.44378 .86873 m
.45136 .87714 L
s
.44728 .872 m
.45136 .87714 L
s
.41245 .86435 m
.45136 .87714 L
s
.41334 .32633 m
.41015 .32726 L
s
.41334 .32633 m
.40606 .33339 L
s
.45671 .65599 m
.4541 .65923 L
s
.45923 .65767 m
.45671 .65599 L
s
.445 .599 .78 r
.54228 .44242 m .52523 .44135 L .52523 .42724 L p F P
0 0 0 r
s
.327 .449 .611 r
.55186 .69385 m .56742 .68987 L .56723 .6746 L p F P
0 0 0 r
s
.274 .382 .529 r
.58092 .66885 m .56723 .6746 L .56742 .68987 L p F P
0 0 0 r
s
.69 .09 .12 r
.40606 .33339 m
.413 .33519 L
s
.40606 .33339 m
.41015 .32726 L
s
.44183 .32014 m
.40606 .33339 L
s
.51301 .7734 m
.5142 .76774 L
s
.44728 .872 m
.44378 .86873 L
s
.72194 .55057 m
.72363 .52275 L
s
.335 .477 .554 r
.44624 .58922 m .4478 .59913 L .44816 .58428 L p F P
0 0 0 r
s
.335 .477 .554 r
.44816 .58428 m .44661 .57433 L .44624 .58922 L p F P
0 0 0 r
s
.69 .09 .12 r
.4541 .65923 m
.45661 .66091 L
s
.4823 .22284 m
.48255 .23228 L
s
.35611 .22477 m
.36118 .22388 L
s
.36118 .22388 m
.35688 .21197 L
s
.36118 .22388 m
.34593 .22255 L
s
.4682 .44112 m
.46961 .44505 L
s
.39868 .55004 m
.39996 .55008 L
s
.40023 .54334 m
.39868 .55004 L
s
.39868 .55004 m
.39603 .546 L
s
.40416 .54742 m
.39868 .55004 L
s
.40583 .53326 m
.39868 .55004 L
s
.06 .089 .131 r
.60523 .5735 m .60398 .58347 L .60435 .59832 L p F P
0 0 0 r
s
.06 .089 .131 r
.60398 .58347 m .60523 .5735 L .60486 .55875 L p F P
0 0 0 r
s
.48 .649 .84 r
.50125 .70948 m .51806 .71138 L .5181 .696 L p F P
0 0 0 r
s
.48 .649 .84 r
.5181 .696 m .50136 .69409 L .50125 .70948 L p F P
0 0 0 r
s
.431 .583 .767 r
.53518 .69592 m .5181 .696 L .51806 .71138 L p F P
0 0 0 r
s
.431 .583 .767 r
.51806 .71138 m .53522 .71129 L .53518 .69592 L p F P
0 0 0 r
s
.38 .517 .691 r
.55186 .69385 m .53518 .69592 L .53522 .71129 L p F P
0 0 0 r
s
.69 .09 .12 r
.35688 .21197 m
.35179 .21281 L
s
.35688 .21197 m
.34593 .22255 L
s
.39129 .76688 m
.38678 .76822 L
s
.38721 .75803 m
.39129 .76688 L
s
.39129 .76688 m
.38193 .76458 L
s
.39207 .76165 m
.39129 .76688 L
s
.36959 .74784 m
.39129 .76688 L
s
.34593 .22255 m
.35611 .22477 L
s
.34593 .22255 m
.35179 .21281 L
s
.3992 .20142 m
.34593 .22255 L
s
.45661 .66091 m
.45923 .65767 L
s
.71573 .22211 m
.67022 .18996 L
s
.40023 .54334 m
.39603 .546 L
s
.40416 .54742 m
.40023 .54334 L
s
.06 .088 .13 r
.44878 .56436 m .44661 .57433 L .44698 .55958 L p F P
0 0 0 r
s
.06 .088 .13 r
.44698 .55958 m .44914 .54957 L .44878 .56436 L p F P
0 0 0 r
s
.69 .09 .12 r
.33851 .43937 m
.34303 .43973 L
s
.34365 .42944 m
.33851 .43937 L
s
.33851 .43937 m
.33766 .43216 L
s
.349 .43698 m
.33851 .43937 L
s
.36289 .41511 m
.33851 .43937 L
s
.53 .714 .909 r
.48549 .70567 m .50125 .70948 L .50136 .69409 L p F P
0 0 0 r
s
.53 .714 .909 r
.50136 .69409 m .48568 .69026 L .48549 .70567 L p F P
0 0 0 r
s
.336 .459 .619 r
.50813 .45685 m .49194 .46037 L .4921 .44614 L p F P
0 0 0 r
s
.336 .459 .619 r
.4921 .44614 m .50822 .44261 L .50813 .45685 L p F P
0 0 0 r
s
.69 .09 .12 r
.38721 .75803 m
.38193 .76458 L
s
.39207 .76165 m
.38721 .75803 L
s
.338 .478 .556 r
.60239 .54876 m .60486 .55875 L .60523 .5735 L p F P
0 0 0 r
s
.338 .478 .556 r
.60486 .55875 m .60239 .54876 L .60203 .5341 L p F P
0 0 0 r
s
.69 .09 .12 r
.33109 .6564 m
.32982 .65677 L
s
.33049 .64573 m
.33109 .6564 L
s
.33109 .6564 m
.32354 .65136 L
s
.33677 .65112 m
.33109 .6564 L
s
.32634 .63027 m
.33109 .6564 L
s
.39996 .55008 m
.40416 .54742 L
s
.38 .517 .691 r
.53522 .71129 m .55198 .70923 L .55186 .69385 L p F P
0 0 0 r
s
.327 .449 .611 r
.56742 .68987 m .55186 .69385 L .55198 .70923 L p F P
0 0 0 r
s
.546 .732 .922 r
.57331 .46542 m .55866 .45999 L .5585 .44577 L p F P
0 0 0 r
s
.497 .667 .854 r
.54228 .44242 m .5585 .44577 L .55866 .45999 L p F P
0 0 0 r
s
.69 .09 .12 r
.32366 .87363 m
.31646 .87629 L
s
.31742 .86048 m
.32366 .87363 L
s
.32366 .87363 m
.30943 .87041 L
s
.32448 .86632 m
.32366 .87363 L
s
.28954 .84692 m
.32366 .87363 L
s
.34365 .42944 m
.33766 .43216 L
s
.349 .43698 m
.34365 .42944 L
s
.38193 .76458 m
.38678 .76822 L
s
.27822 .32848 m
.2858 .32908 L
s
.28695 .31505 m
.27822 .32848 L
s
.27822 .32848 m
.27897 .31772 L
s
.29376 .32636 m
.27822 .32848 L
s
.31956 .29588 m
.27822 .32848 L
s
.09 .133 .211 r
.45496 .54002 m .44914 .54957 L .4495 .53492 L p F P
0 0 0 r
s
.09 .133 .211 r
.4495 .53492 m .4553 .52533 L .45496 .54002 L p F P
0 0 0 r
s
.69 .09 .12 r
.34303 .43973 m
.349 .43698 L
s
.39603 .546 m
.39996 .55008 L
s
.41015 .32726 m
.413 .33519 L
s
.27076 .54568 m
.27257 .54574 L
s
.27366 .53224 m
.27076 .54568 L
s
.27076 .54568 m
.26483 .53755 L
s
.28138 .54041 m
.27076 .54568 L
s
.28269 .51162 m
.27076 .54568 L
s
.603 .821 .995 r
.45192 .6538 m .4605 .66222 L .46081 .64703 L p F P
0 0 0 r
s
.603 .821 .995 r
.46081 .64703 m .45227 .63858 L .45192 .6538 L p F P
0 0 0 r
s
.69 .09 .12 r
.44838 .65034 m
.45872 .66046 L
s
.497 .683 .822 r
.59594 .52457 m .60203 .5341 L .60239 .54876 L p F P
0 0 0 r
s
.497 .683 .822 r
.60203 .5341 m .59594 .52457 L .59562 .51002 L p F P
0 0 0 r
s
.61 .824 1 r
.4602 .67754 m .47175 .68467 L .472 .66938 L p F P
0 0 0 r
s
.61 .824 1 r
.472 .66938 m .4605 .66222 L .4602 .67754 L p F P
0 0 0 r
s
.69 .09 .12 r
.4435 .88048 m
.44728 .872 L
s
.281 .388 .533 r
.49178 .47473 m .47722 .4803 L .47745 .46596 L p F P
0 0 0 r
s
.281 .388 .533 r
.47745 .46596 m .49194 .46037 L .49178 .47473 L p F P
0 0 0 r
s
.69 .09 .12 r
.2633 .76309 m
.25917 .76447 L
s
.26046 .74831 m
.2633 .76309 L
s
.2633 .76309 m
.25071 .75722 L
s
.26894 .75551 m
.2633 .76309 L
s
.24556 .72885 m
.2633 .76309 L
s
.28695 .31505 m
.27897 .31772 L
s
.29376 .32636 m
.28695 .31505 L
s
.33049 .64573 m
.32354 .65136 L
s
.33677 .65112 m
.33049 .64573 L
s
.68714 .76303 m
.71627 .74308 L
s
.222 .311 .441 r
.58092 .66885 m .5922 .66157 L .59189 .64638 L p F P
0 0 0 r
s
.158 .22 .329 r
.60017 .63784 m .59189 .64638 L .5922 .66157 L p F P
0 0 0 r
s
.158 .22 .329 r
.59189 .64638 m .60017 .63784 L .59982 .62275 L p F P
0 0 0 r
s
.69 .09 .12 r
.90391 .63822 m
.91673 .65066 L
s
.8935 .64665 m
.90391 .63822 L
s
.90391 .63822 m
.91245 .63916 L
s
.274 .382 .529 r
.56742 .68987 m .58118 .68414 L .58092 .66885 L p F P
0 0 0 r
s
.222 .311 .441 r
.5922 .66157 m .58092 .66885 L .58118 .68414 L p F P
0 0 0 r
s
.164 .227 .334 r
.46452 .51667 m .4553 .52533 L .45563 .51077 L p F P
0 0 0 r
s
.164 .227 .334 r
.45563 .51077 m .46481 .50208 L .46452 .51667 L p F P
0 0 0 r
s
.69 .09 .12 r
.2858 .32908 m
.29376 .32636 L
s
.491 .682 .818 r
.44706 .62924 m .45227 .63858 L .45261 .6235 L p F P
0 0 0 r
s
.491 .682 .818 r
.45261 .6235 m .44743 .61411 L .44706 .62924 L p F P
0 0 0 r
s
.585 .785 .972 r
.58589 .48697 m .57354 .47977 L .57331 .46542 L p F P
0 0 0 r
s
.546 .732 .922 r
.55866 .45999 m .57331 .46542 L .57354 .47977 L p F P
0 0 0 r
s
.391 .529 .701 r
.52523 .45559 m .50813 .45685 L .50822 .44261 L p F P
0 0 0 r
s
.391 .529 .701 r
.50822 .44261 m .52523 .44135 L .52523 .45559 L p F P
0 0 0 r
s
.225 .314 .442 r
.47699 .49477 m .46481 .50208 L .46509 .48763 L p F P
0 0 0 r
s
.225 .314 .442 r
.46509 .48763 m .47722 .4803 L .47699 .49477 L p F P
0 0 0 r
s
.69 .09 .12 r
.31742 .86048 m
.30943 .87041 L
s
.32448 .86632 m
.31742 .86048 L
s
.497 .667 .854 r
.55866 .45999 m .54236 .45666 L .54228 .44242 L p F P
0 0 0 r
s
.445 .599 .78 r
.52523 .44135 m .54228 .44242 L .54236 .45666 L p F P
0 0 0 r
s
.589 .795 .968 r
.58617 .50142 m .59562 .51002 L .59594 .52457 L p F P
0 0 0 r
s
.589 .795 .968 r
.59562 .51002 m .58617 .50142 L .58589 .48697 L p F P
0 0 0 r
s
.69 .09 .12 r
.21031 .43473 m
.21501 .43465 L
s
.21672 .41803 m
.21031 .43473 L
s
.21031 .43473 m
.20581 .42312 L
s
.22589 .42951 m
.21031 .43473 L
s
.23864 .39187 m
.21031 .43473 L
s
.092 .135 .215 r
.60472 .61331 m .59982 .62275 L .60017 .63784 L p F P
0 0 0 r
s
.092 .135 .215 r
.59982 .62275 m .60472 .61331 L .60435 .59832 L p F P
0 0 0 r
s
.585 .785 .972 r
.57354 .47977 m .58589 .48697 L .58617 .50142 L p F P
0 0 0 r
s
.576 .776 .973 r
.47149 .70011 m .48549 .70567 L .48568 .69026 L p F P
0 0 0 r
s
.576 .776 .973 r
.48568 .69026 m .47175 .68467 L .47149 .70011 L p F P
0 0 0 r
s
.69 .09 .12 r
.38678 .76822 m
.39207 .76165 L
s
.20281 .65232 m
.2016 .65291 L
s
.20338 .63508 m
.20281 .65232 L
s
.20281 .65232 m
.19167 .64342 L
s
.2133 .64452 m
.20281 .65232 L
s
.20118 .6097 m
.20281 .65232 L
s
.445 .599 .78 r
.54236 .45666 m .52523 .45559 L .52523 .44135 L p F P
0 0 0 r
s
.327 .449 .611 r
.55198 .70923 m .56761 .70528 L .56742 .68987 L p F P
0 0 0 r
s
.274 .382 .529 r
.58118 .68414 m .56742 .68987 L .56761 .70528 L p F P
0 0 0 r
s
.69 .09 .12 r
.68087 .4337 m
.66284 .41027 L
s
.30943 .87041 m
.31646 .87629 L
s
.27366 .53224 m
.26483 .53755 L
s
.28138 .54041 m
.27366 .53224 L
s
.335 .477 .554 r
.44586 .60425 m .44743 .61411 L .4478 .59913 L p F P
0 0 0 r
s
.335 .477 .554 r
.4478 .59913 m .44624 .58922 L .44586 .60425 L p F P
0 0 0 r
s
.69 .09 .12 r
.32354 .65136 m
.32982 .65677 L
s
.32982 .65677 m
.33677 .65112 L
s
.06 .089 .131 r
.6056 .58839 m .60435 .59832 L .60472 .61331 L p F P
0 0 0 r
s
.06 .089 .131 r
.60435 .59832 m .6056 .58839 L .60523 .5735 L p F P
0 0 0 r
s
.48 .649 .84 r
.50113 .72501 m .51803 .7269 L .51806 .71138 L p F P
0 0 0 r
s
.48 .649 .84 r
.51806 .71138 m .50125 .70948 L .50113 .72501 L p F P
0 0 0 r
s
.431 .583 .767 r
.53522 .71129 m .51806 .71138 L .51803 .7269 L p F P
0 0 0 r
s
.431 .583 .767 r
.51803 .7269 m .53526 .72681 L .53522 .71129 L p F P
0 0 0 r
s
.38 .517 .691 r
.55198 .70923 m .53522 .71129 L .53526 .72681 L p F P
0 0 0 r
s
.69 .09 .12 r
.35179 .21281 m
.35611 .22477 L
s
.33766 .43216 m
.34303 .43973 L
s
.91673 .65066 m
.90636 .65917 L
s
.91245 .63916 m
.91673 .65066 L
s
.14219 .54131 m
.14372 .54136 L
s
.1462 .52107 m
.14219 .54131 L
s
.14219 .54131 m
.13232 .52901 L
s
.15758 .53334 m
.14219 .54131 L
s
.15639 .48943 m
.14219 .54131 L
s
.26046 .74831 m
.25071 .75722 L
s
.26894 .75551 m
.26046 .74831 L
s
.88462 .75968 m
.92146 .71445 L
s
.84812 .52762 m
.85958 .5368 L
s
.83842 .53562 m
.84812 .52762 L
s
.84812 .52762 m
.85209 .52722 L
s
.21672 .41803 m
.20581 .42312 L
s
.22589 .42951 m
.21672 .41803 L
s
.27257 .54574 m
.28138 .54041 L
s
.06 .088 .13 r
.44841 .57929 m .44624 .58922 L .44661 .57433 L p F P
0 0 0 r
s
.06 .088 .13 r
.44661 .57433 m .44878 .56436 L .44841 .57929 L p F P
0 0 0 r
s
.53 .714 .909 r
.4853 .72122 m .50113 .72501 L .50125 .70948 L p F P
0 0 0 r
s
.53 .714 .909 r
.50125 .70948 m .48549 .70567 L .4853 .72122 L p F P
0 0 0 r
s
.336 .459 .619 r
.50805 .47122 m .49178 .47473 L .49194 .46037 L p F P
0 0 0 r
s
.336 .459 .619 r
.49194 .46037 m .50813 .45685 L .50805 .47122 L p F P
0 0 0 r
s
.338 .478 .556 r
.60275 .56355 m .60523 .5735 L .6056 .58839 L p F P
0 0 0 r
s
.338 .478 .556 r
.60523 .5735 m .60275 .56355 L .60239 .54876 L p F P
0 0 0 r
s
.38 .517 .691 r
.53526 .72681 m .5521 .72476 L .55198 .70923 L p F P
0 0 0 r
s
.327 .449 .611 r
.56761 .70528 m .55198 .70923 L .5521 .72476 L p F P
0 0 0 r
s
.546 .732 .922 r
.57354 .47977 m .55881 .47435 L .55866 .45999 L p F P
0 0 0 r
s
.497 .667 .854 r
.54236 .45666 m .55866 .45999 L .55881 .47435 L p F P
0 0 0 r
s
.69 .09 .12 r
.83544 .74475 m
.84523 .75656 L
s
.82732 .75132 m
.83544 .74475 L
s
.83544 .74475 m
.84481 .74698 L
s
.21501 .43465 m
.22589 .42951 L
s
.20338 .63508 m
.19167 .64342 L
s
.2133 .64452 m
.20338 .63508 L
s
.09 .133 .211 r
.45463 .55485 m .44878 .56436 L .44914 .54957 L p F P
0 0 0 r
s
.09 .133 .211 r
.44914 .54957 m .45496 .54002 L .45463 .55485 L p F P
0 0 0 r
s
.69 .09 .12 r
.25071 .75722 m
.25917 .76447 L
s
.31646 .87629 m
.32448 .86632 L
s
.26483 .53755 m
.27257 .54574 L
s
.603 .821 .995 r
.45157 .66917 m .4602 .67754 L .4605 .66222 L p F P
0 0 0 r
s
.603 .821 .995 r
.4605 .66222 m .45192 .6538 L .45157 .66917 L p F P
0 0 0 r
s
.497 .683 .822 r
.59627 .53926 m .60239 .54876 L .60275 .56355 L p F P
0 0 0 r
s
.497 .683 .822 r
.60239 .54876 m .59627 .53926 L .59594 .52457 L p F P
0 0 0 r
s
.69 .09 .12 r
.84523 .75656 m
.83715 .76319 L
s
.84481 .74698 m
.84523 .75656 L
s
.79204 .41609 m
.80213 .42232 L
s
.78324 .42441 m
.79204 .41609 L
s
.79204 .41609 m
.79159 .41504 L
s
.61 .824 1 r
.45989 .69302 m .47149 .70011 L .47175 .68467 L p F P
0 0 0 r
s
.61 .824 1 r
.47175 .68467 m .4602 .67754 L .45989 .69302 L p F P
0 0 0 r
s
.69 .09 .12 r
.64577 .64673 m
.65545 .63079 L
s
.90636 .65917 m
.8935 .64665 L
s
.8935 .64665 m
.91245 .63916 L
s
.281 .388 .533 r
.49162 .48922 m .47699 .49477 L .47722 .4803 L p F P
0 0 0 r
s
.281 .388 .533 r
.47722 .4803 m .49178 .47473 L .49162 .48922 L p F P
0 0 0 r
s
.69 .09 .12 r
.27897 .31772 m
.2858 .32908 L
s
.222 .311 .441 r
.58118 .68414 m .59251 .6769 L .5922 .66157 L p F P
0 0 0 r
s
.158 .22 .329 r
.60052 .65307 m .5922 .66157 L .59251 .6769 L p F P
0 0 0 r
s
.158 .22 .329 r
.5922 .66157 m .60052 .65307 L .60017 .63784 L p F P
0 0 0 r
s
.69 .09 .12 r
.85958 .5368 m
.84989 .54485 L
s
.85209 .52722 m
.85958 .5368 L
s
.1462 .52107 m
.13232 .52901 L
s
.15758 .53334 m
.1462 .52107 L
s
.274 .382 .529 r
.56761 .70528 m .58144 .69958 L .58118 .68414 L p F P
0 0 0 r
s
.222 .311 .441 r
.59251 .6769 m .58118 .68414 L .58144 .69958 L p F P
0 0 0 r
s
.164 .227 .334 r
.46423 .53139 m .45496 .54002 L .4553 .52533 L p F P
0 0 0 r
s
.164 .227 .334 r
.4553 .52533 m .46452 .51667 L .46423 .53139 L p F P
0 0 0 r
s
.491 .682 .818 r
.44669 .64451 m .45192 .6538 L .45227 .63858 L p F P
0 0 0 r
s
.491 .682 .818 r
.45227 .63858 m .44706 .62924 L .44669 .64451 L p F P
0 0 0 r
s
.585 .785 .972 r
.58617 .50142 m .57376 .49424 L .57354 .47977 L p F P
0 0 0 r
s
.546 .732 .922 r
.55881 .47435 m .57354 .47977 L .57376 .49424 L p F P
0 0 0 r
s
.391 .529 .701 r
.52522 .46996 m .50805 .47122 L .50813 .45685 L p F P
0 0 0 r
s
.391 .529 .701 r
.50813 .45685 m .52523 .45559 L .52522 .46996 L p F P
0 0 0 r
s
.69 .09 .12 r
.25917 .76447 m
.26894 .75551 L
s
.225 .314 .442 r
.47676 .50938 m .46452 .51667 L .46481 .50208 L p F P
0 0 0 r
s
.225 .314 .442 r
.46481 .50208 m .47699 .49477 L .47676 .50938 L p F P
0 0 0 r
s
.497 .667 .854 r
.55881 .47435 m .54243 .47103 L .54236 .45666 L p F P
0 0 0 r
s
.445 .599 .78 r
.52523 .45559 m .54236 .45666 L .54243 .47103 L p F P
0 0 0 r
s
.589 .795 .968 r
.58646 .51601 m .59594 .52457 L .59627 .53926 L p F P
0 0 0 r
s
.589 .795 .968 r
.59594 .52457 m .58646 .51601 L .58617 .50142 L p F P
0 0 0 r
s
.092 .135 .215 r
.60509 .62844 m .60017 .63784 L .60052 .65307 L p F P
0 0 0 r
s
.092 .135 .215 r
.60017 .63784 m .60509 .62844 L .60472 .61331 L p F P
0 0 0 r
s
.69 .09 .12 r
.84989 .54485 m
.83842 .53562 L
s
.83842 .53562 m
.85209 .52722 L
s
.585 .785 .972 r
.57376 .49424 m .58617 .50142 L .58646 .51601 L p F P
0 0 0 r
s
.576 .776 .973 r
.47124 .71569 m .4853 .72122 L .48549 .70567 L p F P
0 0 0 r
s
.576 .776 .973 r
.48549 .70567 m .47149 .70011 L .47124 .71569 L p F P
0 0 0 r
s
.69 .09 .12 r
.63942 .31577 m
.60192 .29756 L
s
.77934 .63438 m
.78776 .64271 L
s
.772 .64001 m
.77934 .63438 L
s
.77934 .63438 m
.78428 .63499 L
s
.445 .599 .78 r
.54243 .47103 m .52522 .46996 L .52523 .45559 L p F P
0 0 0 r
s
.327 .449 .611 r
.5521 .72476 m .56781 .72083 L .56761 .70528 L p F P
0 0 0 r
s
.274 .382 .529 r
.58144 .69958 m .56761 .70528 L .56781 .72083 L p F P
0 0 0 r
s
.69 .09 .12 r
.2016 .65291 m
.2133 .64452 L
s
.335 .477 .554 r
.44548 .61942 m .44706 .62924 L .44743 .61411 L p F P
0 0 0 r
s
.335 .477 .554 r
.44743 .61411 m .44586 .60425 L .44548 .61942 L p F P
0 0 0 r
s
.69 .09 .12 r
.79333 .43067 m
.78324 .42441 L
s
.78324 .42441 m
.79159 .41504 L
s
.73568 .30346 m
.74437 .30723 L
s
.72797 .313 m
.73568 .30346 L
s
.73568 .30346 m
.73097 .30262 L
s
.06 .089 .131 r
.60598 .60343 m .60472 .61331 L .60509 .62844 L p F P
0 0 0 r
s
.06 .089 .131 r
.60472 .61331 m .60598 .60343 L .6056 .58839 L p F P
0 0 0 r
s
.48 .649 .84 r
.50101 .74068 m .51799 .74256 L .51803 .7269 L p F P
0 0 0 r
s
.48 .649 .84 r
.51803 .7269 m .50113 .72501 L .50101 .74068 L p F P
0 0 0 r
s
.431 .583 .767 r
.53526 .72681 m .51803 .7269 L .51799 .74256 L p F P
0 0 0 r
s
.69 .09 .12 r
.76648 .85148 m
.77341 .86295 L
s
.7607 .85669 m
.76648 .85148 L
s
.76648 .85148 m
.77696 .85513 L
s
.431 .583 .767 r
.51799 .74256 m .53531 .74248 L .53526 .72681 L p F P
0 0 0 r
s
.38 .517 .691 r
.5521 .72476 m .53526 .72681 L .53531 .74248 L p F P
0 0 0 r
s
.69 .09 .12 r
.91245 .63916 m
.90636 .65917 L
s
.19167 .64342 m
.2016 .65291 L
s
.77341 .86295 m
.76765 .86821 L
s
.77696 .85513 m
.77341 .86295 L
s
.14372 .54136 m
.15758 .53334 L
s
.84405 .6431 m
.8597 .59998 L
s
.20581 .42312 m
.21501 .43465 L
s
.78776 .64271 m
.78044 .64838 L
s
.78428 .63499 m
.78776 .64271 L
s
.73664 .31681 m
.72797 .313 L
s
.72797 .313 m
.73097 .30262 L
s
.06 .088 .13 r
.44805 .59436 m .44586 .60425 L .44624 .58922 L p F P
0 0 0 r
s
.06 .088 .13 r
.44624 .58922 m .44841 .57929 L .44805 .59436 L p F P
0 0 0 r
s
.69 .09 .12 r
.80213 .42232 m
.79333 .43067 L
s
.79159 .41504 m
.80213 .42232 L
s
.53 .714 .909 r
.48511 .73692 m .50101 .74068 L .50113 .72501 L p F P
0 0 0 r
s
.53 .714 .909 r
.50113 .72501 m .4853 .72122 L .48511 .73692 L p F P
0 0 0 r
s
.336 .459 .619 r
.50796 .48572 m .49162 .48922 L .49178 .47473 L p F P
0 0 0 r
s
.336 .459 .619 r
.49178 .47473 m .50805 .47122 L .50796 .48572 L p F P
0 0 0 r
s
.338 .478 .556 r
.60312 .57849 m .6056 .58839 L .60598 .60343 L p F P
0 0 0 r
s
.338 .478 .556 r
.6056 .58839 m .60312 .57849 L .60275 .56355 L p F P
0 0 0 r
s
.69 .09 .12 r
.85209 .52722 m
.84989 .54485 L
s
.83715 .76319 m
.82732 .75132 L
s
.82732 .75132 m
.84481 .74698 L
s
.38 .517 .691 r
.53531 .74248 m .55223 .74044 L .5521 .72476 L p F P
0 0 0 r
s
.327 .449 .611 r
.56781 .72083 m .5521 .72476 L .55223 .74044 L p F P
0 0 0 r
s
.69 .09 .12 r
.67907 .18972 m
.6863 .19151 L
s
.67261 .20141 m
.67907 .18972 L
s
.67907 .18972 m
.67022 .18996 L
s
.72295 .52304 m
.72999 .52825 L
s
.71658 .52852 m
.72295 .52304 L
s
.72295 .52304 m
.72363 .52275 L
s
.61043 .86121 m
.64805 .85151 L
s
.67981 .20326 m
.67261 .20141 L
s
.67261 .20141 m
.67022 .18996 L
s
.546 .732 .922 r
.57376 .49424 m .55897 .48885 L .55881 .47435 L p F P
0 0 0 r
s
.497 .667 .854 r
.54243 .47103 m .55881 .47435 L .55897 .48885 L p F P
0 0 0 r
s
.09 .133 .211 r
.45429 .56982 m .44841 .57929 L .44878 .56436 L p F P
0 0 0 r
s
.09 .133 .211 r
.44878 .56436 m .45463 .55485 L .45429 .56982 L p F P
0 0 0 r
s
.69 .09 .12 r
.78044 .64838 m
.772 .64001 L
s
.772 .64001 m
.78428 .63499 L
s
.84481 .74698 m
.83715 .76319 L
s
.71007 .74139 m
.71561 .74912 L
s
.70514 .7451 m
.71007 .74139 L
s
.71007 .74139 m
.71627 .74308 L
s
.603 .821 .995 r
.45122 .68469 m .45989 .69302 L .4602 .67754 L p F P
0 0 0 r
s
.603 .821 .995 r
.4602 .67754 m .45157 .66917 L .45122 .68469 L p F P
0 0 0 r
s
.497 .683 .822 r
.59661 .5541 m .60275 .56355 L .60312 .57849 L p F P
0 0 0 r
s
.497 .683 .822 r
.60275 .56355 m .59661 .5541 L .59627 .53926 L p F P
0 0 0 r
s
.61 .824 1 r
.45957 .70864 m .47124 .71569 L .47149 .70011 L p F P
0 0 0 r
s
.61 .824 1 r
.47149 .70011 m .45989 .69302 L .45957 .70864 L p F P
0 0 0 r
s
.69 .09 .12 r
.79159 .41504 m
.79333 .43067 L
s
.13232 .52901 m
.14372 .54136 L
s
.281 .388 .533 r
.49145 .50385 m .47676 .50938 L .47699 .49477 L p F P
0 0 0 r
s
.281 .388 .533 r
.47699 .49477 m .49162 .48922 L .49145 .50385 L p F P
0 0 0 r
s
.69 .09 .12 r
.71561 .74912 m
.7107 .75286 L
s
.71627 .74308 m
.71561 .74912 L
s
.222 .311 .441 r
.58144 .69958 m .59282 .69237 L .59251 .6769 L p F P
0 0 0 r
s
.158 .22 .329 r
.60087 .66844 m .59251 .6769 L .59282 .69237 L p F P
0 0 0 r
s
.158 .22 .329 r
.59251 .6769 m .60087 .66844 L .60052 .65307 L p F P
0 0 0 r
s
.274 .382 .529 r
.56781 .72083 m .5817 .71516 L .58144 .69958 L p F P
0 0 0 r
s
.222 .311 .441 r
.59282 .69237 m .58144 .69958 L .5817 .71516 L p F P
0 0 0 r
s
.164 .227 .334 r
.46393 .54625 m .45463 .55485 L .45496 .54002 L p F P
0 0 0 r
s
.164 .227 .334 r
.45496 .54002 m .46423 .53139 L .46393 .54625 L p F P
0 0 0 r
s
.69 .09 .12 r
.72362 .53375 m
.71658 .52852 L
s
.71658 .52852 m
.72363 .52275 L
s
.491 .682 .818 r
.44631 .65992 m .45157 .66917 L .45192 .6538 L p F P
0 0 0 r
s
.491 .682 .818 r
.45192 .6538 m .44669 .64451 L .44631 .65992 L p F P
0 0 0 r
s
.585 .785 .972 r
.58646 .51601 m .57399 .50886 L .57376 .49424 L p F P
0 0 0 r
s
.546 .732 .922 r
.55897 .48885 m .57376 .49424 L .57399 .50886 L p F P
0 0 0 r
s
.69 .09 .12 r
.72999 .52825 m
.72362 .53375 L
s
.72363 .52275 m
.72999 .52825 L
s
.391 .529 .701 r
.52522 .48447 m .50796 .48572 L .50805 .47122 L p F P
0 0 0 r
s
.391 .529 .701 r
.50805 .47122 m .52522 .46996 L .52522 .48447 L p F P
0 0 0 r
s
.225 .314 .442 r
.47653 .52413 m .46423 .53139 L .46452 .51667 L p F P
0 0 0 r
s
.225 .314 .442 r
.46452 .51667 m .47676 .50938 L .47653 .52413 L p F P
0 0 0 r
s
.497 .667 .854 r
.55897 .48885 m .54251 .48553 L .54243 .47103 L p F P
0 0 0 r
s
.445 .599 .78 r
.52522 .46996 m .54243 .47103 L .54251 .48553 L p F P
0 0 0 r
s
.69 .09 .12 r
.66627 .41039 m
.6719 .41318 L
s
.66108 .41683 m
.66627 .41039 L
s
.66627 .41039 m
.66284 .41027 L
s
.589 .795 .968 r
.58674 .53074 m .59627 .53926 L .59661 .5541 L p F P
0 0 0 r
s
.589 .795 .968 r
.59627 .53926 m .58674 .53074 L .58646 .51601 L p F P
0 0 0 r
s
.69 .09 .12 r
.59449 .51826 m
.60402 .52937 L
s
.78428 .63499 m
.78044 .64838 L
s
.092 .135 .215 r
.60546 .64371 m .60052 .65307 L .60087 .66844 L p F P
0 0 0 r
s
.092 .135 .215 r
.60052 .65307 m .60546 .64371 L .60509 .62844 L p F P
0 0 0 r
s
.69 .09 .12 r
.74437 .30723 m
.73664 .31681 L
s
.73097 .30262 m
.74437 .30723 L
s
.5976 .19677 m
.54087 .1846 L
s
.80931 .85806 m
.85225 .82491 L
s
.585 .785 .972 r
.57399 .50886 m .58646 .51601 L .58674 .53074 L p F P
0 0 0 r
s
.576 .776 .973 r
.47098 .73142 m .48511 .73692 L .4853 .72122 L p F P
0 0 0 r
s
.576 .776 .973 r
.4853 .72122 m .47124 .71569 L .47098 .73142 L p F P
0 0 0 r
s
.69 .09 .12 r
.6667 .41964 m
.66108 .41683 L
s
.66108 .41683 m
.66284 .41027 L
s
.445 .599 .78 r
.54251 .48553 m .52522 .48447 L .52522 .46996 L p F P
0 0 0 r
s
.327 .449 .611 r
.55223 .74044 m .56801 .73653 L .56781 .72083 L p F P
0 0 0 r
s
.274 .382 .529 r
.5817 .71516 m .56781 .72083 L .56801 .73653 L p F P
0 0 0 r
s
.335 .477 .554 r
.4451 .63473 m .44669 .64451 L .44706 .62924 L p F P
0 0 0 r
s
.335 .477 .554 r
.44706 .62924 m .44548 .61942 L .4451 .63473 L p F P
0 0 0 r
s
.69 .09 .12 r
.73097 .30262 m
.73664 .31681 L
s
.06 .089 .131 r
.60636 .6186 m .60509 .62844 L .60546 .64371 L p F P
0 0 0 r
s
.06 .089 .131 r
.60509 .62844 m .60636 .6186 L .60598 .60343 L p F P
0 0 0 r
s
.69 .09 .12 r
.76765 .86821 m
.7607 .85669 L
s
.7607 .85669 m
.77696 .85513 L
s
.48 .649 .84 r
.50089 .75651 m .51795 .75838 L .51799 .74256 L p F P
0 0 0 r
s
.48 .649 .84 r
.51799 .74256 m .50101 .74068 L .50089 .75651 L p F P
0 0 0 r
s
.431 .583 .767 r
.53531 .74248 m .51799 .74256 L .51795 .75838 L p F P
0 0 0 r
s
.431 .583 .767 r
.51795 .75838 m .53535 .7583 L .53531 .74248 L p F P
0 0 0 r
s
.38 .517 .691 r
.55223 .74044 m .53531 .74248 L .53535 .7583 L p F P
0 0 0 r
s
.69 .09 .12 r
.60962 .30622 m
.60547 .30496 L
s
.60547 .30496 m
.60933 .29626 L
s
.60547 .30496 m
.60192 .29756 L
s
.80311 .52546 m
.7978 .48526 L
s
.72363 .52275 m
.72362 .53375 L
s
.77696 .85513 m
.76765 .86821 L
s
.65336 .6305 m
.65751 .63468 L
s
.64948 .63332 m
.65336 .6305 L
s
.65336 .6305 m
.65545 .63079 L
s
.60933 .29626 m
.6135 .29748 L
s
.60933 .29626 m
.60192 .29756 L
s
.64313 .85603 m
.64066 .85878 L
s
.64031 .84816 m
.64313 .85603 L
s
.64805 .85151 m
.64313 .85603 L
s
.63783 .85089 m
.64031 .84816 L
s
.64031 .84816 m
.64805 .85151 L
s
.06 .088 .13 r
.44767 .60958 m .44548 .61942 L .44586 .60425 L p F P
0 0 0 r
s
.06 .088 .13 r
.44586 .60425 m .44805 .59436 L .44767 .60958 L p F P
0 0 0 r
s
.69 .09 .12 r
.65751 .63468 m
.65364 .63752 L
s
.65545 .63079 m
.65751 .63468 L
s
.7107 .75286 m
.70514 .7451 L
s
.70514 .7451 m
.71627 .74308 L
s
.55233 .19312 m
.54978 .1929 L
s
.54978 .1929 m
.55221 .181 L
s
.54978 .1929 m
.54087 .1846 L
s
.6719 .41318 m
.6667 .41964 L
s
.66284 .41027 m
.6719 .41318 L
s
.71627 .74308 m
.7107 .75286 L
s
.53 .714 .909 r
.48491 .75277 m .50089 .75651 L .50101 .74068 L p F P
0 0 0 r
s
.53 .714 .909 r
.50101 .74068 m .48511 .73692 L .48491 .75277 L p F P
0 0 0 r
s
.336 .459 .619 r
.50788 .50037 m .49145 .50385 L .49162 .48922 L p F P
0 0 0 r
s
.336 .459 .619 r
.49162 .48922 m .50796 .48572 L .50788 .50037 L p F P
0 0 0 r
s
.338 .478 .556 r
.60348 .59356 m .60598 .60343 L .60636 .6186 L p F P
0 0 0 r
s
.338 .478 .556 r
.60598 .60343 m .60348 .59356 L .60312 .57849 L p F P
0 0 0 r
s
.38 .517 .691 r
.53535 .7583 m .55235 .75627 L .55223 .74044 L p F P
0 0 0 r
s
.327 .449 .611 r
.56801 .73653 m .55223 .74044 L .55235 .75627 L p F P
0 0 0 r
s
.546 .732 .922 r
.57399 .50886 m .55912 .50348 L .55897 .48885 L p F P
0 0 0 r
s
.497 .667 .854 r
.54251 .48553 m .55897 .48885 L .55912 .50348 L p F P
0 0 0 r
s
.69 .09 .12 r
.55221 .181 m
.55478 .18116 L
s
.55221 .181 m
.54087 .1846 L
s
.6863 .19151 m
.67981 .20326 L
s
.67022 .18996 m
.6863 .19151 L
s
.67022 .18996 m
.67981 .20326 L
s
.65364 .63752 m
.64948 .63332 L
s
.64948 .63332 m
.65545 .63079 L
s
.66284 .41027 m
.6667 .41964 L
s
.09 .133 .211 r
.45395 .58493 m .44805 .59436 L .44841 .57929 L p F P
0 0 0 r
s
.09 .133 .211 r
.44841 .57929 m .45429 .56982 L .45395 .58493 L p F P
0 0 0 r
s
.69 .09 .12 r
.59635 .51809 m
.59909 .51963 L
s
.59373 .52135 m
.59635 .51809 L
s
.59449 .51826 m
.59635 .51809 L
s
.65545 .63079 m
.65364 .63752 L
s
.56189 .41093 m
.53341 .40548 L
s
.603 .821 .995 r
.45086 .70035 m .45957 .70864 L .45989 .69302 L p F P
0 0 0 r
s
.603 .821 .995 r
.45989 .69302 m .45122 .68469 L .45086 .70035 L p F P
0 0 0 r
s
.69 .09 .12 r
.59373 .52135 m
.59646 .52289 L
s
.59373 .52135 m
.59449 .51826 L
s
.497 .683 .822 r
.59694 .56907 m .60312 .57849 L .60348 .59356 L p F P
0 0 0 r
s
.497 .683 .822 r
.60312 .57849 m .59694 .56907 L .59661 .5541 L p F P
0 0 0 r
s
.61 .824 1 r
.45925 .7244 m .47098 .73142 L .47124 .71569 L p F P
0 0 0 r
s
.61 .824 1 r
.47124 .71569 m .45957 .70864 L .45925 .7244 L p F P
0 0 0 r
s
.281 .388 .533 r
.49129 .51862 m .47653 .52413 L .47676 .50938 L p F P
0 0 0 r
s
.281 .388 .533 r
.47676 .50938 m .49145 .50385 L .49129 .51862 L p F P
0 0 0 r
s
.222 .311 .441 r
.5817 .71516 m .59314 .70799 L .59282 .69237 L p F P
0 0 0 r
s
.158 .22 .329 r
.60123 .68396 m .59282 .69237 L .59314 .70799 L p F P
0 0 0 r
s
.158 .22 .329 r
.59282 .69237 m .60123 .68396 L .60087 .66844 L p F P
0 0 0 r
s
.274 .382 .529 r
.56801 .73653 m .58197 .73089 L .5817 .71516 L p F P
0 0 0 r
s
.222 .311 .441 r
.59314 .70799 m .5817 .71516 L .58197 .73089 L p F P
0 0 0 r
s
.164 .227 .334 r
.46364 .56126 m .45429 .56982 L .45463 .55485 L p F P
0 0 0 r
s
.164 .227 .334 r
.45463 .55485 m .46393 .54625 L .46364 .56126 L p F P
0 0 0 r
s
.491 .682 .818 r
.44593 .67548 m .45122 .68469 L .45157 .66917 L p F P
0 0 0 r
s
.491 .682 .818 r
.45157 .66917 m .44631 .65992 L .44593 .67548 L p F P
0 0 0 r
s
.585 .785 .972 r
.58674 .53074 m .57422 .52361 L .57399 .50886 L p F P
0 0 0 r
s
.546 .732 .922 r
.55912 .50348 m .57399 .50886 L .57422 .52361 L p F P
0 0 0 r
s
.69 .09 .12 r
.58469 .74161 m
.58336 .74279 L
s
.58327 .73765 m
.58469 .74161 L
s
.58706 .73916 m
.58469 .74161 L
s
.391 .529 .701 r
.52522 .49912 m .50788 .50037 L .50796 .48572 L p F P
0 0 0 r
s
.391 .529 .701 r
.50796 .48572 m .52522 .48447 L .52522 .49912 L p F P
0 0 0 r
s
.69 .09 .12 r
.58327 .73765 m
.58706 .73916 L
s
.225 .314 .442 r
.47629 .53903 m .46393 .54625 L .46423 .53139 L p F P
0 0 0 r
s
.225 .314 .442 r
.46423 .53139 m .47653 .52413 L .47629 .53903 L p F P
0 0 0 r
s
.69 .09 .12 r
.53913 .40985 m
.53789 .40919 L
s
.53789 .40919 m
.5391 .4033 L
s
.53789 .40919 m
.53341 .40548 L
s
.497 .667 .854 r
.55912 .50348 m .54259 .50018 L .54251 .48553 L p F P
0 0 0 r
s
.445 .599 .78 r
.52522 .48447 m .54251 .48553 L .54259 .50018 L p F P
0 0 0 r
s
.589 .795 .968 r
.58703 .5456 m .59661 .5541 L .59694 .56907 L p F P
0 0 0 r
s
.589 .795 .968 r
.59661 .5541 m .58703 .5456 L .58674 .53074 L p F P
0 0 0 r
s
.69 .09 .12 r
.59909 .51963 m
.59646 .52289 L
s
.59449 .51826 m
.59909 .51963 L
s
.76807 .74099 m
.79032 .71038 L
s
.092 .135 .215 r
.60584 .65913 m .60087 .66844 L .60123 .68396 L p F P
0 0 0 r
s
.092 .135 .215 r
.60087 .66844 m .60584 .65913 L .60546 .64371 L p F P
0 0 0 r
s
.69 .09 .12 r
.6135 .29748 m
.60962 .30622 L
s
.60192 .29756 m
.60962 .30622 L
s
.5391 .4033 m
.54035 .40395 L
s
.5391 .4033 m
.53341 .40548 L
s
.64805 .85151 m
.64066 .85878 L
s
.63783 .85089 m
.64805 .85151 L
s
.585 .785 .972 r
.57422 .52361 m .58674 .53074 L .58703 .5456 L p F P
0 0 0 r
s
.576 .776 .973 r
.47071 .7473 m .48491 .75277 L .48511 .73692 L p F P
0 0 0 r
s
.576 .776 .973 r
.48511 .73692 m .47098 .73142 L .47071 .7473 L p F P
0 0 0 r
s
.69 .09 .12 r
.59449 .51826 m
.59646 .52289 L
s
.64066 .85878 m
.63783 .85089 L
s
.60192 .29756 m
.6135 .29748 L
s
.445 .599 .78 r
.54259 .50018 m .52522 .49912 L .52522 .48447 L p F P
0 0 0 r
s
.327 .449 .611 r
.55235 .75627 m .56821 .75238 L .56801 .73653 L p F P
0 0 0 r
s
.274 .382 .529 r
.58197 .73089 m .56801 .73653 L .56821 .75238 L p F P
0 0 0 r
s
.69 .09 .12 r
.58193 .73882 m
.58327 .73765 L
s
.57439 .74273 m
.58706 .73916 L
s
.335 .477 .554 r
.44471 .6502 m .44631 .65992 L .44669 .64451 L p F P
0 0 0 r
s
.335 .477 .554 r
.44669 .64451 m .4451 .63473 L .44471 .6502 L p F P
0 0 0 r
s
.69 .09 .12 r
.48155 .29725 m
.48195 .29685 L
s
.48195 .29685 m
.4817 .28728 L
s
.48195 .29685 m
.47219 .29246 L
s
.7618 .40673 m
.73577 .37029 L
s
.06 .089 .131 r
.60674 .63392 m .60546 .64371 L .60584 .65913 L p F P
0 0 0 r
s
.06 .089 .131 r
.60546 .64371 m .60674 .63392 L .60636 .6186 L p F P
0 0 0 r
s
.48 .649 .84 r
.50077 .77249 m .51791 .77434 L .51795 .75838 L p F P
0 0 0 r
s
.48 .649 .84 r
.51795 .75838 m .50089 .75651 L .50077 .77249 L p F P
0 0 0 r
s
.431 .583 .767 r
.53535 .7583 m .51795 .75838 L .51791 .77434 L p F P
0 0 0 r
s
.431 .583 .767 r
.51791 .77434 m .5354 .77426 L .53535 .7583 L p F P
0 0 0 r
s
.38 .517 .691 r
.55235 .75627 m .53535 .7583 L .5354 .77426 L p F P
0 0 0 r
s
.69 .09 .12 r
.58706 .73916 m
.58336 .74279 L
s
.58193 .73882 m
.58706 .73916 L
s
.4817 .28728 m
.4813 .28764 L
s
.4817 .28728 m
.47219 .29246 L
s
.58193 .73882 m
.58336 .74279 L
s
.54087 .1846 m
.55233 .19312 L
s
.54087 .1846 m
.55478 .18116 L
s
.42367 .18433 m
.42592 .18431 L
s
.42592 .18431 m
.42417 .17076 L
s
.42592 .18431 m
.41085 .1792 L
s
.53341 .40548 m
.53913 .40985 L
s
.53341 .40548 m
.54035 .40395 L
s
.51153 .84903 m
.51271 .8508 L
s
.51274 .84328 m
.51153 .84903 L
s
.51846 .84787 m
.51153 .84903 L
s
.06 .088 .13 r
.4473 .62494 m .4451 .63473 L .44548 .61942 L p F P
0 0 0 r
s
.06 .088 .13 r
.44548 .61942 m .44767 .60958 L .4473 .62494 L p F P
0 0 0 r
s
.69 .09 .12 r
.51393 .84503 m
.51274 .84328 L
s
.51274 .84328 m
.51846 .84787 L
s
.54035 .40395 m
.53913 .40985 L
s
.42417 .17076 m
.42192 .1707 L
s
.42417 .17076 m
.41085 .1792 L
s
.55478 .18116 m
.55233 .19312 L
s
.53 .714 .909 r
.48472 .76877 m .50077 .77249 L .50089 .75651 L p F P
0 0 0 r
s
.53 .714 .909 r
.50089 .75651 m .48491 .75277 L .48472 .76877 L p F P
0 0 0 r
s
.336 .459 .619 r
.50779 .51515 m .49129 .51862 L .49145 .50385 L p F P
0 0 0 r
s
.336 .459 .619 r
.49145 .50385 m .50788 .50037 L .50779 .51515 L p F P
0 0 0 r
s
.338 .478 .556 r
.60385 .60878 m .60636 .6186 L .60674 .63392 L p F P
0 0 0 r
s
.338 .478 .556 r
.60636 .6186 m .60385 .60878 L .60348 .59356 L p F P
0 0 0 r
s
.38 .517 .691 r
.5354 .77426 m .55248 .77225 L .55235 .75627 L p F P
0 0 0 r
s
.327 .449 .611 r
.56821 .75238 m .55235 .75627 L .55248 .77225 L p F P
0 0 0 r
s
.546 .732 .922 r
.57422 .52361 m .55928 .51826 L .55912 .50348 L p F P
0 0 0 r
s
.497 .667 .854 r
.54259 .50018 m .55912 .50348 L .55928 .51826 L p F P
0 0 0 r
s
.69 .09 .12 r
.51846 .84787 m
.51271 .8508 L
s
.51393 .84503 m
.51846 .84787 L
s
.48974 .8437 m
.51846 .84787 L
s
.47219 .29246 m
.48155 .29725 L
s
.47219 .29246 m
.4813 .28764 L
s
.51937 .29141 m
.47219 .29246 L
s
.46831 .51493 m
.46985 .51413 L
s
.4684 .51012 m
.46985 .51413 L
s
.46469 .51374 m
.46985 .51413 L
s
.09 .133 .211 r
.4536 .60019 m .44767 .60958 L .44805 .59436 L p F P
0 0 0 r
s
.09 .133 .211 r
.44805 .59436 m .45395 .58493 L .4536 .60019 L p F P
0 0 0 r
s
.69 .09 .12 r
.46687 .51091 m
.4684 .51012 L
s
.46469 .51374 m
.4684 .51012 L
s
.46469 .51374 m
.46831 .51493 L
s
.46469 .51374 m
.46687 .51091 L
s
.46469 .51374 m
.48311 .50763 L
s
.603 .821 .995 r
.4505 .71617 m .45925 .7244 L .45957 .70864 L p F P
0 0 0 r
s
.603 .821 .995 r
.45957 .70864 m .45086 .70035 L .4505 .71617 L p F P
0 0 0 r
s
.497 .683 .822 r
.59728 .58418 m .60348 .59356 L .60385 .60878 L p F P
0 0 0 r
s
.497 .683 .822 r
.60348 .59356 m .59728 .58418 L .59694 .56907 L p F P
0 0 0 r
s
.61 .824 1 r
.45893 .74032 m .47071 .7473 L .47098 .73142 L p F P
0 0 0 r
s
.61 .824 1 r
.47098 .73142 m .45925 .7244 L .45893 .74032 L p F P
0 0 0 r
s
.69 .09 .12 r
.45717 .73522 m
.45501 .73584 L
s
.45512 .73068 m
.45717 .73522 L
s
.45717 .73522 m
.45244 .73402 L
s
.45769 .7325 m
.45717 .73522 L
s
.41085 .1792 m
.42367 .18433 L
s
.41085 .1792 m
.42192 .1707 L
s
.47646 .17078 m
.41085 .1792 L
s
.4104 .40271 m
.41367 .40149 L
s
.41367 .40149 m
.41075 .39343 L
s
.41367 .40149 m
.4033 .40066 L
s
.281 .388 .533 r
.49112 .53354 m .47629 .53903 L .47653 .52413 L p F P
0 0 0 r
s
.281 .388 .533 r
.47653 .52413 m .49129 .51862 L .49112 .53354 L p F P
0 0 0 r
s
.222 .311 .441 r
.58197 .73089 m .59346 .72377 L .59314 .70799 L p F P
0 0 0 r
s
.158 .22 .329 r
.60159 .69963 m .59314 .70799 L .59346 .72377 L p F P
0 0 0 r
s
.158 .22 .329 r
.59314 .70799 m .60159 .69963 L .60123 .68396 L p F P
0 0 0 r
s
.274 .382 .529 r
.56821 .75238 m .58223 .74678 L .58197 .73089 L p F P
0 0 0 r
s
.222 .311 .441 r
.59346 .72377 m .58197 .73089 L .58223 .74678 L p F P
0 0 0 r
s
.164 .227 .334 r
.46334 .57641 m .45395 .58493 L .45429 .56982 L p F P
0 0 0 r
s
.164 .227 .334 r
.45429 .56982 m .46364 .56126 L .46334 .57641 L p F P
0 0 0 r
s
.491 .682 .818 r
.44554 .6912 m .45086 .70035 L .45122 .68469 L p F P
0 0 0 r
s
.491 .682 .818 r
.45122 .68469 m .44593 .67548 L .44554 .6912 L p F P
0 0 0 r
s
.69 .09 .12 r
.41075 .39343 m
.40747 .39462 L
s
.41075 .39343 m
.4033 .40066 L
s
.585 .785 .972 r
.58703 .5456 m .57445 .5385 L .57422 .52361 L p F P
0 0 0 r
s
.546 .732 .922 r
.55928 .51826 m .57422 .52361 L .57445 .5385 L p F P
0 0 0 r
s
.69 .09 .12 r
.45512 .73068 m
.45244 .73402 L
s
.45769 .7325 m
.45512 .73068 L
s
.4033 .40066 m
.4104 .40271 L
s
.4033 .40066 m
.40747 .39462 L
s
.43988 .38758 m
.4033 .40066 L
s
.391 .529 .701 r
.52521 .51391 m .50779 .51515 L .50788 .50037 L p F P
0 0 0 r
s
.391 .529 .701 r
.50788 .50037 m .52522 .49912 L .52521 .51391 L p F P
0 0 0 r
s
.69 .09 .12 r
.51271 .8508 m
.51393 .84503 L
s
.225 .314 .442 r
.47605 .55406 m .46364 .56126 L .46393 .54625 L p F P
0 0 0 r
s
.225 .314 .442 r
.46393 .54625 m .47629 .53903 L .47605 .55406 L p F P
0 0 0 r
s
.497 .667 .854 r
.55928 .51826 m .54267 .51497 L .54259 .50018 L p F P
0 0 0 r
s
.445 .599 .78 r
.52522 .49912 m .54259 .50018 L .54267 .51497 L p F P
0 0 0 r
s
.69 .09 .12 r
.72645 .62285 m
.72825 .5956 L
s
.45244 .73402 m
.45501 .73584 L
s
.589 .795 .968 r
.58732 .56061 m .59694 .56907 L .59728 .58418 L p F P
0 0 0 r
s
.589 .795 .968 r
.59694 .56907 m .58732 .56061 L .58703 .5456 L p F P
0 0 0 r
s
.69 .09 .12 r
.4813 .28764 m
.48155 .29725 L
s
.092 .135 .215 r
.60622 .6747 m .60123 .68396 L .60159 .69963 L p F P
0 0 0 r
s
.092 .135 .215 r
.60123 .68396 m .60622 .6747 L .60584 .65913 L p F P
0 0 0 r
s
.69 .09 .12 r
.35218 .28991 m
.35739 .28866 L
s
.35739 .28866 m
.35299 .27651 L
s
.35739 .28866 m
.34178 .28735 L
s
.46687 .51091 m
.46831 .51493 L
s
.585 .785 .972 r
.57445 .5385 m .58703 .5456 L .58732 .56061 L p F P
0 0 0 r
s
.69 .09 .12 r
.39575 .62233 m
.39705 .6226 L
s
.39734 .61555 m
.39575 .62233 L
s
.39575 .62233 m
.39303 .61838 L
s
.40135 .61976 m
.39575 .62233 L
s
.40304 .6059 m
.39575 .62233 L
s
.576 .776 .973 r
.47045 .76333 m .48472 .76877 L .48491 .75277 L p F P
0 0 0 r
s
.576 .776 .973 r
.48491 .75277 m .47071 .7473 L .47045 .76333 L p F P
0 0 0 r
s
.445 .599 .78 r
.54267 .51497 m .52521 .51391 L .52522 .49912 L p F P
0 0 0 r
s
.327 .449 .611 r
.55248 .77225 m .56841 .76838 L .56821 .75238 L p F P
0 0 0 r
s
.274 .382 .529 r
.58223 .74678 m .56821 .75238 L .56841 .76838 L p F P
0 0 0 r
s
.69 .09 .12 r
.35299 .27651 m
.34776 .2777 L
s
.35299 .27651 m
.34178 .28735 L
s
.38819 .84421 m
.38357 .8459 L
s
.38401 .83523 m
.38819 .84421 L
s
.38819 .84421 m
.37861 .84197 L
s
.38898 .83913 m
.38819 .84421 L
s
.36595 .82574 m
.38819 .84421 L
s
.335 .477 .554 r
.44432 .66581 m .44593 .67548 L .44631 .65992 L p F P
0 0 0 r
s
.335 .477 .554 r
.44631 .65992 m .44471 .6502 L .44432 .66581 L p F P
0 0 0 r
s
.69 .09 .12 r
.34178 .28735 m
.35218 .28991 L
s
.34178 .28735 m
.34776 .2777 L
s
.39625 .26642 m
.34178 .28735 L
s
.45501 .73584 m
.45769 .7325 L
s
.7201 .28691 m
.6736 .25507 L
s
.39734 .61555 m
.39303 .61838 L
s
.40135 .61976 m
.39734 .61555 L
s
.06 .089 .131 r
.60713 .64939 m .60584 .65913 L .60622 .6747 L p F P
0 0 0 r
s
.06 .089 .131 r
.60584 .65913 m .60713 .64939 L .60674 .63392 L p F P
0 0 0 r
s
.48 .649 .84 r
.50065 .78862 m .51788 .79046 L .51791 .77434 L p F P
0 0 0 r
s
.48 .649 .84 r
.51791 .77434 m .50077 .77249 L .50065 .78862 L p F P
0 0 0 r
s
.431 .583 .767 r
.5354 .77426 m .51791 .77434 L .51788 .79046 L p F P
0 0 0 r
s
.431 .583 .767 r
.51788 .79046 m .53544 .79038 L .5354 .77426 L p F P
0 0 0 r
s
.38 .517 .691 r
.55248 .77225 m .5354 .77426 L .53544 .79038 L p F P
0 0 0 r
s
.69 .09 .12 r
.3342 .5092 m
.33879 .50987 L
s
.33944 .4991 m
.3342 .5092 L
s
.3342 .5092 m
.3333 .50211 L
s
.34492 .50684 m
.3342 .5092 L
s
.35909 .48533 m
.3342 .5092 L
s
.38401 .83523 m
.37861 .84197 L
s
.38898 .83913 m
.38401 .83523 L
s
.3266 .73126 m
.32528 .73202 L
s
.32597 .72047 m
.3266 .73126 L
s
.3266 .73126 m
.31886 .72635 L
s
.3324 .72611 m
.3266 .73126 L
s
.32166 .70578 m
.3266 .73126 L
s
.39705 .6226 m
.40135 .61976 L
s
.06 .088 .13 r
.44692 .64045 m .44471 .6502 L .4451 .63473 L p F P
0 0 0 r
s
.06 .088 .13 r
.4451 .63473 m .4473 .62494 L .44692 .64045 L p F P
0 0 0 r
s
.69 .09 .12 r
.33944 .4991 m
.3333 .50211 L
s
.34492 .50684 m
.33944 .4991 L
s
.37861 .84197 m
.38357 .8459 L
s
.27251 .39582 m
.28023 .39684 L
s
.28144 .38215 m
.27251 .39582 L
s
.27251 .39582 m
.27324 .3852 L
s
.2884 .39372 m
.27251 .39582 L
s
.31472 .36363 m
.27251 .39582 L
s
.53 .714 .909 r
.48452 .78492 m .50065 .78862 L .50077 .77249 L p F P
0 0 0 r
s
.53 .714 .909 r
.50077 .77249 m .48472 .76877 L .48452 .78492 L p F P
0 0 0 r
s
.336 .459 .619 r
.5077 .53008 m .49112 .53354 L .49129 .51862 L p F P
0 0 0 r
s
.336 .459 .619 r
.49129 .51862 m .50779 .51515 L .5077 .53008 L p F P
0 0 0 r
s
.69 .09 .12 r
.42192 .1707 m
.42367 .18433 L
s
.338 .478 .556 r
.60423 .62415 m .60674 .63392 L .60713 .64939 L p F P
0 0 0 r
s
.338 .478 .556 r
.60674 .63392 m .60423 .62415 L .60385 .60878 L p F P
0 0 0 r
s
.38 .517 .691 r
.53544 .79038 m .5526 .78838 L .55248 .77225 L p F P
0 0 0 r
s
.327 .449 .611 r
.56841 .76838 m .55248 .77225 L .5526 .78838 L p F P
0 0 0 r
s
.69 .09 .12 r
.33879 .50987 m
.34492 .50684 L
s
.39303 .61838 m
.39705 .6226 L
s
.40747 .39462 m
.4104 .40271 L
s
.546 .732 .922 r
.57445 .5385 m .55944 .53317 L .55928 .51826 L p F P
0 0 0 r
s
.497 .667 .854 r
.54267 .51497 m .55928 .51826 L .55944 .53317 L p F P
0 0 0 r
s
.69 .09 .12 r
.26488 .61807 m
.26668 .61858 L
s
.26782 .60445 m
.26488 .61807 L
s
.26488 .61807 m
.25878 .6101 L
s
.27572 .6129 m
.26488 .61807 L
s
.27696 .58469 m
.26488 .61807 L
s
.25724 .84053 m
.25297 .84249 L
s
.25432 .82557 m
.25724 .84053 L
s
.25724 .84053 m
.24433 .83483 L
s
.26298 .83318 m
.25724 .84053 L
s
.23894 .80732 m
.25724 .84053 L
s
.09 .133 .211 r
.45325 .61559 m .4473 .62494 L .44767 .60958 L p F P
0 0 0 r
s
.09 .133 .211 r
.44767 .60958 m .4536 .60019 L .45325 .61559 L p F P
0 0 0 r
s
.69 .09 .12 r
.28144 .38215 m
.27324 .3852 L
s
.2884 .39372 m
.28144 .38215 L
s
.32597 .72047 m
.31886 .72635 L
s
.3324 .72611 m
.32597 .72047 L
s
.69086 .84047 m
.72072 .82112 L
s
.91263 .71278 m
.92577 .72567 L
s
.90202 .72176 m
.91263 .71278 L
s
.91263 .71278 m
.92146 .71445 L
s
.28023 .39684 m
.2884 .39372 L
s
.603 .821 .995 r
.45013 .73213 m .45893 .74032 L .45925 .7244 L p F P
0 0 0 r
s
.603 .821 .995 r
.45925 .7244 m .4505 .71617 L .45013 .73213 L p F P
0 0 0 r
s
.69 .09 .12 r
.44659 .72535 m
.45021 .72873 L
s
.497 .683 .822 r
.59763 .59945 m .60385 .60878 L .60423 .62415 L p F P
0 0 0 r
s
.497 .683 .822 r
.60385 .60878 m .59763 .59945 L .59728 .58418 L p F P
0 0 0 r
s
.61 .824 1 r
.45861 .7564 m .47045 .76333 L .47071 .7473 L p F P
0 0 0 r
s
.61 .824 1 r
.47071 .7473 m .45893 .74032 L .45861 .7564 L p F P
0 0 0 r
s
.69 .09 .12 r
.20302 .50463 m
.20778 .50508 L
s
.20956 .48768 m
.20302 .50463 L
s
.20302 .50463 m
.19837 .49321 L
s
.21894 .49949 m
.20302 .50463 L
s
.23184 .46246 m
.20302 .50463 L
s
.281 .388 .533 r
.49095 .54859 m .47605 .55406 L .47629 .53903 L p F P
0 0 0 r
s
.281 .388 .533 r
.47629 .53903 m .49112 .53354 L .49095 .54859 L p F P
0 0 0 r
s
.222 .311 .441 r
.58223 .74678 m .59379 .73969 L .59346 .72377 L p F P
0 0 0 r
s
.158 .22 .329 r
.60195 .71544 m .59346 .72377 L .59379 .73969 L p F P
0 0 0 r
s
.158 .22 .329 r
.59346 .72377 m .60195 .71544 L .60159 .69963 L p F P
0 0 0 r
s
.274 .382 .529 r
.56841 .76838 m .5825 .76281 L .58223 .74678 L p F P
0 0 0 r
s
.222 .311 .441 r
.59379 .73969 m .58223 .74678 L .5825 .76281 L p F P
0 0 0 r
s
.164 .227 .334 r
.46304 .59171 m .4536 .60019 L .45395 .58493 L p F P
0 0 0 r
s
.164 .227 .334 r
.45395 .58493 m .46334 .57641 L .46304 .59171 L p F P
0 0 0 r
s
.69 .09 .12 r
.38357 .8459 m
.38898 .83913 L
s
.491 .682 .818 r
.44515 .70706 m .4505 .71617 L .45086 .70035 L p F P
0 0 0 r
s
.491 .682 .818 r
.45086 .70035 m .44554 .6912 L .44515 .70706 L p F P
0 0 0 r
s
.585 .785 .972 r
.58732 .56061 m .57468 .55354 L .57445 .5385 L p F P
0 0 0 r
s
.546 .732 .922 r
.55944 .53317 m .57445 .5385 L .57468 .55354 L p F P
0 0 0 r
s
.69 .09 .12 r
.19534 .72728 m
.19404 .72851 L
s
.19591 .70983 m
.19534 .72728 L
s
.19534 .72728 m
.1839 .7186 L
s
.20604 .71968 m
.19534 .72728 L
s
.19347 .6857 m
.19534 .72728 L
s
.68445 .50362 m
.66604 .48057 L
s
.391 .529 .701 r
.52521 .52884 m .5077 .53008 L .50779 .51515 L p F P
0 0 0 r
s
.391 .529 .701 r
.50779 .51515 m .52521 .51391 L .52521 .52884 L p F P
0 0 0 r
s
.225 .314 .442 r
.47581 .56924 m .46334 .57641 L .46364 .56126 L p F P
0 0 0 r
s
.225 .314 .442 r
.46364 .56126 m .47605 .55406 L .47581 .56924 L p F P
0 0 0 r
s
.497 .667 .854 r
.55944 .53317 m .54275 .52989 L .54267 .51497 L p F P
0 0 0 r
s
.445 .599 .78 r
.52521 .51391 m .54267 .51497 L .54275 .52989 L p F P
0 0 0 r
s
.69 .09 .12 r
.26782 .60445 m
.25878 .6101 L
s
.27572 .6129 m
.26782 .60445 L
s
.589 .795 .968 r
.58762 .57576 m .59728 .58418 L .59763 .59945 L p F P
0 0 0 r
s
.589 .795 .968 r
.59728 .58418 m .58762 .57576 L .58732 .56061 L p F P
0 0 0 r
s
.092 .135 .215 r
.60661 .69041 m .60159 .69963 L .60195 .71544 L p F P
0 0 0 r
s
.092 .135 .215 r
.60159 .69963 m .60661 .69041 L .60622 .6747 L p F P
0 0 0 r
s
.585 .785 .972 r
.57468 .55354 m .58732 .56061 L .58762 .57576 L p F P
0 0 0 r
s
.576 .776 .973 r
.47018 .77952 m .48452 .78492 L .48472 .76877 L p F P
0 0 0 r
s
.576 .776 .973 r
.48472 .76877 m .47045 .76333 L .47018 .77952 L p F P
0 0 0 r
s
.69 .09 .12 r
.31886 .72635 m
.32528 .73202 L
s
.32528 .73202 m
.3324 .72611 L
s
.445 .599 .78 r
.54275 .52989 m .52521 .52884 L .52521 .51391 L p F P
0 0 0 r
s
.327 .449 .611 r
.5526 .78838 m .56862 .78454 L .56841 .76838 L p F P
0 0 0 r
s
.274 .382 .529 r
.5825 .76281 m .56841 .76838 L .56862 .78454 L p F P
0 0 0 r
s
.69 .09 .12 r
.34776 .2777 m
.35218 .28991 L
s
.3333 .50211 m
.33879 .50987 L
s
.92577 .72567 m
.9152 .73472 L
s
.92146 .71445 m
.92577 .72567 L
s
.13331 .61378 m
.1348 .61452 L
s
.13739 .59327 m
.13331 .61378 L
s
.13331 .61378 m
.12315 .60174 L
s
.14901 .60598 m
.13331 .61378 L
s
.14757 .56293 m
.13331 .61378 L
s
.25432 .82557 m
.24433 .83483 L
s
.26298 .83318 m
.25432 .82557 L
s
.335 .477 .554 r
.44392 .68157 m .44554 .6912 L .44593 .67548 L p F P
0 0 0 r
s
.335 .477 .554 r
.44593 .67548 m .44432 .66581 L .44392 .68157 L p F P
0 0 0 r
s
.69 .09 .12 r
.67802 .16599 m
.6113 .1396 L
s
.89292 .83722 m
.93089 .79333 L
s
.85557 .5998 m
.86732 .60936 L
s
.84567 .60821 m
.85557 .5998 L
s
.85557 .5998 m
.8597 .59998 L
s
.20956 .48768 m
.19837 .49321 L
s
.21894 .49949 m
.20956 .48768 L
s
.06 .089 .131 r
.60752 .665 m .60622 .6747 L .60661 .69041 L p F P
0 0 0 r
s
.06 .089 .131 r
.60622 .6747 m .60752 .665 L .60713 .64939 L p F P
0 0 0 r
s
.48 .649 .84 r
.50053 .8049 m .51784 .80673 L .51788 .79046 L p F P
0 0 0 r
s
.48 .649 .84 r
.51788 .79046 m .50065 .78862 L .50053 .8049 L p F P
0 0 0 r
s
.431 .583 .767 r
.53544 .79038 m .51788 .79046 L .51784 .80673 L p F P
0 0 0 r
s
.69 .09 .12 r
.26668 .61858 m
.27572 .6129 L
s
.431 .583 .767 r
.51784 .80673 m .53549 .80665 L .53544 .79038 L p F P
0 0 0 r
s
.38 .517 .691 r
.5526 .78838 m .53544 .79038 L .53549 .80665 L p F P
0 0 0 r
s
.69 .09 .12 r
.84261 .82204 m
.85264 .8342 L
s
.83433 .82912 m
.84261 .82204 L
s
.84261 .82204 m
.85225 .82491 L
s
.06 .088 .13 r
.44654 .65611 m .44432 .66581 L .44471 .6502 L p F P
0 0 0 r
s
.06 .088 .13 r
.44471 .6502 m .44692 .64045 L .44654 .65611 L p F P
0 0 0 r
s
.69 .09 .12 r
.20778 .50508 m
.21894 .49949 L
s
.19591 .70983 m
.1839 .7186 L
s
.20604 .71968 m
.19591 .70983 L
s
.53 .714 .909 r
.48432 .80123 m .50053 .8049 L .50065 .78862 L p F P
0 0 0 r
s
.53 .714 .909 r
.50065 .78862 m .48452 .78492 L .48432 .80123 L p F P
0 0 0 r
s
.336 .459 .619 r
.50762 .54515 m .49095 .54859 L .49112 .53354 L p F P
0 0 0 r
s
.336 .459 .619 r
.49112 .53354 m .5077 .53008 L .50762 .54515 L p F P
0 0 0 r
s
.338 .478 .556 r
.6046 .63966 m .60713 .64939 L .60752 .665 L p F P
0 0 0 r
s
.338 .478 .556 r
.60713 .64939 m .6046 .63966 L .60423 .62415 L p F P
0 0 0 r
s
.69 .09 .12 r
.24433 .83483 m
.25297 .84249 L
s
.38 .517 .691 r
.53549 .80665 m .55273 .80467 L .5526 .78838 L p F P
0 0 0 r
s
.327 .449 .611 r
.56862 .78454 m .5526 .78838 L .55273 .80467 L p F P
0 0 0 r
s
.546 .732 .922 r
.57468 .55354 m .5596 .54823 L .55944 .53317 L p F P
0 0 0 r
s
.497 .667 .854 r
.54275 .52989 m .55944 .53317 L .5596 .54823 L p F P
0 0 0 r
s
.69 .09 .12 r
.25878 .6101 m
.26668 .61858 L
s
.85264 .8342 m
.8444 .84134 L
s
.85225 .82491 m
.85264 .8342 L
s
.79821 .48583 m
.80855 .49242 L
s
.78922 .49448 m
.79821 .48583 L
s
.79821 .48583 m
.7978 .48526 L
s
.64855 .72183 m
.65848 .70628 L
s
.9152 .73472 m
.90202 .72176 L
s
.90202 .72176 m
.92146 .71445 L
s
.27324 .3852 m
.28023 .39684 L
s
.09 .133 .211 r
.4529 .63115 m .44692 .64045 L .4473 .62494 L p F P
0 0 0 r
s
.09 .133 .211 r
.4473 .62494 m .45325 .61559 L .4529 .63115 L p F P
0 0 0 r
s
.69 .09 .12 r
.86732 .60936 m
.85743 .61783 L
s
.8597 .59998 m
.86732 .60936 L
s
.13739 .59327 m
.12315 .60174 L
s
.14901 .60598 m
.13739 .59327 L
s
.25297 .84249 m
.26298 .83318 L
s
.603 .821 .995 r
.44977 .74826 m .45861 .7564 L .45893 .74032 L p F P
0 0 0 r
s
.603 .821 .995 r
.45893 .74032 m .45013 .73213 L .44977 .74826 L p F P
0 0 0 r
s
.497 .683 .822 r
.59797 .61486 m .60423 .62415 L .6046 .63966 L p F P
0 0 0 r
s
.497 .683 .822 r
.60423 .62415 m .59797 .61486 L .59763 .59945 L p F P
0 0 0 r
s
.61 .824 1 r
.45828 .77263 m .47018 .77952 L .47045 .76333 L p F P
0 0 0 r
s
.61 .824 1 r
.47045 .76333 m .45861 .7564 L .45828 .77263 L p F P
0 0 0 r
s
.281 .388 .533 r
.49079 .5638 m .47581 .56924 L .47605 .55406 L p F P
0 0 0 r
s
.281 .388 .533 r
.47605 .55406 m .49095 .54859 L .49079 .5638 L p F P
0 0 0 r
s
.69 .09 .12 r
.85743 .61783 m
.84567 .60821 L
s
.84567 .60821 m
.8597 .59998 L
s
.222 .311 .441 r
.5825 .76281 m .59412 .75577 L .59379 .73969 L p F P
0 0 0 r
s
.158 .22 .329 r
.60232 .73141 m .59379 .73969 L .59412 .75577 L p F P
0 0 0 r
s
.158 .22 .329 r
.59379 .73969 m .60232 .73141 L .60195 .71544 L p F P
0 0 0 r
s
.274 .382 .529 r
.56862 .78454 m .58278 .779 L .5825 .76281 L p F P
0 0 0 r
s
.222 .311 .441 r
.59412 .75577 m .5825 .76281 L .58278 .779 L p F P
0 0 0 r
s
.164 .227 .334 r
.46273 .60715 m .45325 .61559 L .4536 .60019 L p F P
0 0 0 r
s
.164 .227 .334 r
.4536 .60019 m .46304 .59171 L .46273 .60715 L p F P
0 0 0 r
s
.69 .09 .12 r
.64206 .38328 m
.6037 .36529 L
s
.491 .682 .818 r
.44476 .72308 m .45013 .73213 L .4505 .71617 L p F P
0 0 0 r
s
.491 .682 .818 r
.4505 .71617 m .44515 .70706 L .44476 .72308 L p F P
0 0 0 r
s
.585 .785 .972 r
.58762 .57576 m .57491 .56872 L .57468 .55354 L p F P
0 0 0 r
s
.546 .732 .922 r
.5596 .54823 m .57468 .55354 L .57491 .56872 L p F P
0 0 0 r
s
.69 .09 .12 r
.78522 .70928 m
.79385 .71792 L
s
.77773 .71528 m
.78522 .70928 L
s
.78522 .70928 m
.79032 .71038 L
s
.391 .529 .701 r
.52521 .54392 m .50762 .54515 L .5077 .53008 L p F P
0 0 0 r
s
.391 .529 .701 r
.5077 .53008 m .52521 .52884 L .52521 .54392 L p F P
0 0 0 r
s
.69 .09 .12 r
.19404 .72851 m
.20604 .71968 L
s
.225 .314 .442 r
.47557 .58457 m .46304 .59171 L .46334 .57641 L p F P
0 0 0 r
s
.225 .314 .442 r
.46334 .57641 m .47581 .56924 L .47557 .58457 L p F P
0 0 0 r
s
.497 .667 .854 r
.5596 .54823 m .54283 .54496 L .54275 .52989 L p F P
0 0 0 r
s
.445 .599 .78 r
.52521 .52884 m .54275 .52989 L .54283 .54496 L p F P
0 0 0 r
s
.589 .795 .968 r
.58792 .59106 m .59763 .59945 L .59797 .61486 L p F P
0 0 0 r
s
.589 .795 .968 r
.59763 .59945 m .58792 .59106 L .58762 .57576 L p F P
0 0 0 r
s
.092 .135 .215 r
.607 .70628 m .60195 .71544 L .60232 .73141 L p F P
0 0 0 r
s
.092 .135 .215 r
.60195 .71544 m .607 .70628 L .60661 .69041 L p F P
0 0 0 r
s
.69 .09 .12 r
.79956 .50111 m
.78922 .49448 L
s
.78922 .49448 m
.7978 .48526 L
s
.585 .785 .972 r
.57491 .56872 m .58762 .57576 L .58792 .59106 L p F P
0 0 0 r
s
.69 .09 .12 r
.74055 .37073 m
.74946 .37484 L
s
.73267 .38054 m
.74055 .37073 L
s
.74055 .37073 m
.73577 .37029 L
s
.576 .776 .973 r
.46991 .79586 m .48432 .80123 L .48452 .78492 L p F P
0 0 0 r
s
.576 .776 .973 r
.48452 .78492 m .47018 .77952 L .46991 .79586 L p F P
0 0 0 r
s
.445 .599 .78 r
.54283 .54496 m .52521 .54392 L .52521 .52884 L p F P
0 0 0 r
s
.69 .09 .12 r
.92146 .71445 m
.9152 .73472 L
s
.327 .449 .611 r
.55273 .80467 m .56882 .80085 L .56862 .78454 L p F P
0 0 0 r
s
.274 .382 .529 r
.58278 .779 m .56862 .78454 L .56882 .80085 L p F P
0 0 0 r
s
.69 .09 .12 r
.1839 .7186 m
.19404 .72851 L
s
.1348 .61452 m
.14901 .60598 L
s
.335 .477 .554 r
.44353 .69749 m .44515 .70706 L .44554 .6912 L p F P
0 0 0 r
s
.335 .477 .554 r
.44554 .6912 m .44392 .68157 L .44353 .69749 L p F P
0 0 0 r
s
.69 .09 .12 r
.85145 .71829 m
.86767 .67622 L
s
.19837 .49321 m
.20778 .50508 L
s
.79385 .71792 m
.78637 .72395 L
s
.79032 .71038 m
.79385 .71792 L
s
.74156 .3847 m
.73267 .38054 L
s
.73267 .38054 m
.73577 .37029 L
s
.06 .089 .131 r
.60791 .68077 m .60661 .69041 L .607 .70628 L p F P
0 0 0 r
s
.06 .089 .131 r
.60661 .69041 m .60791 .68077 L .60752 .665 L p F P
0 0 0 r
s
.48 .649 .84 r
.50041 .82134 m .5178 .82316 L .51784 .80673 L p F P
0 0 0 r
s
.48 .649 .84 r
.51784 .80673 m .50053 .8049 L .50041 .82134 L p F P
0 0 0 r
s
.431 .583 .767 r
.53549 .80665 m .51784 .80673 L .5178 .82316 L p F P
0 0 0 r
s
.431 .583 .767 r
.5178 .82316 m .53554 .82309 L .53549 .80665 L p F P
0 0 0 r
s
.38 .517 .691 r
.55273 .80467 m .53549 .80665 L .53554 .82309 L p F P
0 0 0 r
s
.69 .09 .12 r
.80855 .49242 m
.79956 .50111 L
s
.7978 .48526 m
.80855 .49242 L
s
.8597 .59998 m
.85743 .61783 L
s
.8444 .84134 m
.83433 .82912 L
s
.83433 .82912 m
.85225 .82491 L
s
.68263 .25445 m
.69005 .2566 L
s
.67603 .26641 m
.68263 .25445 L
s
.68263 .25445 m
.6736 .25507 L
s
.72753 .59553 m
.73474 .60099 L
s
.72103 .60125 m
.72753 .59553 L
s
.72753 .59553 m
.72825 .5956 L
s
.68341 .26863 m
.67603 .26641 L
s
.67603 .26641 m
.6736 .25507 L
s
.06 .088 .13 r
.44615 .67192 m .44392 .68157 L .44432 .66581 L p F P
0 0 0 r
s
.06 .088 .13 r
.44432 .66581 m .44654 .65611 L .44615 .67192 L p F P
0 0 0 r
s
.53 .714 .909 r
.48412 .8177 m .50041 .82134 L .50053 .8049 L p F P
0 0 0 r
s
.53 .714 .909 r
.50053 .8049 m .48432 .80123 L .48412 .8177 L p F P
0 0 0 r
s
.336 .459 .619 r
.50753 .56037 m .49079 .5638 L .49095 .54859 L p F P
0 0 0 r
s
.336 .459 .619 r
.49095 .54859 m .50762 .54515 L .50753 .56037 L p F P
0 0 0 r
s
.338 .478 .556 r
.60499 .65533 m .60752 .665 L .60791 .68077 L p F P
0 0 0 r
s
.338 .478 .556 r
.60752 .665 m .60499 .65533 L .6046 .63966 L p F P
0 0 0 r
s
.38 .517 .691 r
.53554 .82309 m .55286 .82111 L .55273 .80467 L p F P
0 0 0 r
s
.327 .449 .611 r
.56882 .80085 m .55273 .80467 L .55286 .82111 L p F P
0 0 0 r
s
.69 .09 .12 r
.78637 .72395 m
.77773 .71528 L
s
.77773 .71528 m
.79032 .71038 L
s
.546 .732 .922 r
.57491 .56872 m .55977 .56343 L .5596 .54823 L p F P
0 0 0 r
s
.497 .667 .854 r
.54283 .54496 m .5596 .54823 L .55977 .56343 L p F P
0 0 0 r
s
.69 .09 .12 r
.62506 .15271 m
.61928 .15209 L
s
.61928 .15209 m
.6245 .13718 L
s
.61928 .15209 m
.6113 .1396 L
s
.85225 .82491 m
.8444 .84134 L
s
.71436 .81904 m
.72003 .82698 L
s
.70932 .82308 m
.71436 .81904 L
s
.71436 .81904 m
.72072 .82112 L
s
.7978 .48526 m
.79956 .50111 L
s
.12315 .60174 m
.1348 .61452 L
s
.6245 .13718 m
.63031 .13772 L
s
.6245 .13718 m
.6113 .1396 L
s
.72003 .82698 m
.71502 .83105 L
s
.72072 .82112 m
.72003 .82698 L
s
.09 .133 .211 r
.45254 .64685 m .44654 .65611 L .44692 .64045 L p F P
0 0 0 r
s
.09 .133 .211 r
.44692 .64045 m .4529 .63115 L .45254 .64685 L p F P
0 0 0 r
s
.69 .09 .12 r
.72824 .60674 m
.72103 .60125 L
s
.72103 .60125 m
.72825 .5956 L
s
.73474 .60099 m
.72824 .60674 L
s
.72825 .5956 m
.73474 .60099 L
s
.603 .821 .995 r
.4494 .76453 m .45828 .77263 L .45861 .7564 L p F P
0 0 0 r
s
.603 .821 .995 r
.45861 .7564 m .44977 .74826 L .4494 .76453 L p F P
0 0 0 r
s
.497 .683 .822 r
.59832 .63041 m .6046 .63966 L .60499 .65533 L p F P
0 0 0 r
s
.497 .683 .822 r
.6046 .63966 m .59832 .63041 L .59797 .61486 L p F P
0 0 0 r
s
.69 .09 .12 r
.66954 .4804 m
.67531 .48343 L
s
.66423 .48702 m
.66954 .4804 L
s
.66954 .4804 m
.66604 .48057 L
s
.61 .824 1 r
.45795 .78901 m .46991 .79586 L .47018 .77952 L p F P
0 0 0 r
s
.61 .824 1 r
.47018 .77952 m .45828 .77263 L .45795 .78901 L p F P
0 0 0 r
s
.69 .09 .12 r
.79032 .71038 m
.78637 .72395 L
s
.74946 .37484 m
.74156 .3847 L
s
.73577 .37029 m
.74946 .37484 L
s
.281 .388 .533 r
.49061 .57915 m .47557 .58457 L .47581 .56924 L p F P
0 0 0 r
s
.281 .388 .533 r
.47581 .56924 m .49079 .5638 L .49061 .57915 L p F P
0 0 0 r
s
.222 .311 .441 r
.58278 .779 m .59445 .772 L .59412 .75577 L p F P
0 0 0 r
s
.158 .22 .329 r
.60269 .74754 m .59412 .75577 L .59445 .772 L p F P
0 0 0 r
s
.158 .22 .329 r
.59412 .75577 m .60269 .74754 L .60232 .73141 L p F P
0 0 0 r
s
.69 .09 .12 r
.59927 .26181 m
.54122 .24975 L
s
.274 .382 .529 r
.56882 .80085 m .58305 .79535 L .58278 .779 L p F P
0 0 0 r
s
.222 .311 .441 r
.59445 .772 m .58278 .779 L .58305 .79535 L p F P
0 0 0 r
s
.164 .227 .334 r
.46242 .62274 m .4529 .63115 L .45325 .61559 L p F P
0 0 0 r
s
.164 .227 .334 r
.45325 .61559 m .46273 .60715 L .46242 .62274 L p F P
0 0 0 r
s
.491 .682 .818 r
.44436 .73925 m .44977 .74826 L .45013 .73213 L p F P
0 0 0 r
s
.491 .682 .818 r
.45013 .73213 m .44476 .72308 L .44436 .73925 L p F P
0 0 0 r
s
.585 .785 .972 r
.58792 .59106 m .57515 .58405 L .57491 .56872 L p F P
0 0 0 r
s
.546 .732 .922 r
.55977 .56343 m .57491 .56872 L .57515 .58405 L p F P
0 0 0 r
s
.69 .09 .12 r
.66999 .49007 m
.66423 .48702 L
s
.66423 .48702 m
.66604 .48057 L
s
.391 .529 .701 r
.5252 .55914 m .50753 .56037 L .50762 .54515 L p F P
0 0 0 r
s
.391 .529 .701 r
.50762 .54515 m .52521 .54392 L .5252 .55914 L p F P
0 0 0 r
s
.225 .314 .442 r
.47532 .60004 m .46273 .60715 L .46304 .59171 L p F P
0 0 0 r
s
.225 .314 .442 r
.46304 .59171 m .47557 .58457 L .47532 .60004 L p F P
0 0 0 r
s
.497 .667 .854 r
.55977 .56343 m .54291 .56018 L .54283 .54496 L p F P
0 0 0 r
s
.445 .599 .78 r
.52521 .54392 m .54283 .54496 L .54291 .56018 L p F P
0 0 0 r
s
.589 .795 .968 r
.58822 .60651 m .59797 .61486 L .59832 .63041 L p F P
0 0 0 r
s
.589 .795 .968 r
.59797 .61486 m .58822 .60651 L .58792 .59106 L p F P
0 0 0 r
s
.69 .09 .12 r
.5961 .5912 m
.60584 .60208 L
s
.092 .135 .215 r
.60739 .72231 m .60232 .73141 L .60269 .74754 L p F P
0 0 0 r
s
.092 .135 .215 r
.60232 .73141 m .60739 .72231 L .607 .70628 L p F P
0 0 0 r
s
.69 .09 .12 r
.73577 .37029 m
.74156 .3847 L
s
.585 .785 .972 r
.57515 .58405 m .58792 .59106 L .58822 .60651 L p F P
0 0 0 r
s
.576 .776 .973 r
.46964 .81236 m .48412 .8177 L .48432 .80123 L p F P
0 0 0 r
s
.576 .776 .973 r
.48432 .80123 m .46991 .79586 L .46964 .81236 L p F P
0 0 0 r
s
.445 .599 .78 r
.54291 .56018 m .5252 .55914 L .52521 .54392 L p F P
0 0 0 r
s
.69 .09 .12 r
.61158 .37414 m
.60733 .3726 L
s
.60733 .3726 m
.61128 .36371 L
s
.60733 .3726 m
.6037 .36529 L
s
.327 .449 .611 r
.55286 .82111 m .56903 .81732 L .56882 .80085 L p F P
0 0 0 r
s
.274 .382 .529 r
.58305 .79535 m .56882 .80085 L .56903 .81732 L p F P
0 0 0 r
s
.69 .09 .12 r
.80959 .59825 m
.8043 .55884 L
s
.72825 .5956 m
.72824 .60674 L
s
.65633 .70575 m
.66058 .71008 L
s
.65237 .70875 m
.65633 .70575 L
s
.65633 .70575 m
.65848 .70628 L
s
.61128 .36371 m
.61555 .36521 L
s
.61128 .36371 m
.6037 .36529 L
s
.335 .477 .554 r
.44312 .71356 m .44476 .72308 L .44515 .70706 L p F P
0 0 0 r
s
.335 .477 .554 r
.44515 .70706 m .44353 .69749 L .44312 .71356 L p F P
0 0 0 r
s
.06 .089 .131 r
.60831 .69669 m .607 .70628 L .60739 .72231 L p F P
0 0 0 r
s
.06 .089 .131 r
.607 .70628 m .60831 .69669 L .60791 .68077 L p F P
0 0 0 r
s
.69 .09 .12 r
.66058 .71008 m
.65662 .7131 L
s
.65848 .70628 m
.66058 .71008 L
s
.71502 .83105 m
.70932 .82308 L
s
.70932 .82308 m
.72072 .82112 L
s
.55295 .25854 m
.55034 .25797 L
s
.55034 .25797 m
.55283 .24584 L
s
.55034 .25797 m
.54122 .24975 L
s
.67531 .48343 m
.66999 .49007 L
s
.66604 .48057 m
.67531 .48343 L
s
.72072 .82112 m
.71502 .83105 L
s
.56937 .82243 m
.58849 .81732 L
s
.55283 .24584 m
.55546 .24634 L
s
.55283 .24584 m
.54122 .24975 L
s
.69005 .2566 m
.68341 .26863 L
s
.6736 .25507 m
.69005 .2566 L
s
.6736 .25507 m
.68341 .26863 L
s
.06 .088 .13 r
.44576 .68789 m .44353 .69749 L .44392 .68157 L p F P
0 0 0 r
s
.06 .088 .13 r
.44392 .68157 m .44615 .67192 L .44576 .68789 L p F P
0 0 0 r
s
.69 .09 .12 r
.65662 .7131 m
.65237 .70875 L
s
.65237 .70875 m
.65848 .70628 L
s
.49404 .14281 m
.49324 .14315 L
s
.49324 .14315 m
.49422 .12726 L
s
.49324 .14315 m
.47861 .13396 L
s
.66604 .48057 m
.66999 .49007 L
s
.336 .459 .619 r
.50744 .57573 m .49061 .57915 L .49079 .5638 L p F P
0 0 0 r
s
.336 .459 .619 r
.49079 .5638 m .50753 .56037 L .50744 .57573 L p F P
0 0 0 r
s
.338 .478 .556 r
.60537 .67114 m .60791 .68077 L .60831 .69669 L p F P
0 0 0 r
s
.338 .478 .556 r
.60791 .68077 m .60537 .67114 L .60499 .65533 L p F P
0 0 0 r
s
.69 .09 .12 r
.598 .59087 m
.6008 .59254 L
s
.59532 .59423 m
.598 .59087 L
s
.5961 .5912 m
.598 .59087 L
s
.546 .732 .922 r
.57515 .58405 m .55993 .57879 L .55977 .56343 L p F P
0 0 0 r
s
.497 .667 .854 r
.54291 .56018 m .55977 .56343 L .55993 .57879 L p F P
0 0 0 r
s
.69 .09 .12 r
.65848 .70628 m
.65662 .7131 L
s
.56273 .48122 m
.53358 .47585 L
s
.59532 .59423 m
.59812 .5959 L
s
.59532 .59423 m
.5961 .5912 L
s
.49422 .12726 m
.49503 .12681 L
s
.49422 .12726 m
.47861 .13396 L
s
.09 .133 .211 r
.45218 .66271 m .44615 .67192 L .44654 .65611 L p F P
0 0 0 r
s
.09 .133 .211 r
.44654 .65611 m .45254 .64685 L .45218 .66271 L p F P
0 0 0 r
s
.69 .09 .12 r
.58607 .81969 m
.5847 .82104 L
s
.58461 .81565 m
.58607 .81969 L
s
.58849 .81732 m
.58607 .81969 L
s
.603 .821 .995 r
.44902 .78097 m .45795 .78901 L .45828 .77263 L p F P
0 0 0 r
s
.603 .821 .995 r
.45828 .77263 m .4494 .76453 L .44902 .78097 L p F P
0 0 0 r
s
.69 .09 .12 r
.58461 .81565 m
.58849 .81732 L
s
.497 .683 .822 r
.59867 .64612 m .60499 .65533 L .60537 .67114 L p F P
0 0 0 r
s
.497 .683 .822 r
.60499 .65533 m .59867 .64612 L .59832 .63041 L p F P
0 0 0 r
s
.69 .09 .12 r
.53944 .48036 m
.53817 .47951 L
s
.53817 .47951 m
.53941 .4735 L
s
.53817 .47951 m
.53358 .47585 L
s
.6113 .1396 m
.62506 .15271 L
s
.6113 .1396 m
.63031 .13772 L
s
.61 .824 1 r
.45762 .80556 m .46964 .81236 L .46991 .79586 L p F P
0 0 0 r
s
.61 .824 1 r
.46991 .79586 m .45795 .78901 L .45762 .80556 L p F P
0 0 0 r
s
.69 .09 .12 r
.6008 .59254 m
.59812 .5959 L
s
.5961 .5912 m
.6008 .59254 L
s
.55608 .13921 m
.47861 .13396 L
s
.77375 .8191 m
.79664 .78938 L
s
.281 .388 .533 r
.49044 .59465 m .47532 .60004 L .47557 .58457 L p F P
0 0 0 r
s
.281 .388 .533 r
.47557 .58457 m .49061 .57915 L .49044 .59465 L p F P
0 0 0 r
s
.69 .09 .12 r
.63031 .13772 m
.62506 .15271 L
s
.61555 .36521 m
.61158 .37414 L
s
.6037 .36529 m
.61158 .37414 L
s
.222 .311 .441 r
.58305 .79535 m .59478 .78839 L .59445 .772 L p F P
0 0 0 r
s
.158 .22 .329 r
.60306 .76382 m .59445 .772 L .59478 .78839 L p F P
0 0 0 r
s
.158 .22 .329 r
.59445 .772 m .60306 .76382 L .60269 .74754 L p F P
0 0 0 r
s
.69 .09 .12 r
.53941 .4735 m
.54069 .47434 L
s
.53941 .4735 m
.53358 .47585 L
s
.274 .382 .529 r
.56903 .81732 m .58333 .81185 L .58305 .79535 L p F P
0 0 0 r
s
.69 .09 .12 r
.58325 .81699 m
.58461 .81565 L
s
.222 .311 .441 r
.59478 .78839 m .58305 .79535 L .58333 .81185 L p F P
0 0 0 r
s
.69 .09 .12 r
.5961 .5912 m
.59812 .5959 L
s
.164 .227 .334 r
.46211 .63849 m .45254 .64685 L .4529 .63115 L p F P
0 0 0 r
s
.164 .227 .334 r
.4529 .63115 m .46242 .62274 L .46211 .63849 L p F P
0 0 0 r
s
.69 .09 .12 r
.6037 .36529 m
.61555 .36521 L
s
.491 .682 .818 r
.44396 .75559 m .4494 .76453 L .44977 .74826 L p F P
0 0 0 r
s
.491 .682 .818 r
.44977 .74826 m .44436 .73925 L .44396 .75559 L p F P
0 0 0 r
s
.585 .785 .972 r
.58822 .60651 m .57539 .59953 L .57515 .58405 L p F P
0 0 0 r
s
.546 .732 .922 r
.55993 .57879 m .57515 .58405 L .57539 .59953 L p F P
0 0 0 r
s
.391 .529 .701 r
.5252 .57451 m .50744 .57573 L .50753 .56037 L p F P
0 0 0 r
s
.391 .529 .701 r
.50753 .56037 m .5252 .55914 L .5252 .57451 L p F P
0 0 0 r
s
.225 .314 .442 r
.47508 .61567 m .46242 .62274 L .46273 .60715 L p F P
0 0 0 r
s
.225 .314 .442 r
.46273 .60715 m .47532 .60004 L .47508 .61567 L p F P
0 0 0 r
s
.497 .667 .854 r
.55993 .57879 m .543 .57555 L .54291 .56018 L p F P
0 0 0 r
s
.445 .599 .78 r
.5252 .55914 m .54291 .56018 L .543 .57555 L p F P
0 0 0 r
s
.69 .09 .12 r
.4805 .36528 m
.48092 .36458 L
s
.48092 .36458 m
.48066 .35483 L
s
.48092 .36458 m
.47093 .36026 L
s
.589 .795 .968 r
.58852 .62211 m .59832 .63041 L .59867 .64612 L p F P
0 0 0 r
s
.589 .795 .968 r
.59832 .63041 m .58852 .62211 L .58822 .60651 L p F P
0 0 0 r
s
.092 .135 .215 r
.60779 .73848 m .60269 .74754 L .60306 .76382 L p F P
0 0 0 r
s
.092 .135 .215 r
.60269 .74754 m .60779 .73848 L .60739 .72231 L p F P
0 0 0 r
s
.585 .785 .972 r
.57539 .59953 m .58822 .60651 L .58852 .62211 L p F P
0 0 0 r
s
.69 .09 .12 r
.76733 .47708 m
.74079 .4412 L
s
.445 .599 .78 r
.543 .57555 m .5252 .57451 L .5252 .55914 L p F P
0 0 0 r
s
.69 .09 .12 r
.58849 .81732 m
.5847 .82104 L
s
.58325 .81699 m
.58849 .81732 L
s
.48066 .35483 m
.48025 .35549 L
s
.48066 .35483 m
.47093 .36026 L
s
.58325 .81699 m
.5847 .82104 L
s
.54122 .24975 m
.55295 .25854 L
s
.54122 .24975 m
.55546 .24634 L
s
.335 .477 .554 r
.44272 .72979 m .44436 .73925 L .44476 .72308 L p F P
0 0 0 r
s
.335 .477 .554 r
.44476 .72308 m .44312 .71356 L .44272 .72979 L p F P
0 0 0 r
s
.69 .09 .12 r
.42126 .24987 m
.42357 .24946 L
s
.42357 .24946 m
.42178 .23565 L
s
.42357 .24946 m
.40814 .24441 L
s
.53358 .47585 m
.53944 .48036 L
s
.53358 .47585 m
.54069 .47434 L
s
.06 .089 .131 r
.60872 .71277 m .60739 .72231 L .60779 .73848 L p F P
0 0 0 r
s
.06 .089 .131 r
.60739 .72231 m .60872 .71277 L .60831 .69669 L p F P
0 0 0 r
s
.69 .09 .12 r
.54069 .47434 m
.53944 .48036 L
s
.42178 .23565 m
.41946 .23598 L
s
.42178 .23565 m
.40814 .24441 L
s
.55546 .24634 m
.55295 .25854 L
s
.47861 .13396 m
.49404 .14281 L
s
.47861 .13396 m
.49503 .12681 L
s
.06 .088 .13 r
.44536 .70402 m .44312 .71356 L .44353 .69749 L p F P
0 0 0 r
s
.06 .088 .13 r
.44353 .69749 m .44576 .68789 L .44536 .70402 L p F P
0 0 0 r
s
.69 .09 .12 r
.47093 .36026 m
.4805 .36528 L
s
.47093 .36026 m
.48025 .35549 L
s
.51922 .35921 m
.47093 .36026 L
s
.46696 .58809 m
.46853 .58715 L
s
.46705 .58306 m
.46853 .58715 L
s
.46324 .58677 m
.46853 .58715 L
s
.336 .459 .619 r
.50735 .59125 m .49044 .59465 L .49061 .57915 L p F P
0 0 0 r
s
.336 .459 .619 r
.49061 .57915 m .50744 .57573 L .50735 .59125 L p F P
0 0 0 r
s
.338 .478 .556 r
.60576 .68711 m .60831 .69669 L .60872 .71277 L p F P
0 0 0 r
s
.338 .478 .556 r
.60831 .69669 m .60576 .68711 L .60537 .67114 L p F P
0 0 0 r
s
.69 .09 .12 r
.46705 .58306 m
.46547 .58399 L
s
.46324 .58677 m
.46705 .58306 L
s
.46324 .58677 m
.46696 .58809 L
s
.46324 .58677 m
.46547 .58399 L
s
.46324 .58677 m
.4821 .58078 L
s
.546 .732 .922 r
.57539 .59953 m .5601 .59429 L .55993 .57879 L p F P
0 0 0 r
s
.497 .667 .854 r
.543 .57555 m .55993 .57879 L .5601 .59429 L p F P
0 0 0 r
s
.69 .09 .12 r
.45555 .8135 m
.45334 .81429 L
s
.45345 .80889 m
.45555 .8135 L
s
.45555 .8135 m
.45071 .81233 L
s
.45608 .81085 m
.45555 .8135 L
s
.40814 .24441 m
.42126 .24987 L
s
.40814 .24441 m
.41946 .23598 L
s
.47529 .23606 m
.40814 .24441 L
s
.40767 .47342 m
.41102 .47193 L
s
.41102 .47193 m
.40804 .4637 L
s
.41102 .47193 m
.40041 .47111 L
s
.09 .133 .211 r
.45182 .67873 m .44576 .68789 L .44615 .67192 L p F P
0 0 0 r
s
.09 .133 .211 r
.44615 .67192 m .45218 .66271 L .45182 .67873 L p F P
0 0 0 r
s
.69 .09 .12 r
.40804 .4637 m
.40467 .46516 L
s
.40804 .4637 m
.40041 .47111 L
s
.45345 .80889 m
.45071 .81233 L
s
.45608 .81085 m
.45345 .80889 L
s
.40041 .47111 m
.40767 .47342 L
s
.40041 .47111 m
.40467 .46516 L
s
.43784 .45823 m
.40041 .47111 L
s
.603 .821 .995 r
.44864 .79757 m .45762 .80556 L .45795 .78901 L p F P
0 0 0 r
s
.69 .09 .12 r
.44471 .80392 m
.45555 .8135 L
s
.603 .821 .995 r
.45795 .78901 m .44902 .78097 L .44864 .79757 L p F P
0 0 0 r
s
.497 .683 .822 r
.59903 .66199 m .60537 .67114 L .60576 .68711 L p F P
0 0 0 r
s
.497 .683 .822 r
.60537 .67114 m .59903 .66199 L .59867 .64612 L p F P
0 0 0 r
s
.69 .09 .12 r
.73117 .69854 m
.7331 .67194 L
s
.45071 .81233 m
.45334 .81429 L
s
.49503 .12681 m
.49404 .14281 L
s
.48025 .35549 m
.4805 .36528 L
s
.281 .388 .533 r
.49027 .6103 m .47508 .61567 L .47532 .60004 L p F P
0 0 0 r
s
.281 .388 .533 r
.47532 .60004 m .49044 .59465 L .49027 .6103 L p F P
0 0 0 r
s
.69 .09 .12 r
.34807 .35814 m
.35342 .3565 L
s
.35342 .3565 m
.34891 .34409 L
s
.35342 .3565 m
.33744 .3552 L
s
.46547 .58399 m
.46696 .58809 L
s
.222 .311 .441 r
.58333 .81185 m .59512 .80494 L .59478 .78839 L p F P
0 0 0 r
s
.158 .22 .329 r
.60344 .78027 m .59478 .78839 L .59512 .80494 L p F P
0 0 0 r
s
.158 .22 .329 r
.59478 .78839 m .60344 .78027 L .60306 .76382 L p F P
0 0 0 r
s
.69 .09 .12 r
.39268 .69803 m
.39401 .69855 L
s
.39431 .69116 m
.39268 .69803 L
s
.39268 .69803 m
.3899 .69417 L
s
.39842 .69553 m
.39268 .69803 L
s
.40012 .682 m
.39268 .69803 L
s
.164 .227 .334 r
.4618 .65439 m .45218 .66271 L .45254 .64685 L p F P
0 0 0 r
s
.164 .227 .334 r
.45254 .64685 m .46211 .63849 L .4618 .65439 L p F P
0 0 0 r
s
.491 .682 .818 r
.44356 .77208 m .44902 .78097 L .4494 .76453 L p F P
0 0 0 r
s
.491 .682 .818 r
.4494 .76453 m .44396 .75559 L .44356 .77208 L p F P
0 0 0 r
s
.585 .785 .972 r
.58852 .62211 m .57563 .61516 L .57539 .59953 L p F P
0 0 0 r
s
.546 .732 .922 r
.5601 .59429 m .57539 .59953 L .57563 .61516 L p F P
0 0 0 r
s
.391 .529 .701 r
.52519 .59003 m .50735 .59125 L .50744 .57573 L p F P
0 0 0 r
s
.391 .529 .701 r
.50744 .57573 m .5252 .57451 L .52519 .59003 L p F P
0 0 0 r
s
.69 .09 .12 r
.34891 .34409 m
.34354 .34567 L
s
.34891 .34409 m
.33744 .3552 L
s
.225 .314 .442 r
.47483 .63145 m .46211 .63849 L .46242 .62274 L p F P
0 0 0 r
s
.225 .314 .442 r
.46242 .62274 m .47508 .61567 L .47483 .63145 L p F P
0 0 0 r
s
.497 .667 .854 r
.5601 .59429 m .54308 .59107 L .543 .57555 L p F P
0 0 0 r
s
.445 .599 .78 r
.5252 .57451 m .543 .57555 L .54308 .59107 L p F P
0 0 0 r
s
.589 .795 .968 r
.58883 .63786 m .59867 .64612 L .59903 .66199 L p F P
0 0 0 r
s
.589 .795 .968 r
.59867 .64612 m .58883 .63786 L .58852 .62211 L p F P
0 0 0 r
s
.69 .09 .12 r
.33744 .3552 m
.34807 .35814 L
s
.33744 .3552 m
.34354 .34567 L
s
.39316 .33452 m
.33744 .3552 L
s
.092 .135 .215 r
.60819 .75482 m .60306 .76382 L .60344 .78027 L p F P
0 0 0 r
s
.092 .135 .215 r
.60306 .76382 m .60819 .75482 L .60779 .73848 L p F P
0 0 0 r
s
.69 .09 .12 r
.45334 .81429 m
.45608 .81085 L
s
.585 .785 .972 r
.57563 .61516 m .58852 .62211 L .58883 .63786 L p F P
0 0 0 r
s
.69 .09 .12 r
.72468 .35477 m
.67714 .3233 L
s
.39431 .69116 m
.3899 .69417 L
s
.39842 .69553 m
.39431 .69116 L
s
.445 .599 .78 r
.54308 .59107 m .52519 .59003 L .5252 .57451 L p F P
0 0 0 r
s
.69 .09 .12 r
.32967 .58232 m
.33436 .58334 L
s
.33504 .57205 m
.32967 .58232 L
s
.32967 .58232 m
.32874 .57536 L
s
.34065 .58 m
.32967 .58232 L
s
.3551 .55891 m
.32967 .58232 L
s
.335 .477 .554 r
.44231 .74618 m .44396 .75559 L .44436 .73925 L p F P
0 0 0 r
s
.335 .477 .554 r
.44436 .73925 m .44272 .72979 L .44231 .74618 L p F P
0 0 0 r
s
.69 .09 .12 r
.3219 .80965 m
.32052 .81084 L
s
.32125 .79873 m
.3219 .80965 L
s
.3219 .80965 m
.31395 .80489 L
s
.32782 .80466 m
.3219 .80965 L
s
.31676 .78491 m
.3219 .80965 L
s
.39401 .69855 m
.39842 .69553 L
s
.06 .089 .131 r
.60912 .729 m .60779 .73848 L .60819 .75482 L p F P
0 0 0 r
s
.06 .089 .131 r
.60779 .73848 m .60912 .729 L .60872 .71277 L p F P
0 0 0 r
s
.69 .09 .12 r
.33504 .57205 m
.32874 .57536 L
s
.34065 .58 m
.33504 .57205 L
s
.26653 .46634 m
.27439 .46781 L
s
.27566 .45241 m
.26653 .46634 L
s
.26653 .46634 m
.26724 .45589 L
s
.28278 .46428 m
.26653 .46634 L
s
.30964 .43464 m
.26653 .46634 L
s
.41946 .23598 m
.42126 .24987 L
s
.33436 .58334 m
.34065 .58 L
s
.3899 .69417 m
.39401 .69855 L
s
.40467 .46516 m
.40767 .47342 L
s
.25871 .69387 m
.26052 .69489 L
s
.26172 .68007 m
.25871 .69387 L
s
.25871 .69387 m
.25244 .6861 L
s
.26979 .68883 m
.25871 .69387 L
s
.27096 .66129 m
.25871 .69387 L
s
.06 .088 .13 r
.44497 .7203 m .44272 .72979 L .44312 .71356 L p F P
0 0 0 r
s
.06 .088 .13 r
.44312 .71356 m .44536 .70402 L .44497 .7203 L p F P
0 0 0 r
s
.336 .459 .619 r
.50726 .60692 m .49027 .6103 L .49044 .59465 L p F P
0 0 0 r
s
.336 .459 .619 r
.49044 .59465 m .50735 .59125 L .50726 .60692 L p F P
0 0 0 r
s
.69 .09 .12 r
.27566 .45241 m
.26724 .45589 L
s
.28278 .46428 m
.27566 .45241 L
s
.32125 .79873 m
.31395 .80489 L
s
.32782 .80466 m
.32125 .79873 L
s
.338 .478 .556 r
.60615 .70324 m .60872 .71277 L .60912 .729 L p F P
0 0 0 r
s
.338 .478 .556 r
.60872 .71277 m .60615 .70324 L .60576 .68711 L p F P
0 0 0 r
s
.69 .09 .12 r
.92177 .79087 m
.93524 .80422 L
s
.91095 .80043 m
.92177 .79087 L
s
.92177 .79087 m
.93089 .79333 L
s
.27439 .46781 m
.28278 .46428 L
s
.546 .732 .922 r
.57563 .61516 m .56026 .60994 L .5601 .59429 L p F P
0 0 0 r
s
.497 .667 .854 r
.54308 .59107 m .5601 .59429 L .56026 .60994 L p F P
0 0 0 r
s
.69 .09 .12 r
.19538 .57784 m
.2002 .57887 L
s
.20207 .56063 m
.19538 .57784 L
s
.19538 .57784 m
.19057 .56664 L
s
.21166 .5728 m
.19538 .57784 L
s
.22471 .53646 m
.19538 .57784 L
s
.09 .133 .211 r
.45145 .69491 m .44536 .70402 L .44576 .68789 L p F P
0 0 0 r
s
.09 .133 .211 r
.44576 .68789 m .45182 .67873 L .45145 .69491 L p F P
0 0 0 r
s
.69 .09 .12 r
.18752 .80579 m
.18612 .8077 L
s
.18808 .78813 m
.18752 .80579 L
s
.18752 .80579 m
.17576 .79737 L
s
.19844 .79841 m
.18752 .80579 L
s
.18539 .76541 m
.18752 .80579 L
s
.6882 .57684 m
.6694 .55424 L
s
.497 .683 .822 r
.59939 .67801 m .60576 .68711 L .60615 .70324 L p F P
0 0 0 r
s
.497 .683 .822 r
.60576 .68711 m .59939 .67801 L .59903 .66199 L p F P
0 0 0 r
s
.69 .09 .12 r
.26172 .68007 m
.25244 .6861 L
s
.26979 .68883 m
.26172 .68007 L
s
.281 .388 .533 r
.49009 .62611 m .47483 .63145 L .47508 .61567 L p F P
0 0 0 r
s
.281 .388 .533 r
.47508 .61567 m .49027 .6103 L .49009 .62611 L p F P
0 0 0 r
s
.158 .22 .329 r
.59512 .80494 m .60382 .79687 L .60344 .78027 L p F P
0 0 0 r
s
.69 .09 .12 r
.31395 .80489 m
.32052 .81084 L
s
.164 .227 .334 r
.46148 .67046 m .45182 .67873 L .45218 .66271 L p F P
0 0 0 r
s
.164 .227 .334 r
.45218 .66271 m .4618 .65439 L .46148 .67046 L p F P
0 0 0 r
s
.69 .09 .12 r
.32052 .81084 m
.32782 .80466 L
s
.491 .682 .818 r
.44315 .78874 m .44864 .79757 L .44902 .78097 L p F P
0 0 0 r
s
.491 .682 .818 r
.44902 .78097 m .44356 .77208 L .44315 .78874 L p F P
0 0 0 r
s
.585 .785 .972 r
.58883 .63786 m .57588 .63095 L .57563 .61516 L p F P
0 0 0 r
s
.546 .732 .922 r
.56026 .60994 m .57563 .61516 L .57588 .63095 L p F P
0 0 0 r
s
.69 .09 .12 r
.34354 .34567 m
.34807 .35814 L
s
.391 .529 .701 r
.52519 .60571 m .50726 .60692 L .50735 .59125 L p F P
0 0 0 r
s
.391 .529 .701 r
.50735 .59125 m .52519 .59003 L .52519 .60571 L p F P
0 0 0 r
s
.69 .09 .12 r
.32874 .57536 m
.33436 .58334 L
s
.225 .314 .442 r
.47457 .64739 m .4618 .65439 L .46211 .63849 L p F P
0 0 0 r
s
.225 .314 .442 r
.46211 .63849 m .47483 .63145 L .47457 .64739 L p F P
0 0 0 r
s
.497 .667 .854 r
.56026 .60994 m .54316 .60674 L .54308 .59107 L p F P
0 0 0 r
s
.445 .599 .78 r
.52519 .59003 m .54308 .59107 L .54316 .60674 L p F P
0 0 0 r
s
.69 .09 .12 r
.93524 .80422 m
.92446 .81386 L
s
.93089 .79333 m
.93524 .80422 L
s
.12402 .68969 m
.12544 .69118 L
s
.12816 .66891 m
.12402 .68969 L
s
.12402 .68969 m
.11353 .67793 L
s
.14004 .68207 m
.12402 .68969 L
s
.13833 .64002 m
.12402 .68969 L
s
.589 .795 .968 r
.58914 .65376 m .59903 .66199 L .59939 .67801 L p F P
0 0 0 r
s
.589 .795 .968 r
.59903 .66199 m .58914 .65376 L .58883 .63786 L p F P
0 0 0 r
s
.092 .135 .215 r
.6086 .77132 m .60344 .78027 L .60382 .79687 L p F P
0 0 0 r
s
.092 .135 .215 r
.60344 .78027 m .6086 .77132 L .60819 .75482 L p F P
0 0 0 r
s
.69 .09 .12 r
.68162 .2313 m
.61334 .20513 L
s
.86338 .67539 m
.87543 .68538 L
s
.85327 .68426 m
.86338 .67539 L
s
.86338 .67539 m
.86767 .67622 L
s
.585 .785 .972 r
.57588 .63095 m .58883 .63786 L .58914 .65376 L p F P
0 0 0 r
s
.69 .09 .12 r
.20207 .56063 m
.19057 .56664 L
s
.21166 .5728 m
.20207 .56063 L
s
.26052 .69489 m
.26979 .68883 L
s
.445 .599 .78 r
.54316 .60674 m .52519 .60571 L .52519 .59003 L p F P
0 0 0 r
s
.335 .477 .554 r
.44189 .76273 m .44356 .77208 L .44396 .75559 L p F P
0 0 0 r
s
.335 .477 .554 r
.44396 .75559 m .44231 .74618 L .44189 .76273 L p F P
0 0 0 r
s
.06 .089 .131 r
.60953 .7454 m .60819 .75482 L .6086 .77132 L p F P
0 0 0 r
s
.06 .089 .131 r
.60819 .75482 m .60953 .7454 L .60912 .729 L p F P
0 0 0 r
s
.69 .09 .12 r
.2002 .57887 m
.21166 .5728 L
s
.18808 .78813 m
.17576 .79737 L
s
.19844 .79841 m
.18808 .78813 L
s
.06 .088 .13 r
.44456 .73675 m .44231 .74618 L .44272 .72979 L p F P
0 0 0 r
s
.06 .088 .13 r
.44272 .72979 m .44497 .7203 L .44456 .73675 L p F P
0 0 0 r
s
.69 .09 .12 r
.25244 .6861 m
.26052 .69489 L
s
.80467 .55889 m
.81528 .56586 L
s
.79548 .56788 m
.80467 .55889 L
s
.80467 .55889 m
.8043 .55884 L
s
.65146 .8005 m
.66166 .7854 L
s
.92446 .81386 m
.91095 .80043 L
s
.91095 .80043 m
.93089 .79333 L
s
.336 .459 .619 r
.50716 .62274 m .49009 .62611 L .49027 .6103 L p F P
0 0 0 r
s
.336 .459 .619 r
.49027 .6103 m .50726 .60692 L .50716 .62274 L p F P
0 0 0 r
s
.69 .09 .12 r
.26724 .45589 m
.27439 .46781 L
s
.338 .478 .556 r
.60655 .71953 m .60912 .729 L .60953 .7454 L p F P
0 0 0 r
s
.338 .478 .556 r
.60912 .729 m .60655 .71953 L .60615 .70324 L p F P
0 0 0 r
s
.69 .09 .12 r
.87543 .68538 m
.86533 .69429 L
s
.86767 .67622 m
.87543 .68538 L
s
.12816 .66891 m
.11353 .67793 L
s
.14004 .68207 m
.12816 .66891 L
s
.546 .732 .922 r
.57588 .63095 m .56043 .62575 L .56026 .60994 L p F P
0 0 0 r
s
.497 .667 .854 r
.54316 .60674 m .56026 .60994 L .56043 .62575 L p F P
0 0 0 r
s
.69 .09 .12 r
.86533 .69429 m
.85327 .68426 L
s
.85327 .68426 m
.86767 .67622 L
s
.09 .133 .211 r
.45108 .71124 m .44497 .7203 L .44536 .70402 L p F P
0 0 0 r
s
.09 .133 .211 r
.44536 .70402 m .45145 .69491 L .45108 .71124 L p F P
0 0 0 r
s
.69 .09 .12 r
.64482 .45399 m
.60557 .43627 L
s
.79139 .78775 m
.80023 .7967 L
s
.78373 .79414 m
.79139 .78775 L
s
.79139 .78775 m
.79664 .78938 L
s
.18612 .8077 m
.19844 .79841 L
s
.497 .683 .822 r
.59975 .69419 m .60615 .70324 L .60655 .71953 L p F P
0 0 0 r
s
.497 .683 .822 r
.60615 .70324 m .59975 .69419 L .59939 .67801 L p F P
0 0 0 r
s
.281 .388 .533 r
.48991 .64207 m .47457 .64739 L .47483 .63145 L p F P
0 0 0 r
s
.281 .388 .533 r
.47483 .63145 m .49009 .62611 L .48991 .64207 L p F P
0 0 0 r
s
.69 .09 .12 r
.80609 .5749 m
.79548 .56788 L
s
.79548 .56788 m
.8043 .55884 L
s
.74566 .44119 m
.7548 .44568 L
s
.73759 .4513 m
.74566 .44119 L
s
.74566 .44119 m
.74079 .4412 L
s
.164 .227 .334 r
.46116 .68667 m .45145 .69491 L .45182 .67873 L p F P
0 0 0 r
s
.164 .227 .334 r
.45182 .67873 m .46148 .67046 L .46116 .68667 L p F P
0 0 0 r
s
.585 .785 .972 r
.58914 .65376 m .57613 .64689 L .57588 .63095 L p F P
0 0 0 r
s
.546 .732 .922 r
.56043 .62575 m .57588 .63095 L .57613 .64689 L p F P
0 0 0 r
s
.69 .09 .12 r
.93089 .79333 m
.92446 .81386 L
s
.17576 .79737 m
.18612 .8077 L
s
.391 .529 .701 r
.52519 .62154 m .50716 .62274 L .50726 .60692 L p F P
0 0 0 r
s
.391 .529 .701 r
.50726 .60692 m .52519 .60571 L .52519 .62154 L p F P
0 0 0 r
s
.225 .314 .442 r
.47432 .66349 m .46148 .67046 L .4618 .65439 L p F P
0 0 0 r
s
.225 .314 .442 r
.4618 .65439 m .47457 .64739 L .47432 .66349 L p F P
0 0 0 r
s
.497 .667 .854 r
.56043 .62575 m .54325 .62256 L .54316 .60674 L p F P
0 0 0 r
s
.445 .599 .78 r
.52519 .60571 m .54316 .60674 L .54325 .62256 L p F P
0 0 0 r
s
.69 .09 .12 r
.12544 .69118 m
.14004 .68207 L
s
.63816 .10666 m
.54941 .08669 L
s
.85919 .79706 m
.87603 .75618 L
s
.589 .795 .968 r
.58945 .66983 m .59939 .67801 L .59975 .69419 L p F P
0 0 0 r
s
.589 .795 .968 r
.59939 .67801 m .58945 .66983 L .58914 .65376 L p F P
0 0 0 r
s
.092 .135 .215 r
.60382 .79687 m .60901 .78798 L .6086 .77132 L p F P
0 0 0 r
s
.69 .09 .12 r
.19057 .56664 m
.2002 .57887 L
s
.80023 .7967 m
.79259 .80312 L
s
.79664 .78938 m
.80023 .7967 L
s
.585 .785 .972 r
.57613 .64689 m .58914 .65376 L .58945 .66983 L p F P
0 0 0 r
s
.69 .09 .12 r
.74672 .45583 m
.73759 .4513 L
s
.73759 .4513 m
.74079 .4412 L
s
.445 .599 .78 r
.54325 .62256 m .52519 .62154 L .52519 .60571 L p F P
0 0 0 r
s
.69 .09 .12 r
.81528 .56586 m
.80609 .5749 L
s
.8043 .55884 m
.81528 .56586 L
s
.335 .477 .554 r
.44147 .77945 m .44315 .78874 L .44356 .77208 L p F P
0 0 0 r
s
.335 .477 .554 r
.44356 .77208 m .44189 .76273 L .44147 .77945 L p F P
0 0 0 r
s
.69 .09 .12 r
.86767 .67622 m
.86533 .69429 L
s
.68636 .32226 m
.69398 .32481 L
s
.6796 .33451 m
.68636 .32226 L
s
.68636 .32226 m
.67714 .3233 L
s
.73234 .67147 m
.73973 .67721 L
s
.72568 .67746 m
.73234 .67147 L
s
.73234 .67147 m
.7331 .67194 L
s
.68718 .33712 m
.6796 .33451 L
s
.6796 .33451 m
.67714 .3233 L
s
.06 .089 .131 r
.60995 .76195 m .6086 .77132 L .60901 .78798 L p F P
0 0 0 r
s
.06 .089 .131 r
.6086 .77132 m .60995 .76195 L .60953 .7454 L p F P
0 0 0 r
s
.69 .09 .12 r
.79259 .80312 m
.78373 .79414 L
s
.78373 .79414 m
.79664 .78938 L
s
.62744 .21858 m
.62151 .21752 L
s
.62151 .21752 m
.62685 .2023 L
s
.62151 .21752 m
.61334 .20513 L
s
.06 .088 .13 r
.44416 .75336 m .44189 .76273 L .44231 .74618 L p F P
0 0 0 r
s
.06 .088 .13 r
.44231 .74618 m .44456 .73675 L .44416 .75336 L p F P
0 0 0 r
s
.69 .09 .12 r
.8043 .55884 m
.80609 .5749 L
s
.11353 .67793 m
.12544 .69118 L
s
.336 .459 .619 r
.50707 .63872 m .48991 .64207 L .49009 .62611 L p F P
0 0 0 r
s
.336 .459 .619 r
.49009 .62611 m .50716 .62274 L .50707 .63872 L p F P
0 0 0 r
s
.69 .09 .12 r
.62685 .2023 m
.63281 .20326 L
s
.62685 .2023 m
.61334 .20513 L
s
.338 .478 .556 r
.60695 .73598 m .60953 .7454 L .60995 .76195 L p F P
0 0 0 r
s
.338 .478 .556 r
.60953 .7454 m .60695 .73598 L .60655 .71953 L p F P
0 0 0 r
s
.546 .732 .922 r
.57613 .64689 m .56061 .64172 L .56043 .62575 L p F P
0 0 0 r
s
.497 .667 .854 r
.54325 .62256 m .56043 .62575 L .56061 .64172 L p F P
0 0 0 r
s
.69 .09 .12 r
.73308 .68322 m
.72568 .67746 L
s
.72568 .67746 m
.7331 .67194 L
s
.56743 .09993 m
.56331 .10032 L
s
.56331 .10032 m
.56715 .08156 L
s
.56331 .10032 m
.54941 .08669 L
s
.73973 .67721 m
.73308 .68322 L
s
.7331 .67194 m
.73973 .67721 L
s
.67297 .55374 m
.67889 .55704 L
s
.66753 .56057 m
.67297 .55374 L
s
.67297 .55374 m
.6694 .55424 L
s
.79664 .78938 m
.79259 .80312 L
s
.7548 .44568 m
.74672 .45583 L
s
.74079 .4412 m
.7548 .44568 L
s
.09 .133 .211 r
.45071 .72774 m .44456 .73675 L .44497 .7203 L p F P
0 0 0 r
s
.09 .133 .211 r
.44497 .7203 m .45108 .71124 L .45071 .72774 L p F P
0 0 0 r
s
.69 .09 .12 r
.60102 .32996 m
.54159 .31804 L
s
.67344 .56389 m
.66753 .56057 L
s
.66753 .56057 m
.6694 .55424 L
s
.56715 .08156 m
.5713 .08103 L
s
.56715 .08156 m
.54941 .08669 L
s
.497 .683 .822 r
.60012 .71053 m .60655 .71953 L .60695 .73598 L p F P
0 0 0 r
s
.497 .683 .822 r
.60655 .71953 m .60012 .71053 L .59975 .69419 L p F P
0 0 0 r
s
.281 .388 .533 r
.48973 .6582 m .47432 .66349 L .47457 .64739 L p F P
0 0 0 r
s
.281 .388 .533 r
.47457 .64739 m .48991 .64207 L .48973 .6582 L p F P
0 0 0 r
s
.69 .09 .12 r
.74079 .4412 m
.74672 .45583 L
s
.164 .227 .334 r
.46084 .70306 m .45108 .71124 L .45145 .69491 L p F P
0 0 0 r
s
.164 .227 .334 r
.45145 .69491 m .46116 .68667 L .46084 .70306 L p F P
0 0 0 r
s
.585 .785 .972 r
.58945 .66983 m .57638 .66298 L .57613 .64689 L p F P
0 0 0 r
s
.546 .732 .922 r
.56061 .64172 m .57613 .64689 L .57638 .66298 L p F P
0 0 0 r
s
.69 .09 .12 r
.61364 .44532 m
.60928 .44347 L
s
.60928 .44347 m
.61332 .43438 L
s
.60928 .44347 m
.60557 .43627 L
s
.391 .529 .701 r
.52518 .63752 m .50707 .63872 L .50716 .62274 L p F P
0 0 0 r
s
.391 .529 .701 r
.50716 .62274 m .52519 .62154 L .52518 .63752 L p F P
0 0 0 r
s
.69 .09 .12 r
.81637 .67453 m
.81112 .63602 L
s
.7331 .67194 m
.73308 .68322 L
s
.65945 .7846 m
.6638 .78909 L
s
.6554 .7878 m
.65945 .7846 L
s
.65945 .7846 m
.66166 .7854 L
s
.225 .314 .442 r
.47406 .67975 m .46116 .68667 L .46148 .67046 L p F P
0 0 0 r
s
.225 .314 .442 r
.46148 .67046 m .47432 .66349 L .47406 .67975 L p F P
0 0 0 r
s
.497 .667 .854 r
.56061 .64172 m .54334 .63854 L .54325 .62256 L p F P
0 0 0 r
s
.445 .599 .78 r
.52519 .62154 m .54325 .62256 L .54334 .63854 L p F P
0 0 0 r
s
.69 .09 .12 r
.61332 .43438 m
.6177 .4362 L
s
.61332 .43438 m
.60557 .43627 L
s
.589 .795 .968 r
.58977 .68605 m .59975 .69419 L .60012 .71053 L p F P
0 0 0 r
s
.589 .795 .968 r
.59975 .69419 m .58977 .68605 L .58945 .66983 L p F P
0 0 0 r
s
.69 .09 .12 r
.59779 .66764 m
.60775 .67827 L
s
.585 .785 .972 r
.57638 .66298 m .58945 .66983 L .58977 .68605 L p F P
0 0 0 r
s
.445 .599 .78 r
.54334 .63854 m .52518 .63752 L .52519 .62154 L p F P
0 0 0 r
s
.69 .09 .12 r
.6638 .78909 m
.65976 .7923 L
s
.66166 .7854 m
.6638 .78909 L
s
.5536 .32711 m
.55092 .32617 L
s
.55092 .32617 m
.55347 .31379 L
s
.55092 .32617 m
.54159 .31804 L
s
.67889 .55704 m
.67344 .56389 L
s
.6694 .55424 m
.67889 .55704 L
s
.06 .089 .131 r
.60901 .78798 m .61037 .77868 L .60995 .76195 L p F P
0 0 0 r
s
.69 .09 .12 r
.55347 .31379 m
.55617 .31467 L
s
.55347 .31379 m
.54159 .31804 L
s
.69398 .32481 m
.68718 .33712 L
s
.67714 .3233 m
.69398 .32481 L
s
.67714 .3233 m
.68718 .33712 L
s
.65976 .7923 m
.6554 .7878 L
s
.6554 .7878 m
.66166 .7854 L
s
.49327 .20876 m
.49246 .20866 L
s
.49246 .20866 m
.49346 .19245 L
s
.49246 .20866 m
.47747 .19954 L
s
.6694 .55424 m
.67344 .56389 L
s
.59973 .66714 m
.6026 .66895 L
s
.59698 .6706 m
.59973 .66714 L
s
.59973 .66714 m
.59779 .66764 L
s
.66166 .7854 m
.65976 .7923 L
s
.06 .088 .13 r
.44375 .77013 m .44147 .77945 L .44189 .76273 L p F P
0 0 0 r
s
.06 .088 .13 r
.44189 .76273 m .44416 .75336 L .44375 .77013 L p F P
0 0 0 r
s
.69 .09 .12 r
.56361 .55487 m
.53377 .54961 L
s
.59698 .6706 m
.59985 .67241 L
s
.59698 .6706 m
.59779 .66764 L
s
.49346 .19245 m
.49428 .19244 L
s
.49346 .19245 m
.47747 .19954 L
s
.336 .459 .619 r
.50698 .65487 m .48973 .6582 L .48991 .64207 L p F P
0 0 0 r
s
.336 .459 .619 r
.48991 .64207 m .50707 .63872 L .50698 .65487 L p F P
0 0 0 r
s
.338 .478 .556 r
.60735 .7526 m .60995 .76195 L .61037 .77868 L p F P
0 0 0 r
s
.338 .478 .556 r
.60995 .76195 m .60735 .7526 L .60695 .73598 L p F P
0 0 0 r
s
.546 .732 .922 r
.57638 .66298 m .56078 .65785 L .56061 .64172 L p F P
0 0 0 r
s
.497 .667 .854 r
.54334 .63854 m .56061 .64172 L .56078 .65785 L p F P
0 0 0 r
s
.69 .09 .12 r
.53977 .55426 m
.53846 .55319 L
s
.53846 .55319 m
.53974 .54707 L
s
.53846 .55319 m
.53377 .54961 L
s
.61334 .20513 m
.62744 .21858 L
s
.61334 .20513 m
.63281 .20326 L
s
.6026 .66895 m
.59985 .67241 L
s
.59779 .66764 m
.6026 .66895 L
s
.5568 .20474 m
.47747 .19954 L
s
.09 .133 .211 r
.45033 .7444 m .44416 .75336 L .44456 .73675 L p F P
0 0 0 r
s
.09 .133 .211 r
.44456 .73675 m .45071 .72774 L .45033 .7444 L p F P
0 0 0 r
s
.69 .09 .12 r
.63281 .20326 m
.62744 .21858 L
s
.6177 .4362 m
.61364 .44532 L
s
.60557 .43627 m
.61364 .44532 L
s
.53974 .54707 m
.54105 .54813 L
s
.53974 .54707 m
.53377 .54961 L
s
.59779 .66764 m
.59985 .67241 L
s
.60557 .43627 m
.6177 .4362 L
s
.497 .683 .822 r
.60049 .72703 m .60695 .73598 L .60735 .7526 L p F P
0 0 0 r
s
.497 .683 .822 r
.60695 .73598 m .60049 .72703 L .60012 .71053 L p F P
0 0 0 r
s
.69 .09 .12 r
.47941 .4366 m
.47984 .43558 L
s
.47984 .43558 m
.47957 .42564 L
s
.47984 .43558 m
.46961 .43131 L
s
.281 .388 .533 r
.48955 .67448 m .47406 .67975 L .47432 .66349 L p F P
0 0 0 r
s
.281 .388 .533 r
.47432 .66349 m .48973 .6582 L .48955 .67448 L p F P
0 0 0 r
s
.69 .09 .12 r
.54941 .08669 m
.56743 .09993 L
s
.54941 .08669 m
.5713 .08103 L
s
.164 .227 .334 r
.46051 .7196 m .45071 .72774 L .45108 .71124 L p F P
0 0 0 r
s
.164 .227 .334 r
.45108 .71124 m .46084 .70306 L .46051 .7196 L p F P
0 0 0 r
s
.585 .785 .972 r
.58977 .68605 m .57663 .67924 L .57638 .66298 L p F P
0 0 0 r
s
.546 .732 .922 r
.56078 .65785 m .57638 .66298 L .57663 .67924 L p F P
0 0 0 r
s
.69 .09 .12 r
.77313 .55081 m
.74606 .51559 L
s
.391 .529 .701 r
.52518 .65367 m .50698 .65487 L .50707 .63872 L p F P
0 0 0 r
s
.391 .529 .701 r
.50707 .63872 m .52518 .63752 L .52518 .65367 L p F P
0 0 0 r
s
.69 .09 .12 r
.47957 .42564 m
.47914 .42661 L
s
.47957 .42564 m
.46961 .43131 L
s
.225 .314 .442 r
.4738 .69617 m .46084 .70306 L .46116 .68667 L p F P
0 0 0 r
s
.225 .314 .442 r
.46116 .68667 m .47406 .67975 L .4738 .69617 L p F P
0 0 0 r
s
.69 .09 .12 r
.54159 .31804 m
.5536 .32711 L
s
.54159 .31804 m
.55617 .31467 L
s
.497 .667 .854 r
.56078 .65785 m .54342 .65468 L .54334 .63854 L p F P
0 0 0 r
s
.445 .599 .78 r
.52518 .63752 m .54334 .63854 L .54342 .65468 L p F P
0 0 0 r
s
.589 .795 .968 r
.59009 .70243 m .60012 .71053 L .60049 .72703 L p F P
0 0 0 r
s
.589 .795 .968 r
.60012 .71053 m .59009 .70243 L .58977 .68605 L p F P
0 0 0 r
s
.69 .09 .12 r
.41873 .31858 m
.42111 .31775 L
s
.42111 .31775 m
.41928 .30367 L
s
.42111 .31775 m
.4053 .31275 L
s
.585 .785 .972 r
.57663 .67924 m .58977 .68605 L .59009 .70243 L p F P
0 0 0 r
s
.69 .09 .12 r
.53377 .54961 m
.53977 .55426 L
s
.53377 .54961 m
.54105 .54813 L
s
.445 .599 .78 r
.54342 .65468 m .52518 .65367 L .52518 .63752 L p F P
0 0 0 r
s
.69 .09 .12 r
.01 w
.52594 .78141 Mdot
.5 Mabswid
.54105 .54813 m
.53977 .55426 L
s
.41928 .30367 m
.41689 .30441 L
s
.41928 .30367 m
.4053 .31275 L
s
.55617 .31467 m
.5536 .32711 L
s
.5713 .08103 m
.56743 .09993 L
s
.47747 .19954 m
.49327 .20876 L
s
.47747 .19954 m
.49428 .19244 L
s
.46961 .43131 m
.47941 .4366 L
s
.46961 .43131 m
.47914 .42661 L
s
.51905 .43028 m
.46961 .43131 L
s
.46553 .66479 m
.46715 .66368 L
s
.46563 .65951 m
.46715 .66368 L
s
.46173 .66331 m
.46715 .66368 L
s
.46563 .65951 m
.46402 .6606 L
s
.46563 .65951 m
.46173 .66331 L
s
.46173 .66331 m
.46553 .66479 L
s
.46173 .66331 m
.46402 .6606 L
s
.46173 .66331 m
.48104 .65746 L
s
.4053 .31275 m
.41873 .31858 L
s
.4053 .31275 m
.41689 .30441 L
s
.47407 .30449 m
.4053 .31275 L
s
.40481 .54755 m
.40825 .54575 L
s
.40825 .54575 m
.4052 .53735 L
s
.40825 .54575 m
.39739 .54495 L
s
.336 .459 .619 r
.50688 .67117 m .48955 .67448 L .48973 .6582 L p F P
0 0 0 r
s
.336 .459 .619 r
.48973 .6582 m .50698 .65487 L .50688 .67117 L p F P
0 0 0 r
s
.338 .478 .556 r
.61037 .77868 m .60776 .76938 L .60735 .7526 L p F P
0 0 0 r
s
.546 .732 .922 r
.57663 .67924 m .56095 .67413 L .56078 .65785 L p F P
0 0 0 r
s
.497 .667 .854 r
.54342 .65468 m .56078 .65785 L .56095 .67413 L p F P
0 0 0 r
s
.69 .09 .12 r
.4052 .53735 m
.40174 .53912 L
s
.4052 .53735 m
.39739 .54495 L
s
.39739 .54495 m
.40481 .54755 L
s
.39739 .54495 m
.40174 .53912 L
s
.4357 .53231 m
.39739 .54495 L
s
.73612 .77788 m
.73818 .75202 L
s
.49428 .19244 m
.49327 .20876 L
s
.47914 .42661 m
.47941 .4366 L
s
.34375 .42967 m
.34925 .42761 L
s
.34925 .42761 m
.34464 .41494 L
s
.34925 .42761 m
.33289 .42633 L
s
.46402 .6606 m
.46553 .66479 L
s
.09 .133 .211 r
.44995 .76124 m .44375 .77013 L .44416 .75336 L p F P
0 0 0 r
s
.09 .133 .211 r
.44416 .75336 m .45033 .7444 L .44995 .76124 L p F P
0 0 0 r
s
.69 .09 .12 r
.38947 .77739 m
.39082 .77818 L
s
.39113 .77043 m
.38947 .77739 L
s
.38947 .77739 m
.38661 .77364 L
s
.39533 .77495 m
.38947 .77739 L
s
.39705 .7618 m
.38947 .77739 L
s
.34464 .41494 m
.33911 .41693 L
s
.34464 .41494 m
.33289 .42633 L
s
.497 .683 .822 r
.60087 .7437 m .60735 .7526 L .60776 .76938 L p F P
0 0 0 r
s
.497 .683 .822 r
.60735 .7526 m .60087 .7437 L .60049 .72703 L p F P
0 0 0 r
s
.69 .09 .12 r
.33289 .42633 m
.34375 .42967 L
s
.33289 .42633 m
.33911 .41693 L
s
.38992 .40594 m
.33289 .42633 L
s
.281 .388 .533 r
.48937 .69093 m .4738 .69617 L .47406 .67975 L p F P
0 0 0 r
s
.281 .388 .533 r
.47406 .67975 m .48955 .67448 L .48937 .69093 L p F P
0 0 0 r
s
.69 .09 .12 r
.72948 .42591 m
.68085 .39487 L
s
.164 .227 .334 r
.46018 .73632 m .45033 .7444 L .45071 .72774 L p F P
0 0 0 r
s
.164 .227 .334 r
.45071 .72774 m .46051 .7196 L .46018 .73632 L p F P
0 0 0 r
s
.69 .09 .12 r
.39113 .77043 m
.38661 .77364 L
s
.39533 .77495 m
.39113 .77043 L
s
.585 .785 .972 r
.59009 .70243 m .57688 .69567 L .57663 .67924 L p F P
0 0 0 r
s
.546 .732 .922 r
.56095 .67413 m .57663 .67924 L .57688 .69567 L p F P
0 0 0 r
s
.69 .09 .12 r
.32493 .65896 m
.32971 .66037 L
s
.33043 .64853 m
.32493 .65896 L
s
.32493 .65896 m
.32396 .65217 L
s
.33617 .65671 m
.32493 .65896 L
s
.35091 .63609 m
.32493 .65896 L
s
.391 .529 .701 r
.52518 .66998 m .50688 .67117 L .50698 .65487 L p F P
0 0 0 r
s
.391 .529 .701 r
.50698 .65487 m .52518 .65367 L .52518 .66998 L p F P
0 0 0 r
s
.225 .314 .442 r
.47354 .71275 m .46051 .7196 L .46084 .70306 L p F P
0 0 0 r
s
.225 .314 .442 r
.46084 .70306 m .4738 .69617 L .47354 .71275 L p F P
0 0 0 r
s
.497 .667 .854 r
.56095 .67413 m .54351 .67099 L .54342 .65468 L p F P
0 0 0 r
s
.445 .599 .78 r
.52518 .65367 m .54342 .65468 L .54351 .67099 L p F P
0 0 0 r
s
.589 .795 .968 r
.59041 .71898 m .60049 .72703 L .60087 .7437 L p F P
0 0 0 r
s
.589 .795 .968 r
.60049 .72703 m .59041 .71898 L .59009 .70243 L p F P
0 0 0 r
s
.69 .09 .12 r
.39082 .77818 m
.39533 .77495 L
s
.585 .785 .972 r
.57688 .69567 m .59009 .70243 L .59041 .71898 L p F P
0 0 0 r
s
.445 .599 .78 r
.54351 .67099 m .52518 .66998 L .52518 .65367 L p F P
0 0 0 r
s
.69 .09 .12 r
.33043 .64853 m
.32396 .65217 L
s
.33617 .65671 m
.33043 .64853 L
s
.26025 .54027 m
.26827 .54223 L
s
.2696 .52608 m
.26025 .54027 L
s
.26025 .54027 m
.26095 .53001 L
s
.2769 .53825 m
.26025 .54027 L
s
.30432 .50914 m
.26025 .54027 L
s
.41689 .30441 m
.41873 .31858 L
s
.32971 .66037 m
.33617 .65671 L
s
.38661 .77364 m
.39082 .77818 L
s
.40174 .53912 m
.40481 .54755 L
s
.25225 .77335 m
.25406 .77491 L
s
.25531 .75936 m
.25225 .77335 L
s
.25225 .77335 m
.24579 .76579 L
s
.26357 .76844 m
.25225 .77335 L
s
.26466 .74167 m
.25225 .77335 L
s
.2696 .52608 m
.26095 .53001 L
s
.2769 .53825 m
.2696 .52608 L
s
.26827 .54223 m
.2769 .53825 L
s
.18738 .65459 m
.19224 .65626 L
s
.19421 .63712 m
.18738 .65459 L
s
.18738 .65459 m
.1824 .64365 L
s
.20402 .64967 m
.18738 .65459 L
s
.21723 .61414 m
.18738 .65459 L
s
.336 .459 .619 r
.50678 .68764 m .48937 .69093 L .48955 .67448 L p F P
0 0 0 r
s
.336 .459 .619 r
.48955 .67448 m .50688 .67117 L .50678 .68764 L p F P
0 0 0 r
s
.546 .732 .922 r
.57688 .69567 m .56113 .69058 L .56095 .67413 L p F P
0 0 0 r
s
.497 .667 .854 r
.54351 .67099 m .56095 .67413 L .56113 .69058 L p F P
0 0 0 r
s
.69 .09 .12 r
.69213 .65362 m
.67293 .63152 L
s
.25531 .75936 m
.24579 .76579 L
s
.26357 .76844 m
.25531 .75936 L
s
.33911 .41693 m
.34375 .42967 L
s
.32396 .65217 m
.32971 .66037 L
s
.497 .683 .822 r
.60776 .76938 m .60125 .76054 L .60087 .7437 L p F P
0 0 0 r
s
.69 .09 .12 r
.11427 .76928 m
.11563 .7716 L
s
.11848 .74822 m
.11427 .76928 L
s
.11427 .76928 m
.10345 .75785 L
s
.13064 .76188 m
.11427 .76928 L
s
.12862 .72097 m
.11427 .76928 L
s
.6854 .29979 m
.61549 .27388 L
s
.281 .388 .533 r
.48918 .70755 m .47354 .71275 L .4738 .69617 L p F P
0 0 0 r
s
.281 .388 .533 r
.4738 .69617 m .48937 .69093 L .48918 .70755 L p F P
0 0 0 r
s
.69 .09 .12 r
.87157 .75466 m
.88393 .76509 L
s
.86124 .764 m
.87157 .75466 L
s
.87157 .75466 m
.87603 .75618 L
s
.19421 .63712 m
.1824 .64365 L
s
.20402 .64967 m
.19421 .63712 L
s
.164 .227 .334 r
.45984 .7532 m .44995 .76124 L .45033 .7444 L p F P
0 0 0 r
s
.164 .227 .334 r
.45033 .7444 m .46018 .73632 L .45984 .7532 L p F P
0 0 0 r
s
.585 .785 .972 r
.59041 .71898 m .57714 .71226 L .57688 .69567 L p F P
0 0 0 r
s
.546 .732 .922 r
.56113 .69058 m .57688 .69567 L .57714 .71226 L p F P
0 0 0 r
s
.69 .09 .12 r
.25406 .77491 m
.26357 .76844 L
s
.391 .529 .701 r
.52517 .68646 m .50678 .68764 L .50688 .67117 L p F P
0 0 0 r
s
.391 .529 .701 r
.50688 .67117 m .52518 .66998 L .52517 .68646 L p F P
0 0 0 r
s
.225 .314 .442 r
.47327 .72951 m .46018 .73632 L .46051 .7196 L p F P
0 0 0 r
s
.225 .314 .442 r
.46051 .7196 m .47354 .71275 L .47327 .72951 L p F P
0 0 0 r
s
.497 .667 .854 r
.56113 .69058 m .5436 .68746 L .54351 .67099 L p F P
0 0 0 r
s
.445 .599 .78 r
.52518 .66998 m .54351 .67099 L .5436 .68746 L p F P
0 0 0 r
s
.589 .795 .968 r
.59073 .7357 m .60087 .7437 L .60125 .76054 L p F P
0 0 0 r
s
.589 .795 .968 r
.60087 .7437 m .59073 .7357 L .59041 .71898 L p F P
0 0 0 r
s
.585 .785 .972 r
.57714 .71226 m .59041 .71898 L .59073 .7357 L p F P
0 0 0 r
s
.445 .599 .78 r
.5436 .68746 m .52517 .68646 L .52518 .66998 L p F P
0 0 0 r
s
.69 .09 .12 r
.19224 .65626 m
.20402 .64967 L
s
.24579 .76579 m
.25406 .77491 L
s
.81145 .6355 m
.82234 .64289 L
s
.80205 .64486 m
.81145 .6355 L
s
.81145 .6355 m
.81112 .63602 L
s
.26095 .53001 m
.26827 .54223 L
s
.88393 .76509 m
.87361 .77449 L
s
.87603 .75618 m
.88393 .76509 L
s
.11848 .74822 m
.10345 .75785 L
s
.13064 .76188 m
.11848 .74822 L
s
.87361 .77449 m
.86124 .764 L
s
.86124 .764 m
.87603 .75618 L
s
.336 .459 .619 r
.50669 .70427 m .48918 .70755 L .48937 .69093 L p F P
0 0 0 r
s
.336 .459 .619 r
.48937 .69093 m .50678 .68764 L .50669 .70427 L p F P
0 0 0 r
s
.546 .732 .922 r
.57714 .71226 m .56131 .7072 L .56113 .69058 L p F P
0 0 0 r
s
.497 .667 .854 r
.5436 .68746 m .56113 .69058 L .56131 .7072 L p F P
0 0 0 r
s
.69 .09 .12 r
.64771 .52815 m
.60753 .51074 L
s
.81294 .6523 m
.80205 .64486 L
s
.80205 .64486 m
.81112 .63602 L
s
.75101 .51508 m
.7604 .51998 L
s
.74276 .5255 m
.75101 .51508 L
s
.75101 .51508 m
.74606 .51559 L
s
.11563 .7716 m
.13064 .76188 L
s
.64089 .17244 m
.54998 .15261 L
s
.1824 .64365 m
.19224 .65626 L
s
.281 .388 .533 r
.489 .72433 m .47327 .72951 L .47354 .71275 L p F P
0 0 0 r
s
.281 .388 .533 r
.47354 .71275 m .48918 .70755 L .489 .72433 L p F P
0 0 0 r
s
.69 .09 .12 r
.75212 .53045 m
.74276 .5255 L
s
.74276 .5255 m
.74606 .51559 L
s
.585 .785 .972 r
.59073 .7357 m .5774 .72901 L .57714 .71226 L p F P
0 0 0 r
s
.546 .732 .922 r
.56131 .7072 m .57714 .71226 L .5774 .72901 L p F P
0 0 0 r
s
.391 .529 .701 r
.52517 .7031 m .50669 .70427 L .50678 .68764 L p F P
0 0 0 r
s
.391 .529 .701 r
.50678 .68764 m .52517 .68646 L .52517 .7031 L p F P
0 0 0 r
s
.69 .09 .12 r
.82234 .64289 m
.81294 .6523 L
s
.81112 .63602 m
.82234 .64289 L
s
.225 .314 .442 r
.473 .74643 m .45984 .7532 L .46018 .73632 L p F P
0 0 0 r
s
.225 .314 .442 r
.46018 .73632 m .47327 .72951 L .473 .74643 L p F P
0 0 0 r
s
.497 .667 .854 r
.56131 .7072 m .54369 .70409 L .5436 .68746 L p F P
0 0 0 r
s
.445 .599 .78 r
.52517 .68646 m .5436 .68746 L .54369 .70409 L p F P
0 0 0 r
s
.589 .795 .968 r
.60125 .76054 m .59106 .75259 L .59073 .7357 L p F P
0 0 0 r
s
.69 .09 .12 r
.87603 .75618 m
.87361 .77449 L
s
.585 .785 .972 r
.5774 .72901 m .59073 .7357 L .59106 .75259 L p F P
0 0 0 r
s
.69 .09 .12 r
.69028 .39339 m
.6981 .39637 L
s
.68335 .40593 m
.69028 .39339 L
s
.69028 .39339 m
.68085 .39487 L
s
.73737 .75111 m
.74496 .75715 L
s
.73057 .75739 m
.73737 .75111 L
s
.73737 .75111 m
.73818 .75202 L
s
.69114 .40898 m
.68335 .40593 L
s
.68335 .40593 m
.68085 .39487 L
s
.445 .599 .78 r
.54369 .70409 m .52517 .7031 L .52517 .68646 L p F P
0 0 0 r
s
.69 .09 .12 r
.62993 .28769 m
.62384 .28615 L
s
.62384 .28615 m
.62931 .2706 L
s
.62384 .28615 m
.61549 .27388 L
s
.59955 .74784 m
.60975 .75818 L
s
.81112 .63602 m
.81294 .6523 L
s
.10345 .75785 m
.11563 .7716 L
s
.62931 .2706 m
.63544 .27204 L
s
.62931 .2706 m
.61549 .27388 L
s
.73815 .76345 m
.73057 .75739 L
s
.73057 .75739 m
.73818 .75202 L
s
.56845 .16629 m
.56423 .16614 L
s
.56423 .16614 m
.56816 .147 L
s
.56423 .16614 m
.54998 .15261 L
s
.74496 .75715 m
.73815 .76345 L
s
.73818 .75202 m
.74496 .75715 L
s
.67656 .63067 m
.68264 .63427 L
s
.671 .63771 m
.67656 .63067 L
s
.67656 .63067 m
.67293 .63152 L
s
.7604 .51998 m
.75212 .53045 L
s
.74606 .51559 m
.7604 .51998 L
s
.336 .459 .619 r
.50659 .72108 m .489 .72433 L .48918 .70755 L p F P
0 0 0 r
s
.336 .459 .619 r
.48918 .70755 m .50669 .70427 L .50659 .72108 L p F P
0 0 0 r
s
.69 .09 .12 r
.60286 .40145 m
.54198 .38969 L
s
.546 .732 .922 r
.5774 .72901 m .56149 .72399 L .56131 .7072 L p F P
0 0 0 r
s
.497 .667 .854 r
.54369 .70409 m .56131 .7072 L .56149 .72399 L p F P
0 0 0 r
s
.69 .09 .12 r
.67706 .64132 m
.671 .63771 L
s
.671 .63771 m
.67293 .63152 L
s
.56816 .147 m
.57242 .14698 L
s
.56816 .147 m
.54998 .15261 L
s
.74606 .51559 m
.75212 .53045 L
s
.6158 .52 m
.61132 .51782 L
s
.61132 .51782 m
.61546 .50852 L
s
.61132 .51782 m
.60753 .51074 L
s
.82348 .75454 m
.81828 .71708 L
s
.73818 .75202 m
.73815 .76345 L
s
.61546 .50852 m
.61996 .51067 L
s
.61546 .50852 m
.60753 .51074 L
s
.281 .388 .533 r
.48881 .74129 m .473 .74643 L .47327 .72951 L p F P
0 0 0 r
s
.281 .388 .533 r
.47327 .72951 m .489 .72433 L .48881 .74129 L p F P
0 0 0 r
s
.585 .785 .972 r
.59106 .75259 m .57766 .74594 L .5774 .72901 L p F P
0 0 0 r
s
.546 .732 .922 r
.56149 .72399 m .5774 .72901 L .57766 .74594 L p F P
0 0 0 r
s
.69 .09 .12 r
.55428 .39905 m
.55153 .39771 L
s
.55153 .39771 m
.55415 .38508 L
s
.55153 .39771 m
.54198 .38969 L
s
.391 .529 .701 r
.52516 .71991 m .50659 .72108 L .50669 .70427 L p F P
0 0 0 r
s
.391 .529 .701 r
.50669 .70427 m .52517 .7031 L .52516 .71991 L p F P
0 0 0 r
s
.497 .667 .854 r
.56149 .72399 m .54378 .7209 L .54369 .70409 L p F P
0 0 0 r
s
.445 .599 .78 r
.52517 .7031 m .54369 .70409 L .54378 .7209 L p F P
0 0 0 r
s
.69 .09 .12 r
.68264 .63427 m
.67706 .64132 L
s
.67293 .63152 m
.68264 .63427 L
s
.55415 .38508 m
.55691 .38636 L
s
.55415 .38508 m
.54198 .38969 L
s
.6981 .39637 m
.69114 .40898 L
s
.68085 .39487 m
.6981 .39637 L
s
.68085 .39487 m
.69114 .40898 L
s
.445 .599 .78 r
.54378 .7209 m .52516 .71991 L .52517 .7031 L p F P
0 0 0 r
s
.69 .09 .12 r
.49246 .27797 m
.49164 .27737 L
s
.49164 .27737 m
.49266 .26085 L
s
.49164 .27737 m
.47627 .26835 L
s
.67293 .63152 m
.67706 .64132 L
s
.60154 .74716 m
.60448 .74912 L
s
.59873 .75072 m
.60154 .74716 L
s
.60154 .74716 m
.59955 .74784 L
s
.56454 .63214 m
.53396 .627 L
s
.60167 .75269 m
.59873 .75072 L
s
.59873 .75072 m
.59955 .74784 L
s
.49266 .26085 m
.4935 .26132 L
s
.49266 .26085 m
.47627 .26835 L
s
.54011 .63181 m
.53877 .6305 L
s
.53877 .6305 m
.54008 .62426 L
s
.53877 .6305 m
.53396 .627 L
s
.61549 .27388 m
.62993 .28769 L
s
.61549 .27388 m
.63544 .27204 L
s
.60448 .74912 m
.60167 .75269 L
s
.59955 .74784 m
.60448 .74912 L
s
.55756 .2735 m
.47627 .26835 L
s
.336 .459 .619 r
.50649 .73805 m .48881 .74129 L .489 .72433 L p F P
0 0 0 r
s
.336 .459 .619 r
.489 .72433 m .50659 .72108 L .50649 .73805 L p F P
0 0 0 r
s
.69 .09 .12 r
.63544 .27204 m
.62993 .28769 L
s
.61996 .51067 m
.6158 .52 L
s
.60753 .51074 m
.6158 .52 L
s
.54008 .62426 m
.54142 .62555 L
s
.54008 .62426 m
.53396 .627 L
s
.59955 .74784 m
.60167 .75269 L
s
.546 .732 .922 r
.57766 .74594 m .56167 .74095 L .56149 .72399 L p F P
0 0 0 r
s
.497 .667 .854 r
.54378 .7209 m .56149 .72399 L .56167 .74095 L p F P
0 0 0 r
s
.69 .09 .12 r
.60753 .51074 m
.61996 .51067 L
s
.47826 .51143 m
.4787 .51006 L
s
.4787 .51006 m
.47843 .49993 L
s
.4787 .51006 m
.46822 .50587 L
s
.54998 .15261 m
.56845 .16629 L
s
.54998 .15261 m
.57242 .14698 L
s
.77922 .62818 m
.7516 .59371 L
s
.47843 .49993 m
.47799 .50126 L
s
.47843 .49993 m
.46822 .50587 L
s
.54198 .38969 m
.55428 .39905 L
s
.54198 .38969 m
.55691 .38636 L
s
.41607 .39069 m
.41853 .3894 L
s
.41853 .3894 m
.41665 .37504 L
s
.41853 .3894 m
.40232 .38447 L
s
.53396 .627 m
.54011 .63181 L
s
.53396 .627 m
.54142 .62555 L
s
.391 .529 .701 r
.52516 .73689 m .50649 .73805 L .50659 .72108 L p F P
0 0 0 r
s
.391 .529 .701 r
.50659 .72108 m .52516 .71991 L .52516 .73689 L p F P
0 0 0 r
s
.497 .667 .854 r
.56167 .74095 m .54387 .73788 L .54378 .7209 L p F P
0 0 0 r
s
.445 .599 .78 r
.52516 .71991 m .54378 .7209 L .54387 .73788 L p F P
0 0 0 r
s
.69 .09 .12 r
.54142 .62555 m
.54011 .63181 L
s
.41665 .37504 m
.41418 .37624 L
s
.41665 .37504 m
.40232 .38447 L
s
.55691 .38636 m
.55428 .39905 L
s
.57242 .14698 m
.56845 .16629 L
s
.47627 .26835 m
.49246 .27797 L
s
.47627 .26835 m
.4935 .26132 L
s
.445 .599 .78 r
.54387 .73788 m .52516 .73689 L .52516 .71991 L p F P
0 0 0 r
s
.69 .09 .12 r
.46822 .50587 m
.47826 .51143 L
s
.46822 .50587 m
.47799 .50126 L
s
.51889 .50486 m
.46822 .50587 L
s
.46404 .74528 m
.4657 .744 L
s
.4657 .744 m
.46414 .73973 L
s
.4657 .744 m
.46015 .74364 L
s
.46414 .73973 m
.46249 .741 L
s
.46414 .73973 m
.46015 .74364 L
s
.46015 .74364 m
.46404 .74528 L
s
.46015 .74364 m
.46249 .741 L
s
.46015 .74364 m
.47992 .73794 L
s
.40232 .38447 m
.41607 .39069 L
s
.40232 .38447 m
.41418 .37624 L
s
.47278 .37632 m
.40232 .38447 L
s
.4018 .62535 m
.40535 .62323 L
s
.40535 .62323 m
.40222 .61465 L
s
.40535 .62323 m
.39421 .62245 L
s
.40222 .61465 m
.39866 .61674 L
s
.40222 .61465 m
.39421 .62245 L
s
.39421 .62245 m
.4018 .62535 L
s
.39421 .62245 m
.39866 .61674 L
s
.43345 .61008 m
.39421 .62245 L
s
.4935 .26132 m
.49246 .27797 L
s
.47799 .50126 m
.47826 .51143 L
s
.33922 .50476 m
.34489 .50224 L
s
.34489 .50224 m
.34016 .48929 L
s
.34489 .50224 m
.32812 .50098 L
s
.46249 .741 m
.46404 .74528 L
s
.34016 .48929 m
.33446 .49174 L
s
.34016 .48929 m
.32812 .50098 L
s
.32812 .50098 m
.33922 .50476 L
s
.32812 .50098 m
.33446 .49174 L
s
.38651 .48094 m
.32812 .50098 L
s
.73451 .50056 m
.68475 .47005 L
s
.31996 .73941 m
.32483 .74124 L
s
.32558 .7288 m
.31996 .73941 L
s
.31996 .73941 m
.31894 .7328 L
s
.33146 .73721 m
.31996 .73941 L
s
.34652 .71715 m
.31996 .73941 L
s
.32558 .7288 m
.31894 .7328 L
s
.33146 .73721 m
.32558 .7288 L
s
.25367 .61787 m
.26185 .62037 L
s
.26324 .60341 m
.25367 .61787 L
s
.25367 .61787 m
.25434 .60783 L
s
.27072 .61589 m
.25367 .61787 L
s
.29872 .58741 m
.25367 .61787 L
s
.41418 .37624 m
.41607 .39069 L
s
.32483 .74124 m
.33146 .73721 L
s
.39866 .61674 m
.4018 .62535 L
s
.26324 .60341 m
.25434 .60783 L
s
.27072 .61589 m
.26324 .60341 L
s
.26185 .62037 m
.27072 .61589 L
s
.17898 .73515 m
.1839 .73752 L
s
.18596 .71742 m
.17898 .73515 L
s
.17898 .73515 m
.17381 .7245 L
s
.19601 .73036 m
.17898 .73515 L
s
.20937 .69577 m
.17898 .73515 L
s
.69626 .73421 m
.67663 .7127 L
s
.33446 .49174 m
.33922 .50476 L
s
.31894 .7328 m
.32483 .74124 L
s
.68937 .37168 m
.61775 .3461 L
s
.18596 .71742 m
.17381 .7245 L
s
.19601 .73036 m
.18596 .71742 L
s
.1839 .73752 m
.19601 .73036 L
s
.81856 .71592 m
.82975 .72377 L
s
.80895 .72568 m
.81856 .71592 L
s
.81856 .71592 m
.81828 .71708 L
s
.25434 .60783 m
.26185 .62037 L
s
.65075 .60601 m
.60958 .58897 L
s
.82013 .73357 m
.80895 .72568 L
s
.80895 .72568 m
.81828 .71708 L
s
.75663 .59267 m
.76628 .59802 L
s
.74817 .60342 m
.75663 .59267 L
s
.75663 .59267 m
.7516 .59371 L
s
.64377 .2415 m
.55059 .22186 L
s
.17381 .7245 m
.1839 .73752 L
s
.7578 .60882 m
.74817 .60342 L
s
.74817 .60342 m
.7516 .59371 L
s
.82975 .72377 m
.82013 .73357 L
s
.81828 .71708 m
.82975 .72377 L
s
.69439 .46807 m
.70243 .47153 L
s
.68729 .48093 m
.69439 .46807 L
s
.69439 .46807 m
.68475 .47005 L
s
.69529 .48446 m
.68729 .48093 L
s
.68729 .48093 m
.68475 .47005 L
s
.63255 .36028 m
.6263 .35821 L
s
.6263 .35821 m
.63191 .34232 L
s
.6263 .35821 m
.61775 .3461 L
s
.81828 .71708 m
.82013 .73357 L
s
.63191 .34232 m
.6382 .34428 L
s
.63191 .34232 m
.61775 .3461 L
s
.56953 .23599 m
.56519 .23527 L
s
.56519 .23527 m
.56921 .21572 L
s
.56519 .23527 m
.55059 .22186 L
s
.68034 .71147 m
.68658 .71537 L
s
.67464 .71873 m
.68034 .71147 L
s
.68034 .71147 m
.67663 .7127 L
s
.76628 .59802 m
.7578 .60882 L
s
.7516 .59371 m
.76628 .59802 L
s
.60478 .47652 m
.54238 .46495 L
s
.68086 .72266 m
.67464 .71873 L
s
.67464 .71873 m
.67663 .7127 L
s
.56921 .21572 m
.57359 .21628 L
s
.56921 .21572 m
.55059 .22186 L
s
.7516 .59371 m
.7578 .60882 L
s
.61806 .59845 m
.61346 .5959 L
s
.61346 .5959 m
.61771 .58639 L
s
.61346 .5959 m
.60958 .58897 L
s
.61771 .58639 m
.62233 .5889 L
s
.61771 .58639 m
.60958 .58897 L
s
.555 .47464 m
.55218 .47284 L
s
.55218 .47284 m
.55486 .45995 L
s
.55218 .47284 m
.54238 .46495 L
s
.68658 .71537 m
.68086 .72266 L
s
.67663 .7127 m
.68658 .71537 L
s
.55486 .45995 m
.5577 .46168 L
s
.55486 .45995 m
.54238 .46495 L
s
.70243 .47153 m
.69529 .48446 L
s
.68475 .47005 m
.70243 .47153 L
s
.68475 .47005 m
.69529 .48446 L
s
.49162 .35068 m
.49077 .34955 L
s
.49077 .34955 m
.49183 .33269 L
s
.49077 .34955 m
.47502 .34064 L
s
.67663 .7127 m
.68086 .72266 L
s
.56551 .71331 m
.53416 .7083 L
s
.49183 .33269 m
.49268 .3337 L
s
.49183 .33269 m
.47502 .34064 L
s
.54047 .71327 m
.53909 .71171 L
s
.53909 .71171 m
.54043 .70534 L
s
.53909 .71171 m
.53416 .7083 L
s
.61775 .3461 m
.63255 .36028 L
s
.61775 .3461 m
.6382 .34428 L
s
.55836 .34572 m
.47502 .34064 L
s
.6382 .34428 m
.63255 .36028 L
s
.62233 .5889 m
.61806 .59845 L
s
.60958 .58897 m
.61806 .59845 L
s
.54043 .70534 m
.54181 .70689 L
s
.54043 .70534 m
.53416 .7083 L
s
.60958 .58897 m
.62233 .5889 L
s
.47705 .59007 m
.47751 .58831 L
s
.47751 .58831 m
.47723 .57797 L
s
.47751 .58831 m
.46676 .58421 L
s
.55059 .22186 m
.56953 .23599 L
s
.55059 .22186 m
.57359 .21628 L
s
.78561 .70944 m
.75742 .67587 L
s
.47723 .57797 m
.47677 .57969 L
s
.47723 .57797 m
.46676 .58421 L
s
.54238 .46495 m
.555 .47464 L
s
.54238 .46495 m
.5577 .46168 L
s
.41328 .46647 m
.41581 .46467 L
s
.41581 .46467 m
.41389 .45001 L
s
.41581 .46467 m
.39919 .45982 L
s
.53416 .7083 m
.54047 .71327 L
s
.53416 .7083 m
.54181 .70689 L
s
.54181 .70689 m
.54047 .71327 L
s
.41389 .45001 m
.41134 .45172 L
s
.41389 .45001 m
.39919 .45982 L
s
.5577 .46168 m
.555 .47464 L
s
.57359 .21628 m
.56953 .23599 L
s
.47502 .34064 m
.49162 .35068 L
s
.47502 .34064 m
.49268 .3337 L
s
.46676 .58421 m
.47705 .59007 L
s
.46676 .58421 m
.47677 .57969 L
s
.51871 .58322 m
.46676 .58421 L
s
.39919 .45982 m
.41328 .46647 L
s
.39919 .45982 m
.41134 .45172 L
s
.47143 .4518 m
.39919 .45982 L
s
.39865 .70711 m
.40229 .70463 L
s
.40229 .70463 m
.39908 .69585 L
s
.40229 .70463 m
.39087 .70387 L
s
.39908 .69585 m
.39543 .6983 L
s
.39908 .69585 m
.39087 .70387 L
s
.39087 .70387 m
.39865 .70711 L
s
.39087 .70387 m
.39543 .6983 L
s
.43109 .69182 m
.39087 .70387 L
s
.49268 .3337 m
.49162 .35068 L
s
.47677 .57969 m
.47705 .59007 L
s
.33446 .58368 m
.3403 .58065 L
s
.3403 .58065 m
.33545 .56741 L
s
.3403 .58065 m
.3231 .57941 L
s
.33545 .56741 m
.32958 .57037 L
s
.33545 .56741 m
.3231 .57941 L
s
.3231 .57941 m
.33446 .58368 L
s
.3231 .57941 m
.32958 .57037 L
s
.38294 .55978 m
.3231 .57941 L
s
.73981 .579 m
.68885 .54912 L
s
.24675 .69941 m
.2551 .70251 L
s
.25656 .68466 m
.24675 .69941 L
s
.24675 .69941 m
.2474 .68962 L
s
.26423 .69748 m
.24675 .69941 L
s
.29284 .66972 m
.24675 .69941 L
s
.41134 .45172 m
.41328 .46647 L
s
.39543 .6983 m
.39865 .70711 L
s
.25656 .68466 m
.2474 .68962 L
s
.26423 .69748 m
.25656 .68466 L
s
.2551 .70251 m
.26423 .69748 L
s
.32958 .57037 m
.33446 .58368 L
s
.69353 .44723 m
.62012 .42206 L
s
.2474 .68962 m
.2551 .70251 L
s
.65394 .68785 m
.61175 .67125 L
s
.76254 .67423 m
.77246 .68007 L
s
.75387 .68533 m
.76254 .67423 L
s
.76254 .67423 m
.75742 .67587 L
s
.64678 .31411 m
.55123 .29469 L
s
.76377 .69122 m
.75387 .68533 L
s
.75387 .68533 m
.75742 .67587 L
s
.69872 .54658 m
.70699 .55056 L
s
.69143 .55978 m
.69872 .54658 L
s
.69872 .54658 m
.68885 .54912 L
s
.69966 .56383 m
.69143 .55978 L
s
.69143 .55978 m
.68885 .54912 L
s
.63531 .43663 m
.62887 .43398 L
s
.62887 .43398 m
.63463 .41773 L
s
.62887 .43398 m
.62012 .42206 L
s
.63463 .41773 m
.64111 .42026 L
s
.63463 .41773 m
.62012 .42206 L
s
.57066 .30931 m
.5662 .30795 L
s
.5662 .30795 m
.57033 .28798 L
s
.5662 .30795 m
.55123 .29469 L
s
.77246 .68007 m
.76377 .69122 L
s
.75742 .67587 m
.77246 .68007 L
s
.60681 .55545 m
.54281 .54412 L
s
.57033 .28798 m
.57483 .28917 L
s
.57033 .28798 m
.55123 .29469 L
s
.75742 .67587 m
.76377 .69122 L
s
.62044 .68096 m
.61572 .678 L
s
.61572 .678 m
.62008 .66826 L
s
.61572 .678 m
.61175 .67125 L
s
.62008 .66826 m
.62482 .67118 L
s
.62008 .66826 m
.61175 .67125 L
s
.55575 .55414 m
.55285 .55185 L
s
.55285 .55185 m
.5556 .53868 L
s
.55285 .55185 m
.54281 .54412 L
s
.5556 .53868 m
.55852 .54091 L
s
.5556 .53868 m
.54281 .54412 L
s
.70699 .55056 m
.69966 .56383 L
s
.68885 .54912 m
.70699 .55056 L
s
.68885 .54912 m
.69966 .56383 L
s
.49072 .42718 m
.48987 .42545 L
s
.48987 .42545 m
.49094 .40824 L
s
.48987 .42545 m
.4737 .41667 L
s
.49094 .40824 m
.49181 .40984 L
s
.49094 .40824 m
.4737 .41667 L
s
.62012 .42206 m
.63531 .43663 L
s
.62012 .42206 m
.64111 .42026 L
s
.55919 .42168 m
.4737 .41667 L
s
.64111 .42026 m
.63531 .43663 L
s
.62482 .67118 m
.62044 .68096 L
s
.61175 .67125 m
.62044 .68096 L
s
.61175 .67125 m
.62482 .67118 L
s
.47578 .67279 m
.47626 .6706 L
s
.47626 .6706 m
.47597 .66006 L
s
.47626 .6706 m
.46522 .6666 L
s
.55123 .29469 m
.57066 .30931 L
s
.55123 .29469 m
.57483 .28917 L
s
.47597 .66006 m
.47549 .6622 L
s
.47597 .66006 m
.46522 .6666 L
s
.54281 .54412 m
.55575 .55414 L
s
.54281 .54412 m
.55852 .54091 L
s
.41034 .54621 m
.41296 .54384 L
s
.41296 .54384 m
.41098 .52888 L
s
.41296 .54384 m
.3959 .53909 L
s
.41098 .52888 m
.40835 .53115 L
s
.41098 .52888 m
.3959 .53909 L
s
.55852 .54091 m
.55575 .55414 L
s
.57483 .28917 m
.57066 .30931 L
s
.4737 .41667 m
.49072 .42718 L
s
.4737 .41667 m
.49181 .40984 L
s
.46522 .6666 m
.47578 .67279 L
s
.46522 .6666 m
.47549 .6622 L
s
.51852 .66564 m
.46522 .6666 L
s
.3959 .53909 m
.41034 .54621 L
s
.3959 .53909 m
.40835 .53115 L
s
.47 .53122 m
.3959 .53909 L
s
.49181 .40984 m
.49072 .42718 L
s
.47549 .6622 m
.47578 .67279 L
s
.32946 .66672 m
.33547 .66313 L
s
.33547 .66313 m
.33049 .64959 L
s
.33547 .66313 m
.31782 .66193 L
s
.33049 .64959 m
.32444 .65311 L
s
.33049 .64959 m
.31782 .66193 L
s
.31782 .66193 m
.32946 .66672 L
s
.31782 .66193 m
.32444 .65311 L
s
.37917 .64278 m
.31782 .66193 L
s
.74537 .66153 m
.69317 .63237 L
s
.40835 .53115 m
.41034 .54621 L
s
.32444 .65311 m
.32946 .66672 L
s
.69792 .52674 m
.62262 .50204 L
s
.64996 .39054 m
.5519 .37139 L
s
.70327 .62923 m
.71178 .63378 L
s
.69579 .64277 m
.70327 .62923 L
s
.70327 .62923 m
.69317 .63237 L
s
.70427 .6474 m
.69579 .64277 L
s
.69579 .64277 m
.69317 .63237 L
s
.63822 .51703 m
.63159 .51374 L
s
.63159 .51374 m
.6375 .49712 L
s
.63159 .51374 m
.62262 .50204 L
s
.6375 .49712 m
.64417 .50028 L
s
.6375 .49712 m
.62262 .50204 L
s
.57185 .38653 m
.56726 .38446 L
s
.56726 .38446 m
.5715 .36405 L
s
.56726 .38446 m
.5519 .37139 L
s
.60895 .63856 m
.54326 .62749 L
s
.5715 .36405 m
.57613 .36594 L
s
.5715 .36405 m
.5519 .37139 L
s
.55654 .63788 m
.55356 .63504 L
s
.55356 .63504 m
.55639 .62159 L
s
.55356 .63504 m
.54326 .62749 L
s
.55639 .62159 m
.55939 .62436 L
s
.55639 .62159 m
.54326 .62749 L
s
.71178 .63378 m
.70427 .6474 L
s
.69317 .63237 m
.71178 .63378 L
s
.69317 .63237 m
.70427 .6474 L
s
.48978 .50776 m
.48891 .50538 L
s
.48891 .50538 m
.49002 .4878 L
s
.48891 .50538 m
.47231 .49676 L
s
.49002 .4878 m
.4909 .49005 L
s
.49002 .4878 m
.47231 .49676 L
s
.62262 .50204 m
.63822 .51703 L
s
.62262 .50204 m
.64417 .50028 L
s
.56008 .50168 m
.47231 .49676 L
s
.64417 .50028 m
.63822 .51703 L
s
.5519 .37139 m
.57185 .38653 L
s
.5519 .37139 m
.57613 .36594 L
s
.54326 .62749 m
.55654 .63788 L
s
.54326 .62749 m
.55939 .62436 L
s
.40725 .63021 m
.40996 .62722 L
s
.40996 .62722 m
.40792 .61194 L
s
.40996 .62722 m
.39243 .62258 L
s
.40792 .61194 m
.4052 .61483 L
s
.40792 .61194 m
.39243 .62258 L
s
.55939 .62436 m
.55654 .63788 L
s
.57613 .36594 m
.57185 .38653 L
s
.47231 .49676 m
.48978 .50776 L
s
.47231 .49676 m
.4909 .49005 L
s
.39243 .62258 m
.40725 .63021 L
s
.39243 .62258 m
.4052 .61483 L
s
.46851 .6149 m
.39243 .62258 L
s
.4909 .49005 m
.48978 .50776 L
s
.4052 .61483 m
.40725 .63021 L
s
.70254 .61053 m
.62526 .58639 L
s
.65331 .47109 m
.55261 .45228 L
s
.64128 .60181 m
.63445 .59783 L
s
.63445 .59783 m
.64052 .5808 L
s
.63445 .59783 m
.62526 .58639 L
s
.64052 .5808 m
.6474 .58467 L
s
.64052 .5808 m
.62526 .58639 L
s
.5731 .46798 m
.56838 .46513 L
s
.56838 .46513 m
.57274 .44426 L
s
.56838 .46513 m
.55261 .45228 L
s
.57274 .44426 m
.57751 .44693 L
s
.57274 .44426 m
.55261 .45228 L
s
.48879 .59276 m
.4879 .58965 L
s
.4879 .58965 m
.48904 .57169 L
s
.4879 .58965 m
.47084 .58123 L
s
.48904 .57169 m
.48994 .57466 L
s
.48904 .57169 m
.47084 .58123 L
s
.62526 .58639 m
.64128 .60181 L
s
.62526 .58639 m
.6474 .58467 L
s
.56101 .58603 m
.47084 .58123 L
s
.6474 .58467 m
.64128 .60181 L
s
.55261 .45228 m
.5731 .46798 L
s
.55261 .45228 m
.57751 .44693 L
s
.57751 .44693 m
.5731 .46798 L
s
.47084 .58123 m
.48879 .59276 L
s
.47084 .58123 m
.48994 .57466 L
s
.48994 .57466 m
.48879 .59276 L
s
.65685 .55612 m
.55336 .53771 L
s
.57443 .55401 m
.56956 .55028 L
s
.56956 .55028 m
.57404 .52894 L
s
.56956 .55028 m
.55336 .53771 L
s
.57404 .52894 m
.57896 .53247 L
s
.57404 .52894 m
.55336 .53771 L
s
.55336 .53771 m
.57443 .55401 L
s
.55336 .53771 m
.57896 .53247 L
s
.57896 .53247 m
.57443 .55401 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[17]:=",
  ImageSize->{400, 407.75},
  ImageMargins->{{0, 0}, {0, 33}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001Ub000`400?l00000o`00003oo`3jl>J@
0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo
003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00
n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool0
0?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03j
l>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00
o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`
iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o
0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V
0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00>40
n_3V0`2`5aj[0?[`iP40oooo003M0?[`iPL0/1LNZ`3jl>H10?ooo`00f`3jl>H30;0G7P<0n_3V00<0
/1LN0?[`iP2`5ah0Z`3jl>H10?ooo`00g03jl>H00`2`5ah0n_3V0;0G7P030;0G7P030?[`iP2`5ah0
n_3V0:X0n_3V0@3oool00=d0n_3V00@0/1LN0?[`iP3jl>H0n_3V1@2`5ajY0?[`iP40oooo003M0?[`
iP<0/1LN00<0n_3V0;0G7P2`5ah00`3jl>H50;0G7Z@0n_3V0@3oool00=h0n_3V00D0/1LN0?[`iP2`
5ah0n_3V0;0G7P080?[`iP@0/1LNX03jl>H10?ooo`00g`3jl>H40;0G7P`0n_3V1@2`5ajK0?[`iP40
oooo003P0?[`iP<0/1LN4@3jl>H40;0G7YL0n_3V0@3oool00?P0n_3V102`5ajC0?[`iP40oooo003l
0?[`iP<0/1LNT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3V
T03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?oo
o`00o`3jl>J@0?[`iP40oooo00340?[`iP80/1LNb@3jl>H10?ooo`00`P3jl>H40;0G7/T0n_3V0@3o
ool00<00n_3V102`5ah00`3jl>H0/1LN0?[`iP380?[`iP40oooo002n0?[`iPP0/1LNb@3jl>H10?oo
o`00_`3jl>H20;0G7P<0n_3V4P2`5ahQ0?[`iP<0/1LNU@3jl>H10?ooo`00`@3jl>H20;0G7P030?[`
iP2`5ah0/1LN0100n_3V202`5ahE0?[`iPT0/1LNT`3jl>H10?ooo`00`P3jl>H40;0G7Rh0n_3V0`2`
5ah01@3jl>H0/1LN0?[`iP3jl>H0/1LN09<0n_3V0@3oool00<@0n_3V0P2`5ah_0?[`iP030;0G7P3j
l>H0/1LN00<0/1LNU03jl>H10?ooo`00h@3jl>H40;0G7Q00n_3V0P2`5ah00`3jl>H0/1LN0?[`iP02
0;0G7Y<0n_3V0@3oool00=l0n_3V102`5ah00`3jl>H0/1LN0?[`iP0@0?[`iP80/1LN0P3jl>H00`2`
5ah0n_3V0;0G7P020;0G7Y00n_3V0@3oool00=d0n_3V0`2`5ah20?[`iP80/1LN4`3jl>H30;0G7PD0
n_3V0P2`5aj>0?[`iP40oooo003K0?[`iP<0/1LN103jl>H20;0G7Q@0n_3V0P2`5ah70?[`iP80/1LN
S03jl>H10?ooo`00g03jl>H60;0G7P030?[`iP2`5ah0n_3V01h0n_3V0`2`5aj90?[`iP40oooo003M
0?[`iP80/1LN0P3jl>H60;0G7Ql0n_3V0P2`5aj70?[`iP40oooo003N0?[`iP80/1LN00<0n_3V0;0G
7P2`5ah0103jl>H40;0G7Qd0n_3V0`2`5aj40?[`iP40oooo003P0?[`iP<0/1LN203jl>H50;0G7Q/0
n_3V0P2`5aj20?[`iP40oooo003Q0?[`iP80/1LN3@3jl>H40;0G7QT0n_3V0P2`5aj00?[`iP40oooo
003d0?[`iPD0/1LNUP3jl>H10?ooo`00Z03jl>H20;0G7Q00n_3V1@2`5ahj0?[`iP@0/1LNTP3jl>H1
0?ooo`00YP3jl>H40;0G7PL0n_3V2@2`5ai30?[`iP<0/1LNS`3jl>H10?ooo`00Y03jl>H30;0G7P03
0?[`iP2`5ah0/1LN00L0/1LNgP3jl>H10?ooo`00X`3jl>H50;0G7P030?[`iP2`5ah0n_3V0>@0n_3V
0@3oool00:D0n_3V0`2`5ah00`3jl>H0/1LN0?[`iP0_0?[`iP@0/1LN/@3jl>H10?ooo`00Z03jl>H2
0;0G7Rd0n_3V102`5ah00`3jl>H0/1LN0;0G7P2a0?[`iP40oooo003H0?[`iP030;0G7P3jl>H0/1LN
00<0/1LN/@3jl>H10?ooo`00f@3jl>H40;0G7P030?[`iP2`5ah0/1LN00<0/1LN:P3jl>H30;0G7Wl0
n_3V0@3oool00=X0n_3V0`2`5ah60?[`iPD0/1LN8`3jl>H70;0G7Wd0n_3V0@3oool00<<0n_3V0`2`
5ahE0?[`iP80/1LN2`3jl>H40;0G7Ql0n_3V0`2`5ah30?[`iP030;0G7P3jl>H0n_3V07/0n_3V0@3o
ool00<00n_3V1P2`5ahV0?[`iP<0/1LN703jl>H01P2`5ah0n_3V0;0G7P2`5ah0n_3V0;0G7Wh0n_3V
0@3oool00;h0n_3V202`5ai60?[`iP80/1LN00<0n_3V0;0G7P2`5ah0OP3jl>H10?ooo`00WP3jl>H2
0;0G7Ql0n_3V0P2`5ah30?[`iP030;0G7P3jl>H0/1LN00l0/1LN8`3jl>H20;0G7Q40n_3V102`5ah0
0`3jl>H0/1LN0?[`iP1l0?[`iP40oooo002L0?[`iP80/1LN8`3jl>H0102`5ah0n_3V0?[`iP2`5ahA
0?[`iPT0/1LN5`3jl>H70;0G7Q40n_3V0P2`5ah20?[`iP80/1LNN`3jl>H10?ooo`00VP3jl>H20;0G
7RH0n_3V0`2`5ah_0?[`iPH0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V
07P0n_3V0@3oool009L0n_3V0`2`5ahZ0?[`iP030;0G7P3jl>H0n_3V02h0n_3V1@2`5ah00`3jl>H0
/1LN0?[`iP0H0?[`iP80/1LNN03jl>H10?ooo`00SP3jl>H00`2`5ah0n_3V0?[`iP040?[`iP80/1LN
GP3jl>H20;0G7P030?[`iP2`5ah0/1LN0080/1LN6`3jl>H00`2`5ah0n_3V0?[`iP1e0?[`iP40oooo
002<0?[`iP<0/1LN103jl>H20;0G7V40n_3V0`2`5ah20?[`iP<0/1LN6P3jl>H20;0G7WD0n_3V0@3o
ool008/0n_3V0P2`5ah20?[`iP@0/1LNC`3jl>H30;0G7Q40n_3V0P2`5ah00`3jl>H0/1LN0;0G7P03
0?[`iP<0/1LN6@3jl>H00`2`5ah0n_3V0?[`iP1b0?[`iP40oooo002;0?[`iPD0/1LNCP3jl>H40;0G
7P030?[`iP2`5ah0/1LN0180n_3V102`5ah60?[`iP80/1LN603jl>H20;0G7W80n_3V0@3oool008X0
n_3V102`5ah20?[`iP030;0G7P3jl>H0n_3V04P0n_3V0`2`5ah40?[`iP030;0G7P3jl>H0/1LN01h0
n_3V0`2`5ahG0?[`iP030;0G7P3jl>H0n_3V06l0n_3V0@3oool008X0n_3V1`2`5ah_0?[`iP030;0G
7P3jl>H0n_3V01T0n_3V00<0/1LN0?[`iP2`5ah0102`5ah00`3jl>H0/1LN0?[`iP0P0?[`iP<0/1LN
QP3jl>H10?ooo`00_P3jl>H30;0G7PD0n_3V2P2`5ah=0?[`iP80/1LN0`3jl>H50;0G7R80n_3V0P2`
5aj40?[`iP40oooo002l0?[`iPX0/1LN603jl>H20;0G7P80n_3V0P2`5ah30?[`iPD0/1LN7`3jl>H3
0;0G7X40n_3V0@3oool00840n_3V00<0/1LN0?[`iP3jl>H0>P3jl>H30;0G7Qh0n_3V0`2`5ah00`3j
l>H0/1LN0?[`iP070?[`iP@0/1LN00<0n_3V0;0G7P2`5ah06`3jl>H20;0G7Wl0n_3V0@3oool00800
n_3V00<0/1LN0?[`iP3jl>H0G@3jl>H40;0G7P/0n_3V1P2`5ajJ0?[`iP40oooo001n0?[`iP80/1LN
9`3jl>H20;0G7Q00n_3V1@2`5ahS0?[`iP<0/1LN2`3jl>H50;0G7P030?[`iP2`5ah0/1LN00<0/1LN
U@3jl>H10?ooo`00O@3jl>H00`2`5ah0n_3V0?[`iP0U0?[`iP@0/1LN1`3jl>H90;0G7SL0n_3V0P2`
5ah00`3jl>H0/1LN0;0G7P050?[`iP@0/1LN8`3jl>H30;0G7V/0n_3V0@3oool007`0n_3V00<0/1LN
0?[`iP3jl>H0903jl>H30;0G7P030?[`iP2`5ah0/1LN00L0/1LN@03jl>H30;0G7P80n_3V0P2`5ah7
0?[`iP<0/1LN803jl>H50;0G7VT0n_3V0@3oool007/0n_3V00<0/1LN0?[`iP3jl>H0903jl>H50;0G
7P030?[`iP2`5ah0/1LN04d0n_3V0P2`5ahW0?[`iP<0/1LN0`3jl>H20;0G7VL0n_3V0@3oool007X0
n_3V00<0/1LN0?[`iP3jl>H09`3jl>H60;0G7S00n_3V102`5ahK0?[`iP80/1LN9@3jl>H20;0G7P05
0?[`iP2`5ah0n_3V0?[`iP2`5ah0J03jl>H10?ooo`00N03jl>H20;0G7Rd0n_3V0`2`5ah]0?[`iP@0
/1LN00<0n_3V0;0G7P2`5ah07@3jl>H20;0G7R<0n_3V0P2`5ah0103jl>H0/1LN0;0G7P2`5aiY0?[`
iP40oooo001c0?[`iP80/1LN0P3jl>H00`2`5ah0n_3V0?[`iP1N0?[`iP030;0G7P3jl>H0/1LN00@0
/1LN7P3jl>H20;0G7R<0n_3V0`2`5aiZ0?[`iP40oooo001a0?[`iP<0/1LN00<0n_3V0;0G7P2`5ah0
HP3jl>H40;0G7P80n_3V102`5ah/0?[`iP<0/1LN4`3jl>H00`2`5ah0n_3V0?[`iP1W0?[`iP40oooo
001a0?[`iP<0/1LN00<0n_3V0;0G7P3jl>H0>@3jl>H20;0G7RP0n_3V0`2`5ah60?[`iPD0/1LN903j
l>H80;0G7Q80n_3V00<0/1LN0?[`iP3jl>H0IP3jl>H10?ooo`00L@3jl>H40;0G7P030?[`iP2`5ah0
n_3V03D0n_3V0`2`5ah[0?[`iP80/1LN2`3jl>H50;0G7Ql0n_3V102`5ah20?[`iP030;0G7P3jl>H0
n_3V0140n_3V00<0/1LN0?[`iP3jl>H0IP3jl>H10?ooo`00I03jl>H00`2`5ah0n_3V0?[`iP0:0?[`
iP<0/1LN00@0n_3V0;0G7P2`5ah0/1LN;@3jl>H00`2`5ah0n_3V0?[`iP030?[`iP80/1LN5`3jl>H0
0`2`5ah0n_3V0?[`iP0V0?[`iP<0/1LN703jl>H0102`5ah0n_3V0;0G7P2`5ah20?[`iP030;0G7P3j
l>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H0I@3jl>H10?ooo`00H`3jl>H00`2`5ah0n_3V0?[`iP0;
0?[`iPD0/1LN;P3jl>H0102`5ah0n_3V0;0G7P3jl>H30;0G7QL0n_3V0`2`5ai80?[`iP80/1LN00<0
n_3V0;0G7P2`5ah05P3jl>H00`2`5ah0n_3V0?[`iP1T0?[`iP40oooo001S0?[`iP030;0G7P3jl>H0
n_3V03L0n_3V0P2`5ah40?[`iPD0/1LN603jl>H20;0G7P80n_3V00<0/1LN0?[`iP3jl>H0AP3jl>H3
0;0G7P040?[`iP2`5ah0/1LN0;0G7Q@0n_3V00<0/1LN0?[`iP3jl>H0I03jl>H10?ooo`00HP3jl>H0
0`2`5ah0n_3V0?[`iP0e0?[`iP<0/1LN1P3jl>H50;0G7QH0n_3V202`5ai90?[`iP80/1LN0`3jl>H0
0`2`5ah0n_3V0?[`iP0B0?[`iP030;0G7P3jl>H0n_3V06<0n_3V0@3oool00640n_3V00<0/1LN0?[`
iP3jl>H0=03jl>H20;0G7PX0n_3V0`2`5ahH0?[`iP80/1LN0`3jl>H00`2`5ah0n_3V0;0G7P0A0;0G
7R40n_3V1@2`5ahG0?[`iP80/1LN4`3jl>H00`2`5ah0n_3V0?[`iP1R0?[`iP40oooo001Q0?[`iP03
0;0G7P3jl>H0n_3V0340n_3V0`2`5ahY0?[`iP80/1LN00<0n_3V0;0G7P3jl>H03P3jl>H;0;0G7QH0
n_3V1P2`5ah20?[`iP030;0G7P3jl>H0n_3V01L0n_3V00<0/1LN0?[`iP3jl>H0403jl>H00`2`5ah0
n_3V0?[`iP1R0?[`iP40oooo001P0?[`iP030;0G7P3jl>H0n_3V02T0n_3V00<0/1LN0?[`iP3jl>H0
0`3jl>H30;0G7Rd0n_3V0`2`5ah@0?[`iPP0/1LN6@3jl>H50;0G7P030?[`iP2`5ah0n_3V01X0n_3V
0P2`5ahA0?[`iP030;0G7P3jl>H0n_3V0640n_3V0@3oool005l0n_3V00<0/1LN0?[`iP3jl>H0:03j
l>H30;0G7P80n_3V0`2`5ahb0?[`iP030;0G7P3jl>H0n_3V00l0n_3V00<0/1LN0?[`iP3jl>H0103j
l>H30;0G7QH0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P020;0G7PT0n_3V0P2`5ahB0?[`iP80/1LNL`3j
l>H10?ooo`00G`3jl>H00`2`5ah0n_3V0?[`iP0W0?[`iP80/1LN0P3jl>H20;0G7VP0n_3V0`2`5ah2
0?[`iP<0/1LN1`3jl>H40;0G7Q80n_3V00<0/1LN0?[`iP3jl>H0L03jl>H10?ooo`00GP3jl>H00`2`
5ah0n_3V0?[`iP0X0?[`iPD0/1LN1@3jl>H00`2`5ah0n_3V0?[`iP1Q0?[`iP<0/1LN0P3jl>H00`2`
5ah0n_3V0?[`iP030;0G7P<0n_3V102`5ahD0?[`iP80/1LN603jl>H00`2`5ah0n_3V0?[`iP1E0?[`
iP40oooo001N0?[`iP030;0G7P3jl>H0n_3V02L0n_3V102`5ah20?[`iP050;0G7P3jl>H0n_3V0?[`
iP2`5ah0;@3jl>H00`2`5ah0n_3V0?[`iP0e0?[`iP@0/1LN1P3jl>H40;0G7P030?[`iP2`5ah0/1LN
01H0n_3V00<0/1LN0?[`iP3jl>H0503jl>H30;0G7UH0n_3V0@3oool004P0n_3V00<0/1LN0?[`iP3j
l>H03`3jl>H20;0G7P030?[`iP2`5ah0n_3V02/0n_3V1@2`5ah20?[`iP030;0G7P3jl>H0n_3V02X0
n_3V0`2`5ahQ0?[`iP@0/1LN503jl>H20;0G7PT0n_3V102`5ah/0?[`iPH0/1LNE03jl>H10?ooo`00
B03jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP<0/1LN00<0n_3V0;0G7P2`5ah0<`3jl>H00`2`5ah0n_3V
0?[`iP0Y0?[`iQ@0/1LN3P3jl>H60;0G7P030?[`iP2`5ah0n_3V0240n_3V0P2`5ah[0?[`iP030;0G
7P3jl>H0/1LN0080n_3V0P2`5aiC0?[`iP40oooo00170?[`iP030;0G7P3jl>H0n_3V00d0n_3V0P2`
5ah00`3jl>H0/1LN0?[`iP020;0G7S40n_3V00<0/1LN0?[`iP3jl>H0:`3jl>H20;0G7P030?[`iP2`
5ah0n_3V01T0n_3V0`2`5ah40?[`iP030;0G7P3jl>H0/1LN02D0n_3V0`2`5ahW0?[`iP040;0G7P3j
l>H0n_3V0;0G7P80n_3V00<0/1LN0?[`iP3jl>H0DP3jl>H10?ooo`00A`3jl>H00`2`5ah0n_3V0?[`
iP0>0?[`iP@0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP0N0?[`iP030;0G7P3jl>H0n_3V00`0n_3V00<0
/1LN0?[`iP3jl>H0;P3jl>H20;0G7Q/0n_3V00<0/1LN0?[`iP2`5ah0102`5ah00`3jl>H0/1LN0?[`
iP0:0?[`iPD0/1LN5@3jl>H00`2`5ah0n_3V0?[`iP030;0G7RD0n_3V1@2`5aiE0?[`iP40oooo0017
0?[`iP030;0G7P3jl>H0n_3V00h0n_3V0`2`5ah30?[`iP80/1LN7P3jl>H00`2`5ah0n_3V0?[`iP0:
0?[`iP80/1LN00<0n_3V0;0G7P3jl>H0C@3jl>H20;0G7P<0n_3V1P2`5ah80?[`iP<0/1LN00<0n_3V
0;0G7P3jl>H05@3jl>H00`2`5ah0n_3V0?[`iP020?[`iP80/1LN9@3jl>H20;0G7UH0n_3V0@3oool0
04L0n_3V00<0/1LN0?[`iP3jl>H03`3jl>H60;0G7Qd0n_3V0P2`5ah;0?[`iP<0/1LN00<0n_3V0;0G
7P3jl>H0C`3jl>H20;0G7P80n_3V00<0/1LN0?[`iP2`5ah00`3jl>H50;0G7P@0n_3V102`5ahF0?[`
iP030;0G7P3jl>H0n_3V01D0n_3V0P2`5ahC0?[`iP030;0G7P3jl>H0n_3V05@0n_3V0@3oool004H0
n_3V00<0/1LN0?[`iP3jl>H0403jl>H40;0G7Qh0n_3V00<0/1LN0?[`iP3jl>H02`3jl>H50;0G7QP0
n_3V0P2`5ahB0?[`iP@0/1LN8@3jl>H30;0G7P030?[`iP2`5ah0n_3V00P0n_3V1`2`5ah00`3jl>H0
/1LN0;0G7P0E0?[`iP030;0G7P3jl>H0n_3V01@0n_3V102`5ahA0?[`iP030;0G7P3jl>H0n_3V05@0
n_3V0@3oool004H0n_3V00<0/1LN0?[`iP3jl>H0<@3jl>H00`2`5ah0n_3V0?[`iP0=0?[`iP80/1LN
00<0n_3V0;0G7P2`5ah05P3jl>H30;0G7P/0n_3V1`2`5ah60?[`iP80/1LN203jl>H@000000H0n_3V
102`5ah=0?[`iPD0/1LN00<0n_3V0;0G7P2`5ah0:P3jl>H20;0G7P80n_3V0P2`5ah?0?[`iP030;0G
7P3jl>H0n_3V05@0n_3V0@3oool004H0n_3V00<0/1LN0?[`iP3jl>H0<03jl>H00`2`5ah0n_3V0?[`
iP0>0?[`iP@0/1LN5@3jl>H20;0G7P030?[`iP2`5ah0/1LN00@0n_3V1`2`5ah90?[`iP040;0G7P3j
l>H0/1LN0;0G7PH0n_3V100000000`1FMIh0000006B7/`0406B7/`030000001aVLL0LIW700@0LIW7
00<0000007nZfP0000000P0000040?[`iP<0/1LN4P3jl>H50;0G7RL0n_3V102`5ah00`3jl>H0/1LN
0?[`iP0?0?[`iP030;0G7P3jl>H0n_3V05@0n_3V0@3oool004D0n_3V00<0/1LN0?[`iP3jl>H0;`3j
l>H20;0G7RT0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P050;0G7Pl0n_3V0`2`5ah50?[`iP<000001@1F
MIh00`000000I8Nc06B7/`0306B7/`030000001aVLL0LIW700@0LIW700<0000007nZfP1oZ]X00P1o
Z]X3000001/0n_3V1@2`5ahR0?[`iP<0/1LN00<0n_3V0;0G7P3jl>H0403jl>H00`2`5ah0n_3V0?[`
iP1D0?[`iP40oooo00150?[`iP030;0G7P3jl>H0n_3V02X0n_3V00@0/1LN0?[`iP3jl>H0n_3V0P2`
5ahY0?[`iP@0/1LN0P3jl>H20;0G7Q40n_3V0`2`5ah40?[`iP80000000<0Af>80000001FMIh01@1F
MIh00`000000I8Nc06B7/`0306B7/`030000001aVLL0LIW700@0LIW700@0000007nZfP1oZ]X0Oj[J
0P2`5ah010000000Rk_/00000000000K0?[`iP80/1LN00@0n_3V0;0G7P2`5ah0/1LN7`3jl>H20;0G
7P030?[`iP2`5ah0/1LN0140n_3V00<0/1LN0?[`iP3jl>H0E03jl>H10?ooo`00A@3jl>H00`2`5ah0
n_3V0?[`iP0X0?[`iP80/1LN00<0n_3V0;0G7P3jl>H00P2`5ah/0?[`iPH0/1LN5P3jl>H2000000<0
Af>800<0000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0306B7/`030000001aVLL0LIW700@0
LIW700<0000007nZfP2`5ah00`2`5ah010000000Rk_/08^kk02;^n`2000001/0n_3V00<0/1LN0?[`
iP3jl>H08P3jl>H20;0G7P030?[`iP2`5ah0n_3V0100n_3V00<0/1LN0?[`iP3jl>H0D`3jl>H10?oo
o`00A@3jl>H00`2`5ah0n_3V0?[`iP0W0?[`iP040;0G7P3jl>H0/1LN0?[`iP80/1LN00<0n_3V0;0G
7P3jl>H0;P3jl>H30;0G7PH0n_3V0P2`5ah<0?[`iP<000001017HhP00`000000EWFN05IeWP0405Ie
WP040000001TQk<0I8Nc06B7/`T000000`2`5ah0101oZ]X0/1LN0;0G7P00000408^kk0<000001@3j
l>H30;0G7SX0n_3V00<0/1LN0?[`iP3jl>H03P3jl>H00`2`5ah0n_3V0?[`iP1C0?[`iP40oooo0014
0?[`iP030;0G7P3jl>H0n_3V02P0n_3V0P2`5ah20?[`iP80/1LN00<0n_3V0;0G7P3jl>H0=@3jl>H2
0;0G7P`0n_3V0P00000203U@L@0300000017HhP0Af>80080Af>800@0000005IeWP1FMIh0EWFN1`00
000206B7/`030000001aVLL0LIW700@0LIW700<000000;0G7P0000001P2`5ah208^kk0030000002E
b?P0ULSh008000000`3jl>H20;0G7R<0n_3V0`2`5ahE0?[`iP030;0G7P3jl>H0n_3V00h0n_3V00<0
/1LN0?[`iP3jl>H0D`3jl>H10?ooo`00@P3jl>H30;0G7Q`0n_3V00<0/1LN0?[`iP3jl>H02`3jl>H4
0;0G7P030?[`iP2`5ah0/1LN03D0n_3V0P2`5ah=0?[`iP030000000iD740>E1a0080>E1a00@00000
04MSR017HhP0Af>81@00000305IeWP030000001TQk<0I8Nc00<0I8Nc00<00000076Ia`1aVLL0101a
VLL00`000000Oj[J0;0G7P020;0G7P<0000000<0Rk_/0;0G7P2`5ah0102`5ah00`2Eb?P000000?[`
iP030?[`iP030;0G7P3jl>H0n_3V01h0n_3V1`2`5ah60?[`iP030;0G7P3jl>H0n_3V00/0n_3V00<0
/1LN0?[`iP3jl>H03@3jl>H00`2`5ah0n_3V0?[`iP1C0?[`iP40oooo00100?[`iP80/1LN00<0n_3V
0;0G7P2`5ah06`3jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP<0/1LN00@0n_3V0;0G7P2`5ah0/1LN;@3j
l>H20;0G7P<0n_3V0`2`5ah>0?[`iP800000100iD7401P000000Af>8000000000000Af>8000000H0
EWFN00<0000006B7/`1TQk<00`1TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J0080
/1LN00<0Oj[J0000002;^n`00P0000000`2;^n`0000009G8n00209G8n0H0/1LN00<0n_3V0;0G7P3j
l>H07P3jl>H30;0G7P<0n_3V00<0/1LN0?[`iP3jl>H00`3jl>H40;0G7P`0n_3V00<0/1LN0?[`iP3j
l>H0303jl>H00`2`5ah0n_3V0?[`iP0?0?[`iP030;0G7P3jl>H0n_3V0440n_3V0@3oool003h0n_3V
0P2`5ah30?[`iP040;0G7P3jl>H0/1LN0;0G7QT0n_3V00<0/1LN0?[`iP3jl>H0303jl>H60;0G7Rh0
n_3V00<0/1LN0?[`iP2`5ah00P2`5ah@0?[`iP030000000Y>UD0000000@0>E1a0P00000304MSR003
0000001FMIh0EWFN00@0EWFN00<0000006B7/`1TQk<00`1TQk<00`000000LIW7076Ia`04076Ia`03
0000001oZ]X0Oj[J00<0Oj[J00@0000008^kk02;^n`0Rk_/0P00000409G8n0050000002FboL00000
0000003jl>H00`2`5ahN0?[`iP060;0G7P3jl>H0/1LN0;0G7P3jl>H0/1LN1@3jl>H00`2`5ah0n_3V
0;0G7P020?[`iP030;0G7P3jl>H0n_3V00T0n_3V00<0/1LN0?[`iP3jl>H07@3jl>H30;0G7T80n_3V
0@3oool003l0n_3V00D0/1LN0?[`iP3jl>H0n_3V0;0G7P030?[`iP030;0G7P3jl>H0n_3V01D0n_3V
00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP0[0?[`iP@0/1LN4P3jl>H00`000000:CYE
0000000203U@L@<000001017HhP00`2`5ah0EWFN05IeWP0405IeWP040000001TQk<0I8Nc06B7/`H0
00000`1aVLL00`000000Oj[J07nZfP0307nZfP030000002;^n`0Rk_/0080Rk_/0`00000209G8n005
0000002FboL0U/_g09K;m`0000008P3jl>H20;0G7P030?[`iP2`5ah0/1LN00H0n_3V102`5ah=0?[`
iP030;0G7P3jl>H0n_3V01X0n_3V1@2`5ai20?[`iP40oooo00100?[`iP040;0G7P3jl>H0/1LN0;0G
7P@0n_3V00<0/1LN0?[`iP3jl>H0503jl>H00`2`5ah0n_3V0?[`iP0A0?[`iP80/1LN9P3jl>H20;0G
7PD0n_3V1@2`5ah@0?[`iP030000000Y>UD0:CYE00<000000P0iD7400`000000Af>804MSR0030;0G
7P<0EWFN1`00000206B7/`040000001aVLL0LIW7076Ia`H000000`1oZ]X00`000000Rk_/08^kk002
08^kk0030000002Eb?P0ULSh00<000000`2FboL00`000000n_3V0?[`iP0P0?[`iP@0/1LN00<0n_3V
0;0G7P2`5ah01@3jl>H00`2`5ah0n_3V0?[`iP0>0?[`iP030;0G7P3jl>H0n_3V01P0n_3V0P2`5ah0
0`3jl>H0/1LN0;0G7P020;0G7T40n_3V0@3oool00400n_3V102`5ah20?[`iP80/1LN5P3jl>H00`2`
5ah0n_3V0?[`iP0@0?[`iP@0/1LN8`3jl>H30;0G7PT0n_3V00<0/1LN0?[`iP3jl>H03`3jl>H20000
0080:CYE00<0000003U@L@0iD7400P0iD7401P000000/1LN0;0G7P2`5ah000000;0G7P<000000`1F
MIh00`000000I8Nc06B7/`0306B7/`030000001aVLL0LIW70080LIW70P2`5ah00`000000Oj[J07nZ
fP05000000<0Rk_/00<0000009G8n02Eb?P00P2Eb?P010000000U/_g09K;m`2FboL2000002<0n_3V
0P2`5ah30?[`iP030;0G7P3jl>H0n_3V0080n_3V00<0/1LN0?[`iP3jl>H03P3jl>H00`2`5ah0n_3V
0?[`iP0G0?[`iP050;0G7P3jl>H0n_3V0?[`iP2`5ah00`3jl>H00`2`5ah0n_3V0?[`iP0n0?[`iP40
oooo00110?[`iP80/1LN00<0n_3V0;0G7P2`5ah05@3jl>H00`2`5ah0n_3V0;0G7P0B0?[`iP060;0G
7P3jl>H0n_3V0;0G7P3jl>H0/1LN803jl>H20;0G7P/0n_3V00<0/1LN0?[`iP3jl>H0403jl>H20000
000302TjE@000000000000<0>E1a0`2`5ah20000000304MSR02`5ah0EWFN00D0EWFN00<0000006B7
/`1TQk<00`1TQk<00`000000LIW7076Ia`030;0G7P03076Ia`000000Oj[J00@0Oj[J00H0000008^k
k0000000000008^kk000000409G8n08000000P2FboL2000002T0n_3V0P2`5ah20?[`iP030;0G7P3j
l>H0n_3V00l0n_3V00<0/1LN0?[`iP3jl>H05`3jl>H0102`5ah0n_3V0?[`iP2`5ah20?[`iP030;0G
7P3jl>H0n_3V03l0n_3V0@3oool00480n_3V0P2`5ahG0?[`iP030;0G7P3jl>H0/1LN01<0n_3V0`2`
5ah20?[`iP030;0G7P3jl>H0n_3V01X0n_3V0`2`5ah=0?[`iP030;0G7P3jl>H0n_3V00l0n_3V00H0
000001LR=P000000000002TjE@00000203U@L@T0/1LN1@1FMIh00`000000I8Nc06B7/`0306B7/`04
0000001aVLL0LIW7076Ia`P0/1LN00<0Oj[J0000002;^n`00P2;^n`2000000@0ULSh00L0000009K;
m`000000U/_g0000001o[]80000000`0n_3V0P2`5ahL0?[`iP030;0G7P3jl>H0/1LN02`0n_3V1@2`
5ai20?[`iP40oooo001K0?[`iP80/1LN503jl>H20;0G7P030?[`iP2`5ah0/1LN01D0n_3V00<0/1LN
0?[`iP3jl>H00P3jl>H30;0G7Pl0n_3V0P2`5ahA0?[`iP060000000G8SH000000000000Y>UD00000
0P0iD7400`000000/1LN0;0G7P0304MSR080/1LN00<0EWFN0;0G7P2`5ah03P2`5ah2076Ia`030000
001oZ]X0Oj[J0080Oj[J0`2`5ah308^kk0<000000P2Eb?P00`000000U/_g09K;m`020000000307n^
dP000000n_3V00P0n_3V1`2`5ah80?[`iP80/1LN4@3jl>H20;0G7Rd0n_3V0P2`5ai40?[`iP40oooo
001K0?[`iP030;0G7P3jl>H0n_3V01@0n_3V0P2`5ahE0?[`iP<0/1LN00@0n_3V0;0G7P2`5ah0/1LN
4@3jl>H30;0G7Q40n_3V00<0000001LR=P0000000P0Y>UD300000080>E1a00@000000;0G7P2`5ah0
Af>80P2`5ah305IeWPh000002@2`5ah408^kk0030000002Eb?P0ULSh00<000000`2FboL00`000000
OjkB000000070?[`iPH0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP050?[`iPD0/1LN403jl>H30;0G7R/0
n_3V00<0/1LN0?[`iP3jl>H0@`3jl>H10?ooo`00F`3jl>H00`2`5ah0n_3V0?[`iP0Z0?[`iP80/1LN
00<0n_3V0;0G7P2`5ah01@3jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP80/1LN00<0n_3V0;0G7P3jl>H0
3P3jl>H400000080:CYE00<0000003U@L@0iD7400P0iD7400`000000Af>804MSR0030;0G7P<00000
0`1FMIh00`000000I8Nc06B7/`0306B7/`030000001aVLL0LIW700@0LIW700<0000007nZfP1oZ]X0
1000000408^kk0030000002Eb?P0ULSh0080ULSh00H0000009K;m`2FboL0U/_g0000001o[]820000
00L0n_3V1@2`5ah00`3jl>H0/1LN0?[`iP070?[`iP040;0G7P3jl>H0/1LN0;0G7Q40n_3V00@0/1LN
0?[`iP3jl>H0/1LN6P3jl>H00`2`5ah0n_3V0?[`iP0=0?[`iP030;0G7P3jl>H0n_3V04<0n_3V0@3o
ool004@0n_3V00<0/1LN0?[`iP3jl>H04@3jl>H40;0G7R/0n_3V102`5ah00`3jl>H0/1LN0?[`iP03
0?[`iP030;0G7P3jl>H0n_3V00h0n_3V0P2`5ah@0?[`iP@0000000<0:CYE000000000000100iD740
0`000000Af>804MSR002000000030;0G7P1FMIh0EWFN00@0EWFN00<0000006B7/`1TQk<00`1TQk<0
0`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00<0Oj[J0`00000308^kk0040000002Eb?P0
ULSh09G8n08000000P2FboL4000000L0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P020;0G7PT0n_3V0`2`
5ahA0?[`iP040;0G7P3jl>H0n_3V0?[`iP80/1LN5`3jl>H30;0G7Pd0n_3V00<0/1LN0?[`iP3jl>H0
A03jl>H10?ooo`00A03jl>H00`2`5ah0n_3V0?[`iP0?0?[`iP80/1LN00@0n_3V0;0G7P2`5ah0/1LN
:P3jl>H50;0G7P80n_3V00@0/1LN0?[`iP3jl>H0/1LN8`3jl>H20000000501LR=P000000000002Tj
E@000000100iD7400`2`5ah000000000000204MSR0030000001FMIh0EWFN00<0EWFN00<0000006B7
/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00<0Oj[J00<0000008^k
k02;^n`00P0000000`2;^n`0000009G8n00209G8n0040000002FboL0000009K;m`@00000203jl>H3
0;0G7P80n_3V102`5ah90?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H0
102`5ah0n_3V0;0G7P3jl>H20;0G7P/0n_3V00<0/1LN0?[`iP3jl>H0A03jl>H10?ooo`00A03jl>H0
0`2`5ah0n_3V0?[`iP0=0?[`iP80/1LN0P3jl>H40;0G7R/0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P02
0;0G7P030?[`iP2`5ah0n_3V02<0n_3V0P0000001@0G8SH000000000000Y>UD000000080>E1a0`2`
5ah404MSR0030000001FMIh0EWFN00<0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076I
a`04076Ia`030000001oZ]X0Oj[J00<0Oj[J00<0000008^kk02;^n`00P2;^n`2000000<0ULSh00<0
000009K;m`2FboL00P0000000`1o[]800000000000080?[`iP80/1LN00<0n_3V0;0G7P2`5ah0103j
l>H30;0G7PL0n_3V00<0/1LN0?[`iP3jl>H0:03jl>H0102`5ah0n_3V0?[`iP2`5ah30?[`iP030;0G
7P3jl>H0n_3V00P0n_3V00<0/1LN0?[`iP3jl>H0A03jl>H10?ooo`00@`3jl>H00`2`5ah0n_3V0?[`
iP0>0?[`iP80/1LN0P3jl>H0102`5ah0n_3V0?[`iP2`5ah/0?[`iP@0/1LN0P3jl>H00`2`5ah0n_3V
0?[`iP0S0?[`iP80000000D05b8f0000000Y>UD0:CYE0000000E0;0G7PX00000101oZ]X00`000000
Rk_/08^kk00308^kk0<0000000<0ULSh0000002FboL00P2FboL010000000OjkB0000000000090?[`
iP@0/1LN1`3jl>H20;0G7PH0n_3V00<0/1LN0?[`iP3jl>H0:03jl>H01P2`5ah0n_3V0;0G7P2`5ah0
n_3V0;0G7P/0n_3V00<0/1LN0?[`iP3jl>H0A03jl>H10?ooo`00@`3jl>H00`2`5ah0n_3V0?[`iP0?
0?[`iP@0/1LN0P3jl>H20;0G7R/0n_3V00@0/1LN0?[`iP3jl>H0n_3V0P2`5ahV0?[`iP@000000P0Y
>UD200000080/1LN00<0>E1a0;0G7P17HhP00`17HhP00`000000EWFN000000020000000305IeWP00
0000I8Nc00D0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000Oj[J000000020000000307nZfP00
0000Rk_/00@0Rk_/00<0000009G8n02Eb?P00P00000309K;m`040000001o[]80000000000100n_3V
0P2`5ah40?[`iP<0/1LN0`3jl>H00`2`5ah0n_3V0?[`iP0Y0?[`iP@0/1LN2`3jl>H00`2`5ah0n_3V
0?[`iP150?[`iP40oooo00130?[`iP030;0G7P3jl>H0n_3V00l0n_3V00<0/1LN0?[`iP2`5ah00P3j
l>H20;0G7R40n_3V00<0/1LN0?[`iP3jl>H0203jl>H40;0G7RP0n_3V0P0000001@0G8SH0000002Tj
E@0Y>UD0000000<0>E1a0P2`5ah304MSR0<00000101FMIh00`000000I8Nc06B7/`0406B7/`030000
001aVLL0LIW700@0LIW700<0000007nZfP1oZ]X00P1oZ]X3000000<0Rk_/0P2`5ah309G8n0800000
0P2FboL4000000H0/1LN2@3jl>H30;0G7PL0n_3V0`2`5ah00`3jl>H0/1LN0?[`iP0Q0?[`iP030;0G
7P3jl>H0n_3V00L0n_3V00<0/1LN0?[`iP3jl>H02P3jl>H00`2`5ah0n_3V0?[`iP150?[`iP40oooo
00130?[`iP030;0G7P3jl>H0n_3V0100n_3V102`5ah00`3jl>H0/1LN0?[`iP0O0?[`iP030;0G7P3j
l>H0n_3V00T0n_3V102`5ahX0?[`iP80000000<05b8f0000000Y>UD00P00000403U@L@0600000017
HhP0000000000017HhP000001@1FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0
LIW700<0000007nZfP1oZ]X00`1oZ]X00`000000Rk_/000000050;0G7P80ULSh00@0000009K;m`00
0000U/_g100000001P3jl>H0/1LN0;0G7P2`5ah0n_3V0;0G7PX0n_3V00<0/1LN0?[`iP3jl>H02@3j
l>H30;0G7Ql0n_3V0`2`5ah90?[`iP030;0G7P3jl>H0n_3V00X0n_3V00<0/1LN0?[`iP3jl>H0A@3j
l>H10?ooo`00@P3jl>H00`2`5ah0n_3V0?[`iP0A0?[`iP80/1LN0P3jl>H30;0G7Qd0n_3V0P2`5ah<
0?[`iP80/1LN00<0n_3V0;0G7P2`5ah09`3jl>H00`0000005b8f01LR=P020000000302TjE@000000
>E1a00<0>E1a0P00000304MSR0030000001FMIh0EWFN00<0EWFN00<0000006B7/`1TQk<0101TQk<0
0`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00<0Oj[J1P2`5ah01@000000/1LN09G8n02E
b?P000000080U/_g0P000000101o[]8000000000003jl>H40;0G7PX0n_3V00<0/1LN0?[`iP3jl>H0
3@3jl>H30;0G7Q<0n_3V0P2`5ah50?[`iP80/1LN00<0n_3V0;0G7P2`5ah02@3jl>H00`2`5ah0n_3V
0?[`iP0:0?[`iP030;0G7P3jl>H0n_3V01@0n_3V0P2`5ah_0?[`iP40oooo00120?[`iP030;0G7P3j
l>H0n_3V01<0n_3V0P2`5ah00`3jl>H0/1LN0?[`iP020;0G7QX0n_3V00<0/1LN0?[`iP3jl>H0303j
l>H40;0G7RP0n_3V00@0000001LR=P0G8SH000000P0Y>UD00`000000>E1a03U@L@0300000080/1LN
0P17HhP00`000000EWFN05IeWP0305IeWP040000001TQk<0I8Nc06B7/`L000000`1aVLL010000000
Oj[J07nZfP1oZ]X30;0G7P@0Rk_/00<0/1LN0000002`5ah00P2Eb?P01P000000U/_g09K;m`2FboL0
000007n^dP8000000P3jl>H50;0G7PL0n_3V00<0/1LN0?[`iP3jl>H04@3jl>H20;0G7Q40n_3V1@2`
5ah0103jl>H0/1LN0?[`iP3jl>H40;0G7PP0n_3V00<0/1LN0?[`iP3jl>H02@3jl>H00`2`5ah0n_3V
0?[`iP0C0?[`iP@0/1LN;`3jl>H10?ooo`00@P3jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP050;0G7P3j
l>H0n_3V0?[`iP2`5ah00`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP040;0G7P3jl>H0n_3V0;0G7Q00
n_3V00<0/1LN0?[`iP3jl>H06P3jl>H00`2`5ah0n_3V0?[`iP0;0?[`iP040000000G8SH000000000
0080:CYE00<000000;0G7P2`5ah00`2`5ah404MSR0040000001FMIh0EWFN05IeWPH000000`1TQk<0
10000000LIW7076Ia`1aVLL600000080Oj[J00<0/1LN0000002`5ah0102`5ah00`000000/1LN0000
0002000000<0U/_g00@0000007n^dP00000000000`3jl>H20;0G7P80n_3V0P2`5ah50?[`iP030;0G
7P3jl>H0n_3V02@0n_3V0P2`5ah20?[`iPH0/1LN00<0n_3V0;0G7P2`5ah0203jl>H00`2`5ah0n_3V
0?[`iP090?[`iP030;0G7P3jl>H0n_3V0140n_3V0P2`5ah0103jl>H0/1LN0;0G7P2`5ah_0?[`iP40
oooo00120?[`iP030;0G7P3jl>H0n_3V01<0n_3V00@0/1LN0?[`iP3jl>H0/1LN0P3jl>H00`2`5ah0
n_3V0?[`iP0D0?[`iP<0/1LN4@3jl>H20;0G7QT0n_3V0`2`5ah=0?[`iP80000000<05b8f0000002`
5ah0102`5ah203U@L@0400000017HhP0Af>804MSR0D000000P1FMIh00`000000I8Nc06B7/`0406B7
/`030000001aVLL0LIW700@0LIW700<0000007nZfP1oZ]X00`0000020;0G7P<0Rk_/1P2`5ah309K;
m`@000002@3jl>H20;0G7P80n_3V00<0/1LN0?[`iP3jl>H0903jl>H40;0G7P80n_3V00<0/1LN0?[`
iP3jl>H00`2`5ah:0?[`iP030;0G7P3jl>H0n_3V01/0n_3V0P2`5ah30?[`iP80/1LN00<0n_3V0;0G
7P3jl>H0;@3jl>H10?ooo`00@@3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iPD0/1LN5P3jl>H20;0G7Q80
n_3V102`5ahG0?[`iP@0/1LN203jl>H90;0G7P0402TjE@00000000000;0G7P<0>E1a00H0000004MS
R0000000000004MSR000000505IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101a
VLL00`000000Oj[J07nZfP0307nZfP070000002`5ah0/1LN0000002`5ah0Rk_/0;0G7P0309G8n003
0000002`5ah0/1LN00<0/1LN0P00000;0?[`iP80/1LN9`3jl>H30;0G7P030?[`iP2`5ah0/1LN00<0
n_3V00<0/1LN0?[`iP3jl>H02P3jl>H00`2`5ah0n_3V0?[`iP0L0?[`iP030;0G7P3jl>H0n_3V0080
/1LN00<0n_3V0;0G7P2`5ah0;P3jl>H10?ooo`00@@3jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP<0/1LN
4P3jl>H20;0G7P<0n_3V00<0/1LN0?[`iP3jl>H0403jl>H01P2`5ah0n_3V0;0G7P2`5ah0n_3V0;0G
7Q@0n_3V0P2`5ah20?[`iPX0/1LN1@3jl>H01`0000005b8f0000000Y>UD0000002TjE@000000100i
D742000000<0Af>800<0000005IeWP1FMIh00`1FMIh00`000000I8Nc06B7/`0406B7/`030000001a
VLL0LIW700@0LIW700<0000007nZfP1oZ]X00`1oZ]X00`000000Rk_/08^kk0020;0G7P030000002`
5ah0ULSh0080ULSh00H0000009K;m`00000000000;0G7P1o[]840;0G7P/0n_3V0P2`5ahU0?[`iP80
/1LN00<0n_3V0;0G7P2`5ah00`3jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP030;0G7P3jl>H0n_3V01`0
n_3V00@0/1LN0?[`iP2`5ah0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP0/0?[`iP40oooo00110?[`iP03
0;0G7P3jl>H0n_3V01L0n_3V00<0/1LN0?[`iP3jl>H03`3jl>H30;0G7P030?[`iP2`5ah0/1LN0080
/1LN4`3jl>H40;0G7Q@0n_3V1`2`5ah=0?[`iP040000000G8SH0000000000080:CYE00<0000003U@
L@0iD7400`00000404MSR0030000001FMIh0EWFN00<0EWFN00<0000006B7/`1TQk<0101TQk<00`00
0000LIW7076Ia`04076Ia`040000001oZ]X0Oj[J07nZfP80/1LN00@0000008^kk02;^n`0Rk_/0`2`
5ah200000080ULSh00<0000009K;m`2`5ah00P2`5ah200000080n_3V1@2`5ah80?[`iP80/1LN9@3j
l>H20;0G7P040?[`iP2`5ah0n_3V0;0G7Pl0n_3V00<0/1LN0?[`iP3jl>H0703jl>H20;0G7P040?[`
iP2`5ah0n_3V0;0G7Rl0n_3V0@3oool00400n_3V0P2`5ah[0?[`iP070;0G7P3jl>H0/1LN0?[`iP2`
5ah0n_3V0;0G7P0E0?[`iP<0/1LN5@3jl>H40;0G7P030?[`iP2`5ah0n_3V00H0n_3V0P2`5ah40?[`
iP030000000G8SH0000000<0:CYE0`00000203U@L@0300000017HhP0Af>80080Af>800<0000005Ie
WP1FMIh00P1FMIhA000000D0/1LN102;^n`20;0G7P80ULSh0`00000209K;m`80/1LN0P0000070?[`
iPD0/1LN8@3jl>H00`2`5ah0n_3V0?[`iP0:0?[`iP80/1LN3`3jl>H00`2`5ah0n_3V0?[`iP0L0?[`
iPD0/1LN<03jl>H10?ooo`00?P3jl>H40;0G7R/0n_3V0P2`5ah00`3jl>H0/1LN0?[`iP020;0G7QH0
n_3V00<0/1LN0?[`iP3jl>H05P3jl>H40;0G7PD0n_3V0P2`5ah60?[`iP<000000`0Y>UD01@000000
>E1a03U@L@0iD740000000D0Af>800<0000005IeWP0000000P0000000`1FMIh0000006B7/`0506B7
/`030000001aVLL0LIW700@0LIW7102`5ah00`000000/1LN0;0G7P0508^kk0030000002Eb?P0ULSh
0080ULSh00<0000009K;m`2FboL00P0000000`2`5ah000000?[`iP0;0?[`iPD0/1LN6P3jl>H40;0G
7P/0n_3V00<0/1LN0?[`iP3jl>H03P3jl>H00`2`5ah0n_3V0?[`iP0L0?[`iP030;0G7P3jl>H0/1LN
0380n_3V0@3oool003`0n_3V0P2`5ah20?[`iP040;0G7P3jl>H0/1LN0;0G7Q/0n_3V00<0/1LN0?[`
iP3jl>H02P3jl>H40;0G7P80n_3V00<0/1LN0?[`iP3jl>H0<03jl>H20;0G7P80n_3V0`2`5ah80?[`
iP<000000P0Y>UD2000000<0>E1a00<0000004MSR017HhP00P17HhP3000000@0EWFN00<0000006B7
/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000002`5ah0Oj[J00D0/1LN00D0000008^k
k02;^n`0Rk_/0000000409G8n080000000D0U/_g000000000000/1LN0000000A0?[`iP<0/1LN5P3j
l>H01P2`5ah0n_3V0?[`iP2`5ah0n_3V0;0G7PX0n_3V0P2`5ahP0?[`iP<0/1LN2P3jl>H00`2`5ah0
n_3V0?[`iP0c0?[`iP40oooo000k0?[`iP030;0G7P3jl>H0n_3V0080n_3V00D0/1LN0?[`iP3jl>H0
n_3V0;0G7P0I0?[`iP030;0G7P3jl>H0n_3V00/0n_3V202`5ah^0?[`iP80/1LN0`3jl>H20;0G7P/0
n_3V00L0000001LR=P000000:CYE0000000Y>UD0000000<0>E1a00<0000004MSR00000000P000000
0`17HhP0000005IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL0
0`000000Oj[J0;0G7P030;0G7P030000002;^n`0/1LN00<0/1LN00<0000009G8n02Eb?P00P2Eb?P2
0000000509K;m`000000OjkB0000002`5ah07`3jl>H60;0G7PH0n_3V102`5ah:0?[`iP040;0G7P3j
l>H0n_3V0;0G7Qh0n_3V1@2`5ah80?[`iP030;0G7P3jl>H0n_3V03@0n_3V0@3oool003`0n_3V00<0
/1LN0?[`iP3jl>H00P2`5ah40?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H02`3j
l>H70;0G7Rh0n_3V0P2`5ah0103jl>H0/1LN0;0G7P2`5ah=0?[`iP040000000G8SH0000000000080
:CYE00@0000003U@L@0iD740>E1a0P00000404MSR0030000001FMIh0EWFN00<0EWFN00<0000006B7
/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`040000001oZ]X0Oj[J07nZfP80/1LN00<00000
08^kk02;^n`00P2;^n`00`000000/1LN0;0G7P030;0G7P050000002FboL000000000001o[]800P00
000O0?[`iPP0/1LN1P3jl>H00`2`5ah0n_3V0?[`iP090?[`iP040;0G7P3jl>H0n_3V0;0G7Qd0n_3V
0P2`5ah0103jl>H0/1LN0;0G7P2`5ah80?[`iP030;0G7P3jl>H0n_3V03@0n_3V0@3oool003d0n_3V
102`5ah20?[`iP80/1LN603jl>H00`2`5ah0n_3V0?[`iP0?0?[`iP@0/1LN;P3jl>H40;0G7Ph0n_3V
0P0000000`0G8SH0000002TjE@0202TjE@030000000iD740>E1a008000001@17HhP00`000000EWFN
05IeWP0305IeWP040000001TQk<0I8Nc06B7/`L000000`1aVLL00`000000Oj[J07nZfP0207nZfP03
0;0G7P000000Rk_/00@0Rk_/0`00000209G8n0D0/1LN0P00000O0?[`iP80/1LN00D0n_3V0;0G7P3j
l>H0n_3V0;0G7P070?[`iP030;0G7P3jl>H0n_3V00P0n_3V00<0/1LN0?[`iP3jl>H00P3jl>H00`2`
5ah0n_3V0?[`iP0I0?[`iP040;0G7P3jl>H0n_3V0?[`iP80/1LN00<0n_3V0;0G7P3jl>H01@3jl>H0
0`2`5ah0n_3V0?[`iP0e0?[`iP40oooo000m0?[`iP040;0G7P3jl>H0/1LN0?[`iP80/1LN5@3jl>H0
1@2`5ah0n_3V0?[`iP3jl>H0/1LN0140n_3V00H0/1LN0?[`iP2`5ah0/1LN0?[`iP2`5ah/0?[`iPH0
/1LN3@3jl>H4000000<0:CYE0`0000000`0iD740000004MSR00404MSR0040000001FMIh0EWFN05Ie
WPH000000`1TQk<010000000LIW7076Ia`1aVLL6000000<0Oj[J00<0000008^kk02;^n`00`2;^n`0
0`000000ULSh09G8n00300000080U/_g00<0000007n^dP2`5ah00P2`5ahO0?[`iP80/1LN00@0n_3V
0;0G7P2`5ah0/1LN1P3jl>H00`2`5ah0n_3V0?[`iP0?0?[`iP030;0G7P3jl>H0n_3V01T0n_3V00@0
/1LN0?[`iP3jl>H0/1LN0`3jl>H00`2`5ah0n_3V0?[`iP030?[`iP030;0G7P3jl>H0n_3V03D0n_3V
0@3oool003h0n_3V102`5ahF0?[`iP040;0G7P3jl>H0n_3V0;0G7Q<0n_3V0`2`5ah20?[`iP030;0G
7P3jl>H0n_3V02`0n_3V00<0/1LN0?[`iP3jl>H03@3jl>H4000000<0:CYE00D0000003U@L@0iD740
>E1a0000000404MSR0D000000P1FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW70080
LIW70P2`5ah00`000000Oj[J07nZfP05000000@0Rk_/00<0000009G8n02Eb?P00P2Eb?P00`000000
U/_g09K;m`0400000200n_3V1P2`5ah60?[`iP030;0G7P3jl>H0n_3V00l0n_3V00<0/1LN0?[`iP3j
l>H04P3jl>H20;0G7PH0n_3V0`2`5ah20?[`iP030;0G7P3jl>H0n_3V00<0n_3V00<0/1LN0?[`iP3j
l>H0=P3jl>H10?ooo`00?`3jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP040;0G7P3jl>H0n_3V0;0G7Q<0
n_3V0P2`5ah00`3jl>H0/1LN0;0G7P0U0?[`iP<0/1LN1P3jl>H00`2`5ah0n_3V0?[`iP0>0?[`iP80
000000@05b8f0000000Y>UD0:CYE0P00000303U@L@0300000017HhP000000080000000<0Af>80000
001FMIh0101FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0/1LN00<0000007nZ
fP1oZ]X00`1oZ]X00`000000Rk_/000000020000000308^kk0000000ULSh00<0ULSh0P0000000`2F
boL000000000000200000200n_3V202`5ah40?[`iP030;0G7P3jl>H0n_3V0100n_3V00<0/1LN0?[`
iP3jl>H03@3jl>H60;0G7PL0n_3V102`5ah50?[`iP030;0G7P3jl>H0n_3V03L0n_3V0@3oool005P0
n_3V00<0/1LN0?[`iP2`5ah05@3jl>H30;0G7R@0n_3V102`5ah60?[`iP80/1LN403jl>H200000006
01LR=P00000000000000000Y>UD000000`0iD742000000<0Af>80P2`5ah505IeWP030000001TQk<0
I8Nc00@0I8Nc00@00000076Ia`1aVLL0LIW7202`5ah00`1oZ]X0000008^kk00308^kk0800000102E
b?P01@000000U/_g000000000000OjkB00800000603jl>H20;0G7PL0n_3V102`5ah30?[`iP050;0G
7P3jl>H0n_3V0?[`iP2`5ah0803jl>H20;0G7P80n_3V102`5ah70?[`iP80/1LN1`3jl>H00`2`5ah0
n_3V0?[`iP0g0?[`iP40oooo001H0?[`iP80/1LN5`3jl>H40;0G7Ql0n_3V0`2`5ah40?[`iP030;0G
7P3jl>H0n_3V0080n_3V102`5ah?0?[`iP80000000<05b8f0000000Y>UD00P0Y>UD00`000000>E1a
03U@L@0200000080Af>8102`5ah505IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0
101aVLL00`000000Oj[J07nZfP0207nZfP@0/1LN0`2;^n`300000080ULSh00D0000009K;m`2FboL0
000007n^dP02000001P0n_3V102`5ah40?[`iP030;0G7P3jl>H0n_3V00H0n_3V0P2`5ah00`3jl>H0
/1LN0?[`iP0P0?[`iP030;0G7P3jl>H0n_3V0080/1LN00<0n_3V0;0G7P3jl>H01@3jl>H00`2`5ah0
n_3V0?[`iP060?[`iP030;0G7P3jl>H0n_3V03P0n_3V0@3oool005P0n_3V0P2`5ahF0?[`iP<0/1LN
0P3jl>H00`2`5ah0n_3V0?[`iP0A0?[`iP030;0G7P3jl>H0n_3V00@0n_3V102`5ah80?[`iP030;0G
7P3jl>H0n_3V0080n_3V0P2`5ah@0?[`iP@000000`0Y>UD30000000403U@L@000000/1LN0;0G7P80
Af>80P2`5ah405IeWQ8000000`1oZ]X00`000000Rk_/08^kk00308^kk0030000002Eb?P0ULSh00<0
00000P2FboL4000001L0n_3V0`2`5ah00`3jl>H0/1LN0;0G7P020?[`iP030;0G7P3jl>H0n_3V00T0
n_3V0P2`5ahN0?[`iP040;0G7P3jl>H0n_3V0?[`iP80/1LN00@0n_3V0;0G7P2`5ah0/1LN1P3jl>H0
0`2`5ah0n_3V0?[`iP050?[`iP030;0G7P3jl>H0n_3V03T0n_3V0@3oool005P0n_3V00<0/1LN0?[`
iP3jl>H0503jl>H01P2`5ah0n_3V0?[`iP2`5ah0n_3V0;0G7Q80n_3V0`2`5ah50?[`iP80/1LN303j
l>H00`2`5ah0n_3V0?[`iP0C0?[`iP@000000`0Y>UD00`000000>E1a03U@L@090;0G7P<0000000<0
EWFN0000001TQk<01@1TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00@000001@2;
^n`00`000000ULSh09G8n00209G8n0030000002FboL0U/_g0080000000<0OjkB0000003jl>H02`3j
l>H20;0G7PT0n_3V1@2`5ah00`3jl>H0/1LN0;0G7P0>0?[`iP030;0G7P3jl>H0n_3V01X0n_3V102`
5ah01@3jl>H0/1LN0;0G7P2`5ah0n_3V0080/1LN1P3jl>H00`2`5ah0n_3V0?[`iP050?[`iP030;0G
7P3jl>H0n_3V03T0n_3V0@3oool00440n_3V00<0/1LN0?[`iP3jl>H04P3jl>H30;0G7QL0n_3V1@2`
5ahA0?[`iP80/1LN0P3jl>H00`2`5ah0n_3V0;0G7P020;0G7Pl0n_3V00<0/1LN0?[`iP2`5ah04P3j
l>H20000000401LR=P000000:CYE02TjE@8000000`0iD7420;0G7P<0Af>800<0/1LN000000000000
4@2`5ah00`1aVLL0000007nZfP0407nZfP<000000`2;^n`00`000000ULSh09G8n00209G8n0800000
00<0U/_g0000001o[]800P0000090?[`iPL0/1LN2@3jl>H40;0G7Q40n_3V0P2`5ahI0?[`iP040;0G
7P3jl>H0/1LN0?[`iP<0/1LN00<0n_3V0;0G7P2`5ah01`3jl>H00`2`5ah0n_3V0?[`iP050?[`iP03
0;0G7P3jl>H0n_3V03X0n_3V0@3oool00440n_3V00<0/1LN0?[`iP3jl>H0403jl>H20;0G7P030?[`
iP2`5ah0/1LN01P0n_3V0`2`5ahA0?[`iP80/1LN00<0n_3V0;0G7P2`5ah00P2`5ah00`3jl>H0/1LN
0?[`iP0@0?[`iP<0/1LN4@3jl>H20000000601LR=P000000:CYE0000000Y>UD000000`0iD7401`00
0000Af>80;0G7P2`5ah000000;0G7P0000001@1FMIh00`000000I8Nc06B7/`0406B7/`030000001a
VLL0LIW700<0LIW72@2`5ah01@2;^n`000000000002;^n`0000000@0ULSh00@0000009K;m`000000
00000P1o[]800`000000n_3V0?[`iP050?[`iPH0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP090?[`iP03
0;0G7P3jl>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H05P3jl>H30;0G7P030?[`iP2`5ah0n_3V0080
/1LN2@3jl>H00`2`5ah0n_3V0?[`iP120?[`iP40oooo00110?[`iP030;0G7P3jl>H0n_3V00h0n_3V
0P2`5ah01@3jl>H0/1LN0;0G7P3jl>H0/1LN01X0n_3V00<0/1LN0?[`iP3jl>H03`3jl>H40;0G7P80
n_3V0P2`5ahA0?[`iP@0/1LN4@3jl>H20000000301LR=P00000000000080:CYE00@0000003U@L@0i
D740>E1a0P0000001@17HhP0/1LN0;0G7P2`5ah0000000D0EWFN00<0000006B7/`1TQk<0101TQk<0
0`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00<0Oj[J00<0000008^kk02;^n`00P2;^n`2
000000@0ULSh00@0000009K;m`2FboL000000P1o[]800`000000n_3V0?[`iP060?[`iPD0/1LN00@0
n_3V0;0G7P3jl>H0n_3V0P2`5ah90?[`iP030;0G7P3jl>H0n_3V0180n_3V0P2`5ahE0?[`iP030;0G
7P3jl>H0n_3V0080/1LN0P3jl>H00`2`5ah0n_3V0?[`iP080?[`iP030;0G7P3jl>H0n_3V0480n_3V
0@3oool00400n_3V00<0/1LN0?[`iP3jl>H03`3jl>H40;0G7P<0n_3V00<0/1LN0?[`iP3jl>H0:03j
l>H80;0G7Q<0n_3V0`2`5ahA0?[`iP80000000<05b8f0000000Y>UD00P0Y>UD00`000000>E1a03U@
L@02000000060;0G7P17HhP0Af>804MSR02`5ah000001@1FMIh010000000I8Nc06B7/`1TQk<70000
00<0LIW700<0000007nZfP1oZ]X00`1oZ]X00`000000Rk_/08^kk00308^kk0<000000P2Eb?P00`00
0000U/_g09K;m`020000000307n^dP000000000000L0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P060;0G
7PX0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP060;0G7P3jl>H0n_3V
0;0G7P3jl>H0/1LN2P3jl>H00`2`5ah0n_3V0?[`iP130?[`iP40oooo00100?[`iP030;0G7P3jl>H0
n_3V00l0n_3V0`2`5ah40?[`iP80/1LN8`3jl>H00`2`5ah0n_3V0?[`iP060?[`iPD0/1LN9`3jl>H4
000000<0:CYE0`0000030;0G7P@0Af>800<0000005IeWP2`5ah02@2`5ah00`1TQk<00000076Ia`02
076Ia`H000000`1oZ]X00`000000Rk_/08^kk00308^kk0030000002Eb?P0ULSh00<000000P2FboL2
0000000307n^dP000000000000P0n_3V0`2`5ah20?[`iP@0/1LN303jl>H00`2`5ah0n_3V0?[`iP0O
0?[`iP<0/1LN1`3jl>H40;0G7P/0n_3V00<0/1LN0?[`iP3jl>H0@`3jl>H10?ooo`00@03jl>H00`2`
5ah0n_3V0?[`iP0@0?[`iPP0/1LN903jl>H00`2`5ah0n_3V0?[`iP040?[`iP<0/1LN00<0n_3V0;0G
7P3jl>H09`3jl>H4000000<0:CYE00<000000;0G7P2`5ah02@2`5ah200000080EWFN00<0000006B7
/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00D00000102;^n`00`00
0000ULSh09G8n00209G8n0050000002FboL0U/_g0000001o[]800`0000080?[`iP<0/1LN0P3jl>H0
102`5ah0n_3V0;0G7P3jl>H30;0G7PT0n_3V00<0/1LN0?[`iP3jl>H07@3jl>H50;0G7PL0n_3V00<0
/1LN0?[`iP2`5ah0303jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP80/1LN;03jl>H10?ooo`00@03jl>H0
0`2`5ah0n_3V0?[`iP0@0?[`iP@0/1LN0P3jl>H00`2`5ah0n_3V0;0G7P0O0?[`iP030;0G7P3jl>H0
n_3V0080n_3V00<0/1LN0?[`iP3jl>H00`3jl>H50;0G7RP0n_3V0P000000100G8SH0000002TjE@0Y
>UD20000000503U@L@2`5ah0/1LN0000002`5ah00`0000000`17HhP0000005IeWP0405IeWP030000
001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000Oj[J07nZfP0307nZfP030000
002;^n`000000080000000<0Rk_/0000002Eb?P00`2Eb?P200000080U/_g00@0000007n^dP000000
00000P3jl>H20;0G7P@0n_3V1@2`5ah20?[`iP030;0G7P3jl>H0n_3V0080n_3V0P2`5ah80?[`iP03
0;0G7P3jl>H0n_3V01/0n_3V0P2`5ah20?[`iP<0/1LN1@3jl>H0102`5ah0n_3V0?[`iP2`5ah;0?[`
iP030;0G7P3jl>H0n_3V01@0n_3V102`5ah/0?[`iP40oooo000o0?[`iP030;0G7P3jl>H0n_3V0180
n_3V00<0/1LN0?[`iP3jl>H00P3jl>H0102`5ah0n_3V0?[`iP2`5ahM0?[`iP030;0G7P3jl>H0n_3V
00@0n_3V00<0/1LN0?[`iP3jl>H00`3jl>H20;0G7P030?[`iP2`5ah0/1LN02L0n_3V0P0000001P0G
8SH00000000000000000:CYE000000<0>E1a102`5ah204MSR0030000001FMIh0EWFN00<0EWFN00<0
000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00<0Oj[J00<0
000008^kk02;^n`00P2;^n`2000000@0ULSh00<0000009K;m`0000000P0000000`1o[]8000000000
00060;0G7P80n_3V00<0/1LN0?[`iP2`5ah00P2`5ah00`3jl>H0/1LN0?[`iP060?[`iP<0/1LN903j
l>H01P2`5ah0n_3V0;0G7P2`5ah0n_3V0;0G7P@0n_3V00D0/1LN0?[`iP3jl>H0n_3V0;0G7P0;0?[`
iP030;0G7P3jl>H0n_3V0180n_3V0P2`5ah0103jl>H0/1LN0;0G7P2`5ah/0?[`iP40oooo000o0?[`
iP030;0G7P3jl>H0n_3V01<0n_3V00D0/1LN0?[`iP3jl>H0n_3V0;0G7P020?[`iP80/1LN6P3jl>H2
0;0G7PP0n_3V00<0/1LN0?[`iP3jl>H00P3jl>H30;0G7RT0n_3V0P0000001`0G8SH0000002TjE@0Y
>UD0000003U@L@2`5ah00P0000020;0G7P@0Af>800<0000005IeWP1FMIh00`1FMIh00`000000I8Nc
06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007nZfP1oZ]X00`1oZ]X00`000000Rk_/
08^kk00308^kk0<000000P2Eb?P01P000000U/_g09K;m`2FboL0000007n^dP80000000<0n_3V0;0G
7P2`5ah00P2`5ah20?[`iP@0/1LN0`3jl>H00`2`5ah0n_3V0?[`iP080?[`iP<0/1LN6@3jl>H40;0G
7PD0n_3V102`5ah40?[`iP030;0G7P3jl>H0n_3V0080n_3V00<0/1LN0?[`iP3jl>H0703jl>H20;0G
7P<0n_3V0P2`5ah00`3jl>H0/1LN0?[`iP0Z0?[`iP40oooo000o0?[`iP030;0G7P3jl>H0n_3V01@0
n_3V0P2`5ah00`3jl>H0/1LN0;0G7P020;0G7QD0n_3V00<0/1LN0?[`iP3jl>H00P3jl>H00`2`5ah0
n_3V0?[`iP090?[`iP040;0G7P3jl>H0n_3V0?[`iP@0/1LN:03jl>H400000080:CYE00<000000;0G
7P2`5ah00P2`5ah00`000000Af>804MSR00304MSR0030000001FMIh0EWFN0080EWFN4@00000407nZ
fP030000002;^n`0Rk_/00<0Rk_/00<0000009G8n02Eb?P00`00000309K;m`050000001o[]800000
0000003jl>H01P2`5ah20?[`iP050;0G7P3jl>H0n_3V0?[`iP2`5ah03P3jl>H30;0G7Q@0n_3V1P2`
5ah50?[`iP80/1LN1@3jl>H00`2`5ah0n_3V0?[`iP030?[`iP030;0G7P3jl>H0n_3V01d0n_3V00<0
/1LN0?[`iP3jl>H00P2`5ah00`3jl>H0/1LN0;0G7P0[0?[`iP40oooo000o0?[`iP030;0G7P3jl>H0
n_3V01H0n_3V102`5ahF0?[`iP050;0G7P3jl>H0n_3V0?[`iP2`5ah03@3jl>H01@2`5ah0n_3V0;0G
7P3jl>H0/1LN0080n_3V00<0/1LN0?[`iP3jl>H09@3jl>H400000080:CYE0`2`5ah203U@L@030000
0017HhP0Af>800<0Af>800<0000005IeWP0000000P0000000`1FMIh0000006B7/`0506B7/`030000
001aVLL0LIW700@0LIW700<0000007nZfP0000000P0000000`1oZ]X0000008^kk00308^kk080/1LN
102Eb?P010000000U/_g09K;m`2FboL4000000@0/1LN0P3jl>H20;0G7QL0n_3V0`2`5ahA0?[`iP03
0;0G7P3jl>H0/1LN00D0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP040?[`iP030;0G7P3jl>H0n_3V00@0
n_3V00<0/1LN0?[`iP3jl>H07P3jl>H0102`5ah0n_3V0;0G7P2`5ah20?[`iP030;0G7P3jl>H0n_3V
02T0n_3V0@3oool003h0n_3V00<0/1LN0?[`iP3jl>H0603jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP03
0;0G7P3jl>H0n_3V0080/1LN3P3jl>H01@2`5ah0n_3V0?[`iP2`5ah0n_3V0080/1LN:03jl>H20000
000301LR=P000000:CYE00800000100iD7400`000000Af>804MSR00204MSR0<00000101FMIh00`00
0000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007nZfP1oZ]X00P1oZ]X30000
000408^kk02`5ah0/1LN08^kk0<0/1LN0P2Eb?P200000080U/_g100000080?[`iP<0/1LN5`3jl>H2
0;0G7Pl0n_3V1P2`5ah20?[`iP<0/1LN3P3jl>H00`2`5ah0n_3V0?[`iP0M0?[`iP80/1LN00@0n_3V
0;0G7P3jl>H0/1LN;03jl>H10?ooo`00?P3jl>H00`2`5ah0n_3V0?[`iP0Z0?[`iP030;0G7P3jl>H0
n_3V00<0n_3V00<0/1LN0?[`iP2`5ah04@3jl>H00`2`5ah0n_3V0?[`iP030;0G7QX0n_3V00@0/1LN
0?[`iP3jl>H0n_3V0P2`5ah80?[`iP80000000D05b8f000000000000:CYE0000000403U@L@030000
0017HhP000000080000000<0Af>80000001FMIh0101FMIh00`000000I8Nc06B7/`0406B7/`030000
001aVLL0LIW700@0LIW700<0000007nZfP1oZ]X00`1oZ]X60;0G7P030000002Eb?P0/1LN0080ULSh
00<0000009K;m`0000000`2`5ah2000000/0n_3V0P2`5ahU0?[`iP030;0G7P3jl>H0/1LN00@0/1LN
0P3jl>H20;0G7Pl0n_3V00<0/1LN0?[`iP3jl>H07@3jl>H50;0G7Rd0n_3V0@3oool003d0n_3V0P2`
5ah/0?[`iP030;0G7P3jl>H0/1LN00<0n_3V0P2`5ahC0?[`iPH0/1LN5`3jl>H30;0G7PD0n_3V0P2`
5ah60?[`iP80000000<05b8f0000000000001@2`5ah00`0iD74000000000000404MSR0030000001F
MIh0EWFN00<0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`040000001o
Z]X0Oj[J07nZfP<0/1LN102;^n`00`2`5ah000000;0G7P0309G8n0030000002FboL0U/_g0080/1LN
00<0OjkB0000000000003@3jl>H20;0G7R40n_3V0P2`5ah30?[`iP<0/1LN00@0n_3V0;0G7P2`5ah0
/1LN403jl>H00`2`5ah0n_3V0?[`iP0M0?[`iP030;0G7P3jl>H0/1LN02l0n_3V0@3oool003/0n_3V
102`5ah/0?[`iP80/1LN00<0n_3V0;0G7P3jl>H00P2`5ahD0?[`iP80/1LN00@0n_3V0;0G7P2`5ah0
/1LN5P3jl>H40;0G7PL0n_3V2`2`5ah0100Y>UD0000003U@L@0iD743000000D0Af>800<0000005Ie
WP1FMIh00`1FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007nZ
fP1oZ]X00P1oZ]X00`2`5ah000000;0G7P040;0G7P030000002`5ah000000080ULSh00@0000009K;
m`2FboL0U/_g0P2`5ah2000000l0n_3V0P2`5ahL0?[`iP<0/1LN1P3jl>H60;0G7Q00n_3V00<0/1LN
0?[`iP3jl>H0703jl>H00`2`5ah0n_3V0?[`iP0`0?[`iP40oooo000i0?[`iP80/1LN0P3jl>H00`2`
5ah0n_3V0;0G7P0Z0?[`iP040;0G7P3jl>H0/1LN0?[`iP<0/1LN503jl>H20;0G7P040?[`iP2`5ah0
/1LN0;0G7QD0n_3V0P2`5ah20?[`iPX0/1LN00D0n_3V0;0G7P2`5ah0/1LN0?[`iP0400000080:CYE
0`00000203U@L@0300000017HhP0Af>800<0Af>800@0000005IeWP1FMIh0EWFN4`00000307nZfP80
/1LN0`2;^n`60;0G7P040000002FboL0U/_g09K;m`80000000<0/1LN0000003jl>H0:`3jl>H40;0G
7PP0n_3V00@0/1LN0?[`iP2`5ah0/1LN403jl>H00`2`5ah0n_3V0?[`iP0A0?[`iP030;0G7P3jl>H0
n_3V00L0n_3V00<0/1LN0?[`iP3jl>H0<@3jl>H10?ooo`00>03jl>H00`2`5ah0n_3V0?[`iP020?[`
iP040;0G7P3jl>H0n_3V0;0G7RT0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P020;0G7QD0n_3V1@2`5ahD
0?[`iPL0/1LN1`3jl>H20;0G7P<0n_3V00<0/1LN0000000000000P00000202TjE@030000000iD740
>E1a0080>E1a00<0000004MSR017HhP00`17HhP400000080EWFN00<0000006B7/`1TQk<0101TQk<0
0`000000LIW7076Ia`04076Ia`040000001oZ]X0Oj[J00000080/1LN00P000000;0G7P2`5ah0Rk_/
0;0G7P2;^n`000000;0G7P<0ULSh1@2`5ah2000000030;0G7P3jl>H0n_3V02T0n_3V0`2`5ah20?[`
iP030;0G7P3jl>H0n_3V00L0n_3V0P2`5ahR0?[`iP@0/1LN203jl>H00`2`5ah0n_3V0?[`iP0a0?[`
iP40oooo000i0?[`iP030;0G7P3jl>H0n_3V0080/1LN0`3jl>H00`2`5ah0n_3V0?[`iP0H0?[`iP03
0;0G7P3jl>H0n_3V00/0n_3V102`5ah00`3jl>H0/1LN0;0G7P0G0?[`iP<0/1LN5@3jl>H60;0G7P@0
n_3V0`2`5ah60?[`iP80000000<05b8f0000000Y>UD00P00000403U@L@0400000017HhP0Af>804MS
R0<000001@1FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007nZ
fP2`5ah0102`5ah01P2;^n`000000;0G7P2`5ah0Rk_/0;0G7P@0ULSh0P00000209K;m`030000002`
5ah0/1LN00<0/1LN:03jl>H00`2`5ah0n_3V0;0G7P030;0G7PT0n_3V00@0/1LN0?[`iP3jl>H0/1LN
803jl>H00`2`5ah0n_3V0;0G7P020;0G7PL0n_3V00<0/1LN0?[`iP3jl>H0<P3jl>H10?ooo`00>P3j
l>H0102`5ah0n_3V0;0G7P2`5ah40?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H0
303jl>H30;0G7P040?[`iP2`5ah0/1LN0;0G7S00n_3V1@2`5ah0103jl>H0/1LN0;0G7P2`5ah90?[`
iP80000000D05b8f000000000000:CYE0000000403U@L@0400000017HhP0000000000080Af>800<0
000005IeWP1FMIh00`1FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW7102`
5ah00`1oZ]X0/1LN0;0G7P0308^kk0<0/1LN102Eb?P00`000000U/_g000000020000000307n^dP00
000000000080n_3V1@2`5ahM0?[`iP<0/1LN00<0n_3V0;0G7P2`5ah00`3jl>H00`2`5ah0n_3V0?[`
iP0=0?[`iP030;0G7P3jl>H0n_3V01/0n_3V0P2`5ah20?[`iP@0/1LN1P3jl>H00`2`5ah0n_3V0?[`
iP0b0?[`iP40oooo000j0?[`iP030;0G7P3jl>H0/1LN00<0n_3V0P2`5ahD0?[`iP030;0G7P3jl>H0
n_3V0080n_3V00<0/1LN0?[`iP3jl>H0303jl>H70;0G7Rl0n_3V1`2`5ah<0?[`iP80000000D05b8f
0000000Y>UD0:CYE0000000403U@L@8000001017HhP00`000000EWFN05IeWP0305IeWP030000001T
Qk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000/1LN07nZfP050;0G7P<0Rk_/0P2`
5ah200000080ULSh00H0000009K;m`2FboL0U/_g0000001o[]82000000L0n_3V1@2`5ahF0?[`iPH0
/1LN1@3jl>H00`2`5ah0n_3V0?[`iP0>0?[`iP030;0G7P3jl>H0n_3V0140n_3V102`5ah40?[`iP03
0;0G7P3jl>H0n_3V0080n_3V00D0/1LN0?[`iP3jl>H0n_3V0;0G7P040?[`iP030;0G7P3jl>H0n_3V
03<0n_3V0@3oool003/0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P0F0?[`iP050;0G7P3jl>H0n_3V0?[`
iP2`5ah0403jl>H20;0G7P050?[`iP2`5ah0/1LN0?[`iP2`5ah09P3jl>H00`2`5ah0n_3V0?[`iP05
0?[`iP@0/1LN3`3jl>H400000080:CYE00<0000003U@L@0iD7400`00000504MSR0030000001FMIh0
EWFN00<0EWFN00@0000006B7/`1TQk<0I8Nc1`000003076Ia`030000001oZ]X0/1LN00<0/1LN00<0
000008^kk02`5ah0102`5ah209G8n0<000000`2FboL010000000OjkB00000000000<0?[`iPD0/1LN
2P3jl>H20;0G7P<0n_3V102`5ah00`3jl>H0/1LN0;0G7P060?[`iP030;0G7P3jl>H0n_3V00l0n_3V
00<0/1LN0?[`iP3jl>H03P3jl>H60;0G7PD0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P020?[`iP030;0G
7P3jl>H0n_3V0080n_3V00<0/1LN0?[`iP3jl>H0=03jl>H10?ooo`00?03jl>H20;0G7QP0n_3V00@0
/1LN0?[`iP3jl>H0/1LN4P3jl>H00`2`5ah0n_3V0;0G7P020;0G7P030?[`iP2`5ah0n_3V02D0n_3V
00<0/1LN0?[`iP3jl>H00`3jl>H60;0G7Ph0n_3V0P000000100G8SH0000002TjE@0Y>UD300000080
>E1a00<0000004MSR017HhP00`17HhP010000000EWFN05IeWP1FMIh6000000<0I8Nc00@00000076I
a`1aVLL0LIW71P000000101oZ]X0/1LN0;0G7P00000508^kk0030000002`5ah0/1LN00<0/1LN0`2F
boL400000140n_3V0`2`5ah60?[`iPh0/1LN1@3jl>H00`2`5ah0n_3V0?[`iP0?0?[`iP030;0G7P3j
l>H0n_3V00d0n_3V0P2`5ah20?[`iP<0/1LN1`3jl>H50;0G7PD0n_3V00<0/1LN0?[`iP3jl>H0=03j
l>H10?ooo`00EP3jl>H0102`5ah0n_3V0?[`iP2`5ahC0?[`iPH0/1LN703jl>H00`2`5ah0n_3V0?[`
iP080?[`iP030;0G7P3jl>H0n_3V00<0n_3V102`5ah?0?[`iP80000000D05b8f0000000Y>UD0:CYE
0000000403U@L@0300000017HhP0Af>80080Af>81@00000205IeWP030000001TQk<0I8Nc00@0I8Nc
00<00000076Ia`1aVLL00P1aVLL20;0G7P030000001oZ]X0Oj[J0080000000<0/1LN000000000000
102;^n`00`000000ULSh09G8n00209G8n0030000002`5ah0/1LN00<0/1LN0P00000J0?[`iPD0/1LN
00<0n_3V0;0G7P2`5ah00`2`5ah00`3jl>H0/1LN0?[`iP050?[`iP030;0G7P3jl>H0n_3V0100n_3V
00<0/1LN0?[`iP3jl>H03@3jl>H0102`5ah0n_3V0;0G7P3jl>H20;0G7PP0n_3V0P2`5ah60?[`iP03
0;0G7P3jl>H0n_3V03D0n_3V0@3oool005H0n_3V00<0/1LN0?[`iP2`5ah05@3jl>H30;0G7P80n_3V
00<0/1LN0?[`iP3jl>H06P3jl>H20;0G7PT0n_3V00@0/1LN0?[`iP3jl>H0n_3V0`2`5ahA0?[`iP05
0000000G8SH05b8f0000000Y>UD00P00000403U@L@0300000017HhP000000080000000<0Af>80000
001FMIh0101FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0/1LN00<0000007nZ
fP1oZ]X00`1oZ]X00`000000Rk_/000000020000000308^kk0000000ULSh00<0ULSh00H0000009K;
m`000000U/_g0000001o[]830;0G7QP0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P020;0G7P030?[`iP2`
5ah0/1LN0080n_3V0P2`5ah60?[`iP030;0G7P3jl>H0n_3V0140n_3V00<0/1LN0?[`iP3jl>H0303j
l>H20;0G7P040?[`iP2`5ah0/1LN0;0G7PL0n_3V00<0/1LN0?[`iP3jl>H01@3jl>H00`2`5ah0n_3V
0?[`iP0f0?[`iP40oooo001F0?[`iP80/1LN5@3jl>H00`2`5ah0n_3V0?[`iP030;0G7Ql0n_3V0P2`
5ah80?[`iP030;0G7P3jl>H0n_3V0080/1LN00<0n_3V0;0G7P3jl>H03`3jl>H00`0000005b8f01LR
=P020000000302TjE@000000>E1a00<0>E1a0P00000404MSR0030000001FMIh0EWFN00<0EWFN00<0
000006B7/`1TQk<0101TQk<010000000LIW7076Ia`1aVLL80;0G7P0307nZfP000000Rk_/00<0Rk_/
0P00000409G8n0030000002FboL0U/_g0080000000<0OjkB0000000000005P3jl>H90;0G7P80n_3V
00@0/1LN0?[`iP2`5ah0n_3V0`2`5ah50?[`iP030;0G7P3jl>H0n_3V0200n_3V0P2`5ah0103jl>H0
/1LN0?[`iP2`5ah70?[`iP030;0G7P3jl>H0n_3V00D0n_3V00<0/1LN0?[`iP3jl>H0=P3jl>H10?oo
o`00EP3jl>H20;0G7QH0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P0Q0?[`iP80/1LN0`3jl>H20;0G7P80
n_3V00<0/1LN0?[`iP2`5ah00P2`5ahA0?[`iP040000000G8SH05b8f00000080:CYE00<0000003U@
L@0iD7400`00000504MSR0030000001FMIh0EWFN00<0EWFN00<0000006B7/`1TQk<0101TQk<00`00
0000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J0080Oj[J102`5ah308^kk0<000000P2Eb?P01P00
0000U/_g09K;m`2FboL0000007n^dP8000004`3jl>H30;0G7P80n_3V1P2`5ah30?[`iP<0/1LN00@0
n_3V0;0G7P3jl>H0n_3V0P2`5ah30?[`iP030;0G7P3jl>H0n_3V01l0n_3V00<0/1LN0?[`iP2`5ah0
0`2`5ah80?[`iP030;0G7P3jl>H0n_3V00@0n_3V00<0/1LN0?[`iP3jl>H0=`3jl>H10?ooo`00EP3j
l>H00`2`5ah0n_3V0?[`iP0G0?[`iP80/1LN7@3jl>H00`2`5ah0n_3V0?[`iP040?[`iP<0/1LN1@3j
l>H30;0G7Q80n_3V00@0000001LR=P00000000000P0Y>UD300000080>E1a00<0000004MSR017HhP0
0`17HhP00`000000EWFN05IeWP0305IeWP040000001TQk<0I8Nc06B7/``000001@1oZ]X00`000000
Rk_/08^kk00208^kk0030000002Eb?P0ULSh00<000000`2FboL010000000OjkB00000000000A0?[`
iP80/1LN1@3jl>H50;0G7PH0n_3V0P2`5ah50?[`iP030;0G7P3jl>H0n_3V0200n_3V0P2`5ah30?[`
iP030;0G7P3jl>H0n_3V00L0n_3V00<0/1LN0?[`iP3jl>H0?`3jl>H10?ooo`00D`3jl>H0102`5ah0
n_3V0?[`iP2`5ahg0?[`iP030;0G7P3jl>H0n_3V0080n_3V0`2`5ah20?[`iP80/1LN0`3jl>H40;0G
7Q80n_3V0P0000001@0G8SH0000002TjE@0Y>UD0000000@0>E1a00<0000004MSR017HhP00P17HhP0
0`2`5ah0000005IeWP0205IeWPH000000`1TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0
000000<0000000<0Oj[J0000002;^n`00`2;^n`00`000000ULSh09G8n00209G8n0040000002FboL0
U/_g09K;m`@000003P3jl>H30;0G7PL0n_3V102`5ah?0?[`iP80/1LN7`3jl>H30;0G7Pd0n_3V00<0
/1LN0?[`iP3jl>H0?`3jl>H10?ooo`00?P3jl>H00`2`5ah0n_3V0?[`iP0A0?[`iPD0/1LN;P3jl>H0
0`2`5ah0n_3V0;0G7P050?[`iP030;0G7P3jl>H0n_3V00<0/1LN1`3jl>H30;0G7P040?[`iP2`5ah0
/1LN0;0G7Q80n_3V0`00000202TjE@800000100iD7400`000000Af>804MSR0030;0G7P@000000P1F
MIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007nZfP1oZ]X00`1o
Z]X3000000<0Rk_/00<0000009G8n02Eb?P00P2Eb?P200000080U/_g1000000<0?[`iP80/1LN0`3j
l>H20;0G7PH0n_3V0`2`5ahA0?[`iP80/1LN703jl>H60;0G7P/0n_3V00<0/1LN0?[`iP3jl>H0?`3j
l>H10?ooo`00?P3jl>H00`2`5ah0n_3V0?[`iP0?0?[`iP<0/1LN00@0n_3V0;0G7P2`5ah0/1LN9P3j
l>H00`2`5ah0n_3V0?[`iP050?[`iP<0/1LN103jl>H40;0G7P`0n_3V102`5ahC0?[`iP070000000G
8SH0000002TjE@000000:CYE0000000403U@L@070000002`5ah0/1LN0;0G7P000000/1LN00000005
05IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000Oj[J07nZfP04
07nZfP060000002;^n`000000000002;^n`00000102Eb?P00`000000U/_g000000020000000307n^
dP000000000000l0n_3V102`5ah90?[`iP030;0G7P3jl>H0n_3V0100n_3V00<0/1LN0?[`iP3jl>H0
603jl>H20;0G7P040?[`iP2`5ah0n_3V0?[`iP80/1LN2@3jl>H00`2`5ah0n_3V0?[`iP100?[`iP40
oooo000m0?[`iP030;0G7P3jl>H0n_3V00l0n_3V00D0/1LN0?[`iP3jl>H0/1LN0?[`iP030;0G7RL0
n_3V00<0/1LN0?[`iP3jl>H00`3jl>H20;0G7P80n_3V00<0/1LN0?[`iP2`5ah00P2`5ah>0?[`iP03
0;0G7P3jl>H0n_3V00<0/1LN4@3jl>H20000000301LR=P00000000000080:CYE00@0000003U@L@0i
D740>E1a0`2`5ah304MSR0030;0G7P000000EWFN00@0EWFN00<0000006B7/`1TQk<0101TQk<00`00
0000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00@0Oj[J00@0000008^kk02;^n`0Rk_/0P000004
09G8n0060000002FboL0U/_g09K;m`000000OjkB0P00000@0?[`iP80/1LN00<0n_3V0;0G7P3jl>H0
203jl>H00`2`5ah0n_3V0?[`iP0@0?[`iP80/1LN3`3jl>H30;0G7PD0n_3V0P2`5ah20?[`iP80/1LN
00<0n_3V0;0G7P3jl>H02@3jl>H00`2`5ah0n_3V0?[`iP100?[`iP40oooo000m0?[`iP030;0G7P3j
l>H0n_3V00l0n_3V0P2`5ah0103jl>H0/1LN0;0G7P3jl>H30;0G7RL0n_3V00@0/1LN0?[`iP3jl>H0
n_3V0P2`5ah00`3jl>H0/1LN0;0G7P030;0G7Q00n_3V1P2`5ahA0?[`iP80000000<05b8f0000000Y
>UD00P0Y>UD00`000000>E1a03U@L@090;0G7PD0EWFN00<0000006B7/`1TQk<0101TQk<00`000000
LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00@0Oj[J00<0000008^kk02;^n`00P2;^n`300000080
ULSh00H0000009K;m`2FboL0U/_g0000001o[]82000000P0n_3V1`2`5ah0103jl>H0/1LN0;0G7P2`
5ah;0?[`iP030;0G7P3jl>H0n_3V0140n_3V0P2`5ah;0?[`iPD0/1LN1@3jl>H30;0G7P80n_3V0P2`
5ah;0?[`iP030;0G7P3jl>H0n_3V0400n_3V0@3oool003d0n_3V00<0/1LN0?[`iP3jl>H0403jl>H0
0`2`5ah0n_3V0;0G7P020;0G7P040?[`iP2`5ah0/1LN0;0G7RL0n_3V00<0/1LN0?[`iP3jl>H01@2`
5ah00`3jl>H0/1LN0?[`iP0A0?[`iP<0/1LN4`3jl>H4000000<0:CYE0`000000100iD740/1LN0;0G
7P2`5ah304MSR0030;0G7P000000/1LN0140/1LN0`00000507nZfP030000002;^n`0Rk_/0080Rk_/
00<0000009G8n02Eb?P00`00000309K;m`@000000`3jl>H00`2`5ah0n_3V0?[`iP020?[`iPT0/1LN
3@3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V0080/1LN1@3jl>H20;0G7P80n_3V
0`2`5ah30?[`iP040;0G7P3jl>H0n_3V0?[`iP@0/1LN2P3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP@0
/1LN:@3jl>H10?ooo`00?@3jl>H00`2`5ah0n_3V0?[`iP0@0?[`iPL0/1LN0P3jl>H00`2`5ah0n_3V
0?[`iP0U0?[`iPT0/1LN:03jl>H4000000<0:CYE00@0000003U@L@0iD740>E1a1@2`5ah01017HhP0
/1LN0000001FMIh30000000305IeWP000000I8Nc00D0I8Nc00<00000076Ia`1aVLL00`1aVLL90;0G
7P@0Rk_/00<0000009G8n02Eb?P00P2Eb?P010000000U/_g09K;m`2FboL400000080n_3V2`2`5ah2
0?[`iP80/1LN3P3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iPH0/1LN103jl>H01P2`5ah0n_3V0;0G7P2`
5ah0n_3V0;0G7P80n_3V00<0/1LN0?[`iP3jl>H0103jl>H00`2`5ah0n_3V0?[`iP090?[`iP030;0G
7P3jl>H0n_3V01<0n_3V1@2`5ahY0?[`iP40oooo000l0?[`iP030;0G7P3jl>H0n_3V0180n_3V0`2`
5ah20?[`iP050;0G7P3jl>H0n_3V0?[`iP2`5ah09`3jl>H00`2`5ah0n_3V0;0G7P040;0G7RT0n_3V
0P000000100G8SH0000002TjE@0Y>UD20000000303U@L@2`5ah0/1LN0080/1LN0P17HhP30;0G7P03
0000002`5ah0/1LN00T0/1LN00<0I8Nc0000001aVLL01@1aVLL00`000000Oj[J07nZfP0307nZfP<0
0000102;^n`010000000ULSh09G8n02Eb?P200000080U/_g00@0000007n^dP00000000000P3jl>H;
0;0G7P80n_3V00<0/1LN0?[`iP3jl>H03P3jl>H00`2`5ah0n_3V0?[`iP0A0?[`iPL0/1LN1@3jl>H4
0;0G7P80n_3V00<0/1LN0?[`iP3jl>H01@3jl>H00`2`5ah0n_3V0?[`iP0M0?[`iP<0/1LN0P3jl>H3
0;0G7RP0n_3V0@3oool003`0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0;0G7P020?[`
iP030;0G7P3jl>H0n_3V02L0n_3V00<0/1LN0?[`iP2`5ah0102`5ahX0?[`iP80000000H05b8f0000
000Y>UD0000002TjE@00000;0;0G7PD0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076I
a`04076Ia`030000001oZ]X0Oj[J00@0Oj[J00<0000008^kk00000000P0000000`2;^n`0000009G8
n00209G8n0030000002FboL000000080000000<0OjkB000000000000102`5ah20?[`iP040;0G7P3j
l>H0n_3V0;0G7P80n_3V102`5ahU0?[`iPD0/1LN1P3jl>H20;0G7P`0n_3V00<0/1LN0?[`iP3jl>H0
703jl>H20;0G7P<0n_3V0P2`5ah00`3jl>H0/1LN0?[`iP0W0?[`iP40oooo000l0?[`iP030;0G7P3j
l>H0n_3V01H0n_3V102`5ahP0?[`iP030;0G7P3jl>H0n_3V00P0n_3V1@2`5ahY0?[`iP80000000<0
5b8f0000000000000P0Y>UD00`000000/1LN0;0G7P040;0G7P@0Af>800<0000005IeWP1FMIh00`1F
MIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007nZfP1oZ]X0101o
Z]X00`000000Rk_/08^kk00208^kk08000000`2Eb?P01P000000U/_g09K;m`2FboL0000007n^dP80
000000<0/1LN0?[`iP3jl>H0102`5ah20?[`iP80/1LN00<0n_3V0;0G7P3jl>H0102`5ahS0?[`iP03
0;0G7P3jl>H0n_3V0080/1LN1@3jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP030;0G7P3jl>H0n_3V01d0
n_3V00H0/1LN0?[`iP3jl>H0/1LN0?[`iP2`5ah20?[`iP030;0G7P3jl>H0n_3V02D0n_3V0@3oool0
03/0n_3V00<0/1LN0?[`iP3jl>H0603jl>H00`2`5ah0n_3V0?[`iP0G0?[`iP030;0G7P3jl>H0n_3V
00@0n_3V0P2`5ah;0?[`iPH0/1LN7`3jl>H20;0G7PL0n_3V0P0000000`0G8SH0000002TjE@0202Tj
E@H0/1LN1@17HhP00`000000EWFN05IeWP0305IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076I
a`1aVLL0101aVLL00`000000Oj[J07nZfP0407nZfP030000002;^n`0Rk_/00<0Rk_/0P00000209G8
n0040000002FboL0U/_g09K;m`80000000<0OjkB0000003jl>H00`2`5ah00`3jl>H0/1LN0?[`iP03
0?[`iP80/1LN0P3jl>H0102`5ah0n_3V0?[`iP3jl>H30;0G7Qh0n_3V0P2`5ah0103jl>H0/1LN0?[`
iP2`5ah60?[`iP030;0G7P3jl>H0n_3V00`0n_3V00<0/1LN0?[`iP3jl>H07P3jl>H20;0G7P80n_3V
00<0/1LN0?[`iP2`5ah0:03jl>H10?ooo`00>`3jl>H00`2`5ah0n_3V0?[`iP0[0?[`iP030;0G7P3j
l>H0n_3V00@0n_3V00<0/1LN0?[`iP3jl>H00`3jl>H00`2`5ah0n_3V0?[`iP0<0?[`iPD0/1LN5@3j
l>H20;0G7PX0n_3V0P2`5ah50?[`iP@000000`0Y>UD30;0G7P80>E1a00<0000004MSR017HhP00`17
HhP00`000000EWFN05IeWP0205IeWQ4000001@1oZ]X00`000000Rk_/08^kk00308^kk0030000002E
b?P00000008000000`2FboL20000000307n^dP000000n_3V00D0/1LN1@3jl>H30;0G7PL0n_3V0`2`
5ahI0?[`iP80/1LN103jl>H40;0G7P<0n_3V00<0/1LN0?[`iP3jl>H03@3jl>H00`2`5ah0n_3V0?[`
iP0O0?[`iPD0/1LN:@3jl>H10?ooo`00>`3jl>H00`2`5ah0n_3V0?[`iP0[0?[`iP030;0G7P3jl>H0
n_3V00<0n_3V00<0/1LN0?[`iP3jl>H00P3jl>H20;0G7Pl0n_3V1@2`5ahG0?[`iP<0/1LN2@3jl>H2
0;0G7P<0n_3V1000000302TjE@030000000iD740>E1a0080>E1a00<0000004MSR017HhP00`17HhP0
0`000000EWFN000000020000000305IeWP000000I8Nc00D0I8Nc00<00000076Ia`1aVLL0101aVLL0
0`000000Oj[J000000030000000307nZfP000000Rk_/00@0Rk_/00D0000009G8n02Eb?P0ULSh0000
000309K;m`040;0G7P1o[]80000000000080n_3V1P2`5ah40?[`iP80/1LN2P3jl>H30;0G7Q@0n_3V
0P2`5ah70?[`iPH0/1LN4@3jl>H00`2`5ah0n_3V0?[`iP0M0?[`iP040;0G7P3jl>H0n_3V0;0G7R/0
n_3V0@3oool003/0n_3V00<0/1LN0?[`iP3jl>H0;03jl>H00`2`5ah0n_3V0?[`iP020?[`iP050;0G
7P3jl>H0n_3V0?[`iP2`5ah0403jl>H60;0G7QX0n_3V102`5ah70?[`iP<0/1LN0P000000100G8SH0
000002TjE@0Y>UD2000000@0>E1a00<0000004MSR017HhP00P17HhP3000000@0EWFN00<0000006B7
/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00<0Oj[J0`00000408^k
k0040000002Eb?P0ULSh09G8n080000000<0U/_g0;0G7P2`5ah00P2`5ah010000000n_3V0?[`iP3j
l>H20;0G7P<0n_3V0`2`5ah@0?[`iP<0/1LN403jl>H00`2`5ah0n_3V0?[`iP060?[`iP<0/1LN0`3j
l>H20;0G7Q00n_3V00<0/1LN0?[`iP3jl>H0703jl>H00`2`5ah0n_3V0?[`iP0]0?[`iP40oooo000j
0?[`iP030;0G7P3jl>H0n_3V02d0n_3V00<0/1LN0?[`iP3jl>H00P3jl>H0102`5ah0n_3V0;0G7P2`
5ahB0?[`iPD0/1LN7P3jl>H30;0G7PH0n_3V00@0/1LN0000000000005b8f0`0000000`0Y>UD00000
03U@L@0303U@L@0300000017HhP000000080000000<0Af>80000001FMIh0101FMIh00`000000I8Nc
06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007nZfP1oZ]X0101oZ]X00`000000Rk_/
000000020000000308^kk0000000ULSh0080ULSh00<0000009K;m`0000000`2`5ah00`1o[]800000
0?[`iP0:0?[`iP80/1LN4@3jl>H30;0G7P/0n_3V0P2`5ah00`3jl>H0/1LN0?[`iP060?[`iP@0/1LN
00<0n_3V0;0G7P2`5ah04@3jl>H00`2`5ah0n_3V0?[`iP0K0?[`iP030;0G7P3jl>H0n_3V02h0n_3V
0@3oool003P0n_3V102`5ah_0?[`iP060;0G7P3jl>H0n_3V0;0G7P3jl>H0/1LN>P3jl>H30;0G7P<0
n_3V00D0/1LN0000000000005b8f0000000302TjE@030000000iD740>E1a0080>E1a0P00000404MS
R0030000001FMIh0EWFN00<0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076I
a`030000001oZ]X0Oj[J00@0Oj[J00<0000008^kk02;^n`00P2;^n`3000000<0ULSh00H0000009K;
m`2FboL0000007n^dP2`5ah2000000`0n_3V0`2`5ahA0?[`iP<0/1LN1P3jl>H20;0G7P80n_3V0`2`
5ah60?[`iP030;0G7P3jl>H0n_3V00<0/1LN4P3jl>H00`2`5ah0n_3V0?[`iP0K0?[`iP030;0G7P3j
l>H0n_3V02h0n_3V0@3oool003H0n_3V0P2`5ah01@3jl>H0/1LN0;0G7P3jl>H0/1LN02d0n_3V0P2`
5ah20?[`iP80/1LN?P3jl>H40;0G7P@000000`0Y>UD00`000000>E1a03U@L@03000000@0Af>800<0
000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0
000007nZfP1oZ]X0101oZ]X00`000000Rk_/08^kk00308^kk0060000002Eb?P000000000002Eb?P0
00000P2FboL20000000307n^dP2`5ah0000000l0n_3V0P2`5ahB0?[`iP80/1LN0`3jl>H02@2`5ah0
n_3V0?[`iP3jl>H0/1LN0?[`iP2`5ah0n_3V0;0G7P060?[`iPD0/1LN903jl>H20;0G7PT0n_3V00<0
/1LN0?[`iP3jl>H0;`3jl>H10?ooo`00=03jl>H20;0G7P<0n_3V00@0/1LN0?[`iP3jl>H0/1LN:`3j
l>H30;0G7P040?[`iP2`5ah0/1LN0;0G7S@0n_3V00<0/1LN0?[`iP3jl>H02P3jl>H00`2`5ah0n_3V
00000003000000<0:CYE0`00000203U@L@0300000017HhP0Af>80080Af>800<0000005IeWP1FMIh0
0`1FMIhC000000<0Oj[J00<0000008^kk02;^n`00P2;^n`20;0G7P<0ULSh0P00000209K;m`800000
00<0OjkB0000002`5ah0903jl>H30;0G7P@0n_3V00@0/1LN0?[`iP3jl>H0/1LN0P3jl>H00`2`5ah0
n_3V0?[`iP050?[`iP<0/1LN8`3jl>H40;0G7PL0n_3V00<0/1LN0?[`iP3jl>H0<03jl>H10?ooo`00
=@3jl>H01@2`5ah0n_3V0?[`iP3jl>H0/1LN00<0n_3V00<0/1LN0?[`iP3jl>H0:03jl>H20;0G7P03
0?[`iP2`5ah0/1LN0080/1LN<P3jl>H30;0G7PP0n_3V0P2`5ah20?[`iP80/1LN0P0000000`0G8SH0
000002TjE@050;0G7P80>E1a00<0000004MSR017HhP00P17HhP00`000000EWFN0000000300000003
05IeWP000000I8Nc00D0I8Nc00<00000076Ia`1aVLL0101aVLL010000000Oj[J07nZfP1oZ]X40000
000508^kk02`5ah0/1LN0;0G7P2;^n`00`2`5ah209G8n080000000<0U/_g0000001o[]800`00000K
0?[`iP<0/1LN103jl>H50;0G7PD0n_3V1@2`5ah;0?[`iP030;0G7P3jl>H0n_3V01@0n_3V102`5ah6
0?[`iP80/1LN00@0n_3V0;0G7P2`5ah0/1LN1P3jl>H00`2`5ah0n_3V0?[`iP0a0?[`iP40oooo000f
0?[`iP040;0G7P3jl>H0n_3V0;0G7P@0n_3V00<0/1LN0?[`iP3jl>H09P3jl>H00`2`5ah0n_3V0;0G
7P050;0G7Ql0n_3V00<0/1LN0?[`iP3jl>H01P3jl>H00`2`5ah0n_3V0?[`iP060?[`iP@0/1LN1@3j
l>H30;0G7P030?[`iP2`5ah0/1LN00P0/1LN00<0:CYE000000000000100iD74010000000Af>804MS
R017HhP3000000D0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000
001oZ]X0Oj[J00<0Oj[J1`2`5ah00`000000ULSh0;0G7P0209G8n080000000@0U/_g0000001o[]80
OjkB0P00000J0?[`iPL0/1LN0P3jl>H40;0G7PL0n_3V00<0/1LN0?[`iP3jl>H0303jl>H00`2`5ah0
n_3V0?[`iP0A0?[`iPH0/1LN1@3jl>H0102`5ah0n_3V0?[`iP3jl>H20;0G7P030?[`iP2`5ah0n_3V
00@0n_3V00<0/1LN0?[`iP3jl>H0<@3jl>H10?ooo`00=P3jl>H40;0G7P80n_3V0P2`5ahE0?[`iP03
0;0G7P3jl>H0n_3V00<0n_3V00<0/1LN0?[`iP3jl>H02`3jl>H90;0G7Ql0n_3V0P2`5ah70?[`iP03
0;0G7P3jl>H0n_3V00<0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P0:0;0G7PD0n_3V0P0000001P0G8SH0
0000000000000000:CYE000000@0>E1a00H0000004MSR0000000000004MSR000000605IeWP030000
001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL010000000Oj[J07nZfP1oZ]X30;0G7P03
0000002;^n`0Rk_/0080000000@0/1LN0000002Eb?P0/1LN0P2Eb?P010000000U/_g000000000002
07n^dP8000006P3jl>H00`2`5ah0n_3V0;0G7P030;0G7P80n_3V102`5ah80?[`iP030;0G7P3jl>H0
n_3V00d0n_3V00<0/1LN0?[`iP3jl>H03`3jl>H20;0G7P80n_3V0`2`5ah60?[`iP030;0G7P3jl>H0
n_3V0080/1LN0P3jl>H01@2`5ah0n_3V0?[`iP3jl>H0/1LN03@0n_3V0@3oool003L0n_3V0P2`5ah0
0`3jl>H0/1LN0;0G7P0G0?[`iP030;0G7P3jl>H0n_3V0080n_3V00<0/1LN0?[`iP3jl>H0303jl>H4
0;0G7P030?[`iP2`5ah0/1LN00<0/1LN803jl>H20;0G7PH0n_3V00@0/1LN0?[`iP3jl>H0n_3V2@2`
5ah<0?[`iP80000000<05b8f0000000Y>UD00P0Y>UD00`000000>E1a03U@L@0203U@L@8000000`17
HhP00`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101a
VLL010000000Oj[J07nZfP1oZ]X90;0G7P030000002`5ah0ULSh0080ULSh00@0000009K;m`2FboL0
00000P1o[]82000001P0n_3V1@2`5ah01@3jl>H0/1LN0?[`iP3jl>H0/1LN0080n_3V00<0/1LN0?[`
iP3jl>H01`3jl>H00`2`5ah0n_3V0?[`iP0=0?[`iP030;0G7P3jl>H0n_3V0100n_3V00L0/1LN0?[`
iP2`5ah0n_3V0;0G7P3jl>H0/1LN00H0n_3V0P2`5ah0103jl>H0/1LN0?[`iP2`5ah30?[`iP030;0G
7P3jl>H0n_3V03<0n_3V0@3oool003P0n_3V0P2`5ahI0?[`iP050;0G7P3jl>H0n_3V0?[`iP2`5ah0
4@3jl>H40;0G7P050?[`iP2`5ah0/1LN0?[`iP2`5ah08@3jl>H00`2`5ah0n_3V0?[`iP040?[`iP04
0;0G7P3jl>H0n_3V0?[`iPL0/1LN3@3jl>H4000000<0:CYE00<0000003U@L@0iD7400`00000404MS
R0030000001FMIh0EWFN00@0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076I
a`030000001oZ]X0/1LN00D0/1LN102;^n`60;0G7P030000002FboL0U/_g0080000000<0OjkB0000
000000005@3jl>H30;0G7P<0n_3V00<0/1LN0?[`iP2`5ah00P3jl>H00`2`5ah0n_3V0?[`iP0;0?[`
iP030;0G7P3jl>H0n_3V00h0n_3V00<0/1LN0?[`iP3jl>H0403jl>H00`2`5ah0n_3V0?[`iP030;0G
7PL0n_3V102`5ah30?[`iP030;0G7P3jl>H0n_3V03@0n_3V0@3oool005<0n_3V00D0/1LN0?[`iP3j
l>H0n_3V0;0G7P0C0?[`iPH0/1LN8`3jl>H20;0G7PD0n_3V00<0/1LN0?[`iP3jl>H01`2`5ah=0?[`
iP@000000`0Y>UD300000080>E1a00<0000004MSR017HhP00P17HhP00`000000EWFN05IeWP0305Ie
WPl00000102`5ah01@1oZ]X0/1LN0;0G7P000000/1LN0080Rk_/00@0/1LN08^kk0000000/1LN0P2E
b?P00`000000/1LN0;0G7P030;0G7P0307n^dP00000000000180n_3V0`2`5ah70?[`iP040;0G7P3j
l>H0/1LN0;0G7Ph0n_3V00<0/1LN0?[`iP3jl>H03`3jl>H00`2`5ah0n_3V0?[`iP0>0?[`iP80/1LN
0P3jl>H00`2`5ah0n_3V0;0G7P070?[`iP030;0G7P3jl>H0/1LN00@0n_3V00<0/1LN0?[`iP3jl>H0
=03jl>H10?ooo`00D`3jl>H0102`5ah0n_3V0?[`iP2`5ahE0?[`iP80/1LN00<0n_3V0;0G7P2`5ah0
9@3jl>H20;0G7P@0n_3V00<0/1LN0?[`iP2`5ah01@2`5ah>0?[`iP80000000<05b8f0000000Y>UD0
0P0Y>UD01@000000>E1a03U@L@0iD740000000D0Af>800<0000005IeWP0000000`0000000`1FMIh0
000006B7/`0506B7/`030000001aVLL0LIW70080LIW70P2`5ah010000000/1LN07nZfP1oZ]X80;0G
7P0308^kk0000000/1LN00<0ULSh0P0000000`2FboL0000007n^dP050;0G7P`0n_3V102`5ah;0?[`
iP030;0G7P3jl>H0n_3V00<0n_3V0`2`5ah80?[`iP030;0G7P3jl>H0n_3V0100n_3V00<0/1LN0?[`
iP3jl>H0303jl>H00`2`5ah0n_3V0?[`iP040;0G7PL0n_3V00<0/1LN0?[`iP3jl>H0103jl>H00`2`
5ah0n_3V0?[`iP0e0?[`iP40oooo001C0?[`iP030;0G7P3jl>H0/1LN01P0n_3V0P2`5ahX0?[`iP80
/1LN00<0n_3V0;0G7P3jl>H0102`5ahA0?[`iP80000000@05b8f0000000Y>UD0:CYE0P00000303U@
L@0300000017HhP0Af>80080Af>80`00000505IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076I
a`1aVLL0102`5ah00`000000Oj[J0;0G7P030;0G7P0407nZfP0000000000000000L0/1LN00L0ULSh
0000002FboL0000009K;m`000000OjkB008000000P3jl>H50;0G7PD0n_3V0P2`5ah>0?[`iP040;0G
7P3jl>H0n_3V0?[`iPT0/1LN1@3jl>H00`2`5ah0n_3V0?[`iP0@0?[`iP030;0G7P3jl>H0n_3V00/0
n_3V00<0/1LN0?[`iP3jl>H00P3jl>H00`2`5ah0n_3V0?[`iP070?[`iP030;0G7P3jl>H0n_3V03`0
n_3V0@3oool005<0n_3V0P2`5ai50?[`iPH0/1LN3P3jl>H30;0G7P040?[`iP000000000001LR=P<0
000000<0:CYE0000000iD7400P0iD7400`000000Af>8000000020000000304MSR0000000EWFN00D0
EWFN00<0000006B7/`1TQk<0101TQk<010000000LIW7076Ia`1aVLL90;0G7P0407nZfP000000Rk_/
08^kk08000000P2`5ah309G8n0H0/1LN00<0OjkB0000000000001`3jl>H60;0G7Q<0n_3V102`5ah3
0?[`iP030;0G7P3jl>H0n_3V01P0n_3V00<0/1LN0?[`iP3jl>H02@3jl>H00`2`5ah0n_3V0?[`iP0=
0?[`iP030;0G7P3jl>H0n_3V03`0n_3V0@3oool005<0n_3V0P2`5ai50?[`iPH0/1LN4@3jl>H01@2`
5ah000000000000G8SH000000080:CYE00<0000003U@L@0iD7400P0iD742000000@0Af>800<00000
05IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700<0LIW700<0/1LN
0000001oZ]X00`1oZ]X40;0G7P<0Rk_/00<000000;0G7P0000000`2Eb?P01@000000U/_g09K;m`2F
boL0000000@0/1LN303jl>H50;0G7PL0n_3V0P2`5ah50?[`iP030;0G7P3jl>H0/1LN0080/1LN0P3j
l>H00`2`5ah0n_3V0?[`iP0S0?[`iP030;0G7P3jl>H0n_3V00d0n_3V00<0/1LN0?[`iP3jl>H0?@3j
l>H10?ooo`00D`3jl>H00`2`5ah0n_3V0?[`iP0U0?[`iP030;0G7P3jl>H0n_3V00H0n_3V00<0/1LN
0?[`iP3jl>H04`3jl>H60;0G7Q80n_3V1000000202TjE@030000000iD740>E1a00<000001@17HhP0
0`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL0
0`000000Oj[J07nZfP0407nZfP030000002;^n`0Rk_/00<0Rk_/00H0000009G8n0000000000009G8
n000000309K;m`040000001o[]80000000000180n_3V0`2`5ah30?[`iPD0/1LN103jl>H20;0G7P80
n_3V0P2`5ahU0?[`iP030;0G7P3jl>H0n_3V00h0n_3V00<0/1LN0?[`iP3jl>H0?@3jl>H10?ooo`00
D03jl>H0102`5ah0n_3V0;0G7P2`5ahX0?[`iP030;0G7P3jl>H0n_3V00D0n_3V00<0/1LN0?[`iP3j
l>H01P3jl>H00`2`5ah0n_3V0?[`iP070?[`iP80/1LN0P3jl>H50;0G7Q80n_3V1000000202TjE@<0
00000P0iD7400`000000Af>804MSR00304MSR0030000001FMIh0EWFN00<0EWFN4@00000507nZfP03
0000002;^n`0Rk_/00<0Rk_/00@0000009G8n02Eb?P0ULSh0P00000309K;m`@000000P3jl>H00`2`
5ah0n_3V0?[`iP040?[`iP80/1LN1P3jl>H20;0G7PD0n_3V0P2`5ah00`3jl>H0/1LN0?[`iP040?[`
iP030;0G7P3jl>H0/1LN0080n_3V0P2`5ahS0?[`iP030;0G7P3jl>H0n_3V0080/1LN3@3jl>H00`2`
5ah0n_3V0?[`iP0m0?[`iP40oooo000j0?[`iP030;0G7P3jl>H0n_3V0180n_3V0`2`5ah00`3jl>H0
/1LN0?[`iP0X0?[`iP030;0G7P3jl>H0n_3V00@0n_3V00<0/1LN0?[`iP3jl>H01@3jl>H00`2`5ah0
n_3V0?[`iP050?[`iP<0/1LN6`3jl>H20000000501LR=P000000:CYE02TjE@000000100iD7400`00
0000Af>804MSR00304MSR0030000001FMIh0000000<0000000<0EWFN0000001TQk<01@1TQk<00`00
0000LIW7076Ia`04076Ia`030000001oZ]X0000000<0000000<0Oj[J0000002;^n`0102;^n`00`00
0000ULSh09G8n00209G8n08000000P2FboL400000080n_3V0`2`5ah30?[`iPD0/1LN0`3jl>H40;0G
7PD0n_3V0`2`5ah60?[`iP@0/1LN0P3jl>H20;0G7QP0n_3V0`2`5ah50?[`iP030;0G7P3jl>H0n_3V
00@0/1LN2`3jl>H00`2`5ah0n_3V0?[`iP0n0?[`iP40oooo000j0?[`iP030;0G7P3jl>H0n_3V0100
n_3V0`2`5ah00`3jl>H0/1LN0;0G7P020;0G7RT0n_3V00<0/1LN0?[`iP3jl>H00`3jl>H00`2`5ah0
n_3V0?[`iP040?[`iP030;0G7P3jl>H0n_3V00<0n_3V0`2`5ahN0?[`iP80000000<05b8f0000000Y
>UD00P00000403U@L@0300000017HhP0Af>80080Af>80`00000505IeWP030000001TQk<0I8Nc00@0
I8Nc00<00000076Ia`1aVLL0101aVLL00`000000Oj[J07nZfP0307nZfP<00000102;^n`00`000000
ULSh09G8n00209G8n0060000002FboL0000009K;m`000000OjkB0P0000020?[`iP030;0G7P3jl>H0
/1LN00L0/1LN1@3jl>H20;0G7PL0n_3V00<0/1LN0?[`iP2`5ah01`3jl>H20;0G7P@0n_3V0P2`5ah;
0?[`iP80/1LN1`3jl>H50;0G7P@0n_3V00<0/1LN0?[`iP3jl>H00`2`5ah20?[`iP80/1LN2@3jl>H0
0`2`5ah0n_3V0?[`iP0n0?[`iP40oooo000j0?[`iP030;0G7P3jl>H0n_3V00l0n_3V00<0/1LN0?[`
iP3jl>H00P2`5ah00`3jl>H0/1LN0;0G7P020;0G7RT0n_3V00<0/1LN0?[`iP3jl>H00P3jl>H20;0G
7P@0n_3V00@0/1LN0?[`iP3jl>H0n_3V0`2`5ahQ0?[`iP80000000D05b8f000000000000:CYE0000
000403U@L@0300000017HhP000000080000000<0Af>80000001FMIh01@1FMIh00`000000I8Nc06B7
/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007nZfP1oZ]X0101oZ]X00`000000Rk_/0000
00020000000308^kk0000000ULSh00<0ULSh00<0000009K;m`2FboL00P0000000`1o[]8000000000
00020?[`iPH0/1LN00<0n_3V0;0G7P2`5ah01@3jl>H00`2`5ah0n_3V0?[`iP0:0?[`iP030;0G7P3j
l>H0n_3V00`0n_3V0P2`5ah70?[`iPL0/1LN0`3jl>H20;0G7P80n_3V0`2`5ah20?[`iP040;0G7P3j
l>H0n_3V0;0G7P80n_3V0P2`5ah30?[`iP030;0G7P3jl>H0n_3V00H0n_3V00<0/1LN0?[`iP3jl>H0
503jl>H40;0G7RH0n_3V0@3oool003T0n_3V00<0/1LN0?[`iP3jl>H0403jl>H60;0G7P050?[`iP2`
5ah0/1LN0?[`iP2`5ah0:@3jl>H00`2`5ah0n_3V0?[`iP030;0G7P<0n_3V00<0/1LN0?[`iP2`5ah0
0P2`5ahT0?[`iP80000000D05b8f0000000Y>UD0:CYE0000000403U@L@8000001017HhP00`000000
EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000
Oj[J07nZfP0407nZfP030000002;^n`0Rk_/0080Rk_/0`00000309G8n0060000002FboL0U/_g09K;
m`000000OjkB0P0000040;0G7P030?[`iP2`5ah0/1LN0080n_3V00<0/1LN0?[`iP3jl>H00`3jl>H0
0`2`5ah0n_3V0?[`iP0<0?[`iP030;0G7P3jl>H0n_3V00d0n_3V00<0/1LN0?[`iP3jl>H01@3jl>H0
0`2`5ah0n_3V0;0G7P030;0G7P@0n_3V00P0/1LN0?[`iP2`5ah0/1LN0?[`iP2`5ah0n_3V0;0G7P@0
n_3V00@0/1LN0?[`iP3jl>H0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP060?[`iP030;0G7P3jl>H0n_3V
01@0n_3V1@2`5ahV0?[`iP40oooo000i0?[`iP030;0G7P3jl>H0n_3V0100n_3V102`5ah30?[`iP80
/1LN0P3jl>H00`2`5ah0n_3V0?[`iP0W0?[`iP<0/1LN00<0n_3V0;0G7P2`5ah0102`5ahW0?[`iP04
0000000G8SH0000000000080:CYE00<0000003U@L@0iD7400`00000504MSR0030;0G7P1FMIh0EWFN
00@0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J
00@0Oj[J00<0000008^kk02;^n`00`2;^n`01P000000ULSh000000000000ULSh000000<0U/_g00@0
000007n^dP00000000000P3jl>H30;0G7PX0n_3V00<0/1LN0?[`iP3jl>H0303jl>H00`2`5ah0n_3V
0?[`iP0>0?[`iP80/1LN1@3jl>H50;0G7PH0n_3V102`5ah80?[`iPD0/1LN2@3jl>H00`2`5ah0n_3V
0?[`iP0B0?[`iP<0/1LN0P3jl>H00`2`5ah0n_3V0;0G7P0U0?[`iP40oooo000i0?[`iP030;0G7P3j
l>H0n_3V0140n_3V1`2`5ah20?[`iP030;0G7P3jl>H0n_3V02P0n_3V1`2`5ahF0?[`iP80/1LN4P3j
l>H20000000401LR=P000000:CYE02TjE@<000000P0iD74010000000Af>804MSR017HhP30;0G7PD0
EWFN4@00000507nZfP030000002;^n`0Rk_/00<0Rk_/00@0000009G8n02Eb?P0ULSh0P00000309K;
m`@000000P3jl>H00`2`5ah0n_3V0?[`iP090?[`iP030;0G7P3jl>H0n_3V00h0n_3V00<0/1LN0?[`
iP3jl>H03`3jl>H20;0G7P80n_3V0`2`5ah00`3jl>H0/1LN0;0G7P060?[`iP@0/1LN2P3jl>H00`2`
5ah0n_3V0?[`iP0M0?[`iP80/1LN0`3jl>H40;0G7RD0n_3V0@3oool003T0n_3V00<0/1LN0?[`iP3j
l>H04@3jl>H20;0G7P030?[`iP2`5ah0/1LN00@0/1LN:`3jl>H70;0G7QP0n_3V0`2`5ah50?[`iP80
/1LN203jl>H20000000501LR=P000000:CYE02TjE@000000100iD7400`000000/1LN0;0G7P020;0G
7P0304MSR02`5ah0EWFN00@0000000<0EWFN0000001TQk<01@1TQk<00`000000LIW7076Ia`04076I
a`030000001oZ]X0000000<0000000<0Oj[J0000002;^n`0102;^n`00`000000ULSh09G8n00209G8
n08000000P2FboL400000200n_3V00<0/1LN0?[`iP3jl>H0403jl>H20;0G7P80n_3V00<0/1LN0?[`
iP2`5ah01P3jl>H0102`5ah0n_3V0?[`iP2`5ah;0?[`iP030;0G7P3jl>H0n_3V01h0n_3V00L0/1LN
0?[`iP3jl>H0/1LN0?[`iP2`5ah0n_3V0080/1LN903jl>H10?ooo`00>03jl>H00`2`5ah0n_3V0?[`
iP0C0?[`iP80/1LN0`3jl>H00`2`5ah0n_3V0?[`iP0Z0?[`iPT0/1LN6P3jl>H40;0G7P<0n_3V0P2`
5ah60?[`iP050000000G8SH05b8f0000000Y>UD00P00000403U@L@@0/1LN00@0Af>80000002`5ah0
00001@1FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007nZfP1o
Z]X00`1oZ]X3000000@0Rk_/00<0000009G8n02Eb?P00P2Eb?P01P000000U/_g0000002FboL00000
07n^dP8000003@3jl>H00`2`5ah0n_3V0?[`iP0R0?[`iP040;0G7P3jl>H0n_3V0;0G7P80n_3V00<0
/1LN0?[`iP3jl>H01@3jl>H00`2`5ah0n_3V0?[`iP0=0?[`iP030;0G7P3jl>H0n_3V01h0n_3V0P2`
5ah20?[`iP040;0G7P3jl>H0n_3V0;0G7R@0n_3V0@3oool003P0n_3V00<0/1LN0?[`iP3jl>H0:`3j
l>H00`2`5ah0n_3V0?[`iP0I0?[`iPL0/1LN7P3jl>H30;0G7P80n_3V0P2`5ah30?[`iP040;0G7P00
00005b8f01LR=P80000000<0:CYE0000000iD7402P2`5ah00`1FMIh0/1LN0;0G7P080;0G7P80I8Nc
00<00000076Ia`1aVLL0101aVLL00`000000Oj[J07nZfP0407nZfP030000002;^n`0000000800000
00<0Rk_/0000002Eb?P00`2Eb?P00`000000U/_g09K;m`020000000307n^dP000000000000/0n_3V
1@2`5ahP0?[`iP80/1LN3@3jl>H00`2`5ah0n_3V0?[`iP0>0?[`iP030;0G7P3jl>H0n_3V01l0n_3V
00<0/1LN0?[`iP2`5ah00P3jl>H00`2`5ah0n_3V0?[`iP0S0?[`iP40oooo000h0?[`iP030;0G7P3j
l>H0n_3V02/0n_3V00<0/1LN0?[`iP3jl>H01@3jl>H00`2`5ah0n_3V0?[`iP0A0?[`iPH0/1LN8P3j
l>H30;0G7P030?[`iP2`5ah0/1LN0080/1LN00@0000001LR=P0G8SH000000P0Y>UD00`000000/1LN
0;0G7P0K0;0G7P80LIW700<0000007nZfP1oZ]X0101oZ]X00`000000Rk_/08^kk00208^kk0800000
102Eb?P01P000000U/_g09K;m`2FboL0000007n^dP8000002@3jl>H20;0G7P030?[`iP2`5ah0/1LN
00<0/1LN7@3jl>H20;0G7Ph0n_3V00<0/1LN0?[`iP3jl>H03`3jl>H00`2`5ah0n_3V0?[`iP0N0?[`
iP030;0G7P3jl>H0/1LN00<0/1LN9P3jl>H10?ooo`00>03jl>H00`2`5ah0n_3V0?[`iP0/0?[`iP03
0;0G7P3jl>H0n_3V00@0n_3V00<0/1LN0?[`iP3jl>H01P3jl>H00`2`5ah0n_3V0?[`iP0:0?[`iP@0
/1LN9@3jl>H50;0G7P040000000G8SH0000000000080:CYE2@2`5ah00`17HhP0/1LN0;0G7P0605Ie
WP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL00P1aVLL:0;0G7PD0Rk_/0`00000209G8
n0060000002FboL0U/_g09K;m`000000OjkB0P0000030?[`iP80/1LN0P3jl>H60;0G7P<0n_3V00<0
/1LN0?[`iP3jl>H06@3jl>H20;0G7Q00n_3V00<0/1LN0?[`iP3jl>H03`3jl>H00`2`5ah0n_3V0?[`
iP0M0?[`iP050;0G7P3jl>H0n_3V0?[`iP2`5ah0:03jl>H10?ooo`00=`3jl>H00`2`5ah0n_3V0?[`
iP0]0?[`iP030;0G7P3jl>H0n_3V00<0n_3V00<0/1LN0?[`iP3jl>H01@3jl>H20;0G7ST0n_3V0P2`
5ah20000000401LR=P000000:CYE02TjE@<000000P0iD7420;0G7P0304MSR02`5ah0/1LN0080/1LN
1P1FMIh010000000I8Nc06B7/`1TQk<7000000<0LIW700<0000007nZfP1oZ]X0101oZ]X00`000000
Rk_/08^kk00308^kk0030000002Eb?P0ULSh00<000000`2FboL01@2`5ah00000000000000000n_3V
00H0/1LN00<0n_3V0;0G7P2`5ah00`2`5ah20?[`iP030;0G7P3jl>H0n_3V01P0n_3V0P2`5ahA0?[`
iP030;0G7P3jl>H0n_3V0100n_3V00<0/1LN0?[`iP3jl>H0703jl>H00`2`5ah0n_3V0?[`iP0[0?[`
iP40oooo000f0?[`iP80/1LN<03jl>H00`2`5ah0n_3V0?[`iP020?[`iP030;0G7P3jl>H0n_3V00@0
n_3V00<0/1LN0?[`iP3jl>H0>03jl>H00`2`5ah0n_3V0;0G7P03000000<0:CYE00<0000003U@L@0i
D7400P0iD7400`000000Af>804MSR00204MSR080/1LN0`1FMIh7000000<0I8Nc00@00000076Ia`1a
VLL0LIW71`00000307nZfP030000002;^n`0Rk_/00<0Rk_/00<0000009G8n02Eb?P00P2Eb?P00`00
0000U/_g09K;m`030;0G7P80000000<0n_3V0;0G7P2`5ah00`2`5ah30?[`iP030;0G7P3jl>H0n_3V
00@0/1LN6@3jl>H00`2`5ah0n_3V0?[`iP0?0?[`iP030;0G7P3jl>H0/1LN01<0n_3V00<0/1LN0?[`
iP3jl>H06`3jl>H00`2`5ah0n_3V0?[`iP0[0?[`iP40oooo000e0?[`iP<0/1LN<03jl>H01@2`5ah0
n_3V0?[`iP3jl>H0/1LN00D0n_3V0P2`5ahk0?[`iP<0/1LN00<0000001LR=P0000000P0Y>UD20000
00@0>E1a00<0000004MSR017HhP00P17HhP5000000<0EWFN00<0000006B7/`1TQk<0101TQk<00`00
0000LIW7076Ia`04076Ia`040000001oZ]X0Oj[J07nZfPD00000102;^n`00`000000ULSh09G8n002
09G8n080000000@0U/_g0;0G7P2`5ah0OjkB0P0000020?[`iP030;0G7P3jl>H0n_3V0080/1LN0`3j
l>H20;0G7P80n_3V00<0/1LN0?[`iP2`5ah00`2`5ah90?[`iP030;0G7P3jl>H0n_3V0100n_3V00<0
/1LN0?[`iP3jl>H01P3jl>H50;0G7Q<0n_3V00<0/1LN0?[`iP3jl>H06P3jl>H00`2`5ah0n_3V0?[`
iP0/0?[`iP40oooo000c0?[`iP80/1LN00@0n_3V0;0G7P2`5ah0/1LN<03jl>H0102`5ah0n_3V0?[`
iP2`5ah40?[`iP030;0G7P3jl>H0n_3V03`0n_3V00@0/1LN0000000000005b8f0`0000000`0Y>UD0
000003U@L@0303U@L@0300000017HhP000000080000000<0Af>80000001FMIh01@1FMIh00`000000
I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007nZfP1oZ]X0101oZ]X00`000000
Rk_/000000020000000308^kk0000000ULSh00<0ULSh00<0000009K;m`0000000P0000000`2`5ah0
0000000000030?[`iP80/1LN0P3jl>H20;0G7P80n_3V00@0/1LN0?[`iP3jl>H0/1LN1@3jl>H30;0G
7P@0n_3V1@2`5ah60?[`iP<0/1LN1P3jl>H30;0G7PL0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P020;0G
7Q40n_3V00<0/1LN0?[`iP3jl>H06@3jl>H00`2`5ah0n_3V0?[`iP0]0?[`iP40oooo000b0?[`iP07
0;0G7P3jl>H0n_3V0?[`iP2`5ah0n_3V0;0G7P0`0?[`iP040;0G7P3jl>H0n_3V0;0G7P80n_3V0P2`
5ahK0?[`iP030;0G7P3jl>H0n_3V0280n_3V0P0000000`0G8SH0000002TjE@0202TjE@030000000i
D740>E1a0080>E1a0P00000404MSR0030000001FMIh0EWFN00@0EWFN00<0000006B7/`1TQk<0101T
Qk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00@0Oj[J00<0000008^kk02;^n`00P2;
^n`2000000@0ULSh00P0000009K;m`2FboL0U/_g0000001o[]80/1LN000000@0n_3V00<0/1LN0?[`
iP3jl>H00P3jl>H50;0G7PT0n_3V0`2`5ah00`3jl>H0/1LN0?[`iP050;0G7P80n_3V1@2`5ah50?[`
iP050;0G7P3jl>H0/1LN0?[`iP2`5ah01@3jl>H40;0G7P80n_3V00<0/1LN0?[`iP3jl>H0503jl>H2
0;0G7P`0n_3V0`2`5ah60?[`iP030;0G7P3jl>H0n_3V02h0n_3V0@3oool00340n_3V00<0/1LN0?[`
iP3jl>H00P3jl>H0102`5ah0n_3V0?[`iP2`5ah_0?[`iP<0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP0L
0?[`iP80/1LN1`3jl>H00`2`5ah0n_3V0?[`iP0H0?[`iP@000000`0Y>UD00`000000>E1a03U@L@03
000000D0Af>800<0000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0
LIW700@0LIW700<0000007nZfP1oZ]X0101oZ]X00`000000Rk_/08^kk00308^kk0<000000P2Eb?P0
20000000U/_g09K;m`2FboL0000007n^dP000000/1LN303jl>H20;0G7P`0n_3V1`2`5ah40?[`iP04
0;0G7P3jl>H0/1LN0;0G7P@0n_3V00@0/1LN0?[`iP3jl>H0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP02
0?[`iP070;0G7P3jl>H0/1LN0?[`iP2`5ah0n_3V0;0G7P0D0?[`iP80/1LN00<0n_3V0;0G7P2`5ah0
0P2`5ah80?[`iPD0/1LN1@3jl>H00`2`5ah0n_3V0?[`iP0^0?[`iP40oooo000b0?[`iP030;0G7P3j
l>H0n_3V0080/1LN0`3jl>H00`2`5ah0n_3V0?[`iP0Z0?[`iP80/1LN00<0n_3V0;0G7P2`5ah00P2`
5ahQ0?[`iP80/1LN1P3jl>H00`2`5ah0n_3V0?[`iP060?[`iP030;0G7P3jl>H0n_3V00h0n_3V1000
000302TjE@<000000P0iD7400`000000Af>804MSR00304MSR0030000001FMIh0EWFN00@0EWFN00@0
000006B7/`1TQk<0I8Nc1`000003076Ia`030000001oZ]X0Oj[J00@0Oj[J00<0000008^kk02;^n`0
0`2;^n`00`000000ULSh09G8n003000000<0U/_g1000000>0?[`iP80/1LN2@3jl>H40;0G7P040?[`
iP2`5ah0/1LN0;0G7P<0n_3V0`2`5ah00`3jl>H0/1LN0?[`iP040?[`iPD0/1LN1P3jl>H00`2`5ah0
n_3V0;0G7P020;0G7Q@0n_3V102`5ah0103jl>H0/1LN0;0G7P2`5ah60?[`iP<0/1LN00@0n_3V0;0G
7P2`5ah0/1LN103jl>H00`2`5ah0n_3V0?[`iP0_0?[`iP40oooo000c0?[`iP040;0G7P3jl>H0/1LN
0;0G7P@0n_3V00<0/1LN0?[`iP3jl>H09`3jl>H20;0G7P030?[`iP2`5ah0/1LN00D0/1LN8P3jl>H2
0;0G7PD0n_3V00<0/1LN0?[`iP3jl>H01@3jl>H00`2`5ah0n_3V0?[`iP0>0?[`iP80000000<05b8f
0000000Y>UD00P0Y>UD00`000000>E1a03U@L@0203U@L@0300000017HhP0Af>800<0Af>800@00000
05IeWP1FMIh0EWFN1`00000306B7/`040000001aVLL0LIW7076Ia`L000000`1oZ]X00`000000Rk_/
08^kk00308^kk0030000002Eb?P0ULSh0080ULSh00@0000009K;m`2FboL0U/_g1000000@0?[`iP80
/1LN103jl>H30;0G7P@0n_3V00@0/1LN0?[`iP3jl>H0n_3V102`5ah00`3jl>H0/1LN0;0G7P080?[`
iP030;0G7P3jl>H0n_3V00L0n_3V0P2`5ah00`3jl>H0/1LN0?[`iP0D0?[`iP040;0G7P3jl>H0n_3V
0?[`iP<0/1LN1@3jl>H20;0G7P<0n_3V0P2`5ah01@3jl>H0/1LN0?[`iP3jl>H0/1LN0380n_3V0@3o
ool003<0n_3V00<0/1LN0?[`iP2`5ah00`3jl>H20;0G7QD0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H3
0;0G7P030?[`iP2`5ah0/1LN00<0/1LN00<0n_3V0;0G7P3jl>H08P3jl>H20;0G7P@0n_3V00<0/1LN
0?[`iP2`5ah00`3jl>H00`2`5ah0n_3V0?[`iP090?[`iP80/1LN103jl>H20000000401LR=P000000
:CYE02TjE@800000100iD7400`000000Af>804MSR00204MSR0D000000`1FMIh00`000000I8Nc06B7
/`0406B7/`030000001aVLL0LIW700@0LIW700@0000007nZfP1oZ]X0Oj[J1@00000408^kk0030000
002Eb?P0ULSh0080ULSh0P00000209K;m`040000001o[]800000000001<0n_3V0`2`5ah;0?[`iP04
0;0G7P3jl>H0n_3V0?[`iP80/1LN203jl>H00`2`5ah0n_3V0?[`iP0:0?[`iP030;0G7P3jl>H0/1LN
01D0n_3V00<0/1LN0?[`iP2`5ah00`2`5ah60?[`iP030;0G7P3jl>H0n_3V0080/1LN0`3jl>H20;0G
7S<0n_3V0@3oool003@0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P0G0?[`iP030;0G7P3jl>H0n_3V0180
n_3V0P2`5ah00`3jl>H0/1LN0;0G7P050;0G7RH0n_3V0P2`5ah30?[`iP<0/1LN0P3jl>H0102`5ah0
n_3V0?[`iP2`5ah50?[`iP<0/1LN1P3jl>H20000000601LR=P00000000000000000Y>UD00000100i
D7400`000000Af>8000000020000000304MSR0000000EWFN00D0EWFN00<0000006B7/`1TQk<0101T
Qk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00@0Oj[J00<0000008^kk00000000P00
00000`2;^n`0000009G8n00309G8n0030000002FboL000000080000000<0OjkB0000000000003`3j
l>H40;0G7Pd0n_3V00<0/1LN0?[`iP3jl>H0303jl>H00`2`5ah0n_3V0?[`iP0=0?[`iP030;0G7P3j
l>H0n_3V0180n_3V0P2`5ah0103jl>H0/1LN0?[`iP2`5ah70?[`iP@0/1LN0P3jl>H00`2`5ah0n_3V
0;0G7P0c0?[`iP40oooo000e0?[`iP80/1LN6@3jl>H00`2`5ah0n_3V0?[`iP030?[`iP030;0G7P3j
l>H0n_3V00`0n_3V2P2`5ahX0?[`iP80/1LN00<0n_3V0;0G7P2`5ah00`2`5ah0103jl>H0/1LN0;0G
7P2`5ah20?[`iP<0/1LN1@3jl>H40;0G7P80000000<05b8f0000000Y>UD01@2`5ah203U@L@800000
1017HhP00`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0
101aVLL00`000000Oj[J07nZfP0407nZfP030000002;^n`0Rk_/0080Rk_/0P00000409G8n0060000
002FboL0U/_g09K;m`000000OjkB0P00000=0?[`iP80/1LN3`3jl>H20;0G7Pl0n_3V00<0/1LN0?[`
iP3jl>H03P3jl>H00`2`5ah0n_3V0?[`iP0@0?[`iP030;0G7P3jl>H0/1LN00<0/1LN2P3jl>H40;0G
7P030?[`iP2`5ah0n_3V03<0n_3V0@3oool00500n_3V00<0/1LN0?[`iP3jl>H00P3jl>H00`2`5ah0
n_3V0?[`iP0=0?[`iPT0/1LN:`3jl>H<0;0G7PL0n_3V2P2`5ah202TjE@030000000iD740>E1a00<0
00001@17HhP00`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1a
VLL0101aVLL00`000000Oj[J07nZfP0407nZfP030000002;^n`0Rk_/00<0Rk_/0`00000209G8n004
0000002FboL0U/_g09K;m`80000000<0OjkB0000003jl>H0703jl>H00`2`5ah0n_3V0?[`iP0?0?[`
iP030;0G7P3jl>H0n_3V00l0n_3V00<0/1LN0?[`iP3jl>H03P3jl>H01@2`5ah0n_3V0?[`iP3jl>H0
/1LN00/0n_3V00<0/1LN0?[`iP2`5ah0>03jl>H10?ooo`00D03jl>H01@2`5ah0n_3V0?[`iP3jl>H0
/1LN0180n_3V102`5ah00`3jl>H0/1LN0?[`iP0[0?[`iQ<0/1LN1@3jl>H4000000<0:CYE0`000002
03U@L@0300000017HhP0Af>800<0Af>800<0000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`04
06B7/`030000001aVLL0LIW700@0LIW700<0000007nZfP1oZ]X0101oZ]X00`000000Rk_/08^kk003
08^kk0030000002Eb?P0ULSh00<000000`2FboL20000000307n^dP000000n_3V02h0n_3V00<0/1LN
0?[`iP3jl>H03`3jl>H00`2`5ah0n_3V0?[`iP0=0?[`iP030;0G7P3jl>H0n_3V00h0n_3V00<0/1LN
0?[`iP3jl>H0>03jl>H10?ooo`00D03jl>H01@2`5ah0n_3V0?[`iP3jl>H0/1LN04@0n_3V2@2`5ah0
0`3jl>H0/1LN0?[`iP0<0?[`iP80000000<05b8f0000000Y>UD00P0Y>UD00`000000>E1a03U@L@02
03U@L@0300000017HhP0Af>800<0Af>800<0000005IeWP1FMIh00`1FMIhC00000080/1LN00<0Oj[J
0000002;^n`0102;^n`00`000000ULSh09G8n00209G8n0060000002FboL0U/_g09K;m`000000OjkB
0P00000_0?[`iP030;0G7P3jl>H0n_3V0100n_3V00<0/1LN0?[`iP3jl>H02`3jl>H00`2`5ah0n_3V
0?[`iP0>0?[`iP030;0G7P3jl>H0n_3V03T0n_3V0@3oool00500n_3V00@0/1LN0?[`iP3jl>H0/1LN
9@3jl>H00`2`5ah0n_3V0?[`iP0N0?[`iPX0/1LN3@3jl>H20000000401LR=P000000:CYE02TjE@80
0000100iD7400`000000Af>804MSR00304MSR0030000001FMIh0000000<0000000<0EWFN0000001T
Qk<01@1TQk<00`000000LIW7076Ia`03076Ia`80/1LN00<0Oj[J0;0G7P2`5ah0102`5ah00`000000
Rk_/08^kk00208^kk0030000002Eb?P0ULSh0080ULSh0P00000209K;m`040000001o[]80OjkB0000
00<0n_3V0P2`5ahn0?[`iP030;0G7P3jl>H0n_3V00T0n_3V00<0/1LN0?[`iP3jl>H03`3jl>H00`2`
5ah0n_3V0?[`iP0i0?[`iP40oooo001@0?[`iP030;0G7P3jl>H0/1LN02L0n_3V00<0/1LN0?[`iP3j
l>H08P3jl>H20;0G7P030?[`iP2`5ah0/1LN00d0n_3V0P0000001P0G8SH0000002TjE@000000:CYE
000000@0>E1a00<0000004MSR017HhP00P17HhP3000000D0EWFN00<0000006B7/`1TQk<0101TQk<0
10000000LIW7076Ia`1aVLL70;0G7P0507nZfP2`5ah0Oj[J0;0G7P2;^n`00`0000000`2;^n`00000
09G8n00309G8n0030000002FboL00000008000000P1o[]800`000000n_3V0?[`iP050;0G7P<0n_3V
0P2`5ahh0?[`iP030;0G7P3jl>H0n_3V00L0n_3V00<0/1LN0?[`iP3jl>H03`3jl>H00`2`5ah0n_3V
0?[`iP0j0?[`iP40oooo001@0?[`iP80/1LN:@3jl>H00`2`5ah0n_3V0?[`iP040?[`iP030;0G7P3j
l>H0n_3V01`0n_3V0P2`5ah>0?[`iP80000000<05b8f0000000000000P0Y>UD00`000000>E1a03U@
L@0203U@L@0300000017HhP000000080000000<0Af>80000001FMIh01@1FMIh00`000000I8Nc06B7
/`0406B7/`030000001aVLL0LIW70080LIW72P2`5ah408^kk0800000102Eb?P01@000000U/_g09K;
m`2FboL000000080OjkB0P0000000`3jl>H0/1LN0;0G7P0:0;0G7P@0n_3V0P2`5ah70?[`iP030;0G
7P3jl>H0n_3V00L0n_3V0P2`5ahU0?[`iP80/1LN4P3jl>H00`2`5ah0n_3V0?[`iP0j0?[`iP40oooo
001@0?[`iP80/1LN:P3jl>H00`2`5ah0n_3V0?[`iP030?[`iP030;0G7P3jl>H0n_3V02`0n_3V0P00
00000`0G8SH0000002TjE@0202TjE@040000000iD740>E1a03U@L@<000001017HhP00`000000EWFN
05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL00`1aVLL00`2`5ah00000
07nZfP030;0G7P0307nZfP2`5ah0/1LN00D0/1LN0`00000209G8n0040000002FboL0U/_g09K;m`80
000000<0OjkB0000000000000`2`5ah00`3jl>H0/1LN0;0G7P060;0G7P@0n_3V0`2`5ah60?[`iP@0
/1LN103jl>H40;0G7P030?[`iP2`5ah0/1LN0100n_3V0P2`5ah@0?[`iP030;0G7P3jl>H0n_3V0180
n_3V00<0/1LN0?[`iP3jl>H0>P3jl>H10?ooo`00D03jl>H20;0G7R/0n_3V00<0/1LN0?[`iP3jl>H0
0P3jl>H00`2`5ah0n_3V0?[`iP0/0?[`iP@000000`0Y>UD01P000000>E1a000000000000>E1a0000
00D0Af>800<0000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW7
00@0LIW700@0000007nZfP1oZ]X0Oj[J0`2`5ah00`000000Rk_/08^kk00308^kk0H0/1LN0`2FboL2
0000000307n^dP00000000000080n_3V1@2`5ah20?[`iP80/1LN1@3jl>H20;0G7P030?[`iP2`5ah0
n_3V00<0n_3V1P2`5ah30?[`iPP0/1LN3@3jl>H70;0G7PH0n_3V0`2`5ah30?[`iP030;0G7P3jl>H0
n_3V00@0n_3V00<0/1LN0?[`iP3jl>H02`3jl>H00`2`5ah0n_3V0?[`iP0k0?[`iP40oooo001=0?[`
iP030;0G7P3jl>H0/1LN00<0/1LN:`3jl>H00`2`5ah0n_3V0?[`iP020?[`iP030;0G7P3jl>H0n_3V
00H0n_3V00<0/1LN0?[`iP3jl>H08P3jl>H4000000<0:CYE0P00000303U@L@0300000017HhP0Af>8
00<0Af>800<0000005IeWP1FMIh0101FMIh010000000I8Nc06B7/`1TQk<7000000<0LIW700<00000
07nZfP1oZ]X00P1oZ]X20;0G7P030000002;^n`0Rk_/00<0Rk_/00<0000009G8n02Eb?P00P2Eb?P0
0`000000/1LN0;0G7P030;0G7P<00000102`5ah50?[`iP030;0G7P3jl>H0n_3V00@0n_3V0`2`5ah5
0?[`iP030;0G7P3jl>H0/1LN0080/1LN103jl>H50;0G7P030?[`iP2`5ah0n_3V00h0n_3V00<0/1LN
0?[`iP2`5ah00`2`5ah50?[`iPD0/1LN00<0n_3V0;0G7P3jl>H01@3jl>H40;0G7P/0n_3V00<0/1LN
0?[`iP3jl>H0503jl>H20;0G7RD0n_3V0@3oool003L0n_3V00<0/1LN0?[`iP3jl>H04@3jl>H40;0G
7P050?[`iP2`5ah0/1LN0?[`iP2`5ah0:`3jl>H20;0G7P80n_3V00<0/1LN0?[`iP3jl>H01@3jl>H0
0`2`5ah0n_3V0?[`iP0?0?[`iP80/1LN4P3jl>H20000000401LR=P000000:CYE02TjE@800000100i
D7400`000000Af>804MSR00304MSR0040000001FMIh0EWFN05IeWPL000000`1TQk<010000000LIW7
076Ia`1aVLL7000000<0Oj[J00<0000008^kk02;^n`00`2;^n`00`000000ULSh09G8n00209G8n080
00000P2FboL00`000000OjkB0;0G7P020;0G7Q00n_3V00<0/1LN0?[`iP3jl>H01P3jl>H20;0G7P03
0?[`iP2`5ah0n_3V00@0n_3V0P2`5ah20?[`iP80/1LN3`3jl>H50;0G7PD0n_3V0P2`5ah0103jl>H0
/1LN0;0G7P2`5ah70?[`iP<0/1LN00@0n_3V0;0G7P2`5ah0/1LN203jl>H00`2`5ah0n_3V0?[`iP0D
0?[`iP030;0G7P3jl>H0/1LN00<0/1LN8P3jl>H10?ooo`00=`3jl>H00`2`5ah0n_3V0?[`iP0?0?[`
iP80/1LN00<0n_3V0;0G7P3jl>H0102`5ah20?[`iP030;0G7P3jl>H0n_3V02X0n_3V00<0/1LN0?[`
iP2`5ah01@3jl>H20;0G7P/0n_3V0P2`5ah70?[`iP@0/1LN3P3jl>H20000000601LR=P000000:CYE
0000000Y>UD00000100iD7400`000000Af>804MSR00204MSR0D000000`1FMIh00`000000I8Nc06B7
/`0406B7/`030000001aVLL0LIW700@0LIW700@0000007nZfP1oZ]X0Oj[J1@00000408^kk0030000
002Eb?P0ULSh0080ULSh00D0000009K;m`000000U/_g0000000207n^dP8000003`3jl>H00`2`5ah0
n_3V0?[`iP090?[`iP030;0G7P3jl>H0/1LN00@0n_3V00L0/1LN0?[`iP2`5ah0n_3V0;0G7P3jl>H0
/1LN00d0n_3V0`2`5ah00`3jl>H0/1LN0;0G7P060?[`iP<0/1LN0P3jl>H00`2`5ah0n_3V0?[`iP04
0?[`iP030;0G7P3jl>H0/1LN00<0n_3V0P2`5ah70?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN
0?[`iP3jl>H0102`5ahR0?[`iP40oooo000f0?[`iP030;0G7P3jl>H0n_3V00l0n_3V00@0/1LN0?[`
iP3jl>H0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P040?[`iP030;0G7P3jl>H0n_3V02X0n_3V102`5ah2
0?[`iP030;0G7P3jl>H0n_3V00P0n_3V0`2`5ah=0?[`iPH0/1LN1`3jl>H0102`5ah000000000000G
8SH200000080:CYE00<0000003U@L@0iD7400P0iD7400`000000Af>8000000020000000304MSR000
0000EWFN00D0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001o
Z]X0Oj[J00@0Oj[J00<0000008^kk00000000P0000000`2;^n`0000009G8n00309G8n0030000002F
boL0U/_g008000000P1o[]82000000l0n_3V00<0/1LN0?[`iP3jl>H02`3jl>H00`2`5ah0n_3V0?[`
iP030?[`iP80/1LN00@0n_3V0;0G7P3jl>H0n_3V0P2`5ah90?[`iP80/1LN0P3jl>H00`2`5ah0n_3V
0;0G7P080?[`iP@0/1LN1P3jl>H0102`5ah0n_3V0?[`iP2`5ah30?[`iP030;0G7P3jl>H0n_3V01/0
n_3V102`5ah0103jl>H0/1LN0;0G7P2`5ahR0?[`iP40oooo000f0?[`iP030;0G7P3jl>H0n_3V00l0
n_3V0P2`5ah01`3jl>H0/1LN0;0G7P3jl>H0/1LN0?[`iP2`5ah00P3jl>H20;0G7R`0n_3V102`5ah0
0`3jl>H0/1LN0;0G7P080?[`iP<0/1LN503jl>H50;0G7P@0n_3V00D0/1LN0000000000005b8f0000
000302TjE@030000000iD740>E1a0080>E1a0P00000404MSR0030000001FMIh0EWFN00@0EWFN00<0
000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00@0Oj[J00<0
000008^kk02;^n`00P2;^n`2000000D0ULSh00@0000009K;m`2FboL000000P1o[]82000000h0n_3V
00<0/1LN0?[`iP3jl>H03@3jl>H00`2`5ah0n_3V0?[`iP040?[`iP030;0G7P3jl>H0n_3V00<0n_3V
0P2`5ah60?[`iP030;0G7P3jl>H0n_3V00<0n_3V00<0/1LN0?[`iP3jl>H01P3jl>H00`2`5ah0n_3V
0;0G7P090?[`iP060;0G7P3jl>H0n_3V0;0G7P3jl>H0/1LN7@3jl>H20;0G7P<0n_3V00<0/1LN0?[`
iP2`5ah00P2`5ahQ0?[`iP40oooo000f0?[`iP030;0G7P3jl>H0n_3V0100n_3V0`2`5ah30?[`iP@0
/1LN;@3jl>H70;0G7PH0n_3V0`2`5ahK0?[`iPD0/1LN00<0n_3V0000000000000P00000302TjE@03
0000000iD740>E1a00<000001@17HhP00`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0
I8Nc00<00000076Ia`1aVLL0101aVLL00`000000Oj[J07nZfP0407nZfP030000002;^n`0Rk_/00<0
Rk_/0`00000309G8n0030000002FboL0U/_g0080000000<0OjkB0000000000007`3jl>H00`2`5ah0
n_3V0?[`iP0;0?[`iP80/1LN0P3jl>H20;0G7Ph0n_3V00<0/1LN0?[`iP3jl>H02`3jl>H40;0G7Ql0
n_3V00@0/1LN0?[`iP3jl>H0n_3V0P2`5ah20?[`iP030;0G7P3jl>H0n_3V01l0n_3V0@3oool003D0
n_3V00<0/1LN0?[`iP3jl>H04@3jl>H80;0G7S00n_3V1P2`5ah20?[`iP@0/1LN8@3jl>H30;0G7P@0
00000`0Y>UD300000080>E1a00<0000004MSR017HhP00`17HhP00`000000EWFN05IeWP0405IeWP03
0000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000Oj[J07nZfP0407nZfP03
0000002;^n`0Rk_/00<0Rk_/00<0000009G8n02Eb?P00P0000001P2Eb?P0000009K;m`2FboL00000
07n^dP<00000803jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP80/1LN403jl>H00`2`5ah0n_3V0?[`iP0=
0?[`iP030;0G7P3jl>H0n_3V01l0n_3V00L0/1LN0?[`iP2`5ah0n_3V0;0G7P3jl>H0/1LN0280n_3V
0@3oool003D0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H20;0G7P030?[`iP2`5ah0/1LN01D0n_3V00<0
/1LN0?[`iP3jl>H06@3jl>H90;0G7RD0n_3V00<0/1LN0?[`iP3jl>H00P0000000`0G8SH0000002Tj
E@0202TjE@030000000iD740>E1a0080>E1a00<0000004MSR017HhP00`17HhP010000000EWFN05Ie
WP1FMIhE000000<0Oj[J00<0000008^kk02;^n`00`2;^n`00`000000ULSh09G8n00209G8n0800000
0P2FboL00`000000OjkB07n^dP0200000240n_3V00<0/1LN0?[`iP3jl>H02@3jl>H20;0G7P030?[`
iP2`5ah0/1LN00h0n_3V00<0/1LN0?[`iP3jl>H03P3jl>H00`2`5ah0n_3V0?[`iP0P0?[`iP030;0G
7P3jl>H0n_3V0080/1LN8`3jl>H10?ooo`00=@3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP80/1LN5`3j
l>H00`2`5ah0n_3V0?[`iP0H0?[`iPP0/1LN9`3jl>H30;0G7P80000000@05b8f0000000Y>UD0:CYE
0P00000403U@L@030000002`5ah0/1LN0080Af>81@00000305IeWP030000001TQk<0I8Nc00@0I8Nc
00<00000076Ia`1aVLL0101aVLL010000000Oj[J07nZfP1oZ]X5000000@0Rk_/00<0000009G8n02E
b?P00`2Eb?P200000080U/_g00@0000007n^dP0000000000:`3jl>H20;0G7PD0n_3V0P2`5ah;0?[`
iP030;0G7P3jl>H0n_3V00l0n_3V00<0/1LN0?[`iP3jl>H07`3jl>H00`2`5ah0n_3V0;0G7P020;0G
7R@0n_3V0@3oool003D0n_3V00<0/1LN0?[`iP3jl>H0;@3jl>H00`2`5ah0n_3V0?[`iP0G0?[`iPL0
/1LN:@3jl>H20;0G7P80000000H05b8f000000000000000002TjE@0000050;0G7P0604MSR0000000
000000000017HhP000001P1FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW7
00<0000007nZfP1oZ]X0101oZ]X00`000000Rk_/000000020000000308^kk0000000ULSh00@0ULSh
00<0000009K;m`0000000P0000000`1o[]8000000000000Z0?[`iP030;0G7P3jl>H0n_3V00L0n_3V
0P2`5ah90?[`iP030;0G7P3jl>H0n_3V00l0n_3V00<0/1LN0?[`iP3jl>H07P3jl>H01@2`5ah0n_3V
0?[`iP3jl>H0/1LN02D0n_3V0@3oool003@0n_3V00<0/1LN0?[`iP3jl>H0;P3jl>H00`2`5ah0n_3V
0?[`iP040?[`iP030;0G7P3jl>H0n_3V00l0n_3V202`5ah[0?[`iP80000000<05b8f0000000Y>UD0
0P0Y>UD20;0G7P80>E1a0P2`5ah00`000000Af>804MSR00204MSR0030000001FMIh0EWFN00@0EWFN
00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00@0Oj[J
00<0000008^kk02;^n`00P2;^n`2000000D0ULSh00H0000009K;m`2FboL0U/_g0000001o[]820000
01d0n_3V0P2`5ahG0?[`iP030;0G7P3jl>H0n_3V00D0n_3V00<0/1LN0?[`iP3jl>H0403jl>H00`2`
5ah0n_3V0?[`iP0M0?[`iP030;0G7P3jl>H0n_3V02P0n_3V0@3oool003@0n_3V00<0/1LN0?[`iP3j
l>H0;`3jl>H00`2`5ah0n_3V0?[`iP030?[`iP030;0G7P3jl>H0n_3V0140n_3V0P2`5ah00`3jl>H0
/1LN0;0G7P060?[`iP030;0G7P3jl>H0n_3V02<0n_3V1000000302TjE@030000002`5ah0/1LN00<0
/1LN1@17HhP00`000000/1LN0;0G7P090;0G7P80I8Nc00<00000076Ia`1aVLL0101aVLL00`000000
Oj[J07nZfP0407nZfP030000002;^n`0Rk_/00<0Rk_/0`00000309G8n0060000002FboL0U/_g09K;
m`000000OjkB0P00000L0?[`iPH0/1LN703jl>H00`2`5ah0n_3V0?[`iP0@0?[`iP030;0G7P3jl>H0
n_3V01d0n_3V00<0/1LN0?[`iP3jl>H0:03jl>H10?ooo`00=03jl>H00`2`5ah0n_3V0?[`iP0_0?[`
iP030;0G7P3jl>H0n_3V0080n_3V00<0/1LN0?[`iP3jl>H0503jl>H20;0G7PP0n_3V0P2`5ahS0?[`
iP@000000`0Y>UD00`000000/1LN0;0G7P090;0G7PH0EWFN00<0000006B7/`1TQk<0101TQk<00`00
0000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00@0Oj[J00<0000008^kk02;^n`00`2;^n`00`00
0000ULSh09G8n0020000000409G8n0000000U/_g09K;m`80/1LN0`0000040?[`iP030;0G7P3jl>H0
n_3V01D0n_3V1@2`5ah50?[`iP@0/1LN4`3jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP030;0G7P3jl>H0
n_3V01/0n_3V00<0/1LN0?[`iP3jl>H0:@3jl>H10?ooo`00<`3jl>H00`2`5ah0n_3V0?[`iP0a0?[`
iP050;0G7P3jl>H0n_3V0?[`iP2`5ah0203jl>H00`2`5ah0n_3V0?[`iP0G0?[`iP80/1LN8@3jl>H2
0000000301LR=P000000:CYE0080:CYE00<0000003U@L@2`5ah0102`5ah404MSR0030000001FMIh0
EWFN00@0EWFN00@0000006B7/`1TQk<0I8Nc3000000507nZfP030000002;^n`0Rk_/00<0Rk_/00<0
000009G8n02Eb?P00P2Eb?P200000080U/_g0`2`5ah200000080n_3V0P2`5ah00`3jl>H0/1LN0?[`
iP0B0?[`iP@0/1LN00<0n_3V0;0G7P2`5ah0103jl>H60;0G7RP0n_3V00<0/1LN0?[`iP3jl>H00P3j
l>H20;0G7QH0n_3V00<0/1LN0?[`iP3jl>H0:P3jl>H10?ooo`00<@3jl>H40;0G7S80n_3V00@0/1LN
0?[`iP3jl>H0/1LN1`3jl>H20;0G7Q`0n_3V0P2`5ah20?[`iP030;0G7P3jl>H0n_3V01X0n_3V0P00
0000100G8SH0000002TjE@0Y>UD2000000<0>E1a0P2`5ah504MSR0040000001FMIh0EWFN05IeWPL0
00000`1TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0000000<0000000<0Oj[J0000002;
^n`01@2;^n`00`000000ULSh09G8n00209G8n08000000P2FboL20;0G7P80000000<0n_3V0;0G7P2`
5ah0102`5ah?0?[`iP<0/1LN103jl>H20;0G7PH0n_3V102`5ah80?[`iP030;0G7P3jl>H0n_3V01h0
n_3V00H0/1LN0?[`iP3jl>H0n_3V0;0G7P3jl>H40;0G7Q80n_3V00<0/1LN0?[`iP3jl>H0:`3jl>H1
0?ooo`00;`3jl>H20;0G7P050?[`iP2`5ah0/1LN0?[`iP2`5ah0<P3jl>H00`2`5ah0n_3V0;0G7P06
0?[`iP030;0G7P3jl>H0n_3V01h0n_3V0P2`5ah00`3jl>H0/1LN0?[`iP0J0?[`iP80000000H05b8f
0000000Y>UD0000002TjE@00000403U@L@0300000017HhP0Af>80080Af>81@00000305IeWP030000
001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000Oj[J07nZfP0307nZfP<00000
1@2;^n`00`000000ULSh09G8n00209G8n0030000002FboL000000080000000@0OjkB0;0G7P000000
n_3V1@2`5ah=0?[`iP<0/1LN1`3jl>H00`2`5ah0n_3V0?[`iP050?[`iP040;0G7P3jl>H0/1LN0;0G
7PH0n_3V1@2`5ah70?[`iP<0/1LN503jl>H00`2`5ah0n_3V0?[`iP070;0G7PT0n_3V00<0/1LN0?[`
iP3jl>H01@3jl>H00`2`5ah0n_3V0?[`iP0/0?[`iP40oooo000]0?[`iP80/1LN0`3jl>H0102`5ah0
n_3V0?[`iP2`5ahb0?[`iP@0/1LN0`3jl>H20;0G7R<0n_3V0`2`5ah30?[`iP030;0G7P3jl>H0n_3V
0100n_3V102`5ah20000000301LR=P00000000000080:CYE00<0000003U@L@0iD7400P0iD7400`00
0000Af>8000000020000000304MSR0000000EWFN00D0EWFN00<0000006B7/`1TQk<0101TQk<00`00
0000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00@0Oj[J00<0000008^kk00000000`0000000`2;
^n`0000009G8n00309G8n0080000002FboL0U/_g09K;m`000000OjkB0000002`5ah20?[`iP80/1LN
00@0n_3V0;0G7P2`5ah0/1LN1`3jl>H40;0G7Q40n_3V00@0/1LN0?[`iP2`5ah0/1LN1P3jl>H0102`
5ah0n_3V0?[`iP2`5ah20?[`iP030;0G7P3jl>H0n_3V00<0n_3V1P2`5ahD0?[`iP80/1LN0P3jl>H4
0;0G7PP0n_3V00@0/1LN0?[`iP2`5ah0/1LN103jl>H00`2`5ah0n_3V0?[`iP0]0?[`iP40oooo000^
0?[`iP050;0G7P3jl>H0n_3V0?[`iP2`5ah00`3jl>H00`2`5ah0n_3V0?[`iP0^0?[`iP@0/1LN00@0
n_3V0;0G7P3jl>H0/1LN9`3jl>H20;0G7P030?[`iP2`5ah0n_3V0080/1LN503jl>H0100000005b8f
01LR=P00000302TjE@030000000iD740>E1a0080>E1a0P00000404MSR0030000001FMIh0EWFN00@0
EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00@0
Oj[J00<0000008^kk02;^n`00`2;^n`3000000<0ULSh00H0000009K;m`2FboL0U/_g0000001o[]82
000000<0n_3V0P2`5ah30?[`iP<0/1LN0P3jl>H20;0G7Q<0n_3V0P2`5ah;0?[`iPD0/1LN1P3jl>H4
0;0G7P80n_3V0P2`5ahC0?[`iP040;0G7P3jl>H0/1LN0?[`iP<0/1LN1`3jl>H00`2`5ah0n_3V0;0G
7P030;0G7P<0n_3V00<0/1LN0?[`iP3jl>H0;@3jl>H10?ooo`00;`3jl>H0102`5ah0n_3V0?[`iP2`
5ah40?[`iP030;0G7P3jl>H0n_3V02`0n_3V1@2`5ah00`3jl>H0/1LN0;0G7P0Z0?[`iP80/1LN00<0
n_3V0;0G7P2`5ah00P3jl>H00`2`5ah0n_3V0?[`iP0?0?[`iP040000000G8SH00000000000<0:CYE
00<0000003U@L@0iD7400`00000504MSR0030000001FMIh0EWFN00@0EWFN00<0000006B7/`1TQk<0
101TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00@0Oj[J00<0000008^kk02;^n`0
102;^n`01P000000ULSh000000000000ULSh000000<0U/_g1000000;0?[`iP80/1LN503jl>H00`2`
5ah0n_3V0?[`iP0=0?[`iP030;0G7P3jl>H0n_3V00D0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P020?[`
iP030;0G7P3jl>H0n_3V01<0n_3V00H0/1LN0?[`iP3jl>H0/1LN0?[`iP2`5ah60?[`iP<0/1LN00L0
n_3V0;0G7P2`5ah0n_3V0;0G7P3jl>H0/1LN0300n_3V0@3oool002l0n_3V00@0/1LN0?[`iP2`5ah0
/1LN0P3jl>H20;0G7QH0n_3V00<0/1LN0?[`iP3jl>H0503jl>H90;0G7R/0n_3V00<0/1LN0?[`iP2`
5ah0102`5ahB0?[`iP80000000<05b8f0000000Y>UD00P0Y>UD300000080>E1a00<0000004MSR017
HhP00`17HhP00`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1a
VLL0101aVLL00`000000Oj[J07nZfP0407nZfP030000002;^n`0Rk_/00@0Rk_/00@0000009G8n02E
b?P0ULSh0P00000309K;m`@000003@3jl>H30;0G7Q00n_3V00<0/1LN0?[`iP3jl>H03@3jl>H00`2`
5ah0n_3V0?[`iP060?[`iP050;0G7P3jl>H0n_3V0;0G7P3jl>H00P2`5ahE0?[`iP030;0G7P3jl>H0
/1LN00<0/1LN1P3jl>H20;0G7P<0n_3V0P2`5ah20?[`iP030;0G7P3jl>H0n_3V02l0n_3V0@3oool0
0300n_3V0P2`5ah0103jl>H0/1LN0;0G7P2`5ahG0?[`iP030;0G7P3jl>H0n_3V01@0n_3V0P2`5ah0
0`3jl>H0/1LN0;0G7P040;0G7RX0n_3V202`5ahB0?[`iP040000000G8SH05b8f000000<0:CYE00<0
000003U@L@0iD7400P0iD7400`000000Af>804MSR00304MSR0040000001FMIh0EWFN05IeWQD00000
0`1oZ]X00`000000Rk_/08^kk00408^kk0030000002Eb?P0ULSh0080ULSh0P00000209K;m`040000
001o[]80000000000100n_3V0P2`5ah<0?[`iP80/1LN403jl>H00`2`5ah0n_3V0?[`iP070?[`iP03
0;0G7P3jl>H0/1LN0080n_3V00<0/1LN0?[`iP3jl>H04P3jl>H01@2`5ah0n_3V0?[`iP3jl>H0/1LN
00T0n_3V00<0/1LN0?[`iP3jl>H00P2`5ah20?[`iP030;0G7P3jl>H0n_3V0300n_3V0@3oool00340
n_3V0`2`5ahI0?[`iP030;0G7P3jl>H0n_3V0180n_3V0P2`5ah00`3jl>H0/1LN0?[`iP050;0G7R`0
n_3V1P2`5ahB0?[`iP8000000P0G8SH00`000000:CYE02TjE@02000000@0>E1a00<0000004MSR017
HhP00P17HhP5000000<0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`04
0000001oZ]X0Oj[J07nZfPD000001@2;^n`00`000000ULSh09G8n00209G8n0060000002FboL00000
09K;m`000000OjkB0P0000030?[`iP030;0G7P3jl>H0n_3V01L0n_3V00<0/1LN0?[`iP3jl>H0403j
l>H00`2`5ah0n_3V0?[`iP080?[`iP@0/1LN00<0n_3V0;0G7P3jl>H0403jl>H20;0G7Pl0n_3V102`
5ah00`3jl>H0/1LN0?[`iP0b0?[`iP40oooo000b0?[`iP030;0G7P3jl>H0n_3V01P0n_3V00<0/1LN
0?[`iP3jl>H04P3jl>H30;0G7P030?[`iP2`5ah0/1LN00<0/1LN;`3jl>H40;0G7Pd0n_3V0P2`5ah3
0?[`iP8000000P0G8SH30000000302TjE@000000>E1a00<0>E1a00<0000004MSR00000000P000000
0`17HhP0000005IeWP0505IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL0
0`000000Oj[J07nZfP0407nZfP030000002;^n`0000000<0000000<0Rk_/0000002Eb?P00`2Eb?P0
0`000000U/_g09K;m`020000000307n^dP00000000000080n_3V102`5ahZ0?[`iP030;0G7P3jl>H0
n_3V00X0n_3V00@0/1LN0?[`iP3jl>H0/1LN403jl>H00`2`5ah0n_3V0?[`iP0@0?[`iP@0/1LN=03j
l>H10?ooo`00C@3jl>H00`2`5ah0n_3V0?[`iP030?[`iP030;0G7P3jl>H0n_3V00`0n_3V0P2`5ah0
0`3jl>H0/1LN0?[`iP020;0G7Ph0n_3V00<0/1LN0?[`iP3jl>H08@3jl>H20;0G7P030?[`iP2`5ah0
/1LN00L0n_3V102`5ah50?[`iP8000000P0G8SH010000000:CYE02TjE@00000503U@L@8000001017
HhP00`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101a
VLL00`000000Oj[J07nZfP0407nZfP030000002;^n`0Rk_/00<0Rk_/0P00000409G8n0060000002F
boL0U/_g09K;m`000000OjkB0P0000020?[`iPH0/1LN:03jl>H00`2`5ah0n_3V0?[`iP0>0?[`iP03
0;0G7P3jl>H0n_3V00`0n_3V00<0/1LN0?[`iP3jl>H04@3jl>H00`2`5ah0n_3V0;0G7P0e0?[`iP40
oooo001=0?[`iP030;0G7P3jl>H0n_3V0080n_3V00<0/1LN0?[`iP3jl>H03@3jl>H30;0G7P030?[`
iP2`5ah0/1LN0080/1LN3P3jl>H00`2`5ah0n_3V0?[`iP0Q0?[`iP@0/1LN103jl>H30;0G7PT0n_3V
0P0000000`0G8SH000000000000202TjE@040000000iD740>E1a03U@L@<000001@17HhP00`000000
EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000
Oj[J07nZfP0407nZfP030000002;^n`0Rk_/00@0Rk_/0`00000209G8n0040000002FboL0U/_g09K;
m`@00000102`5ah20?[`iP040;0G7P3jl>H0n_3V0?[`iP80/1LN903jl>H00`2`5ah0n_3V0?[`iP0?
0?[`iP030;0G7P3jl>H0n_3V00X0n_3V00<0/1LN0?[`iP3jl>H04@3jl>H00`2`5ah0n_3V0?[`iP0f
0?[`iP40oooo001=0?[`iP050;0G7P3jl>H0n_3V0?[`iP2`5ah0403jl>H40;0G7P030?[`iP2`5ah0
/1LN0100n_3V00<0/1LN0?[`iP3jl>H0803jl>H20;0G7P030?[`iP2`5ah0n_3V00<0/1LN303jl>H3
0000000601LR=P000000:CYE02TjE@000000>E1a0P00000203U@L@0300000017HhP0Af>800<0Af>8
00<0000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW7
00<0000007nZfP1oZ]X0101oZ]X00`000000Rk_/08^kk00408^kk0030000002Eb?P0ULSh00<00000
0`2FboL4000000<0n_3V0`2`5ah30?[`iPD0/1LN=@3jl>H00`2`5ah0n_3V0?[`iP080?[`iP030;0G
7P3jl>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H0=P3jl>H10?ooo`00C@3jl>H01@2`5ah0n_3V0?[`
iP3jl>H0/1LN0180n_3V0`2`5ahC0?[`iP030;0G7P3jl>H0n_3V01l0n_3V1@2`5ah?0?[`iP<00000
00@05b8f0000000Y>UD0:CYE0P00000403U@L@0300000017HhP0Af>800<0Af>800<0000005IeWP1F
MIh0101FMIh010000000I8Nc06B7/`1TQk<7000000<0LIW700<0000007nZfP1oZ]X0101oZ]X00`00
0000Rk_/08^kk00408^kk0030000002Eb?P0ULSh0080ULSh00H0000009K;m`2FboL0U/_g0000001o
[]82000000<0n_3V0P2`5ah30?[`iPD0/1LN;@3jl>H20;0G7PP0n_3V00<0/1LN0?[`iP3jl>H01@3j
l>H20;0G7QD0n_3V00<0/1LN0?[`iP3jl>H0=P3jl>H10?ooo`00C@3jl>H0102`5ah0n_3V0?[`iP2`
5ahZ0?[`iP030;0G7P3jl>H0n_3V0080n_3V00<0/1LN0?[`iP3jl>H0603jl>H60;0G7Pl0n_3V0P00
0000100G8SH0000002TjE@0Y>UD2000000@0>E1a00<0000004MSR017HhP01017HhP010000000EWFN
05IeWP1FMIh7000000<0I8Nc00@00000076Ia`1aVLL0LIW70P0000000`2`5ah00000000000020000
00<0Oj[J00<0000008^kk02;^n`0102;^n`00`000000ULSh09G8n00209G8n08000000P2FboL01000
0000OjkB0000000000030?[`iP030;0G7P3jl>H0/1LN0080/1LN0P3jl>H20;0G7PH0n_3V00<0/1LN
0?[`iP3jl>H08`3jl>H70;0G7PD0n_3V00<0/1LN0?[`iP3jl>H0103jl>H00`2`5ah0n_3V0?[`iP0D
0?[`iP030;0G7P3jl>H0n_3V03L0n_3V0@3oool004d0n_3V00<0/1LN0?[`iP2`5ah0;03jl>H01@2`
5ah0n_3V0?[`iP3jl>H0/1LN01`0n_3V1@2`5ah>0?[`iP80000000H05b8f0000000Y>UD0000002Tj
E@00000403U@L@0300000017HhP0Af>800<0Af>81@00000305IeWP030000001TQk<0I8Nc00@0I8Nc
00@00000076Ia`1aVLL0LIW7102`5ah307nZfPD000001@2;^n`00`000000ULSh09G8n00209G8n003
0000002FboL000000080000000@0OjkB000000000000n_3V102`5ah50?[`iP030;0G7P3jl>H0n_3V
00@0n_3V00<0/1LN0?[`iP2`5ah09@3jl>H00`2`5ah0n_3V0;0G7P030;0G7PH0n_3V00<0/1LN0?[`
iP3jl>H00P3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V03L0n_3V0@3oool004d0
n_3V0P2`5ah^0?[`iP80/1LN00<0n_3V0;0G7P3jl>H0803jl>H30;0G7PX0n_3V00@0/1LN00000000
00005b8f0P00000202TjE@030000000iD740>E1a0080>E1a00<0000004MSR00000000`0000000`17
HhP0000005IeWP0505IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL00P1aVLL80;0G
7P0307nZfP000000Rk_/00@0000000<0Rk_/0000002Eb?P00`2Eb?P01P000000U/_g09K;m`2FboL0
000007n^dP80000000<0/1LN0?[`iP3jl>H03P3jl>H20;0G7P030?[`iP2`5ah0n_3V02<0n_3V1@2`
5ah80?[`iP<0/1LN603jl>H00`2`5ah0n_3V0?[`iP0h0?[`iP40oooo001<0?[`iP@0/1LN;`3jl>H0
102`5ah0n_3V0;0G7P2`5ahR0?[`iP<0/1LN1`3jl>H01@2`5ah000000000000G8SH0000000<0:CYE
00<0000003U@L@0iD7400P0iD742000000D0Af>800<0000005IeWP1FMIh0101FMIh00`000000I8Nc
06B7/`0406B7/`030000001aVLL0LIW700<0LIW700<0/1LN0000001oZ]X0101oZ]X40;0G7P<0Rk_/
0P00000409G8n0040000002FboL0U/_g09K;m`80000000<0OjkB0000003jl>H04@3jl>H20;0G7PH0
n_3V0`2`5ahK0?[`iP<0/1LN00<0n_3V0;0G7P2`5ah01P3jl>H50;0G7QP0n_3V00<0/1LN0?[`iP3j
l>H05@3jl>H20;0G7R40n_3V0@3oool004X0n_3V0P2`5ah01@3jl>H0/1LN0;0G7P3jl>H0/1LN02l0
n_3V102`5ahR0?[`iPH0/1LN0P3jl>H00`2`5ah0n_3V00000003000000<0:CYE00<0000003U@L@0i
D7400`00000604MSR0030000001FMIh0EWFN00@0EWFN00<0000006B7/`1TQk<0101TQk<00`000000
LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00@0Oj[J00<0000008^kk02;^n`0102;^n`300000080
ULSh00@0000009K;m`2FboL0U/_g0P0000000`1o[]8000000?[`iP0@0?[`iP030;0G7P3jl>H0n_3V
00H0n_3V1@2`5ahG0?[`iP80/1LN0P3jl>H00`2`5ah0n_3V0;0G7P060?[`iP80/1LN00<0n_3V0;0G
7P2`5ah00P2`5ah90?[`iP030;0G7P3jl>H0n_3V00X0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`
5ah0n_3V0;0G7P020;0G7Ql0n_3V0@3oool004T0n_3V0P2`5ah0103jl>H0/1LN0;0G7P2`5ah20?[`
iP030;0G7P3jl>H0n_3V02`0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P050?[`iP030;0G7P3jl>H0n_3V
01/0n_3V0`2`5ah01@3jl>H0/1LN0;0G7P2`5ah0n_3V00@000000`0Y>UD300000080>E1a00<00000
04MSR017HhP01017HhP00`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000
076Ia`1aVLL0101aVLL00`000000Oj[J07nZfP0507nZfP030000002;^n`0Rk_/00<0Rk_/00<00000
09G8n02Eb?P00`00000309K;m`040000001o[]80000000000100n_3V00<0/1LN0?[`iP3jl>H01`3j
l>H40;0G7QL0n_3V00<0/1LN0?[`iP3jl>H00`3jl>H00`2`5ah0n_3V0?[`iP060?[`iP060;0G7P3j
l>H0/1LN0;0G7P3jl>H0/1LN203jl>H30;0G7P/0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H20;0G7P03
0?[`iP2`5ah0/1LN0080/1LN7`3jl>H10?ooo`00<`3jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP@0/1LN
00<0n_3V0;0G7P3jl>H00`3jl>H00`2`5ah0n_3V0?[`iP0Z0?[`iPH0/1LN103jl>H00`2`5ah0n_3V
0?[`iP0O0?[`iP<0/1LN00H0n_3V0;0G7P000000000001LR=P00000302TjE@030000000iD740>E1a
0080>E1a00<0000004MSR017HhP01017HhP00`000000EWFN05IeWP0305IeWQ4000001P1oZ]X00`00
0000Rk_/08^kk00308^kk0030000002Eb?P0ULSh0080ULSh00D0000009K;m`2FboL0U/_g00000002
07n^dP030000003jl>H0n_3V00h0n_3V00<0/1LN0?[`iP3jl>H0203jl>H00`2`5ah0n_3V0;0G7P0E
0?[`iP80/1LN3`3jl>H20;0G7P030?[`iP2`5ah0/1LN00P0n_3V1P2`5ahN0?[`iP@0/1LN00<0n_3V
0;0G7P2`5ah00P2`5ahN0?[`iP40oooo000c0?[`iP030;0G7P3jl>H0n_3V0100n_3V0P2`5ah00`3j
l>H0/1LN0?[`iP030;0G7P80n_3V0P2`5ah^0?[`iPD0/1LN0P3jl>H20;0G7R@0n_3V0`2`5ah20000
000401LR=P000000:CYE02TjE@800000100iD7400`000000Af>804MSR00404MSR0030000001FMIh0
000000<0000000<0EWFN0000001TQk<01@1TQk<00`000000LIW7076Ia`04076Ia`030000001oZ]X0
000000<000000P1oZ]X00`000000Rk_/08^kk00308^kk0030000002Eb?P0ULSh0080ULSh0P000002
09K;m`030000001o[]80OjkB008000003P3jl>H00`2`5ah0n_3V0?[`iP0:0?[`iP030;0G7P3jl>H0
/1LN0180n_3V0P2`5ahA0?[`iP@0/1LN203jl>H20;0G7P040?[`iP2`5ah0n_3V0?[`iP80/1LN703j
l>H20;0G7P<0n_3V00D0/1LN0?[`iP2`5ah0n_3V0;0G7P0N0?[`iP40oooo000b0?[`iP030;0G7P3j
l>H0n_3V0100n_3V00@0/1LN0?[`iP3jl>H0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P020;0G7S00n_3V
1@2`5ah00`3jl>H0/1LN0?[`iP0V0?[`iP80/1LN0P0000001P0G8SH00000000000000000:CYE0000
00@0>E1a00<0000004MSR017HhP00`17HhP3000000D0EWFN00<0000006B7/`1TQk<0101TQk<00`00
0000LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00<0Oj[J1000000408^kk0030000002Eb?P0ULSh
0080ULSh00<0000009K;m`0000000P00000207n^dP8000007@3jl>H00`2`5ah0n_3V0?[`iP0>0?[`
iP80/1LN4P3jl>H0102`5ah0n_3V0?[`iP2`5ah80?[`iP050;0G7P3jl>H0n_3V0?[`iP2`5ah0103j
l>H00`2`5ah0n_3V0?[`iP0J0?[`iP070;0G7P3jl>H0n_3V0?[`iP2`5ah0n_3V0;0G7P020?[`iP03
0;0G7P3jl>H0n_3V01/0n_3V0@3oool00380n_3V00<0/1LN0?[`iP3jl>H0403jl>H20;0G7P030?[`
iP2`5ah0/1LN00<0n_3V00<0/1LN0?[`iP3jl>H0;`3jl>H20;0G7P050?[`iP2`5ah0/1LN0?[`iP2`
5ah0:P3jl>H20000000301LR=P000000:CYE0080:CYE00<0000003U@L@0iD7400P0iD7400`000000
Af>8000000030000000304MSR0000000EWFN00D0EWFN00<0000006B7/`1TQk<0101TQk<00`000000
LIW7076Ia`04076Ia`030000001oZ]X0Oj[J00D0Oj[J00<0000008^kk00000000P0000000`2;^n`0
000009G8n00309G8n0050000002FboL0U/_g09K;m`0000000P1o[]82000001h0n_3V00<0/1LN0?[`
iP3jl>H02`3jl>H20;0G7Q@0n_3V00<0/1LN0?[`iP3jl>H02P3jl>H20;0G7P80n_3V00@0/1LN0?[`
iP3jl>H0/1LN7P3jl>H00`2`5ah0n_3V0;0G7P020?[`iP030;0G7P3jl>H0/1LN01h0n_3V0@3oool0
0380n_3V00<0/1LN0?[`iP3jl>H04@3jl>H30;0G7P@0n_3V0P2`5ahB0?[`iP030;0G7P3jl>H0n_3V
01`0n_3V0`2`5ah00`3jl>H0/1LN0?[`iP0Z0?[`iP@000000`0Y>UD00`000000>E1a03U@L@0203U@
L@8000001@17HhP00`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076I
a`1aVLL01@1aVLL00`000000Oj[J07nZfP0407nZfP030000002;^n`0Rk_/0080Rk_/0`00000309G8
n0040000002FboL0U/_g09K;m`80000000<0OjkB0000000000007@3jl>H30;0G7P/0n_3V00<0/1LN
0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0=0?[`iPD0/1LN803jl>H20;0G7P040?[`iP2`5ah0
n_3V0;0G7Ql0n_3V0@3oool00340n_3V00<0/1LN0?[`iP3jl>H04P3jl>H80;0G7Q@0n_3V00<0/1LN
0?[`iP3jl>H06P3jl>H50;0G7R`0n_3V1000000302TjE@030000000iD740>E1a00<000001P17HhP0
0`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL01@1aVLL0
0`000000Oj[J07nZfP0407nZfP030000002;^n`0Rk_/00<0Rk_/00H0000009G8n0000000000009G8
n000000309K;m`030000001o[]80000000800000703jl>H20;0G7P030?[`iP2`5ah0/1LN01l0n_3V
00<0/1LN0?[`iP3jl>H0403jl>H00`2`5ah0n_3V0?[`iP0O0?[`iP030;0G7P3jl>H0n_3V00<0/1LN
803jl>H10?ooo`00<@3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP80/1LN00<0n_3V0;0G7P2`5ah05P3j
l>H00`2`5ah0n_3V0?[`iP0J0?[`iPD0/1LN1@3jl>H20;0G7RD0n_3V0P0000000`0G8SH0000002Tj
E@0202TjE@<000000P0iD7400`000000Af>804MSR00404MSR0030000001FMIh0EWFN00@0EWFN00<0
000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`05076Ia`030000001oZ]X0Oj[J00@0Oj[J00<0
000008^kk02;^n`00`2;^n`010000000ULSh09G8n02Eb?P2000000<0U/_g00<0000007n^dP1o[]80
0P00000L0?[`iPL0/1LN703jl>H00`2`5ah0n_3V0?[`iP0A0?[`iP030;0G7P3jl>H0n_3V01h0n_3V
00<0/1LN0?[`iP3jl>H00P3jl>H00`2`5ah0n_3V0?[`iP0O0?[`iP40oooo000a0?[`iP030;0G7P3j
l>H0n_3V01@0n_3V0P2`5ahI0?[`iP030;0G7P3jl>H0n_3V01T0n_3V0P2`5ah0103jl>H0/1LN0;0G
7P2`5ah60?[`iP80/1LN8`3jl>H20000000301LR=P000000:CYE0080:CYE00<0000003U@L@0iD740
0P0iD74010000000Af>80;0G7P2`5ah304MSR0040000001FMIh0EWFN05IeWQH000000`1oZ]X00`00
0000Rk_/08^kk00308^kk0030000002Eb?P0ULSh0080ULSh0P00000209K;m`030000001o[]80OjkB
00800000703jl>H60;0G7Qd0n_3V00<0/1LN0?[`iP3jl>H04@3jl>H00`2`5ah0n_3V0?[`iP0M0?[`
iP030;0G7P3jl>H0n_3V02D0n_3V0@3oool00340n_3V00<0/1LN0?[`iP3jl>H0;`3jl>H00`2`5ah0
n_3V0?[`iP0I0?[`iP@0/1LN2P3jl>H20;0G7R40n_3V0P000000100G8SH0000002TjE@0Y>UD20000
00H0/1LN1017HhP9000000<0NZKG00<0000006jEa01^UL@0101^UL@010000000HHB`0664/01QQ;09
000000@0Rk_/00<0000009G8n02Eb?P00P2Eb?P00`000000U/_g0000000200000080OjkB0P00000I
0?[`iPD0/1LN00<0n_3V0;0G7P2`5ah07@3jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP030;0G7P3jl>H0
n_3V01d0n_3V00<0/1LN0?[`iP3jl>H09@3jl>H10?ooo`00<03jl>H00`2`5ah0n_3V0?[`iP0a0?[`
iP030;0G7P3jl>H0n_3V0080n_3V00<0/1LN0?[`iP3jl>H08`3jl>H20;0G7Q/0n_3V102`5ah20000
000501LR=P00000000000000000Y>UD00`2`5ah203U@L@0400000017HhP0Af>804MSR08000001@27
]^P010000000NZKG07ZVe`1jY]L>000000<0HHB`00<0000005=bW01CLY`00`1CLY`30000000308^k
k0000000ULSh00<0ULSh00D0000009K;m`2FboL0U/_g0000000207n^dP8000005P3jl>H30;0G7P@0
n_3V00<0/1LN0?[`iP2`5ah01`3jl>H30;0G7RT0n_3V00<0/1LN0?[`iP3jl>H0703jl>H00`2`5ah0
n_3V0?[`iP0V0?[`iP40oooo000`0?[`iP030;0G7P3jl>H0n_3V0380n_3V00D0/1LN0?[`iP3jl>H0
n_3V0;0G7P0W0?[`iP80/1LN1P3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP80000000<05b8f0000000Y
>UD00P0Y>UD00`000000/1LN0;0G7P0203U@L@0600000017HhP000000000002Ca_T000001@27]^P0
0`000000NZKG07ZVe`0407ZVe`030000001^UL@0KYG400@0KYG400<000000664/01QQ;00101QQ;00
0`000000Dg:L05=bW00305=bW00300000016HHL0AV6700800000102Eb?P010000000U/_g09K;m`2F
boL20000000307n^dP00000000000180n_3V102`5ah80?[`iP030;0G7P3jl>H0n_3V00@0n_3V1@2`
5ahY0?[`iP030;0G7P3jl>H0n_3V00<0n_3V0P2`5ahF0?[`iP030;0G7P3jl>H0n_3V02L0n_3V0@3o
ool002l0n_3V0P2`5ahd0?[`iP040;0G7P3jl>H0/1LN0;0G7RX0n_3V0P2`5ah30?[`iP030;0G7P3j
l>H0/1LN01D0n_3V1000000302TjE@040000000iD740>E1a03U@L@<000000`2Ca_T00`000000QkKX
08Nfj00308Nfj0030000001jY]L0NZKG00@0NZKG00<0000006jEa01^UL@0101^UL@00`000000HHB`
0664/0040664/0030000001CLY`0Dg:L00<0Dg:L00<0000004IQQ`16HHL00P16HHL200000080ULSh
00@0000009K;m`2FboL0U/_g0P2`5ah00`1o[]8000000000000>0?[`iP@0/1LN503jl>H0102`5ah0
n_3V0;0G7P2`5ahZ0?[`iP060;0G7P3jl>H0n_3V0?[`iP2`5ah0n_3V102`5ahB0?[`iP030;0G7P3j
l>H0n_3V02P0n_3V0@3oool002d0n_3V102`5ahe0?[`iP<0/1LN:`3jl>H30;0G7P030?[`iP2`5ah0
n_3V0080/1LN503jl>H4000000<0:CYE00<0000003U@L@0000000P0000001P2Ca_T0000000000000
0000TlKi000000D0QkKX00<0000007ZVe`1jY]L0101jY]L00`000000KYG406jEa00406jEa0030000
001QQ;00HHB`00@0HHB`00<0000005=bW01CLY`00`1CLY`00`000000AV67000000020000000304IQ
Q`0000000000008000000P2FboL40;0G7P800000303jl>H20;0G7QL0n_3V0`2`5ah00`3jl>H0/1LN
0?[`iP070?[`iP030;0G7P3jl>H0n_3V01l0n_3V00<0/1LN0?[`iP3jl>H01`2`5ahA0?[`iP030;0G
7P3jl>H0n_3V02T0n_3V0@3oool002`0n_3V00H0/1LN0?[`iP3jl>H0/1LN0?[`iP2`5ahc0?[`iP03
0;0G7P3jl>H0/1LN00<0/1LN:P3jl>H01@2`5ah0n_3V0;0G7P2`5ah0n_3V0080/1LN503jl>H20000
000301LR=P000000:CYE0080:CYE0P00000209cBo`030000002Ca_T0TlKi0080TlKi0`00000408Nf
j0030000001jY]L0NZKG00@0NZKG00<0000006jEa01^UL@0101^UL@00`000000HHB`0664/0040664
/0040000001CLY`0Dg:L05=bW0@000001016HHL010000000>4m`03Q?L000000309K;m`<0/1LN0P00
000S0?[`iP80/1LN0P3jl>H20;0G7PP0n_3V0`2`5ahP0?[`iP040;0G7P3jl>H0/1LN0;0G7P80n_3V
102`5ah@0?[`iP030;0G7P3jl>H0n_3V02X0n_3V0@3oool002X0n_3V0P2`5ah20?[`iP80/1LN00<0
n_3V0;0G7P3jl>H0<P3jl>H0102`5ah0n_3V0;0G7P2`5ah20?[`iP030;0G7P3jl>H0n_3V02P0n_3V
0P2`5ah00`3jl>H0/1LN0;0G7P020;0G7Q<0n_3V0P0000001@0G8SH0000002TjE@0Y>UD0000000@0
W=;o00<0000009?6n@2Ca_T00`2Ca_T00`000000QkKX000000020000000308Nfj0000000NZKG00D0
NZKG00<0000006jEa01^UL@0101^UL@010000000HHB`0664/01QQ;0700000080Dg:L00<0000004IQ
Q`16HHL00`16HHL01@000000>4m`03Q?L00hCg0000000080U/_g00D0000007n^dP1o[]80/1LN0000
000R0?[`iP030;0G7P3jl>H0n_3V00/0n_3V1@2`5ahO0?[`iP070;0G7P3jl>H0n_3V0;0G7P3jl>H0
/1LN0?[`iP030;0G7PT0n_3V0`2`5ah40?[`iP030;0G7P3jl>H0n_3V02X0n_3V0@3oool002T0n_3V
00<0/1LN0?[`iP3jl>H00P3jl>H01@2`5ah0n_3V0?[`iP3jl>H0/1LN0340n_3V0`2`5ah0103jl>H0
/1LN0?[`iP2`5ah[0?[`iPL0/1LN4`3jl>H20000000301LR=P000000000000<000000`2Ld_l00`00
0000TlKi09?6n@0309?6n@0300000027]^P0QkKX0080QkKX4`0000030664/0030000001CLY`0Dg:L
00<0Dg:L00<0000004IQQ`16HHL00`16HHL00`000000>4m`03Q?L00500000080OjkB00D000000;0G
7P3jl>H0n_3V0;0G7P0N0?[`iP030;0G7P3jl>H0n_3V00/0n_3V00@0/1LN0?[`iP3jl>H0/1LN0P3j
l>H00`2`5ah0n_3V0?[`iP0P0?[`iP060;0G7P3jl>H0n_3V0;0G7P3jl>H0/1LN203jl>H50;0G7P80
n_3V00<0/1LN0?[`iP3jl>H0:`3jl>H10?ooo`00:P3jl>H01@2`5ah0n_3V0?[`iP3jl>H0/1LN00@0
n_3V00<0/1LN0?[`iP3jl>H0;`3jl>H60;0G7R`0n_3V1@2`5ahD0?[`iP80000000H05b8f0000002J
d_h0V];n0000002Ld_l20000000309cBo`000000TlKi00@0TlKi00<0000008Nfj027]^P00`27]^P0
0`000000NZKG07ZVe`0407ZVe`030000001^UL@0KYG400@0KYG400<000000664/01QQ;00101QQ;00
0`000000Dg:L05=bW00305=bW00300000016HHL0AV6700<0AV670`00000203Q?L0030000000X>5@0
00000080OjkB0P0000020?[`iP<0/1LN6P3jl>H20;0G7Pl0n_3V1@2`5ahQ0?[`iP80/1LN00<0n_3V
0;0G7P2`5ah00P2`5ah80?[`iP80/1LN00H0n_3V0;0G7P2`5ah0/1LN0?[`iP2`5ah^0?[`iP40oooo
000[0?[`iP040;0G7P3jl>H0n_3V0;0G7P@0n_3V0P2`5ah^0?[`iP@0/1LN00<0n_3V0;0G7P2`5ah0
;`3jl>H40;0G7P030?[`iP2`5ah0n_3V0100n_3V1000000209[BoP040000002Ld_l0W=;o09cBo`<0
0000102Ca_T00`000000QkKX08Nfj00308Nfj0030000001jY]L0NZKG00@0NZKG00<0000006jEa01^
UL@0101^UL@00`000000HHB`0664/0040664/0030000001CLY`0Dg:L00<0Dg:L00<0000004IQQ`16
HHL00P16HHL2000000@0>4m`00D0000002PhE00X>5@0000007n^dP0200000080n_3V1@2`5ahG0?[`
iP030;0G7P3jl>H0n_3V0140n_3V00<0/1LN0?[`iP3jl>H0803jl>H00`2`5ah0n_3V0?[`iP020?[`
iP030;0G7P3jl>H0n_3V00L0n_3V0P2`5ah20?[`iP80/1LN00<0n_3V0;0G7P3jl>H0;P3jl>H10?oo
o`00:`3jl>H0102`5ah0n_3V0;0G7P2`5ah20?[`iP<0/1LN5@3jl>H00`2`5ah0n_3V0?[`iP0F0?[`
iP050;0G7P3jl>H0n_3V0;0G7P3jl>H00P2`5ah_0?[`iP80/1LN00@0n_3V0;0G7P2`5ah0/1LN4P3j
l>H400000080V];n00<0000009cBo`2Ld_l00P2Ld_l00`000000TlKi000000020000000309?6n@00
0000QkKX00@0QkKX00<0000007ZVe`1jY]L0101jY]L00`000000KYG406jEa00406jEa0030000001Q
Q;00HHB`00@0HHB`00<0000005=bW01CLY`00`1CLY`00`000000AV67000000020000000304IQQ`00
0000>4m`00<0>4m`00D0000002PhE0000000000007n^dP0200000080n_3V1P2`5ahY0?[`iP030;0G
7P3jl>H0n_3V0200n_3V00<0/1LN0?[`iP3jl>H0303jl>H0102`5ah0n_3V0?[`iP3jl>H20;0G7P<0
n_3V00<0/1LN0?[`iP3jl>H0;03jl>H10?ooo`00;03jl>H20;0G7P040?[`iP2`5ah0/1LN0;0G7QL0
n_3V00<0/1LN0?[`iP3jl>H05`3jl>H30;0G7P80n_3V0P2`5ah_0?[`iPD0/1LN4P3jl>H200000005
07f^d@000000000009[BoP000000102Ld_l00`000000TlKi09?6n@0209?6n@<000001027]^P00`00
0000NZKG07ZVe`0407ZVe`030000001^UL@0KYG400@0KYG400<000000664/01QQ;00101QQ;000`00
0000Dg:L05=bW00205=bW0<000001016HHL00`000000>4m`03Q?L00203Q?L080000000<0:3QD0000
000000000P0000040;0G7P030?[`iP2`5ah0/1LN02X0n_3V00<0/1LN0?[`iP3jl>H07P3jl>H20;0G
7Q00n_3V00<0/1LN0?[`iP3jl>H00P2`5ah20?[`iP030;0G7P3jl>H0n_3V02d0n_3V0@3oool002d0
n_3V102`5ahH0?[`iP030;0G7P3jl>H0n_3V01L0n_3V0P2`5ah0103jl>H0/1LN0;0G7P2`5ah<0?[`
iP030;0G7P3jl>H0n_3V02@0n_3V00<0/1LN0?[`iP3jl>H04@3jl>H20000000307f^d@000000V];n
00800000102Ld_l00`000000TlKi09?6n@0309?6n@0300000027]^P000000080000000<0QkKX0000
001jY]L01@1jY]L00`000000KYG406jEa00406jEa0030000001QQ;00HHB`00@0HHB`00<0000005=b
W00000000P0000000`1CLY`0000004IQQ`0404IQQ`030000000hCg00>4m`0080>4m`0P0000000`0X
>5@0000001LR=`02000000<0n_3V0`2`5ah[0?[`iP030;0G7P3jl>H0n_3V01d0n_3V00<0/1LN0?[`
iP3jl>H04@3jl>H40;0G7P030?[`iP2`5ah0n_3V02l0n_3V0@3oool002h0n_3V00<0/1LN0?[`iP3j
l>H0603jl>H00`2`5ah0n_3V0?[`iP0H0?[`iP@0/1LN3P3jl>H00`2`5ah0n_3V0?[`iP0Q0?[`iP<0
/1LN4`3jl>H20000000507f^d@000000V];n09[BoP000000102Ld_l00`000000TlKi09?6n@0309?6
n@0300000027]^P0QkKX0080QkKX1@00000307ZVe`030000001^UL@0KYG400@0KYG400@000000664
/01QQ;00HHB`1@00000405=bW00300000016HHL0AV6700<0AV6700<0000003Q?L00hCg000P0hCg00
0`000000:3QD02PhE004000000<0n_3V00<0/1LN0?[`iP3jl>H00`3jl>H30;0G7RD0n_3V00<0/1LN
0?[`iP3jl>H0703jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP@0/1LN<@3jl>H10?ooo`00B@3jl>H00`2`
5ah0n_3V0?[`iP0I0?[`iP030;0G7P3jl>H0n_3V00l0n_3V00<0/1LN0?[`iP3jl>H0803jl>H20;0G
7P030?[`iP2`5ah0/1LN0080/1LN3`3jl>H20000000407f^d@000000V];n09[BoP<000000P2Ld_l0
0`000000TlKi09?6n@0309?6n@0300000027]^P0QkKX00<0QkKX00@0000007ZVe`1jY]L0NZKG3P00
00030664/0030000001CLY`0Dg:L00<0Dg:L00<0000004IQQ`16HHL00`16HHL00`000000>4m`03Q?
L00300000080:3QD100000090?[`iPD0/1LN8`3jl>H00`2`5ah0n_3V0?[`iP070?[`iP80/1LN4@3j
l>H20;0G7QH0n_3V00<0/1LN0?[`iP2`5ah0<P3jl>H10?ooo`00B@3jl>H00`2`5ah0n_3V0?[`iP0/
0?[`iP80/1LN8@3jl>H20;0G7P@0n_3V0`2`5ah;0?[`iP030;0G7P000000OJkA008000000P2Jd_h0
0`000000W=;o09cBo`03000000D0TlKi00<0000008Nfj027]^P00`27]^P00`000000NZKG07ZVe`04
07ZVe`030000001^UL@0KYG400@0KYG400<000000664/01QQ;00101QQ;000`000000Dg:L05=bW003
05=bW00300000016HHL0AV6700<0AV670`00000203Q?L0050000000X>5@0:3QD0000000G8SL00P00
00080?[`iPD0/1LN903jl>H00`2`5ah0n_3V0?[`iP060?[`iP030;0G7P3jl>H0/1LN00<0/1LN3@3j
l>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V03<0n_3V0@3oool004T0n_3V00<0/1LN
0?[`iP3jl>H0;P3jl>H00`2`5ah0n_3V0?[`iP0W0?[`iP<0/1LN203jl>H01@2`5ah0000007f^d@1m
[]4000000080V];n00<0000009cBo`2Ld_l00P2Ld_l2000000@0TlKi00<0000008Nfj027]^P00`27
]^P00`000000NZKG07ZVe`0407ZVe`040000001^UL@0KYG40;0G7P<0KYG400<000000664/01QQ;00
101QQ;000`000000Dg:L05=bW00305=bW00300000016HHL0AV670080AV670P00000403Q?L0050000
000X>5@0:3QD0000000G8SL00P0000040?[`iP@0/1LN0P3jl>H20;0G7Rd0n_3V1`2`5ah<0?[`iP03
0;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H0<`3jl>H10?ooo`00B@3jl>H00`2`5ah0n_3V
0?[`iP0_0?[`iP030;0G7P3jl>H0n_3V02T0n_3V102`5ah30?[`iP030;0G7P3jl>H000000080OJkA
0P0000000`2Jd_h0000009cBo`0309cBo`030000002Ca_T000000080000000<0TlKi00000027]^P0
1027]^P00`000000NZKG07ZVe`0407ZVe`030000001^UL@0/1LN0080/1LN0P1^UL@00`000000HHB`
0664/0040664/0030000001CLY`0Dg:L00<0Dg:L00<0000004IQQ`0000000P0000000`16HHL00000
03Q?L00303Q?L0070000000X>5@000000000000G8SL000000?[`iP040;0G7PH0n_3V00<0/1LN0?[`
iP3jl>H0;@3jl>H50;0G7RD0n_3V00<0/1LN0?[`iP3jl>H0=03jl>H10?ooo`00B@3jl>H00`2`5ah0
n_3V0?[`iP0`0?[`iP050;0G7P3jl>H0/1LN0?[`iP2`5ah0:P3jl>H40;0G7P040?[`iP000000OJkA
07f^d@80000000<0V];n0000002Ld_l00`2Ld_l00`000000TlKi09?6n@0209?6n@@000000`27]^P0
0`000000NZKG07ZVe`0407ZVe`040000001^UL@0KYG40;0G7P<0KYG400<000000664/01QQ;00101Q
Q;0010000000Dg:L05=bW01CLY`4000000@0AV6700<0000003Q?L00hCg000P0hCg020000000502Ph
E00000005b8g0000002`5ah04`3jl>H00`2`5ah0n_3V0?[`iP0S0?[`iP80/1LN0P3jl>H20;0G7RD0
n_3V00<0/1LN0?[`iP3jl>H0=03jl>H10?ooo`00BP3jl>H20;0G7S40n_3V1P2`5ahR0?[`iP80/1LN
1P3jl>H30;0G7P050000001m[]40OJkA0000002Jd_h00P00000409cBo`030000002Ca_T0TlKi00<0
TlKi00<0000008Nfj027]^P01`00000307ZVe`030000001^UL@0KYG400@0KYG400@000000664/01Q
Q;00HHB`1`00000205=bW00300000016HHL0AV6700<0AV6700<0000003Q?L00hCg000P0hCg001P00
0000:3QD02PhE00000005b8g00000180n_3V0`2`5ahS0?[`iP80/1LN0P3jl>H00`2`5ah0n_3V0;0G
7P090?[`iP030;0G7P3jl>H0n_3V01X0n_3V00<0/1LN0?[`iP3jl>H0=03jl>H10?ooo`00BP3jl>H3
0;0G7S40n_3V0P2`5ah0103jl>H0/1LN0?[`iP2`5ahS0?[`iP<0/1LN0`3jl>H40;0G7P030000001m
[]4000000080V];n0P00000309cBo`030000002Ca_T0TlKi00<0TlKi00<0000008Nfj027]^P00`27
]^P010000000NZKG07ZVe`1jY]L>000000<0HHB`00<0000005=bW01CLY`00`1CLY`00`000000AV67
04IQQ`0304IQQ`030000000hCg00>4m`00<000000P0X>5@2000001@0n_3V0`2`5ahP0?[`iP80/1LN
1@3jl>H00`2`5ah0n_3V0?[`iP070?[`iP040;0G7P3jl>H0/1LN0;0G7QT0n_3V00<0/1LN0?[`iP3j
l>H05@3jl>H20;0G7Qh0n_3V0@3oool004P0n_3V102`5ah00`3jl>H0/1LN0?[`iP0^0?[`iPL0/1LN
9P3jl>H50;0G7P050?[`iP2`5ah0000007f^d@0000000P2Jd_h01P000000W=;o000000000000W=;o
000000D0TlKi00<0000008Nfj027]^P00`27]^P00`000000NZKG07ZVe`0407ZVe`030000001^UL@0
KYG400@0KYG400<000000664/01QQ;00101QQ;000`000000Dg:L05=bW00305=bW00300000016HHL0
AV6700<0AV670`00000203Q?L0030000000X>5@0:3QD008000004`3jl>H00`2`5ah0n_3V0;0G7P0O
0?[`iP80/1LN403jl>H60;0G7QP0n_3V00<0/1LN0?[`iP3jl>H0503jl>H00`2`5ah0n_3V0;0G7P03
0;0G7Q/0n_3V0@3oool004L0n_3V00<0/1LN0?[`iP3jl>H00P2`5ah20?[`iP030;0G7P3jl>H0n_3V
02d0n_3V1@2`5ahZ0?[`iP<0/1LN00@0n_3V0;0G7P00000000000P2Jd_h010000000W=;o09cBo`2L
d_l3000000@0TlKi00<0000008Nfj027]^P00`27]^P00`000000NZKG07ZVe`0407ZVe`030000001^
UL@0KYG400@0KYG400<000000664/01QQ;00101QQ;000`000000Dg:L05=bW00305=bW00300000016
HHL0AV670080AV670P00000403Q?L0040000000X>5@0:3QD000001<0n_3V00<0/1LN0?[`iP3jl>H0
7P3jl>H20;0G7Q40n_3V0P2`5ah00`3jl>H0/1LN0?[`iP020;0G7QL0n_3V00<0/1LN0?[`iP3jl>H0
503jl>H00`2`5ah0n_3V0?[`iP040;0G7Q/0n_3V0@3oool004H0n_3V00D0/1LN0?[`iP3jl>H0n_3V
0;0G7P040?[`iP030;0G7P3jl>H0n_3V02d0n_3V102`5ah]0?[`iP<0/1LN00@0000009[BoP2Jd_h0
0000102Ld_l00`000000TlKi000000020000000309?6n@000000QkKX00@0QkKX00<0000007ZVe`1j
Y]L0101jY]L00`000000KYG406jEa00406jEa0030000001QQ;00HHB`00@0HHB`00<0000005=bW01C
LY`00`1CLY`00`000000AV67000000020000000304IQQ`000000>4m`00<0>4m`00@0000002PhE00X
>5@000004`3jl>H00`2`5ah0n_3V0?[`iP0L0?[`iP80/1LN503jl>H0102`5ah0n_3V0;0G7P2`5ah2
0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H40;0G7P050?[`iP2`5ah0
/1LN0?[`iP2`5ah06P3jl>H10?ooo`00A`3jl>H0102`5ah0n_3V0?[`iP2`5ah20?[`iP80/1LN<03j
l>H30;0G7Rh0n_3V102`5ah00`000000V];n0000000409cBo`030000002Ca_T0TlKi0080TlKi0`00
000408Nfj0030000001jY]L0NZKG00@0NZKG00<0000006jEa01^UL@0101^UL@00`000000HHB`0664
/0040664/0030000001CLY`0Dg:L0080Dg:L0`00000404IQQ`030000000hCg00>4m`0080>4m`00<0
000002PhE00000004`3jl>H00`2`5ah0n_3V0?[`iP0K0?[`iP80/1LN5`3jl>H50;0G7R`0n_3V0P2`
5ah30?[`iP030;0G7P3jl>H0/1LN0080/1LN6P3jl>H10?ooo`00B03jl>H60;0G7S00n_3V102`5ah_
0?[`iP80/1LN0P3jl>H2000000@0W=;o00<0000009?6n@2Ca_T00`2Ca_T00`000000QkKX00000002
0000000308Nfj0000000NZKG00D0NZKG00<0000006jEa01^UL@0101^UL@00`000000HHB`0664/004
0664/0030000001CLY`000000080000000<0Dg:L00000016HHL01016HHL00`000000>4m`03Q?L002
03Q?L0800000903jl>H00`2`5ah0n_3V0?[`iP0:0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00@0/1LN
0?[`iP3jl>H0/1LN;`3jl>H0102`5ah0n_3V0?[`iP3jl>H20;0G7P80n_3V0P2`5ahI0?[`iP40oooo
00190?[`iP<0/1LN<@3jl>H01P2`5ah0n_3V0?[`iP2`5ah0n_3V0;0G7Rl0n_3V00D0/1LN0?[`iP3j
l>H0n_3V0000000409cBo`030000002Ca_T0TlKi00<0TlKi00<0000008Nfj027]^P00P27]^P50000
00<0NZKG00<0000006jEa01^UL@0101^UL@010000000HHB`0664/01QQ;05000000@0Dg:L00<00000
04IQQ`16HHL00`16HHL00`000000>4m`03Q?L00203Q?L0030000003jl>H0n_3V0280n_3V102`5ahR
0?[`iP030;0G7P3jl>H0n_3V0380n_3V00D0/1LN0?[`iP2`5ah0n_3V0;0G7P030?[`iP030;0G7P3j
l>H0n_3V01L0n_3V0@3oool004X0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP0L
0?[`iP@0/1LN1P3jl>H20;0G7RT0n_3V0P2`5ah20?[`iP8000000P2Ld_l00`000000TlKi09?6n@03
09?6n@0300000027]^P0QkKX00<0QkKX00@0000007ZVe`1jY]L0NZKG3P0000030664/0030000001C
LY`0Dg:L00<0Dg:L00<0000004IQQ`16HHL00`16HHL00`000000>4m`03Q?L002000002@0n_3V1`2`
5ahP0?[`iP030;0G7P3jl>H0n_3V03<0n_3V00D0/1LN0?[`iP3jl>H0/1LN0?[`iP020;0G7QX0n_3V
0@3oool00600n_3V00<0/1LN0?[`iP3jl>H0703jl>H20;0G7PT0n_3V0P2`5ahO0?[`iP@0/1LN103j
l>H30;0G7P<0n_3V0`00000509?6n@0300000027]^P0QkKX00<0QkKX00<0000007ZVe`1jY]L0101j
Y]L00`000000KYG406jEa00406jEa0030000001QQ;00HHB`00@0HHB`00<0000005=bW01CLY`0101C
LY`00`000000AV6704IQQ`0204IQQ`<000009P3jl>H60;0G7R00n_3V00<0/1LN0?[`iP3jl>H0<`3j
l>H00`2`5ah0n_3V0;0G7P030;0G7Q`0n_3V0@3oool00600n_3V00<0/1LN0?[`iP3jl>H0:@3jl>H2
0;0G7R40n_3V202`5ah40?[`iP800000102Ca_T00`000000QkKX08Nfj00308Nfj0030000001jY]L0
NZKG00@0NZKG00<0000006jEa01^UL@0101^UL@00`000000HHB`0664/0040664/0030000001CLY`0
Dg:L00@0Dg:L00@0000004IQQ`16HHL0AV670P00000V0?[`iP@0/1LN00<0n_3V0;0G7P2`5ah0803j
l>H00`2`5ah0n_3V0?[`iP0c0?[`iP050;0G7P3jl>H0n_3V0?[`iP2`5ah07P3jl>H10?ooo`00H@3j
l>H00`2`5ah0n_3V0?[`iP0Z0?[`iP80/1LN903jl>H00`2`5ah0n_3V0?[`iP060;0G7P<0000000<0
TlKi00000027]^P01027]^P00`000000NZKG07ZVe`0407ZVe`030000001^UL@0KYG400@0KYG400<0
00000664/01QQ;00101QQ;000`000000Dg:L05=bW00405=bW00400000016HHL0000000000080n_3V
00<0/1LN0?[`iP3jl>H07`3jl>H40;0G7P<0n_3V00<0/1LN0?[`iP2`5ah0803jl>H00`2`5ah0n_3V
0?[`iP0c0?[`iP030;0G7P3jl>H0n_3V0240n_3V0@3oool00640n_3V00<0/1LN0?[`iP3jl>H0;03j
l>H20;0G7PD0n_3V00<0/1LN0?[`iP3jl>H0903jl>H20;0G7P@000000`27]^P00`000000NZKG07ZV
e`0407ZVe`030000001^UL@0KYG400@0KYG400<000000664/01QQ;00101QQ;0010000000Dg:L05=b
W01CLY`5000000<0n_3V0`2`5ahM0?[`iP<0/1LN203jl>H00`2`5ah0n_3V0?[`iP0O0?[`iP030;0G
7P3jl>H0n_3V03<0n_3V00<0/1LN0?[`iP3jl>H08@3jl>H10?ooo`00HP3jl>H00`2`5ah0n_3V0?[`
iP0]0?[`iP80/1LN0P3jl>H0102`5ah0n_3V0;0G7P2`5ahX0?[`iP030;0G7P3jl>H0000000H00000
0`1jY]L00`000000KYG406jEa00406jEa0040000001QQ;00HHB`0664/0L000001@3jl>H50;0G7QX0
n_3V102`5ahE0?[`iP<0/1LN503jl>H00`2`5ah0n_3V0?[`iP0c0?[`iP030;0G7P3jl>H0n_3V0280
n_3V0@3oool00680n_3V00<0/1LN0?[`iP3jl>H0;`3jl>H30;0G7P80n_3V0P2`5ahW0?[`iP@0/1LN
00<0n_3V0;0G7P2`5ah00P3jl>H>000000X0n_3V0P2`5ahM0?[`iP80/1LN5`3jl>H50;0G7S00n_3V
0P2`5ahG0?[`iP030;0G7P3jl>H0n_3V02<0n_3V0@3oool006<0n_3V00<0/1LN0?[`iP2`5ah0;03j
l>H00`2`5ah0n_3V0?[`iP030;0G7P030?[`iP2`5ah0/1LN01/0n_3V102`5ah80?[`iP80/1LN00D0
n_3V0;0G7P2`5ah0n_3V0;0G7P1C0?[`iP040;0G7P3jl>H0/1LN0;0G7Rl0n_3V00<0/1LN0?[`iP2`
5ah00`2`5ahC0?[`iP030;0G7P3jl>H0n_3V02@0n_3V0@3oool006<0n_3V102`5ah/0?[`iP030;0G
7P3jl>H0/1LN00H0/1LN7P3jl>H70;0G7P80n_3V0P2`5ah30?[`iP80/1LND03jl>H40;0G7P030?[`
iP2`5ah0n_3V02`0n_3V202`5ahB0?[`iP030;0G7P3jl>H0n_3V02D0n_3V0@3oool006<0n_3V0`2`
5ah00`3jl>H0/1LN0?[`iP0[0?[`iP040;0G7P3jl>H0/1LN0?[`iP@0/1LN9@3jl>H;0;0G7R/0n_3V
00<0/1LN0?[`iP3jl>H07`3jl>H0102`5ah0n_3V0?[`iP3jl>H20;0G7Rd0n_3V0`2`5ah20?[`iP@0
/1LN4@3jl>H00`2`5ah0n_3V0?[`iP0V0?[`iP40oooo001R0?[`iP040;0G7P3jl>H0/1LN0;0G7P80
n_3V00<0/1LN0?[`iP3jl>H0:P3jl>H00`2`5ah0n_3V0;0G7P020;0G7Rd0n_3V00<0/1LN0?[`iP2`
5ah00`2`5ahZ0?[`iP<0/1LN7@3jl>H20;0G7S@0n_3V00D0/1LN0?[`iP3jl>H0/1LN0?[`iP030;0G
7Q40n_3V00<0/1LN0?[`iP3jl>H09P3jl>H10?ooo`00H@3jl>H20;0G7P80n_3V0`2`5ah^0?[`iP04
0;0G7P3jl>H0n_3V0;0G7Rd0n_3V102`5ah/0?[`iP030;0G7P3jl>H0/1LN0080/1LN6P3jl>H00`2`
5ah0n_3V0?[`iP0e0?[`iP80/1LN00D0n_3V0;0G7P3jl>H0n_3V0;0G7P0@0?[`iP030;0G7P3jl>H0
n_3V02L0n_3V0@3oool00680n_3V1P2`5ah_0?[`iP@0/1LN;03jl>H20;0G7Rh0n_3V1P2`5ahG0?[`
iP80/1LN=`3jl>H0102`5ah0n_3V0;0G7P3jl>H30;0G7Q00n_3V00<0/1LN0?[`iP3jl>H0:03jl>H1
0?ooo`00H`3jl>H0102`5ah0n_3V0;0G7P2`5aha0?[`iP80/1LN00<0n_3V0;0G7P3jl>H0CP3jl>H>
0;0G7P030?[`iP2`5ah0/1LN01L0n_3V00<0/1LN0?[`iP3jl>H0=P3jl>H0102`5ah0n_3V0?[`iP3j
l>H20;0G7Sd0n_3V0@3oool006@0n_3V0P2`5aha0?[`iP@0/1LN:03jl>H30;0G7PH0n_3V00<0/1LN
0?[`iP3jl>H05@3jl>H70;0G7P`0n_3V0`2`5ai@0?[`iP80/1LN@`3jl>H10?ooo`00V03jl>H40;0G
7RX0n_3V202`5ahY0?[`iP030;0G7P3jl>H0n_3V04l0n_3V00<0/1LN0?[`iP3jl>H0@`3jl>H10?oo
o`00L`3jl>H00`2`5ah0n_3V0?[`iP0V0?[`iP@0/1LN3P3jl>H00`2`5ah0n_3V0?[`iP0K0?[`iP<0
/1LN<03jl>H20;0G7TH0n_3V0P2`5ai60?[`iP40oooo001d0?[`iP80/1LN:P3jl>H40;0G7PX0n_3V
0P2`5ahL0?[`iP80/1LN<03jl>H50;0G7Rh0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V
0?[`iP160?[`iP40oooo001f0?[`iP030;0G7P3jl>H0n_3V02/0n_3V1@2`5ah40?[`iP040;0G7P3j
l>H0/1LN0;0G7T`0n_3V1@2`5ah^0?[`iP040;0G7P3jl>H0/1LN0;0G7Q40n_3V00<0/1LN0?[`iP3j
l>H0A`3jl>H10?ooo`00M`3jl>H00`2`5ah0n_3V0?[`iP0_0?[`iPD0/1LN00@0n_3V0;0G7P2`5ah0
/1LN:`3jl>H00`2`5ah0n_3V0?[`iP0I0?[`iP@0/1LN0P3jl>H20;0G7Rl0n_3V00<0/1LN0?[`iP2`
5ah00`2`5ah=0?[`iP80/1LNBP3jl>H10?ooo`00N03jl>H20;0G7S<0n_3V1P2`5ahZ0?[`iP80/1LN
5P3jl>H40;0G7PH0n_3V00<0/1LN0?[`iP3jl>H0;@3jl>H70;0G7P`0n_3V00<0/1LN0?[`iP3jl>H0
BP3jl>H10?ooo`00NP3jl>H01@2`5ah0n_3V0?[`iP3jl>H0/1LN02d0n_3V00@0/1LN0?[`iP2`5ah0
n_3V102`5ahC0?[`iPL0/1LN3`3jl>H40;0G7Q80n_3V0P2`5ahk0?[`iP80/1LN00<0n_3V0;0G7P2`
5ah0FP3jl>H10?ooo`00N`3jl>H30;0G7P030?[`iP2`5ah0/1LN02/0n_3V102`5ah00`3jl>H0/1LN
0;0G7P0K0?[`iQ00/1LN0P3jl>H20;0G7T`0n_3V0`2`5ah20?[`iP80/1LNFP3jl>H10?ooo`00O03j
l>H20;0G7P040?[`iP2`5ah0n_3V0;0G7R80n_3V0P2`5ah70?[`iP@0/1LN:`3jl>H70;0G7TT0n_3V
0P2`5ah30?[`iP030;0G7P3jl>H0/1LN05/0n_3V0@3oool007`0n_3V00@0/1LN0?[`iP2`5ah0n_3V
0P2`5ahT0?[`iP<0/1LN1@3jl>H0102`5ah0n_3V0?[`iP2`5ahZ0?[`iPH0/1LNB03jl>H20;0G7PH0
n_3V00<0/1LN0?[`iP3jl>H0FP3jl>H10?ooo`00N`3jl>H30;0G7P040?[`iP2`5ah0/1LN0;0G7RL0
n_3V0`2`5ah40?[`iP<0/1LN:@3jl>H40;0G7TP0n_3V0P2`5aiU0?[`iP40oooo001l0?[`iPH0/1LN
:P3jl>H50;0G7P030?[`iP2`5ah0n_3V02T0n_3V00<0/1LN0?[`iP3jl>H0AP3jl>H20;0G7VL0n_3V
0@3oool007h0n_3V0P2`5ah_0?[`iPD0/1LN;`3jl>H00`2`5ah0n_3V0?[`iP0n0?[`iP80/1LNJ@3j
l>H10?ooo`00[`3jl>H60;0G7Ph0n_3V00<0/1LN0?[`iP3jl>H07@3jl>H30;0G7Rh0n_3V0P2`5ah<
0?[`iP80/1LNJ`3jl>H10?ooo`00ZP3jl>H40;0G7P80n_3V0`2`5ah@0?[`iP80/1LN3`3jl>HC0;0G
7R`0n_3V0P2`5ah00`3jl>H0/1LN0;0G7P1g0?[`iP40oooo002^0?[`iPP0/1LN3@3jl>H30;0G7Qd0
n_3V0`2`5ah]0?[`iPL0/1LNM@3jl>H10?ooo`00QP3jl>H20;0G7Rh0n_3V202`5ah40?[`iP030;0G
7P3jl>H0/1LN00<0/1LN6`3jl>H00`2`5ah0n_3V0?[`iP0]0?[`iPH0/1LNMP3jl>H10?ooo`00R03j
l>H20;0G7S@0n_3V202`5ah00`3jl>H0/1LN0;0G7P170?[`iP@0/1LN0P3jl>H20;0G7WL0n_3V0@3o
ool008X0n_3V0`2`5ahe0?[`iP80/1LN0P3jl>H40;0G7T<0n_3V0`2`5ah40?[`iP030;0G7P3jl>H0
/1LN07P0n_3V0@3oool008d0n_3V0P2`5ah70?[`iP030;0G7P3jl>H0n_3V02T0n_3V102`5ah00`3j
l>H0/1LN0;0G7P100?[`iP@0/1LN1`3jl>H20;0G7WT0n_3V0@3oool008l0n_3V0`2`5ah40?[`iP80
/1LN:P3jl>H20;0G7P030?[`iP2`5ah0/1LN03h0n_3V102`5ah;0?[`iP030;0G7P3jl>H0n_3V07P0
n_3V0@3oool00980n_3V0P2`5ah01@3jl>H0/1LN0?[`iP3jl>H0/1LN02X0n_3V0P2`5ahn0?[`iP80
/1LNRP3jl>H10?ooo`00U03jl>H30;0G7P030?[`iP2`5ah0/1LN01`0n_3V102`5ah=0?[`iP030;0G
7P3jl>H0n_3V0<D0n_3V0@3oool009@0n_3V00<0/1LN0?[`iP3jl>H00`2`5ahP0?[`iPL0/1LN1P3j
l>H30;0G7/D0n_3V0@3oool009@0n_3V1`2`5ahV0?[`iP/0/1LN;03jl>H00`2`5ah0n_3V0?[`iP2D
0?[`iP40oooo002E0?[`iP80/1LN00<0n_3V0;0G7P2`5ah0;03jl>H00`2`5ah0n_3V0;0G7P040;0G
7R/0n_3V0`2`5ajD0?[`iP40oooo002F0?[`iP80/1LN;P3jl>H60;0G7R`0n_3V00<0/1LN0?[`iP2`
5ah00P2`5ajB0?[`iP40oooo00360?[`iP@0/1LN;@3jl>H70;0G7Y40n_3V0@3oool00<L0n_3V00<0
/1LN0?[`iP3jl>H08@3jl>H<0;0G7P040?[`iP2`5ah0/1LN0?[`iP80/1LNTP3jl>H10?ooo`00i03j
l>H70;0G7Pd0n_3V0`2`5ajD0?[`iP40oooo002H0?[`iP<0/1LNG@3jl>H00`2`5ah0n_3V0?[`iP2D
0?[`iP40oooo002K0?[`iP@0/1LN3P3jl>H00`2`5ah0n_3V0?[`iP3O0?[`iP40oooo002O0?[`iP@0
/1LN2P3jl>H20;0G7^00n_3V0@3oool00:<0n_3V1@2`5ah40?[`iP040;0G7P3jl>H0n_3V0;0G7Rd0
n_3V00<0/1LN0?[`iP3jl>H0[`3jl>H10?ooo`00Z03jl>H50;0G7P80n_3V0P2`5ah/0?[`iP<0/1LN
[`3jl>H10?ooo`00Z`3jl>H50;0G7P030?[`iP2`5ah0n_3V02X0n_3V0P2`5ah00`3jl>H0/1LN0?[`
iP2]0?[`iP40oooo002[0?[`iPP0/1LN4`3jl>H?0;0G7PP0n_3V00<0/1LN0?[`iP2`5ah00`2`5aj/
0?[`iP40oooo002/0?[`iP80/1LN00<0n_3V0;0G7P2`5ah0903jl>H?0;0G7Z/0n_3V0@3oool00:d0
n_3V0P2`5ah^0?[`iP030;0G7P3jl>H0/1LN00<0/1LN[03jl>H10?ooo`00g@3jl>H20;0G7P030?[`
iP2`5ah0n_3V0:d0n_3V0@3oool00=d0n_3V0`2`5aj_0?[`iP40oooo003M0?[`iP030;0G7P3jl>H0
n_3V0:l0n_3V0@3oool00<<0n_3V00<0/1LN0?[`iP3jl>H0b@3jl>H10?ooo`00Z@3jl>H40;0G7QH0
n_3V0P2`5ak:0?[`iP40oooo002]0?[`iPP0/1LN3P3jl>H30;0G7/T0n_3V0@3oool00;D0n_3V202`
5ah60?[`iPD0/1LNa`3jl>H10?ooo`00_@3jl>H80;0G7P040?[`iP2`5ah0/1LN0;0G7/H0n_3V0@3o
ool00<80n_3V00<0/1LN0?[`iP2`5ah01@2`5ak50?[`iP40oooo00320?[`iPL0/1LNaP3jl>H10?oo
o`00`P3jl>H20;0G7P80n_3V00<0/1LN0?[`iP3jl>H0aP3jl>H10?ooo`00`P3jl>H40;0G7/T0n_3V
0@3oool00<<0n_3V00<0/1LN0?[`iP3jl>H0b@3jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`
iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3o
ool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3V
T03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?oo
o`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@
0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {406.75, 0}} -> {0.0256014, -4.59765*^-06, \
0.00226068, 0.00226068}}]
}, Open  ]],

Cell["\<\
You can obtain more control and better vectors by drawing them yourself.\
\>", "Text"],

Cell[BoxData[
    \(\(vectors = \[IndentingNewLine]Table[{xx, yy, zz} = {r\ Cos[\[Theta]], 
              r\ Sin[\[Theta]], z}; 
          Arrow3D[{xx, yy, zz}, , HeadLength3D \[Rule] 0.25, 
            HeadSegments3D \[Rule] 6], {r, 0.3, 1.1, 
            0.2}, {\[Theta], \[Pi]/4, 2  \[Pi], \[Pi]/4}, {z, \(-1\), 1, 
            1}];\)\)], "Input",
  CellLabel->"In[19]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cylindercolor = \(ColorMix[SteelBlue, LightSteelBlue]\)[
          0.3];\)\), "\n", 
    \(\(plot1 = \
\[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{SurfaceColor[
              cylindercolor, cylindercolor, 
              2], \[IndentingNewLine]ParametricDraw3D[
              0.3 {Cos[\[Theta]], Sin[\[Theta]], z/0.3}, {\[Theta], 0, 
                2  \[Pi]}, {z, \(-1\), 1}], \[IndentingNewLine]IndianRed, 
            SurfaceColor[
              DarkGreen], \[IndentingNewLine]vectors}, \
\[IndentingNewLine]NeutralLighting[0.3, 0.5, 
            0.1], \[IndentingNewLine]Background \[Rule] 
            Linen, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)}], "Input",
  CellLabel->"In[20]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03653 
%%ImageSize: 400 414.612 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-0.0358401 1.12375 1.77647e-016 1.12375 [
[ 0 0 0 0 ]
[ 1 1.03653 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.03653 L
0 1.03653 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.207 .628 .383 r
.57582 .54072 m .54398 .532 L .54285 .53985 L closepath p F P
0 0 0 r
s
.247 .764 .548 r
.57582 .54072 m .54632 .52737 L .54398 .532 L closepath p F P
0 0 0 r
s
.048 .276 .063 r
.57582 .54072 m .54753 .53061 L .54632 .52737 L closepath p F P
0 0 0 r
s
.275 .748 .487 r
.57582 .54072 m .54639 .5385 L .54753 .53061 L closepath p F P
0 0 0 r
s
.031 .242 .042 r
.57582 .54072 m .54285 .53985 L .54404 .54312 L closepath p F P
0 0 0 r
s
.328 .938 .686 r
.57582 .54072 m .54404 .54312 L .54639 .5385 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.45206 .51859 m
.54682 .53553 L
s
.244 .671 .372 r
.35895 .51185 m .33574 .49309 L .33534 .49958 L closepath p F P
0 0 0 r
s
.014 .333 .037 r
.35895 .51185 m .33534 .49958 L .34119 .50075 L closepath p F P
0 0 0 r
s
.318 .857 .61 r
.35895 .51185 m .34197 .48777 L .33574 .49309 L closepath p F P
0 0 0 r
s
.134 .546 .34 r
.35895 .51185 m .34782 .48891 L .34197 .48777 L closepath p F P
0 0 0 r
s
.174 .611 .255 r
.35895 .51185 m .34744 .49541 L .34782 .48891 L closepath p F P
0 0 0 r
s
.378 1 .729 r
.35895 .51185 m .34119 .50075 L .34744 .49541 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.28729 .4392 m
.34488 .49759 L
s
.207 .628 .383 r
.56752 .50946 m .54099 .50219 L .54004 .50872 L closepath p F P
0 0 0 r
s
.247 .764 .548 r
.56752 .50946 m .54293 .49826 L .54099 .50219 L closepath p F P
0 0 0 r
s
.276 .749 .488 r
.56752 .50946 m .54298 .50745 L .54393 .50088 L closepath p F P
0 0 0 r
s
.028 .231 .036 r
.56752 .50946 m .54004 .50872 L .54103 .51136 L closepath p F P
0 0 0 r
s
.328 .938 .686 r
.56752 .50946 m .54103 .51136 L .54298 .50745 L closepath p F P
0 0 0 r
s
.042 .263 .055 r
.56752 .50946 m .54393 .50088 L .54293 .49826 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.46453 .49072 m
.54332 .50505 L
s
.242 .667 .366 r
.38721 .48503 m .36814 .46929 L .36787 .47463 L closepath p F P
0 0 0 r
s
.021 .351 .055 r
.38721 .48503 m .36787 .47463 L .37278 .47555 L closepath p F P
0 0 0 r
s
.32 .859 .613 r
.38721 .48503 m .37331 .46487 L .36814 .46929 L closepath p F P
0 0 0 r
s
.136 .55 .344 r
.38721 .48503 m .37822 .46578 L .37331 .46487 L closepath p F P
0 0 0 r
s
.157 .586 .23 r
.38721 .48503 m .37796 .47112 L .37822 .46578 L closepath p F P
0 0 0 r
s
.379 1 .729 r
.38721 .48503 m .37278 .47555 L .37796 .47112 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.32907 .42417 m
.37574 .47302 L
s
.031 .286 .065 r
.77088 .46715 m .74301 .4777 L .74348 .48421 L closepath p F P
0 0 0 r
s
.191 .634 .42 r
.77088 .46715 m .73984 .47052 L .74301 .4777 L closepath p F P
0 0 0 r
s
0 .361 0 r
.77088 .46715 m .73712 .46983 L .73984 .47052 L closepath p F P
0 0 0 r
s
.123 .674 .263 r
.77088 .46715 m .74348 .48421 L .74076 .48356 L closepath p F P
0 0 0 r
s
.207 .627 .382 r
.5589 .47702 m .53788 .47126 L .53713 .47643 L closepath p F P
0 0 0 r
s
.247 .764 .548 r
.5589 .47702 m .53941 .4681 L .53788 .47126 L closepath p F P
0 0 0 r
s
.276 .751 .489 r
.5589 .47702 m .53944 .4753 L .54019 .47011 L closepath p F P
0 0 0 r
s
.024 .219 .031 r
.5589 .47702 m .53713 .47643 L .53791 .47845 L closepath p F P
0 0 0 r
s
.328 .937 .686 r
.5589 .47702 m .53791 .47845 L .53944 .4753 L closepath p F P
0 0 0 r
s
.036 .25 .047 r
.5589 .47702 m .54019 .47011 L .53941 .4681 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.47741 .46193 m
.53971 .47347 L
s
.082 .384 .143 r
.77088 .46715 m .73757 .47636 L .73712 .46983 L closepath p F P
0 0 0 r
s
.25 .73 .5 r
.77088 .46715 m .74076 .48356 L .73757 .47636 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.65057 .50602 m
.73817 .47772 L
s
.028 .278 .059 r
.72858 .44748 m .7058 .45636 L .70612 .46172 L closepath p F P
0 0 0 r
s
.191 .633 .42 r
.72858 .44748 m .70314 .4504 L .7058 .45636 L closepath p F P
0 0 0 r
s
.001 .368 .003 r
.72858 .44748 m .70078 .44977 L .70314 .4504 L closepath p F P
0 0 0 r
s
.141 .703 .299 r
.72858 .44748 m .70612 .46172 L .70377 .46112 L closepath p F P
0 0 0 r
s
.239 .661 .359 r
.41637 .45737 m .40147 .4448 L .4013 .44898 L closepath p F P
0 0 0 r
s
.029 .37 .075 r
.41637 .45737 m .4013 .44898 L .40522 .44967 L closepath p F P
0 0 0 r
s
.321 .862 .615 r
.41637 .45737 m .40555 .44131 L .40147 .4448 L closepath p F P
0 0 0 r
s
.138 .553 .347 r
.41637 .45737 m .40947 .442 L .40555 .44131 L closepath p F P
0 0 0 r
s
.138 .558 .202 r
.41637 .45737 m .40931 .44618 L .40947 .442 L closepath p F P
0 0 0 r
s
.379 1 .73 r
.41637 .45737 m .40522 .44967 L .40931 .44618 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.37155 .40888 m
.40747 .44775 L
s
.08 .378 .138 r
.72858 .44748 m .70109 .45514 L .70078 .44977 L closepath p F P
0 0 0 r
s
.25 .731 .501 r
.72858 .44748 m .70377 .46112 L .70109 .45514 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.62944 .48012 m
.70163 .45635 L
s
.207 .627 .382 r
.54996 .44336 m .53466 .43916 L .53411 .44291 L closepath p F P
0 0 0 r
s
.247 .764 .548 r
.54996 .44336 m .53577 .43682 L .53466 .43916 L closepath p F P
0 0 0 r
s
.277 .752 .49 r
.54996 .44336 m .53578 .442 L .53633 .43823 L closepath p F P
0 0 0 r
s
.02 .207 .026 r
.54996 .44336 m .53411 .44291 L .53467 .44434 L closepath p F P
0 0 0 r
s
.329 .937 .686 r
.54996 .44336 m .53467 .44434 L .53578 .442 L closepath p F P
0 0 0 r
s
.029 .236 .039 r
.54996 .44336 m .53633 .43823 L .53577 .43682 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.49073 .43219 m
.53597 .44072 L
s
.024 .27 .053 r
.68533 .42737 m .66764 .43448 L .66783 .43867 L closepath p F P
0 0 0 r
s
.19 .633 .419 r
.68533 .42737 m .66551 .42977 L .66764 .43448 L closepath p F P
0 0 0 r
s
.004 .377 .008 r
.68533 .42737 m .66358 .42923 L .66551 .42977 L closepath p F P
0 0 0 r
s
.158 .731 .334 r
.68533 .42737 m .66783 .43867 L .6659 .43815 L closepath p F P
0 0 0 r
s
.077 .373 .132 r
.68533 .42737 m .66377 .43342 L .66358 .42923 L closepath p F P
0 0 0 r
s
.207 .627 .382 r
.579 .73927 m .54512 .73001 L .54392 .73845 L closepath p F P
0 0 0 r
s
.24 .759 .542 r
.579 .73927 m .54761 .72565 L .54512 .73001 L closepath p F P
0 0 0 r
s
.065 .312 .086 r
.579 .73927 m .54891 .72976 L .54761 .72565 L closepath p F P
0 0 0 r
s
.278 .753 .49 r
.579 .73927 m .5477 .73826 L .54891 .72976 L closepath p F P
0 0 0 r
s
.04 .266 .054 r
.579 .73927 m .54392 .73845 L .5452 .7426 L closepath p F P
0 0 0 r
s
.313 .931 .663 r
.579 .73927 m .5452 .7426 L .5477 .73826 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.44728 .71845 m
.54825 .73441 L
s
.251 .732 .502 r
.68533 .42737 m .6659 .43815 L .66377 .43342 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.60768 .45343 m
.66423 .43445 L
s
.235 .655 .351 r
.44645 .42882 m .43577 .41961 L .43568 .42261 L closepath p F P
0 0 0 r
s
.038 .389 .098 r
.44645 .42882 m .43568 .42261 L .43855 .42308 L closepath p F P
0 0 0 r
s
.322 .864 .618 r
.44645 .42882 m .43873 .41708 L .43577 .41961 L closepath p F P
0 0 0 r
s
.14 .557 .351 r
.44645 .42882 m .4416 .41754 L .43873 .41708 L closepath p F P
0 0 0 r
s
.118 .528 .173 r
.44645 .42882 m .44152 .42055 L .4416 .41754 L closepath p F P
0 0 0 r
s
.379 1 .73 r
.44645 .42882 m .43855 .42308 L .44152 .42055 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.41475 .39333 m
.44012 .42174 L
s
.021 .262 .046 r
.64111 .4068 m .62849 .41203 L .62859 .41504 L closepath p F P
0 0 0 r
s
.19 .632 .419 r
.64111 .4068 m .62693 .40861 L .62849 .41203 L closepath p F P
0 0 0 r
s
.007 .388 .016 r
.64111 .4068 m .62547 .40819 L .62693 .40861 L closepath p F P
0 0 0 r
s
.174 .757 .368 r
.64111 .4068 m .62859 .41504 L .62713 .41463 L closepath p F P
0 0 0 r
s
.074 .367 .127 r
.64111 .4068 m .62557 .4112 L .62547 .40819 L closepath p F P
0 0 0 r
s
.251 .732 .502 r
.64111 .4068 m .62713 .41463 L .62557 .4112 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.58525 .42591 m
.62593 .41199 L
s
.206 .626 .381 r
.54067 .40838 m .53131 .40581 L .53097 .4081 L closepath p F P
0 0 0 r
s
.247 .764 .547 r
.54067 .40838 m .53198 .40435 L .53131 .40581 L closepath p F P
0 0 0 r
s
.023 .221 .031 r
.54067 .40838 m .53232 .40519 L .53198 .40435 L closepath p F P
0 0 0 r
s
.278 .754 .491 r
.54067 .40838 m .53199 .40748 L .53232 .40519 L closepath p F P
0 0 0 r
s
.016 .194 .021 r
.54067 .40838 m .53097 .4081 L .53131 .40894 L closepath p F P
0 0 0 r
s
.329 .937 .686 r
.54067 .40838 m .53131 .40894 L .53199 .40748 L closepath p F P
0 0 0 r
s
.481 .649 .84 r
.50242 .4144 m .5185 .41657 L .51854 .40322 L p F P
0 0 0 r
s
.69 .09 .12 r
.51854 .40413 m
.5321 .40673 L
s
.481 .649 .84 r
.51854 .40322 m .50253 .40104 L .50242 .4144 L p F P
0 0 0 r
s
.431 .584 .767 r
.53487 .40312 m .51854 .40322 L .5185 .41657 L p F P
0 0 0 r
s
.431 .584 .767 r
.5185 .41657 m .53491 .41648 L .53487 .40312 L p F P
0 0 0 r
s
.38 .517 .692 r
.55082 .40076 m .53487 .40312 L .53491 .41648 L p F P
0 0 0 r
s
.53 .714 .91 r
.48736 .41004 m .50242 .4144 L .50253 .40104 L p F P
0 0 0 r
s
.53 .714 .91 r
.50253 .40104 m .48754 .39667 L .48736 .41004 L p F P
0 0 0 r
s
.38 .517 .692 r
.53491 .41648 m .55093 .41412 L .55082 .40076 L p F P
0 0 0 r
s
.328 .45 .612 r
.5657 .39621 m .55082 .40076 L .55093 .41412 L p F P
0 0 0 r
s
.244 .671 .372 r
.3481 .71211 m .32329 .6938 L .32283 .70117 L closepath p F P
0 0 0 r
s
0 .251 0 r
.3481 .71211 m .32283 .70117 L .32903 .7029 L closepath p F P
0 0 0 r
s
.327 .876 .628 r
.3481 .71211 m .32992 .68816 L .32329 .6938 L closepath p F P
0 0 0 r
s
.109 .493 .282 r
.3481 .71211 m .33612 .68986 L .32992 .68816 L closepath p F P
0 0 0 r
s
.174 .611 .255 r
.3481 .71211 m .33569 .69724 L .33612 .68986 L closepath p F P
0 0 0 r
s
.377 1 .728 r
.3481 .71211 m .32903 .7029 L .33569 .69724 L closepath p F P
0 0 0 r
s
.231 .648 .343 r
.47751 .39934 m .47107 .39367 L .47104 .39548 L closepath p F P
0 0 0 r
s
.047 .409 .121 r
.47751 .39934 m .47104 .39548 L .47281 .39575 L closepath p F P
0 0 0 r
s
.323 .867 .62 r
.47751 .39934 m .47288 .39213 L .47107 .39367 L closepath p F P
0 0 0 r
s
.141 .56 .355 r
.47751 .39934 m .47465 .39239 L .47288 .39213 L closepath p F P
0 0 0 r
s
.097 .497 .142 r
.47751 .39934 m .47462 .39421 L .47465 .39239 L closepath p F P
0 0 0 r
s
.379 1 .73 r
.47751 .39934 m .47281 .39575 L .47462 .39421 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.27109 .64349 m
.3335 .6991 L
s
.576 .776 .973 r
.47399 .40367 m .48736 .41004 L .48754 .39667 L p F P
0 0 0 r
s
.576 .776 .973 r
.48754 .39667 m .47422 .39028 L .47399 .40367 L p F P
0 0 0 r
s
.207 .627 .381 r
.57022 .70985 m .54196 .70212 L .54095 .70916 L closepath p F P
0 0 0 r
s
.24 .759 .542 r
.57022 .70985 m .54403 .69842 L .54196 .70212 L closepath p F P
0 0 0 r
s
.278 .754 .491 r
.57022 .70985 m .54408 .70884 L .54509 .70177 L closepath p F P
0 0 0 r
s
.037 .257 .049 r
.57022 .70985 m .54095 .70916 L .54201 .71253 L closepath p F P
0 0 0 r
s
.313 .931 .664 r
.57022 .70985 m .54201 .71253 L .54408 .70884 L closepath p F P
0 0 0 r
s
.06 .302 .08 r
.57022 .70985 m .54509 .70177 L .54403 .69842 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.46049 .69219 m
.54453 .70572 L
s
.328 .45 .612 r
.55093 .41412 m .56588 .40959 L .5657 .39621 L p F P
0 0 0 r
s
.275 .382 .53 r
.57885 .38967 m .5657 .39621 L .56588 .40959 L p F P
0 0 0 r
s
.481 .649 .84 r
.50232 .42788 m .51847 .43005 L .5185 .41657 L p F P
0 0 0 r
s
.481 .649 .84 r
.5185 .41657 m .50242 .4144 L .50232 .42788 L p F P
0 0 0 r
s
.431 .584 .767 r
.53491 .41648 m .5185 .41657 L .51847 .43005 L p F P
0 0 0 r
s
.431 .584 .767 r
.51847 .43005 m .53495 .42996 L .53491 .41648 L p F P
0 0 0 r
s
.38 .517 .692 r
.55093 .41412 m .53491 .41648 L .53495 .42996 L p F P
0 0 0 r
s
.53 .714 .91 r
.48719 .42354 m .50232 .42788 L .50242 .4144 L p F P
0 0 0 r
s
.53 .714 .91 r
.50242 .4144 m .48736 .41004 L .48719 .42354 L p F P
0 0 0 r
s
.38 .517 .692 r
.53495 .42996 m .55104 .4276 L .55093 .41412 L p F P
0 0 0 r
s
.328 .45 .612 r
.56588 .40959 m .55093 .41412 L .55104 .4276 L p F P
0 0 0 r
s
.018 .253 .04 r
.59587 .38577 m .58831 .389 L .58835 .39081 L closepath p F P
0 0 0 r
s
.189 .631 .418 r
.59587 .38577 m .58735 .38691 L .58831 .389 L closepath p F P
0 0 0 r
s
.61 .825 1 r
.4629 .39556 m .47399 .40367 L .47422 .39028 L p F P
0 0 0 r
s
.61 .825 1 r
.47422 .39028 m .46319 .38214 L .4629 .39556 L p F P
0 0 0 r
s
.011 .4 .027 r
.59587 .38577 m .58643 .38664 L .58735 .38691 L closepath p F P
0 0 0 r
s
.275 .382 .53 r
.56588 .40959 m .57909 .40307 L .57885 .38967 L p F P
0 0 0 r
s
.071 .361 .122 r
.59587 .38577 m .58646 .38845 L .58643 .38664 L closepath p F P
0 0 0 r
s
.223 .312 .442 r
.58967 .38141 m .57885 .38967 L .57909 .40307 L p F P
0 0 0 r
s
.19 .782 .4 r
.59587 .38577 m .58835 .39081 L .58743 .39054 L closepath p F P
0 0 0 r
s
.057 .352 .15 r
.21882 .38931 m .23394 .36892 L .23017 .36232 L closepath p F P
0 0 0 r
s
0 .411 0 r
.21882 .38931 m .229 .37388 L .23394 .36892 L closepath p F P
0 0 0 r
s
.321 .932 .558 r
.21882 .38931 m .22146 .36066 L .2165 .3656 L closepath p F P
0 0 0 r
s
.3 .847 .618 r
.21882 .38931 m .23017 .36232 L .22146 .36066 L closepath p F P
0 0 0 r
s
.246 .804 .559 r
.21882 .38931 m .22026 .37222 L .229 .37388 L closepath p F P
0 0 0 r
s
.006 .172 .016 r
.21882 .38931 m .2165 .3656 L .22026 .37222 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.2236 .37286 m
.2454 .29787 L
s
.576 .776 .973 r
.47375 .41719 m .48719 .42354 L .48736 .41004 L p F P
0 0 0 r
s
.576 .776 .973 r
.48736 .41004 m .47399 .40367 L .47375 .41719 L p F P
0 0 0 r
s
.328 .45 .612 r
.55104 .4276 m .56606 .42308 L .56588 .40959 L p F P
0 0 0 r
s
.275 .382 .53 r
.57909 .40307 m .56588 .40959 L .56606 .42308 L p F P
0 0 0 r
s
.251 .733 .503 r
.59587 .38577 m .58743 .39054 L .58646 .38845 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.58583 .38927 m
.5867 .38896 L
s
.481 .649 .84 r
.50221 .44149 m .51844 .44365 L .51847 .43005 L p F P
0 0 0 r
s
.481 .649 .84 r
.51847 .43005 m .50232 .42788 L .50221 .44149 L p F P
0 0 0 r
s
.431 .584 .767 r
.53495 .42996 m .51847 .43005 L .51844 .44365 L p F P
0 0 0 r
s
.431 .584 .767 r
.51844 .44365 m .53499 .44355 L .53495 .42996 L p F P
0 0 0 r
s
.38 .517 .692 r
.55104 .4276 m .53495 .42996 L .53499 .44355 L p F P
0 0 0 r
s
.53 .714 .91 r
.48701 .43715 m .50221 .44149 L .50232 .42788 L p F P
0 0 0 r
s
.53 .714 .91 r
.50232 .42788 m .48719 .42354 L .48701 .43715 L p F P
0 0 0 r
s
.38 .517 .692 r
.53499 .44355 m .55116 .44121 L .55104 .4276 L p F P
0 0 0 r
s
.328 .45 .612 r
.56606 .42308 m .55104 .4276 L .55116 .44121 L p F P
0 0 0 r
s
.059 .359 .155 r
.2738 .38286 m .28669 .3661 L .28353 .36069 L closepath p F P
0 0 0 r
s
0 .399 0 r
.2738 .38286 m .28275 .37016 L .28669 .3661 L closepath p F P
0 0 0 r
s
.3 .847 .618 r
.2738 .38286 m .28353 .36069 L .27644 .35933 L closepath p F P
0 0 0 r
s
.246 .805 .56 r
.2738 .38286 m .27563 .3688 L .28275 .37016 L closepath p F P
0 0 0 r
s
.307 .915 .532 r
.2738 .38286 m .27644 .35933 L .27248 .36338 L closepath p F P
0 0 0 r
s
.01 .19 .027 r
.2738 .38286 m .27248 .36338 L .27563 .3688 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.27814 .36928 m
.29764 .30818 L
s
.604 .823 .997 r
.45464 .38603 m .4629 .39556 L .46319 .38214 L p F P
0 0 0 r
s
.604 .823 .997 r
.46319 .38214 m .45496 .37259 L .45464 .38603 L p F P
0 0 0 r
s
.61 .825 1 r
.46262 .40909 m .47375 .41719 L .47399 .40367 L p F P
0 0 0 r
s
.61 .825 1 r
.47399 .40367 m .4629 .39556 L .46262 .40909 L p F P
0 0 0 r
s
.223 .312 .442 r
.57909 .40307 m .58996 .39482 L .58967 .38141 L p F P
0 0 0 r
s
.159 .222 .331 r
.59765 .37176 m .58967 .38141 L .58996 .39482 L p F P
0 0 0 r
s
.275 .382 .53 r
.56606 .42308 m .57933 .41658 L .57909 .40307 L p F P
0 0 0 r
s
.223 .312 .442 r
.58996 .39482 m .57909 .40307 L .57933 .41658 L p F P
0 0 0 r
s
.576 .776 .973 r
.47351 .43082 m .48701 .43715 L .48719 .42354 L p F P
0 0 0 r
s
.576 .776 .973 r
.48719 .42354 m .47375 .41719 L .47351 .43082 L p F P
0 0 0 r
s
.328 .45 .612 r
.55116 .44121 m .56624 .4367 L .56606 .42308 L p F P
0 0 0 r
s
.275 .382 .53 r
.57933 .41658 m .56606 .42308 L .56624 .4367 L p F P
0 0 0 r
s
.481 .649 .84 r
.5021 .45522 m .5184 .45737 L .51844 .44365 L p F P
0 0 0 r
s
.481 .649 .84 r
.51844 .44365 m .50221 .44149 L .5021 .45522 L p F P
0 0 0 r
s
.431 .584 .767 r
.53499 .44355 m .51844 .44365 L .5184 .45737 L p F P
0 0 0 r
s
.431 .584 .767 r
.5184 .45737 m .53503 .45728 L .53499 .44355 L p F P
0 0 0 r
s
.38 .517 .692 r
.55116 .44121 m .53499 .44355 L .53503 .45728 L p F P
0 0 0 r
s
.291 .894 .503 r
.32917 .37637 m .33159 .358 L .32859 .36114 L closepath p F P
0 0 0 r
s
.3 .848 .618 r
.32917 .37637 m .33708 .35906 L .33159 .358 L closepath p F P
0 0 0 r
s
.062 .364 .16 r
.32917 .37637 m .3396 .36327 L .33708 .35906 L closepath p F P
0 0 0 r
s
0 .385 0 r
.32917 .37637 m .33661 .36642 L .3396 .36327 L closepath p F P
0 0 0 r
s
.247 .806 .561 r
.32917 .37637 m .3311 .36536 L .33661 .36642 L closepath p F P
0 0 0 r
s
.014 .209 .039 r
.32917 .37637 m .32859 .36114 L .3311 .36536 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.33288 .3657 m
.34933 .31839 L
s
.53 .714 .91 r
.48683 .4509 m .5021 .45522 L .50221 .44149 L p F P
0 0 0 r
s
.53 .714 .91 r
.50221 .44149 m .48701 .43715 L .48683 .4509 L p F P
0 0 0 r
s
.38 .517 .692 r
.53503 .45728 m .55127 .45494 L .55116 .44121 L p F P
0 0 0 r
s
.328 .45 .612 r
.56624 .4367 m .55116 .44121 L .55127 .45494 L p F P
0 0 0 r
s
.604 .823 .997 r
.45431 .3996 m .46262 .40909 L .4629 .39556 L p F P
0 0 0 r
s
.604 .823 .997 r
.4629 .39556 m .45464 .38603 L .45431 .3996 L p F P
0 0 0 r
s
.61 .825 1 r
.46233 .42275 m .47351 .43082 L .47375 .41719 L p F P
0 0 0 r
s
.61 .825 1 r
.47375 .41719 m .46262 .40909 L .46233 .42275 L p F P
0 0 0 r
s
.223 .312 .442 r
.57933 .41658 m .59025 .40836 L .58996 .39482 L p F P
0 0 0 r
s
.159 .222 .331 r
.59797 .3852 m .58996 .39482 L .59025 .40836 L p F P
0 0 0 r
s
.159 .222 .331 r
.58996 .39482 m .59797 .3852 L .59765 .37176 L p F P
0 0 0 r
s
.275 .382 .53 r
.56624 .4367 m .57957 .43022 L .57933 .41658 L p F P
0 0 0 r
s
.223 .312 .442 r
.59025 .40836 m .57933 .41658 L .57957 .43022 L p F P
0 0 0 r
s
.494 .685 .822 r
.4496 .37551 m .45464 .38603 L .45496 .37259 L p F P
0 0 0 r
s
.494 .685 .822 r
.45496 .37259 m .44995 .36204 L .4496 .37551 L p F P
0 0 0 r
s
.092 .135 .216 r
.60238 .36114 m .59765 .37176 L .59797 .3852 L p F P
0 0 0 r
s
.576 .776 .973 r
.47327 .44459 m .48683 .4509 L .48701 .43715 L p F P
0 0 0 r
s
.576 .776 .973 r
.48701 .43715 m .47351 .43082 L .47327 .44459 L p F P
0 0 0 r
s
.328 .45 .612 r
.55127 .45494 m .56642 .45045 L .56624 .4367 L p F P
0 0 0 r
s
.275 .382 .53 r
.57957 .43022 m .56624 .4367 L .56642 .45045 L p F P
0 0 0 r
s
.273 .869 .469 r
.38492 .36983 m .38692 .35666 L .38483 .35891 L closepath p F P
0 0 0 r
s
.3 .848 .619 r
.38492 .36983 m .39083 .35742 L .38692 .35666 L closepath p F P
0 0 0 r
s
.064 .37 .165 r
.38492 .36983 m .39266 .36043 L .39083 .35742 L closepath p F P
0 0 0 r
s
0 .369 0 r
.38492 .36983 m .39059 .36268 L .39266 .36043 L closepath p F P
0 0 0 r
s
.248 .807 .563 r
.38492 .36983 m .38667 .36192 L .39059 .36268 L closepath p F P
0 0 0 r
s
.019 .226 .052 r
.38492 .36983 m .38483 .35891 L .38667 .36192 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.38782 .36214 m
.40048 .32849 L
s
.481 .649 .84 r
.50199 .46907 m .51837 .47122 L .5184 .45737 L p F P
0 0 0 r
s
.481 .649 .84 r
.5184 .45737 m .5021 .45522 L .50199 .46907 L p F P
0 0 0 r
s
.431 .584 .767 r
.53503 .45728 m .5184 .45737 L .51837 .47122 L p F P
0 0 0 r
s
.431 .584 .767 r
.51837 .47122 m .53507 .47113 L .53503 .45728 L p F P
0 0 0 r
s
.38 .517 .692 r
.55127 .45494 m .53503 .45728 L .53507 .47113 L p F P
0 0 0 r
s
.242 .667 .366 r
.37805 .68682 m .35765 .67144 L .35734 .67751 L closepath p F P
0 0 0 r
s
0 .259 0 r
.37805 .68682 m .35734 .67751 L .36255 .67891 L closepath p F P
0 0 0 r
s
.329 .879 .631 r
.37805 .68682 m .36316 .66675 L .35765 .67144 L closepath p F P
0 0 0 r
s
.112 .499 .289 r
.37805 .68682 m .36838 .66812 L .36316 .66675 L closepath p F P
0 0 0 r
s
.157 .586 .23 r
.37805 .68682 m .36808 .6742 L .36838 .66812 L closepath p F P
0 0 0 r
s
.376 1 .726 r
.37805 .68682 m .36255 .67891 L .36808 .6742 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.31559 .62925 m
.36615 .67585 L
s
.53 .714 .91 r
.48666 .46476 m .50199 .46907 L .5021 .45522 L p F P
0 0 0 r
s
.53 .714 .91 r
.5021 .45522 m .48683 .4509 L .48666 .46476 L p F P
0 0 0 r
s
.38 .517 .692 r
.53507 .47113 m .55139 .46879 L .55127 .45494 L p F P
0 0 0 r
s
.328 .45 .612 r
.56642 .45045 m .55127 .45494 L .55139 .46879 L p F P
0 0 0 r
s
.031 .286 .065 r
.78721 .66993 m .75735 .67927 L .75788 .68667 L closepath p F P
0 0 0 r
s
.186 .628 .416 r
.78721 .66993 m .75399 .67187 L .75735 .67927 L closepath p F P
0 0 0 r
s
.604 .823 .997 r
.45398 .41328 m .46233 .42275 L .46262 .40909 L p F P
0 0 0 r
s
.604 .823 .997 r
.46262 .40909 m .45431 .3996 L .45398 .41328 L p F P
0 0 0 r
s
.61 .825 1 r
.46203 .43654 m .47327 .44459 L .47351 .43082 L p F P
0 0 0 r
s
.61 .825 1 r
.47351 .43082 m .46233 .42275 L .46203 .43654 L p F P
0 0 0 r
s
.223 .312 .442 r
.57957 .43022 m .59054 .42202 L .59025 .40836 L p F P
0 0 0 r
s
.159 .222 .331 r
.5983 .39876 m .59025 .40836 L .59054 .42202 L p F P
0 0 0 r
s
.159 .222 .331 r
.59025 .40836 m .5983 .39876 L .59797 .3852 L p F P
0 0 0 r
s
.275 .382 .53 r
.56642 .45045 m .57982 .44398 L .57957 .43022 L p F P
0 0 0 r
s
.223 .312 .442 r
.59054 .42202 m .57957 .43022 L .57982 .44398 L p F P
0 0 0 r
s
0 .281 0 r
.78721 .66993 m .75113 .67184 L .75399 .67187 L closepath p F P
0 0 0 r
s
.494 .685 .822 r
.44925 .3891 m .45431 .3996 L .45464 .38603 L p F P
0 0 0 r
s
.494 .685 .822 r
.45464 .38603 m .4496 .37551 L .44925 .3891 L p F P
0 0 0 r
s
.066 .376 .169 r
.44107 .36325 m .44589 .35758 L .44477 .35577 L closepath p F P
0 0 0 r
s
0 .353 0 r
.44107 .36325 m .44468 .35893 L .44589 .35758 L closepath p F P
0 0 0 r
s
.3 .848 .619 r
.44107 .36325 m .44477 .35577 L .44243 .35531 L closepath p F P
0 0 0 r
s
.248 .808 .564 r
.44107 .36325 m .44234 .35847 L .44468 .35893 L closepath p F P
0 0 0 r
s
.252 .84 .431 r
.44107 .36325 m .44243 .35531 L .44121 .35666 L closepath p F P
0 0 0 r
s
.024 .243 .065 r
.44107 .36325 m .44121 .35666 L .44234 .35847 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.44296 .35859 m
.44542 .35251 L
s
.092 .135 .216 r
.60273 .37461 m .59797 .3852 L .5983 .39876 L p F P
0 0 0 r
s
.092 .135 .216 r
.59797 .3852 m .60273 .37461 L .60238 .36114 L p F P
0 0 0 r
s
.576 .776 .973 r
.47303 .45847 m .48666 .46476 L .48683 .4509 L p F P
0 0 0 r
s
.576 .776 .973 r
.48683 .4509 m .47327 .44459 L .47303 .45847 L p F P
0 0 0 r
s
.328 .45 .612 r
.55139 .46879 m .56661 .46432 L .56642 .45045 L p F P
0 0 0 r
s
.275 .382 .53 r
.57982 .44398 m .56642 .45045 L .56661 .46432 L p F P
0 0 0 r
s
.019 .469 .038 r
.78721 .66993 m .75788 .68667 L .75503 .6867 L closepath p F P
0 0 0 r
s
.337 .479 .557 r
.44808 .36445 m .4496 .37551 L .44995 .36204 L p F P
0 0 0 r
s
.337 .479 .557 r
.44995 .36204 m .44844 .35096 L .44808 .36445 L p F P
0 0 0 r
s
.69 .09 .12 r
.44542 .35251 m
.44784 .34653 L
s
.061 .09 .132 r
.60359 .35004 m .60238 .36114 L .60273 .37461 L p F P
0 0 0 r
s
.481 .649 .84 r
.50188 .48305 m .51833 .48519 L .51837 .47122 L p F P
0 0 0 r
s
.481 .649 .84 r
.51837 .47122 m .50199 .46907 L .50188 .48305 L p F P
0 0 0 r
s
.431 .584 .767 r
.53507 .47113 m .51837 .47122 L .51833 .48519 L p F P
0 0 0 r
s
.431 .584 .767 r
.51833 .48519 m .53511 .4851 L .53507 .47113 L p F P
0 0 0 r
s
.38 .517 .692 r
.55139 .46879 m .53507 .47113 L .53511 .4851 L p F P
0 0 0 r
s
.206 .626 .381 r
.56108 .67926 m .53867 .67313 L .53787 .6787 L closepath p F P
0 0 0 r
s
.24 .759 .542 r
.56108 .67926 m .5403 .67014 L .53867 .67313 L closepath p F P
0 0 0 r
s
.279 .756 .492 r
.56108 .67926 m .54034 .67833 L .54114 .67273 L closepath p F P
0 0 0 r
s
.033 .248 .044 r
.56108 .67926 m .53787 .6787 L .5387 .68131 L closepath p F P
0 0 0 r
s
.314 .932 .665 r
.56108 .67926 m .5387 .68131 L .54034 .67833 L closepath p F P
0 0 0 r
s
.055 .291 .073 r
.56108 .67926 m .54114 .67273 L .5403 .67014 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.47416 .665 m
.54068 .67592 L
s
.53 .714 .91 r
.48647 .47876 m .50188 .48305 L .50199 .46907 L p F P
0 0 0 r
s
.53 .714 .91 r
.50199 .46907 m .48666 .46476 L .48647 .47876 L p F P
0 0 0 r
s
.38 .517 .692 r
.53511 .4851 m .5515 .48278 L .55139 .46879 L p F P
0 0 0 r
s
.328 .45 .612 r
.56661 .46432 m .55139 .46879 L .5515 .48278 L p F P
0 0 0 r
s
.082 .384 .143 r
.78721 .66993 m .75165 .67927 L .75113 .67184 L closepath p F P
0 0 0 r
s
.604 .823 .997 r
.45364 .4271 m .46203 .43654 L .46233 .42275 L p F P
0 0 0 r
s
.604 .823 .997 r
.46233 .42275 m .45398 .41328 L .45364 .4271 L p F P
0 0 0 r
s
.61 .825 1 r
.46174 .45045 m .47303 .45847 L .47327 .44459 L p F P
0 0 0 r
s
.61 .825 1 r
.47327 .44459 m .46203 .43654 L .46174 .45045 L p F P
0 0 0 r
s
.223 .312 .442 r
.57982 .44398 m .59084 .43581 L .59054 .42202 L p F P
0 0 0 r
s
.159 .222 .331 r
.59864 .41245 m .59054 .42202 L .59084 .43581 L p F P
0 0 0 r
s
.159 .222 .331 r
.59054 .42202 m .59864 .41245 L .5983 .39876 L p F P
0 0 0 r
s
.275 .382 .53 r
.56661 .46432 m .58006 .45787 L .57982 .44398 L p F P
0 0 0 r
s
.223 .312 .442 r
.59084 .43581 m .57982 .44398 L .58006 .45787 L p F P
0 0 0 r
s
.253 .737 .508 r
.78721 .66993 m .75503 .6867 L .75165 .67927 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.65868 .70662 m
.75198 .67999 L
s
.494 .685 .822 r
.44889 .40282 m .45398 .41328 L .45431 .3996 L p F P
0 0 0 r
s
.494 .685 .822 r
.45431 .3996 m .44925 .3891 L .44889 .40282 L p F P
0 0 0 r
s
.092 .135 .216 r
.60308 .3882 m .5983 .39876 L .59864 .41245 L p F P
0 0 0 r
s
.092 .135 .216 r
.5983 .39876 m .60308 .3882 L .60273 .37461 L p F P
0 0 0 r
s
.576 .776 .973 r
.47279 .47249 m .48647 .47876 L .48666 .46476 L p F P
0 0 0 r
s
.576 .776 .973 r
.48666 .46476 m .47303 .45847 L .47279 .47249 L p F P
0 0 0 r
s
.328 .45 .612 r
.5515 .48278 m .5668 .47832 L .56661 .46432 L p F P
0 0 0 r
s
.275 .382 .53 r
.58006 .45787 m .56661 .46432 L .5668 .47832 L p F P
0 0 0 r
s
.337 .479 .557 r
.44772 .37807 m .44925 .3891 L .4496 .37551 L p F P
0 0 0 r
s
.337 .479 .557 r
.4496 .37551 m .44808 .36445 L .44772 .37807 L p F P
0 0 0 r
s
.061 .09 .132 r
.60395 .36353 m .60273 .37461 L .60308 .3882 L p F P
0 0 0 r
s
.061 .09 .132 r
.60273 .37461 m .60395 .36353 L .60359 .35004 L p F P
0 0 0 r
s
.481 .649 .84 r
.50177 .49716 m .5183 .4993 L .51833 .48519 L p F P
0 0 0 r
s
.481 .649 .84 r
.51833 .48519 m .50188 .48305 L .50177 .49716 L p F P
0 0 0 r
s
.431 .584 .767 r
.53511 .4851 m .51833 .48519 L .5183 .4993 L p F P
0 0 0 r
s
.431 .584 .767 r
.5183 .4993 m .53516 .4992 L .53511 .4851 L p F P
0 0 0 r
s
.38 .517 .692 r
.5515 .48278 m .53511 .4851 L .53516 .4992 L p F P
0 0 0 r
s
.06 .088 .128 r
.45022 .35338 m .44808 .36445 L .44844 .35096 L p F P
0 0 0 r
s
.06 .088 .128 r
.44844 .35096 m .45057 .33985 L .45022 .35338 L p F P
0 0 0 r
s
.038 .287 .102 r
.6119 .34322 m .60996 .34809 L .61116 .34991 L closepath p F P
0 0 0 r
s
.25 .81 .567 r
.6119 .34322 m .60765 .34763 L .60996 .34809 L closepath p F P
0 0 0 r
s
0 .039 0 r
.6119 .34322 m .60654 .34898 L .60765 .34763 L closepath p F P
0 0 0 r
s
.53 .714 .91 r
.48629 .49289 m .50177 .49716 L .50188 .48305 L p F P
0 0 0 r
s
.53 .714 .91 r
.50188 .48305 m .48647 .47876 L .48629 .49289 L p F P
0 0 0 r
s
.336 .475 .553 r
.60116 .33895 m .60359 .35004 L .60395 .36353 L p F P
0 0 0 r
s
.69 .09 .12 r
.60384 .35966 m
.60512 .35704 L
s
.173 .726 .292 r
.6119 .34322 m .61116 .34991 L .61005 .35126 L closepath p F P
0 0 0 r
s
.38 .517 .692 r
.53516 .4992 m .55162 .49689 L .5515 .48278 L p F P
0 0 0 r
s
.328 .45 .612 r
.5668 .47832 m .5515 .48278 L .55162 .49689 L p F P
0 0 0 r
s
.074 .392 .183 r
.6119 .34322 m .60774 .3508 L .60654 .34898 L closepath p F P
0 0 0 r
s
.042 .299 .113 r
.66965 .33645 m .66604 .34462 L .66808 .34764 L closepath p F P
0 0 0 r
s
.251 .811 .568 r
.66965 .33645 m .66221 .34385 L .66604 .34462 L closepath p F P
0 0 0 r
s
.301 .849 .62 r
.6119 .34322 m .61005 .35126 L .60774 .3508 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.60512 .35704 m
.60815 .35088 L
s
0 .039 0 r
.66965 .33645 m .66042 .3461 L .66221 .34385 L closepath p F P
0 0 0 r
s
.604 .823 .997 r
.45331 .44104 m .46174 .45045 L .46203 .43654 L p F P
0 0 0 r
s
.604 .823 .997 r
.46203 .43654 m .45364 .4271 L .45331 .44104 L p F P
0 0 0 r
s
.143 .68 .24 r
.66965 .33645 m .66808 .34764 L .66629 .3499 L closepath p F P
0 0 0 r
s
.61 .825 1 r
.46144 .4645 m .47279 .47249 L .47303 .45847 L p F P
0 0 0 r
s
.61 .825 1 r
.47303 .45847 m .46174 .45045 L .46144 .4645 L p F P
0 0 0 r
s
.045 .311 .123 r
.72782 .32964 m .72222 .34114 L .72513 .34537 L closepath p F P
0 0 0 r
s
.251 .811 .569 r
.72782 .32964 m .71689 .34006 L .72222 .34114 L closepath p F P
0 0 0 r
s
.223 .312 .442 r
.58006 .45787 m .59114 .44973 L .59084 .43581 L p F P
0 0 0 r
s
.159 .222 .331 r
.59897 .42627 m .59084 .43581 L .59114 .44973 L p F P
0 0 0 r
s
.159 .222 .331 r
.59084 .43581 m .59897 .42627 L .59864 .41245 L p F P
0 0 0 r
s
.275 .382 .53 r
.5668 .47832 m .58031 .47189 L .58006 .45787 L p F P
0 0 0 r
s
.223 .312 .442 r
.59114 .44973 m .58006 .45787 L .58031 .47189 L p F P
0 0 0 r
s
.494 .685 .822 r
.44853 .41666 m .45364 .4271 L .45398 .41328 L p F P
0 0 0 r
s
.494 .685 .822 r
.45398 .41328 m .44889 .40282 L .44853 .41666 L p F P
0 0 0 r
s
0 .039 0 r
.72782 .32964 m .71446 .34321 L .71689 .34006 L closepath p F P
0 0 0 r
s
.076 .397 .188 r
.66965 .33645 m .66246 .34913 L .66042 .3461 L closepath p F P
0 0 0 r
s
.092 .135 .216 r
.60344 .40192 m .59864 .41245 L .59897 .42627 L p F P
0 0 0 r
s
.092 .135 .216 r
.59864 .41245 m .60344 .40192 L .60308 .3882 L p F P
0 0 0 r
s
.576 .776 .973 r
.47254 .48664 m .48629 .49289 L .48647 .47876 L p F P
0 0 0 r
s
.576 .776 .973 r
.48647 .47876 m .47279 .47249 L .47254 .48664 L p F P
0 0 0 r
s
.301 .85 .621 r
.66965 .33645 m .66629 .3499 L .66246 .34913 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.64838 .37745 m
.66302 .34924 L
s
.049 .321 .132 r
.7864 .32277 m .7785 .33766 L .78232 .3431 L closepath p F P
0 0 0 r
s
.252 .812 .57 r
.7864 .32277 m .77168 .33626 L .7785 .33766 L closepath p F P
0 0 0 r
s
.112 .631 .187 r
.72782 .32964 m .72513 .34537 L .72271 .34853 L closepath p F P
0 0 0 r
s
.328 .45 .612 r
.55162 .49689 m .56698 .49244 L .5668 .47832 L p F P
0 0 0 r
s
.275 .382 .53 r
.58031 .47189 m .5668 .47832 L .56698 .49244 L p F P
0 0 0 r
s
.337 .479 .557 r
.44736 .39182 m .44889 .40282 L .44925 .3891 L p F P
0 0 0 r
s
.337 .479 .557 r
.44925 .3891 m .44772 .37807 L .44736 .39182 L p F P
0 0 0 r
s
0 .039 0 r
.7864 .32277 m .76866 .34031 L .77168 .33626 L closepath p F P
0 0 0 r
s
.061 .09 .132 r
.60431 .37716 m .60308 .3882 L .60344 .40192 L p F P
0 0 0 r
s
.061 .09 .132 r
.60308 .3882 m .60431 .37716 L .60395 .36353 L p F P
0 0 0 r
s
.052 .331 .141 r
.84541 .31585 m .83489 .33417 L .83965 .34082 L closepath p F P
0 0 0 r
s
.253 .813 .571 r
.84541 .31585 m .82659 .33246 L .83489 .33417 L closepath p F P
0 0 0 r
s
.481 .649 .84 r
.50166 .5114 m .51826 .51353 L .5183 .4993 L p F P
0 0 0 r
s
.481 .649 .84 r
.5183 .4993 m .50177 .49716 L .50166 .5114 L p F P
0 0 0 r
s
.431 .584 .767 r
.53516 .4992 m .5183 .4993 L .51826 .51353 L p F P
0 0 0 r
s
.431 .584 .767 r
.51826 .51353 m .5352 .51344 L .53516 .4992 L p F P
0 0 0 r
s
.38 .517 .692 r
.55162 .49689 m .53516 .4992 L .5352 .51344 L p F P
0 0 0 r
s
.078 .402 .192 r
.72782 .32964 m .71737 .34745 L .71446 .34321 L closepath p F P
0 0 0 r
s
.081 .582 .135 r
.7864 .32277 m .78232 .3431 L .77932 .34716 L closepath p F P
0 0 0 r
s
.301 .85 .621 r
.72782 .32964 m .72271 .34853 L .71737 .34745 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.69645 .38695 m
.718 .34758 L
s
.06 .088 .128 r
.44987 .36703 m .44772 .37807 L .44808 .36445 L p F P
0 0 0 r
s
.06 .088 .128 r
.44808 .36445 m .45022 .35338 L .44987 .36703 L p F P
0 0 0 r
s
0 .039 0 r
.84541 .31585 m .82303 .3374 L .82659 .33246 L closepath p F P
0 0 0 r
s
.53 .714 .91 r
.48611 .50714 m .50166 .5114 L .50177 .49716 L p F P
0 0 0 r
s
.53 .714 .91 r
.50177 .49716 m .48629 .49289 L .48611 .50714 L p F P
0 0 0 r
s
.336 .475 .553 r
.60151 .35248 m .60395 .36353 L .60431 .37716 L p F P
0 0 0 r
s
.336 .475 .553 r
.60395 .36353 m .60151 .35248 L .60116 .33895 L p F P
0 0 0 r
s
.38 .517 .692 r
.5352 .51344 m .55174 .51113 L .55162 .49689 L p F P
0 0 0 r
s
.328 .45 .612 r
.56698 .49244 m .55162 .49689 L .55174 .51113 L p F P
0 0 0 r
s
.028 .278 .059 r
.74225 .65133 m .71784 .65922 L .7182 .66532 L closepath p F P
0 0 0 r
s
.186 .627 .415 r
.74225 .65133 m .71501 .65306 L .71784 .65922 L closepath p F P
0 0 0 r
s
.054 .534 .09 r
.84541 .31585 m .83965 .34082 L .83612 .34579 L closepath p F P
0 0 0 r
s
.08 .406 .196 r
.7864 .32277 m .77248 .34577 L .76866 .34031 L closepath p F P
0 0 0 r
s
.09 .132 .21 r
.45597 .34281 m .45022 .35338 L .45057 .33985 L p F P
0 0 0 r
s
.69 .09 .12 r
.44784 .34653 m
.45045 .34007 L
s
.09 .132 .21 r
.45057 .33985 m .4563 .32926 L .45597 .34281 L p F P
0 0 0 r
s
.69 .09 .12 r
.45045 .34007 m
.4506 .33971 L
s
.4506 .33971 m
.45109 .33849 L
s
.301 .851 .621 r
.7864 .32277 m .77932 .34716 L .77248 .34577 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.74403 .39635 m
.77309 .34589 L
s
0 .29 0 r
.74225 .65133 m .71253 .65299 L .71501 .65306 L closepath p F P
0 0 0 r
s
.604 .823 .997 r
.45297 .45511 m .46144 .4645 L .46174 .45045 L p F P
0 0 0 r
s
.604 .823 .997 r
.46174 .45045 m .45331 .44104 L .45297 .45511 L p F P
0 0 0 r
s
.495 .68 .818 r
.59514 .32842 m .60116 .33895 L .60151 .35248 L p F P
0 0 0 r
s
.61 .825 1 r
.46114 .47867 m .47254 .48664 L .47279 .47249 L p F P
0 0 0 r
s
.61 .825 1 r
.47279 .47249 m .46144 .4645 L .46114 .47867 L p F P
0 0 0 r
s
.223 .312 .442 r
.58031 .47189 m .59144 .46377 L .59114 .44973 L p F P
0 0 0 r
s
.159 .222 .331 r
.59931 .44021 m .59114 .44973 L .59144 .46377 L p F P
0 0 0 r
s
.159 .222 .331 r
.59114 .44973 m .59931 .44021 L .59897 .42627 L p F P
0 0 0 r
s
.275 .382 .53 r
.56698 .49244 m .58057 .48604 L .58031 .47189 L p F P
0 0 0 r
s
.223 .312 .442 r
.59144 .46377 m .58031 .47189 L .58057 .48604 L p F P
0 0 0 r
s
.494 .685 .822 r
.44817 .43064 m .45331 .44104 L .45364 .4271 L p F P
0 0 0 r
s
.494 .685 .822 r
.45364 .4271 m .44853 .41666 L .44817 .43064 L p F P
0 0 0 r
s
.029 .494 .061 r
.74225 .65133 m .7182 .66532 L .71573 .66527 L closepath p F P
0 0 0 r
s
.239 .661 .359 r
.40901 .66069 m .39307 .64839 L .39287 .65315 L closepath p F P
0 0 0 r
s
0 .269 0 r
.40901 .66069 m .39287 .65315 L .39704 .65422 L closepath p F P
0 0 0 r
s
.33 .882 .633 r
.40901 .66069 m .39742 .64469 L .39307 .64839 L closepath p F P
0 0 0 r
s
.115 .505 .295 r
.40901 .66069 m .40159 .64574 L .39742 .64469 L closepath p F P
0 0 0 r
s
.138 .558 .202 r
.40901 .66069 m .40141 .6505 L .40159 .64574 L closepath p F P
0 0 0 r
s
.375 1 .725 r
.40901 .66069 m .39704 .65422 L .40141 .6505 L closepath p F P
0 0 0 r
s
.083 .411 .2 r
.84541 .31585 m .8278 .34408 L .82303 .3374 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.36088 .61475 m
.39978 .65188 L
s
.092 .135 .216 r
.6038 .41577 m .59897 .42627 L .59931 .44021 L p F P
0 0 0 r
s
.092 .135 .216 r
.59897 .42627 m .6038 .41577 L .60344 .40192 L p F P
0 0 0 r
s
.576 .776 .973 r
.47229 .50092 m .48611 .50714 L .48629 .49289 L p F P
0 0 0 r
s
.576 .776 .973 r
.48629 .49289 m .47254 .48664 L .47229 .50092 L p F P
0 0 0 r
s
.328 .45 .612 r
.55174 .51113 m .56717 .5067 L .56698 .49244 L p F P
0 0 0 r
s
.275 .382 .53 r
.58057 .48604 m .56698 .49244 L .56717 .5067 L p F P
0 0 0 r
s
.301 .851 .622 r
.84541 .31585 m .83612 .34579 L .8278 .34408 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.79113 .40565 m
.82829 .34418 L
s
.337 .479 .557 r
.44699 .4057 m .44853 .41666 L .44889 .40282 L p F P
0 0 0 r
s
.337 .479 .557 r
.44889 .40282 m .44736 .39182 L .44699 .4057 L p F P
0 0 0 r
s
.061 .09 .132 r
.60467 .39091 m .60344 .40192 L .6038 .41577 L p F P
0 0 0 r
s
.061 .09 .132 r
.60344 .40192 m .60467 .39091 L .60431 .37716 L p F P
0 0 0 r
s
.481 .649 .84 r
.50154 .52578 m .51822 .5279 L .51826 .51353 L p F P
0 0 0 r
s
.481 .649 .84 r
.51826 .51353 m .50166 .5114 L .50154 .52578 L p F P
0 0 0 r
s
.431 .584 .767 r
.5352 .51344 m .51826 .51353 L .51822 .5279 L p F P
0 0 0 r
s
.431 .584 .767 r
.51822 .5279 m .53524 .52781 L .5352 .51344 L p F P
0 0 0 r
s
.38 .517 .692 r
.55174 .51113 m .5352 .51344 L .53524 .52781 L p F P
0 0 0 r
s
.08 .378 .138 r
.74225 .65133 m .71289 .6591 L .71253 .65299 L closepath p F P
0 0 0 r
s
.06 .088 .128 r
.44951 .3808 m .44736 .39182 L .44772 .37807 L p F P
0 0 0 r
s
.06 .088 .128 r
.44772 .37807 m .44987 .36703 L .44951 .3808 L p F P
0 0 0 r
s
.53 .714 .91 r
.48592 .52153 m .50154 .52578 L .50166 .5114 L p F P
0 0 0 r
s
.53 .714 .91 r
.50166 .5114 m .48611 .50714 L .48592 .52153 L p F P
0 0 0 r
s
.336 .475 .553 r
.60186 .36613 m .60431 .37716 L .60467 .39091 L p F P
0 0 0 r
s
.336 .475 .553 r
.60431 .37716 m .60186 .36613 L .60151 .35248 L p F P
0 0 0 r
s
.38 .517 .692 r
.53524 .52781 m .55186 .52551 L .55174 .51113 L p F P
0 0 0 r
s
.328 .45 .612 r
.56717 .5067 m .55174 .51113 L .55186 .52551 L p F P
0 0 0 r
s
.253 .738 .509 r
.74225 .65133 m .71573 .66527 L .71289 .6591 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.63629 .68218 m
.7132 .65979 L
s
.09 .132 .21 r
.45564 .35648 m .44987 .36703 L .45022 .35338 L p F P
0 0 0 r
s
.09 .132 .21 r
.45022 .35338 m .45597 .34281 L .45564 .35648 L p F P
0 0 0 r
s
.604 .823 .997 r
.45263 .46932 m .46114 .47867 L .46144 .4645 L p F P
0 0 0 r
s
.604 .823 .997 r
.46144 .4645 m .45297 .45511 L .45263 .46932 L p F P
0 0 0 r
s
.495 .68 .818 r
.59546 .34198 m .60151 .35248 L .60186 .36613 L p F P
0 0 0 r
s
.495 .68 .818 r
.60151 .35248 m .59546 .34198 L .59514 .32842 L p F P
0 0 0 r
s
.61 .825 1 r
.46083 .49298 m .47229 .50092 L .47254 .48664 L p F P
0 0 0 r
s
.61 .825 1 r
.47254 .48664 m .46114 .47867 L .46083 .49298 L p F P
0 0 0 r
s
.223 .312 .442 r
.58057 .48604 m .59175 .47795 L .59144 .46377 L p F P
0 0 0 r
s
.159 .222 .331 r
.59965 .45429 m .59144 .46377 L .59175 .47795 L p F P
0 0 0 r
s
.159 .222 .331 r
.59144 .46377 m .59965 .45429 L .59931 .44021 L p F P
0 0 0 r
s
.275 .382 .53 r
.56717 .5067 m .58082 .50032 L .58057 .48604 L p F P
0 0 0 r
s
.223 .312 .442 r
.59175 .47795 m .58057 .48604 L .58082 .50032 L p F P
0 0 0 r
s
.163 .225 .333 r
.46512 .33327 m .45597 .34281 L .4563 .32926 L p F P
0 0 0 r
s
.163 .225 .333 r
.4563 .32926 m .4654 .31969 L .46512 .33327 L p F P
0 0 0 r
s
.494 .685 .822 r
.4478 .44474 m .45297 .45511 L .45331 .44104 L p F P
0 0 0 r
s
.494 .685 .822 r
.45331 .44104 m .44817 .43064 L .4478 .44474 L p F P
0 0 0 r
s
.588 .794 .966 r
.58577 .31897 m .59514 .32842 L .59546 .34198 L p F P
0 0 0 r
s
.092 .135 .216 r
.60416 .42975 m .59931 .44021 L .59965 .45429 L p F P
0 0 0 r
s
.092 .135 .216 r
.59931 .44021 m .60416 .42975 L .6038 .41577 L p F P
0 0 0 r
s
.576 .776 .973 r
.47204 .51533 m .48592 .52153 L .48611 .50714 L p F P
0 0 0 r
s
.576 .776 .973 r
.48611 .50714 m .47229 .50092 L .47204 .51533 L p F P
0 0 0 r
s
.328 .45 .612 r
.55186 .52551 m .56737 .52109 L .56717 .5067 L p F P
0 0 0 r
s
.275 .382 .53 r
.58082 .50032 m .56717 .5067 L .56737 .52109 L p F P
0 0 0 r
s
.337 .479 .557 r
.44662 .41971 m .44817 .43064 L .44853 .41666 L p F P
0 0 0 r
s
.337 .479 .557 r
.44853 .41666 m .44699 .4057 L .44662 .41971 L p F P
0 0 0 r
s
.061 .09 .132 r
.60504 .40479 m .6038 .41577 L .60416 .42975 L p F P
0 0 0 r
s
.061 .09 .132 r
.6038 .41577 m .60504 .40479 L .60467 .39091 L p F P
0 0 0 r
s
.481 .649 .84 r
.50143 .54029 m .51819 .5424 L .51822 .5279 L p F P
0 0 0 r
s
.481 .649 .84 r
.51822 .5279 m .50154 .52578 L .50143 .54029 L p F P
0 0 0 r
s
.431 .584 .767 r
.53524 .52781 m .51822 .5279 L .51819 .5424 L p F P
0 0 0 r
s
.431 .584 .767 r
.51819 .5424 m .53528 .54231 L .53524 .52781 L p F P
0 0 0 r
s
.38 .517 .692 r
.55186 .52551 m .53524 .52781 L .53528 .54231 L p F P
0 0 0 r
s
.06 .088 .128 r
.44915 .39471 m .44699 .4057 L .44736 .39182 L p F P
0 0 0 r
s
.06 .088 .128 r
.44736 .39182 m .44951 .3808 L .44915 .39471 L p F P
0 0 0 r
s
.53 .714 .91 r
.48573 .53606 m .50143 .54029 L .50154 .52578 L p F P
0 0 0 r
s
.53 .714 .91 r
.50154 .52578 m .48592 .52153 L .48573 .53606 L p F P
0 0 0 r
s
.336 .475 .553 r
.60221 .37991 m .60467 .39091 L .60504 .40479 L p F P
0 0 0 r
s
.336 .475 .553 r
.60467 .39091 m .60221 .37991 L .60186 .36613 L p F P
0 0 0 r
s
.38 .517 .692 r
.53528 .54231 m .55198 .54002 L .55186 .52551 L p F P
0 0 0 r
s
.328 .45 .612 r
.56737 .52109 m .55186 .52551 L .55198 .54002 L p F P
0 0 0 r
s
.09 .132 .21 r
.45531 .37029 m .44951 .3808 L .44987 .36703 L p F P
0 0 0 r
s
.09 .132 .21 r
.44987 .36703 m .45564 .35648 L .45531 .37029 L p F P
0 0 0 r
s
.206 .626 .38 r
.55158 .64743 m .53524 .64296 L .53466 .64701 L closepath p F P
0 0 0 r
s
.239 .759 .542 r
.55158 .64743 m .53643 .64074 L .53524 .64296 L closepath p F P
0 0 0 r
s
.28 .757 .493 r
.55158 .64743 m .53644 .64664 L .53703 .64258 L closepath p F P
0 0 0 r
s
.03 .237 .039 r
.55158 .64743 m .53466 .64701 L .53526 .64886 L closepath p F P
0 0 0 r
s
.314 .932 .666 r
.55158 .64743 m .53526 .64886 L .53644 .64664 L closepath p F P
0 0 0 r
s
.049 .279 .065 r
.55158 .64743 m .53703 .64258 L .53643 .64074 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.48832 .63685 m
.53669 .64494 L
s
.604 .823 .997 r
.45228 .48366 m .46083 .49298 L .46114 .47867 L p F P
0 0 0 r
s
.604 .823 .997 r
.46114 .47867 m .45263 .46932 L .45228 .48366 L p F P
0 0 0 r
s
.495 .68 .818 r
.59579 .35565 m .60186 .36613 L .60221 .37991 L p F P
0 0 0 r
s
.495 .68 .818 r
.60186 .36613 m .59579 .35565 L .59546 .34198 L p F P
0 0 0 r
s
.61 .825 1 r
.46053 .50742 m .47204 .51533 L .47229 .50092 L p F P
0 0 0 r
s
.61 .825 1 r
.47229 .50092 m .46083 .49298 L .46053 .50742 L p F P
0 0 0 r
s
.223 .312 .442 r
.58082 .50032 m .59206 .49226 L .59175 .47795 L p F P
0 0 0 r
s
.159 .222 .331 r
.6 .4685 m .59175 .47795 L .59206 .49226 L p F P
0 0 0 r
s
.159 .222 .331 r
.59175 .47795 m .6 .4685 L .59965 .45429 L p F P
0 0 0 r
s
.275 .382 .53 r
.56737 .52109 m .58108 .51474 L .58082 .50032 L p F P
0 0 0 r
s
.223 .312 .442 r
.59206 .49226 m .58082 .50032 L .58108 .51474 L p F P
0 0 0 r
s
.163 .225 .333 r
.46483 .34697 m .45564 .35648 L .45597 .34281 L p F P
0 0 0 r
s
.163 .225 .333 r
.45597 .34281 m .46512 .33327 L .46483 .34697 L p F P
0 0 0 r
s
.494 .685 .822 r
.44744 .45898 m .45263 .46932 L .45297 .45511 L p F P
0 0 0 r
s
.494 .685 .822 r
.45297 .45511 m .4478 .44474 L .44744 .45898 L p F P
0 0 0 r
s
.225 .313 .441 r
.47726 .32524 m .46512 .33327 L .4654 .31969 L p F P
0 0 0 r
s
.225 .313 .441 r
.4654 .31969 m .47749 .31165 L .47726 .32524 L p F P
0 0 0 r
s
.252 .735 .505 r
.45372 .31966 m .46337 .31683 L .46233 .31464 L closepath p F P
0 0 0 r
s
.062 .342 .104 r
.45372 .31966 m .46333 .31867 L .46337 .31683 L closepath p F P
0 0 0 r
s
.03 .442 .069 r
.45372 .31966 m .46225 .31832 L .46333 .31867 L closepath p F P
0 0 0 r
s
.187 .628 .416 r
.45372 .31966 m .46121 .31612 L .46225 .31832 L closepath p F P
0 0 0 r
s
.233 .846 .485 r
.45372 .31966 m .46233 .31464 L .46125 .31429 L closepath p F P
0 0 0 r
s
.009 .226 .022 r
.45372 .31966 m .46125 .31429 L .46121 .31612 L closepath p F P
0 0 0 r
s
.588 .794 .966 r
.58605 .33254 m .59546 .34198 L .59579 .35565 L p F P
0 0 0 r
s
.588 .794 .966 r
.59546 .34198 m .58605 .33254 L .58577 .31897 L p F P
0 0 0 r
s
.092 .135 .216 r
.60453 .44386 m .59965 .45429 L .6 .4685 L p F P
0 0 0 r
s
.092 .135 .216 r
.59965 .45429 m .60453 .44386 L .60416 .42975 L p F P
0 0 0 r
s
.584 .784 .971 r
.57346 .31107 m .58577 .31897 L .58605 .33254 L p F P
0 0 0 r
s
.69 .09 .12 r
.58992 .32163 m
.59514 .32842 L
s
.576 .776 .973 r
.47178 .52988 m .48573 .53606 L .48592 .52153 L p F P
0 0 0 r
s
.576 .776 .973 r
.48592 .52153 m .47204 .51533 L .47178 .52988 L p F P
0 0 0 r
s
.328 .45 .612 r
.55198 .54002 m .56756 .53562 L .56737 .52109 L p F P
0 0 0 r
s
.275 .382 .53 r
.58108 .51474 m .56737 .52109 L .56756 .53562 L p F P
0 0 0 r
s
.337 .479 .557 r
.44624 .43384 m .4478 .44474 L .44817 .43064 L p F P
0 0 0 r
s
.337 .479 .557 r
.44817 .43064 m .44662 .41971 L .44624 .43384 L p F P
0 0 0 r
s
.061 .09 .132 r
.60541 .4188 m .60416 .42975 L .60453 .44386 L p F P
0 0 0 r
s
.061 .09 .132 r
.60416 .42975 m .60541 .4188 L .60504 .40479 L p F P
0 0 0 r
s
.481 .649 .84 r
.50131 .55494 m .51815 .55704 L .51819 .5424 L p F P
0 0 0 r
s
.481 .649 .84 r
.51819 .5424 m .50143 .54029 L .50131 .55494 L p F P
0 0 0 r
s
.431 .584 .767 r
.53528 .54231 m .51819 .5424 L .51815 .55704 L p F P
0 0 0 r
s
.431 .584 .767 r
.51815 .55704 m .53533 .55695 L .53528 .54231 L p F P
0 0 0 r
s
.38 .517 .692 r
.55198 .54002 m .53528 .54231 L .53533 .55695 L p F P
0 0 0 r
s
.06 .088 .128 r
.44879 .40875 m .44662 .41971 L .44699 .4057 L p F P
0 0 0 r
s
.06 .088 .128 r
.44699 .4057 m .44915 .39471 L .44879 .40875 L p F P
0 0 0 r
s
.024 .27 .053 r
.69621 .63228 m .67725 .63862 L .67748 .64339 L closepath p F P
0 0 0 r
s
.185 .625 .415 r
.69621 .63228 m .67499 .63375 L .67725 .63862 L closepath p F P
0 0 0 r
s
.53 .714 .91 r
.48554 .55072 m .50131 .55494 L .50143 .54029 L p F P
0 0 0 r
s
.53 .714 .91 r
.50143 .54029 m .48573 .53606 L .48554 .55072 L p F P
0 0 0 r
s
.336 .475 .553 r
.60257 .39382 m .60504 .40479 L .60541 .4188 L p F P
0 0 0 r
s
.336 .475 .553 r
.60504 .40479 m .60257 .39382 L .60221 .37991 L p F P
0 0 0 r
s
.38 .517 .692 r
.53533 .55695 m .5521 .55467 L .55198 .54002 L p F P
0 0 0 r
s
.328 .45 .612 r
.56756 .53562 m .55198 .54002 L .5521 .55467 L p F P
0 0 0 r
s
0 .298 0 r
.69621 .63228 m .67294 .63364 L .67499 .63375 L closepath p F P
0 0 0 r
s
.09 .132 .21 r
.45498 .38423 m .44915 .39471 L .44951 .3808 L p F P
0 0 0 r
s
.09 .132 .21 r
.44951 .3808 m .45531 .37029 L .45498 .38423 L p F P
0 0 0 r
s
.041 .521 .087 r
.69621 .63228 m .67748 .64339 L .67543 .64331 L closepath p F P
0 0 0 r
s
.604 .823 .997 r
.45193 .49813 m .46053 .50742 L .46083 .49298 L p F P
0 0 0 r
s
.604 .823 .997 r
.46083 .49298 m .45228 .48366 L .45193 .49813 L p F P
0 0 0 r
s
.495 .68 .818 r
.59612 .36946 m .60221 .37991 L .60257 .39382 L p F P
0 0 0 r
s
.495 .68 .818 r
.60221 .37991 m .59612 .36946 L .59579 .35565 L p F P
0 0 0 r
s
.379 1 .73 r
.57704 .30488 m .57969 .3106 L .58157 .30898 L closepath p F P
0 0 0 r
s
.036 .397 .051 r
.57704 .30488 m .57972 .31244 L .57969 .3106 L closepath p F P
0 0 0 r
s
.076 .468 .192 r
.57704 .30488 m .58157 .30898 L .5835 .30921 L closepath p F P
0 0 0 r
s
.61 .825 1 r
.46022 .522 m .47178 .52988 L .47204 .51533 L p F P
0 0 0 r
s
.61 .825 1 r
.47204 .51533 m .46053 .50742 L .46022 .522 L p F P
0 0 0 r
s
.28 .387 .532 r
.49183 .31915 m .47726 .32524 L .47749 .31165 L p F P
0 0 0 r
s
.28 .387 .532 r
.47749 .31165 m .49199 .30554 L .49183 .31915 L p F P
0 0 0 r
s
.69 .09 .12 r
.46151 .31677 m
.48026 .30981 L
s
.48026 .30981 m
.48818 .30687 L
s
.223 .312 .442 r
.58108 .51474 m .59237 .5067 L .59206 .49226 L p F P
0 0 0 r
s
.159 .222 .331 r
.60035 .48284 m .59206 .49226 L .59237 .5067 L p F P
0 0 0 r
s
.159 .222 .331 r
.59206 .49226 m .60035 .48284 L .6 .4685 L p F P
0 0 0 r
s
.275 .382 .53 r
.56756 .53562 m .58134 .52929 L .58108 .51474 L p F P
0 0 0 r
s
.223 .312 .442 r
.59237 .5067 m .58108 .51474 L .58134 .52929 L p F P
0 0 0 r
s
.163 .225 .333 r
.46454 .3608 m .45531 .37029 L .45564 .35648 L p F P
0 0 0 r
s
.163 .225 .333 r
.45564 .35648 m .46483 .34697 L .46454 .3608 L p F P
0 0 0 r
s
.494 .685 .822 r
.44706 .47335 m .45228 .48366 L .45263 .46932 L p F P
0 0 0 r
s
.494 .685 .822 r
.45263 .46932 m .44744 .45898 L .44706 .47335 L p F P
0 0 0 r
s
.584 .784 .971 r
.58605 .33254 m .57369 .32466 L .57346 .31107 L p F P
0 0 0 r
s
.545 .731 .921 r
.55879 .30513 m .57346 .31107 L .57369 .32466 L p F P
0 0 0 r
s
.146 .57 .365 r
.57704 .30488 m .58164 .31266 L .57972 .31244 L closepath p F P
0 0 0 r
s
.214 .62 .311 r
.57704 .30488 m .5835 .30921 L .58354 .31105 L closepath p F P
0 0 0 r
s
.225 .313 .441 r
.47703 .33896 m .46483 .34697 L .46512 .33327 L p F P
0 0 0 r
s
.225 .313 .441 r
.46512 .33327 m .47726 .32524 L .47703 .33896 L p F P
0 0 0 r
s
.588 .794 .966 r
.58634 .34624 m .59579 .35565 L .59612 .36946 L p F P
0 0 0 r
s
.588 .794 .966 r
.59579 .35565 m .58634 .34624 L .58605 .33254 L p F P
0 0 0 r
s
.092 .135 .216 r
.6049 .4581 m .6 .4685 L .60035 .48284 L p F P
0 0 0 r
s
.092 .135 .216 r
.6 .4685 m .6049 .4581 L .60453 .44386 L p F P
0 0 0 r
s
.584 .784 .971 r
.57369 .32466 m .58605 .33254 L .58634 .34624 L p F P
0 0 0 r
s
.576 .776 .973 r
.47153 .54457 m .48554 .55072 L .48573 .53606 L p F P
0 0 0 r
s
.576 .776 .973 r
.48573 .53606 m .47178 .52988 L .47153 .54457 L p F P
0 0 0 r
s
.327 .875 .628 r
.57704 .30488 m .58354 .31105 L .58164 .31266 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.58248 .31195 m
.58992 .32163 L
s
.328 .45 .612 r
.5521 .55467 m .56776 .55029 L .56756 .53562 L p F P
0 0 0 r
s
.275 .382 .53 r
.58134 .52929 m .56756 .53562 L .56776 .55029 L p F P
0 0 0 r
s
.077 .373 .132 r
.69621 .63228 m .67316 .63843 L .67294 .63364 L closepath p F P
0 0 0 r
s
.337 .479 .557 r
.44586 .44812 m .44744 .45898 L .4478 .44474 L p F P
0 0 0 r
s
.337 .479 .557 r
.4478 .44474 m .44624 .43384 L .44586 .44812 L p F P
0 0 0 r
s
.206 .626 .38 r
.58261 .96487 m .54642 .95499 L .54514 .96413 L closepath p F P
0 0 0 r
s
.224 .742 .52 r
.58261 .96487 m .54909 .95103 L .54642 .95499 L closepath p F P
0 0 0 r
s
.08 .343 .106 r
.58261 .96487 m .55048 .95623 L .54909 .95103 L closepath p F P
0 0 0 r
s
.048 .287 .064 r
.58261 .96487 m .54514 .96413 L .54651 .96936 L closepath p F P
0 0 0 r
s
.281 .758 .493 r
.58261 .96487 m .54918 .96542 L .55048 .95623 L closepath p F P
0 0 0 r
s
.269 .88 .582 r
.58261 .96487 m .54651 .96936 L .54918 .96542 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.44183 .94594 m
.54988 .96047 L
s
.061 .09 .132 r
.60579 .43294 m .60453 .44386 L .6049 .4581 L p F P
0 0 0 r
s
.061 .09 .132 r
.60453 .44386 m .60579 .43294 L .60541 .4188 L p F P
0 0 0 r
s
.481 .649 .84 r
.5012 .56972 m .51811 .57181 L .51815 .55704 L p F P
0 0 0 r
s
.481 .649 .84 r
.51815 .55704 m .50131 .55494 L .5012 .56972 L p F P
0 0 0 r
s
.431 .584 .767 r
.53533 .55695 m .51815 .55704 L .51811 .57181 L p F P
0 0 0 r
s
.431 .584 .767 r
.51811 .57181 m .53537 .57172 L .53533 .55695 L p F P
0 0 0 r
s
.38 .517 .692 r
.5521 .55467 m .53533 .55695 L .53537 .57172 L p F P
0 0 0 r
s
.253 .739 .51 r
.69621 .63228 m .67543 .64331 L .67316 .63843 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.61317 .65696 m
.67345 .63905 L
s
.06 .088 .128 r
.44842 .42292 m .44624 .43384 L .44662 .41971 L p F P
0 0 0 r
s
.06 .088 .128 r
.44662 .41971 m .44879 .40875 L .44842 .42292 L p F P
0 0 0 r
s
.53 .714 .91 r
.48535 .56552 m .5012 .56972 L .50131 .55494 L p F P
0 0 0 r
s
.53 .714 .91 r
.50131 .55494 m .48554 .55072 L .48535 .56552 L p F P
0 0 0 r
s
.336 .458 .618 r
.50812 .31531 m .49183 .31915 L .49199 .30554 L p F P
0 0 0 r
s
.336 .458 .618 r
.49199 .30554 m .50821 .30169 L .50812 .31531 L p F P
0 0 0 r
s
.336 .475 .553 r
.60294 .40786 m .60541 .4188 L .60579 .43294 L p F P
0 0 0 r
s
.336 .475 .553 r
.60541 .4188 m .60294 .40786 L .60257 .39382 L p F P
0 0 0 r
s
.38 .517 .692 r
.53537 .57172 m .55223 .56945 L .5521 .55467 L p F P
0 0 0 r
s
.328 .45 .612 r
.56776 .55029 m .5521 .55467 L .55223 .56945 L p F P
0 0 0 r
s
.545 .731 .921 r
.57369 .32466 m .55894 .31874 L .55879 .30513 L p F P
0 0 0 r
s
.496 .666 .853 r
.54247 .30148 m .55879 .30513 L .55894 .31874 L p F P
0 0 0 r
s
.235 .655 .351 r
.44102 .63366 m .42958 .62463 L .42948 .62806 L closepath p F P
0 0 0 r
s
0 .279 0 r
.44102 .63366 m .42948 .62806 L .43254 .6288 L closepath p F P
0 0 0 r
s
.331 .885 .636 r
.44102 .63366 m .43274 .62195 L .42958 .62463 L closepath p F P
0 0 0 r
s
.117 .51 .301 r
.44102 .63366 m .43581 .62268 L .43274 .62195 L closepath p F P
0 0 0 r
s
.118 .528 .173 r
.44102 .63366 m .43571 .62611 L .43581 .62268 L closepath p F P
0 0 0 r
s
.375 1 .724 r
.44102 .63366 m .43254 .6288 L .43571 .62611 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.407 .59998 m
.43446 .62717 L
s
.09 .132 .21 r
.45464 .3983 m .44879 .40875 L .44915 .39471 L p F P
0 0 0 r
s
.09 .132 .21 r
.44915 .39471 m .45498 .38423 L .45464 .3983 L p F P
0 0 0 r
s
.604 .823 .997 r
.45158 .51274 m .46022 .522 L .46053 .50742 L p F P
0 0 0 r
s
.604 .823 .997 r
.46053 .50742 m .45193 .49813 L .45158 .51274 L p F P
0 0 0 r
s
.495 .68 .818 r
.59645 .3834 m .60257 .39382 L .60294 .40786 L p F P
0 0 0 r
s
.495 .68 .818 r
.60257 .39382 m .59645 .3834 L .59612 .36946 L p F P
0 0 0 r
s
.61 .825 1 r
.4599 .53671 m .47153 .54457 L .47178 .52988 L p F P
0 0 0 r
s
.61 .825 1 r
.47178 .52988 m .46022 .522 L .4599 .53671 L p F P
0 0 0 r
s
.28 .387 .532 r
.49167 .33288 m .47703 .33896 L .47726 .32524 L p F P
0 0 0 r
s
.28 .387 .532 r
.47726 .32524 m .49183 .31915 L .49167 .33288 L p F P
0 0 0 r
s
.223 .312 .442 r
.58134 .52929 m .59268 .52128 L .59237 .5067 L p F P
0 0 0 r
s
.159 .222 .331 r
.6007 .49732 m .59237 .5067 L .59268 .52128 L p F P
0 0 0 r
s
.159 .222 .331 r
.59237 .5067 m .6007 .49732 L .60035 .48284 L p F P
0 0 0 r
s
.275 .382 .53 r
.56776 .55029 m .5816 .54398 L .58134 .52929 L p F P
0 0 0 r
s
.223 .312 .442 r
.59268 .52128 m .58134 .52929 L .5816 .54398 L p F P
0 0 0 r
s
.163 .225 .333 r
.46425 .37476 m .45498 .38423 L .45531 .37029 L p F P
0 0 0 r
s
.163 .225 .333 r
.45531 .37029 m .46454 .3608 L .46425 .37476 L p F P
0 0 0 r
s
.494 .685 .822 r
.44669 .48786 m .45193 .49813 L .45228 .48366 L p F P
0 0 0 r
s
.494 .685 .822 r
.45228 .48366 m .44706 .47335 L .44669 .48786 L p F P
0 0 0 r
s
.584 .784 .971 r
.58634 .34624 m .57391 .33838 L .57369 .32466 L p F P
0 0 0 r
s
.545 .731 .921 r
.55894 .31874 m .57369 .32466 L .57391 .33838 L p F P
0 0 0 r
s
.391 .529 .7 r
.52532 .31393 m .50812 .31531 L .50821 .30169 L p F P
0 0 0 r
s
.391 .529 .7 r
.50821 .30169 m .52532 .30032 L .52532 .31393 L p F P
0 0 0 r
s
.225 .313 .441 r
.4768 .35281 m .46454 .3608 L .46483 .34697 L p F P
0 0 0 r
s
.225 .313 .441 r
.46483 .34697 m .47703 .33896 L .4768 .35281 L p F P
0 0 0 r
s
.496 .666 .853 r
.55894 .31874 m .54255 .3151 L .54247 .30148 L p F P
0 0 0 r
s
.444 .598 .779 r
.52532 .30032 m .54247 .30148 L .54255 .3151 L p F P
0 0 0 r
s
.69 .09 .12 r
.54386 .30158 m
.54873 .30257 L
s
.588 .794 .966 r
.58662 .36008 m .59612 .36946 L .59645 .3834 L p F P
0 0 0 r
s
.588 .794 .966 r
.59612 .36946 m .58662 .36008 L .58634 .34624 L p F P
0 0 0 r
s
.092 .135 .216 r
.60527 .47247 m .60035 .48284 L .6007 .49732 L p F P
0 0 0 r
s
.092 .135 .216 r
.60035 .48284 m .60527 .47247 L .6049 .4581 L p F P
0 0 0 r
s
.584 .784 .971 r
.57391 .33838 m .58634 .34624 L .58662 .36008 L p F P
0 0 0 r
s
.576 .776 .973 r
.47127 .55939 m .48535 .56552 L .48554 .55072 L p F P
0 0 0 r
s
.576 .776 .973 r
.48554 .55072 m .47153 .54457 L .47127 .55939 L p F P
0 0 0 r
s
.444 .598 .779 r
.54255 .3151 m .52532 .31393 L .52532 .30032 L p F P
0 0 0 r
s
.69 .09 .12 r
.53325 .29942 m
.54386 .30158 L
s
.328 .45 .612 r
.55223 .56945 m .56796 .56509 L .56776 .55029 L p F P
0 0 0 r
s
.275 .382 .53 r
.5816 .54398 m .56776 .55029 L .56796 .56509 L p F P
0 0 0 r
s
.337 .479 .557 r
.44548 .46253 m .44706 .47335 L .44744 .45898 L p F P
0 0 0 r
s
.337 .479 .557 r
.44744 .45898 m .44586 .44812 L .44548 .46253 L p F P
0 0 0 r
s
.061 .09 .132 r
.60617 .44721 m .6049 .4581 L .60527 .47247 L p F P
0 0 0 r
s
.061 .09 .132 r
.6049 .4581 m .60617 .44721 L .60579 .43294 L p F P
0 0 0 r
s
.481 .649 .84 r
.50108 .58464 m .51808 .58673 L .51811 .57181 L p F P
0 0 0 r
s
.481 .649 .84 r
.51811 .57181 m .5012 .56972 L .50108 .58464 L p F P
0 0 0 r
s
.431 .584 .767 r
.53537 .57172 m .51811 .57181 L .51808 .58673 L p F P
0 0 0 r
s
.431 .584 .767 r
.51808 .58673 m .53542 .58664 L .53537 .57172 L p F P
0 0 0 r
s
.38 .517 .692 r
.55223 .56945 m .53537 .57172 L .53542 .58664 L p F P
0 0 0 r
s
.329 .937 .687 r
.51049 .2948 m .51973 .29597 L .52044 .29433 L closepath p F P
0 0 0 r
s
.281 .758 .494 r
.51049 .2948 m .51938 .29838 L .51973 .29597 L closepath p F P
0 0 0 r
s
.007 .179 .01 r
.51049 .2948 m .51973 .29916 L .51938 .29838 L closepath p F P
0 0 0 r
s
.06 .088 .128 r
.44805 .43723 m .44586 .44812 L .44624 .43384 L p F P
0 0 0 r
s
.06 .088 .128 r
.44624 .43384 m .44842 .42292 L .44805 .43723 L p F P
0 0 0 r
s
.005 .15 .006 r
.51049 .2948 m .52044 .29433 L .52079 .29511 L closepath p F P
0 0 0 r
s
.252 .735 .506 r
.40406 .29657 m .42029 .29177 L .41851 .28806 L closepath p F P
0 0 0 r
s
.059 .336 .098 r
.40406 .29657 m .42018 .29485 L .42029 .29177 L closepath p F P
0 0 0 r
s
.037 .457 .086 r
.40406 .29657 m .41828 .29421 L .42018 .29485 L closepath p F P
0 0 0 r
s
.186 .627 .415 r
.40406 .29657 m .41649 .29049 L .41828 .29421 L closepath p F P
0 0 0 r
s
.245 .864 .51 r
.40406 .29657 m .41851 .28806 L .41661 .28741 L closepath p F P
0 0 0 r
s
.006 .216 .016 r
.40406 .29657 m .41661 .28741 L .41649 .29049 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.41705 .29164 m
.46189 .27463 L
s
.247 .764 .547 r
.51049 .2948 m .52043 .29752 L .51973 .29916 L closepath p F P
0 0 0 r
s
.53 .714 .91 r
.48515 .58047 m .50108 .58464 L .5012 .56972 L p F P
0 0 0 r
s
.53 .714 .91 r
.5012 .56972 m .48535 .56552 L .48515 .58047 L p F P
0 0 0 r
s
.336 .458 .618 r
.50804 .32905 m .49167 .33288 L .49183 .31915 L p F P
0 0 0 r
s
.336 .458 .618 r
.49183 .31915 m .50812 .31531 L .50804 .32905 L p F P
0 0 0 r
s
.336 .475 .553 r
.6033 .42204 m .60579 .43294 L .60617 .44721 L p F P
0 0 0 r
s
.336 .475 .553 r
.60579 .43294 m .6033 .42204 L .60294 .40786 L p F P
0 0 0 r
s
.38 .517 .692 r
.53542 .58664 m .55235 .58438 L .55223 .56945 L p F P
0 0 0 r
s
.328 .45 .612 r
.56796 .56509 m .55223 .56945 L .55235 .58438 L p F P
0 0 0 r
s
.545 .731 .921 r
.57391 .33838 m .5591 .33248 L .55894 .31874 L p F P
0 0 0 r
s
.496 .666 .853 r
.54255 .3151 m .55894 .31874 L .5591 .33248 L p F P
0 0 0 r
s
.206 .625 .379 r
.51049 .2948 m .52079 .29511 L .52043 .29752 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.52053 .29684 m
.53325 .29942 L
s
.09 .132 .21 r
.4543 .4125 m .44842 .42292 L .44879 .40875 L p F P
0 0 0 r
s
.09 .132 .21 r
.44879 .40875 m .45464 .3983 L .4543 .4125 L p F P
0 0 0 r
s
.604 .823 .997 r
.45122 .5275 m .4599 .53671 L .46022 .522 L p F P
0 0 0 r
s
.604 .823 .997 r
.46022 .522 m .45158 .51274 L .45122 .5275 L p F P
0 0 0 r
s
.495 .68 .818 r
.59679 .39747 m .60294 .40786 L .6033 .42204 L p F P
0 0 0 r
s
.495 .68 .818 r
.60294 .40786 m .59679 .39747 L .59645 .3834 L p F P
0 0 0 r
s
.61 .825 1 r
.45959 .55157 m .47127 .55939 L .47153 .54457 L p F P
0 0 0 r
s
.61 .825 1 r
.47153 .54457 m .4599 .53671 L .45959 .55157 L p F P
0 0 0 r
s
.28 .387 .532 r
.49151 .34675 m .4768 .35281 L .47703 .33896 L p F P
0 0 0 r
s
.28 .387 .532 r
.47703 .33896 m .49167 .33288 L .49151 .34675 L p F P
0 0 0 r
s
.223 .312 .442 r
.5816 .54398 m .593 .536 L .59268 .52128 L p F P
0 0 0 r
s
.159 .222 .331 r
.60106 .51193 m .59268 .52128 L .593 .536 L p F P
0 0 0 r
s
.159 .222 .331 r
.59268 .52128 m .60106 .51193 L .6007 .49732 L p F P
0 0 0 r
s
.275 .382 .53 r
.56796 .56509 m .58186 .55881 L .5816 .54398 L p F P
0 0 0 r
s
.223 .312 .442 r
.593 .536 m .5816 .54398 L .58186 .55881 L p F P
0 0 0 r
s
.163 .225 .333 r
.46395 .38886 m .45464 .3983 L .45498 .38423 L p F P
0 0 0 r
s
.163 .225 .333 r
.45498 .38423 m .46425 .37476 L .46395 .38886 L p F P
0 0 0 r
s
.494 .685 .822 r
.44631 .50251 m .45158 .51274 L .45193 .49813 L p F P
0 0 0 r
s
.494 .685 .822 r
.45193 .49813 m .44669 .48786 L .44631 .50251 L p F P
0 0 0 r
s
.584 .784 .971 r
.58662 .36008 m .57414 .35223 L .57391 .33838 L p F P
0 0 0 r
s
.545 .731 .921 r
.5591 .33248 m .57391 .33838 L .57414 .35223 L p F P
0 0 0 r
s
.391 .529 .7 r
.52531 .32768 m .50804 .32905 L .50812 .31531 L p F P
0 0 0 r
s
.391 .529 .7 r
.50812 .31531 m .52532 .31393 L .52531 .32768 L p F P
0 0 0 r
s
.225 .313 .441 r
.47656 .3668 m .46425 .37476 L .46454 .3608 L p F P
0 0 0 r
s
.225 .313 .441 r
.46454 .3608 m .4768 .35281 L .47656 .3668 L p F P
0 0 0 r
s
.496 .666 .853 r
.5591 .33248 m .54263 .32884 L .54255 .3151 L p F P
0 0 0 r
s
.444 .598 .779 r
.52532 .31393 m .54255 .3151 L .54263 .32884 L p F P
0 0 0 r
s
.588 .794 .966 r
.58691 .37404 m .59645 .3834 L .59679 .39747 L p F P
0 0 0 r
s
.588 .794 .966 r
.59645 .3834 m .58691 .37404 L .58662 .36008 L p F P
0 0 0 r
s
.092 .135 .216 r
.60565 .48699 m .6007 .49732 L .60106 .51193 L p F P
0 0 0 r
s
.092 .135 .216 r
.6007 .49732 m .60565 .48699 L .60527 .47247 L p F P
0 0 0 r
s
.584 .784 .971 r
.57414 .35223 m .58662 .36008 L .58691 .37404 L p F P
0 0 0 r
s
.576 .776 .973 r
.471 .57436 m .48515 .58047 L .48535 .56552 L p F P
0 0 0 r
s
.576 .776 .973 r
.48535 .56552 m .47127 .55939 L .471 .57436 L p F P
0 0 0 r
s
.444 .598 .779 r
.54263 .32884 m .52531 .32768 L .52532 .31393 L p F P
0 0 0 r
s
.328 .45 .612 r
.55235 .58438 m .56815 .58003 L .56796 .56509 L p F P
0 0 0 r
s
.275 .382 .53 r
.58186 .55881 m .56796 .56509 L .56815 .58003 L p F P
0 0 0 r
s
.337 .479 .557 r
.44509 .47708 m .44669 .48786 L .44706 .47335 L p F P
0 0 0 r
s
.337 .479 .557 r
.44706 .47335 m .44548 .46253 L .44509 .47708 L p F P
0 0 0 r
s
.061 .09 .132 r
.60655 .46163 m .60527 .47247 L .60565 .48699 L p F P
0 0 0 r
s
.061 .09 .132 r
.60527 .47247 m .60655 .46163 L .60617 .44721 L p F P
0 0 0 r
s
.481 .649 .84 r
.50096 .59971 m .51804 .60179 L .51808 .58673 L p F P
0 0 0 r
s
.481 .649 .84 r
.51808 .58673 m .50108 .58464 L .50096 .59971 L p F P
0 0 0 r
s
.431 .584 .767 r
.53542 .58664 m .51808 .58673 L .51804 .60179 L p F P
0 0 0 r
s
.431 .584 .767 r
.51804 .60179 m .53546 .6017 L .53542 .58664 L p F P
0 0 0 r
s
.38 .517 .692 r
.55235 .58438 m .53542 .58664 L .53546 .6017 L p F P
0 0 0 r
s
.021 .262 .046 r
.64906 .61277 m .63554 .61745 L .63566 .62088 L closepath p F P
0 0 0 r
s
.184 .624 .414 r
.64906 .61277 m .63388 .61391 L .63554 .61745 L closepath p F P
0 0 0 r
s
.06 .088 .128 r
.44767 .45168 m .44548 .46253 L .44586 .44812 L p F P
0 0 0 r
s
.06 .088 .128 r
.44586 .44812 m .44805 .43723 L .44767 .45168 L p F P
0 0 0 r
s
0 .307 0 r
.64906 .61277 m .63233 .6138 L .63388 .61391 L closepath p F P
0 0 0 r
s
.53 .714 .91 r
.48496 .59555 m .50096 .59971 L .50108 .58464 L p F P
0 0 0 r
s
.53 .714 .91 r
.50108 .58464 m .48515 .58047 L .48496 .59555 L p F P
0 0 0 r
s
.336 .458 .618 r
.50795 .34293 m .49151 .34675 L .49167 .33288 L p F P
0 0 0 r
s
.336 .458 .618 r
.49167 .33288 m .50804 .32905 L .50795 .34293 L p F P
0 0 0 r
s
.336 .475 .553 r
.60367 .43635 m .60617 .44721 L .60655 .46163 L p F P
0 0 0 r
s
.336 .475 .553 r
.60617 .44721 m .60367 .43635 L .6033 .42204 L p F P
0 0 0 r
s
.38 .517 .692 r
.53546 .6017 m .55248 .59945 L .55235 .58438 L p F P
0 0 0 r
s
.328 .45 .612 r
.56815 .58003 m .55235 .58438 L .55248 .59945 L p F P
0 0 0 r
s
.545 .731 .921 r
.57414 .35223 m .55926 .34634 L .5591 .33248 L p F P
0 0 0 r
s
.496 .666 .853 r
.54263 .32884 m .5591 .33248 L .55926 .34634 L p F P
0 0 0 r
s
.055 .549 .117 r
.64906 .61277 m .63566 .62088 L .63411 .62078 L closepath p F P
0 0 0 r
s
.09 .132 .21 r
.45395 .42684 m .44805 .43723 L .44842 .42292 L p F P
0 0 0 r
s
.09 .132 .21 r
.44842 .42292 m .4543 .4125 L .45395 .42684 L p F P
0 0 0 r
s
.604 .823 .997 r
.45086 .54239 m .45959 .55157 L .4599 .53671 L p F P
0 0 0 r
s
.604 .823 .997 r
.4599 .53671 m .45122 .5275 L .45086 .54239 L p F P
0 0 0 r
s
.495 .68 .818 r
.59712 .41168 m .6033 .42204 L .60367 .43635 L p F P
0 0 0 r
s
.495 .68 .818 r
.6033 .42204 m .59712 .41168 L .59679 .39747 L p F P
0 0 0 r
s
.61 .825 1 r
.45927 .56657 m .471 .57436 L .47127 .55939 L p F P
0 0 0 r
s
.61 .825 1 r
.47127 .55939 m .45959 .55157 L .45927 .56657 L p F P
0 0 0 r
s
.074 .367 .127 r
.64906 .61277 m .63244 .61724 L .63233 .6138 L closepath p F P
0 0 0 r
s
.28 .387 .532 r
.49134 .36075 m .47656 .3668 L .4768 .35281 L p F P
0 0 0 r
s
.28 .387 .532 r
.4768 .35281 m .49151 .34675 L .49134 .36075 L p F P
0 0 0 r
s
.223 .312 .442 r
.58186 .55881 m .59332 .55086 L .593 .536 L p F P
0 0 0 r
s
.159 .222 .331 r
.60141 .52669 m .593 .536 L .59332 .55086 L p F P
0 0 0 r
s
.159 .222 .331 r
.593 .536 m .60141 .52669 L .60106 .51193 L p F P
0 0 0 r
s
.275 .382 .53 r
.56815 .58003 m .58213 .57378 L .58186 .55881 L p F P
0 0 0 r
s
.223 .312 .442 r
.59332 .55086 m .58186 .55881 L .58213 .57378 L p F P
0 0 0 r
s
.163 .225 .333 r
.46366 .40309 m .4543 .4125 L .45464 .3983 L p F P
0 0 0 r
s
.163 .225 .333 r
.45464 .3983 m .46395 .38886 L .46366 .40309 L p F P
0 0 0 r
s
.378 1 .73 r
.61253 .27121 m .61677 .28109 L .61997 .27836 L closepath p F P
0 0 0 r
s
.019 .367 .027 r
.61253 .27121 m .61687 .28416 L .61677 .28109 L closepath p F P
0 0 0 r
s
.085 .486 .214 r
.61253 .27121 m .61997 .27836 L .62327 .2787 L closepath p F P
0 0 0 r
s
.494 .685 .822 r
.44592 .5173 m .45122 .5275 L .45158 .51274 L p F P
0 0 0 r
s
.494 .685 .822 r
.45158 .51274 m .44631 .50251 L .44592 .5173 L p F P
0 0 0 r
s
.584 .784 .971 r
.58691 .37404 m .57437 .36622 L .57414 .35223 L p F P
0 0 0 r
s
.545 .731 .921 r
.55926 .34634 m .57414 .35223 L .57437 .36622 L p F P
0 0 0 r
s
.391 .529 .7 r
.52531 .34156 m .50795 .34293 L .50804 .32905 L p F P
0 0 0 r
s
.391 .529 .7 r
.50804 .32905 m .52531 .32768 L .52531 .34156 L p F P
0 0 0 r
s
.254 .74 .511 r
.64906 .61277 m .63411 .62078 L .63244 .61724 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.5893 .63091 m
.63268 .61774 L
s
.225 .313 .441 r
.47633 .38091 m .46395 .38886 L .46425 .37476 L p F P
0 0 0 r
s
.225 .313 .441 r
.46425 .37476 m .47656 .3668 L .47633 .38091 L p F P
0 0 0 r
s
.496 .666 .853 r
.55926 .34634 m .54271 .34272 L .54263 .32884 L p F P
0 0 0 r
s
.444 .598 .779 r
.52531 .32768 m .54263 .32884 L .54271 .34272 L p F P
0 0 0 r
s
.588 .794 .966 r
.5872 .38814 m .59679 .39747 L .59712 .41168 L p F P
0 0 0 r
s
.588 .794 .966 r
.59679 .39747 m .5872 .38814 L .58691 .37404 L p F P
0 0 0 r
s
.092 .135 .216 r
.60603 .50164 m .60106 .51193 L .60141 .52669 L p F P
0 0 0 r
s
.092 .135 .216 r
.60106 .51193 m .60603 .50164 L .60565 .48699 L p F P
0 0 0 r
s
.584 .784 .971 r
.57437 .36622 m .58691 .37404 L .5872 .38814 L p F P
0 0 0 r
s
.576 .776 .973 r
.47074 .58947 m .48496 .59555 L .48515 .58047 L p F P
0 0 0 r
s
.576 .776 .973 r
.48515 .58047 m .471 .57436 L .47074 .58947 L p F P
0 0 0 r
s
.444 .598 .779 r
.54271 .34272 m .52531 .34156 L .52531 .32768 L p F P
0 0 0 r
s
.328 .45 .612 r
.55248 .59945 m .56836 .59512 L .56815 .58003 L p F P
0 0 0 r
s
.275 .382 .53 r
.58213 .57378 m .56815 .58003 L .56836 .59512 L p F P
0 0 0 r
s
.148 .573 .368 r
.61253 .27121 m .62017 .28452 L .61687 .28416 L closepath p F P
0 0 0 r
s
.206 .625 .379 r
.54168 .61427 m .53167 .61153 L .53131 .61401 L closepath p F P
0 0 0 r
s
.239 .759 .541 r
.54168 .61427 m .53239 .61015 L .53167 .61153 L closepath p F P
0 0 0 r
s
.043 .267 .058 r
.54168 .61427 m .53276 .61124 L .53239 .61015 L closepath p F P
0 0 0 r
s
.281 .759 .494 r
.54168 .61427 m .5324 .61372 L .53276 .61124 L closepath p F P
0 0 0 r
s
.026 .226 .034 r
.54168 .61427 m .53131 .61401 L .53168 .61511 L closepath p F P
0 0 0 r
s
.315 .932 .666 r
.54168 .61427 m .53168 .61511 L .5324 .61372 L closepath p F P
0 0 0 r
s
.337 .479 .557 r
.4447 .49176 m .44631 .50251 L .44669 .48786 L p F P
0 0 0 r
s
.337 .479 .557 r
.44669 .48786 m .44509 .47708 L .4447 .49176 L p F P
0 0 0 r
s
.207 .608 .298 r
.61253 .27121 m .62327 .2787 L .62337 .28178 L closepath p F P
0 0 0 r
s
.061 .09 .132 r
.60693 .47618 m .60565 .48699 L .60603 .50164 L p F P
0 0 0 r
s
.061 .09 .132 r
.60565 .48699 m .60693 .47618 L .60655 .46163 L p F P
0 0 0 r
s
.481 .649 .84 r
.50084 .61492 m .518 .61699 L .51804 .60179 L p F P
0 0 0 r
s
.481 .649 .84 r
.51804 .60179 m .50096 .59971 L .50084 .61492 L p F P
0 0 0 r
s
.431 .584 .767 r
.53546 .6017 m .51804 .60179 L .518 .61699 L p F P
0 0 0 r
s
.431 .584 .767 r
.518 .61699 m .5355 .6169 L .53546 .6017 L p F P
0 0 0 r
s
.38 .517 .692 r
.55248 .59945 m .53546 .6017 L .5355 .6169 L p F P
0 0 0 r
s
.328 .878 .63 r
.61253 .27121 m .62337 .28178 L .62017 .28452 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.6215 .28338 m
.64223 .31148 L
s
.06 .088 .128 r
.4473 .46626 m .44509 .47708 L .44548 .46253 L p F P
0 0 0 r
s
.06 .088 .128 r
.44548 .46253 m .44767 .45168 L .4473 .46626 L p F P
0 0 0 r
s
.53 .714 .91 r
.48476 .61078 m .50084 .61492 L .50096 .59971 L p F P
0 0 0 r
s
.53 .714 .91 r
.50096 .59971 m .48496 .59555 L .48476 .61078 L p F P
0 0 0 r
s
.336 .458 .618 r
.50786 .35694 m .49134 .36075 L .49151 .34675 L p F P
0 0 0 r
s
.336 .458 .618 r
.49151 .34675 m .50795 .34293 L .50786 .35694 L p F P
0 0 0 r
s
.336 .475 .553 r
.60404 .4508 m .60655 .46163 L .60693 .47618 L p F P
0 0 0 r
s
.336 .475 .553 r
.60655 .46163 m .60404 .4508 L .60367 .43635 L p F P
0 0 0 r
s
.38 .517 .692 r
.5355 .6169 m .5526 .61466 L .55248 .59945 L p F P
0 0 0 r
s
.328 .45 .612 r
.56836 .59512 m .55248 .59945 L .5526 .61466 L p F P
0 0 0 r
s
.545 .731 .921 r
.57437 .36622 m .55942 .36034 L .55926 .34634 L p F P
0 0 0 r
s
.496 .666 .853 r
.54271 .34272 m .55926 .34634 L .55942 .36034 L p F P
0 0 0 r
s
.09 .132 .21 r
.4536 .44132 m .44767 .45168 L .44805 .43723 L p F P
0 0 0 r
s
.09 .132 .21 r
.44805 .43723 m .45395 .42684 L .4536 .44132 L p F P
0 0 0 r
s
.604 .823 .997 r
.4505 .55743 m .45927 .56657 L .45959 .55157 L p F P
0 0 0 r
s
.604 .823 .997 r
.45959 .55157 m .45086 .54239 L .4505 .55743 L p F P
0 0 0 r
s
.495 .68 .818 r
.59747 .42602 m .60367 .43635 L .60404 .4508 L p F P
0 0 0 r
s
.495 .68 .818 r
.60367 .43635 m .59747 .42602 L .59712 .41168 L p F P
0 0 0 r
s
.61 .825 1 r
.45895 .58172 m .47074 .58947 L .471 .57436 L p F P
0 0 0 r
s
.61 .825 1 r
.471 .57436 m .45927 .56657 L .45895 .58172 L p F P
0 0 0 r
s
.28 .387 .532 r
.49117 .37488 m .47633 .38091 L .47656 .3668 L p F P
0 0 0 r
s
.28 .387 .532 r
.47656 .3668 m .49134 .36075 L .49117 .37488 L p F P
0 0 0 r
s
.223 .312 .442 r
.58213 .57378 m .59364 .56586 L .59332 .55086 L p F P
0 0 0 r
s
.159 .222 .331 r
.60178 .54158 m .59332 .55086 L .59364 .56586 L p F P
0 0 0 r
s
.159 .222 .331 r
.59332 .55086 m .60178 .54158 L .60141 .52669 L p F P
0 0 0 r
s
.275 .382 .53 r
.56836 .59512 m .5824 .58889 L .58213 .57378 L p F P
0 0 0 r
s
.223 .312 .442 r
.59364 .56586 m .58213 .57378 L .5824 .58889 L p F P
0 0 0 r
s
.163 .225 .333 r
.46335 .41746 m .45395 .42684 L .4543 .4125 L p F P
0 0 0 r
s
.163 .225 .333 r
.4543 .4125 m .46366 .40309 L .46335 .41746 L p F P
0 0 0 r
s
.494 .685 .822 r
.44554 .53224 m .45086 .54239 L .45122 .5275 L p F P
0 0 0 r
s
.494 .685 .822 r
.45122 .5275 m .44592 .5173 L .44554 .53224 L p F P
0 0 0 r
s
.584 .784 .971 r
.5872 .38814 m .5746 .38034 L .57437 .36622 L p F P
0 0 0 r
s
.545 .731 .921 r
.55942 .36034 m .57437 .36622 L .5746 .38034 L p F P
0 0 0 r
s
.391 .529 .7 r
.52531 .35557 m .50786 .35694 L .50795 .34293 L p F P
0 0 0 r
s
.391 .529 .7 r
.50795 .34293 m .52531 .34156 L .52531 .35557 L p F P
0 0 0 r
s
.225 .313 .441 r
.47609 .39517 m .46366 .40309 L .46395 .38886 L p F P
0 0 0 r
s
.225 .313 .441 r
.46395 .38886 m .47633 .38091 L .47609 .39517 L p F P
0 0 0 r
s
.496 .666 .853 r
.55942 .36034 m .54279 .35673 L .54271 .34272 L p F P
0 0 0 r
s
.444 .598 .779 r
.52531 .34156 m .54271 .34272 L .54279 .35673 L p F P
0 0 0 r
s
.588 .794 .966 r
.58749 .40237 m .59712 .41168 L .59747 .42602 L p F P
0 0 0 r
s
.588 .794 .966 r
.59712 .41168 m .58749 .40237 L .5872 .38814 L p F P
0 0 0 r
s
.092 .135 .216 r
.60642 .51643 m .60141 .52669 L .60178 .54158 L p F P
0 0 0 r
s
.092 .135 .216 r
.60141 .52669 m .60642 .51643 L .60603 .50164 L p F P
0 0 0 r
s
.252 .736 .507 r
.3532 .27292 m .37613 .26608 L .37357 .26079 L closepath p F P
0 0 0 r
s
.056 .329 .092 r
.3532 .27292 m .3759 .2704 L .37613 .26608 L closepath p F P
0 0 0 r
s
.044 .473 .104 r
.3532 .27292 m .3731 .26944 L .3759 .2704 L closepath p F P
0 0 0 r
s
.185 .626 .415 r
.3532 .27292 m .37053 .26413 L .3731 .26944 L closepath p F P
0 0 0 r
s
.256 .881 .533 r
.3532 .27292 m .37357 .26079 L .37077 .25981 L closepath p F P
0 0 0 r
s
.004 .206 .011 r
.3532 .27292 m .37077 .25981 L .37053 .26413 L closepath p F P
0 0 0 r
s
.584 .784 .971 r
.5746 .38034 m .5872 .38814 L .58749 .40237 L p F P
0 0 0 r
s
.69 .09 .12 r
.37137 .26587 m
.43472 .2413 L
s
.231 .648 .343 r
.47414 .60569 m .46725 .60012 L .46721 .6022 L closepath p F P
0 0 0 r
s
.001 .29 .003 r
.47414 .60569 m .46721 .6022 L .4691 .60263 L closepath p F P
0 0 0 r
s
.333 .888 .639 r
.47414 .60569 m .46918 .59848 L .46725 .60012 L closepath p F P
0 0 0 r
s
.12 .515 .306 r
.47414 .60569 m .47107 .59891 L .46918 .59848 L closepath p F P
0 0 0 r
s
.097 .497 .142 r
.47414 .60569 m .47103 .60099 L .47107 .59891 L closepath p F P
0 0 0 r
s
.374 1 .722 r
.47414 .60569 m .4691 .60263 L .47103 .60099 L closepath p F P
0 0 0 r
s
.576 .776 .973 r
.47047 .60473 m .48476 .61078 L .48496 .59555 L p F P
0 0 0 r
s
.576 .776 .973 r
.48496 .59555 m .47074 .58947 L .47047 .60473 L p F P
0 0 0 r
s
.444 .598 .779 r
.54279 .35673 m .52531 .35557 L .52531 .34156 L p F P
0 0 0 r
s
.328 .45 .612 r
.5526 .61466 m .56856 .61035 L .56836 .59512 L p F P
0 0 0 r
s
.275 .382 .53 r
.5824 .58889 m .56836 .59512 L .56856 .61035 L p F P
0 0 0 r
s
.337 .479 .557 r
.44431 .50659 m .44592 .5173 L .44631 .50251 L p F P
0 0 0 r
s
.337 .479 .557 r
.44631 .50251 m .4447 .49176 L .44431 .50659 L p F P
0 0 0 r
s
0 .078 0 r
.33575 .94018 m .30856 .93107 L .31516 .93352 L closepath p F P
0 0 0 r
s
.244 .671 .372 r
.33575 .94018 m .30908 .92263 L .30856 .93107 L closepath p F P
0 0 0 r
s
.337 .898 .648 r
.33575 .94018 m .31618 .91663 L .30908 .92263 L closepath p F P
0 0 0 r
s
.07 .408 .184 r
.33575 .94018 m .32278 .91904 L .31618 .91663 L closepath p F P
0 0 0 r
s
.174 .611 .255 r
.33575 .94018 m .32229 .92749 L .32278 .91904 L closepath p F P
0 0 0 r
s
.362 1 .7 r
.33575 .94018 m .31516 .93352 L .32229 .92749 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.25254 .87752 m
.3207 .92884 L
s
.061 .09 .132 r
.60732 .49087 m .60603 .50164 L .60642 .51643 L p F P
0 0 0 r
s
.061 .09 .132 r
.60603 .50164 m .60732 .49087 L .60693 .47618 L p F P
0 0 0 r
s
.481 .649 .84 r
.50072 .63028 m .51796 .63234 L .518 .61699 L p F P
0 0 0 r
s
.481 .649 .84 r
.518 .61699 m .50084 .61492 L .50072 .63028 L p F P
0 0 0 r
s
.431 .584 .767 r
.5355 .6169 m .518 .61699 L .51796 .63234 L p F P
0 0 0 r
s
.431 .584 .767 r
.51796 .63234 m .53555 .63225 L .5355 .6169 L p F P
0 0 0 r
s
.38 .517 .692 r
.5526 .61466 m .5355 .6169 L .53555 .63225 L p F P
0 0 0 r
s
.06 .088 .128 r
.44691 .48099 m .4447 .49176 L .44509 .47708 L p F P
0 0 0 r
s
.06 .088 .128 r
.44509 .47708 m .4473 .46626 L .44691 .48099 L p F P
0 0 0 r
s
.53 .714 .91 r
.48456 .62616 m .50072 .63028 L .50084 .61492 L p F P
0 0 0 r
s
.53 .714 .91 r
.50084 .61492 m .48476 .61078 L .48456 .62616 L p F P
0 0 0 r
s
.336 .458 .618 r
.50778 .37108 m .49117 .37488 L .49134 .36075 L p F P
0 0 0 r
s
.336 .458 .618 r
.49134 .36075 m .50786 .35694 L .50778 .37108 L p F P
0 0 0 r
s
.336 .475 .553 r
.60442 .46538 m .60693 .47618 L .60732 .49087 L p F P
0 0 0 r
s
.336 .475 .553 r
.60693 .47618 m .60442 .46538 L .60404 .4508 L p F P
0 0 0 r
s
.045 .279 .06 r
.57329 .93812 m .54199 .93749 L .54312 .94178 L closepath p F P
0 0 0 r
s
.206 .625 .38 r
.57329 .93812 m .54307 .92987 L .54199 .93749 L closepath p F P
0 0 0 r
s
.224 .741 .519 r
.57329 .93812 m .54528 .9265 L .54307 .92987 L closepath p F P
0 0 0 r
s
.282 .759 .494 r
.57329 .93812 m .54535 .93842 L .54643 .93076 L closepath p F P
0 0 0 r
s
.27 .882 .584 r
.57329 .93812 m .54312 .94178 L .54535 .93842 L closepath p F P
0 0 0 r
s
.076 .334 .101 r
.57329 .93812 m .54643 .93076 L .54528 .9265 L closepath p F P
0 0 0 r
s
.38 .517 .692 r
.53555 .63225 m .55273 .63002 L .5526 .61466 L p F P
0 0 0 r
s
.328 .45 .612 r
.56856 .61035 m .5526 .61466 L .55273 .63002 L p F P
0 0 0 r
s
.69 .09 .12 r
.45587 .92202 m
.54592 .93437 L
s
.545 .731 .921 r
.5746 .38034 m .55958 .37448 L .55942 .36034 L p F P
0 0 0 r
s
.496 .666 .853 r
.54279 .35673 m .55942 .36034 L .55958 .37448 L p F P
0 0 0 r
s
.09 .132 .21 r
.45325 .45594 m .4473 .46626 L .44767 .45168 L p F P
0 0 0 r
s
.09 .132 .21 r
.44767 .45168 m .4536 .44132 L .45325 .45594 L p F P
0 0 0 r
s
.604 .823 .997 r
.45013 .57261 m .45895 .58172 L .45927 .56657 L p F P
0 0 0 r
s
.604 .823 .997 r
.45927 .56657 m .4505 .55743 L .45013 .57261 L p F P
0 0 0 r
s
.495 .68 .818 r
.59781 .4405 m .60404 .4508 L .60442 .46538 L p F P
0 0 0 r
s
.495 .68 .818 r
.60404 .4508 m .59781 .4405 L .59747 .42602 L p F P
0 0 0 r
s
.61 .825 1 r
.45862 .59701 m .47047 .60473 L .47074 .58947 L p F P
0 0 0 r
s
.61 .825 1 r
.47074 .58947 m .45895 .58172 L .45862 .59701 L p F P
0 0 0 r
s
.28 .387 .532 r
.49101 .38915 m .47609 .39517 L .47633 .38091 L p F P
0 0 0 r
s
.28 .387 .532 r
.47633 .38091 m .49117 .37488 L .49101 .38915 L p F P
0 0 0 r
s
.223 .312 .442 r
.5824 .58889 m .59397 .58101 L .59364 .56586 L p F P
0 0 0 r
s
.159 .222 .331 r
.60214 .55662 m .59364 .56586 L .59397 .58101 L p F P
0 0 0 r
s
.159 .222 .331 r
.59364 .56586 m .60214 .55662 L .60178 .54158 L p F P
0 0 0 r
s
.275 .382 .53 r
.56856 .61035 m .58267 .60415 L .5824 .58889 L p F P
0 0 0 r
s
.223 .312 .442 r
.59397 .58101 m .5824 .58889 L .58267 .60415 L p F P
0 0 0 r
s
.163 .225 .333 r
.46305 .43196 m .4536 .44132 L .45395 .42684 L p F P
0 0 0 r
s
.163 .225 .333 r
.45395 .42684 m .46335 .41746 L .46305 .43196 L p F P
0 0 0 r
s
.494 .685 .822 r
.44515 .54732 m .4505 .55743 L .45086 .54239 L p F P
0 0 0 r
s
.494 .685 .822 r
.45086 .54239 m .44554 .53224 L .44515 .54732 L p F P
0 0 0 r
s
.584 .784 .971 r
.58749 .40237 m .57484 .39459 L .5746 .38034 L p F P
0 0 0 r
s
.545 .731 .921 r
.55958 .37448 m .5746 .38034 L .57484 .39459 L p F P
0 0 0 r
s
.391 .529 .7 r
.5253 .36972 m .50778 .37108 L .50786 .35694 L p F P
0 0 0 r
s
.391 .529 .7 r
.50786 .35694 m .52531 .35557 L .5253 .36972 L p F P
0 0 0 r
s
.225 .313 .441 r
.47584 .40956 m .46335 .41746 L .46366 .40309 L p F P
0 0 0 r
s
.225 .313 .441 r
.46366 .40309 m .47609 .39517 L .47584 .40956 L p F P
0 0 0 r
s
.496 .666 .853 r
.55958 .37448 m .54287 .37088 L .54279 .35673 L p F P
0 0 0 r
s
.444 .598 .779 r
.52531 .35557 m .54279 .35673 L .54287 .37088 L p F P
0 0 0 r
s
.588 .794 .966 r
.58779 .41674 m .59747 .42602 L .59781 .4405 L p F P
0 0 0 r
s
.588 .794 .966 r
.59747 .42602 m .58779 .41674 L .58749 .40237 L p F P
0 0 0 r
s
.092 .135 .216 r
.60681 .53137 m .60178 .54158 L .60214 .55662 L p F P
0 0 0 r
s
.092 .135 .216 r
.60178 .54158 m .60681 .53137 L .60642 .51643 L p F P
0 0 0 r
s
.584 .784 .971 r
.57484 .39459 m .58749 .40237 L .58779 .41674 L p F P
0 0 0 r
s
.576 .776 .973 r
.4702 .62013 m .48456 .62616 L .48476 .61078 L p F P
0 0 0 r
s
.576 .776 .973 r
.48476 .61078 m .47047 .60473 L .4702 .62013 L p F P
0 0 0 r
s
.444 .598 .779 r
.54287 .37088 m .5253 .36972 L .52531 .35557 L p F P
0 0 0 r
s
.328 .45 .612 r
.55273 .63002 m .56877 .62573 L .56856 .61035 L p F P
0 0 0 r
s
.275 .382 .53 r
.58267 .60415 m .56856 .61035 L .56877 .62573 L p F P
0 0 0 r
s
.337 .479 .557 r
.44391 .52157 m .44554 .53224 L .44592 .5173 L p F P
0 0 0 r
s
.337 .479 .557 r
.44592 .5173 m .44431 .50659 L .44391 .52157 L p F P
0 0 0 r
s
.061 .09 .132 r
.60772 .5057 m .60642 .51643 L .60681 .53137 L p F P
0 0 0 r
s
.061 .09 .132 r
.60642 .51643 m .60772 .5057 L .60732 .49087 L p F P
0 0 0 r
s
.481 .649 .84 r
.5006 .64579 m .51792 .64784 L .51796 .63234 L p F P
0 0 0 r
s
.481 .649 .84 r
.51796 .63234 m .50072 .63028 L .5006 .64579 L p F P
0 0 0 r
s
.431 .584 .767 r
.53555 .63225 m .51796 .63234 L .51792 .64784 L p F P
0 0 0 r
s
.431 .584 .767 r
.51792 .64784 m .5356 .64775 L .53555 .63225 L p F P
0 0 0 r
s
.38 .517 .692 r
.55273 .63002 m .53555 .63225 L .5356 .64775 L p F P
0 0 0 r
s
.018 .253 .04 r
.60075 .59279 m .59266 .59569 L .5927 .59776 L closepath p F P
0 0 0 r
s
.183 .623 .413 r
.60075 .59279 m .59163 .59353 L .59266 .59569 L closepath p F P
0 0 0 r
s
.329 .937 .687 r
.49959 .25375 m .51533 .25588 L .51652 .25303 L closepath p F P
0 0 0 r
s
.282 .76 .495 r
.49959 .25375 m .51472 .25997 L .51533 .25588 L closepath p F P
0 0 0 r
s
0 .315 0 r
.60075 .59279 m .59065 .59344 L .59163 .59353 L closepath p F P
0 0 0 r
s
.003 .169 .005 r
.49959 .25375 m .51531 .26123 L .51472 .25997 L closepath p F P
0 0 0 r
s
.07 .579 .151 r
.60075 .59279 m .5927 .59776 L .59172 .59768 L closepath p F P
0 0 0 r
s
.06 .088 .128 r
.44653 .49586 m .44431 .50659 L .4447 .49176 L p F P
0 0 0 r
s
.06 .088 .128 r
.4447 .49176 m .44691 .48099 L .44653 .49586 L p F P
0 0 0 r
s
.049 .332 .133 r
.19736 .59615 m .2133 .57676 L .2093 .56936 L closepath p F P
0 0 0 r
s
0 .365 0 r
.19736 .59615 m .20796 .58261 L .2133 .57676 L closepath p F P
0 0 0 r
s
.281 .88 .484 r
.19736 .59615 m .19996 .56778 L .19458 .5736 L closepath p F P
0 0 0 r
s
.305 .864 .634 r
.19736 .59615 m .2093 .56936 L .19996 .56778 L closepath p F P
0 0 0 r
s
.2 .738 .468 r
.19736 .59615 m .19858 .58103 L .20796 .58261 L closepath p F P
0 0 0 r
s
0 .141 0 r
.19736 .59615 m .19458 .5736 L .19858 .58103 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.20194 .5816 m
.22476 .50893 L
s
.53 .714 .91 r
.48436 .64169 m .5006 .64579 L .50072 .63028 L p F P
0 0 0 r
s
.53 .714 .91 r
.50072 .63028 m .48456 .62616 L .48436 .64169 L p F P
0 0 0 r
s
.336 .458 .618 r
.50769 .38536 m .49101 .38915 L .49117 .37488 L p F P
0 0 0 r
s
.336 .458 .618 r
.49117 .37488 m .50778 .37108 L .50769 .38536 L p F P
0 0 0 r
s
.336 .475 .553 r
.6048 .48011 m .60732 .49087 L .60772 .5057 L p F P
0 0 0 r
s
.336 .475 .553 r
.60732 .49087 m .6048 .48011 L .60442 .46538 L p F P
0 0 0 r
s
.38 .517 .692 r
.5356 .64775 m .55286 .64553 L .55273 .63002 L p F P
0 0 0 r
s
.328 .45 .612 r
.56877 .62573 m .55273 .63002 L .55286 .64553 L p F P
0 0 0 r
s
.545 .731 .921 r
.57484 .39459 m .55974 .38875 L .55958 .37448 L p F P
0 0 0 r
s
.496 .666 .853 r
.54287 .37088 m .55958 .37448 L .55974 .38875 L p F P
0 0 0 r
s
.071 .361 .122 r
.60075 .59279 m .59069 .59552 L .59065 .59344 L closepath p F P
0 0 0 r
s
.254 .74 .512 r
.60075 .59279 m .59172 .59768 L .59069 .59552 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.58598 .59736 m
.59085 .59586 L
s
.002 .135 .003 r
.49959 .25375 m .51652 .25303 L .51711 .25429 L closepath p F P
0 0 0 r
s
.09 .132 .21 r
.4529 .4707 m .44691 .48099 L .4473 .46626 L p F P
0 0 0 r
s
.09 .132 .21 r
.4473 .46626 m .45325 .45594 L .4529 .4707 L p F P
0 0 0 r
s
.247 .764 .547 r
.49959 .25375 m .5165 .25839 L .51531 .26123 L closepath p F P
0 0 0 r
s
.604 .823 .997 r
.44976 .58794 m .45862 .59701 L .45895 .58172 L p F P
0 0 0 r
s
.604 .823 .997 r
.45895 .58172 m .45013 .57261 L .44976 .58794 L p F P
0 0 0 r
s
.495 .68 .818 r
.59816 .45512 m .60442 .46538 L .6048 .48011 L p F P
0 0 0 r
s
.495 .68 .818 r
.60442 .46538 m .59816 .45512 L .59781 .4405 L p F P
0 0 0 r
s
.61 .825 1 r
.45829 .61245 m .4702 .62013 L .47047 .60473 L p F P
0 0 0 r
s
.61 .825 1 r
.47047 .60473 m .45862 .59701 L .45829 .61245 L p F P
0 0 0 r
s
.28 .387 .532 r
.49083 .40356 m .47584 .40956 L .47609 .39517 L p F P
0 0 0 r
s
.28 .387 .532 r
.47609 .39517 m .49101 .38915 L .49083 .40356 L p F P
0 0 0 r
s
.223 .312 .442 r
.58267 .60415 m .5943 .59631 L .59397 .58101 L p F P
0 0 0 r
s
.159 .222 .331 r
.60251 .57181 m .59397 .58101 L .5943 .59631 L p F P
0 0 0 r
s
.159 .222 .331 r
.59397 .58101 m .60251 .57181 L .60214 .55662 L p F P
0 0 0 r
s
.275 .382 .53 r
.56877 .62573 m .58295 .61956 L .58267 .60415 L p F P
0 0 0 r
s
.223 .312 .442 r
.5943 .59631 m .58267 .60415 L .58295 .61956 L p F P
0 0 0 r
s
.163 .225 .333 r
.46274 .44661 m .45325 .45594 L .4536 .44132 L p F P
0 0 0 r
s
.163 .225 .333 r
.4536 .44132 m .46305 .43196 L .46274 .44661 L p F P
0 0 0 r
s
.494 .685 .822 r
.44475 .56254 m .45013 .57261 L .4505 .55743 L p F P
0 0 0 r
s
.494 .685 .822 r
.4505 .55743 m .44515 .54732 L .44475 .56254 L p F P
0 0 0 r
s
.584 .784 .971 r
.58779 .41674 m .57507 .40899 L .57484 .39459 L p F P
0 0 0 r
s
.545 .731 .921 r
.55974 .38875 m .57484 .39459 L .57507 .40899 L p F P
0 0 0 r
s
.391 .529 .7 r
.5253 .38401 m .50769 .38536 L .50778 .37108 L p F P
0 0 0 r
s
.391 .529 .7 r
.50778 .37108 m .5253 .36972 L .5253 .38401 L p F P
0 0 0 r
s
.225 .313 .441 r
.4756 .42409 m .46305 .43196 L .46335 .41746 L p F P
0 0 0 r
s
.225 .313 .441 r
.46335 .41746 m .47584 .40956 L .4756 .42409 L p F P
0 0 0 r
s
.496 .666 .853 r
.55974 .38875 m .54295 .38516 L .54287 .37088 L p F P
0 0 0 r
s
.444 .598 .779 r
.5253 .36972 m .54287 .37088 L .54295 .38516 L p F P
0 0 0 r
s
.588 .794 .966 r
.58809 .43125 m .59781 .4405 L .59816 .45512 L p F P
0 0 0 r
s
.588 .794 .966 r
.59781 .4405 m .58809 .43125 L .58779 .41674 L p F P
0 0 0 r
s
.378 1 .729 r
.64926 .23634 m .65496 .25069 L .65951 .24681 L closepath p F P
0 0 0 r
s
.007 .342 .009 r
.64926 .23634 m .65516 .25502 L .65496 .25069 L closepath p F P
0 0 0 r
s
.205 .624 .378 r
.49959 .25375 m .51711 .25429 L .5165 .25839 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.51667 .25729 m
.56455 .26722 L
s
.094 .504 .236 r
.64926 .23634 m .65951 .24681 L .66427 .24725 L closepath p F P
0 0 0 r
s
.092 .135 .216 r
.6072 .54645 m .60214 .55662 L .60251 .57181 L p F P
0 0 0 r
s
.092 .135 .216 r
.60214 .55662 m .6072 .54645 L .60681 .53137 L p F P
0 0 0 r
s
.584 .784 .971 r
.57507 .40899 m .58779 .41674 L .58809 .43125 L p F P
0 0 0 r
s
.576 .776 .973 r
.46993 .63569 m .48436 .64169 L .48456 .62616 L p F P
0 0 0 r
s
.576 .776 .973 r
.48456 .62616 m .4702 .62013 L .46993 .63569 L p F P
0 0 0 r
s
.444 .598 .779 r
.54295 .38516 m .5253 .38401 L .5253 .36972 L p F P
0 0 0 r
s
.328 .45 .612 r
.55286 .64553 m .56897 .64126 L .56877 .62573 L p F P
0 0 0 r
s
.275 .382 .53 r
.58295 .61956 m .56877 .62573 L .56897 .64126 L p F P
0 0 0 r
s
.337 .479 .557 r
.44351 .53669 m .44515 .54732 L .44554 .53224 L p F P
0 0 0 r
s
.337 .479 .557 r
.44554 .53224 m .44391 .52157 L .44351 .53669 L p F P
0 0 0 r
s
.052 .338 .138 r
.25612 .59003 m .26975 .57407 L .26639 .56801 L closepath p F P
0 0 0 r
s
0 .347 0 r
.25612 .59003 m .26549 .57886 L .26975 .57407 L closepath p F P
0 0 0 r
s
.305 .864 .634 r
.25612 .59003 m .26639 .56801 L .25878 .56671 L closepath p F P
0 0 0 r
s
.201 .741 .471 r
.25612 .59003 m .25786 .57757 L .26549 .57886 L closepath p F P
0 0 0 r
s
.261 .853 .448 r
.25612 .59003 m .25878 .56671 L .2545 .57148 L closepath p F P
0 0 0 r
s
.001 .152 .003 r
.25612 .59003 m .2545 .57148 L .25786 .57757 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.26032 .57798 m
.28094 .51881 L
s
.061 .09 .132 r
.60812 .52068 m .60681 .53137 L .6072 .54645 L p F P
0 0 0 r
s
.061 .09 .132 r
.60681 .53137 m .60812 .52068 L .60772 .5057 L p F P
0 0 0 r
s
.481 .649 .84 r
.50047 .66145 m .51788 .66348 L .51792 .64784 L p F P
0 0 0 r
s
.481 .649 .84 r
.51792 .64784 m .5006 .64579 L .50047 .66145 L p F P
0 0 0 r
s
.431 .584 .767 r
.5356 .64775 m .51792 .64784 L .51788 .66348 L p F P
0 0 0 r
s
.431 .584 .767 r
.51788 .66348 m .53564 .6634 L .5356 .64775 L p F P
0 0 0 r
s
.38 .517 .692 r
.55286 .64553 m .5356 .64775 L .53564 .6634 L p F P
0 0 0 r
s
.149 .575 .371 r
.64926 .23634 m .65992 .25548 L .65516 .25502 L closepath p F P
0 0 0 r
s
.198 .594 .284 r
.64926 .23634 m .66427 .24725 L .66448 .25158 L closepath p F P
0 0 0 r
s
.06 .088 .128 r
.44614 .51087 m .44391 .52157 L .44431 .50659 L p F P
0 0 0 r
s
.06 .088 .128 r
.44431 .50659 m .44653 .49586 L .44614 .51087 L p F P
0 0 0 r
s
.53 .714 .91 r
.48416 .65737 m .50047 .66145 L .5006 .64579 L p F P
0 0 0 r
s
.53 .714 .91 r
.5006 .64579 m .48436 .64169 L .48416 .65737 L p F P
0 0 0 r
s
.336 .458 .618 r
.5076 .39979 m .49083 .40356 L .49101 .38915 L p F P
0 0 0 r
s
.336 .458 .618 r
.49101 .38915 m .50769 .38536 L .5076 .39979 L p F P
0 0 0 r
s
.336 .475 .553 r
.60518 .49499 m .60772 .5057 L .60812 .52068 L p F P
0 0 0 r
s
.336 .475 .553 r
.60772 .5057 m .60518 .49499 L .6048 .48011 L p F P
0 0 0 r
s
.38 .517 .692 r
.53564 .6634 m .55299 .66119 L .55286 .64553 L p F P
0 0 0 r
s
.328 .45 .612 r
.56897 .64126 m .55286 .64553 L .55299 .66119 L p F P
0 0 0 r
s
.545 .731 .921 r
.57507 .40899 m .55991 .40316 L .55974 .38875 L p F P
0 0 0 r
s
.496 .666 .853 r
.54295 .38516 m .55974 .38875 L .55991 .40316 L p F P
0 0 0 r
s
.253 .737 .508 r
.30108 .24869 m .33084 .23973 L .32745 .23281 L closepath p F P
0 0 0 r
s
.053 .322 .086 r
.30108 .24869 m .33045 .2453 L .33084 .23973 L closepath p F P
0 0 0 r
s
.052 .489 .123 r
.30108 .24869 m .32666 .24397 L .33045 .2453 L closepath p F P
0 0 0 r
s
.184 .624 .414 r
.30108 .24869 m .32325 .23703 L .32666 .24397 L closepath p F P
0 0 0 r
s
.267 .896 .554 r
.30108 .24869 m .32745 .23281 L .32366 .23145 L closepath p F P
0 0 0 r
s
.003 .196 .007 r
.30108 .24869 m .32366 .23145 L .32325 .23703 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.32443 .23942 m
.40661 .20682 L
s
.33 .881 .633 r
.64926 .23634 m .66448 .25158 L .65992 .25548 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.6617 .25395 m
.69016 .29423 L
s
.09 .132 .21 r
.45254 .4856 m .44653 .49586 L .44691 .48099 L p F P
0 0 0 r
s
.09 .132 .21 r
.44691 .48099 m .4529 .4707 L .45254 .4856 L p F P
0 0 0 r
s
.604 .823 .997 r
.44939 .60342 m .45829 .61245 L .45862 .59701 L p F P
0 0 0 r
s
.604 .823 .997 r
.45862 .59701 m .44976 .58794 L .44939 .60342 L p F P
0 0 0 r
s
.495 .68 .818 r
.59851 .46989 m .6048 .48011 L .60518 .49499 L p F P
0 0 0 r
s
.495 .68 .818 r
.6048 .48011 m .59851 .46989 L .59816 .45512 L p F P
0 0 0 r
s
.61 .825 1 r
.45796 .62804 m .46993 .63569 L .4702 .62013 L p F P
0 0 0 r
s
.61 .825 1 r
.4702 .62013 m .45829 .61245 L .45796 .62804 L p F P
0 0 0 r
s
.28 .387 .532 r
.49066 .41811 m .4756 .42409 L .47584 .40956 L p F P
0 0 0 r
s
.28 .387 .532 r
.47584 .40956 m .49083 .40356 L .49066 .41811 L p F P
0 0 0 r
s
.223 .312 .442 r
.58295 .61956 m .59463 .61175 L .5943 .59631 L p F P
0 0 0 r
s
.159 .222 .331 r
.60289 .58715 m .5943 .59631 L .59463 .61175 L p F P
0 0 0 r
s
.159 .222 .331 r
.5943 .59631 m .60289 .58715 L .60251 .57181 L p F P
0 0 0 r
s
.275 .382 .53 r
.56897 .64126 m .58322 .63512 L .58295 .61956 L p F P
0 0 0 r
s
.223 .312 .442 r
.59463 .61175 m .58295 .61956 L .58322 .63512 L p F P
0 0 0 r
s
.163 .225 .333 r
.46243 .46141 m .4529 .4707 L .45325 .45594 L p F P
0 0 0 r
s
.163 .225 .333 r
.45325 .45594 m .46274 .44661 L .46243 .46141 L p F P
0 0 0 r
s
.494 .685 .822 r
.44435 .57792 m .44976 .58794 L .45013 .57261 L p F P
0 0 0 r
s
.494 .685 .822 r
.45013 .57261 m .44475 .56254 L .44435 .57792 L p F P
0 0 0 r
s
.584 .784 .971 r
.58809 .43125 m .57531 .42352 L .57507 .40899 L p F P
0 0 0 r
s
.545 .731 .921 r
.55991 .40316 m .57507 .40899 L .57531 .42352 L p F P
0 0 0 r
s
.391 .529 .7 r
.5253 .39843 m .5076 .39979 L .50769 .38536 L p F P
0 0 0 r
s
.391 .529 .7 r
.50769 .38536 m .5253 .38401 L .5253 .39843 L p F P
0 0 0 r
s
.225 .313 .441 r
.47535 .43877 m .46274 .44661 L .46305 .43196 L p F P
0 0 0 r
s
.225 .313 .441 r
.46305 .43196 m .4756 .42409 L .47535 .43877 L p F P
0 0 0 r
s
.239 .821 .408 r
.31532 .58385 m .31781 .56564 L .31457 .56936 L closepath p F P
0 0 0 r
s
.305 .865 .635 r
.31532 .58385 m .3237 .56665 L .31781 .56564 L closepath p F P
0 0 0 r
s
.054 .345 .143 r
.31532 .58385 m .32638 .57138 L .3237 .56665 L closepath p F P
0 0 0 r
s
0 .039 0 r
.31532 .58385 m .32316 .5751 L .32638 .57138 L closepath p F P
0 0 0 r
s
.203 .743 .474 r
.31532 .58385 m .31725 .57409 L .32316 .5751 L closepath p F P
0 0 0 r
s
.004 .165 .01 r
.31532 .58385 m .31457 .56936 L .31725 .57409 L closepath p F P
0 0 0 r
s
.496 .666 .853 r
.55991 .40316 m .54303 .39958 L .54295 .38516 L p F P
0 0 0 r
s
.444 .598 .779 r
.5253 .38401 m .54295 .38516 L .54303 .39958 L p F P
0 0 0 r
s
.69 .09 .12 r
.31894 .57438 m
.33648 .52857 L
s
.588 .794 .966 r
.58839 .4459 m .59816 .45512 L .59851 .46989 L p F P
0 0 0 r
s
.588 .794 .966 r
.59816 .45512 m .58839 .4459 L .58809 .43125 L p F P
0 0 0 r
s
.092 .135 .216 r
.6076 .56168 m .60251 .57181 L .60289 .58715 L p F P
0 0 0 r
s
.092 .135 .216 r
.60251 .57181 m .6076 .56168 L .6072 .54645 L p F P
0 0 0 r
s
.584 .784 .971 r
.57531 .42352 m .58809 .43125 L .58839 .4459 L p F P
0 0 0 r
s
.576 .776 .973 r
.46966 .6514 m .48416 .65737 L .48436 .64169 L p F P
0 0 0 r
s
.576 .776 .973 r
.48436 .64169 m .46993 .63569 L .46966 .6514 L p F P
0 0 0 r
s
.444 .598 .779 r
.54303 .39958 m .5253 .39843 L .5253 .38401 L p F P
0 0 0 r
s
.328 .45 .612 r
.55299 .66119 m .56918 .65694 L .56897 .64126 L p F P
0 0 0 r
s
.275 .382 .53 r
.58322 .63512 m .56897 .64126 L .56918 .65694 L p F P
0 0 0 r
s
.337 .479 .557 r
.44311 .55196 m .44475 .56254 L .44515 .54732 L p F P
0 0 0 r
s
.337 .479 .557 r
.44515 .54732 m .44351 .53669 L .44311 .55196 L p F P
0 0 0 r
s
.061 .09 .132 r
.60852 .5358 m .6072 .54645 L .6076 .56168 L p F P
0 0 0 r
s
.061 .09 .132 r
.6072 .54645 m .60852 .5358 L .60812 .52068 L p F P
0 0 0 r
s
.481 .649 .84 r
.50035 .67726 m .51784 .67929 L .51788 .66348 L p F P
0 0 0 r
s
.481 .649 .84 r
.51788 .66348 m .50047 .66145 L .50035 .67726 L p F P
0 0 0 r
s
.431 .584 .767 r
.53564 .6634 m .51788 .66348 L .51784 .67929 L p F P
0 0 0 r
s
.431 .584 .767 r
.51784 .67929 m .53569 .6792 L .53564 .6634 L p F P
0 0 0 r
s
.38 .517 .692 r
.55299 .66119 m .53564 .6634 L .53569 .6792 L p F P
0 0 0 r
s
.06 .088 .128 r
.44575 .52603 m .44351 .53669 L .44391 .52157 L p F P
0 0 0 r
s
.06 .088 .128 r
.44391 .52157 m .44614 .51087 L .44575 .52603 L p F P
0 0 0 r
s
.53 .714 .91 r
.48395 .6732 m .50035 .67726 L .50047 .66145 L p F P
0 0 0 r
s
.53 .714 .91 r
.50047 .66145 m .48416 .65737 L .48395 .6732 L p F P
0 0 0 r
s
.336 .458 .618 r
.50751 .41435 m .49066 .41811 L .49083 .40356 L p F P
0 0 0 r
s
.336 .458 .618 r
.49083 .40356 m .5076 .39979 L .50751 .41435 L p F P
0 0 0 r
s
.336 .475 .553 r
.60557 .51 m .60812 .52068 L .60852 .5358 L p F P
0 0 0 r
s
.336 .475 .553 r
.60812 .52068 m .60557 .51 L .60518 .49499 L p F P
0 0 0 r
s
.38 .517 .692 r
.53569 .6792 m .55312 .677 L .55299 .66119 L p F P
0 0 0 r
s
.328 .45 .612 r
.56918 .65694 m .55299 .66119 L .55312 .677 L p F P
0 0 0 r
s
.545 .731 .921 r
.57531 .42352 m .56007 .41772 L .55991 .40316 L p F P
0 0 0 r
s
.496 .666 .853 r
.54303 .39958 m .55991 .40316 L .56007 .41772 L p F P
0 0 0 r
s
.09 .132 .21 r
.45218 .50066 m .44614 .51087 L .44653 .49586 L p F P
0 0 0 r
s
.09 .132 .21 r
.44653 .49586 m .45254 .4856 L .45218 .50066 L p F P
0 0 0 r
s
.213 .785 .363 r
.37496 .57763 m .37704 .56457 L .3748 .56722 L closepath p F P
0 0 0 r
s
.305 .865 .635 r
.37496 .57763 m .38124 .5653 L .37704 .56457 L closepath p F P
0 0 0 r
s
.056 .351 .148 r
.37496 .57763 m .38319 .56867 L .38124 .5653 L closepath p F P
0 0 0 r
s
0 .039 0 r
.37496 .57763 m .38096 .57133 L .38319 .56867 L closepath p F P
0 0 0 r
s
.204 .745 .477 r
.37496 .57763 m .37676 .57061 L .38096 .57133 L closepath p F P
0 0 0 r
s
.007 .179 .02 r
.37496 .57763 m .3748 .56722 L .37676 .57061 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.37781 .57079 m
.3914 .53822 L
s
.604 .823 .997 r
.44901 .61906 m .45796 .62804 L .45829 .61245 L p F P
0 0 0 r
s
.604 .823 .997 r
.45829 .61245 m .44939 .60342 L .44901 .61906 L p F P
0 0 0 r
s
.495 .68 .818 r
.59887 .4848 m .60518 .49499 L .60557 .51 L p F P
0 0 0 r
s
.495 .68 .818 r
.60518 .49499 m .59887 .4848 L .59851 .46989 L p F P
0 0 0 r
s
.61 .825 1 r
.45763 .64379 m .46966 .6514 L .46993 .63569 L p F P
0 0 0 r
s
.61 .825 1 r
.46993 .63569 m .45796 .62804 L .45763 .64379 L p F P
0 0 0 r
s
0 .073 0 r
.3676 .91713 m .3453 .90935 L .35086 .91133 L closepath p F P
0 0 0 r
s
.242 .667 .366 r
.3676 .91713 m .34566 .90237 L .3453 .90935 L closepath p F P
0 0 0 r
s
.339 .902 .651 r
.3676 .91713 m .35157 .89738 L .34566 .90237 L closepath p F P
0 0 0 r
s
.074 .418 .195 r
.3676 .91713 m .35713 .89934 L .35157 .89738 L closepath p F P
0 0 0 r
s
.157 .586 .23 r
.3676 .91713 m .35679 .90632 L .35713 .89934 L closepath p F P
0 0 0 r
s
.359 1 .695 r
.3676 .91713 m .35086 .91133 L .35679 .90632 L closepath p F P
0 0 0 r
s
.28 .387 .532 r
.49049 .43281 m .47535 .43877 L .4756 .42409 L p F P
0 0 0 r
s
.28 .387 .532 r
.4756 .42409 m .49066 .41811 L .49049 .43281 L p F P
0 0 0 r
s
.69 .09 .12 r
.30013 .86446 m
.35533 .90756 L
s
.223 .312 .442 r
.58322 .63512 m .59497 .62735 L .59463 .61175 L p F P
0 0 0 r
s
.159 .222 .331 r
.60326 .60263 m .59463 .61175 L .59497 .62735 L p F P
0 0 0 r
s
.159 .222 .331 r
.59463 .61175 m .60326 .60263 L .60289 .58715 L p F P
0 0 0 r
s
.275 .382 .53 r
.56918 .65694 m .5835 .65083 L .58322 .63512 L p F P
0 0 0 r
s
.223 .312 .442 r
.59497 .62735 m .58322 .63512 L .5835 .65083 L p F P
0 0 0 r
s
.163 .225 .333 r
.46212 .47635 m .45254 .4856 L .4529 .4707 L p F P
0 0 0 r
s
.163 .225 .333 r
.4529 .4707 m .46243 .46141 L .46212 .47635 L p F P
0 0 0 r
s
.494 .685 .822 r
.44395 .59344 m .44939 .60342 L .44976 .58794 L p F P
0 0 0 r
s
.494 .685 .822 r
.44976 .58794 m .44435 .57792 L .44395 .59344 L p F P
0 0 0 r
s
.584 .784 .971 r
.58839 .4459 m .57555 .4382 L .57531 .42352 L p F P
0 0 0 r
s
.545 .731 .921 r
.56007 .41772 m .57531 .42352 L .57555 .4382 L p F P
0 0 0 r
s
.391 .529 .7 r
.52529 .413 m .50751 .41435 L .5076 .39979 L p F P
0 0 0 r
s
.391 .529 .7 r
.5076 .39979 m .5253 .39843 L .52529 .413 L p F P
0 0 0 r
s
.225 .313 .441 r
.4751 .45359 m .46243 .46141 L .46274 .44661 L p F P
0 0 0 r
s
.225 .313 .441 r
.46274 .44661 m .47535 .43877 L .4751 .45359 L p F P
0 0 0 r
s
.496 .666 .853 r
.56007 .41772 m .54311 .41414 L .54303 .39958 L p F P
0 0 0 r
s
.444 .598 .779 r
.5253 .39843 m .54303 .39958 L .54311 .41414 L p F P
0 0 0 r
s
.588 .794 .966 r
.5887 .4607 m .59851 .46989 L .59887 .4848 L p F P
0 0 0 r
s
.588 .794 .966 r
.59851 .46989 m .5887 .4607 L .58839 .4459 L p F P
0 0 0 r
s
.092 .135 .216 r
.608 .57706 m .60289 .58715 L .60326 .60263 L p F P
0 0 0 r
s
.092 .135 .216 r
.60289 .58715 m .608 .57706 L .6076 .56168 L p F P
0 0 0 r
s
.584 .784 .971 r
.57555 .4382 m .58839 .4459 L .5887 .4607 L p F P
0 0 0 r
s
.576 .776 .973 r
.46938 .66726 m .48395 .6732 L .48416 .65737 L p F P
0 0 0 r
s
.576 .776 .973 r
.48416 .65737 m .46966 .6514 L .46938 .66726 L p F P
0 0 0 r
s
.444 .598 .779 r
.54311 .41414 m .52529 .413 L .5253 .39843 L p F P
0 0 0 r
s
.328 .45 .612 r
.55312 .677 m .56939 .67278 L .56918 .65694 L p F P
0 0 0 r
s
.275 .382 .53 r
.5835 .65083 m .56918 .65694 L .56939 .67278 L p F P
0 0 0 r
s
.031 .286 .065 r
.80588 .90171 m .77372 .90937 L .77432 .91786 L closepath p F P
0 0 0 r
s
.18 .618 .409 r
.80588 .90171 m .77014 .90175 L .77372 .90937 L closepath p F P
0 0 0 r
s
.337 .479 .557 r
.4427 .56738 m .44435 .57792 L .44475 .56254 L p F P
0 0 0 r
s
.337 .479 .557 r
.44475 .56254 m .44311 .55196 L .4427 .56738 L p F P
0 0 0 r
s
.061 .09 .132 r
.60892 .55108 m .6076 .56168 L .608 .57706 L p F P
0 0 0 r
s
.061 .09 .132 r
.6076 .56168 m .60892 .55108 L .60852 .5358 L p F P
0 0 0 r
s
.481 .649 .84 r
.50022 .69323 m .5178 .69524 L .51784 .67929 L p F P
0 0 0 r
s
.481 .649 .84 r
.51784 .67929 m .50035 .67726 L .50022 .69323 L p F P
0 0 0 r
s
.431 .584 .767 r
.53569 .6792 m .51784 .67929 L .5178 .69524 L p F P
0 0 0 r
s
.431 .584 .767 r
.5178 .69524 m .53574 .69515 L .53569 .6792 L p F P
0 0 0 r
s
.38 .517 .692 r
.55312 .677 m .53569 .6792 L .53574 .69515 L p F P
0 0 0 r
s
0 .06 0 r
.80588 .90171 m .76714 .90259 L .77014 .90175 L closepath p F P
0 0 0 r
s
.06 .088 .128 r
.44535 .54135 m .44311 .55196 L .44351 .53669 L p F P
0 0 0 r
s
.06 .088 .128 r
.44351 .53669 m .44575 .52603 L .44535 .54135 L p F P
0 0 0 r
s
0 .039 0 r
.43505 .57136 m .43889 .56755 L .44019 .56596 L closepath p F P
0 0 0 r
s
.305 .865 .635 r
.43505 .57136 m .43899 .56393 L .43648 .56349 L closepath p F P
0 0 0 r
s
.058 .357 .153 r
.43505 .57136 m .44019 .56596 L .43899 .56393 L closepath p F P
0 0 0 r
s
.205 .747 .479 r
.43505 .57136 m .43638 .56712 L .43889 .56755 L closepath p F P
0 0 0 r
s
.186 .745 .314 r
.43505 .57136 m .43648 .56349 L .43518 .56509 L closepath p F P
0 0 0 r
s
.012 .198 .032 r
.43505 .57136 m .43518 .56509 L .43638 .56712 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.43967 .56112 m
.44224 .55543 L
s
.43692 .56721 m
.43967 .56112 L
s
.53 .714 .91 r
.48375 .68919 m .50022 .69323 L .50035 .67726 L p F P
0 0 0 r
s
.53 .714 .91 r
.50035 .67726 m .48395 .6732 L .48375 .68919 L p F P
0 0 0 r
s
.336 .458 .618 r
.50742 .42905 m .49049 .43281 L .49066 .41811 L p F P
0 0 0 r
s
.336 .458 .618 r
.49066 .41811 m .50751 .41435 L .50742 .42905 L p F P
0 0 0 r
s
.336 .475 .553 r
.60596 .52517 m .60852 .5358 L .60892 .55108 L p F P
0 0 0 r
s
.336 .475 .553 r
.60852 .5358 m .60596 .52517 L .60557 .51 L p F P
0 0 0 r
s
.38 .517 .692 r
.53574 .69515 m .55326 .69297 L .55312 .677 L p F P
0 0 0 r
s
.328 .45 .612 r
.56939 .67278 m .55312 .677 L .55326 .69297 L p F P
0 0 0 r
s
.545 .731 .921 r
.57555 .4382 m .56024 .43241 L .56007 .41772 L p F P
0 0 0 r
s
.496 .666 .853 r
.54311 .41414 m .56007 .41772 L .56024 .43241 L p F P
0 0 0 r
s
0 .372 0 r
.80588 .90171 m .77432 .91786 L .77134 .91876 L closepath p F P
0 0 0 r
s
.09 .132 .21 r
.45181 .51586 m .44575 .52603 L .44614 .51087 L p F P
0 0 0 r
s
.09 .132 .21 r
.44614 .51087 m .45218 .50066 L .45181 .51586 L p F P
0 0 0 r
s
.604 .823 .997 r
.44863 .63485 m .45763 .64379 L .45796 .62804 L p F P
0 0 0 r
s
.604 .823 .997 r
.45796 .62804 m .44901 .61906 L .44863 .63485 L p F P
0 0 0 r
s
.495 .68 .818 r
.59923 .49985 m .60557 .51 L .60596 .52517 L p F P
0 0 0 r
s
.495 .68 .818 r
.60557 .51 m .59923 .49985 L .59887 .4848 L p F P
0 0 0 r
s
.61 .825 1 r
.45729 .65969 m .46938 .66726 L .46966 .6514 L p F P
0 0 0 r
s
.61 .825 1 r
.46966 .6514 m .45763 .64379 L .45729 .65969 L p F P
0 0 0 r
s
.28 .387 .532 r
.49031 .44765 m .4751 .45359 L .47535 .43877 L p F P
0 0 0 r
s
.28 .387 .532 r
.47535 .43877 m .49049 .43281 L .49031 .44765 L p F P
0 0 0 r
s
.223 .312 .442 r
.5835 .65083 m .59531 .6431 L .59497 .62735 L p F P
0 0 0 r
s
.159 .222 .331 r
.60364 .61827 m .59497 .62735 L .59531 .6431 L p F P
0 0 0 r
s
.159 .222 .331 r
.59497 .62735 m .60364 .61827 L .60326 .60263 L p F P
0 0 0 r
s
.275 .382 .53 r
.56939 .67278 m .58379 .66669 L .5835 .65083 L p F P
0 0 0 r
s
.223 .312 .442 r
.59531 .6431 m .5835 .65083 L .58379 .66669 L p F P
0 0 0 r
s
.163 .225 .333 r
.4618 .49143 m .45218 .50066 L .45254 .4856 L p F P
0 0 0 r
s
.163 .225 .333 r
.45254 .4856 m .46212 .47635 L .4618 .49143 L p F P
0 0 0 r
s
.042 .271 .056 r
.56357 .91023 m .53871 .90972 L .5396 .91305 L closepath p F P
0 0 0 r
s
.206 .625 .379 r
.56357 .91023 m .53956 .90367 L .53871 .90972 L closepath p F P
0 0 0 r
s
.223 .741 .518 r
.56357 .91023 m .54131 .90094 L .53956 .90367 L closepath p F P
0 0 0 r
s
.283 .761 .496 r
.56357 .91023 m .54136 .91033 L .54222 .90427 L closepath p F P
0 0 0 r
s
.272 .884 .587 r
.56357 .91023 m .5396 .91305 L .54136 .91033 L closepath p F P
0 0 0 r
s
.071 .325 .094 r
.56357 .91023 m .54222 .90427 L .54131 .90094 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.47044 .8972 m
.5418 .90718 L
s
.494 .685 .822 r
.44354 .60912 m .44901 .61906 L .44939 .60342 L p F P
0 0 0 r
s
.494 .685 .822 r
.44939 .60342 m .44395 .59344 L .44354 .60912 L p F P
0 0 0 r
s
.584 .784 .971 r
.5887 .4607 m .5758 .45302 L .57555 .4382 L p F P
0 0 0 r
s
.545 .731 .921 r
.56024 .43241 m .57555 .4382 L .5758 .45302 L p F P
0 0 0 r
s
.391 .529 .7 r
.52529 .42771 m .50742 .42905 L .50751 .41435 L p F P
0 0 0 r
s
.391 .529 .7 r
.50751 .41435 m .52529 .413 L .52529 .42771 L p F P
0 0 0 r
s
.225 .313 .441 r
.47485 .46855 m .46212 .47635 L .46243 .46141 L p F P
0 0 0 r
s
.225 .313 .441 r
.46243 .46141 m .4751 .45359 L .47485 .46855 L p F P
0 0 0 r
s
.496 .666 .853 r
.56024 .43241 m .5432 .42885 L .54311 .41414 L p F P
0 0 0 r
s
.444 .598 .779 r
.52529 .413 m .54311 .41414 L .5432 .42885 L p F P
0 0 0 r
s
.588 .794 .966 r
.58901 .47564 m .59887 .4848 L .59923 .49985 L p F P
0 0 0 r
s
.588 .794 .966 r
.59887 .4848 m .58901 .47564 L .5887 .4607 L p F P
0 0 0 r
s
.092 .135 .216 r
.6084 .59259 m .60326 .60263 L .60364 .61827 L p F P
0 0 0 r
s
.092 .135 .216 r
.60326 .60263 m .6084 .59259 L .608 .57706 L p F P
0 0 0 r
s
.584 .784 .971 r
.5758 .45302 m .5887 .4607 L .58901 .47564 L p F P
0 0 0 r
s
.576 .776 .973 r
.4691 .68328 m .48375 .68919 L .48395 .6732 L p F P
0 0 0 r
s
.576 .776 .973 r
.48395 .6732 m .46938 .66726 L .4691 .68328 L p F P
0 0 0 r
s
.377 1 .729 r
.68732 .20023 m .69431 .21938 L .70025 .21431 L closepath p F P
0 0 0 r
s
.001 .323 .001 r
.68732 .20023 m .69465 .22497 L .69431 .21938 L closepath p F P
0 0 0 r
s
.444 .598 .779 r
.5432 .42885 m .52529 .42771 L .52529 .413 L p F P
0 0 0 r
s
.328 .45 .612 r
.55326 .69297 m .56961 .68877 L .56939 .67278 L p F P
0 0 0 r
s
.275 .382 .53 r
.58379 .66669 m .56939 .67278 L .56961 .68877 L p F P
0 0 0 r
s
.102 .52 .257 r
.68732 .20023 m .70025 .21431 L .70655 .21481 L closepath p F P
0 0 0 r
s
.253 .737 .508 r
.24767 .22385 m .28437 .21269 L .28012 .2041 L closepath p F P
0 0 0 r
s
.049 .314 .08 r
.24767 .22385 m .28378 .21954 L .28437 .21269 L closepath p F P
0 0 0 r
s
.06 .506 .142 r
.24767 .22385 m .2789 .21779 L .28378 .21954 L closepath p F P
0 0 0 r
s
.183 .623 .413 r
.24767 .22385 m .27462 .20914 L .2789 .21779 L closepath p F P
0 0 0 r
s
.277 .909 .573 r
.24767 .22385 m .28012 .2041 L .27524 .20229 L closepath p F P
0 0 0 r
s
.002 .186 .004 r
.24767 .22385 m .27524 .20229 L .27462 .20914 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.27617 .21228 m
.37751 .17114 L
s
.337 .479 .557 r
.44228 .58295 m .44395 .59344 L .44435 .57792 L p F P
0 0 0 r
s
.337 .479 .557 r
.44435 .57792 m .4427 .56738 L .44228 .58295 L p F P
0 0 0 r
s
.082 .384 .143 r
.80588 .90171 m .76773 .9111 L .76714 .90259 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.66793 .93518 m
.76772 .91097 L
s
.061 .09 .132 r
.60933 .5665 m .608 .57706 L .6084 .59259 L p F P
0 0 0 r
s
.69 .09 .12 r
.60825 .56996 m
.60908 .56845 L
s
.061 .09 .132 r
.608 .57706 m .60933 .5665 L .60892 .55108 L p F P
0 0 0 r
s
.481 .649 .84 r
.50009 .70935 m .51776 .71135 L .5178 .69524 L p F P
0 0 0 r
s
.481 .649 .84 r
.5178 .69524 m .50022 .69323 L .50009 .70935 L p F P
0 0 0 r
s
.431 .584 .767 r
.53574 .69515 m .5178 .69524 L .51776 .71135 L p F P
0 0 0 r
s
.431 .584 .767 r
.51776 .71135 m .53579 .71127 L .53574 .69515 L p F P
0 0 0 r
s
.38 .517 .692 r
.55326 .69297 m .53574 .69515 L .53579 .71127 L p F P
0 0 0 r
s
.256 .746 .518 r
.80588 .90171 m .77134 .91876 L .76773 .9111 L closepath p F P
0 0 0 r
s
.06 .088 .128 r
.44495 .55681 m .4427 .56738 L .44311 .55196 L p F P
0 0 0 r
s
.06 .088 .128 r
.44311 .55196 m .44535 .54135 L .44495 .55681 L p F P
0 0 0 r
s
.329 .937 .687 r
.48822 .21093 m .51074 .21418 L .51244 .21003 L closepath p F P
0 0 0 r
s
.283 .762 .496 r
.48822 .21093 m .50988 .22001 L .51074 .21418 L closepath p F P
0 0 0 r
s
.151 .578 .373 r
.68732 .20023 m .70095 .2255 L .69465 .22497 L closepath p F P
0 0 0 r
s
.001 .159 .001 r
.48822 .21093 m .5107 .22172 L .50988 .22001 L closepath p F P
0 0 0 r
s
.53 .714 .91 r
.48354 .70533 m .50009 .70935 L .50022 .69323 L p F P
0 0 0 r
s
.53 .714 .91 r
.50022 .69323 m .48375 .68919 L .48354 .70533 L p F P
0 0 0 r
s
.336 .458 .618 r
.50733 .4439 m .49031 .44765 L .49049 .43281 L p F P
0 0 0 r
s
.336 .458 .618 r
.49049 .43281 m .50742 .42905 L .50733 .4439 L p F P
0 0 0 r
s
.336 .475 .553 r
.60636 .54048 m .60892 .55108 L .60933 .5665 L p F P
0 0 0 r
s
.69 .09 .12 r
.60927 .56811 m
.61075 .56545 L
s
.336 .475 .553 r
.60892 .55108 m .60636 .54048 L .60596 .52517 L p F P
0 0 0 r
s
.188 .578 .268 r
.68732 .20023 m .70655 .21481 L .70692 .22041 L closepath p F P
0 0 0 r
s
.38 .517 .692 r
.53579 .71127 m .55339 .70909 L .55326 .69297 L p F P
0 0 0 r
s
.328 .45 .612 r
.56961 .68877 m .55326 .69297 L .55339 .70909 L p F P
0 0 0 r
s
.545 .731 .921 r
.5758 .45302 m .56041 .44725 L .56024 .43241 L p F P
0 0 0 r
s
.496 .666 .853 r
.5432 .42885 m .56024 .43241 L .56041 .44725 L p F P
0 0 0 r
s
.09 .132 .21 r
.45144 .53121 m .44535 .54135 L .44575 .52603 L p F P
0 0 0 r
s
.09 .132 .21 r
.44575 .52603 m .45181 .51586 L .45144 .53121 L p F P
0 0 0 r
s
.604 .823 .997 r
.44825 .65079 m .45729 .65969 L .45763 .64379 L p F P
0 0 0 r
s
.604 .823 .997 r
.45763 .64379 m .44863 .63485 L .44825 .65079 L p F P
0 0 0 r
s
.495 .68 .818 r
.59959 .51506 m .60596 .52517 L .60636 .54048 L p F P
0 0 0 r
s
.495 .68 .818 r
.60596 .52517 m .59959 .51506 L .59923 .49985 L p F P
0 0 0 r
s
.61 .825 1 r
.45695 .67575 m .4691 .68328 L .46938 .66726 L p F P
0 0 0 r
s
.61 .825 1 r
.46938 .66726 m .45729 .65969 L .45695 .67575 L p F P
0 0 0 r
s
0 .119 .001 r
.48822 .21093 m .51244 .21003 L .51328 .21172 L closepath p F P
0 0 0 r
s
.28 .387 .532 r
.49014 .46263 m .47485 .46855 L .4751 .45359 L p F P
0 0 0 r
s
.28 .387 .532 r
.4751 .45359 m .49031 .44765 L .49014 .46263 L p F P
0 0 0 r
s
.223 .312 .442 r
.58379 .66669 m .59565 .659 L .59531 .6431 L p F P
0 0 0 r
s
.159 .222 .331 r
.60403 .63406 m .59531 .6431 L .59565 .659 L p F P
0 0 0 r
s
.159 .222 .331 r
.59531 .6431 m .60403 .63406 L .60364 .61827 L p F P
0 0 0 r
s
.275 .382 .53 r
.56961 .68877 m .58407 .68272 L .58379 .66669 L p F P
0 0 0 r
s
.223 .312 .442 r
.59565 .659 m .58379 .66669 L .58407 .68272 L p F P
0 0 0 r
s
.163 .225 .333 r
.46148 .50667 m .45181 .51586 L .45218 .50066 L p F P
0 0 0 r
s
.163 .225 .333 r
.45218 .50066 m .4618 .49143 L .46148 .50667 L p F P
0 0 0 r
s
.494 .685 .822 r
.44313 .62496 m .44863 .63485 L .44901 .61906 L p F P
0 0 0 r
s
.494 .685 .822 r
.44901 .61906 m .44354 .60912 L .44313 .62496 L p F P
0 0 0 r
s
.584 .784 .971 r
.58901 .47564 m .57604 .46799 L .5758 .45302 L p F P
0 0 0 r
s
.545 .731 .921 r
.56041 .44725 m .5758 .45302 L .57604 .46799 L p F P
0 0 0 r
s
.331 .884 .636 r
.68732 .20023 m .70692 .22041 L .70095 .2255 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.70313 .22364 m
.73896 .27667 L
s
.391 .529 .7 r
.52529 .44257 m .50733 .4439 L .50742 .42905 L p F P
0 0 0 r
s
.391 .529 .7 r
.50742 .42905 m .52529 .42771 L .52529 .44257 L p F P
0 0 0 r
s
.026 .25 .071 r
.61806 .55227 m .61595 .55661 L .61724 .55865 L closepath p F P
0 0 0 r
s
.209 .752 .487 r
.61806 .55227 m .61348 .55617 L .61595 .55661 L closepath p F P
0 0 0 r
s
.225 .313 .441 r
.4746 .48367 m .4618 .49143 L .46212 .47635 L p F P
0 0 0 r
s
.225 .313 .441 r
.46212 .47635 m .47485 .46855 L .4746 .48367 L p F P
0 0 0 r
s
.496 .666 .853 r
.56041 .44725 m .54328 .4437 L .5432 .42885 L p F P
0 0 0 r
s
.444 .598 .779 r
.52529 .42771 m .5432 .42885 L .54328 .4437 L p F P
0 0 0 r
s
.246 .764 .547 r
.48822 .21093 m .5124 .21758 L .5107 .22172 L closepath p F P
0 0 0 r
s
.588 .794 .966 r
.58932 .49073 m .59923 .49985 L .59959 .51506 L p F P
0 0 0 r
s
.588 .794 .966 r
.59923 .49985 m .58932 .49073 L .58901 .47564 L p F P
0 0 0 r
s
0 .039 0 r
.61806 .55227 m .61229 .55777 L .61348 .55617 L closepath p F P
0 0 0 r
s
.092 .135 .216 r
.60881 .60828 m .60364 .61827 L .60403 .63406 L p F P
0 0 0 r
s
.092 .135 .216 r
.60364 .61827 m .60881 .60828 L .6084 .59259 L p F P
0 0 0 r
s
.584 .784 .971 r
.57604 .46799 m .58901 .47564 L .58932 .49073 L p F P
0 0 0 r
s
.576 .776 .973 r
.46882 .69946 m .48354 .70533 L .48375 .68919 L p F P
0 0 0 r
s
.576 .776 .973 r
.48375 .68919 m .4691 .68328 L .46882 .69946 L p F P
0 0 0 r
s
.094 .603 .157 r
.61806 .55227 m .61724 .55865 L .61605 .56024 L closepath p F P
0 0 0 r
s
.444 .598 .779 r
.54328 .4437 m .52529 .44257 L .52529 .42771 L p F P
0 0 0 r
s
.328 .45 .612 r
.55339 .70909 m .56982 .70492 L .56961 .68877 L p F P
0 0 0 r
s
.275 .382 .53 r
.58407 .68272 m .56961 .68877 L .56982 .70492 L p F P
0 0 0 r
s
.337 .479 .557 r
.44187 .59868 m .44354 .60912 L .44395 .59344 L p F P
0 0 0 r
s
.337 .479 .557 r
.44395 .59344 m .44228 .58295 L .44187 .59868 L p F P
0 0 0 r
s
.066 .374 .168 r
.61806 .55227 m .61358 .5598 L .61229 .55777 L closepath p F P
0 0 0 r
s
.031 .265 .083 r
.67999 .54581 m .67604 .5531 L .67824 .55649 L closepath p F P
0 0 0 r
s
.21 .754 .49 r
.67999 .54581 m .67195 .55236 L .67604 .5531 L closepath p F P
0 0 0 r
s
.305 .867 .636 r
.61806 .55227 m .61605 .56024 L .61358 .5598 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.61075 .56545 m
.61385 .55985 L
s
0 .039 0 r
.67999 .54581 m .67004 .55502 L .67195 .55236 L closepath p F P
0 0 0 r
s
.061 .09 .132 r
.60974 .58208 m .6084 .59259 L .60881 .60828 L p F P
0 0 0 r
s
.061 .09 .132 r
.6084 .59259 m .60974 .58208 L .60933 .5665 L p F P
0 0 0 r
s
.481 .649 .84 r
.49996 .72563 m .51772 .72763 L .51776 .71135 L p F P
0 0 0 r
s
.481 .649 .84 r
.51776 .71135 m .50009 .70935 L .49996 .72563 L p F P
0 0 0 r
s
.431 .584 .767 r
.53579 .71127 m .51776 .71135 L .51772 .72763 L p F P
0 0 0 r
s
.431 .584 .767 r
.51772 .72763 m .53583 .72754 L .53579 .71127 L p F P
0 0 0 r
s
.38 .517 .692 r
.55339 .70909 m .53579 .71127 L .53583 .72754 L p F P
0 0 0 r
s
.065 .554 .109 r
.67999 .54581 m .67824 .55649 L .67633 .55915 L closepath p F P
0 0 0 r
s
.205 .623 .378 r
.48822 .21093 m .51328 .21172 L .5124 .21758 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.51262 .2161 m
.58096 .23055 L
s
.035 .279 .095 r
.7424 .53931 m .73625 .54957 L .73939 .55432 L closepath p F P
0 0 0 r
s
.211 .756 .492 r
.7424 .53931 m .73055 .54854 L .73625 .54957 L closepath p F P
0 0 0 r
s
.06 .088 .128 r
.44454 .57243 m .44228 .58295 L .4427 .56738 L p F P
0 0 0 r
s
.06 .088 .128 r
.4427 .56738 m .44495 .55681 L .44454 .57243 L p F P
0 0 0 r
s
0 .039 0 r
.7424 .53931 m .72797 .55226 L .73055 .54854 L closepath p F P
0 0 0 r
s
.068 .38 .173 r
.67999 .54581 m .67223 .55842 L .67004 .55502 L closepath p F P
0 0 0 r
s
.53 .714 .91 r
.48332 .72164 m .49996 .72563 L .50009 .70935 L p F P
0 0 0 r
s
.53 .714 .91 r
.50009 .70935 m .48354 .70533 L .48332 .72164 L p F P
0 0 0 r
s
.336 .458 .618 r
.50723 .4589 m .49014 .46263 L .49031 .44765 L p F P
0 0 0 r
s
.336 .458 .618 r
.49031 .44765 m .50733 .4439 L .50723 .4589 L p F P
0 0 0 r
s
.336 .475 .553 r
.60676 .55595 m .60933 .5665 L .60974 .58208 L p F P
0 0 0 r
s
.336 .475 .553 r
.60933 .5665 m .60676 .55595 L .60636 .54048 L p F P
0 0 0 r
s
.305 .867 .637 r
.67999 .54581 m .67633 .55915 L .67223 .55842 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.65698 .58488 m
.67254 .55847 L
s
.38 .517 .692 r
.53583 .72754 m .55353 .72538 L .55339 .70909 L p F P
0 0 0 r
s
.328 .45 .612 r
.56982 .70492 m .55339 .70909 L .55353 .72538 L p F P
0 0 0 r
s
.039 .292 .107 r
.80529 .53275 m .79658 .54604 L .8007 .55215 L closepath p F P
0 0 0 r
s
.212 .758 .494 r
.80529 .53275 m .78928 .54471 L .79658 .54604 L closepath p F P
0 0 0 r
s
.04 .509 .068 r
.7424 .53931 m .73939 .55432 L .73682 .55806 L closepath p F P
0 0 0 r
s
.545 .731 .921 r
.57604 .46799 m .56058 .46224 L .56041 .44725 L p F P
0 0 0 r
s
.496 .666 .853 r
.54328 .4437 m .56041 .44725 L .56058 .46224 L p F P
0 0 0 r
s
.09 .132 .21 r
.45107 .54672 m .44495 .55681 L .44535 .54135 L p F P
0 0 0 r
s
.69 .09 .12 r
.44518 .54892 m
.44571 .54776 L
s
.44502 .54927 m
.44518 .54892 L
s
.44224 .55543 m
.44502 .54927 L
s
.09 .132 .21 r
.44535 .54135 m .45144 .53121 L .45107 .54672 L p F P
0 0 0 r
s
0 .039 0 r
.80529 .53275 m .78609 .5495 L .78928 .54471 L closepath p F P
0 0 0 r
s
.043 .304 .117 r
.86866 .52614 m .85702 .5425 L .86217 .54998 L closepath p F P
0 0 0 r
s
.214 .759 .497 r
.86866 .52614 m .84816 .54087 L .85702 .5425 L closepath p F P
0 0 0 r
s
.604 .823 .997 r
.44786 .6669 m .45695 .67575 L .45729 .65969 L p F P
0 0 0 r
s
.604 .823 .997 r
.45729 .65969 m .44825 .65079 L .44786 .6669 L p F P
0 0 0 r
s
.495 .68 .818 r
.59995 .53041 m .60636 .54048 L .60676 .55595 L p F P
0 0 0 r
s
.495 .68 .818 r
.60636 .54048 m .59995 .53041 L .59959 .51506 L p F P
0 0 0 r
s
.61 .825 1 r
.4566 .69197 m .46882 .69946 L .4691 .68328 L p F P
0 0 0 r
s
.61 .825 1 r
.4691 .68328 m .45695 .67575 L .4566 .69197 L p F P
0 0 0 r
s
.07 .385 .177 r
.7424 .53931 m .7311 .55703 L .72797 .55226 L closepath p F P
0 0 0 r
s
.019 .468 .034 r
.80529 .53275 m .8007 .55215 L .79753 .55696 L closepath p F P
0 0 0 r
s
.28 .387 .532 r
.48996 .47777 m .4746 .48367 L .47485 .46855 L p F P
0 0 0 r
s
.28 .387 .532 r
.47485 .46855 m .49014 .46263 L .48996 .47777 L p F P
0 0 0 r
s
.223 .312 .442 r
.58407 .68272 m .59599 .67506 L .59565 .659 L p F P
0 0 0 r
s
.159 .222 .331 r
.60441 .65001 m .59565 .659 L .59599 .67506 L p F P
0 0 0 r
s
.159 .222 .331 r
.59565 .659 m .60441 .65001 L .60403 .63406 L p F P
0 0 0 r
s
.275 .382 .53 r
.56982 .70492 m .58436 .6989 L .58407 .68272 L p F P
0 0 0 r
s
.223 .312 .442 r
.59599 .67506 m .58407 .68272 L .58436 .6989 L p F P
0 0 0 r
s
.163 .225 .333 r
.46116 .52206 m .45144 .53121 L .45181 .51586 L p F P
0 0 0 r
s
.163 .225 .333 r
.45181 .51586 m .46148 .50667 L .46116 .52206 L p F P
0 0 0 r
s
.306 .867 .637 r
.7424 .53931 m .73682 .55806 L .7311 .55703 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.70837 .59391 m
.73133 .55707 L
s
.494 .685 .822 r
.44272 .64096 m .44825 .65079 L .44863 .63485 L p F P
0 0 0 r
s
.494 .685 .822 r
.44863 .63485 m .44313 .62496 L .44272 .64096 L p F P
0 0 0 r
s
.584 .784 .971 r
.58932 .49073 m .57629 .4831 L .57604 .46799 L p F P
0 0 0 r
s
.545 .731 .921 r
.56058 .46224 m .57604 .46799 L .57629 .4831 L p F P
0 0 0 r
s
.391 .529 .7 r
.52528 .45757 m .50723 .4589 L .50733 .4439 L p F P
0 0 0 r
s
.391 .529 .7 r
.50733 .4439 m .52529 .44257 L .52528 .45757 L p F P
0 0 0 r
s
0 .039 0 r
.86866 .52614 m .8444 .54672 L .84816 .54087 L closepath p F P
0 0 0 r
s
.225 .313 .441 r
.47434 .49893 m .46148 .50667 L .4618 .49143 L p F P
0 0 0 r
s
.225 .313 .441 r
.4618 .49143 m .4746 .48367 L .47434 .49893 L p F P
0 0 0 r
s
.496 .666 .853 r
.56058 .46224 m .54337 .4587 L .54328 .4437 L p F P
0 0 0 r
s
.444 .598 .779 r
.52529 .44257 m .54328 .4437 L .54337 .4587 L p F P
0 0 0 r
s
.588 .794 .966 r
.58964 .50597 m .59959 .51506 L .59995 .53041 L p F P
0 0 0 r
s
.588 .794 .966 r
.59959 .51506 m .58964 .50597 L .58932 .49073 L p F P
0 0 0 r
s
.092 .135 .216 r
.60922 .62412 m .60403 .63406 L .60441 .65001 L p F P
0 0 0 r
s
.092 .135 .216 r
.60403 .63406 m .60922 .62412 L .60881 .60828 L p F P
0 0 0 r
s
.584 .784 .971 r
.57629 .4831 m .58932 .49073 L .58964 .50597 L p F P
0 0 0 r
s
.576 .776 .973 r
.46853 .7158 m .48332 .72164 L .48354 .70533 L p F P
0 0 0 r
s
.576 .776 .973 r
.48354 .70533 m .46882 .69946 L .46853 .7158 L p F P
0 0 0 r
s
.028 .278 .059 r
.7579 .8847 m .73161 .8912 L .73202 .89821 L closepath p F P
0 0 0 r
s
.179 .617 .408 r
.7579 .8847 m .72859 .88486 L .73161 .8912 L closepath p F P
0 0 0 r
s
.006 .436 .012 r
.86866 .52614 m .86217 .54998 L .85844 .55585 L closepath p F P
0 0 0 r
s
.444 .598 .779 r
.54337 .4587 m .52528 .45757 L .52529 .44257 L p F P
0 0 0 r
s
.328 .45 .612 r
.55353 .72538 m .57004 .72122 L .56982 .70492 L p F P
0 0 0 r
s
.275 .382 .53 r
.58436 .6989 m .56982 .70492 L .57004 .72122 L p F P
0 0 0 r
s
.073 .39 .182 r
.80529 .53275 m .79021 .55563 L .78609 .5495 L closepath p F P
0 0 0 r
s
.337 .479 .557 r
.44145 .61457 m .44313 .62496 L .44354 .60912 L p F P
0 0 0 r
s
.337 .479 .557 r
.44354 .60912 m .44187 .59868 L .44145 .61457 L p F P
0 0 0 r
s
.061 .09 .132 r
.61016 .59781 m .60881 .60828 L .60922 .62412 L p F P
0 0 0 r
s
.061 .09 .132 r
.60881 .60828 m .61016 .59781 L .60974 .58208 L p F P
0 0 0 r
s
.481 .649 .84 r
.49983 .74208 m .51768 .74406 L .51772 .72763 L p F P
0 0 0 r
s
.481 .649 .84 r
.51772 .72763 m .49996 .72563 L .49983 .74208 L p F P
0 0 0 r
s
.431 .584 .767 r
.53583 .72754 m .51772 .72763 L .51768 .74406 L p F P
0 0 0 r
s
.306 .868 .637 r
.80529 .53275 m .79753 .55696 L .79021 .55563 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.75919 .60284 m
.79024 .55564 L
s
.431 .584 .767 r
.51768 .74406 m .53588 .74398 L .53583 .72754 L p F P
0 0 0 r
s
.38 .517 .692 r
.55353 .72538 m .53583 .72754 L .53588 .74398 L p F P
0 0 0 r
s
0 .058 0 r
.7579 .8847 m .72598 .88549 L .72859 .88486 L closepath p F P
0 0 0 r
s
.06 .088 .128 r
.44414 .5882 m .44187 .59868 L .44228 .58295 L p F P
0 0 0 r
s
.06 .088 .128 r
.44228 .58295 m .44454 .57243 L .44414 .5882 L p F P
0 0 0 r
s
0 .383 0 r
.7579 .8847 m .73202 .89821 L .72942 .89889 L closepath p F P
0 0 0 r
s
.239 .661 .359 r
.40059 .89326 m .38344 .88145 L .38322 .88692 L closepath p F P
0 0 0 r
s
0 .207 0 r
.40059 .89326 m .38322 .88692 L .38768 .88846 L closepath p F P
0 0 0 r
s
.34 .905 .655 r
.40059 .89326 m .38811 .8775 L .38344 .88145 L closepath p F P
0 0 0 r
s
.078 .427 .205 r
.40059 .89326 m .39257 .87902 L .38811 .8775 L closepath p F P
0 0 0 r
s
.138 .558 .202 r
.40059 .89326 m .39236 .8845 L .39257 .87902 L closepath p F P
0 0 0 r
s
.356 1 .69 r
.40059 .89326 m .38768 .88846 L .39236 .8845 L closepath p F P
0 0 0 r
s
.075 .395 .186 r
.86866 .52614 m .84954 .55423 L .8444 .54672 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.80947 .61168 m
.84938 .554 L
s
.34863 .85115 m
.3911 .88557 L
s
.53 .714 .91 r
.48311 .73811 m .49983 .74208 L .49996 .72563 L p F P
0 0 0 r
s
.53 .714 .91 r
.49996 .72563 m .48332 .72164 L .48311 .73811 L p F P
0 0 0 r
s
.336 .458 .618 r
.50714 .47405 m .48996 .47777 L .49014 .46263 L p F P
0 0 0 r
s
.336 .458 .618 r
.49014 .46263 m .50723 .4589 L .50714 .47405 L p F P
0 0 0 r
s
.336 .475 .553 r
.60716 .57158 m .60974 .58208 L .61016 .59781 L p F P
0 0 0 r
s
.336 .475 .553 r
.60974 .58208 m .60716 .57158 L .60676 .55595 L p F P
0 0 0 r
s
.38 .517 .692 r
.53588 .74398 m .55366 .74183 L .55353 .72538 L p F P
0 0 0 r
s
.328 .45 .612 r
.57004 .72122 m .55353 .72538 L .55366 .74183 L p F P
0 0 0 r
s
.545 .731 .921 r
.57629 .4831 m .56075 .47738 L .56058 .46224 L p F P
0 0 0 r
s
.496 .666 .853 r
.54337 .4587 m .56058 .46224 L .56075 .47738 L p F P
0 0 0 r
s
.306 .868 .638 r
.86866 .52614 m .85844 .55585 L .84954 .55423 L closepath p F P
0 0 0 r
s
.09 .132 .21 r
.4507 .56238 m .44454 .57243 L .44495 .55681 L p F P
0 0 0 r
s
.09 .132 .21 r
.44495 .55681 m .45107 .54672 L .4507 .56238 L p F P
0 0 0 r
s
.604 .823 .997 r
.44746 .68317 m .4566 .69197 L .45695 .67575 L p F P
0 0 0 r
s
.604 .823 .997 r
.45695 .67575 m .44786 .6669 L .44746 .68317 L p F P
0 0 0 r
s
.495 .68 .818 r
.60032 .54592 m .60676 .55595 L .60716 .57158 L p F P
0 0 0 r
s
.495 .68 .818 r
.60676 .55595 m .60032 .54592 L .59995 .53041 L p F P
0 0 0 r
s
.61 .825 1 r
.45625 .70835 m .46853 .7158 L .46882 .69946 L p F P
0 0 0 r
s
.61 .825 1 r
.46882 .69946 m .4566 .69197 L .45625 .70835 L p F P
0 0 0 r
s
.28 .387 .532 r
.48978 .49306 m .47434 .49893 L .4746 .48367 L p F P
0 0 0 r
s
.28 .387 .532 r
.4746 .48367 m .48996 .47777 L .48978 .49306 L p F P
0 0 0 r
s
.223 .312 .442 r
.58436 .6989 m .59634 .69129 L .59599 .67506 L p F P
0 0 0 r
s
.159 .222 .331 r
.60481 .66612 m .59599 .67506 L .59634 .69129 L p F P
0 0 0 r
s
.159 .222 .331 r
.59599 .67506 m .60481 .66612 L .60441 .65001 L p F P
0 0 0 r
s
.275 .382 .53 r
.57004 .72122 m .58465 .71524 L .58436 .6989 L p F P
0 0 0 r
s
.223 .312 .442 r
.59634 .69129 m .58436 .6989 L .58465 .71524 L p F P
0 0 0 r
s
.163 .225 .333 r
.46084 .5376 m .45107 .54672 L .45144 .53121 L p F P
0 0 0 r
s
.163 .225 .333 r
.45144 .53121 m .46116 .52206 L .46084 .5376 L p F P
0 0 0 r
s
.08 .378 .138 r
.7579 .8847 m .72638 .89252 L .72598 .88549 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.64411 .9129 m
.72638 .89251 L
s
.494 .685 .822 r
.4423 .65711 m .44786 .6669 L .44825 .65079 L p F P
0 0 0 r
s
.494 .685 .822 r
.44825 .65079 m .44272 .64096 L .4423 .65711 L p F P
0 0 0 r
s
.584 .784 .971 r
.58964 .50597 m .57654 .49837 L .57629 .4831 L p F P
0 0 0 r
s
.545 .731 .921 r
.56075 .47738 m .57629 .4831 L .57654 .49837 L p F P
0 0 0 r
s
.391 .529 .7 r
.52528 .47272 m .50714 .47405 L .50723 .4589 L p F P
0 0 0 r
s
.391 .529 .7 r
.50723 .4589 m .52528 .45757 L .52528 .47272 L p F P
0 0 0 r
s
.225 .313 .441 r
.47408 .51435 m .46116 .52206 L .46148 .50667 L p F P
0 0 0 r
s
.225 .313 .441 r
.46148 .50667 m .47434 .49893 L .47408 .51435 L p F P
0 0 0 r
s
.496 .666 .853 r
.56075 .47738 m .54346 .47385 L .54337 .4587 L p F P
0 0 0 r
s
.444 .598 .779 r
.52528 .45757 m .54337 .4587 L .54346 .47385 L p F P
0 0 0 r
s
.588 .794 .966 r
.58995 .52136 m .59995 .53041 L .60032 .54592 L p F P
0 0 0 r
s
.588 .794 .966 r
.59995 .53041 m .58995 .52136 L .58964 .50597 L p F P
0 0 0 r
s
.092 .135 .216 r
.60964 .64012 m .60441 .65001 L .60481 .66612 L p F P
0 0 0 r
s
.092 .135 .216 r
.60441 .65001 m .60964 .64012 L .60922 .62412 L p F P
0 0 0 r
s
.584 .784 .971 r
.57654 .49837 m .58964 .50597 L .58995 .52136 L p F P
0 0 0 r
s
.576 .776 .973 r
.46824 .7323 m .48311 .73811 L .48332 .72164 L p F P
0 0 0 r
s
.576 .776 .973 r
.48332 .72164 m .46853 .7158 L .46824 .7323 L p F P
0 0 0 r
s
.256 .747 .519 r
.7579 .8847 m .72942 .89889 L .72638 .89252 L closepath p F P
0 0 0 r
s
.444 .598 .779 r
.54346 .47385 m .52528 .47272 L .52528 .45757 L p F P
0 0 0 r
s
.328 .45 .612 r
.55366 .74183 m .57026 .7377 L .57004 .72122 L p F P
0 0 0 r
s
.275 .382 .53 r
.58465 .71524 m .57004 .72122 L .57026 .7377 L p F P
0 0 0 r
s
.337 .479 .557 r
.44102 .63061 m .44272 .64096 L .44313 .62496 L p F P
0 0 0 r
s
.337 .479 .557 r
.44313 .62496 m .44145 .61457 L .44102 .63061 L p F P
0 0 0 r
s
.377 1 .728 r
.72677 .16279 m .73488 .1871 L .74225 .1808 L closepath p F P
0 0 0 r
s
0 .309 0 r
.72677 .16279 m .7354 .19396 L .73488 .1871 L closepath p F P
0 0 0 r
s
.111 .536 .277 r
.72677 .16279 m .74225 .1808 L .75019 .18133 L closepath p F P
0 0 0 r
s
.061 .09 .132 r
.61058 .6137 m .60922 .62412 L .60964 .64012 L p F P
0 0 0 r
s
.061 .09 .132 r
.60922 .62412 m .61058 .6137 L .61016 .59781 L p F P
0 0 0 r
s
.481 .649 .84 r
.4997 .75869 m .51764 .76066 L .51768 .74406 L p F P
0 0 0 r
s
.481 .649 .84 r
.51768 .74406 m .49983 .74208 L .4997 .75869 L p F P
0 0 0 r
s
.431 .584 .767 r
.53588 .74398 m .51768 .74406 L .51764 .76066 L p F P
0 0 0 r
s
.431 .584 .767 r
.51764 .76066 m .53593 .76058 L .53588 .74398 L p F P
0 0 0 r
s
.38 .517 .692 r
.55366 .74183 m .53588 .74398 L .53593 .76058 L p F P
0 0 0 r
s
.06 .088 .128 r
.44372 .60414 m .44145 .61457 L .44187 .59868 L p F P
0 0 0 r
s
.06 .088 .128 r
.44187 .59868 m .44414 .5882 L .44372 .60414 L p F P
0 0 0 r
s
.53 .714 .91 r
.4829 .75475 m .4997 .75869 L .49983 .74208 L p F P
0 0 0 r
s
.53 .714 .91 r
.49983 .74208 m .48311 .73811 L .4829 .75475 L p F P
0 0 0 r
s
.336 .458 .618 r
.50704 .48935 m .48978 .49306 L .48996 .47777 L p F P
0 0 0 r
s
.336 .458 .618 r
.48996 .47777 m .50714 .47405 L .50704 .48935 L p F P
0 0 0 r
s
.336 .475 .553 r
.60757 .58735 m .61016 .59781 L .61058 .6137 L p F P
0 0 0 r
s
.336 .475 .553 r
.61016 .59781 m .60757 .58735 L .60716 .57158 L p F P
0 0 0 r
s
.38 .517 .692 r
.53593 .76058 m .5538 .75844 L .55366 .74183 L p F P
0 0 0 r
s
.328 .45 .612 r
.57026 .7377 m .55366 .74183 L .5538 .75844 L p F P
0 0 0 r
s
.545 .731 .921 r
.57654 .49837 m .56092 .49266 L .56075 .47738 L p F P
0 0 0 r
s
.496 .666 .853 r
.54346 .47385 m .56075 .47738 L .56092 .49266 L p F P
0 0 0 r
s
.152 .581 .376 r
.72677 .16279 m .74333 .19453 L .7354 .19396 L closepath p F P
0 0 0 r
s
.09 .132 .21 r
.45032 .5782 m .44414 .5882 L .44454 .57243 L p F P
0 0 0 r
s
.09 .132 .21 r
.44454 .57243 m .4507 .56238 L .45032 .5782 L p F P
0 0 0 r
s
.177 .561 .251 r
.72677 .16279 m .75019 .18133 L .75075 .1882 L closepath p F P
0 0 0 r
s
.604 .823 .997 r
.44707 .6996 m .45625 .70835 L .4566 .69197 L p F P
0 0 0 r
s
.604 .823 .997 r
.4566 .69197 m .44746 .68317 L .44707 .6996 L p F P
0 0 0 r
s
.495 .68 .818 r
.6007 .56159 m .60716 .57158 L .60757 .58735 L p F P
0 0 0 r
s
.495 .68 .818 r
.60716 .57158 m .6007 .56159 L .60032 .54592 L p F P
0 0 0 r
s
.61 .825 1 r
.4559 .7249 m .46824 .7323 L .46853 .7158 L p F P
0 0 0 r
s
.61 .825 1 r
.46853 .7158 m .45625 .70835 L .4559 .7249 L p F P
0 0 0 r
s
.28 .387 .532 r
.48959 .5085 m .47408 .51435 L .47434 .49893 L p F P
0 0 0 r
s
.28 .387 .532 r
.47434 .49893 m .48978 .49306 L .48959 .5085 L p F P
0 0 0 r
s
.223 .312 .442 r
.58465 .71524 m .5967 .70767 L .59634 .69129 L p F P
0 0 0 r
s
.159 .222 .331 r
.6052 .68239 m .59634 .69129 L .5967 .70767 L p F P
0 0 0 r
s
.159 .222 .331 r
.59634 .69129 m .6052 .68239 L .60481 .66612 L p F P
0 0 0 r
s
.275 .382 .53 r
.57026 .7377 m .58495 .73175 L .58465 .71524 L p F P
0 0 0 r
s
.223 .312 .442 r
.5967 .70767 m .58465 .71524 L .58495 .73175 L p F P
0 0 0 r
s
.163 .225 .333 r
.46051 .5533 m .4507 .56238 L .45107 .54672 L p F P
0 0 0 r
s
.163 .225 .333 r
.45107 .54672 m .46084 .5376 L .46051 .5533 L p F P
0 0 0 r
s
.494 .685 .822 r
.44188 .67343 m .44746 .68317 L .44786 .6669 L p F P
0 0 0 r
s
.494 .685 .822 r
.44786 .6669 m .4423 .65711 L .44188 .67343 L p F P
0 0 0 r
s
.584 .784 .971 r
.58995 .52136 m .5768 .51379 L .57654 .49837 L p F P
0 0 0 r
s
.545 .731 .921 r
.56092 .49266 m .57654 .49837 L .5768 .51379 L p F P
0 0 0 r
s
.391 .529 .7 r
.52527 .48803 m .50704 .48935 L .50714 .47405 L p F P
0 0 0 r
s
.391 .529 .7 r
.50714 .47405 m .52528 .47272 L .52527 .48803 L p F P
0 0 0 r
s
.225 .313 .441 r
.47382 .52993 m .46084 .5376 L .46116 .52206 L p F P
0 0 0 r
s
.225 .313 .441 r
.46116 .52206 m .47408 .51435 L .47382 .52993 L p F P
0 0 0 r
s
.496 .666 .853 r
.56092 .49266 m .54354 .48915 L .54346 .47385 L p F P
0 0 0 r
s
.444 .598 .779 r
.52528 .47272 m .54346 .47385 L .54354 .48915 L p F P
0 0 0 r
s
.588 .794 .966 r
.59027 .53691 m .60032 .54592 L .6007 .56159 L p F P
0 0 0 r
s
.588 .794 .966 r
.60032 .54592 m .59027 .53691 L .58995 .52136 L p F P
0 0 0 r
s
.69 .09 .12 r
.59455 .53166 m
.60014 .53815 L
s
.092 .135 .216 r
.61006 .65628 m .60481 .66612 L .6052 .68239 L p F P
0 0 0 r
s
.092 .135 .216 r
.60481 .66612 m .61006 .65628 L .60964 .64012 L p F P
0 0 0 r
s
.584 .784 .971 r
.5768 .51379 m .58995 .52136 L .59027 .53691 L p F P
0 0 0 r
s
.576 .776 .973 r
.46795 .74898 m .4829 .75475 L .48311 .73811 L p F P
0 0 0 r
s
.576 .776 .973 r
.48311 .73811 m .46824 .7323 L .46795 .74898 L p F P
0 0 0 r
s
.444 .598 .779 r
.54354 .48915 m .52527 .48803 L .52528 .47272 L p F P
0 0 0 r
s
.328 .45 .612 r
.5538 .75844 m .57048 .75434 L .57026 .7377 L p F P
0 0 0 r
s
.275 .382 .53 r
.58495 .73175 m .57026 .7377 L .57048 .75434 L p F P
0 0 0 r
s
.337 .479 .557 r
.44059 .64682 m .4423 .65711 L .44272 .64096 L p F P
0 0 0 r
s
.337 .479 .557 r
.44272 .64096 m .44102 .63061 L .44059 .64682 L p F P
0 0 0 r
s
.333 .887 .639 r
.72677 .16279 m .75075 .1882 L .74333 .19453 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.74585 .19239 m
.78864 .2588 L
s
.061 .09 .132 r
.61101 .62975 m .60964 .64012 L .61006 .65628 L p F P
0 0 0 r
s
.061 .09 .132 r
.60964 .64012 m .61101 .62975 L .61058 .6137 L p F P
0 0 0 r
s
.481 .649 .84 r
.49957 .77547 m .5176 .77743 L .51764 .76066 L p F P
0 0 0 r
s
.481 .649 .84 r
.51764 .76066 m .4997 .75869 L .49957 .77547 L p F P
0 0 0 r
s
.431 .584 .767 r
.53593 .76058 m .51764 .76066 L .5176 .77743 L p F P
0 0 0 r
s
.431 .584 .767 r
.5176 .77743 m .53598 .77734 L .53593 .76058 L p F P
0 0 0 r
s
.38 .517 .692 r
.5538 .75844 m .53593 .76058 L .53598 .77734 L p F P
0 0 0 r
s
.039 .263 .052 r
.55343 .88112 m .53528 .88074 L .53593 .88312 L closepath p F P
0 0 0 r
s
.205 .624 .378 r
.55343 .88112 m .53591 .87634 L .53528 .88074 L closepath p F P
0 0 0 r
s
.223 .74 .518 r
.55343 .88112 m .53718 .8743 L .53591 .87634 L closepath p F P
0 0 0 r
s
.284 .763 .497 r
.55343 .88112 m .5372 .8811 L .53783 .87668 L closepath p F P
0 0 0 r
s
.273 .886 .59 r
.55343 .88112 m .53593 .88312 L .5372 .8811 L closepath p F P
0 0 0 r
s
.067 .315 .088 r
.55343 .88112 m .53783 .87668 L .53718 .8743 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.48556 .87143 m
.53752 .87885 L
s
.06 .088 .128 r
.44331 .62024 m .44102 .63061 L .44145 .61457 L p F P
0 0 0 r
s
.06 .088 .128 r
.44145 .61457 m .44372 .60414 L .44331 .62024 L p F P
0 0 0 r
s
.255 .743 .514 r
.44846 .52978 m .45881 .5269 L .4577 .52462 L closepath p F P
0 0 0 r
s
.062 .342 .104 r
.44846 .52978 m .45877 .52901 L .45881 .5269 L closepath p F P
0 0 0 r
s
0 .337 0 r
.44846 .52978 m .4576 .52885 L .45877 .52901 L closepath p F P
0 0 0 r
s
.18 .618 .409 r
.44846 .52978 m .45648 .52658 L .4576 .52885 L closepath p F P
0 0 0 r
s
.121 .67 .259 r
.44846 .52978 m .4577 .52462 L .45653 .52446 L closepath p F P
0 0 0 r
s
.009 .226 .022 r
.44846 .52978 m .45653 .52446 L .45648 .52658 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.45671 .52705 m
.46789 .52335 L
s
.329 .936 .687 r
.47634 .16624 m .50597 .17078 L .50819 .16522 L closepath p F P
0 0 0 r
s
.284 .764 .497 r
.47634 .16624 m .50483 .17841 L .50597 .17078 L closepath p F P
0 0 0 r
s
.53 .714 .91 r
.48268 .77155 m .49957 .77547 L .4997 .75869 L p F P
0 0 0 r
s
.53 .714 .91 r
.4997 .75869 m .4829 .75475 L .48268 .77155 L p F P
0 0 0 r
s
.336 .458 .618 r
.50695 .50481 m .48959 .5085 L .48978 .49306 L p F P
0 0 0 r
s
.336 .458 .618 r
.48978 .49306 m .50704 .48935 L .50695 .50481 L p F P
0 0 0 r
s
.336 .475 .553 r
.60798 .60329 m .61058 .6137 L .61101 .62975 L p F P
0 0 0 r
s
.336 .475 .553 r
.61058 .6137 m .60798 .60329 L .60757 .58735 L p F P
0 0 0 r
s
.38 .517 .692 r
.53598 .77734 m .55394 .77522 L .5538 .75844 L p F P
0 0 0 r
s
.328 .45 .612 r
.57048 .75434 m .5538 .75844 L .55394 .77522 L p F P
0 0 0 r
s
.545 .731 .921 r
.5768 .51379 m .5611 .50811 L .56092 .49266 L p F P
0 0 0 r
s
.496 .666 .853 r
.54354 .48915 m .56092 .49266 L .5611 .50811 L p F P
0 0 0 r
s
0 .15 0 r
.47634 .16624 m .5059 .18052 L .50483 .17841 L closepath p F P
0 0 0 r
s
.09 .132 .21 r
.44993 .59418 m .44372 .60414 L .44414 .5882 L p F P
0 0 0 r
s
.09 .132 .21 r
.44414 .5882 m .45032 .5782 L .44993 .59418 L p F P
0 0 0 r
s
.604 .823 .997 r
.44667 .7162 m .4559 .7249 L .45625 .70835 L p F P
0 0 0 r
s
.604 .823 .997 r
.45625 .70835 m .44707 .6996 L .44667 .7162 L p F P
0 0 0 r
s
.495 .68 .818 r
.60107 .57741 m .60757 .58735 L .60798 .60329 L p F P
0 0 0 r
s
.495 .68 .818 r
.60757 .58735 m .60107 .57741 L .6007 .56159 L p F P
0 0 0 r
s
.61 .825 1 r
.45554 .74161 m .46795 .74898 L .46824 .7323 L p F P
0 0 0 r
s
.61 .825 1 r
.46824 .7323 m .4559 .7249 L .45554 .74161 L p F P
0 0 0 r
s
.28 .387 .532 r
.48941 .5241 m .47382 .52993 L .47408 .51435 L p F P
0 0 0 r
s
.28 .387 .532 r
.47408 .51435 m .48959 .5085 L .48941 .5241 L p F P
0 0 0 r
s
.69 .09 .12 r
.46789 .52335 m
.47691 .52036 L
s
.47691 .52036 m
.48541 .51754 L
s
.223 .312 .442 r
.58495 .73175 m .59705 .72422 L .5967 .70767 L p F P
0 0 0 r
s
.159 .222 .331 r
.6056 .69883 m .5967 .70767 L .59705 .72422 L p F P
0 0 0 r
s
.159 .222 .331 r
.5967 .70767 m .6056 .69883 L .6052 .68239 L p F P
0 0 0 r
s
.275 .382 .53 r
.57048 .75434 m .58524 .74842 L .58495 .73175 L p F P
0 0 0 r
s
.223 .312 .442 r
.59705 .72422 m .58495 .73175 L .58524 .74842 L p F P
0 0 0 r
s
.163 .225 .333 r
.46017 .56916 m .45032 .5782 L .4507 .56238 L p F P
0 0 0 r
s
.163 .225 .333 r
.4507 .56238 m .46051 .5533 L .46017 .56916 L p F P
0 0 0 r
s
.494 .685 .822 r
.44145 .68992 m .44707 .6996 L .44746 .68317 L p F P
0 0 0 r
s
.494 .685 .822 r
.44746 .68317 m .44188 .67343 L .44145 .68992 L p F P
0 0 0 r
s
.584 .784 .971 r
.59027 .53691 m .57705 .52937 L .5768 .51379 L p F P
0 0 0 r
s
.545 .731 .921 r
.5611 .50811 m .5768 .51379 L .57705 .52937 L p F P
0 0 0 r
s
.391 .529 .7 r
.52527 .50349 m .50695 .50481 L .50704 .48935 L p F P
0 0 0 r
s
.391 .529 .7 r
.50704 .48935 m .52527 .48803 L .52527 .50349 L p F P
0 0 0 r
s
.225 .313 .441 r
.47355 .54566 m .46051 .5533 L .46084 .5376 L p F P
0 0 0 r
s
.225 .313 .441 r
.46084 .5376 m .47382 .52993 L .47355 .54566 L p F P
0 0 0 r
s
.024 .27 .053 r
.70869 .86725 m .68826 .87249 L .68852 .87799 L closepath p F P
0 0 0 r
s
.177 .615 .407 r
.70869 .86725 m .68585 .86747 L .68826 .87249 L closepath p F P
0 0 0 r
s
.496 .666 .853 r
.5611 .50811 m .54363 .50461 L .54354 .48915 L p F P
0 0 0 r
s
.444 .598 .779 r
.52527 .48803 m .54354 .48915 L .54363 .50461 L p F P
0 0 0 r
s
.588 .794 .966 r
.5906 .55261 m .6007 .56159 L .60107 .57741 L p F P
0 0 0 r
s
.588 .794 .966 r
.6007 .56159 m .5906 .55261 L .59027 .53691 L p F P
0 0 0 r
s
.092 .135 .216 r
.61048 .6726 m .6052 .68239 L .6056 .69883 L p F P
0 0 0 r
s
.092 .135 .216 r
.6052 .68239 m .61048 .6726 L .61006 .65628 L p F P
0 0 0 r
s
.584 .784 .971 r
.57705 .52937 m .59027 .53691 L .5906 .55261 L p F P
0 0 0 r
s
.576 .776 .973 r
.46766 .76582 m .48268 .77155 L .4829 .75475 L p F P
0 0 0 r
s
.576 .776 .973 r
.4829 .75475 m .46795 .74898 L .46766 .76582 L p F P
0 0 0 r
s
0 .109 0 r
.47634 .16624 m .50819 .16522 L .50927 .16729 L closepath p F P
0 0 0 r
s
.444 .598 .779 r
.54363 .50461 m .52527 .50349 L .52527 .48803 L p F P
0 0 0 r
s
.328 .45 .612 r
.55394 .77522 m .57071 .77114 L .57048 .75434 L p F P
0 0 0 r
s
.275 .382 .53 r
.58524 .74842 m .57048 .75434 L .57071 .77114 L p F P
0 0 0 r
s
0 .055 0 r
.70869 .86725 m .68368 .86793 L .68585 .86747 L closepath p F P
0 0 0 r
s
.337 .479 .557 r
.44015 .66319 m .44188 .67343 L .4423 .65711 L p F P
0 0 0 r
s
.337 .479 .557 r
.4423 .65711 m .44059 .64682 L .44015 .66319 L p F P
0 0 0 r
s
.246 .764 .547 r
.47634 .16624 m .50813 .17497 L .5059 .18052 L closepath p F P
0 0 0 r
s
.061 .09 .132 r
.61144 .64596 m .61006 .65628 L .61048 .6726 L p F P
0 0 0 r
s
.061 .09 .132 r
.61006 .65628 m .61144 .64596 L .61101 .62975 L p F P
0 0 0 r
s
.481 .649 .84 r
.49944 .79242 m .51755 .79436 L .5176 .77743 L p F P
0 0 0 r
s
.481 .649 .84 r
.5176 .77743 m .49957 .77547 L .49944 .79242 L p F P
0 0 0 r
s
.431 .584 .767 r
.53598 .77734 m .5176 .77743 L .51755 .79436 L p F P
0 0 0 r
s
.431 .584 .767 r
.51755 .79436 m .53603 .79428 L .53598 .77734 L p F P
0 0 0 r
s
.38 .517 .692 r
.55394 .77522 m .53598 .77734 L .53603 .79428 L p F P
0 0 0 r
s
0 .394 0 r
.70869 .86725 m .68852 .87799 L .68636 .87848 L closepath p F P
0 0 0 r
s
.37 1 .714 r
.58078 .51565 m .5836 .52093 L .58563 .51921 L closepath p F P
0 0 0 r
s
.036 .397 .051 r
.58078 .51565 m .58364 .52305 L .5836 .52093 L closepath p F P
0 0 0 r
s
.013 .331 .035 r
.58078 .51565 m .58563 .51921 L .58769 .5196 L closepath p F P
0 0 0 r
s
.06 .088 .128 r
.44288 .6365 m .44059 .64682 L .44102 .63061 L p F P
0 0 0 r
s
.06 .088 .128 r
.44102 .63061 m .44331 .62024 L .44288 .6365 L p F P
0 0 0 r
s
.126 .529 .322 r
.58078 .51565 m .58571 .52345 L .58364 .52305 L closepath p F P
0 0 0 r
s
.214 .62 .311 r
.58078 .51565 m .58769 .5196 L .58774 .52172 L closepath p F P
0 0 0 r
s
.53 .714 .91 r
.48246 .78852 m .49944 .79242 L .49957 .77547 L p F P
0 0 0 r
s
.53 .714 .91 r
.49957 .77547 m .48268 .77155 L .48246 .78852 L p F P
0 0 0 r
s
.336 .458 .618 r
.50685 .52042 m .48941 .5241 L .48959 .5085 L p F P
0 0 0 r
s
.336 .458 .618 r
.48959 .5085 m .50695 .50481 L .50685 .52042 L p F P
0 0 0 r
s
.336 .475 .553 r
.60839 .61939 m .61101 .62975 L .61144 .64596 L p F P
0 0 0 r
s
.336 .475 .553 r
.61101 .62975 m .60839 .61939 L .60798 .60329 L p F P
0 0 0 r
s
.38 .517 .692 r
.53603 .79428 m .55408 .79217 L .55394 .77522 L p F P
0 0 0 r
s
.328 .45 .612 r
.57071 .77114 m .55394 .77522 L .55408 .79217 L p F P
0 0 0 r
s
.545 .731 .921 r
.57705 .52937 m .56128 .52371 L .5611 .50811 L p F P
0 0 0 r
s
.496 .666 .853 r
.54363 .50461 m .5611 .50811 L .56128 .52371 L p F P
0 0 0 r
s
.337 .898 .648 r
.58078 .51565 m .58774 .52172 L .58571 .52345 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.58674 .52257 m
.59455 .53166 L
s
.077 .373 .132 r
.70869 .86725 m .68393 .87344 L .68368 .86793 L closepath p F P
0 0 0 r
s
.205 .623 .377 r
.47634 .16624 m .50927 .16729 L .50813 .17497 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.5084 .17316 m
.59799 .1925 L
s
.09 .132 .21 r
.44954 .61032 m .44331 .62024 L .44372 .60414 L p F P
0 0 0 r
s
.09 .132 .21 r
.44372 .60414 m .44993 .59418 L .44954 .61032 L p F P
0 0 0 r
s
.257 .748 .52 r
.70869 .86725 m .68636 .87848 L .68393 .87344 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.61946 .88984 m
.68396 .87351 L
s
.604 .823 .997 r
.44626 .73296 m .45554 .74161 L .4559 .7249 L p F P
0 0 0 r
s
.604 .823 .997 r
.4559 .7249 m .44667 .7162 L .44626 .73296 L p F P
0 0 0 r
s
.495 .68 .818 r
.60145 .5934 m .60798 .60329 L .60839 .61939 L p F P
0 0 0 r
s
.495 .68 .818 r
.60798 .60329 m .60145 .5934 L .60107 .57741 L p F P
0 0 0 r
s
.61 .825 1 r
.45519 .7585 m .46766 .76582 L .46795 .74898 L p F P
0 0 0 r
s
.61 .825 1 r
.46795 .74898 m .45554 .74161 L .45519 .7585 L p F P
0 0 0 r
s
.28 .387 .532 r
.48922 .53985 m .47355 .54566 L .47382 .52993 L p F P
0 0 0 r
s
.28 .387 .532 r
.47382 .52993 m .48941 .5241 L .48922 .53985 L p F P
0 0 0 r
s
.223 .312 .442 r
.58524 .74842 m .59741 .74094 L .59705 .72422 L p F P
0 0 0 r
s
.159 .222 .331 r
.60601 .71543 m .59705 .72422 L .59741 .74094 L p F P
0 0 0 r
s
.159 .222 .331 r
.59705 .72422 m .60601 .71543 L .6056 .69883 L p F P
0 0 0 r
s
.275 .382 .53 r
.57071 .77114 m .58554 .76527 L .58524 .74842 L p F P
0 0 0 r
s
.223 .312 .442 r
.59741 .74094 m .58524 .74842 L .58554 .76527 L p F P
0 0 0 r
s
.163 .225 .333 r
.45984 .58518 m .44993 .59418 L .45032 .5782 L p F P
0 0 0 r
s
.163 .225 .333 r
.45032 .5782 m .46017 .56916 L .45984 .58518 L p F P
0 0 0 r
s
.494 .685 .822 r
.44102 .70657 m .44667 .7162 L .44707 .6996 L p F P
0 0 0 r
s
.494 .685 .822 r
.44707 .6996 m .44145 .68992 L .44102 .70657 L p F P
0 0 0 r
s
.584 .784 .971 r
.5906 .55261 m .57731 .54511 L .57705 .52937 L p F P
0 0 0 r
s
.545 .731 .921 r
.56128 .52371 m .57705 .52937 L .57731 .54511 L p F P
0 0 0 r
s
.391 .529 .7 r
.52527 .51911 m .50685 .52042 L .50695 .50481 L p F P
0 0 0 r
s
.391 .529 .7 r
.50695 .50481 m .52527 .50349 L .52527 .51911 L p F P
0 0 0 r
s
.225 .313 .441 r
.47329 .56155 m .46017 .56916 L .46051 .5533 L p F P
0 0 0 r
s
.225 .313 .441 r
.46051 .5533 m .47355 .54566 L .47329 .56155 L p F P
0 0 0 r
s
.496 .666 .853 r
.56128 .52371 m .54372 .52022 L .54363 .50461 L p F P
0 0 0 r
s
.444 .598 .779 r
.52527 .50349 m .54363 .50461 L .54372 .52022 L p F P
0 0 0 r
s
.588 .794 .966 r
.59093 .56847 m .60107 .57741 L .60145 .5934 L p F P
0 0 0 r
s
.588 .794 .966 r
.60107 .57741 m .59093 .56847 L .5906 .55261 L p F P
0 0 0 r
s
.092 .135 .216 r
.61091 .68909 m .6056 .69883 L .60601 .71543 L p F P
0 0 0 r
s
.092 .135 .216 r
.6056 .69883 m .61091 .68909 L .61048 .6726 L p F P
0 0 0 r
s
.584 .784 .971 r
.57731 .54511 m .5906 .55261 L .59093 .56847 L p F P
0 0 0 r
s
.576 .776 .973 r
.46736 .78283 m .48246 .78852 L .48268 .77155 L p F P
0 0 0 r
s
.576 .776 .973 r
.48268 .77155 m .46766 .76582 L .46736 .78283 L p F P
0 0 0 r
s
.444 .598 .779 r
.54372 .52022 m .52527 .51911 L .52527 .50349 L p F P
0 0 0 r
s
.235 .655 .351 r
.43479 .86851 m .42249 .85983 L .42237 .86378 L closepath p F P
0 0 0 r
s
0 .217 0 r
.43479 .86851 m .42237 .86378 L .42565 .86486 L closepath p F P
0 0 0 r
s
.342 .909 .658 r
.43479 .86851 m .42588 .85696 L .42249 .85983 L closepath p F P
0 0 0 r
s
.082 .435 .215 r
.43479 .86851 m .42916 .85803 L .42588 .85696 L closepath p F P
0 0 0 r
s
.118 .528 .173 r
.43479 .86851 m .42905 .86198 L .42916 .85803 L closepath p F P
0 0 0 r
s
.353 1 .684 r
.43479 .86851 m .42565 .86486 L .42905 .86198 L closepath p F P
0 0 0 r
s
.328 .45 .612 r
.55408 .79217 m .57093 .78812 L .57071 .77114 L p F P
0 0 0 r
s
.275 .382 .53 r
.58554 .76527 m .57071 .77114 L .57093 .78812 L p F P
0 0 0 r
s
.69 .09 .12 r
.39809 .83758 m
.42805 .86283 L
s
.337 .479 .557 r
.43972 .67973 m .44145 .68992 L .44188 .67343 L p F P
0 0 0 r
s
.337 .479 .557 r
.44188 .67343 m .44015 .66319 L .43972 .67973 L p F P
0 0 0 r
s
.061 .09 .132 r
.61187 .66234 m .61048 .6726 L .61091 .68909 L p F P
0 0 0 r
s
.061 .09 .132 r
.61048 .6726 m .61187 .66234 L .61144 .64596 L p F P
0 0 0 r
s
.481 .649 .84 r
.4993 .80954 m .51751 .81147 L .51755 .79436 L p F P
0 0 0 r
s
.481 .649 .84 r
.51755 .79436 m .49944 .79242 L .4993 .80954 L p F P
0 0 0 r
s
.431 .584 .767 r
.53603 .79428 m .51755 .79436 L .51751 .81147 L p F P
0 0 0 r
s
.431 .584 .767 r
.51751 .81147 m .53608 .81139 L .53603 .79428 L p F P
0 0 0 r
s
.38 .517 .692 r
.55408 .79217 m .53603 .79428 L .53608 .81139 L p F P
0 0 0 r
s
.69 .09 .12 r
.53378 .51042 m
.54517 .51249 L
s
.54517 .51249 m
.5504 .51343 L
s
.06 .088 .128 r
.44246 .65292 m .44015 .66319 L .44059 .64682 L p F P
0 0 0 r
s
.06 .088 .128 r
.44059 .64682 m .44288 .6365 L .44246 .65292 L p F P
0 0 0 r
s
.53 .714 .91 r
.48224 .80567 m .4993 .80954 L .49944 .79242 L p F P
0 0 0 r
s
.53 .714 .91 r
.49944 .79242 m .48246 .78852 L .48224 .80567 L p F P
0 0 0 r
s
.336 .458 .618 r
.50675 .53619 m .48922 .53985 L .48941 .5241 L p F P
0 0 0 r
s
.336 .458 .618 r
.48941 .5241 m .50685 .52042 L .50675 .53619 L p F P
0 0 0 r
s
.336 .475 .553 r
.60881 .63566 m .61144 .64596 L .61187 .66234 L p F P
0 0 0 r
s
.336 .475 .553 r
.61144 .64596 m .60881 .63566 L .60839 .61939 L p F P
0 0 0 r
s
.38 .517 .692 r
.53608 .81139 m .55423 .80929 L .55408 .79217 L p F P
0 0 0 r
s
.328 .45 .612 r
.57093 .78812 m .55408 .79217 L .55423 .80929 L p F P
0 0 0 r
s
.545 .731 .921 r
.57731 .54511 m .56146 .53947 L .56128 .52371 L p F P
0 0 0 r
s
.496 .666 .853 r
.54372 .52022 m .56128 .52371 L .56146 .53947 L p F P
0 0 0 r
s
.09 .132 .21 r
.44915 .62663 m .44288 .6365 L .44331 .62024 L p F P
0 0 0 r
s
.09 .132 .21 r
.44331 .62024 m .44954 .61032 L .44915 .62663 L p F P
0 0 0 r
s
.316 .934 .669 r
.50935 .506 m .51927 .50681 L .52003 .50524 L closepath p F P
0 0 0 r
s
.284 .764 .498 r
.50935 .506 m .51889 .50943 L .51927 .50681 L closepath p F P
0 0 0 r
s
.604 .823 .997 r
.44585 .7499 m .45519 .7585 L .45554 .74161 L p F P
0 0 0 r
s
.604 .823 .997 r
.45554 .74161 m .44626 .73296 L .44585 .7499 L p F P
0 0 0 r
s
.495 .68 .818 r
.60184 .60954 m .60839 .61939 L .60881 .63566 L p F P
0 0 0 r
s
.495 .68 .818 r
.60839 .61939 m .60184 .60954 L .60145 .5934 L p F P
0 0 0 r
s
.025 .226 .033 r
.50935 .506 m .51926 .51049 L .51889 .50943 L closepath p F P
0 0 0 r
s
.61 .825 1 r
.45482 .77556 m .46736 .78283 L .46766 .76582 L p F P
0 0 0 r
s
.61 .825 1 r
.46766 .76582 m .45519 .7585 L .45482 .77556 L p F P
0 0 0 r
s
.28 .387 .532 r
.48903 .55577 m .47329 .56155 L .47355 .54566 L p F P
0 0 0 r
s
.28 .387 .532 r
.47355 .54566 m .48922 .53985 L .48903 .55577 L p F P
0 0 0 r
s
.223 .312 .442 r
.58554 .76527 m .59778 .75783 L .59741 .74094 L p F P
0 0 0 r
s
.159 .222 .331 r
.60641 .7322 m .59741 .74094 L .59778 .75783 L p F P
0 0 0 r
s
.159 .222 .331 r
.59741 .74094 m .60641 .7322 L .60601 .71543 L p F P
0 0 0 r
s
.275 .382 .53 r
.57093 .78812 m .58585 .78228 L .58554 .76527 L p F P
0 0 0 r
s
.223 .312 .442 r
.59778 .75783 m .58554 .76527 L .58585 .78228 L p F P
0 0 0 r
s
.163 .225 .333 r
.4595 .60137 m .44954 .61032 L .44993 .59418 L p F P
0 0 0 r
s
.163 .225 .333 r
.44993 .59418 m .45984 .58518 L .4595 .60137 L p F P
0 0 0 r
s
.494 .685 .822 r
.44058 .72339 m .44626 .73296 L .44667 .7162 L p F P
0 0 0 r
s
.494 .685 .822 r
.44667 .7162 m .44102 .70657 L .44058 .72339 L p F P
0 0 0 r
s
.584 .784 .971 r
.59093 .56847 m .57757 .561 L .57731 .54511 L p F P
0 0 0 r
s
.545 .731 .921 r
.56146 .53947 m .57731 .54511 L .57757 .561 L p F P
0 0 0 r
s
.391 .529 .7 r
.52526 .53488 m .50675 .53619 L .50685 .52042 L p F P
0 0 0 r
s
.391 .529 .7 r
.50685 .52042 m .52527 .51911 L .52526 .53488 L p F P
0 0 0 r
s
.014 .188 .018 r
.50935 .506 m .52003 .50524 L .5204 .50629 L closepath p F P
0 0 0 r
s
.225 .313 .441 r
.47301 .57761 m .45984 .58518 L .46017 .56916 L p F P
0 0 0 r
s
.225 .313 .441 r
.46017 .56916 m .47329 .56155 L .47301 .57761 L p F P
0 0 0 r
s
.496 .666 .853 r
.56146 .53947 m .54381 .536 L .54372 .52022 L p F P
0 0 0 r
s
.444 .598 .779 r
.52527 .51911 m .54372 .52022 L .54381 .536 L p F P
0 0 0 r
s
.588 .794 .966 r
.59126 .5845 m .60145 .5934 L .60184 .60954 L p F P
0 0 0 r
s
.588 .794 .966 r
.60145 .5934 m .59126 .5845 L .59093 .56847 L p F P
0 0 0 r
s
.255 .743 .515 r
.39508 .50769 m .4125 .5028 L .41059 .49894 L closepath p F P
0 0 0 r
s
.059 .336 .098 r
.39508 .50769 m .41237 .50635 L .4125 .5028 L closepath p F P
0 0 0 r
s
0 .343 0 r
.39508 .50769 m .41032 .50604 L .41237 .50635 L closepath p F P
0 0 0 r
s
.179 .617 .408 r
.39508 .50769 m .4084 .50217 L .41032 .50604 L closepath p F P
0 0 0 r
s
.139 .7 .295 r
.39508 .50769 m .41059 .49894 L .40853 .49862 L closepath p F P
0 0 0 r
s
.006 .216 .016 r
.39508 .50769 m .40853 .49862 L .4084 .50217 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.40883 .50304 m
.45712 .48667 L
s
.092 .135 .216 r
.61135 .70575 m .60601 .71543 L .60641 .7322 L p F P
0 0 0 r
s
.092 .135 .216 r
.60601 .71543 m .61135 .70575 L .61091 .68909 L p F P
0 0 0 r
s
.238 .758 .54 r
.50935 .506 m .52002 .50892 L .51926 .51049 L closepath p F P
0 0 0 r
s
.584 .784 .971 r
.57757 .561 m .59093 .56847 L .59126 .5845 L p F P
0 0 0 r
s
.576 .776 .973 r
.46706 .80001 m .48224 .80567 L .48246 .78852 L p F P
0 0 0 r
s
.576 .776 .973 r
.48246 .78852 m .46736 .78283 L .46706 .80001 L p F P
0 0 0 r
s
.444 .598 .779 r
.54381 .536 m .52526 .53488 L .52527 .51911 L p F P
0 0 0 r
s
.328 .45 .612 r
.55423 .80929 m .57116 .80527 L .57093 .78812 L p F P
0 0 0 r
s
.275 .382 .53 r
.58585 .78228 m .57093 .78812 L .57116 .80527 L p F P
0 0 0 r
s
.337 .479 .557 r
.43927 .69644 m .44102 .70657 L .44145 .68992 L p F P
0 0 0 r
s
.337 .479 .557 r
.44145 .68992 m .43972 .67973 L .43927 .69644 L p F P
0 0 0 r
s
.205 .623 .377 r
.50935 .506 m .5204 .50629 L .52002 .50892 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.52016 .50795 m
.53378 .51042 L
s
.061 .09 .132 r
.61231 .67888 m .61091 .68909 L .61135 .70575 L p F P
0 0 0 r
s
.061 .09 .132 r
.61091 .68909 m .61231 .67888 L .61187 .66234 L p F P
0 0 0 r
s
.481 .649 .84 r
.49916 .82684 m .51747 .82876 L .51751 .81147 L p F P
0 0 0 r
s
.481 .649 .84 r
.51751 .81147 m .4993 .80954 L .49916 .82684 L p F P
0 0 0 r
s
.431 .584 .767 r
.53608 .81139 m .51751 .81147 L .51747 .82876 L p F P
0 0 0 r
s
.431 .584 .767 r
.51747 .82876 m .53613 .82867 L .53608 .81139 L p F P
0 0 0 r
s
.38 .517 .692 r
.55423 .80929 m .53608 .81139 L .53613 .82867 L p F P
0 0 0 r
s
.06 .088 .128 r
.44203 .66952 m .43972 .67973 L .44015 .66319 L p F P
0 0 0 r
s
.06 .088 .128 r
.44015 .66319 m .44246 .65292 L .44203 .66952 L p F P
0 0 0 r
s
.53 .714 .91 r
.48201 .82299 m .49916 .82684 L .4993 .80954 L p F P
0 0 0 r
s
.53 .714 .91 r
.4993 .80954 m .48224 .80567 L .48201 .82299 L p F P
0 0 0 r
s
.336 .458 .618 r
.50665 .55213 m .48903 .55577 L .48922 .53985 L p F P
0 0 0 r
s
.336 .458 .618 r
.48922 .53985 m .50675 .53619 L .50665 .55213 L p F P
0 0 0 r
s
.336 .475 .553 r
.60924 .65209 m .61187 .66234 L .61231 .67888 L p F P
0 0 0 r
s
.336 .475 .553 r
.61187 .66234 m .60924 .65209 L .60881 .63566 L p F P
0 0 0 r
s
.38 .517 .692 r
.53613 .82867 m .55437 .82659 L .55423 .80929 L p F P
0 0 0 r
s
.328 .45 .612 r
.57116 .80527 m .55423 .80929 L .55437 .82659 L p F P
0 0 0 r
s
.545 .731 .921 r
.57757 .561 m .56164 .55538 L .56146 .53947 L p F P
0 0 0 r
s
.496 .666 .853 r
.54381 .536 m .56146 .53947 L .56164 .55538 L p F P
0 0 0 r
s
.09 .132 .21 r
.44876 .64311 m .44246 .65292 L .44288 .6365 L p F P
0 0 0 r
s
.09 .132 .21 r
.44288 .6365 m .44915 .62663 L .44876 .64311 L p F P
0 0 0 r
s
.604 .823 .997 r
.44544 .76702 m .45482 .77556 L .45519 .7585 L p F P
0 0 0 r
s
.604 .823 .997 r
.45519 .7585 m .44585 .7499 L .44544 .76702 L p F P
0 0 0 r
s
.495 .68 .818 r
.60223 .62586 m .60881 .63566 L .60924 .65209 L p F P
0 0 0 r
s
.495 .68 .818 r
.60881 .63566 m .60223 .62586 L .60184 .60954 L p F P
0 0 0 r
s
.61 .825 1 r
.45446 .79279 m .46706 .80001 L .46736 .78283 L p F P
0 0 0 r
s
.61 .825 1 r
.46736 .78283 m .45482 .77556 L .45446 .79279 L p F P
0 0 0 r
s
.28 .387 .532 r
.48884 .57185 m .47301 .57761 L .47329 .56155 L p F P
0 0 0 r
s
.28 .387 .532 r
.47329 .56155 m .48903 .55577 L .48884 .57185 L p F P
0 0 0 r
s
.223 .312 .442 r
.58585 .78228 m .59814 .7749 L .59778 .75783 L p F P
0 0 0 r
s
.159 .222 .331 r
.60683 .74915 m .59778 .75783 L .59814 .7749 L p F P
0 0 0 r
s
.159 .222 .331 r
.59778 .75783 m .60683 .74915 L .60641 .7322 L p F P
0 0 0 r
s
.021 .262 .046 r
.6582 .84934 m .64363 .85323 L .64377 .85719 L closepath p F P
0 0 0 r
s
.176 .613 .405 r
.6582 .84934 m .64185 .84958 L .64363 .85323 L closepath p F P
0 0 0 r
s
.275 .382 .53 r
.57116 .80527 m .58615 .79947 L .58585 .78228 L p F P
0 0 0 r
s
.223 .312 .442 r
.59814 .7749 m .58585 .78228 L .58615 .79947 L p F P
0 0 0 r
s
.163 .225 .333 r
.45916 .61772 m .44915 .62663 L .44954 .61032 L p F P
0 0 0 r
s
.163 .225 .333 r
.44954 .61032 m .4595 .60137 L .45916 .61772 L p F P
0 0 0 r
s
.494 .685 .822 r
.44014 .74039 m .44585 .7499 L .44626 .73296 L p F P
0 0 0 r
s
.494 .685 .822 r
.44626 .73296 m .44058 .72339 L .44014 .74039 L p F P
0 0 0 r
s
.584 .784 .971 r
.59126 .5845 m .57784 .57706 L .57757 .561 L p F P
0 0 0 r
s
.545 .731 .921 r
.56164 .55538 m .57757 .561 L .57784 .57706 L p F P
0 0 0 r
s
.391 .529 .7 r
.52526 .55082 m .50665 .55213 L .50675 .53619 L p F P
0 0 0 r
s
.391 .529 .7 r
.50675 .53619 m .52526 .53488 L .52526 .55082 L p F P
0 0 0 r
s
.225 .313 .441 r
.47274 .59383 m .4595 .60137 L .45984 .58518 L p F P
0 0 0 r
s
.225 .313 .441 r
.45984 .58518 m .47301 .57761 L .47274 .59383 L p F P
0 0 0 r
s
.496 .666 .853 r
.56164 .55538 m .5439 .55193 L .54381 .536 L p F P
0 0 0 r
s
.444 .598 .779 r
.52526 .53488 m .54381 .536 L .5439 .55193 L p F P
0 0 0 r
s
.588 .794 .966 r
.59159 .60069 m .60184 .60954 L .60223 .62586 L p F P
0 0 0 r
s
.588 .794 .966 r
.60184 .60954 m .59159 .60069 L .59126 .5845 L p F P
0 0 0 r
s
0 .052 0 r
.6582 .84934 m .64021 .84988 L .64185 .84958 L closepath p F P
0 0 0 r
s
.092 .135 .216 r
.61178 .72257 m .60641 .7322 L .60683 .74915 L p F P
0 0 0 r
s
.092 .135 .216 r
.60641 .7322 m .61178 .72257 L .61135 .70575 L p F P
0 0 0 r
s
.584 .784 .971 r
.57784 .57706 m .59126 .5845 L .59159 .60069 L p F P
0 0 0 r
s
.576 .776 .973 r
.46675 .81738 m .48201 .82299 L .48224 .80567 L p F P
0 0 0 r
s
.576 .776 .973 r
.48224 .80567 m .46706 .80001 L .46675 .81738 L p F P
0 0 0 r
s
.444 .598 .779 r
.5439 .55193 m .52526 .55082 L .52526 .53488 L p F P
0 0 0 r
s
.328 .45 .612 r
.55437 .82659 m .5714 .8226 L .57116 .80527 L p F P
0 0 0 r
s
.275 .382 .53 r
.58615 .79947 m .57116 .80527 L .5714 .8226 L p F P
0 0 0 r
s
0 .403 0 r
.6582 .84934 m .64377 .85719 L .64212 .85751 L closepath p F P
0 0 0 r
s
.337 .479 .557 r
.43882 .71333 m .44058 .72339 L .44102 .70657 L p F P
0 0 0 r
s
.337 .479 .557 r
.44102 .70657 m .43927 .69644 L .43882 .71333 L p F P
0 0 0 r
s
.061 .09 .132 r
.61276 .6956 m .61135 .70575 L .61178 .72257 L p F P
0 0 0 r
s
.061 .09 .132 r
.61135 .70575 m .61276 .6956 L .61231 .67888 L p F P
0 0 0 r
s
.481 .649 .84 r
.49903 .84431 m .51742 .84622 L .51747 .82876 L p F P
0 0 0 r
s
.481 .649 .84 r
.51747 .82876 m .49916 .82684 L .49903 .84431 L p F P
0 0 0 r
s
.431 .584 .767 r
.53613 .82867 m .51747 .82876 L .51742 .84622 L p F P
0 0 0 r
s
.431 .584 .767 r
.51742 .84622 m .53619 .84613 L .53613 .82867 L p F P
0 0 0 r
s
.38 .517 .692 r
.55437 .82659 m .53613 .82867 L .53619 .84613 L p F P
0 0 0 r
s
.074 .367 .127 r
.6582 .84934 m .64034 .85385 L .64021 .84988 L closepath p F P
0 0 0 r
s
.368 1 .711 r
.61898 .48339 m .62349 .49256 L .62693 .48964 L closepath p F P
0 0 0 r
s
.019 .367 .027 r
.61898 .48339 m .62361 .49611 L .62349 .49256 L closepath p F P
0 0 0 r
s
.02 .349 .052 r
.61898 .48339 m .62693 .48964 L .63048 .49027 L closepath p F P
0 0 0 r
s
.06 .088 .128 r
.44159 .68628 m .43927 .69644 L .43972 .67973 L p F P
0 0 0 r
s
.06 .088 .128 r
.43972 .67973 m .44203 .66952 L .44159 .68628 L p F P
0 0 0 r
s
.257 .748 .521 r
.6582 .84934 m .64212 .85751 L .64034 .85385 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.59394 .86598 m
.64039 .85395 L
s
.53 .714 .91 r
.48178 .8405 m .49903 .84431 L .49916 .82684 L p F P
0 0 0 r
s
.53 .714 .91 r
.49916 .82684 m .48201 .82299 L .48178 .8405 L p F P
0 0 0 r
s
.336 .458 .618 r
.50655 .56822 m .48884 .57185 L .48903 .55577 L p F P
0 0 0 r
s
.336 .458 .618 r
.48903 .55577 m .50665 .55213 L .50655 .56822 L p F P
0 0 0 r
s
.336 .475 .553 r
.60967 .66869 m .61231 .67888 L .61276 .6956 L p F P
0 0 0 r
s
.336 .475 .553 r
.61231 .67888 m .60967 .66869 L .60924 .65209 L p F P
0 0 0 r
s
.38 .517 .692 r
.53619 .84613 m .55452 .84407 L .55437 .82659 L p F P
0 0 0 r
s
.328 .45 .612 r
.5714 .8226 m .55437 .82659 L .55452 .84407 L p F P
0 0 0 r
s
.545 .731 .921 r
.57784 .57706 m .56182 .57147 L .56164 .55538 L p F P
0 0 0 r
s
.496 .666 .853 r
.5439 .55193 m .56164 .55538 L .56182 .57147 L p F P
0 0 0 r
s
.33 .936 .687 r
.46394 .11953 m .501 .12556 L .50375 .11847 L closepath p F P
0 0 0 r
s
.285 .765 .498 r
.46394 .11953 m .49958 .13506 L .501 .12556 L closepath p F P
0 0 0 r
s
.128 .534 .326 r
.61898 .48339 m .62716 .49675 L .62361 .49611 L closepath p F P
0 0 0 r
s
.205 .623 .378 r
.54284 .85072 m .53209 .84778 L .53171 .85048 L closepath p F P
0 0 0 r
s
.222 .739 .517 r
.54284 .85072 m .53287 .84651 L .53209 .84778 L closepath p F P
0 0 0 r
s
.062 .305 .082 r
.54284 .85072 m .53326 .84793 L .53287 .84651 L closepath p F P
0 0 0 r
s
.036 .253 .047 r
.54284 .85072 m .53171 .85048 L .5321 .85191 L closepath p F P
0 0 0 r
s
.285 .765 .498 r
.54284 .85072 m .53287 .85064 L .53326 .84793 L closepath p F P
0 0 0 r
s
.274 .887 .592 r
.54284 .85072 m .5321 .85191 L .53287 .85064 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.50128 .84466 m
.51213 .84624 L
s
.51213 .84624 m
.53307 .84929 L
s
.207 .608 .298 r
.61898 .48339 m .63048 .49027 L .6306 .49383 L closepath p F P
0 0 0 r
s
.09 .132 .21 r
.44836 .65976 m .44203 .66952 L .44246 .65292 L p F P
0 0 0 r
s
.09 .132 .21 r
.44246 .65292 m .44876 .64311 L .44836 .65976 L p F P
0 0 0 r
s
0 .142 0 r
.46394 .11953 m .50089 .13753 L .49958 .13506 L closepath p F P
0 0 0 r
s
.604 .823 .997 r
.44502 .78431 m .45446 .79279 L .45482 .77556 L p F P
0 0 0 r
s
.604 .823 .997 r
.45482 .77556 m .44544 .76702 L .44502 .78431 L p F P
0 0 0 r
s
.495 .68 .818 r
.60262 .64234 m .60924 .65209 L .60967 .66869 L p F P
0 0 0 r
s
.495 .68 .818 r
.60924 .65209 m .60262 .64234 L .60223 .62586 L p F P
0 0 0 r
s
.61 .825 1 r
.45409 .8102 m .46675 .81738 L .46706 .80001 L p F P
0 0 0 r
s
.61 .825 1 r
.46706 .80001 m .45446 .79279 L .45409 .8102 L p F P
0 0 0 r
s
.28 .387 .532 r
.48865 .5881 m .47274 .59383 L .47301 .57761 L p F P
0 0 0 r
s
.28 .387 .532 r
.47301 .57761 m .48884 .57185 L .48865 .5881 L p F P
0 0 0 r
s
.339 .901 .651 r
.61898 .48339 m .6306 .49383 L .62716 .49675 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.62882 .49535 m
.65071 .52196 L
s
.223 .312 .442 r
.58615 .79947 m .59852 .79214 L .59814 .7749 L p F P
0 0 0 r
s
.159 .222 .331 r
.60724 .76626 m .59814 .7749 L .59852 .79214 L p F P
0 0 0 r
s
.159 .222 .331 r
.59814 .7749 m .60724 .76626 L .60683 .74915 L p F P
0 0 0 r
s
.275 .382 .53 r
.5714 .8226 m .58646 .81684 L .58615 .79947 L p F P
0 0 0 r
s
.223 .312 .442 r
.59852 .79214 m .58615 .79947 L .58646 .81684 L p F P
0 0 0 r
s
.163 .225 .333 r
.45881 .63424 m .44876 .64311 L .44915 .62663 L p F P
0 0 0 r
s
.163 .225 .333 r
.44915 .62663 m .45916 .61772 L .45881 .63424 L p F P
0 0 0 r
s
.494 .685 .822 r
.43969 .75756 m .44544 .76702 L .44585 .7499 L p F P
0 0 0 r
s
.494 .685 .822 r
.44585 .7499 m .44014 .74039 L .43969 .75756 L p F P
0 0 0 r
s
.584 .784 .971 r
.59159 .60069 m .5781 .59328 L .57784 .57706 L p F P
0 0 0 r
s
.545 .731 .921 r
.56182 .57147 m .57784 .57706 L .5781 .59328 L p F P
0 0 0 r
s
.391 .529 .7 r
.52525 .56693 m .50655 .56822 L .50665 .55213 L p F P
0 0 0 r
s
.391 .529 .7 r
.50665 .55213 m .52526 .55082 L .52525 .56693 L p F P
0 0 0 r
s
.225 .313 .441 r
.47247 .61022 m .45916 .61772 L .4595 .60137 L p F P
0 0 0 r
s
.225 .313 .441 r
.4595 .60137 m .47274 .59383 L .47247 .61022 L p F P
0 0 0 r
s
.496 .666 .853 r
.56182 .57147 m .54399 .56803 L .5439 .55193 L p F P
0 0 0 r
s
.444 .598 .779 r
.52526 .55082 m .5439 .55193 L .54399 .56803 L p F P
0 0 0 r
s
.588 .794 .966 r
.59193 .61704 m .60223 .62586 L .60262 .64234 L p F P
0 0 0 r
s
.588 .794 .966 r
.60223 .62586 m .59193 .61704 L .59159 .60069 L p F P
0 0 0 r
s
.092 .135 .216 r
.61223 .73958 m .60683 .74915 L .60724 .76626 L p F P
0 0 0 r
s
.092 .135 .216 r
.60683 .74915 m .61223 .73958 L .61178 .72257 L p F P
0 0 0 r
s
.584 .784 .971 r
.5781 .59328 m .59159 .60069 L .59193 .61704 L p F P
0 0 0 r
s
.576 .776 .973 r
.46645 .83492 m .48178 .8405 L .48201 .82299 L p F P
0 0 0 r
s
.576 .776 .973 r
.48201 .82299 m .46675 .81738 L .46645 .83492 L p F P
0 0 0 r
s
.444 .598 .779 r
.54399 .56803 m .52525 .56693 L .52526 .55082 L p F P
0 0 0 r
s
.328 .45 .612 r
.55452 .84407 m .57163 .8401 L .5714 .8226 L p F P
0 0 0 r
s
.275 .382 .53 r
.58646 .81684 m .5714 .8226 L .57163 .8401 L p F P
0 0 0 r
s
.337 .479 .557 r
.43837 .73038 m .44014 .74039 L .44058 .72339 L p F P
0 0 0 r
s
.337 .479 .557 r
.44058 .72339 m .43882 .71333 L .43837 .73038 L p F P
0 0 0 r
s
0 .105 0 r
.46394 .11953 m .50375 .11847 L .50509 .12088 L closepath p F P
0 0 0 r
s
.061 .09 .132 r
.61321 .71249 m .61178 .72257 L .61223 .73958 L p F P
0 0 0 r
s
.061 .09 .132 r
.61178 .72257 m .61321 .71249 L .61276 .6956 L p F P
0 0 0 r
s
.06 .088 .128 r
.44116 .70323 m .43882 .71333 L .43927 .69644 L p F P
0 0 0 r
s
.06 .088 .128 r
.43927 .69644 m .44159 .68628 L .44116 .70323 L p F P
0 0 0 r
s
.246 .763 .547 r
.46394 .11953 m .50365 .13045 L .50089 .13753 L closepath p F P
0 0 0 r
s
.336 .458 .618 r
.50645 .58449 m .48865 .5881 L .48884 .57185 L p F P
0 0 0 r
s
.336 .458 .618 r
.48884 .57185 m .50655 .56822 L .50645 .58449 L p F P
0 0 0 r
s
.336 .475 .553 r
.6101 .68546 m .61276 .6956 L .61321 .71249 L p F P
0 0 0 r
s
.336 .475 .553 r
.61276 .6956 m .6101 .68546 L .60967 .66869 L p F P
0 0 0 r
s
.255 .744 .516 r
.34031 .48503 m .36493 .47805 L .36217 .47255 L closepath p F P
0 0 0 r
s
.056 .329 .092 r
.34031 .48503 m .36467 .48304 L .36493 .47805 L closepath p F P
0 0 0 r
s
0 .349 0 r
.34031 .48503 m .36163 .48254 L .36467 .48304 L closepath p F P
0 0 0 r
s
.177 .615 .407 r
.34031 .48503 m .35886 .47703 L .36163 .48254 L closepath p F P
0 0 0 r
s
.156 .728 .33 r
.34031 .48503 m .36217 .47255 L .35913 .47203 L closepath p F P
0 0 0 r
s
.004 .206 .011 r
.34031 .48503 m .35913 .47203 L .35886 .47703 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.35953 .47836 m
.42779 .45468 L
s
.545 .731 .921 r
.5781 .59328 m .56201 .58772 L .56182 .57147 L p F P
0 0 0 r
s
.496 .666 .853 r
.54399 .56803 m .56182 .57147 L .56201 .58772 L p F P
0 0 0 r
s
.09 .132 .21 r
.44795 .67658 m .44159 .68628 L .44203 .66952 L p F P
0 0 0 r
s
.09 .132 .21 r
.44203 .66952 m .44836 .65976 L .44795 .67658 L p F P
0 0 0 r
s
.231 .648 .343 r
.47027 .84283 m .46285 .83747 L .46281 .83986 L closepath p F P
0 0 0 r
s
0 .226 0 r
.47027 .84283 m .46281 .83986 L .46484 .84051 L closepath p F P
0 0 0 r
s
.344 .912 .661 r
.47027 .84283 m .46492 .83572 L .46285 .83747 L closepath p F P
0 0 0 r
s
.086 .444 .225 r
.47027 .84283 m .46696 .83636 L .46492 .83572 L closepath p F P
0 0 0 r
s
.097 .497 .142 r
.47027 .84283 m .46691 .83875 L .46696 .83636 L closepath p F P
0 0 0 r
s
.35 1 .678 r
.47027 .84283 m .46484 .84051 L .46691 .83875 L closepath p F P
0 0 0 r
s
.604 .823 .997 r
.4446 .80178 m .45409 .8102 L .45446 .79279 L p F P
0 0 0 r
s
.604 .823 .997 r
.45446 .79279 m .44502 .78431 L .4446 .80178 L p F P
0 0 0 r
s
.495 .68 .818 r
.60302 .65899 m .60967 .66869 L .6101 .68546 L p F P
0 0 0 r
s
.495 .68 .818 r
.60967 .66869 m .60302 .65899 L .60262 .64234 L p F P
0 0 0 r
s
.61 .825 1 r
.45371 .8278 m .46645 .83492 L .46675 .81738 L p F P
0 0 0 r
s
.69 .09 .12 r
.45755 .83168 m
.46625 .83931 L
s
.61 .825 1 r
.46675 .81738 m .45409 .8102 L .45371 .8278 L p F P
0 0 0 r
s
.28 .387 .532 r
.48846 .60451 m .47247 .61022 L .47274 .59383 L p F P
0 0 0 r
s
.28 .387 .532 r
.47274 .59383 m .48865 .5881 L .48846 .60451 L p F P
0 0 0 r
s
.223 .312 .442 r
.58646 .81684 m .59889 .80955 L .59852 .79214 L p F P
0 0 0 r
s
.159 .222 .331 r
.60766 .78356 m .59852 .79214 L .59889 .80955 L p F P
0 0 0 r
s
.159 .222 .331 r
.59852 .79214 m .60766 .78356 L .60724 .76626 L p F P
0 0 0 r
s
.275 .382 .53 r
.57163 .8401 m .58678 .83439 L .58646 .81684 L p F P
0 0 0 r
s
.223 .312 .442 r
.59889 .80955 m .58646 .81684 L .58678 .83439 L p F P
0 0 0 r
s
.163 .225 .333 r
.45846 .65094 m .44836 .65976 L .44876 .64311 L p F P
0 0 0 r
s
.163 .225 .333 r
.44876 .64311 m .45881 .63424 L .45846 .65094 L p F P
0 0 0 r
s
.494 .685 .822 r
.43924 .77492 m .44502 .78431 L .44544 .76702 L p F P
0 0 0 r
s
.494 .685 .822 r
.44544 .76702 m .43969 .75756 L .43924 .77492 L p F P
0 0 0 r
s
.584 .784 .971 r
.59193 .61704 m .57837 .60967 L .5781 .59328 L p F P
0 0 0 r
s
.545 .731 .921 r
.56201 .58772 m .5781 .59328 L .57837 .60967 L p F P
0 0 0 r
s
.69 .09 .12 r
.57378 .8396 m
.58113 .83766 L
s
.56751 .84126 m
.571 .84034 L
s
.571 .84034 m
.57378 .8396 L
s
.391 .529 .7 r
.52525 .5832 m .50645 .58449 L .50655 .56822 L p F P
0 0 0 r
s
.391 .529 .7 r
.50655 .56822 m .52525 .56693 L .52525 .5832 L p F P
0 0 0 r
s
.225 .313 .441 r
.47219 .62678 m .45881 .63424 L .45916 .61772 L p F P
0 0 0 r
s
.225 .313 .441 r
.45916 .61772 m .47247 .61022 L .47219 .62678 L p F P
0 0 0 r
s
.496 .666 .853 r
.56201 .58772 m .54409 .58429 L .54399 .56803 L p F P
0 0 0 r
s
.444 .598 .779 r
.52525 .56693 m .54399 .56803 L .54409 .58429 L p F P
0 0 0 r
s
.588 .794 .966 r
.59227 .63357 m .60262 .64234 L .60302 .65899 L p F P
0 0 0 r
s
.588 .794 .966 r
.60262 .64234 m .59227 .63357 L .59193 .61704 L p F P
0 0 0 r
s
.205 .622 .376 r
.46394 .11953 m .50509 .12088 L .50365 .13045 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.50397 .12836 m
.61567 .15299 L
s
.092 .135 .216 r
.61267 .75676 m .60724 .76626 L .60766 .78356 L p F P
0 0 0 r
s
.092 .135 .216 r
.60724 .76626 m .61267 .75676 L .61223 .73958 L p F P
0 0 0 r
s
.584 .784 .971 r
.57837 .60967 m .59193 .61704 L .59227 .63357 L p F P
0 0 0 r
s
.444 .598 .779 r
.54409 .58429 m .52525 .5832 L .52525 .56693 L p F P
0 0 0 r
s
.337 .479 .557 r
.43791 .74762 m .43969 .75756 L .44014 .74039 L p F P
0 0 0 r
s
.337 .479 .557 r
.44014 .74039 m .43837 .73038 L .43791 .74762 L p F P
0 0 0 r
s
.061 .09 .132 r
.61366 .72955 m .61223 .73958 L .61267 .75676 L p F P
0 0 0 r
s
.061 .09 .132 r
.61223 .73958 m .61366 .72955 L .61321 .71249 L p F P
0 0 0 r
s
.06 .088 .128 r
.44071 .72034 m .43837 .73038 L .43882 .71333 L p F P
0 0 0 r
s
.06 .088 .128 r
.43882 .71333 m .44116 .70323 L .44071 .72034 L p F P
0 0 0 r
s
.336 .458 .618 r
.50635 .60092 m .48846 .60451 L .48865 .5881 L p F P
0 0 0 r
s
.336 .458 .618 r
.48865 .5881 m .50645 .58449 L .50635 .60092 L p F P
0 0 0 r
s
.336 .475 .553 r
.61054 .70241 m .61321 .71249 L .61366 .72955 L p F P
0 0 0 r
s
.336 .475 .553 r
.61321 .71249 m .61054 .70241 L .6101 .68546 L p F P
0 0 0 r
s
.545 .731 .921 r
.57837 .60967 m .56219 .60414 L .56201 .58772 L p F P
0 0 0 r
s
.496 .666 .853 r
.54409 .58429 m .56201 .58772 L .56219 .60414 L p F P
0 0 0 r
s
.09 .132 .21 r
.44754 .69358 m .44116 .70323 L .44159 .68628 L p F P
0 0 0 r
s
.09 .132 .21 r
.44159 .68628 m .44795 .67658 L .44754 .69358 L p F P
0 0 0 r
s
.604 .823 .997 r
.44418 .81943 m .45371 .8278 L .45409 .8102 L p F P
0 0 0 r
s
.69 .09 .12 r
.4521 .8269 m
.45755 .83168 L
s
.44851 .82375 m
.4521 .8269 L
s
.604 .823 .997 r
.45409 .8102 m .4446 .80178 L .44418 .81943 L p F P
0 0 0 r
s
.018 .253 .04 r
.60638 .83097 m .59766 .83339 L .59771 .83579 L closepath p F P
0 0 0 r
s
.175 .611 .404 r
.60638 .83097 m .59656 .83116 L .59766 .83339 L closepath p F P
0 0 0 r
s
.495 .68 .818 r
.60342 .67581 m .6101 .68546 L .61054 .70241 L p F P
0 0 0 r
s
.495 .68 .818 r
.6101 .68546 m .60342 .67581 L .60302 .65899 L p F P
0 0 0 r
s
.28 .387 .532 r
.48826 .6211 m .47219 .62678 L .47247 .61022 L p F P
0 0 0 r
s
.28 .387 .532 r
.47247 .61022 m .48846 .60451 L .48826 .6211 L p F P
0 0 0 r
s
.317 .934 .67 r
.4976 .46664 m .51452 .46816 L .51581 .46543 L closepath p F P
0 0 0 r
s
.285 .766 .499 r
.4976 .46664 m .51387 .47261 L .51452 .46816 L closepath p F P
0 0 0 r
s
0 .049 0 r
.60638 .83097 m .5955 .83132 L .59656 .83116 L closepath p F P
0 0 0 r
s
.223 .312 .442 r
.58678 .83439 m .59927 .82715 L .59889 .80955 L p F P
0 0 0 r
s
.159 .222 .331 r
.60809 .80104 m .59889 .80955 L .59927 .82715 L p F P
0 0 0 r
s
.159 .222 .331 r
.59889 .80955 m .60809 .80104 L .60766 .78356 L p F P
0 0 0 r
s
.163 .225 .333 r
.45811 .66781 m .44795 .67658 L .44836 .65976 L p F P
0 0 0 r
s
.163 .225 .333 r
.44836 .65976 m .45846 .65094 L .45811 .66781 L p F P
0 0 0 r
s
.019 .211 .025 r
.4976 .46664 m .5145 .47435 L .51387 .47261 L closepath p F P
0 0 0 r
s
.494 .685 .822 r
.43879 .79245 m .4446 .80178 L .44502 .78431 L p F P
0 0 0 r
s
.494 .685 .822 r
.44502 .78431 m .43924 .77492 L .43879 .79245 L p F P
0 0 0 r
s
.584 .784 .971 r
.59227 .63357 m .57865 .62624 L .57837 .60967 L p F P
0 0 0 r
s
.545 .731 .921 r
.56219 .60414 m .57837 .60967 L .57865 .62624 L p F P
0 0 0 r
s
.001 .414 .002 r
.60638 .83097 m .59771 .83579 L .59666 .83596 L closepath p F P
0 0 0 r
s
0 .039 0 r
.17269 .83406 m .18371 .82317 L .18952 .81621 L closepath p F P
0 0 0 r
s
.225 .801 .383 r
.17269 .83406 m .17518 .80636 L .16933 .8133 L closepath p F P
0 0 0 r
s
.308 .88 .648 r
.17269 .83406 m .18526 .80782 L .17518 .80636 L closepath p F P
0 0 0 r
s
.043 .31 .116 r
.17269 .83406 m .18952 .81621 L .18526 .80782 L closepath p F P
0 0 0 r
s
.121 .603 .29 r
.17269 .83406 m .17359 .82172 L .18371 .82317 L closepath p F P
0 0 0 r
s
0 .116 0 r
.17269 .83406 m .16933 .8133 L .17359 .82172 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.17684 .82218 m
.20085 .75351 L
s
.391 .529 .7 r
.52525 .59964 m .50635 .60092 L .50645 .58449 L p F P
0 0 0 r
s
.391 .529 .7 r
.50645 .58449 m .52525 .5832 L .52525 .59964 L p F P
0 0 0 r
s
.225 .313 .441 r
.47191 .64351 m .45846 .65094 L .45881 .63424 L p F P
0 0 0 r
s
.225 .313 .441 r
.45881 .63424 m .47219 .62678 L .47191 .64351 L p F P
0 0 0 r
s
.496 .666 .853 r
.56219 .60414 m .54418 .60073 L .54409 .58429 L p F P
0 0 0 r
s
.444 .598 .779 r
.52525 .5832 m .54409 .58429 L .54418 .60073 L p F P
0 0 0 r
s
.588 .794 .966 r
.59262 .65027 m .60302 .65899 L .60342 .67581 L p F P
0 0 0 r
s
.588 .794 .966 r
.60302 .65899 m .59262 .65027 L .59227 .63357 L p F P
0 0 0 r
s
.092 .135 .216 r
.61312 .77411 m .60766 .78356 L .60809 .80104 L p F P
0 0 0 r
s
.092 .135 .216 r
.60766 .78356 m .61312 .77411 L .61267 .75676 L p F P
0 0 0 r
s
.584 .784 .971 r
.57865 .62624 m .59227 .63357 L .59262 .65027 L p F P
0 0 0 r
s
.071 .361 .122 r
.60638 .83097 m .59555 .83372 L .5955 .83132 L closepath p F P
0 0 0 r
s
.444 .598 .779 r
.54418 .60073 m .52525 .59964 L .52525 .5832 L p F P
0 0 0 r
s
.257 .749 .522 r
.60638 .83097 m .59666 .83596 L .59555 .83372 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.58113 .83766 m
.5956 .83382 L
s
.337 .479 .557 r
.43745 .76504 m .43924 .77492 L .43969 .75756 L p F P
0 0 0 r
s
.337 .479 .557 r
.43969 .75756 m .43791 .74762 L .43745 .76504 L p F P
0 0 0 r
s
.01 .174 .013 r
.4976 .46664 m .51581 .46543 L .51644 .46715 L closepath p F P
0 0 0 r
s
.238 .758 .54 r
.4976 .46664 m .51579 .47162 L .5145 .47435 L closepath p F P
0 0 0 r
s
.061 .09 .132 r
.61412 .74679 m .61267 .75676 L .61312 .77411 L p F P
0 0 0 r
s
.061 .09 .132 r
.61267 .75676 m .61412 .74679 L .61366 .72955 L p F P
0 0 0 r
s
.06 .088 .128 r
.44026 .73764 m .43791 .74762 L .43837 .73038 L p F P
0 0 0 r
s
.06 .088 .128 r
.43837 .73038 m .44071 .72034 L .44026 .73764 L p F P
0 0 0 r
s
.366 1 .708 r
.65863 .44991 m .66467 .46328 L .66956 .45912 L closepath p F P
0 0 0 r
s
.007 .342 .009 r
.65863 .44991 m .6649 .46829 L .66467 .46328 L closepath p F P
0 0 0 r
s
.205 .622 .376 r
.4976 .46664 m .51644 .46715 L .51579 .47162 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.51602 .47004 m
.56743 .47956 L
s
.028 .367 .073 r
.65863 .44991 m .66956 .45912 L .6747 .45997 L closepath p F P
0 0 0 r
s
.336 .458 .618 r
.50625 .61753 m .48826 .6211 L .48846 .60451 L p F P
0 0 0 r
s
.336 .458 .618 r
.48846 .60451 m .50635 .60092 L .50625 .61753 L p F P
0 0 0 r
s
.336 .475 .553 r
.61098 .71953 m .61366 .72955 L .61412 .74679 L p F P
0 0 0 r
s
.336 .475 .553 r
.61366 .72955 m .61098 .71953 L .61054 .70241 L p F P
0 0 0 r
s
.545 .731 .921 r
.57865 .62624 m .56238 .62073 L .56219 .60414 L p F P
0 0 0 r
s
.496 .666 .853 r
.54418 .60073 m .56219 .60414 L .56238 .62073 L p F P
0 0 0 r
s
.09 .132 .21 r
.44713 .71075 m .44071 .72034 L .44116 .70323 L p F P
0 0 0 r
s
.09 .132 .21 r
.44116 .70323 m .44754 .69358 L .44713 .71075 L p F P
0 0 0 r
s
0 .039 0 r
.23578 .82842 m .2456 .81943 L .25023 .81373 L closepath p F P
0 0 0 r
s
.308 .881 .648 r
.23578 .82842 m .24664 .80686 L .23844 .80566 L closepath p F P
0 0 0 r
s
.045 .317 .121 r
.23578 .82842 m .25023 .81373 L .24664 .80686 L closepath p F P
0 0 0 r
s
.123 .606 .295 r
.23578 .82842 m .23737 .81824 L .2456 .81943 L closepath p F P
0 0 0 r
s
.198 .763 .336 r
.23578 .82842 m .23844 .80566 L .23379 .81134 L closepath p F P
0 0 0 r
s
0 .123 0 r
.23578 .82842 m .23379 .81134 L .23737 .81824 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.23965 .81857 m
.2616 .76266 L
s
.495 .68 .818 r
.60382 .69281 m .61054 .70241 L .61098 .71953 L p F P
0 0 0 r
s
.495 .68 .818 r
.61054 .70241 m .60382 .69281 L .60342 .67581 L p F P
0 0 0 r
s
.13 .538 .331 r
.65863 .44991 m .67003 .46915 L .6649 .46829 L closepath p F P
0 0 0 r
s
.198 .594 .284 r
.65863 .44991 m .6747 .45997 L .67494 .46498 L closepath p F P
0 0 0 r
s
.28 .387 .532 r
.48806 .63786 m .47191 .64351 L .47219 .62678 L p F P
0 0 0 r
s
.28 .387 .532 r
.47219 .62678 m .48826 .6211 L .48806 .63786 L p F P
0 0 0 r
s
.159 .222 .331 r
.59927 .82715 m .60852 .81869 L .60809 .80104 L p F P
0 0 0 r
s
.163 .225 .333 r
.45775 .68485 m .44754 .69358 L .44795 .67658 L p F P
0 0 0 r
s
.163 .225 .333 r
.44795 .67658 m .45811 .66781 L .45775 .68485 L p F P
0 0 0 r
s
.494 .685 .822 r
.43833 .81017 m .44418 .81943 L .4446 .80178 L p F P
0 0 0 r
s
.494 .685 .822 r
.4446 .80178 m .43879 .79245 L .43833 .81017 L p F P
0 0 0 r
s
.584 .784 .971 r
.59262 .65027 m .57892 .64297 L .57865 .62624 L p F P
0 0 0 r
s
.545 .731 .921 r
.56238 .62073 m .57865 .62624 L .57892 .64297 L p F P
0 0 0 r
s
.391 .529 .7 r
.52524 .61625 m .50625 .61753 L .50635 .60092 L p F P
0 0 0 r
s
.391 .529 .7 r
.50635 .60092 m .52525 .59964 L .52524 .61625 L p F P
0 0 0 r
s
.225 .313 .441 r
.47162 .66042 m .45811 .66781 L .45846 .65094 L p F P
0 0 0 r
s
.225 .313 .441 r
.45846 .65094 m .47191 .64351 L .47162 .66042 L p F P
0 0 0 r
s
.496 .666 .853 r
.56238 .62073 m .54428 .61733 L .54418 .60073 L p F P
0 0 0 r
s
.444 .598 .779 r
.52525 .59964 m .54418 .60073 L .54428 .61733 L p F P
0 0 0 r
s
.588 .794 .966 r
.59297 .66714 m .60342 .67581 L .60382 .69281 L p F P
0 0 0 r
s
.588 .794 .966 r
.60342 .67581 m .59297 .66714 L .59262 .65027 L p F P
0 0 0 r
s
.092 .135 .216 r
.61358 .79165 m .60809 .80104 L .60852 .81869 L p F P
0 0 0 r
s
.092 .135 .216 r
.60809 .80104 m .61358 .79165 L .61312 .77411 L p F P
0 0 0 r
s
.584 .784 .971 r
.57892 .64297 m .59262 .65027 L .59297 .66714 L p F P
0 0 0 r
s
.256 .745 .517 r
.28409 .46177 m .31606 .45262 L .3124 .44542 L closepath p F P
0 0 0 r
s
.053 .322 .086 r
.28409 .46177 m .31561 .45907 L .31606 .45262 L closepath p F P
0 0 0 r
s
0 .355 0 r
.28409 .46177 m .31149 .45835 L .31561 .45907 L closepath p F P
0 0 0 r
s
.176 .613 .405 r
.28409 .46177 m .3078 .45112 L .31149 .45835 L closepath p F P
0 0 0 r
s
.172 .754 .364 r
.28409 .46177 m .3124 .44542 L .30827 .44465 L closepath p F P
0 0 0 r
s
.003 .196 .007 r
.28409 .46177 m .30827 .44465 L .3078 .45112 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.30876 .453 m
.39738 .42149 L
s
.444 .598 .779 r
.54428 .61733 m .52524 .61625 L .52525 .59964 L p F P
0 0 0 r
s
.34 .905 .654 r
.65863 .44991 m .67494 .46498 L .67003 .46915 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.67226 .46726 m
.70226 .50545 L
s
.337 .479 .557 r
.43698 .78264 m .43879 .79245 L .43924 .77492 L p F P
0 0 0 r
s
.337 .479 .557 r
.43924 .77492 m .43745 .76504 L .43698 .78264 L p F P
0 0 0 r
s
.061 .09 .132 r
.61458 .76421 m .61312 .77411 L .61358 .79165 L p F P
0 0 0 r
s
.061 .09 .132 r
.61312 .77411 m .61458 .76421 L .61412 .74679 L p F P
0 0 0 r
s
.06 .088 .128 r
.43981 .75512 m .43745 .76504 L .43791 .74762 L p F P
0 0 0 r
s
.06 .088 .128 r
.43791 .74762 m .44026 .73764 L .43981 .75512 L p F P
0 0 0 r
s
.169 .72 .286 r
.29937 .82274 m .30193 .80496 L .29842 .80938 L closepath p F P
0 0 0 r
s
.308 .881 .648 r
.29937 .82274 m .30828 .80589 L .30193 .80496 L closepath p F P
0 0 0 r
s
.047 .324 .126 r
.29937 .82274 m .31115 .81124 L .30828 .80589 L closepath p F P
0 0 0 r
s
0 .039 0 r
.29937 .82274 m .30765 .81568 L .31115 .81124 L closepath p F P
0 0 0 r
s
.125 .61 .3 r
.29937 .82274 m .30128 .81475 L .30765 .81568 L closepath p F P
0 0 0 r
s
0 .135 0 r
.29937 .82274 m .29842 .80938 L .30128 .81475 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.30276 .81496 m
.32162 .77169 L
s
.336 .458 .618 r
.50614 .63431 m .48806 .63786 L .48826 .6211 L p F P
0 0 0 r
s
.336 .458 .618 r
.48826 .6211 m .50625 .61753 L .50614 .63431 L p F P
0 0 0 r
s
.336 .475 .553 r
.61142 .73683 m .61412 .74679 L .61458 .76421 L p F P
0 0 0 r
s
.336 .475 .553 r
.61412 .74679 m .61142 .73683 L .61098 .71953 L p F P
0 0 0 r
s
.545 .731 .921 r
.57892 .64297 m .56257 .63749 L .56238 .62073 L p F P
0 0 0 r
s
.496 .666 .853 r
.54428 .61733 m .56238 .62073 L .56257 .63749 L p F P
0 0 0 r
s
.09 .132 .21 r
.44671 .72811 m .44026 .73764 L .44071 .72034 L p F P
0 0 0 r
s
.09 .132 .21 r
.44071 .72034 m .44713 .71075 L .44671 .72811 L p F P
0 0 0 r
s
.495 .68 .818 r
.60423 .70999 m .61098 .71953 L .61142 .73683 L p F P
0 0 0 r
s
.495 .68 .818 r
.61098 .71953 m .60423 .70999 L .60382 .69281 L p F P
0 0 0 r
s
.28 .387 .532 r
.48786 .6548 m .47162 .66042 L .47191 .64351 L p F P
0 0 0 r
s
.28 .387 .532 r
.47191 .64351 m .48806 .63786 L .48786 .6548 L p F P
0 0 0 r
s
.163 .225 .333 r
.45739 .70208 m .44713 .71075 L .44754 .69358 L p F P
0 0 0 r
s
.163 .225 .333 r
.44754 .69358 m .45775 .68485 L .45739 .70208 L p F P
0 0 0 r
s
.584 .784 .971 r
.59297 .66714 m .5792 .65988 L .57892 .64297 L p F P
0 0 0 r
s
.545 .731 .921 r
.56257 .63749 m .57892 .64297 L .5792 .65988 L p F P
0 0 0 r
s
.391 .529 .7 r
.52524 .63304 m .50614 .63431 L .50625 .61753 L p F P
0 0 0 r
s
.391 .529 .7 r
.50625 .61753 m .52524 .61625 L .52524 .63304 L p F P
0 0 0 r
s
.225 .313 .441 r
.47133 .67751 m .45775 .68485 L .45811 .66781 L p F P
0 0 0 r
s
.225 .313 .441 r
.45811 .66781 m .47162 .66042 L .47133 .67751 L p F P
0 0 0 r
s
.496 .666 .853 r
.56257 .63749 m .54437 .63412 L .54428 .61733 L p F P
0 0 0 r
s
.444 .598 .779 r
.52524 .61625 m .54428 .61733 L .54437 .63412 L p F P
0 0 0 r
s
.588 .794 .966 r
.59332 .68419 m .60382 .69281 L .60423 .70999 L p F P
0 0 0 r
s
.588 .794 .966 r
.60382 .69281 m .59332 .68419 L .59297 .66714 L p F P
0 0 0 r
s
.092 .135 .216 r
.60852 .81869 m .61404 .80938 L .61358 .79165 L p F P
0 0 0 r
s
.584 .784 .971 r
.5792 .65988 m .59297 .66714 L .59332 .68419 L p F P
0 0 0 r
s
.444 .598 .779 r
.54437 .63412 m .52524 .63304 L .52524 .61625 L p F P
0 0 0 r
s
.337 .479 .557 r
.43651 .80043 m .43833 .81017 L .43879 .79245 L p F P
0 0 0 r
s
.337 .479 .557 r
.43879 .79245 m .43698 .78264 L .43651 .80043 L p F P
0 0 0 r
s
.139 .673 .233 r
.36348 .81701 m .36566 .80425 L .36323 .80742 L closepath p F P
0 0 0 r
s
.308 .881 .648 r
.36348 .81701 m .37018 .80492 L .36566 .80425 L closepath p F P
0 0 0 r
s
.049 .33 .131 r
.36348 .81701 m .37228 .80875 L .37018 .80492 L closepath p F P
0 0 0 r
s
0 .039 0 r
.36348 .81701 m .36985 .81192 L .37228 .80875 L closepath p F P
0 0 0 r
s
.127 .614 .305 r
.36348 .81701 m .36533 .81125 L .36985 .81192 L closepath p F P
0 0 0 r
s
0 .146 .001 r
.36348 .81701 m .36323 .80742 L .36533 .81125 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.36618 .81138 m
.38091 .78062 L
s
.061 .09 .132 r
.61505 .78182 m .61358 .79165 L .61404 .80938 L p F P
0 0 0 r
s
.061 .09 .132 r
.61358 .79165 m .61505 .78182 L .61458 .76421 L p F P
0 0 0 r
s
.06 .088 .128 r
.43935 .77279 m .43698 .78264 L .43745 .76504 L p F P
0 0 0 r
s
.06 .088 .128 r
.43745 .76504 m .43981 .75512 L .43935 .77279 L p F P
0 0 0 r
s
.69 .09 .12 r
.61105 .81528 m
.61379 .81108 L
s
.336 .458 .618 r
.50604 .65127 m .48786 .6548 L .48806 .63786 L p F P
0 0 0 r
s
.336 .458 .618 r
.48806 .63786 m .50614 .63431 L .50604 .65127 L p F P
0 0 0 r
s
.336 .475 .553 r
.61188 .75432 m .61458 .76421 L .61505 .78182 L p F P
0 0 0 r
s
.336 .475 .553 r
.61458 .76421 m .61188 .75432 L .61142 .73683 L p F P
0 0 0 r
s
.545 .731 .921 r
.5792 .65988 m .56277 .65443 L .56257 .63749 L p F P
0 0 0 r
s
.496 .666 .853 r
.54437 .63412 m .56257 .63749 L .56277 .65443 L p F P
0 0 0 r
s
.09 .132 .21 r
.44629 .74565 m .43981 .75512 L .44026 .73764 L p F P
0 0 0 r
s
.09 .132 .21 r
.44026 .73764 m .44671 .72811 L .44629 .74565 L p F P
0 0 0 r
s
.495 .68 .818 r
.60464 .72736 m .61142 .73683 L .61188 .75432 L p F P
0 0 0 r
s
.495 .68 .818 r
.61142 .73683 m .60464 .72736 L .60423 .70999 L p F P
0 0 0 r
s
.28 .387 .532 r
.48766 .67192 m .47133 .67751 L .47162 .66042 L p F P
0 0 0 r
s
.28 .387 .532 r
.47162 .66042 m .48786 .6548 L .48766 .67192 L p F P
0 0 0 r
s
.163 .225 .333 r
.45702 .71949 m .44671 .72811 L .44713 .71075 L p F P
0 0 0 r
s
.163 .225 .333 r
.44713 .71075 m .45739 .70208 L .45702 .71949 L p F P
0 0 0 r
s
.584 .784 .971 r
.59332 .68419 m .57948 .67697 L .5792 .65988 L p F P
0 0 0 r
s
.545 .731 .921 r
.56277 .65443 m .5792 .65988 L .57948 .67697 L p F P
0 0 0 r
s
.391 .529 .7 r
.52523 .65 m .50604 .65127 L .50614 .63431 L p F P
0 0 0 r
s
.391 .529 .7 r
.50614 .63431 m .52524 .63304 L .52523 .65 L p F P
0 0 0 r
s
.225 .313 .441 r
.47104 .69477 m .45739 .70208 L .45775 .68485 L p F P
0 0 0 r
s
.225 .313 .441 r
.45775 .68485 m .47133 .67751 L .47104 .69477 L p F P
0 0 0 r
s
.496 .666 .853 r
.56277 .65443 m .54447 .65107 L .54437 .63412 L p F P
0 0 0 r
s
.444 .598 .779 r
.52524 .63304 m .54437 .63412 L .54447 .65107 L p F P
0 0 0 r
s
.588 .794 .966 r
.59367 .70142 m .60423 .70999 L .60464 .72736 L p F P
0 0 0 r
s
.588 .794 .966 r
.60423 .70999 m .59367 .70142 L .59332 .68419 L p F P
0 0 0 r
s
0 .039 0 r
.42811 .81123 m .43221 .80815 L .43362 .80625 L closepath p F P
0 0 0 r
s
.308 .881 .649 r
.42811 .81123 m .43233 .80395 L .42963 .80355 L closepath p F P
0 0 0 r
s
.051 .336 .136 r
.42811 .81123 m .43362 .80625 L .43233 .80395 L closepath p F P
0 0 0 r
s
.129 .618 .309 r
.42811 .81123 m .42951 .80775 L .43221 .80815 L closepath p F P
0 0 0 r
s
.108 .624 .18 r
.42811 .81123 m .42963 .80355 L .42822 .80544 L closepath p F P
0 0 0 r
s
.002 .158 .006 r
.42811 .81123 m .42822 .80544 L .42951 .80775 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.43304 .80179 m
.43579 .79653 L
s
.4299 .80781 m
.43304 .80179 L
s
.584 .784 .971 r
.57948 .67697 m .59332 .68419 L .59367 .70142 L p F P
0 0 0 r
s
.444 .598 .779 r
.54447 .65107 m .52523 .65 L .52524 .63304 L p F P
0 0 0 r
s
.061 .09 .132 r
.61404 .80938 m .61552 .79961 L .61505 .78182 L p F P
0 0 0 r
s
.06 .088 .128 r
.43889 .79065 m .43651 .80043 L .43698 .78264 L p F P
0 0 0 r
s
.06 .088 .128 r
.43698 .78264 m .43935 .77279 L .43889 .79065 L p F P
0 0 0 r
s
.336 .458 .618 r
.50593 .6684 m .48766 .67192 L .48786 .6548 L p F P
0 0 0 r
s
.336 .458 .618 r
.48786 .6548 m .50604 .65127 L .50593 .6684 L p F P
0 0 0 r
s
.336 .475 .553 r
.61233 .77199 m .61505 .78182 L .61552 .79961 L p F P
0 0 0 r
s
.69 .09 .12 r
.61379 .81108 m
.61724 .80578 L
s
.336 .475 .553 r
.61505 .78182 m .61233 .77199 L .61188 .75432 L p F P
0 0 0 r
s
.545 .731 .921 r
.57948 .67697 m .56296 .67155 L .56277 .65443 L p F P
0 0 0 r
s
.496 .666 .853 r
.54447 .65107 m .56277 .65443 L .56296 .67155 L p F P
0 0 0 r
s
.364 1 .704 r
.69982 .41513 m .70719 .43304 L .71359 .42761 L closepath p F P
0 0 0 r
s
.001 .323 .001 r
.69982 .41513 m .70758 .43952 L .70719 .43304 L closepath p F P
0 0 0 r
s
.037 .387 .095 r
.69982 .41513 m .71359 .42761 L .7204 .42864 L closepath p F P
0 0 0 r
s
.256 .746 .518 r
.22637 .43789 m .26582 .42648 L .26121 .41752 L closepath p F P
0 0 0 r
s
.049 .314 .08 r
.22637 .43789 m .26513 .43441 L .26582 .42648 L closepath p F P
0 0 0 r
s
0 .361 0 r
.22637 .43789 m .25981 .43341 L .26513 .43441 L closepath p F P
0 0 0 r
s
.175 .611 .404 r
.22637 .43789 m .25516 .4244 L .25981 .43341 L closepath p F P
0 0 0 r
s
.188 .779 .396 r
.22637 .43789 m .26121 .41752 L .25588 .41645 L closepath p F P
0 0 0 r
s
.002 .186 .004 r
.22637 .43789 m .25588 .41645 L .25516 .4244 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.25646 .42692 m
.36582 .38706 L
s
.09 .132 .21 r
.44586 .76338 m .43935 .77279 L .43981 .75512 L p F P
0 0 0 r
s
.09 .132 .21 r
.43981 .75512 m .44629 .74565 L .44586 .76338 L p F P
0 0 0 r
s
.495 .68 .818 r
.60506 .7449 m .61188 .75432 L .61233 .77199 L p F P
0 0 0 r
s
.495 .68 .818 r
.61188 .75432 m .60506 .7449 L .60464 .72736 L p F P
0 0 0 r
s
.28 .387 .532 r
.48746 .68922 m .47104 .69477 L .47133 .67751 L p F P
0 0 0 r
s
.28 .387 .532 r
.47133 .67751 m .48766 .67192 L .48746 .68922 L p F P
0 0 0 r
s
.163 .225 .333 r
.45665 .73708 m .44629 .74565 L .44671 .72811 L p F P
0 0 0 r
s
.163 .225 .333 r
.44671 .72811 m .45702 .71949 L .45665 .73708 L p F P
0 0 0 r
s
.584 .784 .971 r
.59367 .70142 m .57976 .69425 L .57948 .67697 L p F P
0 0 0 r
s
.545 .731 .921 r
.56296 .67155 m .57948 .67697 L .57976 .69425 L p F P
0 0 0 r
s
.317 .934 .67 r
.4853 .42545 m .50957 .42784 L .5114 .42385 L closepath p F P
0 0 0 r
s
.287 .768 .5 r
.4853 .42545 m .50864 .43419 L .50957 .42784 L closepath p F P
0 0 0 r
s
.391 .529 .7 r
.52523 .66714 m .50593 .6684 L .50604 .65127 L p F P
0 0 0 r
s
.391 .529 .7 r
.50604 .65127 m .52523 .65 L .52523 .66714 L p F P
0 0 0 r
s
.225 .313 .441 r
.47075 .71223 m .45702 .71949 L .45739 .70208 L p F P
0 0 0 r
s
.225 .313 .441 r
.45739 .70208 m .47104 .69477 L .47075 .71223 L p F P
0 0 0 r
s
.496 .666 .853 r
.56296 .67155 m .54457 .66821 L .54447 .65107 L p F P
0 0 0 r
s
.444 .598 .779 r
.52523 .65 m .54447 .65107 L .54457 .66821 L p F P
0 0 0 r
s
.588 .794 .966 r
.59403 .71883 m .60464 .72736 L .60506 .7449 L p F P
0 0 0 r
s
.588 .794 .966 r
.60464 .72736 m .59403 .71883 L .59367 .70142 L p F P
0 0 0 r
s
.132 .542 .335 r
.69982 .41513 m .7144 .44058 L .70758 .43952 L closepath p F P
0 0 0 r
s
.014 .195 .018 r
.4853 .42545 m .50952 .43658 L .50864 .43419 L closepath p F P
0 0 0 r
s
.188 .578 .268 r
.69982 .41513 m .7204 .42864 L .72082 .43513 L closepath p F P
0 0 0 r
s
.584 .784 .971 r
.57976 .69425 m .59367 .70142 L .59403 .71883 L p F P
0 0 0 r
s
.444 .598 .779 r
.54457 .66821 m .52523 .66714 L .52523 .65 L p F P
0 0 0 r
s
.006 .159 .009 r
.4853 .42545 m .5114 .42385 L .51229 .42621 L closepath p F P
0 0 0 r
s
.342 .908 .657 r
.69982 .41513 m .72082 .43513 L .7144 .44058 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.71712 .43827 m
.7548 .48863 L
s
.014 .206 .037 r
.62516 .79362 m .62286 .79719 L .62425 .7995 L closepath p F P
0 0 0 r
s
.135 .628 .323 r
.62516 .79362 m .62021 .79679 L .62286 .79719 L closepath p F P
0 0 0 r
s
.238 .757 .54 r
.4853 .42545 m .51135 .43259 L .50952 .43658 L closepath p F P
0 0 0 r
s
0 .039 0 r
.62516 .79362 m .61893 .79869 L .62021 .79679 L closepath p F P
0 0 0 r
s
.336 .458 .618 r
.50583 .68573 m .48746 .68922 L .48766 .67192 L p F P
0 0 0 r
s
.336 .458 .618 r
.48766 .67192 m .50593 .6684 L .50583 .68573 L p F P
0 0 0 r
s
.336 .475 .553 r
.61552 .79961 m .61279 .78985 L .61233 .77199 L p F P
0 0 0 r
s
.028 .485 .048 r
.62516 .79362 m .62425 .7995 L .62298 .8014 L closepath p F P
0 0 0 r
s
.545 .731 .921 r
.57976 .69425 m .56316 .68885 L .56296 .67155 L p F P
0 0 0 r
s
.496 .666 .853 r
.54457 .66821 m .56296 .67155 L .56316 .68885 L p F P
0 0 0 r
s
.058 .355 .152 r
.62516 .79362 m .62032 .801 L .61893 .79869 L closepath p F P
0 0 0 r
s
.019 .224 .05 r
.69193 .78765 m .68759 .79366 L .68996 .79751 L closepath p F P
0 0 0 r
s
.137 .632 .328 r
.69193 .78765 m .68318 .79298 L .68759 .79366 L closepath p F P
0 0 0 r
s
.308 .882 .649 r
.62516 .79362 m .62298 .8014 L .62032 .801 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.61724 .80578 m
.62035 .801 L
s
.09 .132 .21 r
.44543 .7813 m .43889 .79065 L .43935 .77279 L p F P
0 0 0 r
s
.69 .09 .12 r
.43875 .79084 m
.43892 .79052 L
s
.43579 .79653 m
.43875 .79084 L
s
.43892 .79052 m
.43948 .78944 L
s
.09 .132 .21 r
.43935 .77279 m .44586 .76338 L .44543 .7813 L p F P
0 0 0 r
s
0 .039 0 r
.69193 .78765 m .68114 .79615 L .68318 .79298 L closepath p F P
0 0 0 r
s
.495 .68 .818 r
.60549 .76264 m .61233 .77199 L .61279 .78985 L p F P
0 0 0 r
s
.495 .68 .818 r
.61233 .77199 m .60549 .76264 L .60506 .7449 L p F P
0 0 0 r
s
.011 .449 .02 r
.69193 .78765 m .68996 .79751 L .68792 .80069 L closepath p F P
0 0 0 r
s
.204 .622 .376 r
.4853 .42545 m .51229 .42621 L .51135 .43259 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.51167 .43044 m
.58515 .44434 L
s
.28 .387 .532 r
.48725 .70671 m .47075 .71223 L .47104 .69477 L p F P
0 0 0 r
s
.28 .387 .532 r
.47104 .69477 m .48746 .68922 L .48725 .70671 L p F P
0 0 0 r
s
.023 .241 .063 r
.75925 .78163 m .75245 .79012 L .75585 .79551 L closepath p F P
0 0 0 r
s
.139 .635 .332 r
.75925 .78163 m .74631 .78916 L .75245 .79012 L closepath p F P
0 0 0 r
s
.163 .225 .333 r
.45628 .75487 m .44586 .76338 L .44629 .74565 L p F P
0 0 0 r
s
.163 .225 .333 r
.44629 .74565 m .45665 .73708 L .45628 .75487 L p F P
0 0 0 r
s
.584 .784 .971 r
.59403 .71883 m .58005 .7117 L .57976 .69425 L p F P
0 0 0 r
s
.545 .731 .921 r
.56316 .68885 m .57976 .69425 L .58005 .7117 L p F P
0 0 0 r
s
.391 .529 .7 r
.52523 .68447 m .50583 .68573 L .50593 .6684 L p F P
0 0 0 r
s
.391 .529 .7 r
.50593 .6684 m .52523 .66714 L .52523 .68447 L p F P
0 0 0 r
s
.225 .313 .441 r
.47045 .72987 m .45665 .73708 L .45702 .71949 L p F P
0 0 0 r
s
.225 .313 .441 r
.45702 .71949 m .47075 .71223 L .47045 .72987 L p F P
0 0 0 r
s
.496 .666 .853 r
.56316 .68885 m .54467 .68554 L .54457 .66821 L p F P
0 0 0 r
s
.444 .598 .779 r
.52523 .66714 m .54457 .66821 L .54467 .68554 L p F P
0 0 0 r
s
0 .039 0 r
.75925 .78163 m .74356 .7936 L .74631 .78916 L closepath p F P
0 0 0 r
s
.06 .361 .157 r
.69193 .78765 m .68351 .80001 L .68114 .79615 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.66689 .82369 m
.68343 .79988 L
s
.588 .794 .966 r
.5944 .73643 m .60506 .7449 L .60549 .76264 L p F P
0 0 0 r
s
.588 .794 .966 r
.60506 .7449 m .5944 .73643 L .59403 .71883 L p F P
0 0 0 r
s
.584 .784 .971 r
.58005 .7117 m .59403 .71883 L .5944 .73643 L p F P
0 0 0 r
s
.308 .883 .649 r
.69193 .78765 m .68792 .80069 L .68351 .80001 L closepath p F P
0 0 0 r
s
.028 .257 .076 r
.82712 .77556 m .81745 .78657 L .82192 .79351 L closepath p F P
0 0 0 r
s
.14 .639 .337 r
.82712 .77556 m .80961 .78534 L .81745 .78657 L closepath p F P
0 0 0 r
s
.003 .422 .005 r
.75925 .78163 m .75585 .79551 L .75311 .79996 L closepath p F P
0 0 0 r
s
.444 .598 .779 r
.54467 .68554 m .52523 .68447 L .52523 .66714 L p F P
0 0 0 r
s
0 .043 0 r
.82712 .77556 m .80621 .79105 L .80961 .78534 L closepath p F P
0 0 0 r
s
.033 .272 .089 r
.89557 .76945 m .88258 .78301 L .88817 .7915 L closepath p F P
0 0 0 r
s
.142 .642 .341 r
.89557 .76945 m .87305 .7815 L .88258 .78301 L closepath p F P
0 0 0 r
s
.063 .367 .162 r
.75925 .78163 m .74696 .79901 L .74356 .7936 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.72208 .832 m
.74671 .79862 L
s
0 .403 0 r
.82712 .77556 m .82192 .79351 L .81854 .79924 L closepath p F P
0 0 0 r
s
.308 .883 .65 r
.75925 .78163 m .75311 .79996 L .74696 .79901 L closepath p F P
0 0 0 r
s
0 .049 0 r
.89557 .76945 m .86907 .78848 L .87305 .7815 L closepath p F P
0 0 0 r
s
.336 .458 .618 r
.50572 .70323 m .48725 .70671 L .48746 .68922 L p F P
0 0 0 r
s
.336 .458 .618 r
.48746 .68922 m .50583 .68573 L .50572 .70323 L p F P
0 0 0 r
s
.545 .731 .921 r
.58005 .7117 m .56336 .70634 L .56316 .68885 L p F P
0 0 0 r
s
.496 .666 .853 r
.54467 .68554 m .56316 .68885 L .56336 .70634 L p F P
0 0 0 r
s
0 .387 0 r
.89557 .76945 m .88817 .7915 L .88423 .79851 L closepath p F P
0 0 0 r
s
.065 .372 .167 r
.82712 .77556 m .81068 .79801 L .80621 .79105 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.77662 .84022 m
.81019 .79725 L
s
.308 .883 .65 r
.82712 .77556 m .81854 .79924 L .81068 .79801 L closepath p F P
0 0 0 r
s
.495 .68 .818 r
.61279 .78985 m .60591 .78056 L .60549 .76264 L p F P
0 0 0 r
s
.28 .387 .532 r
.48704 .72439 m .47045 .72987 L .47075 .71223 L p F P
0 0 0 r
s
.28 .387 .532 r
.47075 .71223 m .48725 .70671 L .48704 .72439 L p F P
0 0 0 r
s
.163 .225 .333 r
.4559 .77285 m .44543 .7813 L .44586 .76338 L p F P
0 0 0 r
s
.163 .225 .333 r
.44586 .76338 m .45628 .75487 L .4559 .77285 L p F P
0 0 0 r
s
.584 .784 .971 r
.5944 .73643 m .58034 .72935 L .58005 .7117 L p F P
0 0 0 r
s
.545 .731 .921 r
.56336 .70634 m .58005 .7117 L .58034 .72935 L p F P
0 0 0 r
s
.391 .529 .7 r
.52522 .70199 m .50572 .70323 L .50583 .68573 L p F P
0 0 0 r
s
.391 .529 .7 r
.50583 .68573 m .52523 .68447 L .52522 .70199 L p F P
0 0 0 r
s
.225 .313 .441 r
.47015 .7477 m .45628 .75487 L .45665 .73708 L p F P
0 0 0 r
s
.225 .313 .441 r
.45665 .73708 m .47045 .72987 L .47015 .7477 L p F P
0 0 0 r
s
.496 .666 .853 r
.56336 .70634 m .54477 .70304 L .54467 .68554 L p F P
0 0 0 r
s
.444 .598 .779 r
.52523 .68447 m .54467 .68554 L .54477 .70304 L p F P
0 0 0 r
s
.067 .378 .171 r
.89557 .76945 m .87466 .79701 L .86907 .78848 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.83054 .84834 m
.87386 .79579 L
s
.588 .794 .966 r
.59476 .75422 m .60549 .76264 L .60591 .78056 L p F P
0 0 0 r
s
.588 .794 .966 r
.60549 .76264 m .59476 .75422 L .5944 .73643 L p F P
0 0 0 r
s
.584 .784 .971 r
.58034 .72935 m .5944 .73643 L .59476 .75422 L p F P
0 0 0 r
s
.444 .598 .779 r
.54477 .70304 m .52522 .70199 L .52523 .68447 L p F P
0 0 0 r
s
.308 .884 .65 r
.89557 .76945 m .88423 .79851 L .87466 .79701 L closepath p F P
0 0 0 r
s
.336 .458 .618 r
.50561 .72093 m .48704 .72439 L .48725 .70671 L p F P
0 0 0 r
s
.336 .458 .618 r
.48725 .70671 m .50572 .70323 L .50561 .72093 L p F P
0 0 0 r
s
.545 .731 .921 r
.58034 .72935 m .56356 .72402 L .56336 .70634 L p F P
0 0 0 r
s
.496 .666 .853 r
.54477 .70304 m .56336 .70634 L .56356 .72402 L p F P
0 0 0 r
s
.362 1 .7 r
.74264 .37898 m .75113 .40179 L .75908 .39504 L closepath p F P
0 0 0 r
s
0 .309 0 r
.74264 .37898 m .75173 .40977 L .75113 .40179 L closepath p F P
0 0 0 r
s
.046 .407 .118 r
.74264 .37898 m .75908 .39504 L .76768 .39623 L closepath p F P
0 0 0 r
s
.28 .387 .532 r
.48683 .74225 m .47015 .7477 L .47045 .72987 L p F P
0 0 0 r
s
.28 .387 .532 r
.47045 .72987 m .48704 .72439 L .48683 .74225 L p F P
0 0 0 r
s
.584 .784 .971 r
.59476 .75422 m .58063 .74718 L .58034 .72935 L p F P
0 0 0 r
s
.545 .731 .921 r
.56356 .72402 m .58034 .72935 L .58063 .74718 L p F P
0 0 0 r
s
.391 .529 .7 r
.52522 .71969 m .50561 .72093 L .50572 .70323 L p F P
0 0 0 r
s
.391 .529 .7 r
.50572 .70323 m .52522 .70199 L .52522 .71969 L p F P
0 0 0 r
s
.225 .313 .441 r
.46985 .76573 m .4559 .77285 L .45628 .75487 L p F P
0 0 0 r
s
.225 .313 .441 r
.45628 .75487 m .47015 .7477 L .46985 .76573 L p F P
0 0 0 r
s
.496 .666 .853 r
.56356 .72402 m .54487 .72074 L .54477 .70304 L p F P
0 0 0 r
s
.444 .598 .779 r
.52522 .70199 m .54477 .70304 L .54487 .72074 L p F P
0 0 0 r
s
.588 .794 .966 r
.60591 .78056 m .59514 .7722 L .59476 .75422 L p F P
0 0 0 r
s
.584 .784 .971 r
.58063 .74718 m .59476 .75422 L .59514 .7722 L p F P
0 0 0 r
s
.69 .09 .12 r
.59992 .77456 m
.60591 .78056 L
s
.444 .598 .779 r
.54487 .72074 m .52522 .71969 L .52522 .70199 L p F P
0 0 0 r
s
.134 .546 .339 r
.74264 .37898 m .76033 .411 L .75173 .40977 L closepath p F P
0 0 0 r
s
.177 .561 .251 r
.74264 .37898 m .76768 .39623 L .76833 .40421 L closepath p F P
0 0 0 r
s
.336 .458 .618 r
.5055 .73882 m .48683 .74225 L .48704 .72439 L p F P
0 0 0 r
s
.336 .458 .618 r
.48704 .72439 m .50561 .72093 L .5055 .73882 L p F P
0 0 0 r
s
.545 .731 .921 r
.58063 .74718 m .56376 .74189 L .56356 .72402 L p F P
0 0 0 r
s
.496 .666 .853 r
.54487 .72074 m .56356 .72402 L .56376 .74189 L p F P
0 0 0 r
s
.343 .912 .661 r
.74264 .37898 m .76833 .40421 L .76033 .411 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.76349 .40832 m
.80836 .47148 L
s
.28 .387 .532 r
.48662 .76031 m .46985 .76573 L .47015 .7477 L p F P
0 0 0 r
s
.28 .387 .532 r
.47015 .7477 m .48683 .74225 L .48662 .76031 L p F P
0 0 0 r
s
.584 .784 .971 r
.59514 .7722 m .58093 .76521 L .58063 .74718 L p F P
0 0 0 r
s
.545 .731 .921 r
.56376 .74189 m .58063 .74718 L .58093 .76521 L p F P
0 0 0 r
s
.391 .529 .7 r
.52521 .73759 m .5055 .73882 L .50561 .72093 L p F P
0 0 0 r
s
.391 .529 .7 r
.50561 .72093 m .52522 .71969 L .52521 .73759 L p F P
0 0 0 r
s
.258 .752 .525 r
.44239 .77282 m .45354 .7699 L .45234 .76754 L closepath p F P
0 0 0 r
s
.062 .342 .104 r
.44239 .77282 m .45349 .77236 L .45354 .7699 L closepath p F P
0 0 0 r
s
0 .04 0 r
.44239 .77282 m .45223 .77246 L .45349 .77236 L closepath p F P
0 0 0 r
s
.17 .605 .398 r
.44239 .77282 m .45102 .7701 L .45223 .77246 L closepath p F P
0 0 0 r
s
.017 .467 .035 r
.44239 .77282 m .45234 .76754 L .45107 .76764 L closepath p F P
0 0 0 r
s
.009 .226 .022 r
.44239 .77282 m .45107 .76764 L .45102 .7701 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.45113 .77033 m
.47304 .76409 L
s
.47304 .76409 m
.4822 .76149 L
s
.496 .666 .853 r
.56376 .74189 m .54497 .73863 L .54487 .72074 L p F P
0 0 0 r
s
.444 .598 .779 r
.52522 .71969 m .54487 .72074 L .54497 .73863 L p F P
0 0 0 r
s
.318 .935 .671 r
.47242 .38232 m .5044 .38575 L .50679 .38037 L closepath p F P
0 0 0 r
s
.288 .77 .501 r
.47242 .38232 m .50317 .39408 L .5044 .38575 L closepath p F P
0 0 0 r
s
.444 .598 .779 r
.54497 .73863 m .52521 .73759 L .52522 .71969 L p F P
0 0 0 r
s
.009 .182 .011 r
.47242 .38232 m .50432 .39708 L .50317 .39408 L closepath p F P
0 0 0 r
s
.336 .458 .618 r
.50538 .7569 m .48662 .76031 L .48683 .74225 L p F P
0 0 0 r
s
.336 .458 .618 r
.48683 .74225 m .5055 .73882 L .50538 .7569 L p F P
0 0 0 r
s
.003 .144 .005 r
.47242 .38232 m .50679 .38037 L .50795 .38334 L closepath p F P
0 0 0 r
s
.545 .731 .921 r
.58093 .76521 m .56397 .75995 L .56376 .74189 L p F P
0 0 0 r
s
.496 .666 .853 r
.54497 .73863 m .56376 .74189 L .56397 .75995 L p F P
0 0 0 r
s
.238 .757 .539 r
.47242 .38232 m .50671 .39172 L .50432 .39708 L closepath p F P
0 0 0 r
s
.338 .991 .656 r
.58511 .75973 m .58813 .76438 L .59032 .76253 L closepath p F P
0 0 0 r
s
.036 .397 .051 r
.58511 .75973 m .58818 .76684 L .58813 .76438 L closepath p F P
0 0 0 r
s
0 .251 0 r
.58511 .75973 m .59032 .76253 L .59255 .76315 L closepath p F P
0 0 0 r
s
.097 .467 .252 r
.58511 .75973 m .59041 .76746 L .58818 .76684 L closepath p F P
0 0 0 r
s
.391 .529 .7 r
.52521 .75568 m .50538 .7569 L .5055 .73882 L p F P
0 0 0 r
s
.391 .529 .7 r
.5055 .73882 m .52521 .73759 L .52521 .75568 L p F P
0 0 0 r
s
.214 .62 .311 r
.58511 .75973 m .59255 .76315 L .5926 .76561 L closepath p F P
0 0 0 r
s
.496 .666 .853 r
.56397 .75995 m .54507 .75672 L .54497 .73863 L p F P
0 0 0 r
s
.444 .598 .779 r
.52521 .73759 m .54497 .73863 L .54507 .75672 L p F P
0 0 0 r
s
.349 .924 .671 r
.58511 .75973 m .5926 .76561 L .59041 .76746 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.59172 .76635 m
.59992 .77456 L
s
.444 .598 .779 r
.54507 .75672 m .52521 .75568 L .52521 .73759 L p F P
0 0 0 r
s
.204 .621 .375 r
.47242 .38232 m .50795 .38334 L .50671 .39172 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.50711 .38902 m
.60359 .40768 L
s
.53544 .75505 m
.54668 .7568 L
s
.54668 .7568 m
.55233 .75768 L
s
.278 .892 .6 r
.50802 .75078 m .51873 .7511 L .51955 .74964 L closepath p F P
0 0 0 r
s
.288 .77 .502 r
.50802 .75078 m .51832 .75396 L .51873 .7511 L closepath p F P
0 0 0 r
s
.045 .271 .06 r
.50802 .75078 m .51872 .75538 L .51832 .75396 L closepath p F P
0 0 0 r
s
.024 .221 .032 r
.50802 .75078 m .51955 .74964 L .51996 .75106 L closepath p F P
0 0 0 r
s
.259 .753 .526 r
.38468 .75236 m .40347 .7474 L .4014 .7434 L closepath p F P
0 0 0 r
s
.059 .336 .098 r
.38468 .75236 m .40332 .75153 L .40347 .7474 L closepath p F P
0 0 0 r
s
0 .039 0 r
.38468 .75236 m .40109 .75167 L .40332 .75153 L closepath p F P
0 0 0 r
s
.169 .602 .396 r
.38468 .75236 m .399 .74766 L .40109 .75167 L closepath p F P
0 0 0 r
s
.028 .491 .058 r
.38468 .75236 m .4014 .7434 L .39916 .74352 L closepath p F P
0 0 0 r
s
.006 .216 .016 r
.38468 .75236 m .39916 .74352 L .399 .74766 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.39924 .74811 m
.45157 .73284 L
s
.221 .737 .514 r
.50802 .75078 m .51954 .75393 L .51872 .75538 L closepath p F P
0 0 0 r
s
.204 .621 .375 r
.50802 .75078 m .51996 .75106 L .51954 .75393 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.51973 .7526 m
.53544 .75505 L
s
.334 .986 .647 r
.62647 .72979 m .6313 .73789 L .635 .73476 L closepath p F P
0 0 0 r
s
.019 .367 .027 r
.62647 .72979 m .63143 .74204 L .6313 .73789 L closepath p F P
0 0 0 r
s
0 .258 0 r
.62647 .72979 m .635 .73476 L .63886 .73577 L closepath p F P
0 0 0 r
s
.318 .935 .672 r
.45892 .33708 m .499 .34175 L .50196 .33487 L closepath p F P
0 0 0 r
s
.289 .772 .502 r
.45892 .33708 m .49746 .35214 L .499 .34175 L closepath p F P
0 0 0 r
s
.1 .474 .26 r
.62647 .72979 m .63528 .74305 L .63143 .74204 L closepath p F P
0 0 0 r
s
.207 .608 .298 r
.62647 .72979 m .63886 .73577 L .639 .73991 L closepath p F P
0 0 0 r
s
.004 .172 .006 r
.45892 .33708 m .49887 .35572 L .49746 .35214 L closepath p F P
0 0 0 r
s
.35 .928 .674 r
.62647 .72979 m .639 .73991 L .63528 .74305 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.63739 .74127 m
.66053 .76558 L
s
.001 .128 .002 r
.45892 .33708 m .50196 .33487 L .5034 .3384 L closepath p F P
0 0 0 r
s
.237 .757 .539 r
.45892 .33708 m .50185 .34886 L .49887 .35572 L closepath p F P
0 0 0 r
s
.259 .754 .527 r
.32535 .73132 m .35193 .72423 L .34894 .71853 L closepath p F P
0 0 0 r
s
.056 .329 .092 r
.32535 .73132 m .35163 .73006 L .35193 .72423 L closepath p F P
0 0 0 r
s
0 .262 0 r
.32535 .73132 m .34831 .7302 L .35163 .73006 L closepath p F P
0 0 0 r
s
.167 .599 .394 r
.32535 .73132 m .34529 .72448 L .34831 .7302 L closepath p F P
0 0 0 r
s
.04 .517 .084 r
.32535 .73132 m .34894 .71853 L .34561 .71863 L closepath p F P
0 0 0 r
s
.004 .206 .011 r
.32535 .73132 m .34561 .71863 L .34529 .72448 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.34569 .72523 m
.41973 .70307 L
s
.204 .62 .374 r
.45892 .33708 m .5034 .3384 L .50185 .34886 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.50232 .34567 m
.6228 .3695 L
s
.279 .894 .602 r
.49528 .71421 m .51359 .71489 L .51497 .71235 L closepath p F P
0 0 0 r
s
.289 .772 .503 r
.49528 .71421 m .51288 .71977 L .51359 .71489 L closepath p F P
0 0 0 r
s
.039 .258 .052 r
.49528 .71421 m .51356 .72212 L .51288 .71977 L closepath p F P
0 0 0 r
s
.02 .209 .027 r
.49528 .71421 m .51497 .71235 L .51566 .71469 L closepath p F P
0 0 0 r
s
.22 .737 .513 r
.49528 .71421 m .51495 .71959 L .51356 .72212 L closepath p F P
0 0 0 r
s
.329 .98 .638 r
.66954 .69863 m .67596 .71048 L .68125 .70602 L closepath p F P
0 0 0 r
s
.007 .342 .009 r
.66954 .69863 m .67623 .71634 L .67596 .71048 L closepath p F P
0 0 0 r
s
.204 .62 .374 r
.49528 .71421 m .51566 .71469 L .51495 .71959 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.51527 .71739 m
.57078 .72624 L
s
0 .268 0 r
.66954 .69863 m .68125 .70602 L .68683 .7074 L closepath p F P
0 0 0 r
s
.103 .48 .267 r
.66954 .69863 m .6818 .71775 L .67623 .71634 L closepath p F P
0 0 0 r
s
.198 .594 .284 r
.66954 .69863 m .68683 .7074 L .68711 .71327 L closepath p F P
0 0 0 r
s
.259 .755 .528 r
.26433 .70968 m .29886 .70038 L .29488 .69291 L closepath p F P
0 0 0 r
s
.053 .322 .086 r
.26433 .70968 m .29834 .70794 L .29886 .70038 L closepath p F P
0 0 0 r
s
0 .271 0 r
.26433 .70968 m .29381 .70804 L .29834 .70794 L closepath p F P
0 0 0 r
s
.165 .597 .391 r
.26433 .70968 m .2898 .70053 L .29381 .70804 L closepath p F P
0 0 0 r
s
.053 .546 .114 r
.26433 .70968 m .29488 .69291 L .29035 .69295 L closepath p F P
0 0 0 r
s
.003 .196 .007 r
.26433 .70968 m .29035 .69295 L .2898 .70053 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.29041 .70167 m
.38661 .6721 L
s
.352 .932 .678 r
.66954 .69863 m .68711 .71327 L .6818 .71775 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.68466 .71534 m
.71627 .75028 L
s
.323 .974 .628 r
.71442 .66615 m .72221 .68211 L .72913 .67627 L closepath p F P
0 0 0 r
s
.001 .323 .001 r
.71442 .66615 m .72266 .68971 L .72221 .68211 L closepath p F P
0 0 0 r
s
0 .278 0 r
.71442 .66615 m .72913 .67627 L .73655 .678 L closepath p F P
0 0 0 r
s
.26 .756 .529 r
.20153 .68741 m .24419 .67581 L .23916 .66649 L closepath p F P
0 0 0 r
s
.049 .314 .08 r
.20153 .68741 m .24338 .68512 L .24419 .67581 L closepath p F P
0 0 0 r
s
0 .28 0 r
.20153 .68741 m .23751 .68514 L .24338 .68512 L closepath p F P
0 0 0 r
s
.164 .594 .389 r
.20153 .68741 m .23244 .67577 L .23751 .68514 L closepath p F P
0 0 0 r
s
.068 .575 .147 r
.20153 .68741 m .23916 .66649 L .23328 .66643 L closepath p F P
0 0 0 r
s
.002 .186 .004 r
.20153 .68741 m .23328 .66643 L .23244 .67577 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.23331 .67738 m
.35214 .63986 L
s
.281 .895 .605 r
.4819 .6758 m .5082 .67699 L .51018 .67325 L closepath p F P
0 0 0 r
s
.29 .774 .504 r
.4819 .6758 m .50719 .68396 L .5082 .67699 L closepath p F P
0 0 0 r
s
.106 .487 .275 r
.71442 .66615 m .73008 .69148 L .72266 .68971 L closepath p F P
0 0 0 r
s
.033 .244 .044 r
.4819 .6758 m .50815 .68724 L .50719 .68396 L closepath p F P
0 0 0 r
s
.188 .578 .268 r
.71442 .66615 m .73655 .678 L .73704 .68561 L closepath p F P
0 0 0 r
s
.016 .196 .021 r
.4819 .6758 m .51018 .67325 L .51115 .67651 L closepath p F P
0 0 0 r
s
.354 .936 .681 r
.71442 .66615 m .73704 .68561 L .73008 .69148 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.7336 .68852 m
.77318 .73467 L
s
.22 .736 .512 r
.4819 .6758 m .51013 .68352 L .50815 .68724 L closepath p F P
0 0 0 r
s
.204 .62 .373 r
.4819 .6758 m .51115 .67651 L .51013 .68352 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.51057 .68047 m
.59003 .69343 L
s
.317 .967 .617 r
.76123 .63228 m .77012 .65271 L .77874 .64544 L closepath p F P
0 0 0 r
s
0 .309 0 r
.76123 .63228 m .77083 .66209 L .77012 .65271 L closepath p F P
0 0 0 r
s
.001 .288 .002 r
.76123 .63228 m .77874 .64544 L .78813 .6475 L closepath p F P
0 0 0 r
s
.109 .493 .282 r
.76123 .63228 m .78022 .66421 L .77083 .66209 L closepath p F P
0 0 0 r
s
.177 .561 .251 r
.76123 .63228 m .78813 .6475 L .7889 .65689 L closepath p F P
0 0 0 r
s
.355 .94 .685 r
.76123 .63228 m .7889 .65689 L .78022 .66421 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.78431 .66076 m
.83129 .71872 L
s
.282 .897 .607 r
.46783 .63541 m .50256 .63727 L .50515 .63223 L closepath p F P
0 0 0 r
s
.292 .776 .505 r
.46783 .63541 m .50123 .64644 L .50256 .63727 L closepath p F P
0 0 0 r
s
.027 .23 .036 r
.46783 .63541 m .50246 .65062 L .50123 .64644 L closepath p F P
0 0 0 r
s
.012 .182 .016 r
.46783 .63541 m .50515 .63223 L .5064 .63637 L closepath p F P
0 0 0 r
s
.219 .735 .511 r
.46783 .63541 m .50506 .6456 L .50246 .65062 L closepath p F P
0 0 0 r
s
.203 .619 .372 r
.46783 .63541 m .5064 .63637 L .50506 .6456 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.50562 .64172 m
.61014 .65918 L
s
.283 .898 .609 r
.45302 .59289 m .49664 .59561 L .49986 .58913 L closepath p F P
0 0 0 r
s
.293 .778 .507 r
.45302 .59289 m .49497 .60706 L .49664 .59561 L closepath p F P
0 0 0 r
s
.021 .215 .028 r
.45302 .59289 m .49649 .61213 L .49497 .60706 L closepath p F P
0 0 0 r
s
.008 .167 .011 r
.45302 .59289 m .49986 .58913 L .50141 .59413 L closepath p F P
0 0 0 r
s
.218 .734 .51 r
.45302 .59289 m .49972 .60567 L .49649 .61213 L closepath p F P
0 0 0 r
s
.203 .618 .371 r
.45302 .59289 m .50141 .59413 L .49972 .60567 L closepath p F P
0 0 0 r
s
.69 .09 .12 r
.5004 .601 m
.63115 .62338 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{400, 414.563},
  ImageMargins->{{0, 0}, {0, 22}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001WR000`400?l00000o`00003oo`3jl>J@
0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo
003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00
n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool0
0?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03j
l>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00
o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`
iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o
0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V
0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0
n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H1
0?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3j
l>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40
oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`
iY00n_3V0@3oool00<40n_3V200000360?[`iP40oooo002i0?[`iQ400000a@3jl>H10?ooo`00^P3j
l>H5000000X0=9mP00<000000?[`iP3jl>H0``3jl>H10?ooo`00_03jl>H20000000303k3S0000000
0000008000001@0dWf000`000000n_3V0?[`iP340?[`iP40oooo002n0?[`iP8000000`0n`h`40000
000303BOH0000000/1LN0080/1LN``3jl>H10?ooo`00`03jl>H2000000D0?/><0P0000030?[`iP@0
/1LN_`3jl>H10?ooo`00`P3jl>H2000000@0?/><00<000000?[`iP3jl>H01@3jl>H40;0G7[/0n_3V
0@3oool00<@0n_3V0P0000000`0n`h`000000?[`iP0;0?[`iPD0/1LN]P3jl>H10?ooo`00aP3jl>H2
00000140n_3V102`5ajb0?[`iP40oooo003M0?[`iPD0/1LN[@3jl>H10?ooo`00hP3jl>H40;0G7ZT0
n_3V0@3oool00>H0n_3V102`5ajU0?[`iP40oooo003Z0?[`iPD0/1LNX03jl>H10?ooo`00k`3jl>H4
0;0G7Y`0n_3V0@3oool00?<0n_3V0`2`5ajI0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3V
T03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iR80n_3V00<000000?[`iP3jl>H0J`3jl>H1
0?ooo`00_P3jl>H=000005H0n_3V0`00001[0?[`iP40oooo002o0?[`iP@000000P0dWf07000005H0
n_3V0`00001Z0?[`iP40oooo002E0?[`iP80/1LN:P3jl>H5000000D0=9mP00<000000?[`iP3jl>H0
E03jl>H4000006T0n_3V0@3oool009<0n_3V0P2`5ah^0?[`iP80000000D0?/><0000000000000000
03BOH0030;0G7UD0n_3V0P000000101Ehj<0000000000000001W0?[`iP40oooo002A0?[`iP80/1LN
<P3jl>H200000080?/><0P0000020?[`iP@0/1LNDP3jl>H20000000405GSX`000000;Hm0000006H0
n_3V0@3oool008h0n_3V0`2`5ahf0?[`iP<000001`3jl>H50;0G7Td0n_3V0P00000205GSX`040000
000]Sd000000000006@0n_3V0@3oool008`0n_3V0P2`5ahk0?[`iP030000003jl>H0n_3V00X0n_3V
102`5ai90?[`iP030000000VU60000000080EN>S00@0000002f?@00]Sd000000H`3jl>H10?ooo`00
RP3jl>H20;0G7Th0n_3V1@2`5ai50?[`iP8000000`1Ehj<00`000000;Hm00000001S0?[`iP40oooo
00270?[`iP<0/1LNE@3jl>H40;0G7T40n_3V00<0000002JDH00000000`1Ehj<2000006<0n_3V0@3o
ool008D0n_3V0P2`5aiL0?[`iPD0/1LN?03jl>H00`0000009YAP0000000405GSX`030000003jl>H0
n_3V0640n_3V0@3oool008<0n_3V0P2`5aiS0?[`iP@0/1LN>@3jl>H00`0000009YAP0000000205GS
X`030000003jl>H0n_3V0680n_3V0@3oool00800n_3V0`2`5aiY0?[`iP<0/1LN=P3jl>H300000003
05GSX`2`5ah0n_3V06@0n_3V0@3oool007h0n_3V0P2`5ajW0?[`iP80000000<0n_3V0;0G7P3jl>H0
H`3jl>H10?ooo`00N`3jl>H30;0G7Z`0n_3V00<0/1LN0?[`iP3jl>H0HP3jl>H10?ooo`00N@3jl>H2
0;0G7YL0n_3V00<000000?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP1Q0?[`iP40oooo001]0?[`
iP<000001`3jl>H20;0G7YT0n_3V0P00000H0?[`iP030;0G7P3jl>H0n_3V0600n_3V0@3oool006/0
n_3V1@0000040?[`iP<0/1LN:P3jl>H20;0G7W00n_3V0P00000G0?[`iP030;0G7P3jl>H0n_3V0600
n_3V0@3oool006X0n_3V00@00000000_0@00;`4000000P10_88010000000n_3V0;0G7P2`5ah[0?[`
iP80/1LNLP3jl>H010000000E>:R00000000000F0?[`iP030;0G7P3jl>H0n_3V05l0n_3V0@3oool0
06T0n_3V00<00000000_0@0000000P000002042lPP80/1LN:P3jl>H30;0G7R<0n_3V2`0000160?[`
iP80000000<0E>:R0000000000005P3jl>H00`2`5ah0n_3V0?[`iP1N0?[`iP40oooo001W0?[`iP@0
00000`0^WfT20;0G7P800000:03jl>H20;0G7RP0n_3V0`00000503BOH0030000003jl>H0n_3V04@0
n_3V0P00000205CRXP8000005@3jl>H00`2`5ah0n_3V0?[`iP1N0?[`iP40oooo001V0?[`iP<00000
1@0^WfT20000000300a@50000000n_3V02@0n_3V0`2`5ah/0?[`iPD0000000@0=9mP0;0G7P2`5ah0
/1LNA@3jl>H200000080E>:R0P00000E0?[`iP030;0G7P3jl>H0n_3V05d0n_3V0@3oool006D0n_3V
0P00000502jOJ@@0000000<0350D0000003jl>H08P3jl>H20;0G7S40n_3V0P0000000`0n`h`00000
000000020?[`iP@0/1LN@@3jl>H2000000<0E>:R00<000000?[`iP3jl>H0503jl>H00`2`5ah0n_3V
0?[`iP1L0?[`iP40oooo001S0?[`iP80000000<0;YmY0000000000002P00000P0?[`iP<0/1LN=@3j
l>H2000000L0n_3V1@2`5ahl0?[`iP030000000VTel0000000<0E>:R00<000000?[`iP3jl>H04`3j
l>H00`2`5ah0n_3V0?[`iP1L0?[`iP40oooo001R0?[`iPP000009@3jl>H30;0G7TH0n_3V102`5ahi
0?[`iP80000000<0E>:R0;0G7P0000005`3jl>H00`2`5ah0n_3V0?[`iP1K0?[`iP40oooo002=0?[`
iP80/1LNC@3jl>H50;0G7S@0n_3V0`0000000`3jl>H0/1LN0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V
05/0n_3V0@3oool008X0n_3V0`2`5aiD0?[`iP@0/1LN=03jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP03
0;0G7P3jl>H0n_3V05X0n_3V0@3oool00840n_3V00<000000?[`iP3jl>H0103jl>H20;0G7U/0n_3V
0`2`5ahb0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H0F@3jl>H10?ooo`00P03j
l>H300000080n_3V0`2`5ajC0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H0F@3j
l>H10?ooo`00OP3jl>H400000003042lPP2`5ah0/1LN07h0n_3V00<000000?[`iP3jl>H05@3jl>H0
0`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V05P0n_3V0@3oool007d0n_3V00@00000000b
0@00<P4000000P2`5ah00`000000n_3V0?[`iP1m0?[`iP8000005`3jl>H00`2`5ah0n_3V0?[`iP0F
0?[`iP030;0G7P3jl>H0n_3V05L0n_3V0@3oool007`0n_3V00L00000000b0@000000000002nOJ@00
0000@;b2008000009`3jl>H20;0G7UD0n_3V0`00000G0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0
/1LN0?[`iP3jl>H0E`3jl>H10?ooo`00NP3jl>H400000080;imY1000000V0?[`iP80/1LNF03jl>H0
10000000E>6R00000000000E0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H0EP3j
l>H10?ooo`00N@3jl>H;000002<0n_3V0`2`5aiJ0?[`iP80000000<0E>6R0000000000005@3jl>H0
0`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V05D0n_3V0@3oool007P0n_3V1P00000W0?[`
iP80/1LNG@3jl>H200000080E>6R0P00000E0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`
iP3jl>H0E@3jl>H10?ooo`00XP3jl>H30;0G7Ul0n_3V00<0000002JCGP0000000P1DhJ800`000000
n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H0E03jl>H10?ooo`00
X03jl>H20;0G7RD0n_3V2000000f0?[`iP80000000<0E>6R0;0G7P3jl>H05P3jl>H00`2`5ah0n_3V
0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V05<0n_3V0@3oool009d0n_3V0`2`5ahX0?[`iPD0000000<0
=9mP0000003jl>H0=@3jl>H3000000030?[`iP2`5ah0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H05@3j
l>H00`2`5ah0n_3V0?[`iP1C0?[`iP40oooo002K0?[`iP80/1LN;@3jl>H20000000303o3S0000000
/1LN0080/1LN>03jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN
0?[`iP3jl>H0DP3jl>H10?ooo`00T`3jl>H300000080n_3V0`2`5aha0?[`iP8000000`3jl>H50;0G
7S@0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0?[`iP1Z0?[`iP40oooo002A0?[`iPD0
00000P2`5ahn0?[`iP@0/1LN<@3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V06T0
n_3V0@3oool00900n_3V100000020;0G7P030000003jl>H0n_3V0440n_3V1@2`5ah/0?[`iP030;0G
7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H0J@3jl>H10?ooo`00S`3jl>H200000080;j1Z0`00
00190?[`iP<0/1LN:P3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V06P0n_3V0@3o
ool008d0n_3V2@00001N0?[`iP030000003jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H0
0`2`5ah0n_3V0?[`iP1W0?[`iP40oooo002<0?[`iPD00000H`3jl>H2000001L0n_3V00<0/1LN0?[`
iP3jl>H05@3jl>H00`2`5ah0n_3V0?[`iP1W0?[`iP40oooo002g0?[`iP80/1LN?03jl>H3000001H0
n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0?[`iP1V0?[`iP40oooo002d0?[`iP<0/1LN
?P3jl>H4000001H0n_3V00<0/1LN0?[`iP3jl>H0O@3jl>H10?ooo`00/@3jl>H30;0G7T80n_3V00<0
000005?PX@0000005`3jl>H00`2`5ah0n_3V0?[`iP1l0?[`iP40oooo002^0?[`iP<0/1LNA@3jl>H0
0`000000/1LN0?[`iP0G0?[`iP030;0G7P3jl>H0n_3V07`0n_3V0@3oool00:/0n_3V0`2`5ai:0?[`
iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H0N`3jl>H10?ooo`00YP3jl>H00`000000
n_3V0;0G7P020;0G7Th0n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP1j0?[`iP40
oooo002T0?[`iP8000000P2`5aiA0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H0
NP3jl>H10?ooo`00XP3jl>H6000002H0n_3V0P00000Z0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0
/1LN0?[`iP3jl>H0N@3jl>H10?ooo`00X@3jl>H7000002<0n_3V100000030;0G7RT0n_3V00<0/1LN
0?[`iP3jl>H0T@3jl>H10?ooo`00H@3jl>H00`2`5ah0n_3V0?[`iP1Y0?[`iP<000000P3jl>H50;0G
7RD0n_3V00<0/1LN0?[`iP3jl>H0T03jl>H10?ooo`00H@3jl>H00`2`5ah0n_3V0?[`iP1U0?[`iPh0
00000`2`5ahS0?[`iP030;0G7P3jl>H0n_3V08l0n_3V0@3oool00600n_3V00<0/1LN0?[`iP3jl>H0
H`3jl>H30000000305IeWP000000I8Nc00D0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000OZ[J
0;0G7P0200000240n_3V00<0/1LN0?[`iP3jl>H0SP3jl>H10?ooo`00H03jl>H00`2`5ah0n_3V0?[`
iP1O0?[`iP040;0G7P0000000000000000@0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7
076Ia`04076Ia`030000001nZ]X0OZ[J0080OZ[J0`0000060?[`iP030000003jl>H0n_3V01D0n_3V
00<0/1LN0?[`iP3jl>H0SP3jl>H10?ooo`00H03jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G7P3j
l>H0n_3V04L0n_3V0P2`5ah00`000000Af>80000000505IeWP030000001TQk<0I8Nc00@0I8Nc00<0
0000076Ia`1aVLL0101aVLL00`000000OZ[J07jZfP0307jZfP030000002;^n/00000008000000`3j
l>H3000001H0n_3V00<0/1LN0?[`iP3jl>H0S@3jl>H10?ooo`00H03jl>H00`2`5ah0n_3V0?[`iP0C
0?[`iP030;0G7P3jl>H0n_3V04D0n_3V0P2`5ah404MSR0030000001FMIh0EWFN00<0EWFN00<00000
06B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001nZ]X0OZ[J00<0OZ[J00<00000
08^kj`2;^n/00P2;^n/200000080n_3V00<000000;0G7P3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP2<
0?[`iP40oooo001O0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H0@03jl>H00`00
0000n_3V0;0G7P030;0G7P0300000017HhP0Af>800<0Af>800<0000005IeWP1FMIh00`1FMIh01000
0000I8Nc06B7/`1TQk<7000000<0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`02
08^kj`D0000000<0/1LN0?[`iP3jl>H0X`3jl>H10?ooo`00G`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`
iP030;0G7P3jl>H0n_3V03h0n_3V0P0000020;0G7P8000000P0iD7000`000000Af>804MSR00304MS
R0040000001FMIh0EWFN05IeWPH000000`1TQk<010000000LIW7076Ia`1aVLL7000000<0OZ[J00<0
000008^kj`2;^n/00P2;^n/00`000000ULSh09G8n002000000030;0G7P3jl>H0n_3V06D0n_3V00<0
00000?[`iP3jl>H0>`3jl>H10?ooo`00G`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0
n_3V01<0n_3V00<0/1LN0?[`iP3jl>H09`3jl>H5000000@0>E1`00<0000004MSR017HhP00`17HhP4
00000080EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`040000001nZ]X0
OZ[J07jZfPD000000`2;^n/00`000000ULSh09G8n00209G8n0030000002`5ah0n_3V06@0n_3V0P00
000m0?[`iP40oooo001O0?[`iP030;0G7P3jl>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H0503jl>H0
0`2`5ah0n_3V0?[`iP0Z0?[`iP800000100iD70010000000Af>804MSR017HhP3000000D0EWFN00<0
000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001nZ]X0OZ[J00@0OZ[J00H0
000008^kj`000000000008^kj`00000409G8n080000000<0/1LN0?[`iP3jl>H0H@3jl>H3000003d0
n_3V0@3oool005h0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G
7P3jl>H0n_3V02X0n_3V00<0000002TiE@000000100iD70010000000Af>800000000000204MSR003
0000001FMIh0EWFN00<0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`03
0000001nZ]X0OZ[J00@0OZ[J00@0000008^kj`2;^n/0Rk_[0P00000409G8n0040000002FboL00000
0;0G7T`0n_3V00<000000?[`iP3jl>H04P3jl>H3000003h0n_3V0@3oool005h0n_3V00<0/1LN0?[`
iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V02X0n_3V00<0000002Ti
E@000000100iD702000000@0Af>800<0000005IeWP1FMIh00`1FMIh00`000000I8Nc06B7/`0406B7
/`030000001aVLL0LIW700@0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0208^k
j`8000000`2Eb?P010000000U/_g09K;m`2`5ai;0?[`iP8000004P3jl>H30000000304gIW`000000
n_3V03d0n_3V0@3oool005h0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP0D0?[`
iP030;0G7P3jl>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H0503jl>H010000000:CUE02TiE@000002
03U@L0<000001@17HhP00`000000EWFN05IeWP0205IeWQ4000001@1nZ]X00`000000Rk_[08^kj`02
08^kj`060000002Eb?P000000000002Eb?P000000`2FboL00`2`5ah0n_3V0?[`iP0b0?[`iP030000
003jl>H0n_3V0180n_3V0`00000A0?[`iP80000000@05FTc0000000000000000?P3jl>H10?ooo`00
GP3jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H0
4`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP8000000P0Y>ED300000080>E1`00<0000004MSR017HhP0
0`17HhP00`000000EWFN000000020000000305IeWP000000I8Nc00D0I8Nc00<00000076Ia`1aVLL0
101aVLL00`000000OZ[J000000030000000307jZfP000000Rk_[00<0Rk_[00@0000009G8n02Eb?P0
ULSh0P00000309K;m`030000003jl>H0n_3V0340n_3V0P00000B0?[`iPD00000403jl>H200000003
01EY<`000000CMVO00800000?P3jl>H10?ooo`00G@3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G
7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP800000
0P0Y>ED00`000000>E1`03U@L00203U@L00300000017HhP0Af>80080Af>80`00000405IeWP030000
001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000OZ[J07jZfP0307jZfP<00000
0`2;^n/00`000000ULSh09G8n00209G8n0040000002FboL0U/_g09K;m`800000<@3jl>H300000140
n_3V0P0000000`0DIc8000000000000@0?[`iP8000000P0EJC<010000000CMVO00000000000n0?[`
iP40oooo001M0?[`iP030;0G7P3jl>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0
n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V01<0n_3V0P0000000`0Y>ED000000000000@00000003
05IeWP000000I8Nc00D0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000OZ[J07jZfP0407jZfP06
0000002;^n/000000000002;^n/00000102Eb?P200000080U/_g0P00000L0?[`iP030000003jl>H0
n_3V0140n_3V1000000@0?[`iP80000000@056Lb00000000000000003`3jl>H2000000805FTc00@0
000004gIW`0000000000?`3jl>H10?ooo`00G@3jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP030;0G7P3j
l>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP040;0G7P00
0000000002TiE@H000000`0dWUl90000000305IeWP000000I8Nc00D0I8Nc00<00000076Ia`1aVLL0
101aVLL00`000000OZ[J07jZfP0407jZfP040000002;^n/0Rk_[08^kj`800000102Eb?P00`000000
U/_g000000020000000307j^d@000000n_3V01T0n_3V0P00000C0?[`iP<00000403jl>H200000080
56Lb0`00000?0?[`iP040000000EJC<05FTc00000080CMVO0P00000o0?[`iP40oooo001L0?[`iP03
0;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP03
0;0G7P3jl>H0n_3V01<0n_3V00@0/1LN01LQ=@00000000000P0Y>ED30000000403c1R@0000000000
000000P0=9iO00<0000005IeWP0000000`1TQk<7000000<0LIW700<0000007jZfP1nZ]X0101nZ]X0
0`000000Rk_[08^kj`0208^kj`<000000P2Eb?P01`000000U/_g09K;m`2FboL0000007j^d@000000
6@3jl>H300000180n_3V0P0000000`1=fIh000000?[`iP0?0?[`iP050000000DIc8056Lb0000001=
fIh00P00000@0?[`iP030000000EJC<000000080CMVO0P00000o0?[`iP40oooo001L0?[`iP030;0G
7P3jl>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G
7P3jl>H0n_3V0180n_3V00@0/1LN0000000G8CD000000`0Y>ED500000080?<690`00000503BNG`H0
00000`1TQk<010000000LIW7076Ia`1aVLL7000000<0OZ[J00<0000008^kj`2;^n/00P2;^n/00`00
0000ULSh09G8n003000000<0U/_g0`0000040?[`iP030000003jl>H0n_3V0140n_3V0`00000B0?[`
iP030000000CIS400000008000004@3jl>H01P00000056Lb00000000000059@R00000140n_3V00<0
/1LN0000001=fIl00P0000100?[`iP40oooo001L0?[`iP030;0G7P3jl>H0n_3V0180n_3V00<0/1LN
0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00@0/1LN
00000000000000000`0Y>ED00`000000>E1`03U@L00203U@L08000000`0l`HT40000000403BNG`2`
5ah0/1LN0;0G7PH0I8Nc00<00000076Ia`1aVLL0101aVLL010000000OZ[J07jZfP1nZ]X5000000@0
Rk_[00D0000009G8n02Eb?P0ULSh0000000309K;m`80000000@0OZkA0000003jl>H0n_3V0P00000B
0?[`iP040000000CIC00000000000180n_3V0P0000000`1=fIh000000000000B0?[`iP040;0G7P00
0000000000000140n_3V00<0/1LN0?[`iP3jl>H00P0000110?[`iP40oooo001L0?[`iP030;0G7P3j
l>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP030;0G7P3j
l>H0n_3V01<0n_3V1000000202TiE@800000100iD70010000000Af>800000000000503c1R@800000
00<0EWFN0000002`5ah0102`5ah00`1TQk<00000076Ia`05076Ia`030000001nZ]X0OZ[J00@0OZ[J
00<0000008^kj`0000000P0000000`2;^n/0000009G8n00209G8n08000000P2FboL01@000000OZkA
000000000000n_3V00800000503jl>H00`2`5ah000000000000C0?[`iP030;0G7P00000000000180
n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP130?[`iP40oooo001K0?[`iP030;0G
7P3jl>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G
7P3jl>H0n_3V0180n_3V00T0/1LN0000000000005b4e0000000Y>ED0000002TiE@000000100iD700
0`000000Af>800000003000000@0?<6900<0000005IeWP0000001@1TQk<60;0G7P80LIW700<00000
07jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0208^kj`8000000`2Eb?P01P000000U/_g0000002F
boL0000007j^d@80000000<0n_3V0;0G7P0000004`3jl>H00`2`5ah0n_3V0000000C0?[`iP030;0G
7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP140?[`iP40oooo
001K0?[`iP030;0G7P3jl>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`
iP0B0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00@0/1LN0000000000005b4e0P00000202TiE@030000
000iD700>E1`0080>E1`0P00000404MSR080000000D0?<690000001FMIh0EWFN0000000606B7/`03
0000001aVLL0LIW70080LIW71@2`5ah407jZfP030000002;^n/0Rk_[00<0Rk_[0P00000209G8n003
0000002FboL0U/_g008000000P1n[]400`000000/1LN0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V01<0
n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V04@0
n_3V0@3oool005/0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP030;0G
7P3jl>H0n_3V0180n_3V00<000000;0G7P3jl>H04`3jl>H01P2`5ah000000000000000005b4e0000
00<0:CUE00<0000003U@L00iD7000`00000504MSR0050000001FMIh000000000001FMIh04@000000
0`1nZ]X0/1LN0;0G7P030;0G7PD0Rk_[00H0000009G8n0000000000009G8n000000209K;m`050000
001n[]40OZkA0000002`5ah0503jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V01<0
n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP150?[`iP40oooo001K0?[`iP030;0G
7P3jl>H0n_3V0100n_3V00<000000;0G7P3jl>H04`3jl>H00`000000/1LN0000000B0?[`iP030000
002`5ah0000001@0n_3V00<0/1LN0000000000000`00000302TiE@<000000P0iD7000`000000Af>8
04MSR00304MSR0030000001FMIh000000080000000<0EWFN0000001TQk<01@1TQk<00`000000LIW7
076Ia`04076Ia`030000001nZ]X0000000<0000000<0OZ[J0000002`5ah01@2`5ah309G8n0800000
0P2FboL20000000307j^d@000000n_3V01@0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V
0?[`iP0B0?[`iP030;0G7P3jl>H0n_3V0180n_3V00<0/1LN0?[`iP3jl>H0AP3jl>H10?ooo`00F03j
l>H2000000030;0G7P000000n_3V0100n_3V0P0000000`2`5ah000000000000A0?[`iP80000000<0
/1LN0000003jl>H04@3jl>H010000000/1LN011N:P00000B0?[`iP80000000<0n_3V000000000000
0P00000302TiE@030000000iD700>E1`0080>E1`00<0000004MSR017HhP00P17HhP3000000@0EWFN
00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001nZ]X0OZ[J00<0OZ[J
0`00000408^kj`030000002`5ah0/1LN00<0/1LN0P2FboL20000000307j^d@000000n_3V01<0n_3V
00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP030;0G7P3jl>H0n_3V01<0n_3V
00<0/1LN0?[`iP3jl>H0AP3jl>H10?ooo`00E`3jl>H20000000404cHWP2`5ah00000000000l0n_3V
00H0000004kZR0000000/1LN04cHWP00000A0?[`iP050000002`5ah0000000mM:00000004@3jl>H3
000001<0n_3V00<000000?[`iP3jl>H00P000000100G8CD0000002TiE@0Y>ED2000000@0>E1`00<0
000004MSR00000000P0000000`17HhP0000005IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<0
0000076Ia`1aVLL0101aVLL00`000000OZ[J07jZfP0407jZfP030000002;^n/000000080000000<0
Rk_[0000002Eb?P00`2Eb?P00`000000/1LN0;0G7P030;0G7P030000003jl>H0n_3V0180n_3V00<0
/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V0180n_3V00<0
/1LN0?[`iP3jl>H0A`3jl>H10?ooo`00EP3jl>H01`000000D^j>0000001<f9h0/1LN00iJ9P000000
3`3jl>H01`000000C^Z80;0G7P1<f9h0000000mK9`000000403jl>H010000000/1LN00000000000B
0?[`iP8000005`3jl>H20000000601LQ=@000000:CUE0000000Y>ED00000100iD702000000@0Af>8
00<0000005IeWP1FMIh00`1FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW7
00<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0208^kj`800000102Eb?P010000000U/_g
00000000000207j^d@H0/1LN3P3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V0180
n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP170?[`iP40oooo001F0?[`iP050000
001BkXh0000004cHWP2`5ah00P0>FRH00`000000n_3V0?[`iP0<0?[`iP80000000@0/1LN04cHWP00
000000004@3jl>H3000001<0n_3V00<000000?[`iP3jl>H05P3jl>H20000000301LQ=@0000000000
0080:CUE00<0000003U@L00iD7000`00000404MSR0030000001FMIh0EWFN00@0EWFN00@0000006B7
/`1TQk<0I8Nc1`000003076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/00`2;^n/3
00000080ULSh00@0000009K;m`2FboL000000P1n[]400`000000n_3V0?[`iP030?[`iP<0/1LN2`3j
l>H00`2`5ah0n_3V0?[`iP0B0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H04P3j
l>H00`2`5ah0n_3V0?[`iP180?[`iP40oooo001F0?[`iP<0000000@0/1LN0000000>FRH000003`3j
l>H20000000403k>S`000000000000000140n_3V0`00000/0?[`iP80000000<05b4e0000000Y>ED0
0P0Y>ED300000080>E1`00<0000004MSR017HhP00P17HhP00`000000EWFN05IeWP0305IeWPD00000
0`1TQk<010000000LIW7076Ia`1aVLL7000000<0OZ[J00<0000008^kj`2;^n/00`2;^n/00`000000
ULSh09G8n00300000080U/_g0P0000000`1n[]4000000000000A0?[`iP030;0G7P3jl>H0n_3V01<0
n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP030;0G7P3jl>H0n_3V04T0
n_3V0@3oool005H0n_3V0P000000100ncHl0/1LN00000000000@0?[`iP80000000<0?/j?00000000
00004P3jl>H2000002d0n_3V1000000302TiE@030000000iD700>E1`0080>E1`00<0000004MSR017
HhP00P17HhP00`000000EWFN000000030000000305IeWP000000I8Nc00D0I8Nc00<00000076Ia`1a
VLL0101aVLL010000000OZ[J07jZfP1nZ]X4000000D0Rk_[00<0000009G8n02Eb?P00P2Eb?P00`00
0000U/_g09K;m`020000000307j^d@00000000000140n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`
5ah0n_3V0?[`iP0B0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H0B@3jl>H10?oo
o`00EP3jl>H200000080?/f?0P00000A0?[`iP030000000ncXl0000001<0n_3V00<000000?[`iP3j
l>H0;03jl>H400000080:CUE0P00000403U@L00400000017HhP0Af>804MSR0<000001@1FMIh00`00
0000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007jZfP1nZ]X0101nZ]X30000
00<0Rk_[00<0000009G8n02Eb?P00P2Eb?P20000000309K;m`000000OZkA00<00000403jl>H00`2`
5ah0n_3V0?[`iP0B0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`
5ah0n_3V0?[`iP1:0?[`iP40oooo001G0?[`iP040000000ncHl0?/f?00000180n_3V0P0000130?[`
iP80000000H05b4e0000000Y>ED0000002TiE@00000403U@L00600000017HhP0000000000017HhP0
00001P1FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007jZfP1n
Z]X0101nZ]X00`000000Rk_[08^kj`020000000308^kj`000000ULSh00<0ULSh0P0000000`2FboL0
000007j^d@0300000100n_3V00<0/1LN0?[`iP3jl>H04P3jl>H00`2`5ah0n_3V0?[`iP0>0?[`iP05
0000003jl>H0n_3V0?[`iP2`5ah05@3jl>H00`2`5ah0n_3V0?[`iP1:0?[`iP40oooo001G0?[`iP03
0000000ncHl0000001<0n_3V0P0000130?[`iP80000000<05b4e0000000000000P0Y>ED00`000000
>E1`03U@L00?000000H0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000OZ[J07jZfP0407jZfP03
0000002;^n/0Rk_[0080Rk_[0P00000409G8n0040000002FboL0000000000080OZkA0P00000T0?[`
iP030;0G7P3jl>H0n_3V00l0n_3V0`0000000`3jl>H0/1LN0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V
04/0n_3V0@3oool005L0n_3V0P00000D0?[`iP030000003jl>H0n_3V0480n_3V0P0000000`0G8CD0
000002TiE@0202TiE@030000000iD700>E1`00H0000000<0=9iO0000000000001P00000306B7/`L0
00000`1aVLL00`000000OZ[J07jZfP0407jZfP030000002;^n/0Rk_[00<0Rk_[0`00000209G8n004
0000002FboL0U/_g00000080OZkA0P00000T0?[`iP030;0G7P3jl>H0n_3V00l0n_3V1000000D0?[`
iP030;0G7P3jl>H0n_3V04`0n_3V0@3oool005L0n_3V0P00000g0?[`iP80/1LN803jl>H4000000<0
:CUE0`00000203U@L00300000017HhP0000000@000001@0dWUl4000000<0I8Nc00@00000076Ia`1a
VLL0LIW71`00000307jZfP030000002;^n/0Rk_[00<0Rk_[00<0000009G8n02Eb?P00`00000209K;
m`80000000<0OZkA0000000000008`3jl>H00`2`5ah0n_3V0?[`iP0A0?[`iP@000004`3jl>H00`2`
5ah0n_3V0?[`iP1<0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V03<0n_3V0`2`5ahR0?[`iP@0
00000`0Y>ED01@000000>E1`03U@L00iD700000000@0Af>80P0000000`0l`HT00000000000020000
000403BNG`2`5ah0/1LN0;0G7P@0I8Nc00<00000076Ia`1aVLL0101aVLL010000000OZ[J07jZfP1n
Z]X5000000@0Rk_[00<0000009G8n02Eb?P00P2Eb?P00`000000U/_g09K;m`020000000307j^d@00
0000000003L0n_3V0P000000101GjJT0000000000000000@0?[`iP030;0G7P3jl>H0n_3V04d0n_3V
0@3oool008/0n_3V0P2`5ahU0?[`iP80000000@05b4e0000000Y>ED0:CUE0P00000303U@L0040000
0017HhP0Af>804MSR0D000000`0l`HT200000080I8Nc1@2`5ah6076Ia`030000001nZ]X0OZ[J00@0
OZ[J00<0000008^kj`0000000P0000000`2;^n/0000009G8n00309G8n080000000<0U/_g0000001n
[]400`00000g0?[`iP070000000RReH0000005OYZ@000000;Hm00000000?0?[`iP030;0G7P3jl>H0
n_3V04d0n_3V0@3oool008P0n_3V0`2`5ahJ0?[`iP030;0G7P3jl>H0n_3V00X0n_3V0P0000001P0G
8CD0000002TiE@000000:CUE000000<0>E1`00@0000004MSR000000000000P17HhP00`000000EWFN
05IeWP020000000303c1R@000000000000H0I8Nc00<000000;0G7P2`5ah00P2`5ah2076Ia`030000
001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/00P2;^n/2000000@0ULSh00H0000009K;m`000000
U/_g0000001n[]42000003L0n_3V00<0000002:;EP0000000P1GjJT010000000;Hm000000000000<
0?[`iP030;0G7P3jl>H0n_3V04h0n_3V0@3oool008D0n_3V0`2`5ahN0?[`iP030;0G7P3jl>H0n_3V
00T0n_3V0P0000000`0G8CD000000000000202TiE@040000000iD700>E1`03U@L08000001017HhP0
0`000000EWFN05IeWP0205IeWP<000001P1TQk<00`000000LIW7076Ia`02076Ia`D0/1LN101nZ]X0
0`000000Rk_[08^kj`0308^kj`<000000P2Eb?P00`000000U/_g09K;m`020000000307j^d@000000
000003H0n_3V00D0/1LN0?[`iP0000008X]F0000000205OYZ@040000000]Sd00;Hm0000000X0n_3V
00<0/1LN0?[`iP3jl>H0C`3jl>H10?ooo`00P`3jl>H20;0G7R80n_3V00<0/1LN0?[`iP3jl>H0203j
l>H20000000301LQ=@000000:CUE0080:CUE00<0000003U@L00iD7000P00000504MSR0030000001F
MIh0EWFN00<0EWFN4@0000000`1nZ]X0/1LN0;0G7P030;0G7PD0Rk_[00<0000009G8n02Eb?P00`00
000309K;m`040000001n[]400000000003P0n_3V00<0000002:;EP0000000`1GjJT00`000000;Hm0
0000000:0?[`iP030;0G7P3jl>H0n_3V04l0n_3V0@3oool00800n_3V0`2`5ahU0?[`iP030;0G7P3j
l>H0n_3V00L0n_3V1000000302TiE@<0000000<0>E1`00000017HhP01017HhP00`000000EWFN0000
00030000000305IeWP000000I8Nc00D0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000OZ[J0000
00030000000307jZfP000000/1LN00@0/1LN00<0000009G8n02Eb?P00P2Eb?P01P000000U/_g09K;
m`2FboL0000007j^d@800000>03jl>H0100000008X]F02:;EP00000305OYZ@8000002@3jl>H00`2`
5ah0n_3V0?[`iP1@0?[`iP40oooo001m0?[`iP<0/1LN:@3jl>H00`2`5ah0n_3V0?[`iP060?[`iP@0
00000`0Y>ED01@000000>E1`03U@L00iD700000000@0Af>80`00000505IeWP030000001TQk<0I8Nc
00@0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000OZ[J07jZfP0307jZfP<00000102;^n/40;0G
7P0309G8n000000000000080U/_g1000000h0?[`iP040000000RReH08X]F000000@0EnVY00<00000
0?[`iP3jl>H01`3jl>H00`2`5ah0n_3V0?[`iP1@0?[`iP40oooo001k0?[`iP80/1LN;@3jl>H00`2`
5ah0n_3V0?[`iP050?[`iP80000000@05b4e0000000Y>ED0:CUE0P00000303U@L00300000017HhP0
00000080000000<0Af>80000001FMIh01@1FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0
LIW700@0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[000000020000000308^kj`000000
ULSh0080ULSh1@2`5ah4000000/0n_3V0`00000[0?[`iP040000000RReH08X]F00000080EnVY00<0
00000?[`iP3jl>H01`3jl>H00`2`5ah0n_3V0?[`iP1A0?[`iP40oooo001h0?[`iP<0/1LN6@3jl>H0
0`2`5ah0n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V00D0n_3V0P0000001P0G8CD0000002TiE@00
0000:CUE000000<0>E1`0P00000404MSR0030000001FMIh0EWFN00@0EWFN00<0000006B7/`1TQk<0
101TQk<00`000000LIW7076Ia`04076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/0
0P2;^n/2000000@0ULSh00@0000009K;m`2FboL000000`2`5ah00`000000n_3V0?[`iP050?[`iPH0
0000;03jl>H20000000402:;EP000000EnVY0;0G7Uh0n_3V0@3oool007D0n_3V0`2`5ahM0?[`iP03
0;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H0103jl>H20000000501LQ=@000000000002Ti
E@0000000P0iD703000000D0Af>800<0000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0406B7
/`030000001aVLL0LIW700@0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0308^k
j`<000000P2Eb?P01P000000U/_g09K;m`2FboL0000007j^d@8000001P3jl>H20;0G7P@00000;`3j
l>H3000000030?[`iP2`5ah0n_3V05`0n_3V0@3oool007<0n_3V0P2`5ahQ0?[`iP030;0G7P3jl>H0
n_3V01<0n_3V00<0/1LN0?[`iP3jl>H00`3jl>H20000000401LQ=@000000:CUE02TiE@<000000P0i
D7000`000000Af>804MSR00304MSR0030000001FMIh0EWFN00<0EWFN4@00000507jZfP030000002;
^n/0Rk_[00<0Rk_[00<0000009G8n02Eb?P00`00000309K;m`040000001n[]400000000000@0n_3V
0P2`5ah20?[`iP800000=@3jl>H00`2`5ah0n_3V0?[`iP1K0?[`iP40oooo001V0?[`iP030000003j
l>H0n_3V00L0n_3V0`2`5ahT0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP0000000P3j
l>H0100000005b4e00000000000202TiE@030000000iD700>E1`0080>E1`00<0000004MSR017HhP0
0`17HhP00`000000EWFN000000030000000305IeWP000000I8Nc00D0I8Nc00<00000076Ia`1aVLL0
101aVLL00`000000OZ[J000000030000000307jZfP000000Rk_[00@0Rk_[00<0000009G8n02Eb?P0
0P2Eb?P010000000U/_g09K;m`2FboL4000000040?[`iP2`5ah0/1LN0;0G7P@0n_3V00<000000?[`
iP3jl>H06P3jl>H00`000000n_3V0?[`iP0H0?[`iP030;0G7P3jl>H0n_3V05X0n_3V0@3oool006D0
n_3V100000040?[`iP<0/1LN9`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP050000002`5ah0D]fN0000
003jl>H00P0000000`0G8CD0000002TiE@02000000@0>E1`00<0000004MSR017HhP00P17HhP30000
00D0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001nZ]X0OZ[J
00<0OZ[J0`00000408^kj`030000002Eb?P0ULSh0080ULSh0P00000209K;m`@0000000<0/1LN0?[`
iP3jl>H08P3jl>H3000001T0n_3V00<0/1LN0?[`iP3jl>H0F@3jl>H10?ooo`00H`3jl>H500000003
046nQ0000000n_3V0080/1LN:`3jl>H00`2`5ah0n_3V0?[`iP020?[`iP80/1LN3P3jl>H200000003
0;0G7P000000n_3V0080000000D05b4e000000000000:CUE0000000403U@L00300000017HhP00000
0080000000<0Af>80000001FMIh01@1FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW7
00@0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[000000020000000308^kj`000000ULSh
00<0ULSh00H0000009K;m`000000U/_g0000001n[]42000002H0n_3V0`00000I0?[`iP030;0G7P3j
l>H0n_3V05P0n_3V0@3oool00680n_3V00@00000000_0@00;`4000000P11_X@30;0G7QP0n_3V00<0
/1LN0?[`iP3jl>H04`3jl>H40;0G7Q00n_3V0`0000000`1QokX000000000000201LQ=@80000000<0
:CUE0000000iD7000`0iD702000000@0Af>800@0000005IeWP1FMIh0EWFN1P00000406B7/`030000
001aVLL0LIW700@0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0208^kj`800000
102Eb?P00`000000U/_g09K;m`020000000307j^d@000000000002H0n_3V1@00000G0?[`iP030;0G
7P3jl>H0n_3V05P0n_3V0@3oool00640n_3V00<00000000_0@0000000P0000020;0G7P03046nQ000
0000000001T0n_3V00<0/1LN0?[`iP3jl>H04@3jl>H30;0G7Q@0n_3V1000000201LQ=@040000000Y
>ED0:CUE00000080>E1`0`00000304MSR0`00000101TQk<00`000000LIW7076Ia`04076Ia`030000
001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/00`2;^n/300000080ULSh00H0000009K;m`2FboL0
U/_g0000001n[]42000001/0n_3V1@0000060?[`iP80000000<0EnRX0000000`Td@00P00000F0?[`
iP030;0G7P3jl>H0n_3V05L0n_3V0@3oool005l0n_3V1000000302bLI`<0000000<0350D0000003j
l>H06@3jl>H00`2`5ah0n_3V0?[`iP0=0?[`iP<0/1LN0`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP80
000000<05b4e0000000000000P0Y>ED300000080>E1`00<0000004MSR017HhP00`17HhP4000000D0
=9mP4000000307jZfP030000002;^n/0Rk_[00<0Rk_[00<0000009G8n02Eb?P00`00000309K;m`04
0000001n[]400000000001H0n_3V2@0000080?[`iP80000000D0EnRX0000000`Td@0<9=40000000F
0?[`iP030;0G7P3jl>H0n_3V05H0n_3V0@3oool005h0n_3V0`00000502bLI`040000000<D1@0350D
000001`0n_3V00<0/1LN0?[`iP3jl>H02@3jl>H30;0G7PL0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H2
0000000501LQ=@000000:CUE02TiE@000000100iD7000`000000Af>804MSR00304MSR0030000001F
MIh0000000D0000000@0=9mP0;0G7P2`5ah0/1LN0P1TQk<00`000000LIW7076Ia`04076Ia`040000
001nZ]X0OZ[J07jZfP@000001@2;^n/00`000000ULSh09G8n00209G8n0040000002FboL0U/_g09K;
m`@000005P3jl>H00`0000004elQ0000000200000003042kP0000000n_3V00T0n_3V00L00000026:
E@000000EnRX0000000`Td@0000001H0n_3V00<0/1LN0?[`iP3jl>H0EP3jl>H10?ooo`00G@3jl>H2
000000D0;9aW1P00000M0?[`iP030;0G7P3jl>H0n_3V00H0n_3V0P2`5ah;0?[`iP030;0G7P3jl>H0
n_3V0180n_3V0`00000202TiE@800000100iD7000`000000Af>804MSR00204MSR0<000000`1FMIh2
0000000303c1RP00000000000080I8Nc1P2`5ah3076Ia`030000001nZ]X0OZ[J00@0OZ[J0`000003
08^kj`030000002Eb?P0ULSh0080ULSh0P00000209K;m`@000005P3jl>H20;0G7P80@;^00P00000;
0?[`iP030000000QRUD000000080EnRX0P00000G0?[`iP030;0G7P3jl>H0n_3V05D0n_3V0@3oool0
05/0n_3V0P0000000`0/W6L000000000000600000240n_3V00<0/1LN0?[`iP3jl>H00`3jl>H30;0G
7Ph0n_3V00<0/1LN0?[`iP3jl>H04@3jl>H01`0000005b4e0000000Y>ED0000002TiE@000000100i
D7000`000000Af>8000000020000000304MSR0000000EWFN00D0EWFN0P00000506B7/`040000001a
VLL0LIW7076Ia`H0/1LN101nZ]X00`000000Rk_[08^kj`020000000308^kj`000000ULSh00<0ULSh
00H0000009K;m`000000U/_g0000001n[]42000001<0n_3V0`2`5ah00`000000@;^0000000020000
00d0n_3V00<00000026:E@0000000P1Gj:P00`000000n_3V0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V
05@0n_3V0@3oool005X0n_3V1000000D0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP2`
5ah00P2`5ahA0?[`iP030;0G7P3jl>H0n_3V0140n_3V00@0000001LQ=@00000000000P0Y>ED00`00
0000>E1`03U@L00203U@L08000001017HhP00`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc
00@0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000OZ[J07jZfP060;0G7P<0Rk_[0P00000409G8
n0030000002FboL0U/_g0080000000<0OZkA000000000000403jl>H30;0G7P@0n_3V0P00000?0?[`
iP<0000000<0EnRX0;0G7P3jl>H06@3jl>H00`2`5ah0n_3V0?[`iP1C0?[`iP40oooo001c0?[`iP03
0;0G7P3jl>H0n_3V0180n_3V0P2`5ahE0?[`iP030;0G7P3jl>H00000008000003@3jl>H200000003
01LQ=@000000:CUE0080:CUE00<0000003U@L00iD7000`00000504MSR0030000001FMIh0EWFN00@0
EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001nZ]X0OZ[J00@0
OZ[J00<0000008^kj`2`5ah01@2`5ah010000000ULSh09G8n000000309K;m`040000001n[]400000
000000d0n_3V0`2`5ahJ0?[`iP80000000<0n_3V0;0G7P3jl>H0603jl>H00`2`5ah0n_3V0?[`iP1C
0?[`iP40oooo001d0?[`iP030;0G7P3jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H01`3jl>H30;0G
7P80n_3V00<0/1LN0?[`iP3jl>H04`3jl>H0102`5ah0D]bM00000000000=0?[`iP@000000`0Y>ED3
00000080>E1`00<0000004MSR017HhP00`17HhP00`000000EWFN05IeWP0305IeWQ<000000`1nZ]X0
0`000000Rk_[08^kj`0308^kj`030000002Eb?P0/1LN0080/1LN00@0000009K;m`2FboL0U/_g0P00
00000`1n[]4000000?[`iP0:0?[`iP80/1LN803jl>H00`2`5ah0n_3V0?[`iP0H0?[`iP030;0G7P3j
l>H0n_3V0580n_3V0@3oool007D0n_3V00@0/1LN0?[`iP3jl>H0n_3V100000050?[`iP<0/1LN1P3j
l>H00`2`5ah0n_3V0?[`iP0B0?[`iP030000002`5ah0D]bM00800000303jl>H4000000<0:CUE00<0
000003U@L00iD7000P0iD7000`000000Af>804MSR00304MSR0030000001FMIh0000000<0000000<0
EWFN0000001TQk<01@1TQk<00`000000LIW7076Ia`04076Ia`040000001nZ]X0OZ[J07jZfP@00000
1@2;^n/00`000000ULSh09G8n00209G8n0040000002FboL0U/_g09K;m`80000000<0OZkA0000003j
l>H01`3jl>H30;0G7R00n_3V0`0000000`2`5ah000000000000H0?[`iP030;0G7P3jl>H0n_3V0540
n_3V0@3oool007H0n_3V00@0/1LN0?[`iP00000003810P0000001011_X@000000?[`iP3jl>H20;0G
7PX0n_3V00<0/1LN0?[`iP3jl>H04@3jl>H2000000030;0G7P1QokX0000000`0n_3V0P000000100G
8CD0000002TiE@0Y>ED2000000@0>E1`00<0000004MSR017HhP00P17HhP3000000D0EWFN00<00000
06B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001nZ]X0OZ[J00@0OZ[J0`000003
08^kj`030000002Eb?P0ULSh0080ULSh0P00000209K;m`040000001n[]400000000000D0n_3V0`2`
5ah<0?[`iP030000003jl>H0n_3V00h0n_3V1P0000001@0DH2<00000000000000000/1LN01X0n_3V
00<0/1LN0?[`iP3jl>H0D03jl>H10?ooo`00M`3jl>H0100000000381000000000002046nQ0<0/1LN
3@3jl>H00`2`5ah0n_3V0?[`iP0A0?[`iPD000002`3jl>H20000000601LQ=@000000:CUE0000000Y
>ED00000100iD7000`000000Af>8000000020000000304MSR0000000EWFN00D0EWFN00<0000006B7
/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^k
j`2;^n/00P0000000`2;^n/0000009G8n00309G8n0050000002FboL0000009K;m`0000000P1n[]40
0`000000n_3V0?[`iP030;0G7Pl0n_3V0`00000>0?[`iP030000000DH2<0560S0080560S10000002
0?[`iP030;0G7P3jl>H0n_3V01L0n_3V00<0/1LN0?[`iP3jl>H0D03jl>H10?ooo`00M@3jl>H40000
0080;IaW0P2`5ah2000000l0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H3000000<0n_3V0P2`5ah60?[`
iP80000000<05b4e0000000000000P0Y>ED00`000000>E1`03U@L00203U@L08000001017HhP00`00
0000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL00`00
0000OZ[J07jZfP0407jZfP030000002;^n/0Rk_[0080Rk_[0P00000409G8n0030000002FboL0U/_g
008000000P1n[]400`000000/1LN0;0G7P0C0?[`iP@00000303jl>H00`000000560S000000020000
000303nkP0000000000000<0n_3V00<0/1LN0?[`iP3jl>H0603jl>H00`2`5ah0n_3V0?[`iP1?0?[`
iP40oooo001d0?[`iP<00000100]W6L00`0000003E8F0000000A0?[`iP030;0G7P3jl>H0n_3V01<0
n_3V00@000000;0G7P2`5ah0/1LN203jl>H20000000301LQ=@000000:CUE0080:CUE00<0000003U@
L00iD7000`00000504MSR0030000001FMIh0EWFN00@0EWFN00<0000006B7/`1TQk<0101TQk<00`00
0000LIW7076Ia`04076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/00`2;^n/30000
0080ULSh00D0000009K;m`2FboL0U/_g0000000207j^d@800000503jl>H6000000T0n_3V0P2`5ah0
0`000000?k^003nkP002000000H0n_3V00<0/1LN0?[`iP3jl>H0603jl>H00`2`5ah0n_3V0?[`iP1>
0?[`iP40oooo001b0?[`iP<000000P0]W6L700000180n_3V00<0/1LN0?[`iP3jl>H04@3jl>H20;0G
7P/0n_3V1000000302TiE@<000000P0iD7000`000000Af>804MSR00304MSR0030000001FMIh0EWFN
00<0EWFN4`00000307jZfP030000002;^n/0Rk_[00<0Rk_[00<0000009G8n02Eb?P00`00000309K;
m`80000000<0OZkA000000000000503jl>H200000080EnNW00<0000003:HB00000001@3jl>H30;0G
7P030?[`iP000000?k^000<00000203jl>H00`2`5ah0n_3V0?[`iP0G0?[`iP030;0G7P3jl>H0n_3V
04h0n_3V0@3oool00740n_3V1`0000030?[`iP030;0G7P3jl>H0n_3V0180n_3V00<0/1LN0?[`iP3j
l>H03P3jl>H30;0G7Pd0n_3V1000000302TiE@030000000iD700>E1`0080>E1`00<0000004MSR017
HhP00`17HhP00`000000EWFN000000030000000305IeWP000000I8Nc00D0I8Nc00<00000076Ia`1a
VLL0101aVLL010000000OZ[J07jZfP1nZ]X4000000D0Rk_[00<0000009G8n02Eb?P00P2Eb?P01000
0000U/_g09K;m`2FboL20000000307j^d@000000000001D0n_3V0P00000205OWY`8000000P3jl>H3
0;0G7PD0n_3V0P00000;0?[`iP030;0G7P3jl>H0n_3V01L0n_3V00<0/1LN0?[`iP3jl>H0C@3jl>H1
0?ooo`00O03jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP040;0G7P3jl>H0n_3V000000T0n_3V0`2`5ah@
0?[`iP80000000@05b4e0000000Y>ED0:CUE0P00000403U@L00300000017HhP0Af>80080Af>80`00
000505IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000OZ[J07jZ
fP0407jZfP<000000`2;^n/00`000000ULSh09G8n00209G8n08000000P2FboL00`000000OZkA0000
0002000001D0n_3V00<000000269E00000000P1GijL00`000000/1LN0;0G7P0E0?[`iP030;0G7P3j
l>H0n_3V01P0n_3V00<0/1LN0?[`iP3jl>H0C03jl>H10?ooo`00O@3jl>H00`2`5ah0n_3V0?[`iP0B
0?[`iP030;0G7P000000DM^L008000001@3jl>H20;0G7Q<0n_3V0P0000001P0G8CD0000002TiE@00
0000:CUE000000@0>E1`00<0000004MSR00000000P0000001017HhP0000005IeWP1FMIh900000080
I8Nc00<00000076Ia`1aVLL0101aVLL00`000000OZ[J07jZfP0407jZfP030000002;^n/0Rk_[0080
000000<0Rk_[0000002Eb?P00`2Eb?P00`000000U/_g0000000200000080OZkA0P00000F0?[`iP80
000000<0EnNW0;0G7P3jl>H0603jl>H00`2`5ah0n_3V0?[`iP040?[`iPL000003@3jl>H00`2`5ah0
n_3V0?[`iP1;0?[`iP40oooo001n0?[`iP030;0G7P3jl>H0n_3V0140n_3V00<000000;0G7P1Afi`0
0`000000103jl>H0/1LN0;0G7P2`5ahE0?[`iP80000000<05b4e0000000000000P0Y>ED00`000000
>E1`03U@L00203U@L08000001017HhP00`000000EWFN05IeWP0205IeWP@0000000H0=9mP0;0G7P2`
5ah0/1LN06B7/`000006076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/00P2;^n/2
000000@0ULSh00D0000009K;m`2FboL0U/_g0000000207j^d@8000004`3jl>H30;0G7P<0000000<0
n_3V0;0G7P3jl>H05`3jl>H00`000000/1LN0000000400000080568T1000000>0?[`iP030;0G7P3j
l>H0n_3V04/0n_3V0@3oool007l0n_3V00<0/1LN0?[`iP3jl>H03@3jl>H2000000050?[`iP000000
00000;0G7P1Afi`00`2`5ahH0?[`iP80000000<05b4e0000000Y>ED00P0Y>ED00`000000>E1`03U@
L003000000D0Af>800<0000005IeWP1FMIh0101FMIh400000080I8Nc1@2`5ah3076Ia`030000001n
Z]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/00`2;^n/3000000<0ULSh00<0000009K;m`2FboL00P00
00000`1n[]4000000000000@0?[`iP<0/1LN1`3jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP030000000D
HR@0/1LN0080568T1P00000A0?[`iP030;0G7P3jl>H0n_3V04X0n_3V0@3oool00800n_3V00<0/1LN
0?[`iP3jl>H02P3jl>H4000000030?[`iP000000?JYM0080/1LN00<0HOnj000000000000603jl>H4
000000<0:CUE0`00000203U@L00300000017HhP0Af>800<0Af>800<0000005IeWP1FMIh00`1FMIh<
000000H0/1LN00D0000007jZfP1nZ]X0OZ[J0000000508^kj`030000002Eb?P0ULSh0080000000@0
ULSh0000002FboL0U/_g0P0000000`1n[]4000000000000=0?[`iP<0/1LN2`3jl>H00`2`5ah0n_3V
0?[`iP0E0?[`iP030000000DHR@0/1LN008000000`0o^Wl2000005l0n_3V0@3oool00840n_3V00<0
/1LN0?[`iP3jl>H0203jl>H01@0000000C@2000000000000@Kj400<0/1LN00D00000067o^P1QokX0
HOnj0000000H0?[`iP@000000`0Y>ED00`000000>E1`03U@L00203U@L00300000017HhP0Af>800<0
Af>800<0000005IeWP0000000`0000000`1FMIh0000006B7/`0506B7/`030000001aVLL0LIW700@0
LIW700<0000007jZfP1nZ]X01@2`5ah508^kj`030000002Eb?P0ULSh0080ULSh0P00000209K;m`03
0000001n[]400000008000002P3jl>H30;0G7Pl0n_3V00<0/1LN0?[`iP3jl>H0503jl>H200000004
03njO`2`5ah0?kYo03njO`800000H@3jl>H10?ooo`00PP3jl>H00`2`5ah0n_3V0?[`iP050?[`iP@0
000000@0;IeX0;0G7P2`5ah000000`3jl>H200000003067o^P000000000001L0n_3V0P000000100G
8CD0000002TiE@0Y>ED2000000@0>E1`00<0000004MSR017HhP00P17HhP3000000D0EWFN00<00000
06B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001nZ]X0OZ[J00@0OZ[J00@00000
0;0G7P2`5ah0/1LN0P2;^n/00`000000ULSh09G8n00309G8n080000000@0U/_g0000001n[]40OZkA
0P0000080?[`iP80/1LN4`3jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP80/1LN0`0o^Wl00`2`5ah00000
0?[`iP1R0?[`iP40oooo00230?[`iP030;0G7P3jl>H0n_3V0080n_3V2P0000050?[`iP<000005`3j
l>H20000000601LQ=@000000:CUE0000000Y>ED00000100iD7000`000000Af>80000000200000003
04MSR0000000EWFN00D0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`03
0000001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/00P0000000`2;^n/0000009G8n00409G8n004
0000002FboL0000000000080OZkA0P00000M0?[`iP030;0G7P3jl>H0n_3V00l0n_3V0`2`5ah20?[`
iP@0000000<0/1LN0?[`iP3jl>H0H@3jl>H10?ooo`00Q03jl>H00`2`5ah0n_3V0?[`iP0;000000L0
n_3V0P00000F0?[`iP80000000<05b4e0000000000000P0Y>ED00`000000>E1`03U@L00203U@L080
00001017HhP00`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1a
VLL0101aVLL00`000000OZ[J07jZfP0407jZfP030000002;^n/0Rk_[0080Rk_[0P00000509G8n004
0000002FboL0U/_g00000080OZkA0P0000030?[`iP030000003jl>H0n_3V01P0n_3V00<0/1LN0?[`
iP3jl>H02`3jl>H30;0G7PD0n_3V0P0000020?[`iP030;0G7P3jl>H0n_3V0640n_3V0@3oool008D0
n_3V00<0/1LN0?[`iP3jl>H0:@3jl>H20000000601LQ=@000000/1LN0;0G7P0Y>ED000000P0iD703
000000D0Af>800<0000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0
LIW700@0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0308^kj`<000000`2Eb?P0
0`000000U/_g09K;m`020000000307j^d@000000000000<0n_3V0`00000I0?[`iP030;0G7P3jl>H0
n_3V00H0n_3V102`5ah=0?[`iP030;0G7P3jl>H0n_3V0600n_3V0@3oool008H0n_3V00<0/1LN0?[`
iP0000000P00000V0?[`iP040000002`5ah0/1LN0;0G7P<0:CUE0`00000203U@L00300000017HhP0
Af>800<0Af>800<0000005IeWP1FMIh00`1FMIhA000000D0OZ[J00<0000008^kj`2;^n/00`2;^n/0
0`000000ULSh09G8n0020000000409G8n0000000U/_g09K;m`80000000<0OZkA000000000000103j
l>H4000001P0n_3V00<0/1LN0?[`iP3jl>H00P3jl>H30;0G7Q80n_3V00<0/1LN0?[`iP3jl>H0G`3j
l>H10?ooo`00QP3jl>H00`000000/1LN057KW003000002@0n_3V0P2`5ah3000000<0:CUE00<00000
03U@L00iD7000P0iD7000`000000Af>804MSR00304MSR0030000001FMIh0000000<0000000<0EWFN
0000001TQk<01@1TQk<00`000000LIW7076Ia`04076Ia`030000001nZ]X0000000<0000000<0OZ[J
0000002;^n/0102;^n/00`000000ULSh09G8n00209G8n08000000P2FboL00`000000OZkA00000002
000000@0n_3V0P0000000`1FiZH000000000000G0?[`iP030;0G7P3jl>H0/1LN0080/1LNM`3jl>H1
0?ooo`00Q@3jl>H01@000000DM^L057KW02`5ah0DM^L008000008@3jl>H30;0G7P050?[`iP000000
000001LQ=@0000000P0Y>ED2000000@0>E1`00<0000004MSR017HhP00P17HhP3000000D0EWFN00<0
000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04076Ia`030000001nZ]X0OZ[J00<0OZ[J0`00
000508^kj`030000002Eb?P0ULSh0080ULSh0P00000209K;m`040000001n[]400000000000D0n_3V
0P0000000`1FiZH000000?[`iP0E0?[`iP<0/1LNNP3jl>H10?ooo`00Q@3jl>H300000005057KW02`
5ah0000002bL@@0000007@3jl>H30;0G7P@0n_3V0P0000001P0G8CD0000002TiE@000000:CUE0000
00@0>E1`00<0000004MSR00000000P0000000`17HhP0000005IeWP0505IeWP030000001TQk<0I8Nc
00@0I8Nc00<00000076Ia`1aVLL0101aVLL00`000000OZ[J07jZfP0407jZfP030000002;^n/00000
00<0000000<0Rk_[0000002Eb?P00`2Eb?P00`000000U/_g000000020000000307j^d@0000000000
00D0n_3V0P0000000`2`5ah0n_3V0?[`iP0B0?[`iP<0/1LN0`3jl>H00`2`5ah0n_3V0?[`iP1g0?[`
iP40oooo00250?[`iP80000000@0?Z]O000000000000H?nj0P00000F0?[`iP030000003jl>H0n_3V
0080n_3V0P2`5ah70?[`iP80000000<05b4e0000000000000P0Y>ED00`000000>E1`03U@L00203U@
L08000001017HhP00`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076I
a`1aVLL0101aVLL00`000000OZ[J07jZfP0407jZfP030000002;^n/0Rk_[00<0Rk_[0P00000409G8
n0060000002FboL0U/_g09K;m`000000OZkA0P0000080?[`iP030;0G7P3jl>H0n_3V00d0n_3V102`
5ah70?[`iP030;0G7P3jl>H0n_3V07H0n_3V0@3oool008H0n_3V0`000003063o^P8000004`3jl>H3
000000040?[`iP2`5ah0/1LN0;0G7PT0n_3V0P0000000`0G8CD0000002TiE@0202TiE@030000000i
D700>E1`00<000001@17HhP00`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<0
0000076Ia`1aVLL0101aVLL00`000000OZ[J07jZfP0407jZfP030000002;^n/0Rk_[00@0Rk_[0`00
000209G8n0060000002FboL0U/_g09K;m`000000OZkA0P0000090?[`iP030;0G7P3jl>H0n_3V00T0
n_3V0`2`5ah;0?[`iP030;0G7P3jl>H0n_3V07H0n_3V0@3oool008P0n_3V0`0000000`1PokX00000
0000000A0?[`iP80000000@0;IeX0000002`5ah0/1LN303jl>H4000000<0:CUE0`00000203U@L003
00000017HhP0Af>800<0Af>800<0000005IeWP1FMIh00`1FMIhA000000D0OZ[J00<0000008^kj`2;
^n/0102;^n/00`000000ULSh09G8n003000000<0U/_g1000000:0?[`iP030;0G7P3jl>H0n_3V00D0
n_3V0`2`5ah?0?[`iP030;0G7P3jl>H0n_3V07D0n_3V0@3oool008X0n_3V1@00000>0?[`iPP00000
303jl>H4000000<0:CUE00<0000003U@L00iD7000P0iD7000`000000Af>804MSR00304MSR0030000
001FMIh0000000<0000000<0EWFN000000000000100000000`1TQk<00000076Ia`05076Ia`030000
001nZ]X0000000<0000000<0OZ[J0000002;^n/01@2;^n/00`000000ULSh09G8n00209G8n0040000
002FboL0U/_g09K;m`@000002`3jl>H00`2`5ah0n_3V0?[`iP020?[`iP80/1LN4`3jl>H00`2`5ah0
n_3V0?[`iP1d0?[`iP40oooo001I0?[`iP030;0G7P3jl>H0n_3V0300n_3V0`00000R0?[`iP800000
00@05b4e0000000Y>ED0:CUE0P00000403U@L00300000017HhP0Af>80080Af>80`00000505IeWP03
0000001TQk<00000008000000`2`5ah6076Ia`030000001nZ]X0OZ[J00<0OZ[J0`00000508^kj`03
0000002Eb?P0ULSh0080ULSh0P00000209K;m`040000001n[]400000000000/0n_3V00<0/1LN0?[`
iP3jl>H0SP3jl>H10?ooo`00F@3jl>H00`2`5ah0n_3V0?[`iP0b0?[`iP8000008@3jl>H200000006
01LQ=@000000:CUE0000000Y>ED00000100iD7000`000000Af>8000000020000000304MSR0000000
EWFN00D0EWFN00@0000006B7/`1TQk<0I8Nc0P0000000`1TQk<000000;0G7P070;0G7PD0OZ[J00<0
000008^kj`0000000`0000000`2;^n/0000009G8n00309G8n0030000002FboL000000080000000<0
OZkA000000000000303jl>H00`2`5ah0n_3V0?[`iP2=0?[`iP40oooo001H0?[`iP030;0G7P3jl>H0
n_3V05H0n_3V0P0000000`0G8CD000000000000202TiE@030000000iD700>E1`0080>E1`0P000004
04MSR0030000001FMIh0EWFN00@0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04
076Ia`040000001nZ]X0/1LN0;0G7P<0OZ[J00<0000008^kj`2;^n/00`2;^n/2000000@0ULSh00H0
000009K;m`2FboL0U/_g0000001n[]42000000d0n_3V00<0/1LN0?[`iP3jl>H0S03jl>H10?ooo`00
F03jl>H00`2`5ah0n_3V0?[`iP1F0?[`iP80000000<05b4e0000000Y>ED00P0Y>ED00`000000>E1`
03U@L003000000<0Af>800<0/1LN04MSR00000001P1FMIh00`000000I8Nc06B7/`0406B7/`030000
001aVLL0LIW700@0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0408^kj`<00000
0P2Eb?P01P000000U/_g09K;m`2FboL0000007j^d@8000003P3jl>H00`2`5ah0n_3V0?[`iP2;0?[`
iP40oooo001H0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H0?P3jl>H010000000
5b4e00000000000302TiE@<000000P0iD70010000000Af>80;0G7P2`5ah204MSR0030000001FMIh0
EWFN00@0EWFN00@0000006B7/`1TQk<0I8Nc3000000507jZfP030000002;^n/0Rk_[00@0Rk_[1P00
000309K;m`@000003`3jl>H00`2`5ah0n_3V0?[`iP2:0?[`iP40oooo001G0?[`iP030;0G7P3jl>H0
n_3V01H0n_3V00<0/1LN0?[`iP3jl>H0?P3jl>H20000000301LQ=@000000:CUE0080:CUE00<00000
03U@L00iD7000P0iD7020;0G7P@0Af>800@0000005IeWP1FMIh0EWFN1`00000306B7/`030000001a
VLL0LIW700@0LIW700<0000007jZfP0000000`0000000`1nZ]X0000008^kj`0508^kj`060000002E
b?P0000005KUY@2`5ah000000`2FboL400000100n_3V00<0/1LN0?[`iP3jl>H0R@3jl>H10?ooo`00
E`3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V03l0n_3V0P0000000`0G8CD00000
02TiE@03000000@0/1LN00<0000004MSR017HhP00P17HhP5000000<0EWFN00<0000006B7/`1TQk<0
101TQk<00`000000LIW7076Ia`04076Ia`030000001nZ]X0OZ[J00<0OZ[J0`00000508^kj`070000
002Eb?P000000000002Eb?P0/1LN0000000209K;m`040000001n[]400000000009`0n_3V0@3oool0
05L0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0?[`iP0o0?[`iP030000000G8CD05b4e
008000000`2`5ah403U@L00300000017HhP000000080000000<0Af>80000001FMIh01@1FMIh00`00
0000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007jZfP1nZ]X0101nZ]X00`00
0000Rk_[000000030000000308^kj`000000ULSh00<0ULSh00H0/1LN09K;m`000000U/_g0000001n
[]42000006L0n_3V00<000000?[`iP3jl>H0<P3jl>H10?ooo`00E`3jl>H00`2`5ah0n_3V0?[`iP0D
0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H09`3jl>H8000000D0>E1`0P000004
04MSR0030000001FMIh0EWFN00@0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`04
076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/00`2;^n/2000000@0ULSh00<00000
0;0G7P2FboL00P0000000`1n[]4000000000001V0?[`iP800000=03jl>H10?ooo`00EP3jl>H00`2`
5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H09`3jl>H20000
00805b4e00@0000002TiE@0Y>ED000000`0iD703000000D0Af>800<0000005IeWP1FMIh0101FMIh0
0`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007jZfP1nZ]X0101nZ]X0
0`000000Rk_[08^kj`0408^kj`<000000P2Eb?P01P000000U/_g0;0G7P2FboL0000007j^d@800000
CP3jl>H00`000000n_3V0?[`iP0C0?[`iP@00000=03jl>H10?ooo`00EP3jl>H00`2`5ah0n_3V0?[`
iP0E0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0:03jl>H20000000301LQ=@00
000000000080:CUE00@0000003U@L000000000000P0iD7000`000000Af>804MSR00304MSR0030000
001FMIh0EWFN00@0EWFN00@0000006B7/`1TQk<0I8Nc1`000003076Ia`030000001nZ]X0OZ[J00D0
OZ[J00<0000008^kj`2;^n/00`2;^n/00`000000ULSh09G8n00300000080U/_g00<0/1LN0000001n
[]400P00001<0?[`iP<00000503jl>H0100000004fD_00000000000e0?[`iP40oooo001F0?[`iP03
0;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0?[`iP0X0?[`iP<0
000000@05b4e0000000Y>ED0:CUE0P00000403U@L00300000017HhP0Af>800<0Af>800@0000005Ie
WP1FMIh0EWFN1`00000306B7/`040000001aVLL0LIW7076Ia`L00000101nZ]X00`000000Rk_[08^k
j`0308^kj`030000002Eb?P0ULSh0080ULSh00@0000009K;m`2FboL0/1LN1000001;0?[`iP<00000
503jl>H01@0000004fD_0000001>gZ<0000003D0n_3V0@3oool005D0n_3V00<0/1LN0?[`iP3jl>H0
5@3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H0
4@3jl>H400000080:CUE0P00000403U@L00300000017HhP0Af>800<0Af>81@00000305IeWP030000
001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL0101aVLL010000000OZ[J07jZfP1nZ]X6000000@0
Rk_[00<0000009G8n02Eb?P00P2Eb?P200000080U/_g00@0/1LN0000000000000000=@3jl>H00`00
0000n_3V0?[`iP0B0?[`iP@000004P3jl>H20000000301=U;`000000C]jS00800000=@3jl>H10?oo
o`00E@3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3j
l>H05@3jl>H00`2`5ah0n_3V0?[`iP0A0?[`iP80000000H05b4e0000000Y>ED0000002TiE@000004
03U@L00400000017HhP0Af>804MSR080000000<0Af>80000001FMIh01@1FMIh00`000000I8Nc06B7
/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007jZfP1nZ]X01@1nZ]X00`000000Rk_[0000
00020000000308^kj`000000ULSh00<0ULSh00H0000009K;m`000000U/_g0000001n[]42000003@0
n_3V0P00000B0?[`iP<0000000<04V<^0000000000004@3jl>H2000000804fD_00@0000004kNX`00
00000000=@3jl>H10?ooo`00E@3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V01D0
n_3V00<0/1LN0?[`iP3jl>H0503jl>H00`2`5ah0n_3V0?[`iP0B0?[`iP80000000<05b4e00000000
00000P0Y>ED00`000000>E1`03U@L00203U@L00400000017HhP00000000000<0Af>800<0000005Ie
WP1FMIh0101FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700@0LIW700<0000007jZ
fP1nZ]X01@1nZ]X00`000000Rk_[08^kj`0208^kj`800000102Eb?P00`000000U/_g09K;m`020000
000307j^d@00000000000380n_3V1000000A0?[`iP8000000P0BHbh300000100n_3V00D0000001=U
;`0CIBl04fD_0000000204kNX`030000003jl>H0n_3V03@0n_3V0@3oool005@0n_3V00<0/1LN0?[`
iP3jl>H05@3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`
iP3jl>H04P3jl>H010000000/1LN01LQ=@00000302TiE@030000000iD700>E1`0080>E1`0P000005
04MSR0030000001FMIh0EWFN00@0EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`05
076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/00`2;^n/300000080ULSh00H00000
09K;m`2FboL0U/_g0000001n[]42000001`0n_3V00<000000?[`iP3jl>H04P3jl>H400000140n_3V
0P000002019S;P030000001>gZ<000000100n_3V00D0000001=U;`0CIBl04fD_0000000204kNX`80
0000=P3jl>H10?ooo`00E03jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V01D0n_3V
00<0/1LN0?[`iP3jl>H0503jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP040000002`5ah00000000000<0
:CUE00<0000003U@L00iD7000`00000604MSR0030000001FMIh0EWFN00@0EWFN00<0000006B7/`1T
Qk<0101TQk<00`000000LIW7076Ia`05076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;
^n/00`2;^n/00`000000ULSh09G8n003000000<0U/_g0P0000000`1n[]4000000?[`iP0I0?[`iP<0
00004`3jl>H00`0000004F8]0000000200000140n_3V00L00000019S;P0BHbh04V<^0000001>gZ<0
00000140n_3V00<0000001=U;`0000000`1>gZ<2000003H0n_3V0@3oool005@0n_3V00<0/1LN0?[`
iP3jl>H0503jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`
iP3jl>H04`3jl>H010000000/1LN00000000000302TiE@<000000P0iD7000`000000Af>804MSR004
04MSR0030000001FMIh0EWFN00<0EWFN4P00000507jZfP030000002;^n/0Rk_[00<0Rk_[00<00000
09G8n02Eb?P00P2Eb?P010000000U/_g09K;m`2FboL20000000307j^d@000000n_3V0080n_3V00<0
00000?[`iP3jl>H04`3jl>H3000001<0n_3V00@00000015R;@000000C]fS0P00000B0?[`iP030000
000BHbh000000080C]jS00<000000?[`iP3jl>H03`3jl>H00`0000004fD_0000000304kNX`030000
003jl>H0n_3V03D0n_3V0@3oool005<0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0?[`
iP0D0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0503jl>H0102`5ah0000001LQ
=@00000302TiE@030000000iD700>E1`0080>E1`00<0000004MSR017HhP01017HhP00`000000EWFN
000000030000000305IeWP000000I8Nc00D0I8Nc00<00000076Ia`1aVLL01@1aVLL00`000000OZ[J
000000030000000307jZfP000000Rk_[00@0Rk_[00<0000009G8n02Eb?P00P2Eb?P200000080U/_g
00@0000007j^d@00000000000P3jl>H2000001@0n_3V00@00000015Q;000000000004`3jl>H01000
00004F8]0000001>gJ<200000180n_3V00D00000019S;P000000C]jS0000000C0?[`iP8000000P1>
gZ<2000003L0n_3V0@3oool005<0n_3V00<0/1LN0?[`iP3jl>H0503jl>H00`2`5ah0n_3V0?[`iP0E
0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0503jl>H0102`5ah0000001LQ=@00
000202TiE@800000100iD7000`000000Af>804MSR00304MSR0<000001@1FMIh00`000000I8Nc06B7
/`0406B7/`030000001aVLL0LIW700D0LIW700<0000007jZfP1nZ]X00`1nZ]X3000000@0Rk_[00<0
000009G8n02Eb?P00P2Eb?P01@000000U/_g0000002FboL000000080OZkA00<000000?[`iP000000
0P00000D0?[`iP040000000AHB`00000000001@0n_3V00@0/1LN04kMX`0000000000503jl>H0102`
5ah0000000000000000B0?[`iP030;0G7P3jl>H0n_3V00<00000>03jl>H10?ooo`00D`3jl>H00`2`
5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0503jl>H00`2`
5ah0n_3V0?[`iP0D0?[`iP040;0G7P000000000001LQ=@<0000000<0:CUE0000000iD7000`0iD700
0`000000Af>8000000030000000304MSR0000000EWFN00D0EWFN00<0000006B7/`1TQk<0101TQk<0
0`000000LIW7076Ia`05076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^kj`0000000P000000
0`2;^n/0000009G8n00309G8n0030000002FboL0U/_g008000000P1n[]400`000000n_3V0;0G7P02
000001D0n_3V00<0/1LN0000003jl>H04`3jl>H0102`5ah0n_3V00000000000D0?[`iP030;0G7P3j
l>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0>`3jl>H10?ooo`00DP3jl>H00`2`5ah0n_3V0?[`iP0E
0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0503jl>H00`2`5ah0n_3V0?[`iP0D
0?[`iP050;0G7P000000000001LQ=@0000000`0Y>ED00`000000>E1`03U@L00203U@L08000001@17
HhP00`000000EWFN05IeWP0405IeWP030000001TQk<0I8Nc00@0I8Nc00<00000076Ia`1aVLL01@1a
VLL00`000000OZ[J07jZfP0407jZfP030000002;^n/0Rk_[0080Rk_[0P00000409G8n0050000002F
boL0U/_g09K;m`0000000P1n[]42000000030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0
503jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H0
?03jl>H10?ooo`00DP3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0
/1LN0?[`iP3jl>H04P3jl>H00`000000/1LN0000000D0?[`iP030000002`5ah0000000@000000`0Y
>ED00`000000>E1`03U@L003000000H0Af>800<0000005IeWP1FMIh0101FMIh00`000000I8Nc06B7
/`0406B7/`030000001aVLL0LIW700D0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^k
j`0308^kj`<000000P2Eb?P010000000U/_g09K;m`2FboL20000000307j^d@000000000001L0n_3V
00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V01<0n_3V
00<0/1LN0?[`iP3jl>H0?@3jl>H10?ooo`00C`3jl>H2000000030?[`iP2`5ah0n_3V01<0n_3V0P00
00000`2`5ah0n_3V0?[`iP0B0?[`iP80000000<0/1LN0000003jl>H04P3jl>H2000000030;0G7P00
0000n_3V01<0n_3V00<000000;0G7P0000001000000302TiE@<000000P0iD7000`000000Af>804MS
R00404MSR0030000001FMIh0EWFN00@0EWFN00@0000006B7/`1TQk<0I8Nc1`000004076Ia`030000
001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/00`2;^n/00`000000ULSh09G8n003000000<0U/_g
0P0000000`1n[]4000000000000F0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0
503jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V03d0n_3V0@3oool004h0n_3V0P00
0000101>gJ8000000;0G7P00000B0?[`iP80000000<0/1LN0000000000004P3jl>H20000000304kM
XP2`5ah0000001<0n_3V00@000000;0G7P0000000000503jl>H2000000050?[`iP000000000001LQ
=@0000000`0Y>ED00`000000>E1`03U@L00203U@L00300000017HhP0Af>800@0Af>800@0000005Ie
WP1FMIh0EWFN1`00000306B7/`040000001aVLL0LIW7076Ia`P000000`1nZ]X00`000000Rk_[08^k
j`0308^kj`030000002Eb?P0ULSh0080ULSh00H0000009K;m`2FboL0U/_g0000001n[]43000001H0
n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V01@0
n_3V00<0/1LN0?[`iP3jl>H0?P3jl>H10?ooo`00CP3jl>H20000000304kMXP2`5ah0C]fR00800000
403jl>H010000000@]Yb0000002`5ah200000180n_3V0P000000102`5ah0000000eH9000000B0?[`
iP040000002`5ah00000000001@0n_3V00<000000?[`iP3jl>H00P000000100G8CD0000002TiE@0Y
>ED2000000@0>E1`00<0000004MSR017HhP00`17HhP5000000<0EWFN00<0000006B7/`1TQk<0101T
Qk<00`000000LIW7076Ia`05076Ia`040000001nZ]X0OZ[J07jZfPD00000102;^n/00`000000ULSh
09G8n00209G8n08000000P2FboL00`000000OZkA07j^d@02000001D0n_3V00<0/1LN0?[`iP3jl>H0
4`3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H0
?`3jl>H10?ooo`00C@3jl>H020000000An5k0000001>gJ80/1LN0000000<E2800000403jl>H01`00
0000@]Yb0000002`5ah0000000eF8`0000004@3jl>H2000000030;0G7P000000000001<0n_3V0`00
000H0?[`iP80000000H05b4e0000000Y>ED0000002TiE@00000403U@L00300000017HhP0000000<0
000000<0Af>80000001FMIh01@1FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700D0
LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[000000020000000308^kj`000000ULSh00<0
ULSh00<0000009K;m`0000000P00000207j^d@800000503jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP03
0;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`5ah0n_3V0?[`iP100?[`iP40
oooo001=0?[`iP<0000000<0C]fR0;0G7P0000000P0<E2800`000000n_3V0?[`iP0=0?[`iP800000
00@0/1LN0000000=ER<000004P3jl>H4000001@0n_3V00<000000?[`iP3jl>H0603jl>H200000003
01LQ=@00000000000080:CUE00<0000003U@L00iD7000P0iD702000000D0Af>800<0000005IeWP1F
MIh0101FMIh00`000000I8Nc06B7/`0406B7/`030000001aVLL0LIW700D0LIW700<0000007jZfP1n
Z]X0101nZ]X00`000000Rk_[08^kj`0208^kj`800000102Eb?P01@000000U/_g09K;m`2FboL00000
0080OZkA0P00000D0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H0503jl>H00`2`
5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V0400n_3V0@3oool004d0n_3V0`0000000`2`5ah0
000000aD8P0200000100n_3V0P0000000`2`5ah000000000000C0?[`iP<00000<03jl>H200000003
01LQ=@000000:CUE0080:CUE00<0000003U@L00iD7000`00000604MSR0030000001FMIh0EWFN00@0
EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`05076Ia`030000001nZ]X0OZ[J00@0
OZ[J00<0000008^kj`2;^n/00`2;^n/300000080ULSh00@0000009K;m`2FboL0U/_g0P0000000`1n
[]4000000000000C0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`
5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V0440n_3V0@3oool004d0n_3V00@00000000T0000
0000/1LN0`00000B0?[`iP030000000c_GP0000001@0n_3V0P00000a0?[`iP@000000`0Y>ED30000
0080>E1`00<0000004MSR017HhP00`17HhP00`000000EWFN05IeWP0505IeWP030000001TQk<0I8Nc
00@0I8Nc00<00000076Ia`1aVLL01@1aVLL00`000000OZ[J07jZfP0407jZfP030000002;^n/0Rk_[
00<0Rk_[00<0000009G8n02Eb?P00`00000309K;m`80000000<0OZkA0000000000004`3jl>H00`2`
5ah0n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`2`
5ah0n_3V0?[`iP120?[`iP40oooo001=0?[`iP04000000009000000003>lM`8000004`3jl>H30000
01@0n_3V00<000000?[`iP3jl>H0<03jl>H4000000<0:CUE00<0000003U@L00iD7000P0iD7000`00
0000Af>804MSR00304MSR0030000001FMIh0EWFN00@0EWFN5000000307jZfP030000002;^n/0Rk_[
00<0Rk_[00<0000009G8n02Eb?P00P2Eb?P01P000000U/_g09K;m`2FboL0000007j^d@<000004P3j
l>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0503j
l>H00`2`5ah0n_3V0?[`iP120?[`iP40oooo001>0?[`iP80000000<0<kag0000003jl>H04`3jl>H2
000004P0n_3V0P000000100G8CD0000002TiE@0Y>ED2000000@0>E1`00<0000004MSR017HhP00`17
HhP00`000000EWFN05IeWP040000000305IeWP000000I8Nc00D0I8Nc00<00000076Ia`1aVLL01@1a
VLL010000000OZ[J07jZfP1nZ]X4000000D0Rk_[00<0000009G8n02Eb?P00P2Eb?P200000080U/_g
00<0000007j^d@1n[]400P00000X0?[`iP030;0G7P3jl>H0n_3V01<0n_3V00<0/1LN0?[`iP3jl>H0
503jl>H00`2`5ah0n_3V0?[`iP130?[`iP40oooo001>0?[`iP040000000c_7L00000000001@0n_3V
00<000000?[`iP3jl>H0A`3jl>H20000000601LQ=@000000:CUE0000000Y>ED00000100iD7000`00
0000Af>80000000900000080EWFN00<0000006B7/`1TQk<0101TQk<00`000000LIW7076Ia`05076I
a`030000001nZ]X0OZ[J00@0OZ[J0`00000308^kj`030000002Eb?P0ULSh0080ULSh00D0000009K;
m`000000U/_g0000000207j^d@8000009`3jl>H00`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0
n_3V01<0n_3V00<0/1LN0?[`iP3jl>H0A03jl>H10?ooo`00CP3jl>H3000005l0n_3V0P0000000`0G
8CD0000000000009000000T00RX200@0000005IeWP1FMIh000001P1TQk<00`000000LIW7076Ia`05
076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/00P0000000`2;^n/0000009G8n003
09G8n0030000002FboL0U/_g008000000P1n[]42000002L0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H0
0`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V04@0n_3V0@3oool004h0n_3V0P00001P0?[`
iP80000000@05b4e0000000Y>ED0:CUE0`00000503>NGP/0000000<0EWFN0000001TQk<01@1TQk<0
0`000000LIW7076Ia`05076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/00P2;^n/2
000000D0ULSh00@0000009K;m`2FboL000000P1n[]42000002H0n_3V00<0/1LN0?[`iP3jl>H04`3j
l>H00`2`5ah0n_3V0?[`iP0D0?[`iP030;0G7P3jl>H0n_3V04D0n_3V0@3oool004h0n_3V00<00000
0?[`iP3jl>H0G`3jl>H4000000<0:CUE1@00000<03>NGP030000001FMIh0000000H0I8Nc00<00000
076Ia`1aVLL01@1aVLL00`000000OZ[J07jZfP0407jZfP030000002;^n/0Rk_[00<0Rk_[0`000003
09G8n0030000002FboL0U/_g0080000000<0OZkA000000000000>`3jl>H00`2`5ah0n_3V0?[`iP0D
0?[`iP030;0G7P3jl>H0n_3V04H0n_3V0@3oool00:80n_3V00<0/1LN0?[`iP3jl>H02`3jl>H40000
00<0:CUE2@00000803>NGP030000001FMIh0000000<0I8Nc1`000004076Ia`030000001nZ]X0OZ[J
00@0OZ[J00<0000008^kj`2;^n/00`2;^n/00`000000ULSh09G8n0020000000409G8n0000000U/_g
09K;m`80000000<0OZkA000000000000>`3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP030;0G7P3jl>H0
n_3V04L0n_3V0@3oool00:<0n_3V00<0/1LN0?[`iP3jl>H02P3jl>H20000000301LQ=@000000:CUE
0080:CUE00<0000003U@L00iD7000P0iD7030000000403NkPP0000000000000000@0<iiN0`2`5ah4
000000<0I8Nc00@00000076Ia`1aVLL0LIW72000000307jZfP030000002;^n/0Rk_[00<0Rk_[00<0
000009G8n02Eb?P00P2Eb?P200000080U/_g00<0000007j^d@0000000P00000j0?[`iP030;0G7P3j
l>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0A`3jl>H10?ooo`00Y03jl>H00`2`5ah0n_3V0?[`iP09
0?[`iP80000000@05b4e0000000Y>ED0:CUE0P00000403U@L00300000017HhP0Af>8008000000P0g
^h830000000403>NGP000000EWFN05IeWPH0/1LN00<0I8Nc0000001aVLL01P1aVLL010000000OZ[J
07jZfP1nZ]X5000000@0Rk_[00<0000009G8n02Eb?P00`2Eb?P200000080U/_g00@0000007j^d@00
00000000D03jl>H00`2`5ah0n_3V0?[`iP180?[`iP40oooo002U0?[`iP030;0G7P3jl>H0n_3V00P0
n_3V0P0000001P0G8CD00000000000000000:CUE000000@0>E1`00<0000004MSR000000010000003
03NkPP8000000P1FMIh00`000000I8Nc06B7/`0306B7/`H0/1LN0`1aVLL00`000000OZ[J07jZfP04
07jZfP030000002;^n/000000080000000<0Rk_[0000002Eb?P0102Eb?P00`000000U/_g00000002
0000000307j^d@000000000004l0n_3V00<0/1LN0?[`iP3jl>H0B@3jl>H10?ooo`00YP3jl>H00`2`
5ah0n_3V0?[`iP070?[`iP80000000<05b4e0000000Y>ED00P0Y>ED00`000000>E1`03U@L00203U@
L08000001017HhP30000000503NkPP000000EWFN05IeWP0000001`1TQk<00`000000LIW7076Ia`02
076Ia`H0/1LN101nZ]X00`000000Rk_[08^kj`0208^kj`8000001@2Eb?P01P000000U/_g09K;m`2F
boL0000007j^d@800000C`3jl>H00`2`5ah0n_3V0?[`iP190?[`iP40oooo002W0?[`iP030;0G7P3j
l>H0n_3V00H0n_3V00@0000001LQ=@00000000000`0Y>ED00`000000>E1`03U@L003000000D0Af>8
00<0000005IeWP1FMIh00P00000205IeWP030000001TQk<0I8Nc00D0I8Nc00<00000076Ia`1aVLL0
1@1aVLL00`000000OZ[J07jZfP050;0G7PD0Rk_[0`00000309G8n0060000002FboL0U/_g09K;m`00
0000OZkA0P00000<0?[`iP<00000?`3jl>H00`2`5ah0n_3V0?[`iP1:0?[`iP40oooo002?0?[`iP03
0;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H01@3jl>H20000000301LQ=@000000:CUE0080
:CUE0`00000203U@L00300000017HhP0Af>800<0Af>800<0000005IeWP1FMIh0101FMIh00`000000
I8Nc06B7/`0506B7/`030000001aVLL0LIW700D0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000
/1LN0;0G7P040;0G7P80ULSh0P0000000`2Eb?P0000009K;m`0209K;m`@00000203jl>H6000008d0
n_3V0@3oool00900n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP040?[`iP800000
00<05b4e0000000Y>ED00P0Y>ED00`000000>E1`03U@L00203U@L00300000017HhP0Af>800<0Af>8
00<0000005IeWP1FMIh00`1FMIhC000000D0OZ[J00<0000008^kj`2;^n/00`2;^n/00`000000/1LN
0;0G7P040;0G7P<0U/_g100000070?[`iP80/1LN00@00000046mPP0000000000SP3jl>H10?ooo`00
T@3jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V00<0n_3V00@0000001LQ=@0G8CD0
00000P0Y>ED2000000@0>E1`00<0000004MSR017HhP00`17HhP00`000000EWFN0000000300000003
05IeWP000000I8Nc00H0I8Nc00<00000076Ia`1aVLL01@1aVLL00`000000OZ[J0000000300000003
07jZfP000000Rk_[00@0Rk_[00<0000009G8n02Eb?P00`2Eb?P00`000000/1LN0;0G7P040;0G7P03
0000003jl>H0n_3V0080n_3V0`2`5ah0103jl>H00000046mPP00002@0?[`iP40oooo002B0?[`iP03
0;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0000000000000P3jl>H0200000005b4e01LQ=@000000:CUE
0000000Y>ED00000100iD7000`000000Af>804MSR00204MSR0<000001@1FMIh00`000000I8Nc06B7
/`0506B7/`030000001aVLL0LIW700D0LIW700<0000007jZfP1nZ]X00`1nZ]X3000000@0Rk_[00<0
000009G8n02Eb?P00`2Eb?P01`000000U/_g0000002FboL0000007j^d@0000001P2`5ah40?[`iP03
0000003jl>H0n_3V08l0n_3V0@3oool009<0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H010000000/1LN
0000003jl>H2000000805b4e0P00000202TiE@030000000iD700>E1`0080>E1`00<0000004MSR000
00000P0000000`17HhP0000005IeWP0505IeWP030000001TQk<0I8Nc00D0I8Nc00<00000076Ia`1a
VLL01@1aVLL00`000000OZ[J07jZfP0407jZfP030000002;^n/000000080000000<0Rk_[0000002E
b?P0102Eb?P00`000000U/_g09K;m`020000000407j^d@00000000000;0G7P@0n_3V0`2`5ajC0?[`
iP40oooo002D0?[`iP030;0G7P3jl>H0n_3V01@0n_3V0P000000102`5ah0000000000000000201LQ
=@050000000Y>ED0:CUE02TiE@000000100iD702000000@0Af>800<0000005IeWP1FMIh0101FMIh0
0`000000I8Nc06B7/`0506B7/`030000001aVLL0LIW700D0LIW700<0000007jZfP1nZ]X0101nZ]X0
0`000000Rk_[08^kj`0208^kj`8000001@2Eb?P01P000000U/_g09K;m`2FboL0000007j^d@800000
V`3jl>H10?ooo`00O@3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V01<0n_3V0P00
00001@1OokT000000000000000005b4e008000000`0Y>ED00`000000>E1`03U@L003000000D0Af>8
00<0000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0506B7/`030000001aVLL0LIW700D0LIW7
00<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0308^kj`<000000`2Eb?P01P000000U/_g
09K;m`2FboL0000007j^d@800000V`3jl>H10?ooo`00OP3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP03
0;0G7P3jl>H0n_3V01<0n_3V1P0000000`0G8CD0000002TiE@0202TiE@<000000P0iD7000`000000
Af>804MSR00304MSR0P000001`1TQk<00`000000LIW7076Ia`05076Ia`030000001nZ]X0OZ[J00@0
OZ[J00<0000008^kj`2;^n/00`2;^n/00`000000ULSh09G8n0020000000309G8n0000000U/_g0080
U/_g1000000M0?[`iPD000006@3jl>H00`000000n_3V0?[`iP1M0?[`iP40oooo001o0?[`iP030;0G
7P3jl>H0n_3V01D0n_3V0P2`5ahE0?[`iP@0000000<05b4e0000000Y>ED00P0Y>ED00`000000>E1`
03U@L008000000L00bh45000000307jZfP030000002;^n/0Rk_[00<0Rk_[00<0000009G8n02Eb?P0
0P2Eb?P2000000<0U/_g1000000H0?[`iPT000006P3jl>H3000005d0n_3V0@3oool00800n_3V00<0
/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP8000000P0G8CD00`000000:CUE02Ti
E@02000000<0>E1`1000000303>NG`T000001P1TQk<00`000000LIW7076Ia`05076Ia`040000001n
Z]X0OZ[J07jZfPD00000102;^n/00`000000ULSh09G8n00309G8n08000000P2FboL010000000OZkA
00000000000H0?[`iP030000000CGb4000000080000000<0@;f20000003jl>H0703jl>H4000005/0
n_3V0@3oool00840n_3V00<0/1LN0?[`iP3jl>H01`3jl>H20;0G7Pd0n_3V00<0/1LN0?[`iP3jl>H0
4P3jl>H2000000805b4e00D0000002TiE@000000:CUE0000000403U@L0H00000200cWUl00`000000
I8Nc06B7/`0406B7/`030000001aVLL0LIW700D0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000
Rk_[000000020000000308^kj`000000ULSh00@0ULSh00<0000009K;m`0000000P0000000`1n[]40
00000000000G0?[`iP80/1LN00<00000042mPP10_H800P00000N0?[`iP<0000000<0;Hm000000000
0000F@3jl>H10?ooo`00PP3jl>H20;0G7P@0n_3V0`2`5ah@0?[`iP030;0G7P3jl>H0n_3V0140n_3V
0P00000201LQ=@8000000P0Y>ED00`000000>E1`03U@L00203U@L00300000017HhP0000000800000
00@0>;b20000000000000000100cWUl30;0G7PD0I8Nc00<00000076Ia`1aVLL01@1aVLL00`000000
OZ[J07jZfP0407jZfP030000002;^n/0Rk_[0080Rk_[0P00000509G8n0060000002FboL0U/_g09K;
m`000000OZkA0P00000C0?[`iP@0/1LN00<0n_3V00000010_H800`00000O0?[`iP80000000@0F_2_
0000000]Sd00;Hm00P00001G0?[`iP40oooo001/0?[`iP030;0G7P3jl>H0n_3V01D0n_3V102`5ahD
0?[`iP030;0G7P3jl>H000000100n_3V0P00000201LQ=@040000000Y>ED0:CUE000000D0>E1`0P00
000304MSR08000000P0h_8830000000403>NG`000000I8Nc06B7/`H0/1LN1`1aVLL00`000000OZ[J
07jZfP0407jZfP030000002;^n/0Rk_[00<0Rk_[0`00000309G8n0040000002FboL0U/_g09K;m`80
000000<0OZkA0000003jl>H03`3jl>H30;0G7PH0n_3V0P00000R0?[`iP80000000<0F_2_00000000
00000P0]Sd02000005D0n_3V0@3oool006d0n_3V00<0/1LN0?[`iP3jl>H04P3jl>H40;0G7QL0n_3V
00@0/1LN05CQXP00000000003P3jl>H20000000301LQ=@00000000000080:CUE00@0000003U@L00i
D700>E1`0`00000504MSR0<000000`0h_882000000L0I8Nc00<000000;0G7P2`5ah0102`5ah00`1a
VLL0000007jZfP0507jZfP030000002;^n/0Rk_[00<0Rk_[00<0000009G8n02Eb?P00P0000000`2E
b?P0000009K;m`0209K;m`80000000<0OZkA0000003jl>H0303jl>H30;0G7Rd0n_3V00<0000001]n
B00000000P1Jl:l01@000000;Hm002f?@00]Sd00000005@0n_3V0@3oool006h0n_3V00<0/1LN0?[`
iP3jl>H03@3jl>H40;0G7P@0n_3V00<0/1LN0?[`iP3jl>H04`3jl>H00`000000E>6R0;0G7P020000
00h0n_3V0`0000001P0G8CD0000002TiE@0Y>ED0000003U@L08000000P0iD7000`000000Af>804MS
R00304MSR0030000001FMIh0EWFN0080000000<0>;b2000000000000101TQk<7000000<0LIW71P2`
5ah207jZfP030000002;^n/0Rk_[00<0Rk_[00<0000009G8n02Eb?P00P2Eb?P2000000<0U/_g00@0
000007j^d@00000000002@3jl>H40;0G7S00n_3V00<0000001]nB00000000`1Jl:l010000000;Hm0
02f?@000001D0?[`iP40oooo001_0?[`iP030;0G7P3jl>H0n_3V00T0n_3V0`2`5ah90?[`iP030;0G
7P3jl>H0n_3V0180n_3V0`0000000`2`5ah0Goni0000000=0?[`iP80000000<05b4e0000000Y>ED0
0P0Y>ED2000000@0>E1`00<0000004MSR017HhP00`17HhP010000000EWFN05IeWP1FMIh8000000<0
I8Nc00@00000076Ia`1aVLL0LIW7200000000`1nZ]X0/1LN0;0G7P040;0G7P<0Rk_[00<0000009G8
n02Eb?P00P2Eb?P200000080U/_g00@0000007j^d@1n[]4000001P3jl>H30;0G7Ql0n_3V3@000009
0?[`iP030000000KOTP0000000<0F_2_00<0000002f?@0000000E03jl>H10?ooo`00L03jl>H20;0G
7PH0n_3V0`2`5ah=0?[`iP030;0G7P3jl>H0n_3V0140n_3V0`00000205oo^@030000003jl>H0n_3V
00/0n_3V0P000000100G8CD0000002TiE@0Y>ED2000000D0>E1`00<0000004MSR017HhP00P17HhP5
000000<0EWFN00<0000006B7/`1TQk<01@1TQk<00`000000LIW7076Ia`05076Ia`040000001nZ]X0
OZ[J07jZfPD000000P2;^n/60;0G7P80ULSh00D0000009K;m`000000U/_g0000000207j^d@030000
003jl>H0n_3V00@0/1LN8P3jl>H00`000000560S01AP8`0401AP8`D000002P3jl>H0100000006gi8
01]nB000000305[`[`800000E03jl>H10?ooo`00LP3jl>H00`2`5ah0n_3V0?[`iP030;0G7Q40n_3V
00<0/1LN0?[`iP3jl>H04P3jl>H30000000305oo^@000000n_3V00/0n_3V0P0000001P0G8CD00000
000000000000:CUE000000D0>E1`00<0000004MSR00000000P0000000`17HhP0000005IeWP0505Ie
WP030000001TQk<0I8Nc00D0I8Nc00<00000076Ia`1aVLL01@1aVLL00`000000OZ[J07jZfP0407jZ
fP030000002;^n/0000000<0000000@0Rk_[0000002Eb?P0ULSh1P2`5ah00`000000OZkA07j^d@02
000000030;0G7P3jl>H0n_3V02@0n_3V00<0000001AP8`0DH2<01`00000<0?[`iP040000000KOTP0
6gi8000000@0F_2_00<000000?[`iP3jl>H0DP3jl>H10?ooo`00LP3jl>H30;0G7QD0n_3V00<0/1LN
0?[`iP3jl>H04`3jl>H3000000`0n_3V0P0000000`0G8CD0000002TiE@0202TiE@030000000iD700
>E1`00<0>E1`0P00000404MSR0030000001FMIh0EWFN00@0EWFN00<0000006B7/`1TQk<01@1TQk<0
0`000000LIW7076Ia`05076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^kj`2;^n/00`2;^n/2
000000@0ULSh00@0000009K;m`2FboL0U/_g102`5ah00`000000n_3V0?[`iP0T0?[`iP80/1LN0P00
0002042lPP<000003`3jl>H0100000006gi801]nB000000205[`[`030000003jl>H0n_3V05<0n_3V
0@3oool006l0n_3V0`2`5ah20?[`iP030;0G7P3jl>H0n_3V01@0n_3V00<0/1LN0?[`iP3jl>H0503j
l>H2000000/0n_3V1000000302TiE@040000000iD700>E1`03U@L0<000001@17HhP00`000000EWFN
05IeWP0405IeWP030000001TQk<0I8Nc00D0I8Nc00<00000076Ia`1aVLL01@1aVLL00`000000OZ[J
07jZfP0407jZfP030000002;^n/0Rk_[00@0Rk_[0`00000209G8n0040000002FboL0U/_g09K;m`80
000000<0OZkA0000000000008P3jl>H40;0G7P040?[`iP000000@;b2042lPP<000004@3jl>H20000
000401]nB0000000F_2_0;0G7UH0n_3V0@3oool006`0n_3V0`2`5ah60?[`iP030;0G7P3jl>H0n_3V
01@0n_3V0P2`5ahQ0?[`iP@000000`0Y>ED010000000>E1`00000000000203U@L00300000017HhP0
Af>800<0Af>800<0000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0506B7/`030000001aVLL0
LIW700D0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0408^kj`030000002Eb?P0
ULSh00<000000`2FboL20000000307j^d@000000000001l0n_3V0`2`5ah60?[`iP<000005@3jl>H3
000000030?[`iP2`5ah0n_3V05@0n_3V0@3oool005d0n_3V0`0000080?[`iP@0/1LN2P3jl>H00`2`
5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0000001h0n_3V0P0000000`0G8CD0000002TiE@0202Ti
E@800000100iD7000`000000Af>804MSR00304MSR0030000001FMIh0EWFN00@0EWFN00<0000006B7
/`1TQk<00P1TQk<7000000@0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0408^k
j`030000002Eb?P0ULSh0080ULSh00H0000009K;m`2FboL0U/_g0000001n[]43000001/0n_3V102`
5ah90?[`iP030000003jl>H0n_3V01X0n_3V00<0/1LN0?[`iP3jl>H0DP3jl>H10?ooo`00F`3jl>H5
000000D0n_3V0`2`5ah?0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00@0/1LN05CQX@0000000000703j
l>H20000000401LQ=@000000:CUE02TiE@8000001@0iD7000`000000Af>804MSR00304MSR0040000
001FMIh0EWFN05IeWPP000000`1TQk<010000000LIW7076Ia`1aVLL8000000<0OZ[J00<0000008^k
j`2;^n/0102;^n/00`000000ULSh09G8n00209G8n08000000P2FboL00`000000OZkA07j^d@020000
01P0n_3V0`2`5ah=0?[`iP<000004`3jl>H7000000030;0G7P3jl>H0n_3V0580n_3V0@3oool005T0
n_3V0P0000000`00;`40000004;1Q`0204;1Q`030000003jl>H0/1LN0080/1LN4`3jl>H20;0G7Q@0
n_3V00<0000005CQX@2`5ah00`0000050?[`iP80/1LN503jl>H20000000601LQ=@000000:CUE0000
000Y>ED000001@0iD7000`000000Af>804MSR00204MSR0D000000`1FMIh00`000000I8Nc06B7/`05
06B7/`030000001aVLL0LIW700D0LIW700@0000007jZfP1nZ]X0OZ[J1@00000508^kj`030000002E
b?P0ULSh0080ULSh00D0000009K;m`000000U/_g0000000207j^d@8000005@3jl>H30;0G7Q40n_3V
100000090?[`iPP000000P0DHR@5000000030?[`iP2`5ah0n_3V0580n_3V0@3oool005P0n_3V00D0
0000000_0@00;`4002l10000000204;1Q`<0/1LN603jl>H00`2`5ah0n_3V0?[`iP0A0?[`iP800000
00@0E>6Q0;0G7P00000000000P3jl>H30;0G7QH0n_3V0P0000000`0G8CD000000000000202TiE@03
0000000iD700>E1`00<0>E1`00<0000004MSR00000000P0000000`17HhP0000005IeWP0205IeWPH0
00001@1TQk<00`000000LIW7076Ia`05076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^kj`00
00000`0000000`2;^n/0000009G8n00309G8n0030000002FboL0U/_g008000000P1n[]4200000140
n_3V102`5ahD0?[`iP80000000@0F^n^00000000000000001`3jl>H00`000000568T01AR900301AR
90@0000000<0@;b2000000000000103jl>H00`2`5ah0n_3V0?[`iP1@0?[`iP40oooo001F0?[`iP80
00000`00;`4200000080/1LN0`00000I0?[`iP030;0G7P3jl>H0n_3V0100n_3V00@0000003fZG@00
00000000102`5ahI0?[`iP80000000<05b4e0000000Y>ED00P0Y>ED00`000000>E1`03U@L00303U@
L08000000P17HhP<000000D0I8Nc00<00000076Ia`1aVLL01@1aVLL00`000000OZ[J07jZfP0407jZ
fP030000002;^n/0Rk_[00<0Rk_[0P00000409G8n0050000002FboL0U/_g09K;m`0000000P1n[]42
000000h0n_3V0`2`5ahH0?[`iP8000000P1Jkjh010000000<9=40000000000050?[`iP030000000D
HR@0000000<000000`10_882000000L0n_3V00<0/1LN0?[`iP3jl>H0C`3jl>H10?ooo`00E@3jl>H0
0`00000002l1000_0@0300000080:IQS0P00000200a@50030000003jl>H0n_3V01P0n_3V00<0/1LN
0?[`iP3jl>H0403jl>H30;0G7P80H?ni00<000000?[`iP3jl>H0603jl>H4000000<0:CUE00@00000
03U@L00iD700>E1`0`00000504MSR0@000001@0dWUl30;0G7P<0I8Nc00<00000076Ia`1aVLL01@1a
VLL00`000000OZ[J07jZfP0407jZfP030000002;^n/0Rk_[00@0Rk_[0`00000209G8n0040000002F
boL0U/_g09K;m`80000000<0OZkA0000000000002P3jl>H40;0G7Q`0n_3V0P00000205[_[P<00000
1@3jl>H20;0G7PD0@;b20`0000090?[`iP030;0G7P3jl>H0n_3V04h0n_3V0@3oool005<0n_3V1@00
000502VHH`050000000<D1@0350D00a@500000006`3jl>H00`2`5ah0n_3V0?[`iP0<0?[`iP<0/1LN
0P3jl>H200000003063o^@000000000001T0n_3V1000000302TiE@040000000iD700000000000080
>E1`00<0000004MSR017HhP00`17HhP00`000000EWFN000000050000000403BNG`000000I8Nc06B7
/`D0/1LN1P1aVLL00`000000OZ[J07jZfP0407jZfP030000002;^n/0Rk_[00@0Rk_[00<0000009G8
n02Eb?P00`00000309K;m`030000001n[]40000000800000203jl>H20;0G7R00n_3V00<0000001]l
AP0000000`1Jkjh2000000@0/1LN00<0n_3V00000010_8800P10_883000000`0n_3V00<0/1LN0?[`
iP3jl>H0C@3jl>H10?ooo`00D@3jl>H4000000<0:IQS2P00000L0?[`iP030;0G7P3jl>H0n_3V00P0
n_3V0`2`5ah70?[`iP<000006@3jl>H20000000301LQ=@000000:CUE0080:CUE0P00000403U@L003
00000017HhP0Af>800<0Af>800<0000005IeWP1FMIh00P1FMIh20000000303RlP`00000000000080
I8Nc1@0000060;0G7P8000001@1nZ]X00`000000Rk_[08^kj`0408^kj`030000002Eb?P0ULSh0080
ULSh00D0000009K;m`2FboL0U/_g0000000207j^d@800000:P3jl>H00`0000006ga60000000405[_
[P030000003jl>H0n_3V00<0n_3V00<00000042lPP0000000P00000>0?[`iP030;0G7P3jl>H0n_3V
04d0n_3V0@3oool00500n_3V2@00000V0?[`iP030;0G7P3jl>H0n_3V00<0n_3V102`5ah<0?[`iP80
0000603jl>H20000000401LQ=@000000:CUE02TiE@800000100iD7000`000000Af>804MSR00404MS
R0040000001FMIh0EWFN05IeWPP000000`1TQk<00`000000LIW7076Ia`05076Ia`D0/1LN00<00000
07jZfP0000001P2;^n/00`000000ULSh09G8n00209G8n08000000P2FboL00`000000OZkA07j^d@02
000002/0n_3V00<0000001]lAP0000000P1Jkjh00`000000n_3V0?[`iP050?[`iP8000004@3jl>H0
0`2`5ah0n_3V0?[`iP1<0?[`iP40oooo00200?[`iPD0/1LN0P00000X0?[`iP80000000H05b4e0000
000Y>ED0000002TiE@00000403U@L00300000017HhP0Af>800<0Af>81@00000305IeWP030000001T
Qk<0I8Nc00D0I8Nc00<00000076Ia`1aVLL01@1aVLL00`000000OZ[J07jZfP0207jZfPD0/1LN102;
^n/00`000000ULSh09G8n00209G8n0030000002FboL00000008000000P1n[]42000002P0n_3V0`2`
5ah30000000305[_[P2`5ah0n_3V01/0n_3V00<0/1LN0?[`iP3jl>H0B`3jl>H10?ooo`00L`3jl>H3
000000T0n_3V102`5ah0101Ch:00000001]nB000000X0?[`iP80000000<05b4e0000000000000P0Y
>ED00`000000>E1`03U@L00203U@L00300000017HhP0000000<0000000<0Af>80000001FMIh01@1F
MIh00`000000I8Nc06B7/`0506B7/`030000001aVLL0LIW700D0LIW700<0000007jZfP1nZ]X0101n
Z]X00`000000Rk_[000000060;0G7P<0ULSh00D0000009K;m`2FboL0U/_g0000000207j^d@800000
9@3jl>H30;0G7PD0n_3V0P0000000`3jl>H0/1LN0?[`iP0K0?[`iP030;0G7P3jl>H0n_3V04X0n_3V
0@3oool00740n_3V100000000`12`HL000000?[`iP040?[`iP<0/1LN00T0n_3V0000001Ch:00Dn2P
0;0G7P1Ch:00000002bL@@0000009`3jl>H20000000301LQ=@000000:CUE0080:CUE00<0000003U@
L00iD7000P0iD702000000D0Af>800<0000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0506B7
/`030000001aVLL0LIW700D0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0308^k
j`80000000D0ULSh0;0G7P2`5ah0/1LN0000000309K;m`80000000<0OZkA0000000000008@3jl>H4
0;0G7P`0n_3V00<0/1LN0?[`iP3jl>H06P3jl>H00`2`5ah0n_3V0?[`iP190?[`iP40oooo001`0?[`
iP0400000000<P40038100000080@/6700<000000?[`iP2`5ah00`2`5ah40?[`iP<0000000D0Dn2P
0;0G7P000000;9a10000000W0?[`iP@000000`0Y>ED00`000000>E1`03U@L003000000H0Af>800<0
000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0506B7/`030000001aVLL0LIW700D0LIW700<0
000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0408^kj`<000000P2Eb?P010000000U/_g09K;
m`2FboL20000000307j^d@000000000001h0n_3V0`2`5ahA0?[`iP030;0G7P3jl>H0n_3V01X0n_3V
00<0/1LN0?[`iP3jl>H0B03jl>H10?ooo`00K`3jl>H00`0000000381000b0@020000000404;1Q`2`
5ah0/1LN0;0G7PP0n_3V00<0000003j[G`0nZel00P000000102`5ah0000002bL@@00000V0?[`iP@0
00000`0Y>ED300000080>E1`00<0000004MSR017HhP01017HhP00`000000EWFN05IeWP0405IeWP03
0000001TQk<0I8Nc00D0I8Nc00<00000076Ia`1aVLL01@1aVLL00`000000OZ[J07jZfP0407jZfP03
0000002;^n/0Rk_[00@0Rk_[00<0000009G8n02Eb?P00`00000309K;m`030000001n[]4000000080
00005P3jl>H200000080n_3V102`5ahE0?[`iP030;0G7P3jl>H0n_3V01T0n_3V00<0/1LN0?[`iP3j
l>H0B03jl>H10?ooo`00K@3jl>H200000004000b0@000000000002ZHI080/1LN00<0000000eB5P00
0000203jl>H4000000<0H?nj0P00000M0?[`iP80/1LN1`3jl>H20000000301LQ=@000000:CUE0080
:CUE00<0000003U@L00iD7000P0iD7000`000000Af>804MSR00404MSR0030000001FMIh0EWFN00@0
EWFN00<0000006B7/`1TQk<00P1TQk<=000000D0OZ[J00<0000008^kj`2;^n/0102;^n/00`000000
ULSh09G8n00209G8n0030000002FboL0U/_g0080U/_g00@0000007j^d@00000000005P3jl>H40000
01T0n_3V00<0/1LN0?[`iP3jl>H06P3jl>H00`2`5ah0n_3V0?[`iP170?[`iP40oooo001/0?[`iP@0
0000100ZV6@0100000003E8F00eB5P00000:0?[`iP@0000000@0H?nj0000000/W44000006@3jl>H3
0;0G7PT0n_3V0P000000100G8CD0000002TiE@0Y>ED2000000@0>E1`00<0000004MSR017HhP01017
HhP010000000EWFN05IeWP1FMIh8000000<0I8Nc00<00000076Ia`1aVLL01@1aVLL00`000000OZ[J
000000030000000307jZfP000000Rk_[00D0Rk_[00<0000009G8n02Eb?P00P2Eb?P300000080U/_g
00@0000007j^d@00000000004`3jl>H40;0G7P80000000<0<YQ8000000000000603jl>H00`2`5ah0
n_3V0?[`iP0J0?[`iP030;0G7P3jl>H0n_3V04H0n_3V0@3oool006X0n_3V0`00000302ZHI0P00000
303jl>H6000001D0n_3V102`5ah<0?[`iP80000000H05b4e0000000Y>ED0000002TiE@00000403U@
L00300000017HhP0Af>800<0Af>81@00000305IeWP030000001TQk<0I8Nc00D0I8Nc00<00000076I
a`1aVLL01@1aVLL00`000000OZ[J07jZfP0307jZfP<000001@2;^n/00`000000ULSh09G8n00209G8
n0030000002FboL0U/_g00<0000000<0OZkA0000000000004@3jl>H20;0G7P@0n_3V100000000`0b
V4P000000000000G0?[`iP030;0G7P3jl>H0n_3V01X0n_3V00<0/1LN0?[`iP3jl>H0A@3jl>H10?oo
o`00J@3jl>H8000001H0n_3V1000000A0?[`iP<0/1LN403jl>H20000000301LQ=@00000000000080
:CUE00<0000003U@L00iD7000P0iD7000`000000Af>8000000030000000304MSR0000000EWFN00D0
EWFN00<0000006B7/`1TQk<01@1TQk<00`000000LIW7076Ia`05076Ia`030000001nZ]X0OZ[J00@0
OZ[J00<0000008^kj`0000000`0000000`2;^n/0000009G8n00309G8n0030000002FboL0U/_g0080
U/_g00@0000007j^d@00000000005`3jl>H01`0000006WY40000001JkZd0000003:HB0000000603j
l>H00`2`5ah0n_3V0?[`iP0J0?[`iP030;0G7P3jl>H0n_3V04@0n_3V0@3oool008T0n_3V0P00000>
0?[`iP<0/1LN4`3jl>H0100000005b4e01LQ=@00000302TiE@030000000iD700>E1`0080>E1`0P00
000504MSR0030000001FMIh0EWFN00@0EWFN1@00000306B7/`030000001aVLL0LIW700D0LIW700<0
000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0308^kj`8000001@2Eb?P01P000000U/_g09K;
m`2FboL0000007j^d@8000005`3jl>H01@0000006WY401YjA0000000F^j]008000006@3jl>H00`2`
5ah0n_3V0?[`iP0J0?[`iP030;0G7P3jl>H0n_3V04<0n_3V0@3oool009D0n_3V102`5ahF0?[`iP04
0000000G8CD00000000000<0:CUE00<0000003U@L00iD7000`00000604MSR0030000001FMIh0EWFN
00T000000`1TQk<00`000000LIW7076Ia`05076Ia`030000001nZ]X0OZ[J00@0OZ[J00<0000008^k
j`2;^n/0102;^n/3000000<0ULSh00@0000009K;m`2FboL0U/_g1000000H0?[`iP060000000JNT@0
000005[^[@2`5ah000006P3jl>H00`2`5ah0n_3V0?[`iP0I0?[`iP030;0G7P3jl>H0n_3V04<0n_3V
0@3oool00980n_3V0`2`5ahJ0?[`iP80000000<05b4e0000000Y>ED00P0Y>ED300000080>E1`00<0
000004MSR017HhP01017HhP00`000000EWFN05IeWP0205IeWP@000000P0dWUl30;0G7P0306B7/`00
0000LIW700H0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0408^kj`030000002E
b?P0ULSh0080000000<0ULSh0000002FboL00P2FboL4000001P0n_3V1@0000000`2`5ah0n_3V0?[`
iP0I0?[`iP030;0G7P3jl>H0n_3V01T0n_3V00<0/1LN0?[`iP3jl>H0@P3jl>H10?ooo`00R@3jl>H3
000000<0n_3V0`2`5ahM0?[`iP040000000G8CD05b4e000000<0:CUE00<0000003U@L00iD7000P0i
D7000`000000Af>804MSR00404MSR0030000001FMIh0EWFN00@0EWFN1`0000060;0G7P<0LIW700<0
000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0408^kj`030000002Eb?P0ULSh0080ULSh0P00
000309K;m`040000001n[]400000000001h0n_3V00<0/1LN0?[`iP3jl>H06@3jl>H00`2`5ah0n_3V
0?[`iP0I0?[`iP030;0G7P3jl>H0n_3V0440n_3V0@3oool008L0n_3V100000040;0G7Ql0n_3V0P00
000201LQ=@030000000Y>ED0:CUE00800000100iD7000`000000Af>804MSR00404MSR0040000001F
MIh0EWFN05IeWPP000000`1TQk<01@000000LIW7076Ia`1aVLL0000000D0/1LN0P00000307jZfP03
0000002;^n/0Rk_[00@0Rk_[00<0000009G8n02Eb?P00`2Eb?P200000080U/_g00@0000007j^d@00
000000007`3jl>H00`2`5ah0n_3V0?[`iP0I0?[`iP030;0G7P3jl>H0n_3V05`0n_3V0@3oool008H0
n_3V00<00000004d0P0000000P2`5ah200000240n_3V0P00000201LQ=@<0000000<0:CUE0000000i
D7000`0iD7000`000000Af>804MSR00304MSR0D000000`1FMIh00`000000I8Nc06B7/`0506B7/`03
0000001aVLL0LIW700D0LIW700<0000007jZfP2`5ah01@2`5ah00`000000Rk_[08^kj`0308^kj`03
0000002Eb?P0ULSh00<0ULSh00<0000009K;m`0000000P0000000`1n[]4000000000000O0?[`iP03
0;0G7P3jl>H0n_3V01T0n_3V00<0/1LN0?[`iP3jl>H0G03jl>H10?ooo`00Q03jl>H40000000502ZI
I0000000000000iD5`0000008@3jl>H2000000805b4e00D0000002TiE@0Y>ED0:CUE0000000403U@
L00300000017HhP0000000<0000000<0Af>80000001FMIh01@1FMIh00`000000I8Nc06B7/`0506B7
/`030000001aVLL0LIW700D0LIW700<0000007jZfP1nZ]X0101nZ]X010000000/1LN0;0G7P2`5ah2
0000000308^kj`000000ULSh00@0ULSh00H0000009K;m`2FboL0U/_g0000001n[]4200000200n_3V
00<0/1LN0?[`iP3jl>H06@3jl>H00`2`5ah0n_3V0?[`iP1K0?[`iP40oooo00220?[`iP/000008@3j
l>H20000000301LQ=@000000000000<0:CUE00<0000003U@L00iD7000P0iD702000000D0Af>800<0
000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0506B7/`030000001aVLL0LIW700D0LIW700<0
000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0308^kj`8000001@2Eb?P01P000000U/_g09K;
m`2FboL0000007j^d@800000103jl>H2000001/0n_3V00<0/1LN0?[`iP3jl>H06@3jl>H00`2`5ah0
n_3V0?[`iP1J0?[`iP40oooo00210?[`iPH000009`3jl>H30000000601LQ=@000000/1LN0;0G7P0Y
>ED000000P0iD703000000H0Af>800<0000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0506B7
/`030000001aVLL0LIW700D0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0408^k
j`<000000`2Eb?P010000000U/_g09K;m`2FboL4000000@0n_3V1000000J0?[`iP030;0G7P3jl>H0
n_3V01T0n_3V00<0/1LN0?[`iP3jl>H0F@3jl>H10?ooo`00[P3jl>H00`000000/1LN0;0G7P020;0G
7P<0:CUE0`00000203U@L00300000017HhP0Af>800@0Af>800<0000005IeWP1FMIh0101FMIh00`00
0000I8Nc06B7/`0506B7/`030000001aVLL0LIW700D0LIW700<0000007jZfP1nZ]X0101nZ]X00`00
0000Rk_[08^kj`0408^kj`030000002Eb?P0ULSh0080000000<0ULSh0000002FboL00P2FboL30000
000305IiS@3jl>H0n_3V00<0n_3V1@00000I0?[`iP030;0G7P3jl>H0n_3V01T0n_3V00<0/1LN0?[`
iP3jl>H0F03jl>H10?ooo`00[03jl>H30;0G7P040000000G8CD05b4e000000<0:CUE00<0000003U@
L00iD7000P0iD7000`000000Af>804MSR00404MSR0030000001FMIh0EWFN00@0EWFN00<0000006B7
/`1TQk<00P1TQk<7000000@0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0408^k
j`030000002Eb?P0ULSh0080ULSh0P00000309K;m`040000001n[]40000005IiS@D0n_3V0P000000
0`1IkJ`000000000000J0?[`iP030;0G7P3jl>H0n_3V07<0n_3V0@3oool00:P0n_3V102`5ah20?[`
iP8000000P0G8CD00`000000:CUE02TiE@02000000@0>E1`00<0000004MSR017HhP01017HhP01000
0000EWFN05IeWP1FMIh8000000<0I8Nc00@00000076Ia`1aVLL0LIW72000000307jZfP030000002;
^n/0Rk_[00@0Rk_[00<0000009G8n02Eb?P00`2Eb?P200000080U/_g00D0000007j^d@000000EWV=
000000050?[`iP80000000<0FNf/0000003jl>H06P3jl>H00`2`5ah0n_3V0?[`iP1b0?[`iP40oooo
002U0?[`iP<0/1LN1P3jl>H2000000805b4e0`0000000`0Y>ED0000003U@L00303U@L00300000017
HhP0Af>800<0Af>81@00000305IeWP030000001TQk<0I8Nc00D0I8Nc00<00000076Ia`1aVLL01@1a
VLL010000000OZ[J07jZfP1nZ]X5000000D0Rk_[00<0000009G8n02Eb?P00`2Eb?P00`000000U/_g
000000020000000407j^d@0000000000000000D0n_3V0`0000000`2`5ah0n_3V0?[`iP0I0?[`iP03
0;0G7P3jl>H0n_3V0780n_3V0@3oool009l0n_3V0P0000040;0G7PT0n_3V0P00000201LQ=@050000
000Y>ED0:CUE02TiE@000000100iD7000`000000Af>8000000030000000304MSR0000000EWFN00D0
EWFN00<0000006B7/`1TQk<01@1TQk<00`000000LIW7076Ia`05076Ia`030000001nZ]X0OZ[J00@0
OZ[J00<0000008^kj`0000000`0000000`2;^n/0000009G8n00409G8n0060000002FboL0U/_g09K;
m`000000OZkA0`0000090?[`iP030;0G7P3jl>H0n_3V01T0n_3V00<0/1LN0?[`iP3jl>H0L@3jl>H1
0?ooo`00W@3jl>H200000080/1LN3@3jl>H20000000301LQ=@000000000000<0:CUE00<0000003U@
L00iD7000P0iD702000000D0Af>800<0000005IeWP1FMIh0101FMIh00`000000I8Nc06B7/`0506B7
/`030000001aVLL0LIW700D0LIW700<0000007jZfP1nZ]X0101nZ]X00`000000Rk_[08^kj`0308^k
j`8000001@2Eb?P010000000U/_g09K;m`2FboL20000000307j^d@000000000000X0n_3V00<0/1LN
0?[`iP3jl>H06@3jl>H00`2`5ah0n_3V0?[`iP1`0?[`iP40oooo002K0?[`iP<0000000<0:iYU0000
000000003@3jl>H30000000301LQ=@000000:CUE0080:CUE00<0000003U@L00iD7000`00000604MS
R0030000001FMIh0EWFN00@0EWFN1`0000000`1TQk<00000076Ia`06076Ia`030000001nZ]X0OZ[J
00@0OZ[J00<0000008^kj`2;^n/0102;^n/3000000<0ULSh00@0000009K;m`2FboL0U/_g0P000000
0`1n[]4000000000000;0?[`iP030;0G7P3jl>H0n_3V01T0n_3V00<0/1LN0?[`iP3jl>H0K`3jl>H1
0?ooo`00V@3jl>H8000000d0n_3V0`0000000`0G8CD0000002TiE@0202TiE@<000000P0iD7000`00
0000Af>804MSR00404MSR0030000001FMIh0EWFN00@0EWFN00<0000006B7/`0000000`0000030;0G
7PL0LIW700<0000007jZfP1nZ]X01@1nZ]X00`000000Rk_[08^kj`0308^kj`030000002Eb?P0ULSh
0080000000<0ULSh0000002FboL00P2FboL00`000000OZkA00000002000000`0n_3V00<0/1LN0?[`
iP3jl>H0RP3jl>H10?ooo`00D03jl>H00`2`5ah0n_3V0?[`iP1K0?[`iP80000000<05b4e0000000Y
>ED00`0Y>ED00`000000>E1`03U@L00203U@L00300000017HhP0Af>800@0Af>800<0000005IeWP1F
MIh0101FMIh010000000I8Nc06B7/`1TQk<5000000H0/1LN00<0LIW70000001nZ]X01P1nZ]X00`00
0000Rk_[08^kj`0308^kj`030000002Eb?P0ULSh0080ULSh0P00000309K;m`030000001n[]40OZkA
008000003@3jl>H00`2`5ah0n_3V0?[`iP290?[`iP40oooo001@0?[`iP030;0G7P3jl>H0n_3V05/0
n_3V0P0000000`0G8CD0000002TiE@0202TiE@800000100iD7000`000000Af>804MSR00404MSR004
0000001FMIh0EWFN05IeWPT000001P1^UL@3000000D0/1LN101nZ]X00`000000Rk_[08^kj`0308^k
j`030000002Eb?P0ULSh00<0ULSh0P00000209K;m`030000001n[]40OZkA008000003P3jl>H00`2`
5ah0n_3V0?[`iP280?[`iP40oooo001?0?[`iP030;0G7P3jl>H0n_3V05`0n_3V0P0000000`0G8CD0
000002TiE@020000000302TiE@000000>E1`00<0>E1`00<0000004MSR017HhP00`17HhPR000000@0
Rk_[00@0000009G8n000000000000P2Eb?P00`000000U/_g0000000200000080OZkA0P00000?0?[`
iP030;0G7P3jl>H0n_3V08L0n_3V0@3oool004l0n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0
n_3V0?[`iP130?[`iP80000000<05b4e0000000000000`0Y>ED00`000000>E1`03U@L00203U@L004
00000017HhP0000000000080/1LN1P27]^P00`000000NjKG07^Ve`0407^Ve`030000001^UL@0KYG4
00@0KYG400<000000664/@1QQ;40101QQ;400`000000Dg>L05=cW00405=cW0<0000000<0Rk_[0000
002Eb?P01@00000309K;m`030000001n[]40OZkA00800000403jl>H00`2`5ah0n_3V0?[`iP260?[`
iP40oooo001?0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H0@`3jl>H200000003
01LQ=@000000:CUE0080:CUE00<0000003U@L00iD7000`0iD7040;0G7P0309?6n@000000QkKX00D0
QkKX00<0000007^Ve`1kY]L0101kY]L00`000000KYG406jEa00406jEa0030000001QQ;40HHBa00@0
HHBa00<0000005=cW01CLi`0101CLi`00`000000AV6704IQQ`0200000080ULSh00@0000005W/Z`00
000000000`2FboL20000000307j^d@00000000000140n_3V00<0/1LN0?[`iP3jl>H0Q@3jl>H10?oo
o`00CP3jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V04@0n_3V100000001@0Y>ED0
0000000000000000>E1`00@0/1LN0P00000309?6n@0300000027]^P0QkKX00@0QkKX00<0000007^V
e`1kY]L0101kY]L00`000000KYG406jEa00406jEa0030000001QQ;40HHBa00@0HHBa00<0000005=c
W01CLi`0101CLi`010000000AV6704IQQ`16HHL5000000030;0G7P000000U/_g0080U/_g0P000000
0`1n[]4000000000002I0?[`iP40oooo001>0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`
iP3jl>H0A03jl>H6000000<0/1LN0P000000102Ldol0000009?6n@2Ca_T20000000309?6n@000000
QkKX00D0QkKX00<0000007^Ve`1kY]L0101kY]L00`000000KYG406jEa00406jEa0030000001QQ;40
HHBa00D0HHBa00<0000005=cW01CLi`00`1CLi`010000000AV6700000000000204IQQ`<0000000<0
ULSh0;0G7P2FboL00P2FboL00`000000OZkA00000002000006l0n_3V00<000000?[`iP3jl>H09`3j
l>H10?ooo`00C@3jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V01L0n_3V00<0/1LN
0?[`iP3jl>H0:`3jl>H9000000<0W=?o00<0000009?6n@2Ca_T00P2Ca_T5000000<0QkKX00<00000
07^Ve`1kY]L0101kY]L00`000000KYG406jEa00406jEa0030000001QQ;40HHBa00D0HHBa00@00000
05=cW01CLi`0Dg>L1000000404IQQ`030000000iCg40>Dma0080000000@0/1LN09K;m`2FboL00000
0P1n[]42000006d0n_3V0`00000Y0?[`iP40oooo001=0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0
/1LN0?[`iP3jl>H05`3jl>H00`2`5ah0n_3V0?[`iP0[0?[`iP80000000@05b4e0000000Y>ED0:CUE
0P00000409cCo`030000002Ca_T0TlKi00<0TlKi00@0000008Nfj027]^P0QkKX1`00000307^Ve`03
0000001^UL@0KYG400@0KYG400<000000664/@1QQ;400P1QQ;4700000080Dg>L00<0000004IQQ`16
HHL00`16HHL00`000000>Dma03U?L@0203U?L@040000002`5ah0U/_g00000080OZkA0P00001D0?[`
iP030000003jl>H0n_3V01@0n_3V1000000Z0?[`iP40oooo001=0?[`iP030;0G7P3jl>H0n_3V01H0
n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP0/0?[`iP80000000D05b4e0000000Y
>ED0000009[Bo`0300000080W=?o00<0000009?6n@2Ca_T00`2Ca_T00`000000QkKX08Nfj00408Nf
j0040000001kY]L0NjKG07^Ve`l000000`1QQ;400`000000Dg>L05=cW00305=cW00300000016HHL0
AV6700<0AV6700<0000003U?L@0iCg4010000000102`5ah0000007j^d@1n[]4200000580n_3V0`00
000D0?[`iP<0000000<04F0[000000000000:P3jl>H10?ooo`00C03jl>H00`2`5ah0n_3V0?[`iP0F
0?[`iP030;0G7P3jl>H0n_3V01L0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0?[`iP0D
0?[`iP80000000<05b4e0000000000000P2Jd_l00`000000W=?o09cCo`03000000D0TlKi00<00000
08Nfj027]^P01027]^P00`000000NjKG07^Ve`0407^Ve`030000001^UL@0KYG400@0KYG400<00000
0664/@1QQ;401@1QQ;400`000000Dg>L05=cW00305=cW00300000016HHL0AV6700<0AV670`000002
03U?L@040000000X>5@0:3QD0;0G7P80OZkA0P00001@0?[`iP@000004`3jl>H400000004015P:`00
00000000000002X0n_3V0@3oool004`0n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`
iP0F0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H0503jl>H20000000301LQ=@00
0000V];o0080V];o00<0000009cCo`2Ldol00P2Ldol00`000000TlKi09?6n@0309?6n@0300000027
]^P0QkKX00@0QkKX00<0000007^Ve`1kY]L0101kY]L00`000000KYG406jEa00406jEa0030000001Q
Q;40HHBa00D0HHBa00<0000005=cW01CLi`00`1CLi`00`000000AV6704IQQ`0204IQQ`800000100i
Cg401P000000:3QD02PhE00X>5@0000007j^d@800000>03jl>H00`000000n_3V0?[`iP0C0?[`iP<0
000000<045lZ0000000000004P3jl>H00`00000000`000000002015P:`030000001>hZH0000002/0
n_3V0@3oool004`0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0?[`iP0G0?[`iP030;0G
7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H4000000<0V];o00<0000009cCo`2Ldol0
0P2Ldol3000000<0TlKi00<0000008Nfj027]^P01027]^P00`000000NjKG07^Ve`0407^Ve`030000
001^UL@0KYG400@0KYG400<000000664/@1QQ;401@1QQ;400`000000Dg>L05=cW00305=cW0030000
0016HHL000000080000000<0AV670000000iCg400`0iCg401P000000:3QD02PhE00X>5@0000007j^
d@800000=P3jl>H3000001@0n_3V00@00000000;0000000045lZ0P00000B0?[`iP03000000003000
000000804F0[00@0000004kRYP0000000000:`3jl>H10?ooo`00B`3jl>H00`2`5ah0n_3V0?[`iP0F
0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP0E
0?[`iPD000000P2Jd_l00`000000W=?o09cCo`0209cCo`030000002Ca_T0TlKi0080000000<0TlKi
00000027]^P01@27]^P00`000000NjKG07^Ve`0407^Ve`030000001^UL@0KYG400@0KYG400<00000
0664/@1QQ;401@1QQ;400`000000Dg>L05=cW00205=cW0<000001016HHL00`000000>Dma03U?L@02
03U?L@030000000X>5@0:3QD00D000007P3jl>H00`000000n_3V0?[`iP0C0?[`iPD000004`3jl>H3
00000004011O:P000000C^:V00000180n_3V0P000002015P:`030000001>hZH0C^:V00800000:`3j
l>H10?ooo`00B`3jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN
0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP050000002`5ah0OZoB0000002Jd_l00`00
000409cCo`030000002Ca_T0TlKi0080TlKi1@00000308Nfj0030000001kY]L0NjKG00@0NjKG00<0
000006jEa01^UL@0101^UL@00`000000HHBa0664/@050664/@030000001CLi`000000080000000<0
Dg>L00000016HHL01016HHL00`000000>Dma03U?L@0203U?L@<0000000<0:3QD0000000G8SL00P00
000L0?[`iP<00000503jl>H5000001@0n_3V00@00000011O:P0@GbX000000P1>hZH00`000000n_3V
0?[`iP0?0?[`iP050000000AH2/04F0[015P:`0000000`1>hZH00`000000n_3V0?[`iP0Z0?[`iP40
oooo001:0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V
0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00@0/1LN0000001n[m8000000`2Jd_l00`000000
W=?o09cCo`0209cCo`030000002Ca_T0TlKi00<0TlKi00@0000008Nfj027]^P0QkKX1`00000307^V
e`030000001^UL@0KYG400@0KYG400<000000664/@1QQ;400P1QQ;45000000@0Dg>L00<0000004IQ
Q`16HHL00`16HHL00`000000>Dma03U?L@0203U?L@060000000X>5@0:3QD02PhE00000005b8g0P00
000J0?[`iP@00000503jl>H20000008045dY0P00000C0?[`iP070000000@GbX045lZ011O:P000000
C^:V0000000C0?[`iP040000000AH2/04F0[00000080C^:V0P00000/0?[`iP40oooo001:0?[`iP03
0;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP03
0;0G7P3jl>H0n_3V01H0n_3V00@0/1LN0000001n[m8000000`2Jd_l300000080W=?o00<0000009?6
n@2Ca_T00`2Ca_T00`000000QkKX08Nfj00408Nfj0040000001kY]L0NjKG07^Ve`l000000`1QQ;40
0`000000Dg>L05=cW00305=cW00300000016HHL0AV6700<0AV6700<0000003U?L@0iCg400`000003
02PhE0@000000`3jl>H00`000000n_3V0?[`iP0C0?[`iP80000000<03e`X000000000000503jl>H0
1P00000045dY011M:@000000C^:V000001@0n_3V00<00000011O:P0000000P1>hZH00`000000n_3V
0?[`iP0A0?[`iP030000002`5ah0000000<0C^:V00<000000?[`iP3jl>H0:`3jl>H10?ooo`00BP3j
l>H00`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H05P3j
l>H00`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P0000000000008000000`2Jd_l00`000000W=?o09cC
o`03000000D0TlKi00<0000008Nfj027]^P01027]^P00`000000NjKG07^Ve`0407^Ve`030000001^
UL@0KYG400@0KYG400<000000664/@1QQ;401@1QQ;400`000000Dg>L05=cW00305=cW00300000016
HHL0AV6700<0AV670`00000203U?L@040000000X>5@0:3QD02PhE0@0000000@0n_3V000000000000
00005@3jl>H00`0000003e`X00000002000001D0n_3V00@00000011M:@00000000005P3jl>H20000
000304kRYP000000n_3V01<0n_3V00<0/1LN0000000000000P1>hZH2000002d0n_3V0@3oool004T0
n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V01H0
n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V00000003000000<0V];o00<0000009cCo`2L
dol00P2Ldol2000000@0TlKi00<0000008Nfj027]^P01027]^P00`000000NjKG07^Ve`0407^Ve`03
0000001^UL@0KYG400@0KYG400<000000664/@1QQ;401@1QQ;400`000000Dg>L05=cW00305=cW003
00000016HHL0AV670080AV670P00000403U?L@060000000X>5@0:3QD02PhE00000005b8g0`000000
0`0>FRH000000000000F0?[`iP<000005P3jl>H0102`5ah0000000000000000E0?[`iP030;0G7P3j
l>H0n_3V008000004`3jl>H0102`5ah0n_3V0?[`iP3jl>H3000002h0n_3V0@3oool004T0n_3V00<0
/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V01L0n_3V00<0
/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0000000207j_dP050000002Jd_l0V];o09[Bo`000000
102Ldol00`000000TlKi000000020000000309?6n@000000QkKX00D0QkKX00<0000007^Ve`1kY]L0
101kY]L00`000000KYG406jEa00406jEa0030000001QQ;40HHBa00D0HHBa00<0000005=cW01CLi`0
0`1CLi`00`000000AV67000000020000000304IQQ`000000>Dma00<0>Dma00D0000002PhE00X>5@0
:3QD0000000201LR=`040000003jl>H0/1LN000001H0n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`
5ah0n_3V0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H0<P3jl>H10?oo
o`00B@3jl>H00`2`5ah0n_3V0?[`iP0C0?[`iP80000000<0/1LN0?[`iP3jl>H0503jl>H200000003
0;0G7P000000n_3V01@0n_3V0P0000000`2`5ah0n_3V0?[`iP0D0?[`iP050000002`5ah000000?[`
iP0000000P1n[m8200000080V];o00<0000009cCo`2Ldol00P2Ldol00`000000TlKi09?6n@0209?6
n@<000001@27]^P00`000000NjKG07^Ve`0407^Ve`030000001^UL@0KYG400@0KYG400<000000664
/@1QQ;401@1QQ;400`000000Dg>L05=cW00205=cW0<000001016HHL00`000000>Dma03U?L@0203U?
L@030000000X>5@0:3QD008000000P0G8SL00`000000/1LN0?[`iP0G0?[`iP030;0G7P3jl>H0n_3V
01H0n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V
03<0n_3V0@3oool004D0n_3V0`0000000`2`5ah000000?[`iP0C0?[`iP80000000<0C^6U0;0G7P00
0000503jl>H2000000030;0G7P000000000001@0n_3V0P0000000`1>hJD0/1LN0?[`iP0E0?[`iP03
0000002`5ah00000008000000P1n[m800`000000V];o00000002000000@0W=?o00<0000009?6n@2C
a_T00`2Ca_T00`000000QkKX000000030000000308Nfj0000000NjKG00D0NjKG00<0000006jEa01^
UL@0101^UL@00`000000HHBa0664/@050664/@030000001CLi`000000080000000<0Dg>L00000016
HHL01016HHL00`000000>Dma03U?L@0203U?L@<0000000D0:3QD0000000G8SL05b8g0;0G7P0H0?[`
iP030;0G7P3jl>H0n_3V01H0n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP0E0?[`
iP030;0G7P3jl>H0n_3V03@0n_3V0@3oool004@0n_3V0P00000204kQY@030;0G7P000000n_3V01<0
n_3V0P0000000`1>hJD0/1LN0000000D0?[`iP80000000@0/1LN0000000<DR0000004`3jl>H20000
00030;0G7P0<E240000001D0n_3V0`0000001@3jl>H0000007j_dP1n[m80000000<0V];o00<00000
09cCo`2Ldol00P2Ldol00`000000TlKi09?6n@0309?6n@0300000027]^P0QkKX00<0QkKX1@000003
07^Ve`030000001^UL@0KYG400@0KYG400<000000664/@1QQ;400P1QQ;45000000@0Dg>L00<00000
04IQQ`16HHL00`16HHL00`000000>Dma03U?L@0203U?L@050000000X>5@0:3QD02PhE00000000P0G
8SL00`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H05P3j
l>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V03D0n_3V0@3oool004<0n_3V00P00000
03W=HP000000C^6U0;0G7P0000002dlM00000180n_3V00L0000003;3EP000000/1LN0000000;DAh0
000001<0n_3V00<000000;0G7P0000000P0<DR000`000000n_3V0?[`iP0A0?[`iP80000000<0/1LN
0000003jl>H05@3jl>H00`000000n_3V0?[`iP020?[`iP030000001n[m80000000<0V];o0`000002
09cCo`030000002Ca_T0TlKi00<0TlKi00<0000008Nfj027]^P01027]^P010000000NjKG07^Ve`1k
Y]L?000000<0HHBa00<0000005=cW01CLi`00`1CLi`00`000000AV6704IQQ`0304IQQ`030000000i
Cg40>Dma00<000000`0X>5@00`0000005b8g0;0G7P0H0?[`iP030;0G7P3jl>H0n_3V01H0n_3V00<0
/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V03H0n_3V0@3o
ool004<0n_3V00P0000003W=HP000000C^6U0;0G7P0000002dlM00000180n_3V00@0000003;3EP00
0000/1LN0P0;DAh00`000000n_3V0?[`iP0A0?[`iP030000002`5ah00000008000005@3jl>H20000
01`0n_3V00<0000007j_dP0000000`2Jd_l00`000000W=?o09cCo`03000000D0TlKi00<0000008Nf
j027]^P01027]^P00`000000NjKG07^Ve`0407^Ve`030000001^UL@0KYG400@0KYG400<000000664
/@1QQ;401@1QQ;400`000000Dg>L05=cW00305=cW00300000016HHL0AV6700<0AV670`00000203U?
L@060000000X>5@0:3QD02PhE0000000/1LN603jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P3j
l>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`iP0f0?[`iP40oooo0013
0?[`iP<0000000<0C^6U0;0G7P0;Cad00P0;Cad00`000000n_3V0?[`iP0?0?[`iP80000000@0/1LN
0000000;DAh00000503jl>H4000001H0n_3V00<000000?[`iP3jl>H0703jl>H2000000<0V];o00<0
000009cCo`2Ldol00P2Ldol2000000@0TlKi00<0000008Nfj027]^P01027]^P00`000000NjKG07^V
e`0407^Ve`030000001^UL@0KYG400@0KYG400<000000664/@1QQ;401@1QQ;400`000000Dg>L05=c
W00305=cW00300000016HHL0AV670080AV670P00000403U?L@040000000X>5@0:3QD02PhE0800000
603jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H0
5P3jl>H00`2`5ah0n_3V0?[`iP0g0?[`iP40oooo00130?[`iP<0000000D0/1LN0000000;Cad02dlM
0000000B0?[`iP80000000@0/1LN0000000000000000503jl>H2000003P0n_3V00D0000009[Bo`2J
d_l0V];o0000000409cCo`030000002Ca_T000000080000000<0TlKi00000027]^P01@27]^P00`00
0000NjKG07^Ve`0407^Ve`030000001^UL@0KYG400@0KYG400<000000664/@1QQ;401@1QQ;400`00
0000Dg>L05=cW00305=cW00300000016HHL000000080000000<0AV670000000iCg40100iCg401000
0000:3QD02PhE000000H0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H05P3jl>H0
0`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V03P0n_3V0@3oool004<0n_3V00@00000000M
00000000/1LN0`00000D0?[`iP040000000OVd/07i];000001D0n_3V00<000000?[`iP3jl>H0>03j
l>H010000000V];o09[Bo`00000409cCo`030000002Ca_T0TlKi0080TlKi0`00000508Nfj0030000
001kY]L0NjKG00@0NjKG00<0000006jEa01^UL@0101^UL@00`000000HHBa0664/@050664/@030000
001CLi`0Dg>L0080Dg>L0`00000404IQQ`030000000iCg40>Dma00<0>Dma00<0000002PhE0000000
6@3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H0
5@3jl>H00`2`5ah0n_3V0?[`iP0i0?[`iP40oooo00140?[`iP8000000P0NVTX00`000000n_3V0?[`
iP0C0?[`iP<00000D@3jl>H0102`5ah0000000000000000409cCo`030000002Ca_T0TlKi00<0TlKi
00<0000008Nfj00000000`0000000`27]^P0000007^Ve`0507^Ve`030000001^UL@0KYG400@0KYG4
00<000000664/@1QQ;401@1QQ;400`000000Dg>L000000020000000305=cW0000000AV6700@0AV67
00<0000003U?L@0iCg400`0iCg42000001T0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V
0?[`iP0E0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H0>P3jl>H10?ooo`00A03j
l>H20000000301jJBP000000n_3V01D0n_3V00<000000?[`iP3jl>H0DP3jl>H20;0G7P030000002L
dol0W=?o0080W=?o00<0000009?6n@2Ca_T00`2Ca_T00`000000QkKX08Nfj00308Nfj0D000000`1k
Y]L00`000000KYG406jEa00406jEa0030000001QQ;40HHBa0080HHBa1@00000405=cW00300000016
HHL0AV6700@0AV6700<0000003U?L@0iCg400P0iCg400`000000n_3V0?[`iP0_0?[`iP030;0G7P3j
l>H0n_3V01D0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0?[`iP0k0?[`iP40oooo0014
0?[`iP030000000NVTX0000006h0n_3V00<0/1LN0000000000000P2Ldol00`000000TlKi09?6n@03
09?6n@0300000027]^P0QkKX00@0QkKX00@0000007^Ve`1kY]L0NjKG3`0000030664/@030000001C
Li`0Dg>L00<0Dg>L00<0000004IQQ`16HHL01016HHL00`000000>Dma03U?L@02000000030?[`iP00
0000000002l0n_3V00<0/1LN0?[`iP3jl>H0503jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P3j
l>H0n_3V03/0n_3V0@3oool004@0n_3V0P00001`0?[`iP030;0G7P3jl>H00000008000001@2Ca_T0
0`000000QkKX08Nfj00408Nfj0030000001kY]L0NjKG00@0NjKG00<0000006jEa01^UL@0101^UL@0
0`000000HHBa0664/@050664/@030000001CLi`0Dg>L00@0Dg>L00<0000004IQQ`16HHL00`16HHL7
000002l0n_3V00<0/1LN0?[`iP3jl>H0503jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P3jl>H0
n_3V03`0n_3V0@3oool004@0n_3V00<000000?[`iP3jl>H0L03jl>H00`2`5ah0n_3V000000020000
00@0TlKi00<0000008Nfj027]^P01027]^P00`000000NjKG07^Ve`0407^Ve`030000001^UL@0KYG4
00@0KYG400<000000664/@1QQ;401@1QQ;400`000000Dg>L05=cW00405=cW00300000016HHL0AV67
0080AV670P0000030;0G7P030000003jl>H0n_3V04H0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`
5ah0n_3V0?[`iP0m0?[`iP40oooo002N0?[`iP030;0G7P3jl>H0n_3V01L0n_3V0P2`5ah00`000000
n_3V000000020000000309?6n@000000QkKX00D0QkKX00<0000007^Ve`1kY]L0101kY]L00`000000
KYG406jEa00406jEa0030000001QQ;40HHBa00D0HHBa00<0000005=cW01CLi`0101CLi`00`000000
AV670;0G7P040;0G7T/0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H00`2`5ah0n_3V0?[`iP0n0?[`iP40
oooo002O0?[`iP030;0G7P3jl>H0n_3V01H0n_3V0P0000000`2`5ah0n_3V0?[`iP020?[`iP<00000
1@27]^P00`000000NjKG07^Ve`0407^Ve`030000001^UL@0KYG400@0KYG400<000000664/@1QQ;40
1@1QQ;400`000000Dg>L05=cW00305=cW0<0/1LNC`3jl>H00`2`5ah0n_3V0?[`iP0E0?[`iP030;0G
7P3jl>H0n_3V03l0n_3V0@3oool00:00n_3V00<0/1LN0?[`iP3jl>H05`3jl>H2000000H0n_3V1000
00000`27]^P0000007^Ve`0507^Ve`030000001^UL@0KYG400@0KYG400<000000664/@1QQ;401@1Q
Q;400`000000Dg>L00000002000000030;0G7P3jl>H0n_3V06P0n_3V00<0/1LN0?[`iP3jl>H0?`3j
l>H10?ooo`00X@3jl>H20;0G7R<0n_3V0P0000020;0G7P050000001kY]L0NjKG07^Ve`0000001P1^
UL@00`000000HHBa0664/@020664/@D00000K@3jl>H00`2`5ah0n_3V0?[`iP100?[`iP40oooo002S
0?[`iP030;0G7P3jl>H0n_3V02@0n_3V1P2`5ah:00000740n_3V00<0/1LN0?[`iP3jl>H0@@3jl>H1
0?ooo`00Y03jl>H00`2`5ah0n_3V0?[`iP0Y0?[`iPD0/1LN1000000V0?[`iPP00000R03jl>H10?oo
o`00R`3jl>H00`2`5ah0n_3V0?[`iP0G0?[`iP030;0G7P3jl>H0n_3V02`0n_3V0`00000X0?[`iP03
0000000BGB00000000@00000R@3jl>H10?ooo`00S03jl>H00`2`5ah0n_3V0?[`iP0G0?[`iP030;0G
7P3jl>H0n_3V05@0n_3V0`2`5ah010000000@Kn500000000002;0?[`iP40oooo002=0?[`iP80/1LN
603jl>H20;0G7P<00000C03jl>H50;0G7P<0n_3V0P00002=0?[`iP40oooo002?0?[`iP030;0G7P3j
l>H0n_3V01H0n_3V00@000000;0G7P0000000000B03jl>H40;0G7YL0n_3V0@3oool00900n_3V00<0
/1LN0?[`iP3jl>H05@3jl>H2000000030;0G7P00000000000480n_3V1@2`5ajK0?[`iP40oooo001g
0?[`iP030;0G7P3jl>H0n_3V01L0n_3V0P2`5ahE0?[`iP<0000000<0F_n_0000003jl>H0?P3jl>H3
0;0G7Z00n_3V0@3oool007P0n_3V00<0/1LN0?[`iP3jl>H0603jl>H00`2`5ah0n_3V0?[`iP0E0?[`
iP<00000HP3jl>H;000007@0n_3V0@3oool007T0n_3V0P2`5ahI0?[`iP030;0G7P3jl>H0n_3V07T0
n_3V00<0000001=O8@0CGb401`00001e0?[`iP40oooo001k0?[`iP030;0G7P3jl>H0n_3V01L0n_3V
0P2`5ahZ0?[`iP@0/1LNBP3jl>H20;0G7P8000000P11_hD3000007L0n_3V0@3oool007`0n_3V00<0
/1LN0?[`iP3jl>H0603jl>H00`2`5ah0n_3V0?[`iP0[0?[`iPL0/1LN2P3jl>H2000003<0n_3V102`
5ah0103jl>H00000046oQ@11_hD3000007T0n_3V0@3oool006@0n_3V00<0/1LN0?[`iP3jl>H05P3j
l>H20;0G7QT0n_3V00<0/1LN0?[`iP000000<@3jl>H70;0G7P80n_3V1P00000]0?[`iP<0/1LN1P3j
l>H3000007/0n_3V0@3oool006D0n_3V00<0/1LN0?[`iP3jl>H05`3jl>H00`2`5ah0n_3V0?[`iP0G
0?[`iP80/1LN0P00000f0?[`iP@0/1LN1P00000W0?[`iP@0/1LNQ`3jl>H10?ooo`00IP3jl>H20;0G
7QP0n_3V00<0/1LN0?[`iP3jl>H05@3jl>H010000000EnNW05OWY`2`5ah2000003L0n_3V1000000W
0?[`iP@0/1LNR`3jl>H10?ooo`00J03jl>H00`2`5ah0n_3V0?[`iP0F0?[`iP030;0G7P3jl>H0n_3V
01@0n_3V0`0000000`1GijL0/1LN0000001O0?[`iP<0/1LN8@3jl>H>00000600n_3V0@3oool006T0
n_3V00<0/1LN0?[`iP3jl>H05P3jl>H20;0G7Q@0n_3V100000000`1Kok0000000000001J0?[`iP@0
/1LN903jl>H00`000000560S01AP8`0401AP8`H00000H@3jl>H10?ooo`00JP3jl>H20;0G7QP0n_3V
00<0/1LN0?[`iP3jl>H04`3jl>H5000005P0n_3V0P2`5ahX0?[`iP030000000DH2<0560S00@00000
0P11_h@2000006<0n_3V0@3oool006`0n_3V00<0/1LN0?[`iP3jl>H05P3jl>H00`2`5ah0n_3V0?[`
iP0F0?[`iP800000O`3jl>H20;0G7P<000001011_h@2000006D0n_3V0@3oool006d0n_3V00<0/1LN
0?[`iP3jl>H05P3jl>H20;0G7Y<0n_3V102`5ah30?[`iP0400000011_h@0@Kn4046oQ0800000I`3j
l>H10?ooo`00KP3jl>H00`2`5ah0n_3V0?[`iP0G0?[`iP050;0G7P3jl>H0n_3V0?[`iP000000;P3j
l>H40;0G7UP0n_3V102`5ah70?[`iP0400000011_h@00000000006T0n_3V0@3oool006l0n_3V0P2`
5ahH0?[`iP040;0G7P000000000005KVYP800000<03jl>H70;0G7Q40n_3V0P00000j0?[`iP@0/1LN
303jl>H00`000000n_3V0?[`iP1Y0?[`iP40oooo001a0?[`iP030;0G7P3jl>H0n_3V01D0n_3V00@0
00000;0G7P2`5ah0E^JV0`00000f0?[`iPP0/1LN2@3jl>H0100000004U<H00000000000d0?[`iP@0
/1LN7`3jl>H@000004d0n_3V0@3oool00780n_3V00<0/1LN0?[`iP3jl>H0503jl>H3000000040;0G
7P1FiZH00000000003h0n_3V1`2`5ah20?[`iP<0000000<04U<H000000000000;P3jl>H40;0G7R<0
n_3V00<0000001AR900DHR@01@0DHR@7000004h0n_3V0@3oool007<0n_3V0P2`5ahD0?[`iP080000
000mZUd0?JYM0000002`5ah0000002RF>P0000140?[`iP@0/1LN00<0B<9n0000000000000`00000X
0?[`iP@0/1LN9`3jl>H00`000000568T01AR9005000000<0@Kj40P00001@0?[`iP40oooo001e0?[`
iP030;0G7P3jl>H0n_3V0140n_3V0P000000100mZUd000000000001Kok42000004D0n_3V2`00000R
0?[`iP@0/1LN:P3jl>H0102`5ah00000000000000006046nQ0800000DP3jl>H10?ooo`00MP3jl>H0
0`2`5ah0n_3V0?[`iP0A0?[`iP<000000`1Kok42000004D0n_3V1@00000T0?[`iP<0/1LN:P3jl>H4
0;0G7P030?[`iP000000@Kj400D0@Kj40P00001D0?[`iP40oooo001g0?[`iP030;0G7P3jl>H0n_3V
01<0n_3V1@00002G0?[`iP@0/1LN1@3jl>H00`000000@Kj4046nQ002046nQ0800000EP3jl>H10?oo
o`00N03jl>H20;0G7P@0n_3V00<000000?[`iP3jl>H0403jl>H200000980n_3V102`5ah:0?[`iP04
00000011_X@00000000005P0n_3V0@3oool007X0n_3V00D0/1LN0?[`iP000000000005KUY@020000
0:00n_3V102`5ah>0?[`iP800000FP3jl>H10?ooo`00N`3jl>H00`2`5ah0E^FU05KUY@0205KUY@80
0000<`3jl>H40;0G7V@0n_3V102`5ai^0?[`iP40oooo001k0?[`iP030000002`5ah0/1LN0080E^FU
0P00000g0?[`iPL0/1LNF@3jl>H40;0G7W80n_3V0@3oool007/0n_3V00P0000003j[G`0nZel0/1LN
05KUY@000000;9a1000003d0n_3V1`2`5ahB0?[`iP800000>P3jl>H40;0G7WH0n_3V0@3oool007/0
n_3V0P000000100nZel000000;0G7P1Lok<2000004@0n_3V202`5ah90?[`iPH00000<`3jl>H40;0G
7WX0n_3V0@3oool007`0n_3V0`00000305co/`800000B`3jl>H70;0G7P80n_3V00@0000003BOH@00
0000B<9n1000000]0?[`iP@0/1LNOP3jl>H10?ooo`00O`3jl>H200000080G?nc0P00001A0?[`iP@0
/1LN1@18`Wh4000002L0n_3V0`2`5aj20?[`iP40oooo00210?[`iP@00000D`3jl>H=00000:X0n_3V
0@3oool008@0n_3V0P00001B0?[`iP0400000015hID0AN6E04GQU@H00000[@3jl>H10?ooo`00f03j
l>H400000;<0n_3V0@3oool00;00n_3V102`5akK0?[`iP40oooo002d0?[`iPL0/1LNe03jl>H10?oo
o`00^`3jl>H70;0G7QT0n_3V0P00002b0?[`iP40oooo00320?[`iPP0/1LN403jl>H20000000301AG
6`00000000000;00n_3V0@3oool00<X0n_3V1`2`5ah90?[`iP<000000P0DEa/200000:h0n_3V0@3o
ool00=40n_3V1`2`5ah20?[`iP80000000D0Al9n000000000000000001AG6`0200000:`0n_3V0@3o
ool00=P0n_3V102`5ah404O2OPD00000ZP3jl>H10?ooo`00f@3jl>H00`000000=:1Q0000000804O2
OP<00000Z03jl>H10?ooo`00f@3jl>H@00000:H0n_3V0@3oool00=T0n_3V0P00000304CQU0L00000
ZP3jl>H10?ooo`00fP3jl>H400000;40n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`
iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o
0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V
0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0
n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H1
0?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3j
l>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40
oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {413.563, 0}} -> {0.0318749, -4.61197*^-06, \
0.00223036, 0.00223036}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(plot1 = 
        Draw3DItems[\[IndentingNewLine]{BarChart3D[{{1, 2, 3}, {4, 5, 6}}] // 
              DrawGraphics3D}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
              1}, \[IndentingNewLine]Axes \[Rule] True];\)\)\)], "Input",
  CellLabel->"In[25]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 5.12828e-017 1.16608 [
[.09072 .22988 -17.7473 -9 ]
[.09072 .22988 .25272 0 ]
[.21906 .17566 -5.65366 -9 ]
[.21906 .17566 .34634 0 ]
[.3545 .11847 -16.1747 -9 ]
[.3545 .11847 1.82534 0 ]
[.49765 .05807 -5.12945 -9 ]
[.49765 .05807 .87055 0 ]
[.64919 -0.00583 -14.602 -9 ]
[.64919 -0.00583 3.39797 0 ]
[.00955 .82643 -3.46362 0 ]
[.00955 .82643 2.53638 9 ]
[.1357 .91488 -3.34141 0 ]
[.1357 .91488 2.65859 9 ]
[.2472 .99305 -3.23852 0 ]
[.2472 .99305 2.76148 9 ]
[.34647 1.06263 -3.15071 0 ]
[.34647 1.06263 2.84929 9 ]
[.07325 .26228 -6 -2.6177 ]
[.07325 .26228 0 6.3823 ]
[.04822 .41894 -6 -2.75702 ]
[.04822 .41894 0 6.24298 ]
[.0202 .59437 -6 -2.91482 ]
[.0202 .59437 0 6.08518 ]
[-0.01139 .79218 -6 -3.09501 ]
[-0.01139 .79218 0 5.90499 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0.5)] .09072 .22988 .97192 1 Mshowa
.22871 .18658 m
.23354 .19204 L
s
[(1)] .21906 .17566 .88455 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(1.5)] .3545 .11847 .79718 1 Mshowa
.50609 .06995 m
.51031 .07589 L
s
[(2)] .49765 .05807 .70982 1 Mshowa
.65689 .00654 m
.66074 .01273 L
s
[(2.5)] .64919 -0.00583 .62245 1 Mshowa
.125 Mabswid
.12591 .22981 m
.12892 .23297 L
s
.1512 .21917 m
.15419 .22236 L
s
.17676 .20842 m
.17972 .21164 L
s
.2026 .19756 m
.20553 .20081 L
s
.25511 .17548 m
.25797 .17879 L
s
.28179 .16426 m
.28462 .1676 L
s
.30875 .15292 m
.31155 .15628 L
s
.33602 .14146 m
.33878 .14485 L
s
.39145 .11815 m
.39414 .1216 L
s
.41963 .1063 m
.42229 .10978 L
s
.44813 .09432 m
.45074 .09783 L
s
.47695 .0822 m
.47952 .08574 L
s
.53556 .05756 m
.53805 .06115 L
s
.56537 .04502 m
.56782 .04865 L
s
.59553 .03235 m
.59793 .036 L
s
.62603 .01952 m
.62839 .0232 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.13735 .90039 m
.13817 .89315 L
s
[(1)] .1357 .91488 .1138 -1 Mshowa
.24836 .97852 m
.24893 .97125 L
s
[(2)] .2472 .99305 .07951 -1 Mshowa
.3472 1.04807 m
.34757 1.0408 L
s
[(3)] .34647 1.06263 .05024 -1 Mshowa
.125 Mabswid
.03819 .83061 m
.03882 .82629 L
s
.06393 .84873 m
.06453 .8444 L
s
.08902 .86639 m
.08958 .86205 L
s
.11348 .8836 m
.11401 .87926 L
s
.16063 .91678 m
.16109 .91243 L
s
.18335 .93277 m
.18378 .92842 L
s
.20553 .94838 m
.20594 .94403 L
s
.2272 .96362 m
.22757 .95927 L
s
.26903 .99307 m
.26935 .9887 L
s
.28924 1.00729 m
.28953 1.00292 L
s
.30899 1.02119 m
.30926 1.01682 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.36568 1.06108 m
.36588 1.05671 L
s
.38377 1.07381 m
.38394 1.06944 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.0867 .25665 m
.09342 .25384 L
s
[(0)] .07325 .26228 1 -0.41829 Mshowa
.06181 .41367 m
.06861 .41104 L
s
[(2)] .04822 .41894 1 -0.38733 Mshowa
.03395 .58953 m
.04082 .58711 L
s
[(4)] .0202 .59437 1 -0.35226 Mshowa
.00252 .78784 m
.00948 .78567 L
s
[(6)] -0.01139 .79218 1 -0.31222 Mshowa
.125 Mabswid
.08073 .29431 m
.08477 .29265 L
s
.0746 .333 m
.07865 .33137 L
s
.0683 .37277 m
.07236 .37117 L
s
.05515 .45574 m
.05924 .45419 L
s
.04829 .49904 m
.05239 .49752 L
s
.04122 .54362 m
.04533 .54213 L
s
.02645 .63684 m
.03058 .63543 L
s
.01872 .68562 m
.02287 .68424 L
s
.01075 .73593 m
.01491 .73458 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.672 .728 .891 r
.65504 .5055 m .42216 .58164 L .34338 .50111 L p F P
0 g
s
.573 .367 .563 r
.66477 .73412 m .65504 .5055 L .42216 .58164 L p F P
0 g
s
.573 .367 .563 r
.42216 .58164 m .41465 .80504 L .66477 .73412 L p F P
0 g
s
.938 .685 .528 r
.34338 .50111 m .42216 .58164 L .41465 .80504 L p F P
0 g
s
.672 .728 .891 r
.91022 .42206 m .65504 .5055 L .58428 .41724 L p F P
0 g
s
.573 .367 .563 r
.97657 .93008 m .91022 .42206 L .65504 .5055 L p F P
0 g
s
.573 .367 .563 r
.65504 .5055 m .6761 1.00015 L .97657 .93008 L p F P
0 g
s
.672 .728 .891 r
.34338 .50111 m .58428 .41724 L .65504 .5055 L p F P
0 g
s
.938 .685 .528 r
.41465 .80504 m .32951 .73002 L .34338 .50111 L p F P
0 g
s
.656 .751 .92 r
.66477 .73412 m .41465 .80504 L .32951 .73002 L p F P
0 g
s
.656 .751 .92 r
.32951 .73002 m .5889 .65133 L .66477 .73412 L p F P
0 g
s
.966 .687 .452 r
.58428 .41724 m .65504 .5055 L .6761 1.00015 L p F P
0 g
s
.966 .687 .452 r
.58428 .41724 m .65504 .5055 L .66477 .73412 L p F P
0 g
s
.558 .344 .546 r
.5889 .65133 m .58428 .41724 L .34338 .50111 L p F P
0 g
s
.558 .344 .546 r
.34338 .50111 m .32951 .73002 L .5889 .65133 L p F P
0 g
s
.672 .728 .891 r
.58428 .41724 m .34338 .50111 L .25661 .4124 L p F P
0 g
s
.558 .344 .546 r
.58728 .56926 m .58428 .41724 L .34338 .50111 L p F P
0 g
s
.558 .344 .546 r
.34338 .50111 m .33436 .64995 L .58728 .56926 L p F P
0 g
s
.938 .685 .528 r
.25661 .4124 m .34338 .50111 L .33436 .64995 L p F P
0 g
s
.672 .728 .891 r
.58428 .41724 m .84947 .32491 L .91022 .42206 L p F P
0 g
s
.973 .663 .31 r
.84947 .32491 m .91022 .42206 L .97657 .93008 L p F P
0 g
s
.558 .344 .546 r
.90883 .84708 m .84947 .32491 L .58428 .41724 L p F P
0 g
s
.966 .687 .452 r
.6761 1.00015 m .59432 .926 L .58428 .41724 L p F P
0 g
s
.966 .687 .452 r
.66477 .73412 m .5889 .65133 L .58428 .41724 L p F P
0 g
s
.558 .344 .546 r
.58428 .41724 m .59432 .926 L .90883 .84708 L p F P
0 g
s
.672 .728 .891 r
.84947 .32491 m .58428 .41724 L .50596 .31957 L p F P
0 g
s
.558 .344 .546 r
.89747 .74713 m .84947 .32491 L .58428 .41724 L p F P
0 g
s
.558 .344 .546 r
.58428 .41724 m .59241 .8293 L .89747 .74713 L p F P
0 g
s
.672 .728 .891 r
.25661 .4124 m .50596 .31957 L .58428 .41724 L p F P
0 g
s
.938 .685 .528 r
.33436 .64995 m .2426 .56459 L .25661 .4124 L p F P
0 g
s
.662 .743 .91 r
.58728 .56926 m .33436 .64995 L .2426 .56459 L p F P
0 g
s
.662 .743 .91 r
.2426 .56459 m .50485 .4748 L .58728 .56926 L p F P
0 g
s
.966 .687 .452 r
.50596 .31957 m .58428 .41724 L .59241 .8293 L p F P
0 g
s
.966 .687 .452 r
.50596 .31957 m .58428 .41724 L .58728 .56926 L p F P
0 g
s
.539 .317 .526 r
.50485 .4748 m .50596 .31957 L .25661 .4124 L p F P
0 g
s
.539 .317 .526 r
.25661 .4124 m .2426 .56459 L .50485 .4748 L p F P
0 g
s
.672 .728 .891 r
.50596 .31957 m .25661 .4124 L .16055 .31419 L p F P
0 g
s
.539 .317 .526 r
.50542 .39511 m .50596 .31957 L .25661 .4124 L p F P
0 g
s
.539 .317 .526 r
.25661 .4124 m .24978 .48657 L .50542 .39511 L p F P
0 g
s
.938 .685 .528 r
.16055 .31419 m .25661 .4124 L .24978 .48657 L p F P
0 g
s
.938 .685 .528 r
.24978 .48657 m .15078 .38981 L .16055 .31419 L p F P
0 g
s
.668 .735 .9 r
.50542 .39511 m .24978 .48657 L .15078 .38981 L p F P
0 g
s
.973 .663 .31 r
.97657 .93008 m .90883 .84708 L .84947 .32491 L p F P
0 g
s
.672 .728 .891 r
.50596 .31957 m .78189 .21685 L .84947 .32491 L p F P
0 g
s
.973 .663 .31 r
.78189 .21685 m .84947 .32491 L .89747 .74713 L p F P
0 g
s
.966 .687 .452 r
.58728 .56926 m .50485 .4748 L .50596 .31957 L p F P
0 g
s
.539 .317 .526 r
.82232 .64945 m .78189 .21685 L .50596 .31957 L p F P
0 g
s
.966 .687 .452 r
.59241 .8293 m .50293 .74234 L .50596 .31957 L p F P
0 g
s
.539 .317 .526 r
.50596 .31957 m .50293 .74234 L .82232 .64945 L p F P
0 g
s
.672 .728 .891 r
.78189 .21685 m .50596 .31957 L .41883 .21088 L p F P
0 g
s
.539 .317 .526 r
.81324 .55231 m .78189 .21685 L .50596 .31957 L p F P
0 g
s
.539 .317 .526 r
.50596 .31957 m .50361 .64799 L .81324 .55231 L p F P
0 g
s
.672 .728 .891 r
.16055 .31419 m .41883 .21088 L .50596 .31957 L p F P
0 g
s
.668 .735 .9 r
.15078 .38981 m .4158 .28775 L .50542 .39511 L p F P
0 g
s
.966 .687 .452 r
.41883 .21088 m .50596 .31957 L .50361 .64799 L p F P
0 g
s
.966 .687 .452 r
.41883 .21088 m .50596 .31957 L .50542 .39511 L p F P
0 g
s
.514 .282 .5 r
.4158 .28775 m .41883 .21088 L .16055 .31419 L p F P
0 g
s
.514 .282 .5 r
.16055 .31419 m .15078 .38981 L .4158 .28775 L p F P
0 g
s
.966 .687 .452 r
.50542 .39511 m .4158 .28775 L .41883 .21088 L p F P
0 g
s
.625 .78 .956 r
.97657 .93008 m .6761 1.00015 L .59432 .926 L p F P
0 g
s
.973 .663 .31 r
.89747 .74713 m .82232 .64945 L .78189 .21685 L p F P
0 g
s
.672 .728 .891 r
.41883 .21088 m .70626 .09591 L .78189 .21685 L p F P
0 g
s
.973 .663 .31 r
.70626 .09591 m .78189 .21685 L .81324 .55231 L p F P
0 g
s
.514 .282 .5 r
.72983 .43813 m .70626 .09591 L .41883 .21088 L p F P
0 g
s
.966 .687 .452 r
.50361 .64799 m .40559 .54672 L .41883 .21088 L p F P
0 g
s
.514 .282 .5 r
.41883 .21088 m .40559 .54672 L .72983 .43813 L p F P
0 g
s
.638 .77 .943 r
.89747 .74713 m .59241 .8293 L .50293 .74234 L p F P
0 g
s
.625 .78 .956 r
.59432 .926 m .90883 .84708 L .97657 .93008 L p F P
0 g
s
.648 .761 .931 r
.81324 .55231 m .50361 .64799 L .40559 .54672 L p F P
0 g
s
.973 .663 .31 r
.81324 .55231 m .72983 .43813 L .70626 .09591 L p F P
0 g
s
.638 .77 .943 r
.50293 .74234 m .82232 .64945 L .89747 .74713 L p F P
0 g
s
.648 .761 .931 r
.40559 .54672 m .72983 .43813 L .81324 .55231 L p F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0.5)] .09072 .22988 .97192 1 Mshowa
.22871 .18658 m
.23354 .19204 L
s
[(1)] .21906 .17566 .88455 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(1.5)] .3545 .11847 .79718 1 Mshowa
.50609 .06995 m
.51031 .07589 L
s
[(2)] .49765 .05807 .70982 1 Mshowa
.65689 .00654 m
.66074 .01273 L
s
[(2.5)] .64919 -0.00583 .62245 1 Mshowa
.125 Mabswid
.12591 .22981 m
.12892 .23297 L
s
.1512 .21917 m
.15419 .22236 L
s
.17676 .20842 m
.17972 .21164 L
s
.2026 .19756 m
.20553 .20081 L
s
.25511 .17548 m
.25797 .17879 L
s
.28179 .16426 m
.28462 .1676 L
s
.30875 .15292 m
.31155 .15628 L
s
.33602 .14146 m
.33878 .14485 L
s
.39145 .11815 m
.39414 .1216 L
s
.41963 .1063 m
.42229 .10978 L
s
.44813 .09432 m
.45074 .09783 L
s
.47695 .0822 m
.47952 .08574 L
s
.53556 .05756 m
.53805 .06115 L
s
.56537 .04502 m
.56782 .04865 L
s
.59553 .03235 m
.59793 .036 L
s
.62603 .01952 m
.62839 .0232 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.13735 .90039 m
.13817 .89315 L
s
[(1)] .1357 .91488 .1138 -1 Mshowa
.24836 .97852 m
.24893 .97125 L
s
[(2)] .2472 .99305 .07951 -1 Mshowa
.3472 1.04807 m
.34757 1.0408 L
s
[(3)] .34647 1.06263 .05024 -1 Mshowa
.125 Mabswid
.03819 .83061 m
.03882 .82629 L
s
.06393 .84873 m
.06453 .8444 L
s
.08902 .86639 m
.08958 .86205 L
s
.11348 .8836 m
.11401 .87926 L
s
.16063 .91678 m
.16109 .91243 L
s
.18335 .93277 m
.18378 .92842 L
s
.20553 .94838 m
.20594 .94403 L
s
.2272 .96362 m
.22757 .95927 L
s
.26903 .99307 m
.26935 .9887 L
s
.28924 1.00729 m
.28953 1.00292 L
s
.30899 1.02119 m
.30926 1.01682 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.36568 1.06108 m
.36588 1.05671 L
s
.38377 1.07381 m
.38394 1.06944 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[25]:=",
  ImageSize->{265.313, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004900017b000`400?l00000o`00003oo`3oool:
0?ooo`00X03oool4000000<0oooo0P0000040?ooo`800000FP3oool00:00oooo00<000000?ooo`3o
ool02@3oool010000000oooo0?ooo`00001I0?ooo`00X@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo05L0oooo002R0?ooo`030000003oool0oooo00P0oooo0P00001J0?ooo`00X03o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo05T0oooo002Q0?ooo`8000002P3o
ool3000005T0oooo003o0?ooo`X0oooo003o0?ooo`X0oooo003o0?ooo`X0oooo002b0?ooo`800000
E@3oool00;00oooo0P0000000`3oool000000000001D0?ooo`00[P3oool300000080oooo0P00001D
0?ooo`00Z`3oool3000000<0oooo00D000000?ooo`000000oooo0000001C0?ooo`00Z@3oool20000
00P0oooo00<000000?ooo`000000D`3oool00:L0oooo0P00000:0?ooo`040000003oool0oooo0000
0580oooo002T0?ooo`<0000000<0oooo0000003oool02@3oool01@000000oooo0?ooo`3oool00000
0540oooo00230?ooo`@000006`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000001A0?oo
o`00P`3oool00`000000oooo0?ooo`0I0?ooo`<000004@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo04h0oooo00240?ooo`030000003oool0oooo01H0oooo0P0000020?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`00Q@3o
ool00`000000oooo0?ooo`0C0?ooo`8000005`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo04d0oooo00230?ooo`040000003oool0oooo00000140oooo0`00000I0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0C03oool008@0oooo0P00000@0?ooo`80000000<0oooo
0000003oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04`0oooo002D0?oo
o`8000007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04/0oooo002A0?ooo`<0
0000803oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04X0oooo002?0?ooo`@00000
8@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04X0oooo002=0?ooo`8000009@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04T0oooo002:0?ooo`<000009`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo04P0oooo00280?ooo`<00000:@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo04P0oooo00260?ooo`8000000`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A`3oool008<0oooo
0`00000^0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A`3oool00840oooo0P00
000a0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0AP3oool005@0oooo1@000002
0?ooo`800000103oool2000001`0oooo0P0000020?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`150?ooo`00EP3oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000001P0oooo0`00000e0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0A@3oool005H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?oo
o`800000>03oool00`000000oooo0?ooo`040?ooo`8000001@3oool00`000000oooo0?ooo`140?oo
o`00EP3oool00`000000oooo0?ooo`080?ooo`800000503oool300000080oooo00<000000?ooo`3o
ool0=P3oool010000000oooo0?ooo`3oool20000000308=8O`000000000000D0oooo00<000000?oo
o`3oool0@`3oool005H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`80
0000?P3oool4000000<0PdQo0P0000050?ooo`030000003oool0oooo04<0oooo001E0?ooo`800000
2P3oool3000000l0oooo0P00000o0?ooo`8000001P23B7l00`000000nJU?000000050?ooo`030000
003oool0oooo0480oooo001`0?ooo`<000000P3oool00`000000oooo0?ooo`0i0?ooo`<0000000<0
PdQo00000023B7l01@23B7l00`000000nJU?000000050?ooo`030000003oool0oooo0480oooo001^
0?ooo`800000?`3oool2000000@0PdQo00<0000008=8O`23B7l01023B7l010000000nJU?0?VYC`00
00050?ooo`030000003oool0oooo0440oooo001/0?ooo`800000?P3oool3000000H0PdQo00<00000
08=8O`23B7l01023B7l01@000000nJU?0?VYC`3iZDl0000000D0oooo00<000000?ooo`3oool0@03o
ool006T0oooo0`0000000`3oool000000?ooo`0k0?ooo`8000002@23B7l00`000000PdQo08=8O`04
08=8O`050000003iZDl0nJU?0?VYC`0000001@3oool00`000000oooo0?ooo`100?ooo`00I`3oool2
000003h0oooo0`00000;08=8O`0300000023B7l0PdQo00D0PdQo00D000000?VYC`3iZDl0nJU?0000
00050?ooo`030000003oool0oooo03l0oooo001U0?ooo`800000?P3oool2000000h0PdQo00<00000
08=8O`23B7l01@23B7l00`000000nJU?0?VYC`020?VYC`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0?P3oool00680oooo0`0000020?ooo`030000003oool0oooo03P0oooo0`00000@08=8
O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl00P3iZDl00`000000oooo0?ooo`030?oo
o`030000003oool0oooo03h0oooo001P0?ooo`800000?P3oool2000001<0PdQo00<0000008=8O`23
B7l01@23B7l00`000000nJU?0?VYC`030?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0?@3oool003d0oooo1@00000L0?ooo`<00000?03oool3000001D0PdQo00<0000008=8O`23B7l0
1@23B7l00`000000nJU?0?VYC`030?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
?@3oool003l0oooo00<000000?ooo`3oool06@3oool3000003d0oooo0P00000H08=8O`0300000023
B7l0PdQo00D0PdQo00<000000?VYC`3iZDl0103iZDl00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03`0oooo000o0?ooo`030000003oool0oooo01L0oooo0P00000n0?ooo`8000006P23B7l0
0`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00D0nJU?00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0k0?ooo`00?`3oool00`000000oooo0?ooo`0D0?ooo`@00000?03oool30000
01`0PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`050?VYC`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0>`3oool003l0oooo00<000000?ooo`3oool04P3oool2000003h0
oooo0P00000O08=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl01P3iZDl00`000000
oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo000n0?ooo`8000004@3oool3000003d0oooo
0`00000R08=8O`0300000023B7l0PdQo00@0PdQo00<000000?VYC`3iZDl01P3iZDl00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03T0oooo001?0?ooo`@00000?03oool2000002D0PdQo00<0
000008=8O`23B7l01023B7l00`000000nJU?0?VYC`070?VYC`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0>@3oool004d0oooo0P00000m0?ooo`<000009`23B7l00`000000PdQo08=8O`04
08=8O`030000003iZDl0nJU?00P0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0h
0?ooo`00BP3oool3000003d0oooo0P00000Z08=8O`0300000023B7l0PdQo00@0PdQo00<000000?VY
C`3iZDl0203iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo03P0oooo00180?ooo`@0
0000>`3oool3000002`0PdQo00<0000008=8O`23B7l01023B7l00`000000nJU?0?VYC`090?VYC`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0=`3oool004H0oooo0P00000m0?ooo`800000
;`23B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00P0nJU?00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0f0?ooo`00A03oool2000003`0oooo0`00000a08=8O`0300000023
B7l0PdQo00D0PdQo00<000000?VYC`3iZDl02@3iZDl00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03H0oooo00110?ooo`<0000000<0oooo0000003oool0>@3oool2000003@0PdQo00<00000
08=8O`23B7l01@23B7l00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0=@3oool003l0oooo0P00000l0?ooo`<00000=P23B7l00`000000PdQo08=8O`0508=8
O`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0d0?oo
o`004@3oool2000000@0oooo0P0000040?ooo`8000007P3oool2000003`0oooo0P00000i08=8O`03
00000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl02`3iZDl00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo03@0oooo000@0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000006P3oool3000000030?ooo`000000oooo03P0oooo0`00000k08=8O`0300000023B7l0PdQo
00D0PdQo00<000000?VYC`3iZDl0303iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo
03<0oooo000@0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool05@3oool30000
03`0oooo0P00000n08=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl0303iZDl00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo000@0?ooo`040000003oool0oooo0000
00T0oooo0P00000G0?ooo`800000>`3oool300000400PdQo00<0000008=8O`23B7l01@23B7l00`00
0000nJU?0?VYC`0=0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<P3oool00100
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0C0?ooo`<00000>`3oool20000
000308=8O`000000PdQo0400PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0=0?VY
C`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<@3oool00140oooo0P00000:0?ooo`<0
0000403oool3000003/0oooo0`00000308=8O`0300000023B7l0PdQo03l0PdQo00<0000008=8O`23
B7l01@23B7l00`000000nJU?0?VYC`0>0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0<@3oool002h0oooo1000000j0?ooo`8000001P23B7l00`000000PdQo08=8O`0o08=8O`030000
0023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl2000000D0oooo00<000000?ooo`3oool0
<03oool002`0oooo0P00000k0?ooo`<000002023B7l00`000000PdQo08=8O`0o08=8O`0300000023
B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl2000000H0oooo00<000000?ooo`3oool0;`3o
ool002X0oooo0P00000k0?ooo`8000002`23B7l00`000000PdQo08=8O`1008=8O`0300000023B7l0
PdQo00@0PdQo00<000000?VYC`3iZDl03P3iZDl00`000000nJU?000000050?ooo`030000003oool0
oooo02l0oooo000W0?ooo`<0000000<0oooo0000003oool0=`3oool3000000d0PdQo00<0000008=8
O`23B7l0@023B7l00`000000PdQo08=8O`0408=8O`030000003iZDl0nJU?00h0nJU?00@000000?VY
C`3iZDl000001@3oool00`000000oooo0?ooo`0^0?ooo`009@3oool2000003/0oooo0P00000@08=8
O`0300000023B7l0PdQo0400PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0=0?VY
C`040000003iZDl0nJU?000000D0oooo00<000000?ooo`3oool0;P3oool002<0oooo0P00000j0?oo
o`<000004P23B7l00`000000PdQo08=8O`1008=8O`0300000023B7l0PdQo00D0PdQo00<000000?VY
C`3iZDl03P3iZDl010000000nJU?0?VYC`0000050?ooo`030000003oool0oooo02d0oooo000Q0?oo
o`8000000P3oool00`000000oooo0?ooo`0e0?ooo`8000005@23B7l00`000000PdQo08=8O`1008=8
O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl010000000nJU?0?VYC`000006
0?ooo`030000003oool0oooo02`0oooo000Q0?ooo`800000=`3oool3000001H0PdQo0P00001208=8
O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl01@000000nJU?0?VYC`3iZDl0
000000D0oooo00<000000?ooo`3oool0;03oool00240oooo0`00000d0?ooo`8000006@23B7l00`00
0000PdQo08=8O`1108=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl00`00
0000nJU?0?VYC`020?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:`3oool00200
oooo0P0000020?ooo`030000003oool0oooo02h0oooo0`00000K08=8O`0300000023B7l0PdQo0440
PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0>0?VYC`030000003iZDl0nJU?0080
nJU?00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Z0?ooo`00803oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02/0oooo0P00000N08=8O`0300000023B7l0PdQo0440PdQo
00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0>0?VYC`030000003iZDl0nJU?00<0nJU?
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?ooo`006@3oool2000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`<000008023B7l00`000000PdQo08=8
O`1108=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl00`000000nJU?0?VY
C`040?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:@3oool001P0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0oooo0P00
000S08=8O`0300000023B7l0PdQo0440PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VY
C`0>0?VYC`030000003iZDl0nJU?00@0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0Y0?ooo`00603oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0803oool3000002D0PdQo00<0000008=8O`23B7l0@@23B7l00`000000PdQo08=8
O`0508=8O`030000003iZDl0nJU?00h0nJU?00<000000?VYC`3iZDl01@3iZDl00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02P0oooo000H0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0M0?ooo`800000:023B7l00`000000PdQo08=8
O`1108=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl00`000000nJU?0?VY
C`050?VYC`030000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool001P0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo0`00
000Z08=8O`0300000023B7l0PdQo0440PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VY
C`0?0?VYC`030000003iZDl0nJU?00D0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0W0?ooo`006@3oool2000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F
0?ooo`800000;023B7l2000004<0PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0?
0?VYC`030000003iZDl0nJU?00H0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0V
0?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0180oooo0`00000/08=8
O`80000000<0ZkcV00000023B7l0@P23B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?
00l0nJU?00<000000?VYC`3iZDl01P3iZDl00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02D0oooo000O0?ooo`800000303oool00`000000oooo0?ooo`0?0?ooo`800000;023B7l3000000<0
ZkcV00<0000008=8O`23B7l0@P23B7l00`000000PdQo08=8O`0408=8O`030000003iZDl0nJU?00l0
nJU?00<000000?VYC`3iZDl01`3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo02D0
oooo000O0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool3000002/0PdQo
0`0000060:^liP0300000023B7l0PdQo0480PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?
0?VYC`0>0?VYC`030000003iZDl0nJU?00P0nJU?00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0T0?ooo`007`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo0P00
000/08=8O`8000002@2[_>H00`000000PdQo08=8O`1208=8O`0300000023B7l0PdQo00D0PdQo00<0
00000?VYC`3iZDl03P3iZDl00`000000nJU?0?VYC`080?VYC`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0903oool001l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`<00000:`23B7l3000000/0ZkcV00<0000008=8O`23B7l0@P23B7l00`000000PdQo08=8O`05
08=8O`030000003iZDl0nJU?00h0nJU?00<000000?VYC`3iZDl02@3iZDl00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02<0oooo000N0?ooo`030000003oool0oooo0100oooo00@000000?oo
o`3oool0oooo0P00000/08=8O`8000003P2[_>H00`000000PdQo08=8O`1208=8O`0300000023B7l0
PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl00`000000nJU?0?VYC`090?VYC`030000003oool0
oooo00@0oooo00<000000?ooo`3oool08P3oool001h0oooo00<000000?ooo`3oool04@3oool20000
02`0PdQo0`00000@0:^liP0300000023B7l0PdQo0480PdQo00<0000008=8O`23B7l01@23B7l00`00
0000nJU?0?VYC`0>0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0R0?ooo`007P3oool00`000000oooo0?ooo`0B0?ooo`0300000023B7l0PdQo02P0
PdQo0P00000C0:^liP0300000023B7l0PdQo0480PdQo00<0000008=8O`23B7l01@23B7l00`000000
nJU?0?VYC`0>0?VYC`030000003iZDl0nJU?00/0nJU?00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0Q0?ooo`007P3oool00`000000oooo0?ooo`0B0?ooo`0300000023B7l0PdQo02D0PdQo
0`00000E0:^liP0300000023B7l0PdQo0480PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?
0?VYC`0>0?VYC`030000003iZDl0nJU?00/0nJU?00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0P0?ooo`007P3oool00`000000oooo0?ooo`0B0?ooo`0300000023B7l0PdQo0280PdQo0`00
000H0:^liP0300000023B7l0PdQo0480PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VY
C`0?0?VYC`030000003iZDl0nJU?00/0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0P0?ooo`007P3oool00`000000oooo0?ooo`0A0?ooo`0300000023B7l0PdQo0240PdQo0P00000K
0:^liP0300000023B7l0PdQo0480PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0?
0?VYC`030000003iZDl0nJU?00/0nJU?0P0000050?ooo`030000003oool0oooo01l0oooo000M0?oo
o`030000003oool0oooo0180oooo00<0000008=8O`23B7l07P23B7l3000001d0ZkcV00<0000008=8
O`23B7l0@P23B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00l0nJU?00<000000?VY
C`3iZDl02`3iZDl2000000D0oooo00<000000?ooo`3oool07`3oool001d0oooo00<000000?ooo`3o
ool04P3oool00`000000PdQo08=8O`0L08=8O`8000007`2[_>H00`000000PdQo08=8O`1308=8O`03
00000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0;0?VYC`03
0000003iZDl0000000D0oooo00<000000?ooo`3oool07P3oool001d0oooo00<000000?ooo`3oool0
4P3oool00`000000PdQo08=8O`0I08=8O`<000008@2[_>H00`000000PdQo08=8O`1308=8O`030000
0023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0;0?VYC`030000
003iZDl0000000H0oooo00<000000?ooo`3oool07@3oool001d0oooo00<000000?ooo`3oool04P3o
ool00`000000PdQo08=8O`0G08=8O`800000902[_>H00`000000PdQo08=8O`1308=8O`0300000023
B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003i
ZDl0000000D0oooo00<000000?ooo`3oool07@3oool001d0oooo00<000000?ooo`3oool04P3oool0
0`000000PdQo08=8O`0D08=8O`<000009P2[_>H00`000000PdQo08=8O`1308=8O`0300000023B7l0
PdQo00D0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0<0?VYC`040000003iZDl0
nJU?000000D0oooo00<000000?ooo`3oool0703oool001d0oooo00<000000?ooo`3oool04@3oool0
0`000000PdQo08=8O`0B08=8O`<00000:@2[_>H00`000000PdQo08=8O`1308=8O`0300000023B7l0
PdQo00H0PdQo00<000000?VYC`3iZDl03P3iZDl00`000000nJU?0?VYC`0<0?VYC`040000003iZDl0
nJU?000000H0oooo00<000000?ooo`3oool06`3oool001`0oooo00<000000?ooo`3oool04P3oool0
0`000000PdQo08=8O`0@08=8O`800000;02[_>H00`000000PdQo08=8O`1408=8O`0300000023B7l0
PdQo00D0PdQo00<000000?VYC`3iZDl03P3iZDl00`000000nJU?0?VYC`0<0?VYC`050000003iZDl0
nJU?0?VYC`0000001@3oool00`000000oooo0?ooo`0K0?ooo`00703oool00`000000oooo0?ooo`0B
0?ooo`0300000023B7l0PdQo00d0PdQo0`00000^0:^liP0300000023B7l0PdQo04@0PdQo00<00000
08=8O`23B7l01@23B7l00`000000nJU?0?VYC`0>0?VYC`030000003iZDl0nJU?00`0nJU?00<00000
0?VYC`3iZDl00P3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo000L0?oo
o`030000003oool0oooo0180oooo00<0000008=8O`23B7l02`23B7l200000340ZkcV00<0000008=8
O`23B7l0A023B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00l0nJU?00<000000?VY
C`3iZDl02`3iZDl00`000000nJU?0?VYC`020?VYC`030000003oool0oooo00<0oooo00<000000?oo
o`3oool06P3oool001`0oooo00<000000?ooo`3oool04P3oool00`000000PdQo08=8O`0808=8O`<0
0000<`2[_>H00`000000PdQo08=8O`1408=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3i
ZDl03`3iZDl00`000000nJU?0?VYC`0;0?VYC`030000003iZDl0nJU?00<0nJU?00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0I0?ooo`006`3oool2000001@0oooo00<0000008=8O`23B7l0
1P23B7l2000003H0ZkcV00<0000008=8O`23B7l0A023B7l00`000000PdQo08=8O`0508=8O`030000
003iZDl0nJU?00l0nJU?00<000000?VYC`3iZDl02`3iZDl00`000000nJU?0?VYC`030?VYC`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0603oool001`0oooo00<000000?ooo`3oool04@3o
ool00`000000PdQo08=8O`0408=8O`<00000>02[_>H00`000000PdQo08=8O`1408=8O`0300000023
B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0;0?VYC`030000003i
ZDl0nJU?00@0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`006`3oool0
0`000000oooo0?ooo`0B0?ooo`0400000023B7l0PdQo08=8O`<00000>`2[_>H00`000000PdQo08=8
O`1408=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VY
C`0<0?VYC`030000003iZDl0nJU?00@0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0G0?ooo`006`3oool00`000000oooo0?ooo`0B0?ooo`0400000023B7l00000000003h0ZkcV00<0
000008=8O`23B7l0A023B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00l0nJU?00<0
00000?VYC`3iZDl0303iZDl00`000000nJU?0?VYC`040?VYC`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool04P3oool200000400ZkcV00<00000
08=8O`23B7l0A023B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00l0nJU?00<00000
0?VYC`3iZDl0303iZDl00`000000nJU?0?VYC`050?VYC`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool04`3oool00`000000ZkcV0:^liP0n0:^l
iP0300000023B7l0PdQo04@0PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0?0?VY
C`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl01P3iZDl00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01D0oooo000K0?ooo`030000003oool0oooo01@0oooo00<000000:^liP2[
_>H0?@2[_>H00`000000PdQo08=8O`1408=8O`0300000023B7l0PdQo00D0PdQo00<000000?VYC`3i
ZDl03`3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00H0nJU?00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0E0?ooo`006`3oool00`000000oooo0?ooo`0E0?ooo`030000
002[_>H0ZkcV03`0ZkcV00<0000008=8O`23B7l0A023B7l00`000000PdQo08=8O`0508=8O`030000
003iZDl0nJU?00l0nJU?00<000000?VYC`3iZDl0303iZDl00`000000nJU?0?VYC`070?VYC`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001X0oooo00<000000?ooo`3oool05`3o
ool00`000000ZkcV0:^liP0k0:^liP0300000023B7l0PdQo04@0PdQo00<0000008=8O`23B7l01@23
B7l00`000000nJU?0?VYC`0?0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl01`3i
ZDl00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo000J0?ooo`030000003oool0
000001P0oooo00<000000:^liP2[_>H0>P2[_>H00`000000PdQo08=8O`1408=8O`0300000023B7l0
PdQo00H0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0;0?VYC`030000003iZDl0
nJU?00P0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`006P3oool20000
01X0oooo00<000000:^liP2[_>H0>@2[_>H00`000000PdQo08=8O`1408=8O`0300000023B7l0PdQo
00H0PdQo00<000000?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0;0?VYC`8000002P3iZDl00`00
0000oooo0?ooo`020?ooo`800000503oool001X0oooo00<000000?ooo`3oool06P3oool00`000000
ZkcV0:^liP0h0:^liP0300000023B7l0PdQo04@0PdQo00<0000008=8O`23B7l01P23B7l00`000000
nJU?0?VYC`0?0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl0203iZDl00`000000
oooo00000002000000030?ooo`000000oooo01<0oooo000A0?ooo`@000001@3oool00`000000oooo
0?ooo`0K0?ooo`030000002[_>H0ZkcV03L0ZkcV00<0000008=8O`23B7l0A023B7l00`000000PdQo
08=8O`0608=8O`030000003iZDl0nJU?00l0nJU?00<000000?VYC`3iZDl0303iZDl00`000000nJU?
0?VYC`090?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00140oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`030000002[_>H0ZkcV03D0ZkcV00<0
000008=8O`23B7l0AP23B7l00`000000PdQo08=8O`0508=8O`030000003iZDl0nJU?00l0nJU?00<0
00000?VYC`3iZDl0303iZDl00`000000nJU?0?VYC`090?VYC`030000003oool0oooo0080oooo00<0
00000?ooo`3oool04P3oool00180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N
0?ooo`030000002[_>H0ZkcV03<0ZkcV0P00001808=8O`0300000023B7l0PdQo00D0PdQo00<00000
0?VYC`3iZDl03`3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00T0nJU?00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01l0oooo00<000000:^liP2[_>H0<02[_>H20000000308UAQP000000PdQo
04L0PdQo00<0000008=8O`23B7l01@23B7l00`000000nJU?0?VYC`0?0?VYC`030000003iZDl0nJU?
00`0nJU?00<000000?VYC`3iZDl02@3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0140oooo000A0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0803oool00`00
0000ZkcV0:^liP0/0:^liP<000000`29DHH00`000000PdQo08=8O`1608=8O`0300000023B7l0PdQo
00@0PdQo0P00000A0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl02P3iZDl00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo000B0?ooo`8000001@3oool00`000000
oooo0?ooo`0Q0?ooo`030000002[_>H0ZkcV02P0ZkcV0`00000608UAQP0300000023B7l0PdQo04H0
PdQo00@0000008=8O`23B7l0PdQo0`0000020:G2kP030000003iZDl0nJU?00h0nJU?00<000000?VY
C`3iZDl0303iZDl00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo0080oooo00<000000?oo
o`3oool04@3oool001T0oooo00<000000?ooo`3oool08P3oool00`000000ZkcV0:^liP0U0:^liP80
00002@29DHH00`000000PdQo08=8O`1608=8O`@000001@2U`^h00`000000nJU?0?VYC`0>0?VYC`03
0000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0140oooo000I0?ooo`030000003oool0oooo02<0oooo00<000000:^liP2[_>H0
8@2[_>H3000000/0RE6600<0000008=8O`23B7l0A023B7l3000000T0YL;^00<000000?VYC`3iZDl0
3P3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00T0nJU?00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0A0?ooo`00603oool2000002H0oooo00<000000:^liP2[_>H07@2[
_>H3000000h0RE6600<0000008=8O`23B7l0@@23B7l300000080YL;^00<000000:G2kP2U`^h0202U
`^h00`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl02@3i
ZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo000H0?ooo`030000003oool0
oooo02H0oooo00<000000:^liP2[_>H06P2[_>H200000140RE6600<0000008=8O`23B7l0?P23B7l3
000000D0YL;^00<000000:G2kP2U`^h02@2U`^h00`000000nJU?0?VYC`0<0?VYC`030000003iZDl0
nJU?00`0nJU?00<000000?VYC`3iZDl02@3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0140oooo000H0?ooo`030000003oool0oooo02L0oooo00<000000:^liP2[_>H05P2[_>H30000
01<0RE6600<0000008=8O`23B7l0>`23B7l3000000P0YL;^00<000000:G2kP2U`^h02@2U`^h00`00
0000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl02@3iZDl00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000H0?ooo`030000003oool0oooo02P0
oooo00<000000:^liP2[_>H04P2[_>H3000001H0RE6600<0000008=8O`23B7l0>@23B7l2000000/0
YL;^00<000000:G2kP2U`^h02P2U`^h00`000000nJU?0?VYC`0;0?VYC`030000003iZDl0nJU?00`0
nJU?00<000000?VYC`3iZDl02@3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100
oooo000H0?ooo`030000003oool0oooo02T0oooo00<000000:^liP2[_>H03`2[_>H2000001T0RE66
00<0000008=8O`23B7l0=P23B7l3000000d0YL;^00<000000:G2kP2U`^h02`2U`^h00`000000nJU?
0?VYC`0:0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo000H0?ooo`030000003oool0oooo02X0oooo00<0
00000:^liP2[_>H02`2[_>H3000001/0RE6600<0000008=8O`23B7l0<`23B7l300000100YL;^00<0
00000:G2kP2U`^h0302U`^h00`000000nJU?0?VYC`090?VYC`030000003iZDl0nJU?00`0nJU?00<0
00000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo000G
0?ooo`030000003oool0oooo02`0oooo00<000000:^liP2[_>H01`2[_>H3000001h0RE6600<00000
08=8O`23B7l0<023B7l3000001<0YL;^00<000000:G2kP2U`^h0302U`^h00`000000nJU?0?VYC`09
0?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo000G0?ooo`030000003oool0oooo02d0oooo00<000000:^l
iP2[_>H0102[_>H200000240RE6600<0000008=8O`23B7l0;@23B7l3000001H0YL;^00<000000:G2
kP2U`^h03@2U`^h00`000000nJU?0?VYC`080?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VY
C`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo000G0?ooo`03
0000003oool0oooo02h0oooo00<000000:^liP2[_>H00`00000S08UAQP0300000023B7l0PdQo02X0
PdQo0`00000I0:G2kP030000002U`^h0YL;^00h0YL;^00<000000?VYC`3iZDl01`3iZDl00`000000
nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00T0nJU?00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`005`3oool00`000000oooo0?ooo`0_0?ooo`8000009P29DHH00`000000PdQo
08=8O`0W08=8O`<000007@2U`^h00`000000YL;^0:G2kP0=0:G2kP030000003iZDl0nJU?00L0nJU?
00<000000?VYC`3iZDl03@3iZDl00`000000nJU?0?VYC`090?VYC`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03`3oool001L0oooo00<000000?ooo`3oool0;`3oool00`000000RE6608UA
QP0U08UAQP0300000023B7l0PdQo02@0PdQo0`00000P0:G2kP030000002U`^h0YL;^00h0YL;^00<0
00000?VYC`3iZDl01`3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00T0nJU?00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`005`3oool00`000000oooo0?ooo`0_
0?ooo`0300000029DHH0RE6602D0RE6600<0000008=8O`23B7l08@23B7l3000002<0YL;^00<00000
0:G2kP2U`^h03`2U`^h00`000000nJU?0?VYC`060?VYC`030000003iZDl0nJU?00`0nJU?00<00000
0?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo000F0?oo
o`030000003oool0oooo0300oooo00<0000008UAQP29DHH09@29DHH00`000000PdQo08=8O`0N08=8
O`<000009P2U`^h00`000000YL;^0:G2kP0@0:G2kP030000003iZDl0nJU?00D0nJU?00<000000?VY
C`3iZDl0303iZDl00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo0080oooo00<000000?oo
o`3oool03`3oool001H0oooo00<000000?ooo`3oool0<03oool00`000000RE6608UAQP0U08UAQP03
00000023B7l0PdQo01/0PdQo0`00000Y0:G2kP030000002U`^h0YL;^0100YL;^00<000000?VYC`3i
ZDl01@3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`005P3oool00`000000oooo0?ooo`0_0?ooo`030000
0029DHH0RE6602D0RE6600<0000008=8O`23B7l06@23B7l3000002`0YL;^00<000000:G2kP2U`^h0
4@2U`^h00`000000nJU?0?VYC`040?VYC`030000003iZDl0nJU?00`0nJU?00<000000?VYC`3iZDl0
2P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo000F0?ooo`030000003o
ool0oooo02l0oooo00<0000008UAQP29DHH08P29DHH4000001P0PdQo0`00000_0:G2kP030000002U
`^h0YL;^0180YL;^00<000000?VYC`3iZDl00`3iZDl00`000000nJU?0?VYC`0<0?VYC`030000003i
ZDl0nJU?00X0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`005P3oool0
0`000000oooo0?ooo`0_0?ooo`0300000029DHH0RE6601l0RE660`0000030:Vnj00300000023B7l0
PdQo01<0PdQo0`00000b0:G2kP030000002U`^h0YL;^0180YL;^00<000000?VYC`3iZDl00`3iZDl0
0`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0?0?ooo`005P3oool00`000000oooo0?ooo`0_0?ooo`0300000029DHH0RE66
01`0RE660`0000060:Vnj00300000023B7l0PdQo0140PdQo0P00000e0:G2kP030000002U`^h0YL;^
01<0YL;^00<000000?VYC`3iZDl00P3iZDl00`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?
00T0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`005@3oool00`000000
oooo0?ooo`0`0?ooo`0300000029DHH0RE6601T0RE660`0000090:Vnj00300000023B7l0PdQo00h0
PdQo0`00000g0:G2kP030000002U`^h0YL;^01@0YL;^00D000000?VYC`3iZDl0nJU?0000000?0?VY
C`030000003iZDl0nJU?00T0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?oo
o`005@3oool00`000000oooo0?ooo`0`0?ooo`0300000029DHH0RE6601H0RE660`00000<0:Vnj003
00000023B7l0PdQo00/0PdQo0`00000j0:G2kP030000002U`^h0YL;^01D0YL;^00@000000?VYC`3i
ZDl000003`3iZDl00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo0080oooo00<000000?oo
o`3oool03P3oool001D0oooo00<000000?ooo`3oool0<03oool00`000000RE6608UAQP0C08UAQP<0
00003`2Y_^P00`000000PdQo08=8O`0808=8O`<00000?@2U`^h00`000000YL;^0:G2kP0E0:G2kP05
0000003iZDl0nJU?0?VYC`0000003P3iZDl00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo
0080oooo00<000000?ooo`3oool03P3oool001D0oooo00<000000?ooo`3oool0<03oool00`000000
RE6608UAQP0@08UAQP<000004P2Y_^P00`000000PdQo08=8O`0508=8O`<00000@02U`^h00`000000
YL;^0:G2kP0F0:G2kP040000003iZDl0nJU?000000h0nJU?00<000000?VYC`3iZDl02P3iZDl00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo000E0?ooo`800000<@3oool00`000000
RE6608UAQP0=08UAQP<000005@2Y_^P00`000000PdQo08=8O`0208=8O`<00000@`2U`^h00`000000
YL;^0:G2kP0G0:G2kP030000003iZDl0000000h0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo000E0?ooo`030000003oool0oooo0300oooo
00<0000008UAQP29DHH02P29DHH3000001P0ZKkX00<0000008=8O`0000000P0000160:G2kP030000
002U`^h0YL;^01P0YL;^0P00000>0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`005@3oool00`000000oooo0?ooo`0_0?ooo`0300000029
DHH0RE6600P0RE660`00000K0:Vnj0800000B@2U`^h00`000000YL;^0:G2kP0H0:G2kP8000003P3i
ZDl00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3o
ool001@0oooo00<000000?ooo`3oool0<03oool00`000000RE6608UAQP0508UAQP<000007`2Y_^P0
0`000000YL;^0:G2kP180:G2kP030000002U`^h0YL;^01L0YL;^0P00000>0?VYC`8000002`3iZDl0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo000D0?ooo`030000003oool0oooo
0300oooo00<0000008UAQP29DHH00P29DHH3000002<0ZKkX00<000000:G2kP2U`^h0A`2U`^h00`00
0000YL;^0:G2kP0D0:G2kP<0000000<0RE660000003iZDl03P3iZDl00`000000nJU?0?VYC`0:0?VY
C`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool001@0oooo00<000000?ooo`3o
ool0<03oool00`000000RE6600000002000002L0ZKkX00<000000:G2kP2U`^h0AP2U`^h00`000000
YL;^0:G2kP0@0:G2kP@000001029DHH00`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00X0
nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`00503oool00`000000oooo
0?ooo`0`0?ooo`800000:`2Y_^P00`000000YL;^0:G2kP150:G2kP030000002U`^h0YL;^00d0YL;^
0`00000808UAQP030000003iZDl0nJU?00d0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00d0oooo000D0?ooo`030000003oool0oooo0340oooo00<0
00000:Vnj02Y_^P0:P2Y_^P00`000000YL;^0:G2kP140:G2kP030000002U`^h0YL;^00X0YL;^0`00
000;08UAQP030000003iZDl0nJU?00d0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00d0oooo000D0?ooo`030000003oool0oooo0380oooo00<00000
0:Vnj02Y_^P0:P2Y_^P00`000000YL;^0:G2kP130:G2kP030000002U`^h0YL;^00L0YL;^0`00000>
08UAQP030000003iZDl0nJU?00d0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00d0oooo000C0?ooo`030000003oool0oooo03@0oooo00<000000:Vn
j02Y_^P0:P2Y_^P00`000000YL;^0:G2kP120:G2kP030000002U`^h0YL;^00<0YL;^1000000A08UA
QP030000003iZDl0nJU?00d0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo000C0?ooo`030000003oool0oooo03D0oooo00<000000:Vnj02Y
_^P0:P2Y_^P00`000000YL;^0:G2kP110:G2kP030000002U`^h0YL;^00<000005@29DHH00`000000
nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0<0?ooo`004`3oool00`000000oooo0?ooo`0f0?ooo`030000002Y_^P0ZKkX02X0ZKkX
00<000000:G2kP2U`^h0?`2U`^h4000001T0RE6600<000000?VYC`3iZDl0303iZDl00`000000nJU?
0?VYC`0:0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool001<0oooo0`00
000g0?ooo`030000002Y_^P0ZKkX02X0ZKkX00<000000:G2kP2U`^h0>`2U`^h40000000308UAQP00
0000RE6601T0RE6600<000000?VYC`3iZDl0303iZDl2000000`0nJU?00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0<0?ooo`004`3oool00`000000oooo0?ooo`0h0?ooo`030000002Y_^P0
ZKkX02X0ZKkX00<000000:G2kP2U`^h0=P2U`^h5000000D0RE6600<0000008UAQP29DHH05`29DHH0
0`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0<0?ooo`00303oool3000000@0oooo00<000000?ooo`3oool0>@3oool00`00
0000ZKkX0:Vnj00Z0:Vnj0030000002U`^h0YL;^0380YL;^1000000908UAQP0300000029DHH0RE66
01L0RE6600<000000?VYC`3iZDl03@3iZDl00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0k0?ooo`030000002Y_^P0ZKkX02X0ZKkX00<000000:G2kP2U`^h0;P2U`^h4000000d0
RE6600<0000008UAQP29DHH05P29DHH00`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00X0
nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`002P3oool5000000<0oooo
00<000000?ooo`3oool0?03oool00`000000ZKkX0:Vnj00Z0:Vnj0030000002U`^h0YL;^02X0YL;^
1000000A08UAQP0300000029DHH0RE6601D0RE6600<000000?VYC`3iZDl03@3iZDl00`000000nJU?
0?VYC`0:0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool000X0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0m0?ooo`800000:`2Y_^P00`000000YL;^
0:G2kP0U0:G2kPD000005@29DHH00`000000RE6608UAQP0D08UAQP030000003iZDl0nJU?00d0nJU?
00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo
000;0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0?`3oool00`000000ZKkX0:Vn
j00T0:Vnj0@0000000<0SUR;0000002U`^h08P2U`^h4000001X0RE6600<0000008UAQP29DHH04`29
DHH00`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0;0?ooo`00303oool2000000@0oooo00<000000?ooo`3oool0@03oool0
0`000000ZKkX0:Vnj00P0:Vnj0<000001P2>F8/00`000000YL;^0:G2kP0M0:G2kP@000007@29DHH0
0`000000RE6608UAQP0C08UAQP030000003iZDl0nJU?00d0nJU?00<000000?VYC`3iZDl02`3iZDl0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo000B0?ooo`030000003oool0oooo
0440oooo00<000000:Vnj02Y_^P0702Y_^P3000000X0SUR;00<000000:G2kP2U`^h06@2U`^h40000
0240RE6600<0000008UAQP29DHH04P29DHH00`000000nJU?0?VYC`0=0?VYC`030000003iZDl0nJU?
00/0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`004@3oool00`000000
oooo0?ooo`130?ooo`030000002Y_^P0ZKkX01P0ZKkX0`00000>08iHR`030000002U`^h0YL;^01D0
YL;^1000000U08UAQP0300000029DHH0RE660140RE6600<000000?VYC`3iZDl03@3iZDl2000000`0
nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`004@3oool00`000000oooo
0?ooo`140?ooo`030000002Y_^P0ZKkX01@0ZKkX0`00000B08iHR`030000002U`^h0YL;^0100YL;^
1000000Z08UAQP0300000029DHH0RE660140RE6600<000000?VYC`3iZDl03@3iZDl00`000000nJU?
0?VYC`0:0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00140oooo00<0
00000?ooo`3oool0A@3oool00`000000ZKkX0:Vnj00@0:Vnj0<000005P2>F8/00`000000YL;^0:G2
kP0<0:G2kP@00000;P29DHH00`000000RE6608UAQP0@08UAQP030000003iZDl0nJU?00d0nJU?00<0
00000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo000A
0?ooo`800000A`3oool00`000000ZKkX0:Vnj00<0:Vnj0<000006P2>F8/00`000000YL;^0:G2kP08
0:G2kP@00000<@29DHH00`000000RE6608UAQP0@08UAQP030000003iZDl0nJU?00d0nJU?00<00000
0?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo000A0?oo
o`030000003oool0oooo04L0oooo00<000000:Vnj02Y_^P0202Y_^P3000001h0SUR;00<000000:G2
kP2U`^h0102U`^h4000003D0RE6600<0000008UAQP29DHH03`29DHH00`000000nJU?0?VYC`0=0?VY
C`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?oo
o`004@3oool00`000000oooo0?ooo`180?ooo`030000002Y_^P0ZKkX00@0ZKkX0`00000R08iHR`03
0000002U`^h0000000<00000>P29DHH00`000000RE6608UAQP0>08UAQP030000003iZDl0nJU?00d0
nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0
oooo000@0?ooo`030000003oool0oooo04X0oooo00<000000:Vnj02Y_^P00`00000T08iHR`@00000
?P29DHH00`000000RE6608UAQP0<08UAQP8000003`3iZDl00`000000nJU?0?VYC`0;0?VYC`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00100oooo00<000000?ooo`3oool0B`3o
ool2000002@0SUR;0`00000208iHR`0300000029DHH0RE6603h0RE6600<0000008UAQP29DHH02029
DHH300000080XlGa00<000000?VYC`3iZDl0303iZDl00`000000nJU?0?VYC`0;0?VYC`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02P3oool00100oooo00<000000?ooo`3oool0B`3oool0
0`000000SUR;08iHR`0P08iHR`<000001@2>F8/00`000000RE6608UAQP0n08UAQP0300000029DHH0
RE6600@0RE66100000060:?5l@030000003iZDl0nJU?00/0nJU?0P00000<0?VYC`030000003oool0
oooo0080oooo00<000000?ooo`3oool02P3oool00100oooo00<000000?ooo`3oool0B`3oool00`00
0000SUR;08iHR`0L08iHR`@00000202>F8/00`000000RE6608UAQP0o08UAQP0300000029DHH0RE66
00<000002P2SaO400`000000nJU?0?VYC`0<0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`00403oool00`000000oooo0?ooo`1;0?ooo`03
0000002>F8/0SUR;01T0SUR;0`00000<08iHR`0300000029DHH0RE6603l0RE660`00000>0:?5l@03
0000003iZDl0nJU?00/0nJU?00<000000?VYC`3iZDl02P3iZDl00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo000@0?ooo`030000003oool0oooo04/0oooo00<0000008iHR`2>F8/0
5P2>F8/3000000l0SUR;00<0000008UAQP29DHH0>`29DHH400000080XlGa00<000000:?5l@2SaO40
3@2SaO400`000000nJU?0?VYC`0:0?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`090?ooo`003`3oool00`000000oooo0?ooo`1<0?ooo`030000002>
F8/0SUR;01<0SUR;0`00000B08iHR`0300000029DHH0RE6603P0RE660`0000070:?5l@030000002S
aO40XlGa00d0XlGa00<000000?VYC`3iZDl02@3iZDl00`000000nJU?0?VYC`0:0?VYC`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool000l0oooo00<000000?ooo`3oool0C03oool0
0`000000SUR;08iHR`0?08iHR`@000005@2>F8/00`000000RE6608UAQP0e08UAQP<000002P2SaO40
0`000000XlGa0:?5l@0=0:?5l@030000003iZDl0nJU?00T0nJU?00<000000?VYC`3iZDl02P3iZDl0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo000?0?ooo`030000003oool0oooo
04`0oooo00<0000008iHR`2>F8/0302>F8/3000001H0SUR;1000000c08UAQP@000003P2SaO400`00
0000XlGa0:?5l@0=0:?5l@030000003iZDl0nJU?00P0nJU?00<000000?VYC`3iZDl02`3iZDl00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo000?0?ooo`800000C@3oool00`000000
SUR;08iHR`0908iHR`<000005P2>F8/3000000<0Yl3[00<0000008UAQP29DHH0;P29DHH3000001<0
XlGa00<000000:?5l@2SaO403@2SaO400`000000nJU?0?VYC`070?VYC`030000003iZDl0nJU?00/0
nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`003`3oool00`000000oooo
0?ooo`1<0?ooo`030000002>F8/0SUR;00H0SUR;0`00000F08iHR`<000001P2W`>/00`000000RE66
08UAQP0[08UAQP<000005`2SaO400`000000XlGa0:?5l@0=0:?5l@030000003iZDl0nJU?00H0nJU?
00<000000?VYC`3iZDl02`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
000?0?ooo`030000003oool0oooo04`0oooo00<0000008iHR`2>F8/00`2>F8/3000001D0SUR;1000
00090:O0j`0300000029DHH0RE6602L0RE661000000K0:?5l@030000002SaO40XlGa00`0XlGa00<0
00000?VYC`3iZDl01P3iZDl2000000`0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`090?ooo`003P3oool00`000000oooo0?ooo`1=0?ooo`030000002>F8/0000000<000005@2>F8/3
000000d0Yl3[00<0000008UAQP29DHH09029DHH300000200XlGa00<000000:?5l@2SaO40302SaO40
0`000000nJU?0?VYC`060?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`003P3oool00`000000oooo0?ooo`1<0?ooo`<000005P2>F8/30000
0100Yl3[00<0000008UAQP29DHH08@29DHH3000002<0XlGa00<000000:?5l@2SaO403@2SaO400`00
0000nJU?0?VYC`050?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`080?ooo`003P3oool00`000000oooo0?ooo`190?ooo`@000005@2>F8/3000001<0
Yl3[00<0000008UAQP29DHH07@29DHH4000002L0XlGa00<000000:?5l@2SaO403@2SaO400`000000
nJU?0?VYC`040?VYC`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`003P3oool00`000000oooo0?ooo`160?ooo`<000000`3oool00`000000SUR;
08iHR`0?08iHR`@000005P2W`>/00`000000RE6608UAQP0J08UAQP<00000;02SaO400`000000XlGa
0:?5l@0<0:?5l@030000003iZDl0nJU?00@0nJU?00<000000?VYC`3iZDl02`3iZDl00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo000>0?ooo`030000003oool0oooo0480oooo1000
00060?ooo`030000002>F8/0SUR;00`0SUR;0`00000J0:O0j`0300000029DHH0RE6601L0RE660`00
000`0:?5l@030000002SaO40XlGa00`0XlGa00<000000?VYC`3iZDl00`3iZDl00`000000nJU?0?VY
C`0;0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool000h0oooo00<00000
0?ooo`3oool0?`3oool3000000X0oooo00<0000008iHR`2>F8/02@2>F8/3000001d0Yl3[00<00000
08UAQP29DHH04`29DHH4000003@0XlGa00<000000:?5l@2SaO40302SaO400`000000nJU?0?VYC`02
0?VYC`030000003iZDl0nJU?00/0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`003@3oool00`000000oooo0?ooo`0m0?ooo`<000003@3oool00`000000SUR;08iHR`0608iH
R`<00000802W`>/00`000000RE6608UAQP0@08UAQP<00000>02SaO400`000000XlGa0:?5l@0=0:?5
l@050000003iZDl0nJU?0?VYC`0000003@3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo000=0?ooo`030000003oool0oooo03X0oooo0`00000@0?ooo`030000002>F8/0SUR;
0080SUR;1000000S0:O0j`0300000029DHH0RE6600d0RE660`00000l0:?5l@030000002SaO40XlGa
00`0XlGa00D000000?VYC`3iZDl0nJU?0000000=0?VYC`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0203oool000d0oooo00<000000?ooo`3oool0=P3oool4000001<0oooo00<0000008iH
R`0000000P00000W0:O0j`0300000029DHH0RE6600T0RE66100000100:?5l@030000002SaO40XlGa
00`0XlGa00<000000?VYC`3iZDl00P00000<0?VYC`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool000d0oooo00<000000?ooo`3oool0<`3oool3000001L0oooo0P00000Z0:O0j`03
00000029DHH0RE6600H0RE660`0000150:?5l@030000002SaO40XlGa00`0XlGa00@000000?VYC`3i
ZDl00000303iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo000=0?ooo`80
0000<@3oool3000001/0oooo00<000000:O0j`2W`>/0:02W`>/00`000000RE6608UAQP0308UAQP<0
0000B@2SaO400`000000XlGa0:?5l@0<0:?5l@030000003iZDl0000000`0nJU?00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`003@3oool00`000000oooo0?ooo`0]0?ooo`<00000
7`3oool00`000000Yl3[0:O0j`0W0:O0j`0300000029DHH0000000<00000C02SaO400`000000XlGa
0:?5l@0<0:?5l@030000003iZDl0000000d0nJU?00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`00303oool00`000000oooo0?ooo`0Z0?ooo`@000008`3oool2000002L0Yl3[0P00
001A0:?5l@030000002SaO40XlGa00`0XlGa0P00000=0?VYC`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool09`3oool3000002T0oooo00<00000
0:O0j`2W`>/09@2W`>/00`000000XlGa0:?5l@1@0:?5l@030000002SaO40XlGa00/0XlGa0P00000=
0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool000`0oooo00<000000?oo
o`3oool0903oool3000002d0oooo00<000000:O0j`2W`>/09@2W`>/00`000000XlGa0:?5l@1@0:?5
l@030000002SaO40XlGa00H0XlGa100000000`2>F8/000000?VYC`0<0?VYC`030000003oool0oooo
0080oooo00<000000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool08@3oool300000340
oooo00<000000:O0j`2W`>/09@2W`>/00`000000XlGa0:?5l@1@0:?5l@040000002SaO40XlGa0:?5
l@@000001@2>F8/00`000000nJU?0?VYC`0;0?VYC`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool000`0oooo00<000000?ooo`3oool07@3oool4000003D0oooo00<000000:O0j`2W
`>/09@2W`>/00`000000XlGa0:?5l@1?0:?5l@@000002@2>F8/00`000000nJU?0?VYC`0;0?VYC`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool000`0oooo00<000000?ooo`3oool0
6P3oool3000003X0oooo00<000000:O0j`2W`>/09@2W`>/00`000000XlGa0:?5l@1;0:?5l@D00000
302>F8/00`000000nJU?0?VYC`0:0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool000/0oooo00<000000?ooo`3oool0603oool3000003h0oooo00<000000:O0j`2W`>/09@2W
`>/00`000000XlGa0:?5l@160:?5l@@000001@2>F8/00`000000SUR;08iHR`0908iHR`030000003i
ZDl0nJU?00/0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`002`3oool0
0`000000oooo0?ooo`0E0?ooo`<00000@P3oool2000002H0Yl3[00<000000:?5l@2SaO40@P2SaO43
000000X0SUR;00<0000008iHR`2>F8/0202>F8/00`000000nJU?0?VYC`0;0?VYC`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool000/0oooo00<000000?ooo`3oool04P3oool30000
04L0oooo00<000000:O0j`2W`>/08@2W`>/4000003l0XlGa1000000>08iHR`030000002>F8/0SUR;
00L0SUR;00<000000?VYC`3iZDl02`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo000;0?ooo`030000003oool0oooo00h0oooo1000001;0?ooo`030000002W`>/0Yl3[01`0
Yl3[100000040?ooo`030000002SaO40XlGa03P0XlGa1000000B08iHR`030000002>F8/0SUR;00L0
SUR;00<000000?VYC`3iZDl02`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo000;0?ooo`030000003oool0oooo00/0oooo0`00001@0?ooo`030000002W`>/0Yl3[01P0Yl3[
0`0000090?ooo`030000002SaO40XlGa03@0XlGa0`00000G08iHR`030000002>F8/0SUR;00H0SUR;
00<000000?VYC`3iZDl02`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
000;0?ooo`<00000203oool3000005@0oooo00<000000:O0j`2W`>/04`2W`>/4000000d0oooo00<0
00000:?5l@2SaO40;`2SaO44000001/0SUR;00<0000008iHR`2>F8/01@2>F8/00`000000nJU?0?VY
C`0;0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00080oooo0`000005
0?ooo`030000003oool0oooo00H0oooo0`00001H0?ooo`030000002W`>/0Yl3[00l0Yl3[0`00000B
0?ooo`030000002SaO40XlGa02X0XlGa1000000P08iHR`030000002>F8/0SUR;00@0SUR;00<00000
0?VYC`3iZDl02`3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool4000005`0oooo0P00000;
0:O0j`@000005P3oool00`000000XlGa0:?5l@0V0:?5l@<000009@2>F8/00`000000SUR;08iHR`04
08iHR`030000003iZDl0nJU?00X0nJU?00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0000000800000HP3oool0
0`000000Yl3[0:O0j`050:O0j`<000006`3oool00`000000XlGa0:?5l@0Q0:?5l@@00000:02>F8/0
0`000000SUR;08iHR`0408iHR`030000003iZDl0nJU?00/0nJU?00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`000P3oool3000000D0oooo0P00001U0?ooo`8000000P2W`>/40000
01l0oooo00<000000:?5l@2SaO40702SaO44000002d0SUR;00<0000008iHR`2>F8/00`2>F8/00`00
0000nJU?0?VYC`0;0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool000<0
oooo00<000000?ooo`3oool01@3oool3000006<0oooo00@000000?ooo`0000000000903oool00`00
0000XlGa0:?5l@0H0:?5l@<00000<P2>F8/00`000000SUR;08iHR`0208iHR`030000003iZDl0nJU?
00/0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`000`3oool3000000L0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0V0?ooo`030000002SaO40XlGa01<0
XlGa1000000f08iHR`050000002>F8/0SUR;08iHR`0000003@3iZDl00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo000>0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool09`3oool00`000000XlGa0:?5l@0>0:?5l@@00000>`2>F8/010000000SUR;08iHR`00000=0?VY
C`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool000l0oooo0P00001P0?ooo`03
0000003oool0oooo02P0oooo00<000000:?5l@2SaO402P2SaO43000003l0SUR;00@0000008iHR`2>
F8/000003@3iZDl00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo000A0?ooo`03
0000003oool0oooo05d0oooo00<000000?ooo`3oool0:@3oool00`000000XlGa0:?5l@050:?5l@@0
0000@`2>F8/00`000000SUR;0000000=0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00180oooo0`00001L0?ooo`030000003oool0oooo02X0oooo00<000000:?5l@2SaO40
1000001808iHR`8000003P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
000D0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0:`3oool2000004d0SUR;0P00
000=0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool001D0oooo0P00001J
0?ooo`030000003oool0oooo02/0oooo00<0000008iHR`2>F8/0C@2>F8/00`000000nJU?0?VYC`0;
0?VYC`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool001L0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0[0?ooo`030000002>F8/0SUR;04d0SUR;00<000000?VY
C`3iZDl02`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo000;0?ooo`80
00002`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo02`0oooo00<0000008iHR`2>
F8/0C02>F8/2000000`0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`00
2P3oool010000000oooo0?ooo`00000;0?ooo`800000EP3oool00`000000oooo0?ooo`0/0?ooo`03
0000002>F8/0SUR;04/0SUR;0P0000000`3iZDl000000?VYC`0:0?VYC`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool000X0oooo00@000000?ooo`3oool00000303oool2000005D0
oooo00<000000?ooo`3oool0;03oool00`000000SUR;08iHR`1708iHR`@000000P2Oao@00`000000
nJU?0000000:0?VYC`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool000X0oooo
00@000000?ooo`3oool000003P3oool2000005<0oooo00<000000?ooo`3oool0;03oool00`000000
SUR;08iHR`1308iHR`@000001`2Oao@00`000000nJU?000000090?VYC`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool000X0oooo00@000000?ooo`3oool00000403oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo02`0oooo00<0000008iHR`2>F8/0?`2>F8/4000000/0
WlOd00<000000?VYC`0000002P3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo000;0?ooo`8000004P3oool3000004l0oooo00<000000?ooo`3oool0;03oool00`000000SUR;
08iHR`0k08iHR`@00000402Oao@00`000000nJU?000000090?VYC`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00240oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0/0?ooo`030000002>F8/0SUR;03L0SUR;1000000E09o7m0030000003iZDl0000000P0nJU?00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo02`0oooo00<0000008iHR`2>F8/0<`2>F8/4000001X0WlOd00<00000
0?VYC`0000001`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo000S0?oo
o`800000C03oool00`000000oooo0?ooo`0/0?ooo`030000002>F8/0SUR;02l0SUR;1000000O09o7
m0030000003iZDl0000000H0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`009@3oool00`000000oooo000000190?ooo`030000003oool0oooo02`0oooo00<0000008iHR`2>
F8/0:`2>F8/4000002<0WlOd00@000000?VYC`3iZDl000001@3iZDl00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo000V0?ooo`800000B@3oool00`000000oooo0?ooo`0/0?ooo`03
0000002>F8/0SUR;02L0SUR;1000000X09o7m0030000003iZDl0000000D0nJU?00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`00:03oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo02`0oooo00<0000008iHR`2>F8/08`2>F8/4000002d0WlOd00<000000?VYC`000000
1@3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo000Y0?ooo`800000AP3o
ool00`000000oooo0?ooo`0/0?ooo`030000002>F8/0SUR;01l0SUR;1000000b09o7m0030000003i
ZDl0000000@0nJU?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`00:`3oool0
0`000000oooo000000130?ooo`030000003oool0oooo02`0oooo00<0000008iHR`2>F8/06`2>F8/4
000003L0WlOd00<000000?VYC`0000000`3iZDl00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo000/0?ooo`800000@P3oool00`000000oooo0?ooo`0]0?ooo`030000002>F8/0SUR;
01L0SUR;1000000l09o7m0030000003iZDl000000080nJU?00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`00;@3oool200000440oooo00<000000?ooo`3oool0;@3oool00`000000
SUR;08iHR`0C08iHR`@00000@02Oao@00`000000nJU?000000020?VYC`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool002l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0]0?ooo`030000002>F8/0SUR;00l0SUR;1000001509o7m0050000003iZDl000000?VYC`00
00001@3oool00`000000oooo0?ooo`010?ooo`00<03oool2000003h0oooo00<000000?ooo`3oool0
;@3oool00`000000SUR;08iHR`0;08iHR`@00000BP2Oao@010000000nJU?0000000000050?ooo`03
0000003oool0oooo0040oooo000b0?ooo`800000?03oool00`000000oooo0?ooo`0]0?ooo`030000
002>F8/0SUR;00L0SUR;1000001?09o7m0030000003iZDl0000000D0oooo00<000000?ooo`3oool0
0@3oool003<0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0]0?ooo`030000002>
F8/0SUR;00<0SUR;1000001D09o7m0030000003iZDl0000000@0oooo00<000000?ooo`3oool00@3o
ool003@0oooo0P00000j0?ooo`030000003oool0oooo02d0oooo00<0000008iHR`0000000`00001H
09o7m0030000003iZDl0000000@0oooo00<000000?ooo`3oool00@3oool003H0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0]0?ooo`800000G@2Oao@3000000<0oooo00<000000?oo
o`3oool00@3oool002X0oooo1@0000080?ooo`800000=`3oool00`000000oooo0?ooo`0^0?ooo`03
0000002Oao@0WlOd05X0WlOd0`0000001@3oool000000?ooo`3oool0000000<0oooo000/0?ooo`03
0000003oool0oooo00T0oooo0P00000f0?ooo`030000003oool0oooo02l0oooo00<0000009o7m02O
ao@0E@2Oao@4000000D0oooo00<000000?ooo`0000000`3oool002`0oooo00<000000?ooo`3oool0
2`3oool2000003@0oooo00<000000?ooo`3oool0<03oool00`000000WlOd09o7m01@09o7m0@00000
2P3oool00`000000oooo000000020?ooo`00;03oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0<@3oool00`000000WlOd09o7m01;09o7m0@000003P3o
ool00`000000oooo000000020?ooo`00;03oool00`000000oooo0?ooo`0>0?ooo`800000<@3oool0
0`000000oooo0?ooo`0b0?ooo`030000002Oao@0WlOd04H0WlOd1000000C0?ooo`8000000P3oool0
02/0oooo0P00000A0?ooo`800000<03oool00`000000oooo0?ooo`0c0?ooo`030000002Oao@0WlOd
0400WlOd1@00000F0?ooo`<000000P3oool00400oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0d0?ooo`030000002Oao@0WlOd03/0WlOd1000000G0?ooo`@000001@3oool00440oooo
0P0000000`3oool000000?ooo`0Z0?ooo`030000003oool0oooo03D0oooo00<0000009o7m02Oao@0
=P2Oao@4000001H0oooo1@0000090?ooo`00@`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo03H0oooo00<0000009o7m02Oao@0<@2Oao@4000001H0oooo1000000>0?ooo`00@`3oool3
000002X0oooo00<000000?ooo`3oool0=`3oool2000002`0WlOd1@00000F0?ooo`@000004P3oool0
04H0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`0i0?ooo`030000002Oao@0
WlOd02D0WlOd1000000F0?ooo`D000005P3oool004L0oooo00<000000?ooo`0000009P3oool00`00
0000oooo0?ooo`0j0?ooo`030000002Oao@0WlOd0200WlOd1000000F0?ooo`@000006`3oool004P0
oooo0P00000V0?ooo`030000003oool0oooo03/0oooo00<0000009o7m02Oao@06`2Oao@4000001D0
oooo1@00000O0?ooo`00BP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03`0oooo
00<0000009o7m02Oao@05P2Oao@4000001D0oooo1000000T0?ooo`00B`3oool2000002<0oooo00<0
00000?ooo`3oool0?@3oool00`000000WlOd09o7m00@09o7m0D00000503oool5000002P0oooo001=
0?ooo`8000008@3oool00`000000oooo0?ooo`0n0?ooo`030000002Oao@0WlOd00/0WlOd1000000E
0?ooo`@00000;@3oool004h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0o0?oo
o`030000002Oao@0WlOd00H0WlOd1000000D0?ooo`D00000<@3oool004l0oooo0P00000O0?ooo`03
0000003oool0oooo0400oooo00@0000009o7m02Oao@0WlOd1000000D0?ooo`@00000=P3oool00540
oooo00<000000?ooo`000000703oool00`000000oooo0?ooo`110?ooo`<00000503oool4000003X0
oooo001B0?ooo`800000703oool00`000000oooo0?ooo`1C0?ooo`D00000?P3oool004H0oooo1000
00090?ooo`8000006`3oool00`000000oooo0?ooo`1?0?ooo`@00000@`3oool004H0oooo00<00000
0?ooo`3oool0303oool2000001T0oooo00<000000?ooo`3oool0BP3oool5000004L0oooo00170?oo
o`030000003oool0oooo00d0oooo0P00000G0?ooo`030000003oool0oooo04H0oooo1000001<0?oo
o`00B03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0@@3oool500000500oooo00160?ooo`040000003oool0oooo000000l0oooo0P00000D0?ooo`03
0000003oool0oooo03h0oooo1000001E0?ooo`00A`3oool200000180oooo00<000000?ooo`000000
4@3oool00`000000oooo0?ooo`0i0?ooo`D00000F@3oool005`0oooo0P00000A0?ooo`030000003o
ool0oooo03D0oooo1000001N0?ooo`00GP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0340oooo1000001R0?ooo`00G`3oool2000000030?ooo`000000oooo00/0oooo00<000000?oo
o`3oool0;03oool5000006H0oooo001Q0?ooo`800000303oool00`000000oooo0?ooo`0X0?ooo`@0
0000J`3oool00680oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0S0?ooo`D00000
K`3oool006<0oooo0P00000:0?ooo`030000003oool0oooo01l0oooo1000001d0?ooo`00I@3oool2
000000P0oooo00<000000?ooo`3oool06P3oool5000007P0oooo001V0?ooo`8000001`3oool00`00
0000oooo0?ooo`0F0?ooo`@00000O@3oool006P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0A0?ooo`D00000P@3oool006T0oooo0`0000030?ooo`030000003oool0oooo00d0oooo
100000260?ooo`00J`3oool01@000000oooo0?ooo`3oool0000000/0oooo1000002:0?ooo`00H03o
ool2000000X0oooo00@000000?ooo`3oool000001P3oool5000008h0oooo001O0?ooo`040000003o
ool0oooo000000X0oooo0`0000020?ooo`@00000T`3oool00640oooo00<000000?ooo`3oool02`3o
ool3000009L0oooo001R0?ooo`030000003oool0oooo0:@0oooo001O0?ooo`040000003oool0oooo
00000:H0oooo001P0?ooo`800000Y`3oool00001\
\>"],
  ImageRangeCache->{{{0, 264.313}, {286.938, 0}} -> {0.0120589, -0.035668, \
0.00340708, 0.00340708}}]
}, Open  ]],

Cell["Unfortunately, RealTime3D throws away all style directives.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(<< RealTime3D`\), "\[IndentingNewLine]", 
    \(\(Show[plot1];\)\), "\[IndentingNewLine]", 
    \(<< Default3D`\)}], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
  Graphics3D[{
    Cuboid[{0.500000, 0.500000, 0.000000},{1.500000, 1.500000, 1.000000}],
    Cuboid[{0.500000, 1.500000, 0.000000},{1.500000, 2.500000, 2.000000}],
    Cuboid[{0.500000, 2.500000, 0.000000},{1.500000, 3.500000, 3.000000}],
    Cuboid[{1.500000, 0.500000, 0.000000},{2.500000, 1.500000, 4.000000}],
    Cuboid[{1.500000, 1.500000, 0.000000},{2.500000, 2.500000, 5.000000}],
    Cuboid[{1.500000, 2.500000, 0.000000},{2.500000, 3.500000, 6.000000}]},
    BoxRatios -> {1.000000, 1.000000, 1.000000},
    ViewPoint -> {-1.912929, -1.442961, 2.229199}
  ]
], "Graphics",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00WP3oool3000007l0oooo002L0?ooo`80000000@0oooo0000003oool00000OP3oool009X0
oooo0P0000030?ooo`040000003oool0oooo000007d0oooo002H0?ooo`8000001@3oool01@000000
oooo0?ooo`3oool0000007`0oooo002G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1i0?ooo`00U@3oool2000000P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1h0?ooo`00T`3oool2000000X0oooo00<000000?ooo`3oool0103o
ool2000007P0oooo002A0?ooo`800000303oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo07D0oooo002?0?ooo`8000003P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
07@0oooo002>0?ooo`030000003oool0oooo00`0oooo0`00000:0?ooo`030000003oool0oooo07<0
oooo002<0?ooo`8000003@3oool20000000303<c<`000000000000/0oooo00<000000?ooo`3oool0
LP3oool008X0oooo0P00000=0?ooo`8000000`0c<c<3000000/0oooo00<000000?ooo`3oool0L@3o
ool008P0oooo0P00000=0?ooo`8000001@0c<c<20000000303<c<`000000000000X0oooo0P00001a
0?ooo`00QP3oool2000000h0oooo0P00000603<c<`8000000`0c<c<00`000000oooo0?ooo`090?oo
o`030000003oool0oooo06h0oooo00250?ooo`030000003oool0oooo00`0oooo0P00000803<c<`80
0000100c<c<00`000000oooo0?ooo`090?ooo`030000003oool0oooo06d0oooo00230?ooo`800000
3@3oool2000000X0<c<c0P00000503<c<`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
K03oool00840oooo0P00000=0?ooo`800000300c<c<2000000H0<c<c00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1[0?ooo`00O`3oool2000000d0oooo0P00000>03<c<`8000001`0c<c<0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo06X0oooo001m0?ooo`8000003@3oool20000
0100<c<c0P00000803<c<`8000002P3oool2000006X0oooo001l0?ooo`030000003oool0oooo00`0
oooo00<0000003<c<`0c<c<0400c<c<00`000000<c<c0000000903<c<`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0I`3oool007X0oooo0P00000=0?ooo`8000004`0c<c<00`000000<c<c
0000000:03<c<`030000003oool0oooo00T0oooo00<000000?ooo`3oool0IP3oool007P0oooo0P00
000=0?ooo`<00000500c<c<00`000000<c<c0000000;03<c<`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0I@3oool007H0oooo0P00000=0?ooo`8000000P0c<c<00`000000<c<c03<c<`0B
03<c<`030000000c<c<0000000`0<c<c00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1T
0?ooo`00M03oool2000000d0oooo0P00000403<c<`030000000c<c<0<c<c0180<c<c00<0000003<c
<`0000003@0c<c<2000000X0oooo00<000000?ooo`3oool0H`3oool007<0oooo00<000000?ooo`3o
ool02`3oool2000000H0<c<c00<0000003<c<`0c<c<04P0c<c<00`000000<c<c0000000=03<c<`03
0000000c<c<0000000X0oooo00<000000?ooo`3oool0HP3oool00740oooo0P00000=0?ooo`030000
000c<c<0<c<c00H0<c<c00<0000003<c<`0c<c<04P0c<c<00`000000<c<c0000000=03<c<`040000
000c<c<0<c<c000000X0oooo0P00001R0?ooo`00K`3oool2000000d0oooo0P00000903<c<`030000
000c<c<0<c<c0180<c<c00<0000003<c<`0000003@0c<c<01@000000<c<c03<c<`0c<c<0000000/0
oooo00<000000?ooo`3oool0G`3oool006d0oooo0P00000=0?ooo`8000002`0c<c<00`000000<c<c
03<c<`0B03<c<`030000000c<c<0000000d0<c<c00<0000003<c<`0c<c<00P0c<c<00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05h0oooo001[0?ooo`8000003@3oool2000000d0<c<c00<0
000003<c<`0c<c<04P0c<c<00`000000<c<c0000000=03<c<`030000000c<c<0<c<c00<0<c<c00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`1M0?ooo`00JP3oool00`000000oooo0?ooo`0;
0?ooo`8000003`0c<c<00`000000<c<c03<c<`0B03<c<`030000000c<c<0000000d0<c<c00<00000
03<c<`0c<c<0100c<c<2000000X0oooo00<000000?ooo`3oool0G03oool006P0oooo0P00000<0?oo
o`8000004@0c<c<00`000000<c<c03<c<`0B03<c<`030000000c<c<0000000d0<c<c00<0000003<c
<`0c<c<01P0c<c<00`000000oooo0?ooo`050?ooo`<00000GP3oool006H0oooo0P00000=0?ooo`03
0000000c<c<0<c<c0140<c<c00<0000003<c<`0c<c<0400c<c<2000000030<RYb0000000000000d0
<c<c00<0000003<c<`0c<c<01`0c<c<00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000
oooo0?ooo`1L0?ooo`00I03oool2000000d0oooo0`00000C03<c<`030000000c<c<0<c<c00h0<c<c
0P0000040<RYb0800000300c<c<00`000000<c<c03<c<`0803<c<`040000003oool00000000000@0
oooo00<000000?ooo`3oool0G03oool00680oooo0P00000=0?ooo`8000000P0c<c<00`000000<c<c
03<c<`0A03<c<`030000000c<c<0<c<c00`0<c<c0P0000060<RYb00300000038ZLP0000000/0<c<c
00<0000003<c<`0c<c<02@0c<c<00`000000oooo0?ooo`050?ooo`030000003oool0oooo05/0oooo
001Q0?ooo`030000003oool0oooo00/0oooo0P00000403<c<`030000000c<c<0<c<c0140<c<c00<0
000003<c<`0c<c<02P0c<c<2000000P0b:W800@000000<RYb038ZLP000002P0c<c<00`000000<c<c
03<c<`0:03<c<`8000001@3oool00`000000oooo0?ooo`1K0?ooo`00G`3oool2000000`0oooo0P00
000603<c<`030000000c<c<0<c<c0140<c<c00<0000003<c<`0c<c<0200c<c<2000000X0b:W800D0
00000<RYb038ZLP0b:W80000000903<c<`030000000c<c<0<c<c00`0<c<c00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1K0?ooo`00GP3oool3000000X0oooo0P00000803<c<`030000000c
<c<0<c<c0140<c<c00<0000003<c<`0c<c<01P0c<c<2000000`0b:W800<000000<RYb038ZLP00P38
ZLP2000000L0<c<c00<0000003<c<`0c<c<0300c<c<00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo05/0oooo001N0?ooo`040000003oool0oooo000000L0oooo0P00000:03<c<`030000000c
<c<0<c<c0140<c<c00<0000003<c<`0c<c<0100c<c<2000000h0b:W800<000000<RYb038ZLP01038
ZLP00`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c00`0<c<c00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1K0?ooo`00GP3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
000003<c<`0c<c<02P0c<c<00`000000<c<c03<c<`0A03<c<`030000000c<c<0<c<c0080<c<c0P00
000@0<RYb00300000038ZLP0b:W800D0b:W800<0000003<c<`0c<c<00`0c<c<00`000000<c<c03<c
<`0<03<c<`030000003oool0oooo0080oooo00<000000?ooo`3oool0F`3oool005h0oooo00<00000
0?ooo`3oool00P3oool2000000030?ooo`000000000000d0<c<c00<0000003<c<`0c<c<04@0c<c<0
0`000000<c<c03<c<`0200000180b:W800<000000<RYb038ZLP01P38ZLP00`000000<c<c03<c<`03
03<c<`030000000c<c<0<c<c00/0<c<c00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1K
0?ooo`00GP3oool00`000000oooo0?ooo`030?ooo`8000003`0c<c<00`000000<c<c03<c<`0A03<c
<`<000005038ZLP00`000000b:W80<RYb0070<RYb08000000`0c<c<00`000000<c<c03<c<`0;03<c
<`030000003oool0oooo0080oooo00<000000?ooo`3oool0F`3oool005h0oooo00<000000?ooo`3o
ool00P3oool00`000000<c<c03<c<`0?03<c<`030000000c<c<0<c<c0140<c<c00<000000<RYb038
ZLP05038ZLP00`000000b:W80<RYb0090<RYb0040000000c<c<0<c<c000000d0<c<c00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1K0?ooo`00GP3oool00`000000oooo0?ooo`020?ooo`03
0000000c<c<0<c<c00l0<c<c00<0000003<c<`0c<c<04@0c<c<00`000000<c<c0<RYb00D0<RYb003
00000038ZLP0b:W800X0b:W800<0000003<c<`0000003@0c<c<00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo05/0oooo001N0?ooo`050000003oool0oooo0?ooo`0000004P0c<c<00`000000
<c<c03<c<`0A03<c<`040000000c<c<0<c<c000001<0b:W800<000000<RYb038ZLP02`38ZLP20000
00d0<c<c00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1K0?ooo`00GP3oool01@000000
oooo0?ooo`3oool000000180<c<c00<0000003<c<`0c<c<04@0c<c<01@000000<c<c03<c<`0c<c<0
00000180b:W800<000000<RYb038ZLP02P38ZLP00`000000<c<c0000000>03<c<`050000003oool0
oooo0?ooo`000000G@3oool005h0oooo00D000000?ooo`3oool0oooo0000000B03<c<`030000000c
<c<0<c<c0140<c<c00<0000003<c<`0c<c<00`0c<c<A0<RYb00300000038ZLP0b:W800P0b:W800D0
000003<c<`0c<c<0<c<c0000000>03<c<`050000003oool0oooo0?ooo`000000G@3oool005h0oooo
00D000000?ooo`3oool0oooo0000000B03<c<`030000000c<c<0<c<c0140<c<c00<0000003<c<`0c
<c<0100c<c<00`000000b:W80<RYb00=0<RYb00300000038ZLP0b:W800H0b:W800<0000003<c<`0c
<c<00`0c<c<00`000000<c<c03<c<`0<03<c<`050000003oool0oooo0?ooo`000000G@3oool005h0
oooo00D000000?ooo`3oool0oooo0000000B03<c<`030000000c<c<0<c<c0140<c<c00<0000003<c
<`0c<c<01@0c<c<00`000000b:W80<RYb00<0<RYb00300000038ZLP0b:W800@0b:W800<0000003<c
<`0c<c<01@0c<c<00`000000<c<c03<c<`0<03<c<`050000003oool0oooo0?ooo`000000G@3oool0
05h0oooo00D000000?ooo`3oool0oooo0000000B03<c<`030000000c<c<0<c<c0140<c<c00<00000
03<c<`0c<c<01`0c<c<=0<RYb00300000038ZLP0b:W80080b:W800<0000003<c<`0c<c<01`0c<c<0
0`000000<c<c03<c<`0<03<c<`050000003oool0oooo0?ooo`000000G@3oool005h0oooo00D00000
0?ooo`3oool0oooo0000000B03<c<`030000000c<c<0<c<c0140<c<c00<0000003<c<`0c<c<0200c
<c<00`000000b:W80<RYb0090<RYb00300000038ZLP0000000`0<c<c00<0000003<c<`0c<c<0300c
<c<00`000000oooo0?ooo`020?ooo`030000003oool0oooo05X0oooo001N0?ooo`050000003oool0
oooo0?ooo`0000004P0c<c<00`000000<c<c03<c<`0A03<c<`030000000c<c<0<c<c00T0<c<c00<0
00000<RYb038ZLP02038ZLP00`000000<c<c03<c<`0<03<c<`030000000c<c<0<c<c00`0<c<c00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1J0?ooo`00GP3oool01@000000oooo0?ooo`3o
ool000000180<c<c00<0000003<c<`0c<c<04@0c<c<00`000000<c<c03<c<`0;03<c<`L0b:W800<0
000003<c<`0000003P0c<c<00`000000<c<c03<c<`0<03<c<`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0FP3oool005d0oooo00<000000?ooo`3oool00P3oool00`000000<c<c03<c<`0@
03<c<`030000000c<c<0<c<c0140<c<c00<0000003<c<`0c<c<0300c<c<01@000000b:W80<RYb038
ZLP0000000<0<c<c00<0000003<c<`0c<c<0300c<c<00`000000<c<c03<c<`0<03<c<`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0FP3oool005d0oooo00<000000?ooo`3oool00P3oool0
0`000000<c<c03<c<`0@03<c<`030000000c<c<0<c<c0140<c<c00<0000003<c<`0c<c<03@0c<c<2
000000D0<c<c00<0000003<c<`0c<c<0300c<c<00`000000<c<c03<c<`0<03<c<`030000003oool0
oooo0080oooo00<000000?ooo`3oool0FP3oool005d0oooo00<000000?ooo`3oool00P3oool00`00
0000<c<c03<c<`0@03<c<`030000000c<c<0<c<c0140<c<c00<0000003<c<`0c<c<03P0c<c<00`00
0000<c<c03<c<`0303<c<`030000000c<c<0<c<c00`0<c<c00<0000003<c<`0c<c<0300c<c<00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo05X0oooo001M0?ooo`030000003oool0oooo0080
oooo00<0000003<c<`0c<c<03`0c<c<00`000000<c<c03<c<`0B03<c<`030000000c<c<0<c<c00h0
<c<c00<0000003<c<`0c<c<00`0c<c<00`000000<c<c03<c<`0<03<c<`030000000c<c<0<c<c00`0
<c<c00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1J0?ooo`00G@3oool00`000000oooo
0?ooo`020?ooo`030000000c<c<0<c<c00l0<c<c00<0000003<c<`0c<c<04P0c<c<00`000000<c<c
03<c<`0>03<c<`030000000c<c<0<c<c00<0<c<c00<0000003<c<`0c<c<0300c<c<00`000000<c<c
03<c<`0<03<c<`030000003oool0oooo0080oooo00<000000?ooo`3oool0FP3oool005d0oooo00<0
00000?ooo`3oool00P3oool00`000000<c<c03<c<`0?03<c<`030000000c<c<0<c<c0180<c<c00<0
000003<c<`0c<c<03P0c<c<00`000000<c<c03<c<`0303<c<`030000000c<c<0<c<c00`0<c<c00<0
000003<c<`0c<c<0300c<c<00`000000oooo0?ooo`020?ooo`030000003oool0oooo05X0oooo001M
0?ooo`030000003oool0oooo0080oooo00<0000003<c<`0c<c<03`0c<c<00`000000<c<c03<c<`0B
03<c<`030000000c<c<0<c<c00h0<c<c00<0000003<c<`0c<c<00`0c<c<00`000000<c<c03<c<`0<
03<c<`030000000c<c<0<c<c00`0<c<c00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1J
0?ooo`00G@3oool00`000000oooo0?ooo`020?ooo`030000000c<c<0<c<c00l0<c<c00<0000003<c
<`0c<c<04P0c<c<00`000000<c<c03<c<`0>03<c<`030000000c<c<0<c<c00<0<c<c00<0000003<c
<`0c<c<0300c<c<00`000000<c<c03<c<`0<03<c<`030000003oool0oooo0080oooo00<000000?oo
o`3oool0FP3oool005d0oooo00<000000?ooo`3oool00P3oool00`000000<c<c03<c<`0?03<c<`03
0000000c<c<0<c<c0180<c<c00<0000003<c<`0c<c<03P0c<c<00`000000<c<c03<c<`0303<c<`03
0000000c<c<0<c<c00`0<c<c00<0000003<c<`0c<c<0300c<c<00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo05X0oooo001M0?ooo`050000003oool0oooo0?ooo`0000004P0c<c<00`000000
<c<c03<c<`0B03<c<`030000000c<c<0<c<c00h0<c<c00<0000003<c<`0c<c<00`0c<c<00`000000
<c<c03<c<`0<03<c<`030000000c<c<0<c<c00d0<c<c00D000000?ooo`3oool0oooo0000001L0?oo
o`00G@3oool01@000000oooo0?ooo`3oool000000180<c<c00<0000003<c<`0c<c<04P0c<c<00`00
0000<c<c03<c<`0>03<c<`030000000c<c<0<c<c00<0<c<c00<0000003<c<`0c<c<0300c<c<00`00
0000<c<c03<c<`0=03<c<`050000003oool0oooo0?ooo`000000G03oool005d0oooo00D000000?oo
o`3oool0oooo0000000B03<c<`030000000c<c<0<c<c0140<c<c0P00000@03<c<`030000000c<c<0
<c<c00<0<c<c00<0000003<c<`0c<c<0300c<c<00`000000<c<c03<c<`0=03<c<`050000003oool0
oooo0?ooo`000000G03oool005d0oooo00D000000?ooo`3oool0oooo0000000B03<c<`030000000c
<c<0<c<c00l0<c<c0P0000020<RYb0030000000c<c<0<c<c00d0<c<c00<0000003<c<`0c<c<00`0c
<c<00`000000<c<c03<c<`0<03<c<`030000000c<c<0<c<c00d0<c<c00D000000?ooo`3oool0oooo
0000001L0?ooo`00G@3oool01@000000oooo0?ooo`3oool000000180<c<c00<0000003<c<`0c<c<0
3@0c<c<2000000D0b:W80P00000=03<c<`030000000c<c<0<c<c00<0<c<c00<0000003<c<`0c<c<0
3@0c<c<00`000000<c<c03<c<`0<03<c<`030000003oool0oooo0080oooo00<000000?ooo`3oool0
F@3oool005d0oooo00D000000?ooo`3oool0oooo0000000B03<c<`030000000c<c<0<c<c00/0<c<c
0P0000090<RYb0030000000c<c<0<c<c00X0<c<c00<0000003<c<`0c<c<00`0c<c<00`000000<c<c
03<c<`0=03<c<`030000000c<c<0<c<c00`0<c<c00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1I0?ooo`00G@3oool01@000000oooo0?ooo`3oool000000180<c<c00<0000003<c<`0c<c<0
2@0c<c<2000000`0b:W80P00000:03<c<`030000000c<c<0<c<c00<0<c<c00<0000003<c<`0c<c<0
3@0c<c<00`000000<c<c03<c<`0<03<c<`030000003oool0oooo0080oooo00<000000?ooo`3oool0
F@3oool005d0oooo00D000000?ooo`3oool0oooo0000000B03<c<`030000000c<c<0<c<c00L0<c<c
0P00000@0<RYb0030000000c<c<0<c<c00L0<c<c00<0000003<c<`0c<c<0100c<c<00`000000<c<c
03<c<`0<03<c<`030000000c<c<0<c<c00`0<c<c00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1I0?ooo`00G03oool00`000000oooo0?ooo`020?ooo`030000000c<c<0<c<c0100<c<c00<0
000003<c<`0c<c<01@0c<c<2000001<0b:W800<0000003<c<`0c<c<01P0c<c<00`000000<c<c03<c
<`0403<c<`030000000c<c<0<c<c00`0<c<c00<0000003<c<`0c<c<0300c<c<00`000000oooo0?oo
o`020?ooo`030000003oool0oooo05T0oooo001L0?ooo`030000003oool0oooo0080oooo00<00000
03<c<`0c<c<0400c<c<00`000000<c<c03<c<`0303<c<`8000005P38ZLP2000000H0<c<c00<00000
03<c<`0c<c<0100c<c<00`000000<c<c03<c<`0<03<c<`030000000c<c<0<c<c00`0<c<c00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1I0?ooo`00G03oool00`000000oooo0?ooo`020?oo
o`030000000c<c<0<c<c0100<c<c00@0000003<c<`0c<c<0<c<c0P00000J0<RYb0030000000c<c<0
<c<c00<0<c<c00<0000003<c<`0c<c<0100c<c<00`000000<c<c03<c<`0<03<c<`030000000c<c<0
<c<c00`0<c<c00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1I0?ooo`00G03oool00`00
0000oooo0?ooo`020?ooo`030000000c<c<0<c<c0100<c<c1000000M0<RYb08000000`0c<c<00`00
0000<c<c03<c<`0403<c<`030000000c<c<0<c<c00`0<c<c00<0000003<c<`0c<c<0300c<c<00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo05T0oooo001L0?ooo`030000003oool0oooo0080
oooo00<0000003<c<`0c<c<0400c<c<00`000000b:W80<RYb00P0<RYb0040000000c<c<0<c<c0000
00H0<c<c00<0000003<c<`0c<c<0300c<c<00`000000<c<c03<c<`0<03<c<`030000003oool0oooo
0080oooo00<000000?ooo`3oool0F@3oool005`0oooo00<000000?ooo`3oool00P3oool00`000000
<c<c03<c<`0@03<c<`030000000c<c<000000240b:W800<0000003<c<`0000001P0c<c<00`000000
<c<c03<c<`0<03<c<`030000000c<c<0<c<c00`0<c<c00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1I0?ooo`00G03oool00`000000oooo0?ooo`020?ooo`030000000c<c<0<c<c0100<c<c
00@0000003<c<`0c<c<000008@38ZLP2000000H0<c<c00<0000003<c<`0c<c<0300c<c<00`000000
<c<c03<c<`0<03<c<`030000003oool0oooo0080oooo00<000000?ooo`3oool0F@3oool005`0oooo
00<000000?ooo`3oool00P3oool00`000000<c<c03<c<`0@03<c<`030000000c<c<0<c<c0080<c<c
00<000000<RYb038ZLP06`38ZLP20000000303<c<`000000<c<c00D0<c<c00<0000003<c<`0c<c<0
300c<c<00`000000<c<c03<c<`0<03<c<`030000003oool0oooo0080oooo00<000000?ooo`3oool0
F@3oool005`0oooo00<000000?ooo`3oool00P3oool00`000000<c<c03<c<`0@03<c<`030000000c
<c<0<c<c00<0<c<c00<000000<RYb038ZLP06038ZLP00`000000<c<c03<c<`0203<c<`030000000c
<c<0<c<c00@0<c<c00<0000003<c<`0c<c<0300c<c<00`000000<c<c03<c<`0<03<c<`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0F@3oool005`0oooo00<000000?ooo`3oool00P3oool0
0`000000<c<c03<c<`0@03<c<`030000000c<c<0<c<c00D0<c<c00<000000<RYb038ZLP05038ZLP0
0`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<0300c<c<0
0`000000<c<c03<c<`0<03<c<`030000003oool0oooo0080oooo00<000000?ooo`3oool0F@3oool0
05`0oooo00D000000?ooo`3oool0oooo0000000C03<c<`030000000c<c<0<c<c00H0<c<c00<00000
0<RYb038ZLP04@38ZLP00`000000<c<c03<c<`0603<c<`030000000c<c<0<c<c00@0<c<c00<00000
03<c<`0c<c<0300c<c<00`000000<c<c03<c<`0=03<c<`050000003oool0oooo0?ooo`000000F`3o
ool005`0oooo00D000000?ooo`3oool0oooo0000000C03<c<`030000000c<c<0<c<c00P0<c<c00<0
00000<RYb038ZLP03@38ZLP00`000000<c<c03<c<`0803<c<`030000000c<c<0<c<c00@0<c<c00<0
000003<c<`0c<c<0300c<c<00`000000<c<c03<c<`0=03<c<`050000003oool0oooo0?ooo`000000
F`3oool005`0oooo00D000000?ooo`3oool0oooo0000000C03<c<`030000000c<c<0<c<c00T0<c<c
00<000000<RYb038ZLP02P38ZLP00`000000<c<c03<c<`0:03<c<`030000000c<c<0<c<c00@0<c<c
00<0000003<c<`0c<c<0300c<c<00`000000<c<c03<c<`0=03<c<`030000003oool0oooo0080oooo
00<000000?ooo`3oool0F03oool005`0oooo00D000000?ooo`3oool0oooo0000000C03<c<`030000
000c<c<0<c<c00/0<c<c00<000000<RYb038ZLP01@38ZLP2000000h0<c<c00<0000003<c<`0c<c<0
100c<c<00`000000<c<c03<c<`0<03<c<`030000000c<c<0<c<c00d0<c<c00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1H0?ooo`00G03oool01@000000oooo0?ooo`3oool0000001<0<c<c
00<0000003<c<`0c<c<0300c<c<00`000000b:W80<RYb0020<RYb0030000000c<c<0<c<c00l0<c<c
00<0000003<c<`0c<c<0100c<c<00`000000<c<c03<c<`0<03<c<`030000000c<c<0<c<c00d0<c<c
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1H0?ooo`00G03oool01@000000oooo0?oo
o`3oool0000001<0<c<c00<0000003<c<`0c<c<03P0c<c<2000001<0<c<c00<0000003<c<`0c<c<0
100c<c<00`000000<c<c03<c<`0<03<c<`030000000c<c<0<c<c00d0<c<c00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1H0?ooo`00F`3oool00`000000oooo0?ooo`020?ooo`030000000c
<c<0<c<c0100<c<c00<0000003<c<`0c<c<03`0c<c<00`000000<c<c03<c<`0B03<c<`030000000c
<c<0<c<c00@0<c<c00<0000003<c<`0c<c<0300c<c<00`000000<c<c03<c<`0=03<c<`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0F03oool005/0oooo00<000000?ooo`3oool00P3oool0
0`000000<c<c03<c<`0@03<c<`030000000c<c<0<c<c00l0<c<c00<0000003<c<`0c<c<04P0c<c<0
0`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c00`0<c<c00<0000003<c<`0c<c<03@0c<c<0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo05P0oooo001K0?ooo`030000003oool0oooo
0080oooo00<0000003<c<`0c<c<0400c<c<00`000000<c<c03<c<`0?03<c<`030000000c<c<0<c<c
0180<c<c00<0000003<c<`0c<c<0100c<c<00`000000<c<c03<c<`0<03<c<`030000000c<c<0<c<c
00d0<c<c00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1H0?ooo`00F`3oool00`000000
oooo0?ooo`020?ooo`030000000c<c<0<c<c0100<c<c00<0000003<c<`0c<c<03`0c<c<00`000000
<c<c03<c<`0B03<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<0300c<c<00`000000
<c<c03<c<`0=03<c<`030000003oool0oooo0080oooo00<000000?ooo`3oool0F03oool005/0oooo
00<000000?ooo`3oool00P3oool00`000000<c<c03<c<`0@03<c<`030000000c<c<0<c<c00l0<c<c
00<0000003<c<`0c<c<04P0c<c<00`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c00`0<c<c
00<0000003<c<`0c<c<03@0c<c<00`000000oooo0?ooo`020?ooo`030000003oool0oooo05P0oooo
001K0?ooo`030000003oool0oooo0080oooo00<0000003<c<`0c<c<0400c<c<00`000000<c<c03<c
<`0?03<c<`030000000c<c<0<c<c0180<c<c00<0000003<c<`0c<c<0100c<c<00`000000<c<c03<c
<`0<03<c<`030000000c<c<0<c<c00d0<c<c00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1H0?ooo`00F`3oool00`000000oooo0?ooo`020?ooo`030000000c<c<0<c<c0100<c<c00<00000
03<c<`0c<c<03`0c<c<00`000000<c<c03<c<`0B03<c<`030000000c<c<0<c<c00@0<c<c00<00000
03<c<`0c<c<03@0c<c<00`000000<c<c03<c<`0<03<c<`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0F03oool005/0oooo00<000000?ooo`3oool00P3oool00`000000<c<c03<c<`0@03<c
<`030000000c<c<0<c<c00l0<c<c00<0000003<c<`0c<c<04P0c<c<00`000000<c<c03<c<`0403<c
<`030000000c<c<0<c<c00d0<c<c00<0000003<c<`0c<c<0300c<c<00`000000oooo0?ooo`020?oo
o`030000003oool0oooo05P0oooo001K0?ooo`030000003oool0oooo0080oooo00<0000003<c<`0c
<c<0400c<c<00`000000<c<c03<c<`0?03<c<`030000000c<c<0<c<c0180<c<c00<0000003<c<`0c
<c<0100c<c<00`000000<c<c03<c<`0=03<c<`030000000c<c<0<c<c00`0<c<c00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1H0?ooo`00F`3oool00`000000oooo0?ooo`020?ooo`030000
000c<c<0<c<c0100<c<c00<0000003<c<`0c<c<03`0c<c<00`000000<c<c03<c<`0B03<c<`030000
000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<03@0c<c<00`000000<c<c03<c<`0<03<c<`030000
003oool0oooo0080oooo00<000000?ooo`3oool0F03oool005/0oooo00<000000?ooo`3oool00P3o
ool00`000000<c<c03<c<`0@03<c<`030000000c<c<0<c<c00l0<c<c00<0000003<c<`0c<c<04P0c
<c<00`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c00d0<c<c00<0000003<c<`0c<c<0300c
<c<00`000000oooo0?ooo`020?ooo`030000003oool0oooo05P0oooo001K0?ooo`030000003oool0
oooo0080oooo00<0000003<c<`0c<c<03`0c<c<300000100<c<c00<0000003<c<`0c<c<04P0c<c<0
0`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c00d0<c<c00<0000003<c<`0c<c<0300c<c<0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo05P0oooo001K0?ooo`050000003oool0oooo
0?ooo`000000400c<c<2000000<0b:W800<0000003<c<`0c<c<03@0c<c<00`000000<c<c03<c<`0B
03<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<03@0c<c<00`000000<c<c03<c<`0=
03<c<`030000003oool0oooo0080oooo00<000000?ooo`3oool0E`3oool005/0oooo00D000000?oo
o`3oool0oooo0000000>03<c<`8000001P38ZLP2000000d0<c<c00<0000003<c<`0c<c<04P0c<c<0
0`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c00d0<c<c00<0000003<c<`0c<c<03@0c<c<0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo05L0oooo001K0?ooo`050000003oool0oooo
0?ooo`000000300c<c<2000000X0b:W80P00000;03<c<`030000000c<c<0<c<c0180<c<c00<00000
03<c<`0c<c<0100c<c<00`000000<c<c03<c<`0=03<c<`030000000c<c<0<c<c00d0<c<c00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1G0?ooo`00F`3oool01@000000oooo0?ooo`3oool0
000000T0<c<c0`00000>0<RYb0030000000c<c<0<c<c00P0<c<c00<0000003<c<`0c<c<04P0c<c<0
0`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c00d0<c<c00<0000003<c<`0c<c<03@0c<c<0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo05L0oooo001J0?ooo`030000003oool0oooo
0080oooo00<0000003<c<`0c<c<01@0c<c<200000180b:W80P00000803<c<`030000000c<c<0<c<c
0180<c<c00<0000003<c<`0c<c<0100c<c<00`000000<c<c03<c<`0=03<c<`030000000c<c<0<c<c
00d0<c<c00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1G0?ooo`00FP3oool00`000000
oooo0?ooo`020?ooo`030000000c<c<0<c<c00<0<c<c0P00000F0<RYb0030000000c<c<0<c<c00D0
<c<c00<0000003<c<`0c<c<04P0c<c<00`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c00d0
<c<c00<0000003<c<`0c<c<03@0c<c<00`000000oooo0?ooo`020?ooo`030000003oool0oooo05L0
oooo001J0?ooo`030000003oool0oooo0080oooo00@0000003<c<`0c<c<0<c<c0P00000I0<RYb080
00001@0c<c<00`000000<c<c03<c<`0B03<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c
<c<03@0c<c<00`000000<c<c03<c<`0=03<c<`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0E`3oool005X0oooo00<000000?ooo`3oool00P3oool010000000<c<c00000000000M0<RYb080
00000`0c<c<00`000000<c<c03<c<`0B03<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c
<c<03@0c<c<00`000000<c<c03<c<`0=03<c<`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0E`3oool005X0oooo00<000000?ooo`3oool00P3oool200000240b:W800@0000003<c<`0c<c<0
0000500c<c<00`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c00d0<c<c00<0000003<c<`0c
<c<03@0c<c<00`000000oooo0?ooo`020?ooo`030000003oool0oooo05L0oooo001J0?ooo`030000
003oool0oooo00<0oooo0P00000Q0<RYb0<00000500c<c<00`000000<c<c03<c<`0403<c<`030000
000c<c<0<c<c00d0<c<c00<0000003<c<`0c<c<03@0c<c<00`000000oooo0?ooo`020?ooo`030000
003oool0oooo05L0oooo001J0?ooo`030000003oool0oooo00D0oooo0P00000P0<RYb0800000500c
<c<00`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c00d0<c<c00<0000003<c<`0c<c<03@0c
<c<00`000000oooo0?ooo`020?ooo`030000003oool0oooo05L0oooo001J0?ooo`030000003oool0
oooo00L0oooo00<000000<RYb038ZLP06`38ZLP010000000<c<c03<c<`00000D03<c<`030000000c
<c<0<c<c00@0<c<c00<0000003<c<`0c<c<03@0c<c<00`000000<c<c03<c<`0=03<c<`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0E`3oool005X0oooo00<000000?ooo`3oool0203oool2
000001T0b:W800<0000003<c<`0c<c<00P0c<c<00`000000<c<c03<c<`0B03<c<`030000000c<c<0
<c<c00@0<c<c00<0000003<c<`0c<c<03@0c<c<00`000000<c<c03<c<`0=03<c<`030000003oool0
oooo0080oooo00<000000?ooo`3oool0E`3oool005X0oooo00<000000?ooo`3oool02P3oool20000
01@0b:W80P00000603<c<`030000000c<c<0<c<c0180<c<c00<0000003<c<`0c<c<0100c<c<00`00
0000<c<c03<c<`0=03<c<`030000000c<c<0<c<c00d0<c<c00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1G0?ooo`00FP3oool00`000000oooo0?ooo`0<0?ooo`8000004038ZLP00`000000
<c<c03<c<`0703<c<`030000000c<c<0<c<c0180<c<c00<0000003<c<`0c<c<0100c<c<00`000000
<c<c03<c<`0=03<c<`030000000c<c<0<c<c00d0<c<c00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1G0?ooo`00FP3oool00`000000oooo0?ooo`0>0?ooo`0300000038ZLP0b:W800/0b:W8
00<0000003<c<`0c<c<02@0c<c<00`000000<c<c03<c<`0B03<c<`030000000c<c<0<c<c00@0<c<c
00<0000003<c<`0c<c<03@0c<c<00`000000<c<c03<c<`0=03<c<`030000003oool0oooo0080oooo
00<000000?ooo`3oool0E`3oool005X0oooo00<000000?ooo`3oool03`3oool2000000T0b:W800<0
000003<c<`0c<c<02`0c<c<00`000000<c<c03<c<`0B03<c<`030000000c<c<0<c<c00@0<c<c00<0
000003<c<`0c<c<0300c<c<3000000h0<c<c00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1F0?ooo`00FP3oool00`000000oooo0?ooo`0A0?ooo`8000001038ZLP00`000000<c<c03<c<`0>
03<c<`030000000c<c<0<c<c0180<c<c00<0000003<c<`0c<c<0100c<c<00`000000<c<c03<c<`09
03<c<`<000000`38ZLP2000000d0<c<c00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1F
0?ooo`00FP3oool00`000000oooo0?ooo`0C0?ooo`<000004P0c<c<00`000000<c<c03<c<`0B03<c
<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<01`0c<c<2000000P0b:W800<0000003<c
<`0c<c<02P0c<c<00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo001J0?ooo`03
0000003oool0oooo01@0oooo00<0000003<c<`0c<c<04@0c<c<00`000000<c<c03<c<`0B03<c<`03
0000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<0100c<c<3000000/0b:W80P00000:03<c<`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0EP3oool005X0oooo00<000000?ooo`3oool0
503oool00`000000<c<c03<c<`0A03<c<`030000000c<c<0<c<c0180<c<c00<0000003<c<`0c<c<0
1@0c<c<010000000<c<c03<c<`0c<c<200000100b:W800<0000003<c<`0c<c<01`0c<c<00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo001I0?ooo`030000003oool0oooo01D0oooo
00<0000003<c<`0c<c<04@0c<c<00`000000<c<c03<c<`0B03<c<`030000000c<c<0<c<c00D0<c<c
1000000C0<RYb08000001`0c<c<00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo
001I0?ooo`030000003oool0oooo01D0oooo00<0000003<c<`0c<c<04@0c<c<00`000000<c<c03<c
<`0B03<c<`030000000c<c<0<c<c00@0<c<c0P00000H0<RYb0030000000c<c<0<c<c00@0<c<c00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1F0?ooo`00F@3oool00`000000oooo0?ooo`0E
0?ooo`030000000c<c<0<c<c0140<c<c00<0000003<c<`0c<c<04P0c<c<010000000<c<c03<c<`0c
<c<3000000030<RYb0000000b:W801P0b:W80P00000403<c<`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0EP3oool005T0oooo00<000000?ooo`3oool05@3oool00`000000<c<c03<c<`0A
03<c<`030000000c<c<0<c<c0180<c<c00@0000003<c<`00000000001038ZLP00`000000b:W80<RY
b00I0<RYb0050000000c<c<0<c<c03<c<`000000103oool00`000000oooo0?ooo`1F0?ooo`00F@3o
ool00`000000oooo0?ooo`0E0?ooo`030000000c<c<0<c<c0140<c<c00<0000003<c<`0c<c<04P0c
<c<2000000H0b:W800<000000<RYb038ZLP06P38ZLP20000000303<c<`000000oooo00<0oooo00<0
00000?ooo`3oool0EP3oool005T0oooo00<000000?ooo`3oool05@3oool00`000000<c<c03<c<`0A
03<c<`030000000c<c<0<c<c0180<c<c00@0000003<c<`0c<c<000001038ZLP00`000000b:W80<RY
b00L0<RYb0800000103oool00`000000oooo0?ooo`1F0?ooo`00F@3oool00`000000oooo0?ooo`0E
0?ooo`030000000c<c<0<c<c0140<c<c00<0000003<c<`0c<c<04P0c<c<01@000000<c<c03<c<`0c
<c<0000000<0b:W800<000000<RYb038ZLP07038ZLP2000000@0oooo00<000000?ooo`3oool0EP3o
ool005T0oooo00<000000?ooo`3oool05@3oool00`000000<c<c03<c<`0A03<c<`030000000c<c<0
<c<c0180<c<c00<0000003<c<`0c<c<00`0c<c<00`000000b:W80000000K0<RYb0<000001P3oool0
0`000000oooo0?ooo`1F0?ooo`00F@3oool00`000000oooo0?ooo`0E0?ooo`030000000c<c<0<c<c
0140<c<c00<0000003<c<`0c<c<04`0c<c<00`000000<c<c03<c<`0403<c<`0300000038ZLP0b:W8
01L0b:W80P0000090?ooo`030000003oool0oooo05H0oooo001I0?ooo`030000003oool0oooo01D0
oooo00<0000003<c<`0c<c<04@0c<c<00`000000<c<c03<c<`0C03<c<`030000000c<c<0<c<c00@0
<c<c0P00000E0<RYb0<000002`3oool00`000000oooo0?ooo`1F0?ooo`00F@3oool00`000000oooo
0?ooo`0E0?ooo`030000000c<c<0<c<c0140<c<c00<0000003<c<`0c<c<04`0c<c<00`000000<c<c
03<c<`0403<c<`040000000c<c<0<c<c00000100b:W80`00000>0?ooo`030000003oool0oooo05H0
oooo001I0?ooo`030000003oool0oooo01D0oooo00<0000003<c<`0c<c<04@0c<c<00`000000<c<c
03<c<`0C03<c<`030000000c<c<0<c<c00@0<c<c00D0000003<c<`0c<c<0<c<c0000000=0<RYb080
00004P3oool00`000000oooo0?ooo`1E0?ooo`00F@3oool00`000000oooo0?ooo`0E0?ooo`030000
000c<c<0<c<c0140<c<c00<0000003<c<`0c<c<04`0c<c<00`000000<c<c03<c<`0403<c<`030000
000c<c<0<c<c00<0<c<c00<000000<RYb038ZLP01P38ZLP3000001@0oooo00<000000?ooo`3oool0
E@3oool005T0oooo00<000000?ooo`3oool05@3oool00`000000<c<c03<c<`0A03<c<`030000000c
<c<0<c<c01<0<c<c00<0000003<c<`0c<c<0100c<c<00`000000<c<c03<c<`0503<c<`0400000038
ZLP0b:W80<RYb0<000005`3oool00`000000oooo0?ooo`1E0?ooo`00F@3oool00`000000oooo0?oo
o`0E0?ooo`030000000c<c<0<c<c0140<c<c00<0000003<c<`0c<c<04`0c<c<00`000000<c<c03<c
<`0403<c<`030000000c<c<0<c<c00H0<c<c0`00000J0?ooo`030000003oool0oooo05D0oooo001I
0?ooo`030000003oool0oooo01D0oooo00<0000003<c<`0c<c<04@0c<c<00`000000<c<c03<c<`0C
03<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<01`0c<c<00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo05D0oooo001H0?ooo`030000003oool0oooo01H0oooo00<0000003<c
<`0c<c<04@0c<c<00`000000<c<c03<c<`0C03<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c
<`0c<c<01`0c<c<00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05D0oooo001H0?ooo`03
0000003oool0oooo01H0oooo00<0000003<c<`0c<c<04@0c<c<00`000000<c<c03<c<`0C03<c<`03
0000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<01`0c<c<00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo05D0oooo001H0?ooo`030000003oool0oooo01D0oooo00<0000003<c<`0c<c<0
4P0c<c<00`000000<c<c03<c<`0C03<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<0
1`0c<c<00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05D0oooo001H0?ooo`030000003o
ool0oooo01D0oooo00<0000003<c<`0c<c<04P0c<c<00`000000<c<c03<c<`0C03<c<`030000000c
<c<0<c<c00@0<c<c00<0000003<c<`0c<c<01`0c<c<00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo05D0oooo001H0?ooo`030000003oool0oooo01D0oooo00<0000003<c<`0c<c<04P0c<c<0
0`000000<c<c03<c<`0C03<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<01`0c<c<0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05D0oooo001H0?ooo`030000003oool0oooo
01D0oooo00<0000003<c<`0c<c<04P0c<c<00`000000<c<c03<c<`0C03<c<`030000000c<c<0<c<c
00@0<c<c00<0000003<c<`0c<c<01`0c<c<00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
05D0oooo001H0?ooo`030000003oool0oooo01D0oooo00<0000003<c<`0c<c<04P0c<c<00`000000
<c<c03<c<`0C03<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<01`0c<c<00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo05D0oooo001H0?ooo`030000003oool0oooo01D0oooo
00<0000003<c<`0c<c<04P0c<c<00`000000<c<c03<c<`0C03<c<`030000000c<c<0<c<c00@0<c<c
00<0000003<c<`0c<c<01`0c<c<00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05D0oooo
001H0?ooo`030000003oool0oooo01D0oooo00<0000003<c<`0c<c<04P0c<c<00`000000<c<c03<c
<`0C03<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<01`0c<c<00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo05D0oooo001H0?ooo`030000003oool0oooo01D0oooo00<00000
03<c<`0c<c<04P0c<c<00`000000<c<c03<c<`0C03<c<`030000000c<c<0<c<c00@0<c<c00<00000
03<c<`0c<c<01`0c<c<00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05D0oooo001H0?oo
o`030000003oool0oooo01D0oooo00<0000003<c<`0c<c<04P0c<c<00`000000<c<c03<c<`0C03<c
<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<01`0c<c<00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo05D0oooo001H0?ooo`030000003oool0oooo01D0oooo00<0000003<c<`0c
<c<04P0c<c<00`000000<c<c03<c<`0C03<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c
<c<01`0c<c<00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05@0oooo001H0?ooo`030000
003oool0oooo01D0oooo00<0000003<c<`0c<c<04P0c<c<00`000000<c<c03<c<`0C03<c<`030000
000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<01`0c<c<00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo05@0oooo001H0?ooo`030000003oool0oooo01D0oooo00<0000003<c<`0c<c<04P0c
<c<00`000000<c<c03<c<`0C03<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<01`0c
<c<00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05@0oooo001H0?ooo`030000003oool0
oooo01D0oooo00<0000003<c<`0c<c<04P0c<c<00`000000<c<c03<c<`0@03<c<`<0000000<0b:W8
0000000c<c<0100c<c<00`000000<c<c03<c<`0703<c<`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0E03oool005P0oooo00<000000?ooo`3oool05@3oool00`000000<c<c03<c<`0B03<c
<`030000000c<c<0<c<c00d0<c<c0`0000050<RYb08000000`0c<c<00`000000<c<c03<c<`0703<c
<`030000003oool0oooo01X0oooo00<000000?ooo`3oool0E03oool005P0oooo00<000000?ooo`3o
ool05@3oool00`000000<c<c03<c<`0B03<c<`030000000c<c<0<c<c00/0<c<c0P00000:0<RYb080
000000<0<c<c0000000c<c<0200c<c<00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05@0
oooo001G0?ooo`030000003oool0oooo01H0oooo00<0000003<c<`0c<c<04P0c<c<00`000000<c<c
03<c<`0803<c<`<000003P38ZLP2000000T0<c<c00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1D0?ooo`00E`3oool00`000000oooo0?ooo`0F0?ooo`030000000c<c<0<c<c0180<c<c00<0
000003<c<`0c<c<01@0c<c<300000180b:W80`00000703<c<`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0E03oool005L0oooo00<000000?ooo`3oool05P3oool00`000000<c<c03<c<`0B
03<c<`030000000c<c<0<c<c0080<c<c0`00000E0<RYb00400000038ZLP00000000000H0<c<c00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1D0?ooo`00E`3oool00`000000oooo0?ooo`0F
0?ooo`030000000c<c<0<c<c0180<c<c00<0000003<c<`0c<c<00P00000H0<RYb00400000038ZLP0
b:W80<RYb0800000100c<c<00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05@0oooo001G
0?ooo`030000003oool0oooo01H0oooo00<0000003<c<`0c<c<04P0c<c<3000001X0b:W800<00000
0<RYb038ZLP00`38ZLP200000080<c<c00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1D
0?ooo`00E`3oool00`000000oooo0?ooo`0F0?ooo`030000000c<c<0<c<c0180<c<c0P00000K0<RY
b00300000038ZLP0b:W800D0b:W80`00000L0?ooo`030000003oool0oooo05@0oooo001G0?ooo`03
0000003oool0oooo01H0oooo00<0000003<c<`0c<c<04P0c<c<010000000<c<c03<c<`00000I0<RY
b00300000038ZLP0b:W800L0b:W800<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1D0?oo
o`00E`3oool00`000000oooo0?ooo`0F0?ooo`030000000c<c<0<c<c0180<c<c00<0000003<c<`0c
<c<00P0c<c<00`000000b:W80<RYb00E0<RYb00300000038ZLP0b:W800@0b:W80`00000M0?ooo`03
0000003oool0oooo05@0oooo001G0?ooo`030000003oool0oooo01H0oooo00<0000003<c<`0c<c<0
4P0c<c<00`000000<c<c03<c<`0403<c<`0300000038ZLP0b:W801<0b:W800@000000<RYb038ZLP0
b:W80`00000P0?ooo`030000003oool0oooo05@0oooo001G0?ooo`030000003oool0oooo01H0oooo
00<0000003<c<`0c<c<04@0c<c<00`000000<c<c03<c<`0703<c<`0300000038ZLP0b:W80140b:W8
1000000S0?ooo`030000003oool0oooo05@0oooo001G0?ooo`030000003oool0oooo01H0oooo00<0
000003<c<`0c<c<04@0c<c<00`000000<c<c03<c<`0903<c<`0300000038ZLP0b:W800d0b:W80`00
000W0?ooo`030000003oool0oooo05<0oooo001G0?ooo`030000003oool0oooo01H0oooo00<00000
03<c<`0c<c<04@0c<c<00`000000<c<c03<c<`0:03<c<`0300000038ZLP0b:W800T0b:W80`000000
103oool0000000000000000V0?ooo`030000003oool0oooo05<0oooo001G0?ooo`030000003oool0
oooo01H0oooo00<0000003<c<`0c<c<04@0c<c<00`000000<c<c03<c<`0<03<c<`0300000038ZLP0
b:W800D0b:W80P000000103oool000000000000000030?ooo`800000903oool00`000000oooo0?oo
o`1C0?ooo`00E`3oool00`000000oooo0?ooo`0F0?ooo`030000000c<c<0<c<c0140<c<c00<00000
03<c<`0c<c<03P0c<c<00`000000b:W80<RYb006000000P0oooo0P00000R0?ooo`030000003oool0
oooo05<0oooo001G0?ooo`030000003oool0oooo01D0oooo00<0000003<c<`0c<c<04P0c<c<00`00
0000<c<c03<c<`0?03<c<`D000003@3oool200000200oooo00<000000?ooo`3oool0D`3oool005L0
oooo00<000000?ooo`3oool05@3oool00`000000<c<c03<c<`0B03<c<`030000000c<c<0<c<c00h0
<c<c0`00000B0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0D`3oool005H0oooo
00<000000?ooo`3oool05P3oool00`000000<c<c03<c<`0B03<c<`030000000c<c<0<c<c00`0<c<c
0P0000000`0c<c<000000?ooo`0C0?ooo`8000007@3oool00`000000oooo0?ooo`1C0?ooo`00EP3o
ool00`000000oooo0?ooo`0F0?ooo`030000000c<c<0<c<c0180<c<c00<0000003<c<`0c<c<02@0c
<c<3000000<0<c<c00<000000?ooo`3oool0503oool2000001/0oooo00<000000?ooo`3oool0D`3o
ool005H0oooo00<000000?ooo`3oool05P3oool00`000000<c<c03<c<`0B03<c<`030000000c<c<0
<c<c00H0<c<c0`00000603<c<`030000003oool0oooo01H0oooo0P00000I0?ooo`030000003oool0
oooo05<0oooo001F0?ooo`030000003oool0oooo01H0oooo00<0000003<c<`0c<c<04P0c<c<00`00
0000<c<c03<c<`0303<c<`<000002@0c<c<00`000000oooo0?ooo`0H0?ooo`8000005`3oool00`00
0000oooo0?ooo`1C0?ooo`00EP3oool00`000000oooo0?ooo`0F0?ooo`030000000c<c<0<c<c0180
<c<c00<0000003<c<`0c<c<00`00000<03<c<`030000003oool0oooo01X0oooo0P00000E0?ooo`03
0000003oool0oooo05<0oooo001F0?ooo`030000003oool0oooo01H0oooo00<0000003<c<`0c<c<0
4P0c<c<3000000l0<c<c00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo05<0oooo001F0?ooo`030000003oool0oooo01H0oooo00<0000003<c<`0c<c<03`0c
<c<400000140<c<c00<000000?ooo`3oool07@3oool200000180oooo00<000000?ooo`3oool0D`3o
ool005H0oooo00<000000?ooo`3oool05P3oool00`000000<c<c03<c<`0<03<c<`<000000`0c<c<0
0`000000<c<c03<c<`0?03<c<`030000003oool0oooo01l0oooo0P00000@0?ooo`030000003oool0
oooo05<0oooo001F0?ooo`030000003oool0oooo01H0oooo00<0000003<c<`0c<c<02@0c<c<30000
00H0<c<c00<0000003<c<`0c<c<03`0c<c<00`000000oooo0?ooo`0Q0?ooo`8000003P3oool00`00
0000oooo0?ooo`1C0?ooo`00EP3oool00`000000oooo0?ooo`0F0?ooo`030000000c<c<0<c<c00L0
<c<c0P00000903<c<`030000000c<c<0<c<c00l0<c<c00<000000?ooo`3oool08`3oool2000000`0
oooo00<000000?ooo`3oool0D`3oool005H0oooo00<000000?ooo`3oool05P3oool00`000000<c<c
03<c<`0403<c<`<000002`0c<c<00`000000<c<c03<c<`0?03<c<`030000003oool0oooo02D0oooo
0P00000;0?ooo`030000003oool0oooo0580oooo001F0?ooo`030000003oool0oooo01H0oooo00@0
000003<c<`0c<c<0<c<c0`00000>03<c<`030000000c<c<0<c<c00l0<c<c00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0580oooo001F0?ooo`030000003o
ool0oooo01H0oooo1000000A03<c<`030000000c<c<0<c<c00l0<c<c00<000000?ooo`3oool0:03o
ool2000000P0oooo00<000000?ooo`3oool0DP3oool005H0oooo00<000000?ooo`3oool0503oool3
000001@0<c<c00<0000003<c<`0c<c<03`0c<c<00`000000oooo0?ooo`0Z0?ooo`8000001P3oool0
0`000000oooo0?ooo`1B0?ooo`00EP3oool00`000000oooo0?ooo`0A0?ooo`<000000P3oool00`00
0000<c<c03<c<`0B03<c<`030000000c<c<0<c<c00l0<c<c00<000000?ooo`3oool0;03oool20000
00@0oooo00<000000?ooo`3oool0DP3oool005H0oooo00<000000?ooo`3oool03P3oool3000000D0
oooo00<0000003<c<`0c<c<04@0c<c<300000100<c<c00<000000?ooo`3oool0;P3oool200000080
oooo00<000000?ooo`3oool0DP3oool005D0oooo00<000000?ooo`3oool0303oool3000000P0oooo
00<0000003<c<`0c<c<03P0c<c<3000000<0b:W80P00000>03<c<`030000003oool0oooo0300oooo
0`00001D0?ooo`00E@3oool00`000000oooo0?ooo`090?ooo`<000002`3oool00`000000<c<c03<c
<`0;03<c<`<000002038ZLP2000000`0<c<c00<000000?ooo`3oool0<@3oool2000005@0oooo001E
0?ooo`030000003oool0oooo00L0oooo0P00000>0?ooo`030000000c<c<0<c<c00P0<c<c0`00000=
0<RYb0<000002@0c<c<00`000000oooo0?ooo`0]0?ooo`@00000EP3oool005D0oooo00<000000?oo
o`3oool0103oool300000100oooo00<0000003<c<`0c<c<01@0c<c<3000001<0b:W80P00000703<c
<`030000003oool0oooo02X0oooo0`00001J0?ooo`00E@3oool010000000oooo0?ooo`3oool30000
01<0oooo00<0000003<c<`0c<c<00P0c<c<3000001P0b:W80P00000503<c<`030000003oool0oooo
02L0oooo0`00001M0?ooo`00E@3oool4000001H0oooo00<0000003<c<`0000000P00000M0<RYb080
00000`0c<c<00`000000oooo0?ooo`0S0?ooo`@00000H03oool005H0oooo0P00000G0?ooo`800000
8P38ZLP20000000303<c<`000000oooo0240oooo0`00001T0?ooo`00F03oool2000001H0oooo0`00
000R0<RYb08000007`3oool3000006L0oooo001J0?ooo`8000005`3oool2000001l0b:W80`00000L
0?ooo`<00000JP3oool005`0oooo0`00000F0?ooo`8000006P38ZLP3000001/0oooo1000001]0?oo
o`00G`3oool2000001H0oooo0P00000D0<RYb0@000006`3oool300000740oooo001Q0?ooo`<00000
5@3oool3000000h0b:W80`00000L0?ooo`<00000M03oool006@0oooo0P00000F0?ooo`8000002@38
ZLP3000001/0oooo1000001g0?ooo`00IP3oool2000001H0oooo0P0000040<RYb0<000006`3oool3
000007/0oooo001X0?ooo`<000005@3oool4000001/0oooo0`00001n0?ooo`00J`3oool2000001<0
oooo00<000000?ooo`3oool0603oool400000840oooo001]0?ooo`8000004@3oool00`000000oooo
0?ooo`0E0?ooo`<00000Q@3oool006l0oooo0`00000>0?ooo`030000003oool0oooo0180oooo0`00
00280?ooo`00LP3oool2000000`0oooo00<000000?ooo`3oool03P3oool4000008/0oooo001d0?oo
o`8000002P3oool00`000000oooo0?ooo`0;0?ooo`<00000S`3oool007H0oooo0`0000070?ooo`03
0000003oool0oooo00P0oooo0`00002B0?ooo`00N@3oool2000000D0oooo00<000000?ooo`3oool0
1@3oool3000009D0oooo001k0?ooo`8000000`3oool010000000oooo0?ooo`3oool4000009P0oooo
001m0?ooo`L00000W03oool00800oooo00<000000?ooo`3oool0W@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"]]
}, Open  ]],

Cell[BoxData[
    \(Clear[cylindercolor, vectors, xx, yy, zz, plot1]\)], "Input",
  CellLabel->"In[10]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->{},
WindowSize->{494, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 64, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1843, 56, 499, 16, 74, "Usage",
      CellTags->"Function?"],
    Cell[2345, 74, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 789903, 31519}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 64, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1843, 56, 499, 16, 74, "Usage",
  CellTags->"Function?"],
Cell[2345, 74, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2442, 79, 179, 3, 58, "MathCaption"],
Cell[2624, 84, 159, 6, 41, "MathCaption"],
Cell[2786, 92, 408, 14, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3219, 110, 34, 0, 39, "ExampleSection"],
Cell[3256, 112, 99, 2, 29, "Input"],
Cell[3358, 116, 248, 4, 59, "Text"],

Cell[CellGroupData[{
Cell[3631, 124, 835, 14, 269, "Input"],
Cell[4469, 140, 367184, 17846, 447, 242916, 16307, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[371668, 17989, 96, 2, 25, "Text"],
Cell[371767, 17993, 375, 7, 109, "Input"],

Cell[CellGroupData[{
Cell[372167, 18004, 779, 15, 269, "Input"],
Cell[372949, 18021, 310840, 11543, 443, 205994, 10244, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[683826, 29569, 309, 5, 129, "Input"],
Cell[684138, 29576, 64696, 1405, 294, 11723, 746, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[748849, 30984, 75, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[748949, 30988, 171, 4, 69, "Input"],
Cell[749123, 30994, 39980, 499, 294, 597, 11, "BoxData", "Graphics3D", \
"Graphics"]
}, Open  ]],
Cell[789118, 31496, 106, 2, 29, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

