(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4316,        150]*)
(*NotebookOutlinePosition[      5212,        182]*)
(*  CellTagsIndexPosition[      5138,        176]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawWithOptions", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["DrawWithOptions",
          "MR"], 
        StyleBox["[",
          "MR"], \(plot[args]\), 
        StyleBox["]",
          "MR"]}]]],
  " will extract the primitive graphics and options from any plot that \
produces or can be converted to Graphics."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "Normal usage is ",
  Cell[BoxData[
      \({primitives, \ options} = DrawWithOptions[plot[arg]]\)]],
  "."
}], "MathCaption"],

Cell["Normal display is suppressed.", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawGraphics",
    ButtonData:>{"DrawGraphics"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FullDraw",
    ButtonData:>{"FullDraw"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FullGraphics",
    ButtonStyle->"RefGuideLink"],
  " ."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[{
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<Graphics`Graphics`\>"]\)}], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
LogPlot is not directly supported in DrawingPaper because the axes labels are \
an important part of the plot. DrawWithOptions extracts the options along \
with the primitives.\
\>", "Text"],

Cell[BoxData[
    \(\({primitives, options} = 
        DrawWithOptions[LogPlot[x\^2, {x, 1, 10}]];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(primitives\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(options\)], "Input",
  CellLabel->"In[5]:="],

Cell["\<\
This puts the pieces back together. But one might as well have used LogPlot \
in the first place.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{primitives}, options];\)\)], "Input",
  CellLabel->"In[6]:="],

Cell["Here we add in another curve and change some of the options.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{primitives, \[IndentingNewLine]Red, 
          Draw[Log[10, 2  x\^2], {x, 0.2, 
              10}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotLabel \[Rule] "\<Two Log Plots\>", \
\[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]options];\)\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(Clear[primitives, options]\)], "Input",
  CellLabel->"In[8]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{494, 740},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 62, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1841, 56, 380, 13, 50, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 4967, 167}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 62, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1841, 56, 380, 13, 50, "Usage",
  CellTags->"Function?"],
Cell[2224, 71, 144, 5, 58, "MathCaption"],
Cell[2371, 78, 52, 0, 41, "MathCaption"],
Cell[2426, 80, 315, 13, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[2766, 97, 34, 0, 39, "ExampleSection"],
Cell[2803, 99, 164, 3, 49, "Input"],
Cell[2970, 104, 200, 4, 42, "Text"],
Cell[3173, 110, 137, 3, 50, "Input"],
Cell[3313, 115, 67, 2, 29, "Input"],
Cell[3383, 119, 64, 2, 29, "Input"],
Cell[3450, 123, 121, 3, 25, "Text"],
Cell[3574, 128, 110, 2, 49, "Input"],
Cell[3687, 132, 76, 0, 25, "Text"],
Cell[3766, 134, 436, 8, 173, "Input"],
Cell[4205, 144, 83, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

