(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    735153,      29681]*)
(*NotebookOutlinePosition[    736088,      29714]*)
(*  CellTagsIndexPosition[    736010,      29708]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawWithOptions3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["DrawWithOptions3D",
          "MR"], 
        StyleBox["[",
          "MR"], \(plot[args]\), 
        StyleBox["]",
          "MR"]}]]],
  " will extract the primitive graphics and the options used  from any plot \
that produces or can be converted to Graphics3D."
}], "Usage",
  CellTags->"Function?"],

Cell["Normal display is suppressed.", "MathCaption"],

Cell["\<\
DrawWithOptions3D can be used when you wish to pick up the overall plot \
options of some plot to be used in a Show or Draw3DItems statement.\
\>", "MathCaption"],

Cell[TextData[{
  "The usage is: ",
  Cell[BoxData[
      \("\<{primitives,options} = DrawWithOptions3D[plot[args]]\>"\)]]
}], "MathCaption"],

Cell["\<\
You will probably not have many occasions to use this command.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawGraphics3D",
    ButtonData:>{"DrawGraphics3D"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[{
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<Graphics`Graphics3D`\>"]\)}], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
The Graphics`Graphics3D`  routines are not directly covered by DrawGraphics. \
However you can still use them. Here we use the ShadowPlot3D example with \
DrawGraphics3D. We have added some extra plot options but failed to include \
some normal options which ShadowPlot3D uses (BoxRatios, Lighting). The result \
is unsatisfactory.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{ShadowPlot3D[
              E\^\(-\((x\^2 + y\^2)\)\), {x, \(-2\), 2}, {y, \(-2\), 2}, 
              ShadowPosition \[Rule] 1, PlotPoints \[Rule] 25] // 
            DrawGraphics3D}, Axes \[Rule] True, 
        FaceGrids \[Rule] {{\(-1\), 0, 0}, {0, 1, 0}}];\)\)], "Input",
  CellLabel->"In[259]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .79647 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.03352e-016 1.04964 -0.0751154 1.04964 [
[.03875 .24116 -12 -8.72198 ]
[.03875 .24116 0 .27802 ]
[.18188 .18504 -11.7953 -9 ]
[.18188 .18504 .20466 0 ]
[.3334 .12567 -5.59779 -9 ]
[.3334 .12567 .40221 0 ]
[.49408 .06274 -5.29792 -9 ]
[.49408 .06274 .70208 0 ]
[.66475 -0.00406 -4.99804 -9 ]
[.66475 -0.00406 1.00196 0 ]
[.71012 .00789 0 -6.24266 ]
[.71012 .00789 12 2.75734 ]
[.78813 .12692 0 -6.12643 ]
[.78813 .12692 12 2.87357 ]
[.85815 .23377 0 -6.02473 ]
[.85815 .23377 6 2.97527 ]
[.92136 .33023 0 -5.935 ]
[.92136 .33023 6 3.065 ]
[.97869 .41773 0 -5.85525 ]
[.97869 .41773 6 3.14475 ]
[.02148 .26513 -6 -2.74887 ]
[.02148 .26513 0 6.25113 ]
[.01081 .33199 -18 -2.8053 ]
[.01081 .33199 0 6.1947 ]
[-0.00032 .4018 -6 -2.86447 ]
[-0.00032 .4018 0 6.13553 ]
[-0.01196 .47476 -18 -2.9266 ]
[-0.01196 .47476 0 6.0734 ]
[ 0 0 0 0 ]
[ 1 .79647 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03448 .25553 m
.68961 0 L
s
.04831 .25013 m
.0531 .25462 L
s
[(-2)] .03875 .24116 1 .93822 Mshowa
.191 .19448 m
.19555 .1992 L
s
[(-1)] .18188 .18504 .96589 1 Mshowa
.34199 .13558 m
.34629 .14054 L
s
[(0)] .3334 .12567 .86593 1 Mshowa
.50206 .07315 m
.50605 .07836 L
s
[(1)] .49408 .06274 .76597 1 Mshowa
.67203 .00686 m
.67566 .01232 L
s
[(2)] .66475 -0.00406 .66601 1 Mshowa
.125 Mabswid
.07622 .23925 m
.07906 .24197 L
s
.10443 .22824 m
.10725 .23099 L
s
.13296 .21712 m
.13576 .21989 L
s
.16182 .20586 m
.16458 .20866 L
s
.22051 .18297 m
.22321 .18583 L
s
.25036 .17133 m
.25303 .17422 L
s
.28055 .15955 m
.28319 .16247 L
s
.31109 .14764 m
.3137 .15058 L
s
.37325 .12339 m
.3758 .1264 L
s
.40489 .11105 m
.40739 .11409 L
s
.43689 .09857 m
.43936 .10163 L
s
.46928 .08594 m
.47171 .08903 L
s
.53523 .06021 m
.53758 .06337 L
s
.56881 .04712 m
.57112 .0503 L
s
.60279 .03386 m
.60506 .03708 L
s
.6372 .02044 m
.63942 .02369 L
s
.25 Mabswid
.68961 0 m
.97156 .4298 L
s
.69789 .01262 m
.69177 .01499 L
s
[(-2)] .71012 .00789 -1 .38726 Mshowa
.77579 .13138 m
.76962 .13361 L
s
[(-1)] .78813 .12692 -1 .36143 Mshowa
.84573 .23798 m
.83951 .24009 L
s
[(0)] .85815 .23377 -1 .33883 Mshowa
.90886 .33421 m
.90261 .33621 L
s
[(1)] .92136 .33023 -1 .31889 Mshowa
.96612 .42151 m
.95984 .4234 L
s
[(2)] .97869 .41773 -1 .30117 Mshowa
.125 Mabswid
.71417 .03745 m
.71049 .03885 L
s
.73009 .06171 m
.72641 .0631 L
s
.74566 .08545 m
.74197 .08682 L
s
.76089 .10866 m
.75719 .11002 L
s
.79038 .15361 m
.78667 .15493 L
s
.80465 .17537 m
.80094 .17668 L
s
.81863 .19668 m
.81491 .19797 L
s
.83232 .21755 m
.8286 .21882 L
s
.85886 .25801 m
.85513 .25926 L
s
.87174 .27763 m
.868 .27887 L
s
.88436 .29687 m
.88061 .29809 L
s
.89673 .31572 m
.89298 .31693 L
s
.92075 .35235 m
.917 .35353 L
s
.93242 .37013 m
.92866 .3713 L
s
.94387 .38758 m
.9401 .38874 L
s
.9551 .40471 m
.95133 .40585 L
s
.25 Mabswid
.03448 .25553 m
0 .47309 L
s
.03371 .26038 m
.03982 .258 L
s
[(0)] .02148 .26513 1 -0.38914 Mshowa
.02309 .32737 m
.02923 .32506 L
s
[(0.5)] .01081 .33199 1 -0.3766 Mshowa
.01201 .39732 m
.01817 .39508 L
s
[(1)] -0.00032 .4018 1 -0.36345 Mshowa
.00042 .47043 m
.00661 .46827 L
s
[(1.5)] -0.01196 .47476 1 -0.34964 Mshowa
.125 Mabswid
.03162 .27355 m
.03529 .27213 L
s
.02952 .28683 m
.03319 .28542 L
s
.02739 .30023 m
.03107 .29882 L
s
.02525 .31374 m
.02893 .31234 L
s
.02091 .34112 m
.0246 .33974 L
s
.01872 .35498 m
.02241 .35361 L
s
.0165 .36897 m
.02019 .36761 L
s
.01426 .38308 m
.01796 .38173 L
s
.00973 .41168 m
.01343 .41035 L
s
.00744 .42617 m
.01114 .42485 L
s
.00512 .44079 m
.00883 .43948 L
s
.00278 .45555 m
.00649 .45424 L
s
.4 g
.25 Mabswid
.03371 .26038 m
.40448 .60403 L
s
.02309 .32737 m
.40234 .66514 L
s
.01201 .39732 m
.40013 .72845 L
s
.00042 .47043 m
.39784 .79409 L
s
.04511 .26542 m
.01157 .48249 L
s
.14586 .35906 m
.12071 .57123 L
s
.23737 .44412 m
.21922 .65132 L
s
.32086 .52172 m
.30858 .72397 L
s
.39734 .59281 m
.39001 .79017 L
s
0 g
.03448 .25553 m
0 .47309 L
s
0 .47309 m
.39775 .79647 L
s
.39775 .79647 m
.40464 .59959 L
s
.40464 .59959 m
.03448 .25553 L
s
.68961 0 m
.97156 .4298 L
s
.97156 .4298 m
1 .63788 L
s
1 .63788 m
.70282 .22771 L
s
.70282 .22771 m
.68961 0 L
s
.03448 .25553 m
0 .47309 L
s
0 .47309 m
.70282 .22771 L
s
.70282 .22771 m
.68961 0 L
s
.68961 0 m
.03448 .25553 L
s
.4 g
.41688 .59593 m
.41068 .79307 L
s
.54243 .55832 m
.54346 .7581 L
s
.67395 .51893 m
.68294 .72137 L
s
.81187 .47762 m
.82963 .68274 L
s
.95668 .43425 m
.9841 .64206 L
s
.40448 .60403 m
.9722 .43446 L
s
.40234 .66514 m
.98099 .49879 L
s
.40013 .72845 m
.99014 .5657 L
s
.39784 .79409 m
.99965 .63535 L
s
0 g
.40464 .59959 m
.97156 .4298 L
s
.97156 .4298 m
1 .63788 L
s
1 .63788 m
.39775 .79647 L
s
.39775 .79647 m
.40464 .59959 L
s
0 0 m
1 0 L
1 .79647 L
0 .79647 L
closepath
clip
newpath
.5 Mabswid
.662 .742 .91 r
.3977 .58264 m .40947 .59361 L .42925 .5877 L p F P
0 0 0 r
s
.662 .743 .91 r
.41758 .57668 m .42925 .5877 L .44918 .58177 L p F P
0 0 0 r
s
.662 .742 .91 r
.42925 .5877 m .41758 .57668 L .3977 .58264 L p F P
0 0 0 r
s
.662 .743 .91 r
.38577 .57154 m .3977 .58264 L .41758 .57668 L p F P
0 0 0 r
s
.661 .744 .911 r
.4376 .57071 m .44918 .58177 L .46926 .57583 L p F P
0 0 0 r
s
.662 .743 .91 r
.44918 .58177 m .4376 .57071 L .41758 .57668 L p F P
0 0 0 r
s
.661 .743 .911 r
.40574 .56555 m .41758 .57668 L .4376 .57071 L p F P
0 0 0 r
s
.662 .743 .91 r
.41758 .57668 m .40574 .56555 L .38577 .57154 L p F P
0 0 0 r
s
.66 .745 .912 r
.45777 .56477 m .46926 .57583 L .48948 .56988 L p F P
0 0 0 r
s
.661 .744 .911 r
.46926 .57583 m .45777 .56477 L .4376 .57071 L p F P
0 0 0 r
s
.661 .743 .911 r
.37368 .56032 m .38577 .57154 L .40574 .56555 L p F P
0 0 0 r
s
.66 .744 .913 r
.42585 .55958 m .4376 .57071 L .45777 .56477 L p F P
0 0 0 r
s
.661 .743 .911 r
.4376 .57071 m .42585 .55958 L .40574 .56555 L p F P
0 0 0 r
s
.659 .746 .914 r
.47809 .55885 m .48948 .56988 L .50986 .56394 L p F P
0 0 0 r
s
.66 .745 .912 r
.48948 .56988 m .47809 .55885 L .45777 .56477 L p F P
0 0 0 r
s
.659 .744 .913 r
.39374 .55432 m .40574 .56555 L .42585 .55958 L p F P
0 0 0 r
s
.661 .743 .911 r
.40574 .56555 m .39374 .55432 L .37368 .56032 L p F P
0 0 0 r
s
.658 .746 .915 r
.44612 .55367 m .45777 .56477 L .47809 .55885 L p F P
0 0 0 r
s
.66 .744 .913 r
.45777 .56477 m .44612 .55367 L .42585 .55958 L p F P
0 0 0 r
s
.658 .749 .917 r
.49857 .55297 m .50986 .56394 L .5304 .558 L p F P
0 0 0 r
s
.659 .746 .914 r
.50986 .56394 m .49857 .55297 L .47809 .55885 L p F P
0 0 0 r
s
.659 .743 .912 r
.36142 .54898 m .37368 .56032 L .39374 .55432 L p F P
0 0 0 r
s
.657 .746 .915 r
.41394 .54839 m .42585 .55958 L .44612 .55367 L p F P
0 0 0 r
s
.659 .744 .913 r
.42585 .55958 m .41394 .54839 L .39374 .55432 L p F P
0 0 0 r
s
.656 .749 .918 r
.46654 .54785 m .47809 .55885 L .49857 .55297 L p F P
0 0 0 r
s
.658 .746 .915 r
.47809 .55885 m .46654 .54785 L .44612 .55367 L p F P
0 0 0 r
s
.657 .752 .92 r
.5192 .54715 m .5304 .558 L .55109 .55207 L p F P
0 0 0 r
s
.658 .749 .917 r
.5304 .558 m .5192 .54715 L .49857 .55297 L p F P
0 0 0 r
s
.657 .745 .915 r
.38156 .54301 m .39374 .55432 L .41394 .54839 L p F P
0 0 0 r
s
.659 .743 .912 r
.39374 .55432 m .38156 .54301 L .36142 .54898 L p F P
0 0 0 r
s
.655 .748 .919 r
.4343 .54259 m .44612 .55367 L .46654 .54785 L p F P
0 0 0 r
s
.657 .746 .915 r
.44612 .55367 m .4343 .54259 L .41394 .54839 L p F P
0 0 0 r
s
.654 .753 .922 r
.48711 .54214 m .49857 .55297 L .5192 .54715 L p F P
0 0 0 r
s
.656 .749 .918 r
.49857 .55297 m .48711 .54214 L .46654 .54785 L p F P
0 0 0 r
s
.656 .756 .923 r
.54 .54136 m .55109 .55207 L .57194 .54611 L p F P
0 0 0 r
s
.657 .752 .92 r
.55109 .55207 m .54 .54136 L .5192 .54715 L p F P
0 0 0 r
s
.657 .744 .914 r
.34898 .53754 m .36142 .54898 L .38156 .54301 L p F P
0 0 0 r
s
.653 .747 .918 r
.40186 .53718 m .41394 .54839 L .4343 .54259 L p F P
0 0 0 r
s
.657 .745 .915 r
.41394 .54839 m .40186 .53718 L .38156 .54301 L p F P
0 0 0 r
s
.651 .752 .924 r
.45481 .53697 m .46654 .54785 L .48711 .54214 L p F P
0 0 0 r
s
.655 .748 .919 r
.46654 .54785 m .45481 .53697 L .4343 .54259 L p F P
0 0 0 r
s
.652 .758 .927 r
.50785 .53655 m .5192 .54715 L .54 .54136 L p F P
0 0 0 r
s
.654 .753 .922 r
.5192 .54715 m .50785 .53655 L .48711 .54214 L p F P
0 0 0 r
s
.656 .761 .927 r
.56096 .53557 m .57194 .54611 L .59295 .54011 L p F P
0 0 0 r
s
.656 .756 .923 r
.57194 .54611 m .56096 .53557 L .54 .54136 L p F P
0 0 0 r
s
.653 .745 .917 r
.36921 .53163 m .38156 .54301 L .40186 .53718 L p F P
0 0 0 r
s
.657 .744 .914 r
.38156 .54301 m .36921 .53163 L .34898 .53754 L p F P
0 0 0 r
s
.648 .751 .924 r
.4223 .53158 m .4343 .54259 L .45481 .53697 L p F P
0 0 0 r
s
.653 .747 .918 r
.4343 .54259 m .4223 .53158 L .40186 .53718 L p F P
0 0 0 r
s
.647 .758 .931 r
.47548 .53157 m .48711 .54214 L .50785 .53655 L p F P
0 0 0 r
s
.651 .752 .924 r
.48711 .54214 m .47548 .53157 L .45481 .53697 L p F P
0 0 0 r
s
.65 .765 .933 r
.52875 .53106 m .54 .54136 L .56096 .53557 L p F P
0 0 0 r
s
.652 .758 .927 r
.54 .54136 m .52875 .53106 L .50785 .53655 L p F P
0 0 0 r
s
.656 .766 .93 r
.58209 .52975 m .59295 .54011 L .61412 .53403 L p F P
0 0 0 r
s
.656 .761 .927 r
.59295 .54011 m .58209 .52975 L .56096 .53557 L p F P
0 0 0 r
s
.654 .744 .916 r
.33637 .52598 m .34898 .53754 L .36921 .53163 L p F P
0 0 0 r
s
.647 .748 .923 r
.38959 .52596 m .40186 .53718 L .4223 .53158 L p F P
0 0 0 r
s
.653 .745 .917 r
.40186 .53718 m .38959 .52596 L .36921 .53163 L p F P
0 0 0 r
s
.642 .756 .932 r
.4429 .52629 m .45481 .53697 L .47548 .53157 L p F P
0 0 0 r
s
.648 .751 .924 r
.45481 .53697 m .4429 .52629 L .4223 .53158 L p F P
0 0 0 r
s
.642 .767 .939 r
.49632 .52639 m .50785 .53655 L .52875 .53106 L p F P
0 0 0 r
s
.647 .758 .931 r
.50785 .53655 m .49632 .52639 L .47548 .53157 L p F P
0 0 0 r
s
.648 .773 .939 r
.54983 .52562 m .56096 .53557 L .58209 .52975 L p F P
0 0 0 r
s
.65 .765 .933 r
.56096 .53557 m .54983 .52562 L .52875 .53106 L p F P
0 0 0 r
s
.656 .77 .933 r
.60338 .52382 m .61412 .53403 L .63546 .52784 L p F P
0 0 0 r
s
.656 .766 .93 r
.61412 .53403 m .60338 .52382 L .58209 .52975 L p F P
0 0 0 r
s
.648 .746 .92 r
.35668 .52018 m .36921 .53163 L .38959 .52596 L p F P
0 0 0 r
s
.654 .744 .916 r
.36921 .53163 m .35668 .52018 L .33637 .52598 L p F P
0 0 0 r
s
.639 .753 .931 r
.41012 .52067 m .4223 .53158 L .4429 .52629 L p F P
0 0 0 r
s
.647 .748 .923 r
.4223 .53158 m .41012 .52067 L .38959 .52596 L p F P
0 0 0 r
s
.634 .765 .942 r
.46367 .52137 m .47548 .53157 L .49632 .52639 L p F P
0 0 0 r
s
.642 .756 .932 r
.47548 .53157 m .46367 .52137 L .4429 .52629 L p F P
0 0 0 r
s
.637 .777 .948 r
.51733 .52142 m .52875 .53106 L .54983 .52562 L p F P
0 0 0 r
s
.642 .767 .939 r
.52875 .53106 m .51733 .52142 L .49632 .52639 L p F P
0 0 0 r
s
.648 .781 .945 r
.57108 .52014 m .58209 .52975 L .60338 .52382 L p F P
0 0 0 r
s
.648 .773 .939 r
.58209 .52975 m .57108 .52014 L .54983 .52562 L p F P
0 0 0 r
s
.65 .744 .918 r
.32357 .51431 m .33637 .52598 L .35668 .52018 L p F P
0 0 0 r
s
.658 .774 .935 r
.62484 .51772 m .63546 .52784 L .65695 .52151 L p F P
0 0 0 r
s
.656 .77 .933 r
.63546 .52784 m .62484 .51772 L .60338 .52382 L p F P
0 0 0 r
s
.639 .749 .928 r
.37714 .51475 m .38959 .52596 L .41012 .52067 L p F P
0 0 0 r
s
.648 .746 .92 r
.38959 .52596 m .37714 .51475 L .35668 .52018 L p F P
0 0 0 r
s
.628 .76 .942 r
.43081 .51587 m .4429 .52629 L .46367 .52137 L p F P
0 0 0 r
s
.639 .753 .931 r
.4429 .52629 m .43081 .51587 L .41012 .52067 L p F P
0 0 0 r
s
.624 .776 .954 r
.48461 .51685 m .49632 .52639 L .51733 .52142 L p F P
0 0 0 r
s
.634 .765 .942 r
.49632 .52639 m .48461 .51685 L .46367 .52137 L p F P
0 0 0 r
s
.633 .789 .957 r
.53853 .51656 m .54983 .52562 L .57108 .52014 L p F P
0 0 0 r
s
.637 .777 .948 r
.54983 .52562 m .53853 .51656 L .51733 .52142 L p F P
0 0 0 r
s
.649 .789 .949 r
.5925 .51451 m .60338 .52382 L .62484 .51772 L p F P
0 0 0 r
s
.648 .781 .945 r
.60338 .52382 m .5925 .51451 L .57108 .52014 L p F P
0 0 0 r
s
.66 .777 .935 r
.64647 .51139 m .65695 .52151 L .67861 .51501 L p F P
0 0 0 r
s
.658 .774 .935 r
.65695 .52151 m .64647 .51139 L .62484 .51772 L p F P
0 0 0 r
s
.641 .745 .924 r
.34397 .50865 m .35668 .52018 L .37714 .51475 L p F P
0 0 0 r
s
.65 .744 .918 r
.35668 .52018 m .34397 .50865 L .32357 .51431 L p F P
0 0 0 r
s
.625 .754 .939 r
.39775 .50987 m .41012 .52067 L .43081 .51587 L p F P
0 0 0 r
s
.639 .749 .928 r
.41012 .52067 m .39775 .50987 L .37714 .51475 L p F P
0 0 0 r
s
.612 .771 .956 r
.45166 .51166 m .46367 .52137 L .48461 .51685 L p F P
0 0 0 r
s
.628 .76 .942 r
.46367 .52137 m .45166 .51166 L .43081 .51587 L p F P
0 0 0 r
s
.614 .791 .967 r
.50573 .51268 m .51733 .52142 L .53853 .51656 L p F P
0 0 0 r
s
.624 .776 .954 r
.51733 .52142 m .50573 .51268 L .48461 .51685 L p F P
0 0 0 r
s
.646 .743 .92 r
.31058 .50249 m .32357 .51431 L .34397 .50865 L p F P
0 0 0 r
s
.631 .803 .965 r
.55991 .51167 m .57108 .52014 L .5925 .51451 L p F P
0 0 0 r
s
.633 .789 .957 r
.57108 .52014 m .55991 .51167 L .53853 .51656 L p F P
0 0 0 r
s
.651 .796 .952 r
.6141 .50862 m .62484 .51772 L .64647 .51139 L p F P
0 0 0 r
s
.649 .789 .949 r
.62484 .51772 m .6141 .50862 L .5925 .51451 L p F P
0 0 0 r
s
.662 .777 .935 r
.66825 .5048 m .67861 .51501 L .70043 .50835 L p F P
0 0 0 r
s
.66 .777 .935 r
.67861 .51501 m .66825 .5048 L .64647 .51139 L p F P
0 0 0 r
s
.627 .748 .934 r
.3645 .50352 m .37714 .51475 L .39775 .50987 L p F P
0 0 0 r
s
.641 .745 .924 r
.37714 .51475 m .3645 .50352 L .34397 .50865 L p F P
0 0 0 r
s
.606 .762 .954 r
.41852 .50573 m .43081 .51587 L .45166 .51166 L p F P
0 0 0 r
s
.625 .754 .939 r
.43081 .51587 m .41852 .50573 L .39775 .50987 L p F P
0 0 0 r
s
.593 .786 .972 r
.4727 .50807 m .48461 .51685 L .50573 .51268 L p F P
0 0 0 r
s
.612 .771 .956 r
.48461 .51685 m .4727 .50807 L .45166 .51166 L p F P
0 0 0 r
s
.633 .744 .928 r
.33106 .497 m .34397 .50865 L .3645 .50352 L p F P
0 0 0 r
s
.646 .743 .92 r
.34397 .50865 m .33106 .497 L .31058 .50249 L p F P
0 0 0 r
s
.604 .809 .979 r
.52705 .50872 m .53853 .51656 L .55991 .51167 L p F P
0 0 0 r
s
.614 .791 .967 r
.53853 .51656 m .52705 .50872 L .50573 .51268 L p F P
0 0 0 r
s
.664 .776 .933 r
.6902 .49796 m .70043 .50835 L .72241 .50154 L p F P
0 0 0 r
s
.662 .777 .935 r
.70043 .50835 m .6902 .49796 L .66825 .5048 L p F P
0 0 0 r
s
.655 .8 .952 r
.63586 .50236 m .64647 .51139 L .66825 .5048 L p F P
0 0 0 r
s
.651 .796 .952 r
.64647 .51139 m .63586 .50236 L .6141 .50862 L p F P
0 0 0 r
s
.632 .816 .971 r
.58147 .50656 m .5925 .51451 L .6141 .50862 L p F P
0 0 0 r
s
.631 .803 .965 r
.5925 .51451 m .58147 .50656 L .55991 .51167 L p F P
0 0 0 r
s
.647 .762 .933 r
.39068 .7715 m .40314 .78177 L .42399 .77623 L p F P
0 0 0 r
s
.606 .753 .948 r
.38519 .49916 m .39775 .50987 L .41852 .50573 L p F P
0 0 0 r
s
.627 .748 .934 r
.39775 .50987 m .38519 .49916 L .3645 .50352 L p F P
0 0 0 r
s
.579 .774 .972 r
.43945 .50245 m .45166 .51166 L .4727 .50807 L p F P
0 0 0 r
s
.606 .762 .954 r
.45166 .51166 m .43945 .50245 L .41852 .50573 L p F P
0 0 0 r
s
.64 .741 .922 r
.29741 .4905 m .31058 .50249 L .33106 .497 L p F P
0 0 0 r
s
.57 .804 .987 r
.49393 .50504 m .50573 .51268 L .52705 .50872 L p F P
0 0 0 r
s
.593 .786 .972 r
.50573 .51268 m .49393 .50504 L .4727 .50807 L p F P
0 0 0 r
s
.666 .773 .93 r
.7123 .49088 m .72241 .50154 L .74456 .49462 L p F P
0 0 0 r
s
.664 .776 .933 r
.72241 .50154 m .7123 .49088 L .6902 .49796 L p F P
0 0 0 r
s
.66 .802 .951 r
.65778 .49569 m .66825 .5048 L .6902 .49796 L p F P
0 0 0 r
s
.655 .8 .952 r
.66825 .5048 m .65778 .49569 L .63586 .50236 L p F P
0 0 0 r
s
.613 .746 .94 r
.35167 .49221 m .3645 .50352 L .38519 .49916 L p F P
0 0 0 r
s
.633 .744 .928 r
.3645 .50352 m .35167 .49221 L .33106 .497 L p F P
0 0 0 r
s
.636 .827 .974 r
.60322 .50104 m .6141 .50862 L .63586 .50236 L p F P
0 0 0 r
s
.632 .816 .971 r
.6141 .50862 m .60322 .50104 L .58147 .50656 L p F P
0 0 0 r
s
.596 .828 .988 r
.54857 .50473 m .55991 .51167 L .58147 .50656 L p F P
0 0 0 r
s
.604 .809 .979 r
.55991 .51167 m .54857 .50473 L .52705 .50872 L p F P
0 0 0 r
s
.647 .762 .933 r
.41164 .76588 m .42399 .77623 L .445 .77064 L p F P
0 0 0 r
s
.647 .762 .933 r
.42399 .77623 m .41164 .76588 L .39068 .7715 L p F P
0 0 0 r
s
.575 .76 .966 r
.40602 .49582 m .41852 .50573 L .43945 .50245 L p F P
0 0 0 r
s
.606 .753 .948 r
.41852 .50573 m .40602 .49582 L .38519 .49916 L p F P
0 0 0 r
s
.624 .741 .931 r
.31796 .48519 m .33106 .497 L .35167 .49221 L p F P
0 0 0 r
s
.64 .741 .922 r
.33106 .497 m .31796 .48519 L .29741 .4905 L p F P
0 0 0 r
s
.542 .788 .989 r
.46057 .5001 m .4727 .50807 L .49393 .50504 L p F P
0 0 0 r
s
.579 .774 .972 r
.4727 .50807 m .46057 .5001 L .43945 .50245 L p F P
0 0 0 r
s
.647 .762 .933 r
.37805 .76109 m .39068 .7715 L .41164 .76588 L p F P
0 0 0 r
s
.667 .769 .926 r
.73456 .48362 m .74456 .49462 L .76687 .48761 L p F P
0 0 0 r
s
.666 .773 .93 r
.74456 .49462 m .73456 .48362 L .7123 .49088 L p F P
0 0 0 r
s
.664 .8 .947 r
.67986 .48859 m .6902 .49796 L .7123 .49088 L p F P
0 0 0 r
s
.66 .802 .951 r
.6902 .49796 m .67986 .48859 L .65778 .49569 L p F P
0 0 0 r
s
.647 .762 .933 r
.43275 .76022 m .445 .77064 L .46618 .76501 L p F P
0 0 0 r
s
.647 .762 .933 r
.445 .77064 m .43275 .76022 L .41164 .76588 L p F P
0 0 0 r
s
.643 .834 .974 r
.62513 .49495 m .63586 .50236 L .65778 .49569 L p F P
0 0 0 r
s
.636 .827 .974 r
.63586 .50236 m .62513 .49495 L .60322 .50104 L p F P
0 0 0 r
s
.545 .823 .997 r
.51537 .50236 m .52705 .50872 L .54857 .50473 L p F P
0 0 0 r
s
.57 .804 .987 r
.52705 .50872 m .51537 .50236 L .49393 .50504 L p F P
0 0 0 r
s
.594 .846 .992 r
.57029 .50044 m .58147 .50656 L .60322 .50104 L p F P
0 0 0 r
s
.596 .828 .988 r
.58147 .50656 m .57029 .50044 L .54857 .50473 L p F P
0 0 0 r
s
.582 .748 .956 r
.37242 .48844 m .38519 .49916 L .40602 .49582 L p F P
0 0 0 r
s
.613 .746 .94 r
.38519 .49916 m .37242 .48844 L .35167 .49221 L p F P
0 0 0 r
s
.635 .739 .924 r
.28404 .47831 m .29741 .4905 L .31796 .48519 L p F P
0 0 0 r
s
.528 .768 .985 r
.42702 .49369 m .43945 .50245 L .46057 .5001 L p F P
0 0 0 r
s
.575 .76 .966 r
.43945 .50245 m .42702 .49369 L .40602 .49582 L p F P
0 0 0 r
s
.647 .762 .933 r
.3991 .75539 m .41164 .76588 L .43275 .76022 L p F P
0 0 0 r
s
.647 .762 .933 r
.41164 .76588 m .3991 .75539 L .37805 .76109 L p F P
0 0 0 r
s
.667 .764 .923 r
.75698 .47626 m .76687 .48761 L .78935 .48055 L p F P
0 0 0 r
s
.667 .769 .926 r
.76687 .48761 m .75698 .47626 L .73456 .48362 L p F P
0 0 0 r
s
.597 .74 .945 r
.33864 .48074 m .35167 .49221 L .37242 .48844 L p F P
0 0 0 r
s
.624 .741 .931 r
.35167 .49221 m .33864 .48074 L .31796 .48519 L p F P
0 0 0 r
s
.668 .795 .943 r
.70208 .48112 m .7123 .49088 L .73456 .48362 L p F P
0 0 0 r
s
.664 .8 .947 r
.7123 .49088 m .70208 .48112 L .67986 .48859 L p F P
0 0 0 r
s
.647 .762 .933 r
.45403 .75451 m .46618 .76501 L .48752 .75934 L p F P
0 0 0 r
s
.647 .762 .933 r
.46618 .76501 m .45403 .75451 L .43275 .76022 L p F P
0 0 0 r
s
.652 .837 .971 r
.6472 .48819 m .65778 .49569 L .67986 .48859 L p F P
0 0 0 r
s
.643 .834 .974 r
.65778 .49569 m .6472 .48819 L .62513 .49495 L p F P
0 0 0 r
s
.493 .802 .999 r
.4819 .49858 m .49393 .50504 L .51537 .50236 L p F P
0 0 0 r
s
.542 .788 .989 r
.49393 .50504 m .4819 .49858 L .46057 .5001 L p F P
0 0 0 r
s
.599 .862 .993 r
.59219 .49551 m .60322 .50104 L .62513 .49495 L p F P
0 0 0 r
s
.594 .846 .992 r
.60322 .50104 m .59219 .49551 L .57029 .50044 L p F P
0 0 0 r
s
.523 .843 .999 r
.53703 .49967 m .54857 .50473 L .57029 .50044 L p F P
0 0 0 r
s
.545 .823 .997 r
.54857 .50473 m .53703 .49967 L .51537 .50236 L p F P
0 0 0 r
s
.534 .75 .975 r
.39331 .486 m .40602 .49582 L .42702 .49369 L p F P
0 0 0 r
s
.582 .748 .956 r
.40602 .49582 m .39331 .486 L .37242 .48844 L p F P
0 0 0 r
s
.614 .737 .934 r
.30467 .47314 m .31796 .48519 L .33864 .48074 L p F P
0 0 0 r
s
.635 .739 .924 r
.31796 .48519 m .30467 .47314 L .28404 .47831 L p F P
0 0 0 r
s
.647 .762 .933 r
.36522 .75053 m .37805 .76109 L .3991 .75539 L p F P
0 0 0 r
s
.667 .759 .919 r
.77958 .46884 m .78935 .48055 L .812 .47346 L p F P
0 0 0 r
s
.667 .764 .923 r
.78935 .48055 m .77958 .46884 L .75698 .47626 L p F P
0 0 0 r
s
.67 .788 .937 r
.72446 .47338 m .73456 .48362 L .75698 .47626 L p F P
0 0 0 r
s
.668 .795 .943 r
.73456 .48362 m .72446 .47338 L .70208 .48112 L p F P
0 0 0 r
s
.647 .762 .933 r
.42032 .74964 m .43275 .76022 L .45403 .75451 L p F P
0 0 0 r
s
.647 .762 .933 r
.43275 .76022 m .42032 .74964 L .3991 .75539 L p F P
0 0 0 r
s
.461 .773 .997 r
.44822 .49285 m .46057 .5001 L .4819 .49858 L p F P
0 0 0 r
s
.528 .768 .985 r
.46057 .5001 m .44822 .49285 L .42702 .49369 L p F P
0 0 0 r
s
.662 .834 .966 r
.66942 .48075 m .67986 .48859 L .70208 .48112 L p F P
0 0 0 r
s
.652 .837 .971 r
.67986 .48859 m .66942 .48075 L .6472 .48819 L p F P
0 0 0 r
s
.647 .762 .933 r
.47548 .74875 m .48752 .75934 L .50903 .75362 L p F P
0 0 0 r
s
.647 .762 .933 r
.48752 .75934 m .47548 .74875 L .45403 .75451 L p F P
0 0 0 r
s
.553 .738 .962 r
.35945 .47756 m .37242 .48844 L .39331 .486 L p F P
0 0 0 r
s
.597 .74 .945 r
.37242 .48844 m .35945 .47756 L .33864 .48074 L p F P
0 0 0 r
s
.612 .874 .991 r
.61428 .48971 m .62513 .49495 L .6472 .48819 L p F P
0 0 0 r
s
.599 .862 .993 r
.62513 .49495 m .61428 .48971 L .59219 .49551 L p F P
0 0 0 r
s
.437 .812 .992 r
.50347 .49758 m .51537 .50236 L .53703 .49967 L p F P
0 0 0 r
s
.493 .802 .999 r
.51537 .50236 m .50347 .49758 L .4819 .49858 L p F P
0 0 0 r
s
.63 .737 .925 r
.27049 .46587 m .28404 .47831 L .30467 .47314 L p F P
0 0 0 r
s
.51 .861 .991 r
.55892 .49653 m .57029 .50044 L .59219 .49551 L p F P
0 0 0 r
s
.523 .843 .999 r
.57029 .50044 m .55892 .49653 L .53703 .49967 L p F P
0 0 0 r
s
.647 .762 .933 r
.38638 .74474 m .3991 .75539 L .42032 .74964 L p F P
0 0 0 r
s
.647 .762 .933 r
.3991 .75539 m .38638 .74474 L .36522 .75053 L p F P
0 0 0 r
s
.46 .748 .991 r
.41437 .48515 m .42702 .49369 L .44822 .49285 L p F P
0 0 0 r
s
.534 .75 .975 r
.42702 .49369 m .41437 .48515 L .39331 .486 L p F P
0 0 0 r
s
.58 .733 .948 r
.32542 .46899 m .33864 .48074 L .35945 .47756 L p F P
0 0 0 r
s
.614 .737 .934 r
.33864 .48074 m .32542 .46899 L .30467 .47314 L p F P
0 0 0 r
s
.671 .779 .931 r
.747 .46548 m .75698 .47626 L .77958 .46884 L p F P
0 0 0 r
s
.67 .788 .937 r
.75698 .47626 m .747 .46548 L .72446 .47338 L p F P
0 0 0 r
s
.666 .755 .916 r
.80235 .46141 m .812 .47346 L .83484 .46637 L p F P
0 0 0 r
s
.667 .759 .919 r
.812 .47346 m .80235 .46141 L .77958 .46884 L p F P
0 0 0 r
s
.647 .762 .933 r
.44171 .74385 m .45403 .75451 L .47548 .74875 L p F P
0 0 0 r
s
.647 .762 .933 r
.45403 .75451 m .44171 .74385 L .42032 .74964 L p F P
0 0 0 r
s
.669 .826 .959 r
.69178 .47273 m .70208 .48112 L .72446 .47338 L p F P
0 0 0 r
s
.662 .834 .966 r
.70208 .48112 m .69178 .47273 L .66942 .48075 L p F P
0 0 0 r
s
.647 .762 .933 r
.4971 .74295 m .50903 .75362 L .53071 .74786 L p F P
0 0 0 r
s
.647 .762 .933 r
.50903 .75362 m .4971 .74295 L .47548 .74875 L p F P
0 0 0 r
s
.631 .88 .987 r
.63651 .48286 m .6472 .48819 L .66942 .48075 L p F P
0 0 0 r
s
.612 .874 .991 r
.6472 .48819 m .63651 .48286 L .61428 .48971 L p F P
0 0 0 r
s
.371 .769 .986 r
.46964 .49316 m .4819 .49858 L .50347 .49758 L p F P
0 0 0 r
s
.461 .773 .997 r
.4819 .49858 m .46964 .49316 L .44822 .49285 L p F P
0 0 0 r
s
.485 .731 .98 r
.3804 .47604 m .39331 .486 L .41437 .48515 L p F P
0 0 0 r
s
.553 .738 .962 r
.39331 .486 m .3804 .47604 L .35945 .47756 L p F P
0 0 0 r
s
.605 .732 .935 r
.2912 .46078 m .30467 .47314 L .32542 .46899 L p F P
0 0 0 r
s
.63 .737 .925 r
.30467 .47314 m .2912 .46078 L .27049 .46587 L p F P
0 0 0 r
s
.647 .762 .933 r
.35222 .73981 m .36522 .75053 L .38638 .74474 L p F P
0 0 0 r
s
.515 .879 .981 r
.58101 .49247 m .59219 .49551 L .61428 .48971 L p F P
0 0 0 r
s
.51 .861 .991 r
.59219 .49551 m .58101 .49247 L .55892 .49653 L p F P
0 0 0 r
s
.385 .815 .963 r
.52528 .4966 m .53703 .49967 L .55892 .49653 L p F P
0 0 0 r
s
.437 .812 .992 r
.53703 .49967 m .52528 .4966 L .50347 .49758 L p F P
0 0 0 r
s
.647 .762 .933 r
.40771 .73891 m .42032 .74964 L .44171 .74385 L p F P
0 0 0 r
s
.647 .762 .933 r
.42032 .74964 m .40771 .73891 L .38638 .74474 L p F P
0 0 0 r
s
.67 .771 .926 r
.7697 .45753 m .77958 .46884 L .80235 .46141 L p F P
0 0 0 r
s
.671 .779 .931 r
.77958 .46884 m .7697 .45753 L .747 .46548 L p F P
0 0 0 r
s
.666 .751 .914 r
.8253 .45402 m .83484 .46637 L .85786 .45927 L p F P
0 0 0 r
s
.666 .755 .916 r
.83484 .46637 m .8253 .45402 L .80235 .46141 L p F P
0 0 0 r
s
.647 .762 .933 r
.46326 .73801 m .47548 .74875 L .4971 .74295 L p F P
0 0 0 r
s
.647 .762 .933 r
.47548 .74875 m .46326 .73801 L .44171 .74385 L p F P
0 0 0 r
s
.674 .815 .951 r
.71428 .46428 m .72446 .47338 L .747 .46548 L p F P
0 0 0 r
s
.669 .826 .959 r
.72446 .47338 m .71428 .46428 L .69178 .47273 L p F P
0 0 0 r
s
.647 .762 .933 r
.51889 .7371 m .53071 .74786 L .55256 .74205 L p F P
0 0 0 r
s
.647 .762 .933 r
.53071 .74786 m .51889 .7371 L .4971 .74295 L p F P
0 0 0 r
s
.524 .724 .965 r
.34629 .46634 m .35945 .47756 L .3804 .47604 L p F P
0 0 0 r
s
.58 .733 .948 r
.35945 .47756 m .34629 .46634 L .32542 .46899 L p F P
0 0 0 r
s
.351 .732 .986 r
.43563 .486 m .44822 .49285 L .46964 .49316 L p F P
0 0 0 r
s
.46 .748 .991 r
.44822 .49285 m .43563 .486 L .41437 .48515 L p F P
0 0 0 r
s
.652 .878 .982 r
.65889 .47497 m .66942 .48075 L .69178 .47273 L p F P
0 0 0 r
s
.631 .88 .987 r
.66942 .48075 m .65889 .47497 L .63651 .48286 L p F P
0 0 0 r
s
.626 .734 .925 r
.25674 .45314 m .27049 .46587 L .2912 .46078 L p F P
0 0 0 r
s
.647 .762 .933 r
.37348 .73394 m .38638 .74474 L .40771 .73891 L p F P
0 0 0 r
s
.647 .762 .933 r
.38638 .74474 m .37348 .73394 L .35222 .73981 L p F P
0 0 0 r
s
.539 .896 .974 r
.60328 .4871 m .61428 .48971 L .63651 .48286 L p F P
0 0 0 r
s
.515 .879 .981 r
.61428 .48971 m .60328 .4871 L .58101 .49247 L p F P
0 0 0 r
s
.647 .762 .933 r
.4292 .73303 m .44171 .74385 L .46326 .73801 L p F P
0 0 0 r
s
.647 .762 .933 r
.44171 .74385 m .4292 .73303 L .40771 .73891 L p F P
0 0 0 r
s
.564 .724 .949 r
.31202 .45685 m .32542 .46899 L .34629 .46634 L p F P
0 0 0 r
s
.605 .732 .935 r
.32542 .46899 m .31202 .45685 L .2912 .46078 L p F P
0 0 0 r
s
.669 .764 .921 r
.79258 .44961 m .80235 .46141 L .8253 .45402 L p F P
0 0 0 r
s
.67 .771 .926 r
.80235 .46141 m .79258 .44961 L .7697 .45753 L p F P
0 0 0 r
s
.269 .746 .934 r
.49132 .49421 m .50347 .49758 L .52528 .4966 L p F P
0 0 0 r
s
.371 .769 .986 r
.50347 .49758 m .49132 .49421 L .46964 .49316 L p F P
0 0 0 r
s
.665 .748 .912 r
.84844 .44666 m .85786 .45927 L .88106 .45216 L p F P
0 0 0 r
s
.666 .751 .914 r
.85786 .45927 m .84844 .44666 L .8253 .45402 L p F P
0 0 0 r
s
.677 .802 .942 r
.73693 .4556 m .747 .46548 L .7697 .45753 L p F P
0 0 0 r
s
.674 .815 .951 r
.747 .46548 m .73693 .4556 L .71428 .46428 L p F P
0 0 0 r
s
.647 .762 .933 r
.48499 .73212 m .4971 .74295 L .51889 .7371 L p F P
0 0 0 r
s
.647 .762 .933 r
.4971 .74295 m .48499 .73212 L .46326 .73801 L p F P
0 0 0 r
s
.38 .711 .987 r
.4015 .4765 m .41437 .48515 L .43563 .486 L p F P
0 0 0 r
s
.485 .731 .98 r
.41437 .48515 m .4015 .4765 L .3804 .47604 L p F P
0 0 0 r
s
.354 .817 .921 r
.54733 .495 m .55892 .49653 L .58101 .49247 L p F P
0 0 0 r
s
.385 .815 .963 r
.55892 .49653 m .54733 .495 L .52528 .4966 L p F P
0 0 0 r
s
.647 .762 .933 r
.54085 .73121 m .55256 .74205 L .57458 .7362 L p F P
0 0 0 r
s
.647 .762 .933 r
.55256 .74205 m .54085 .73121 L .51889 .7371 L p F P
0 0 0 r
s
.669 .868 .974 r
.68139 .46617 m .69178 .47273 L .71428 .46428 L p F P
0 0 0 r
s
.652 .878 .982 r
.69178 .47273 m .68139 .46617 L .65889 .47497 L p F P
0 0 0 r
s
.599 .727 .935 r
.27753 .44806 m .2912 .46078 L .31202 .45685 L p F P
0 0 0 r
s
.626 .734 .925 r
.2912 .46078 m .27753 .44806 L .25674 .45314 L p F P
0 0 0 r
s
.647 .762 .933 r
.33902 .72893 m .35222 .73981 L .37348 .73394 L p F P
0 0 0 r
s
.436 .705 .979 r
.36728 .46563 m .3804 .47604 L .4015 .4765 L p F P
0 0 0 r
s
.524 .724 .965 r
.3804 .47604 m .36728 .46563 L .34629 .46634 L p F P
0 0 0 r
s
.647 .762 .933 r
.39491 .72802 m .40771 .73891 L .4292 .73303 L p F P
0 0 0 r
s
.647 .762 .933 r
.40771 .73891 m .39491 .72802 L .37348 .73394 L p F P
0 0 0 r
s
.58 .912 .974 r
.62571 .48017 m .63651 .48286 L .65889 .47497 L p F P
0 0 0 r
s
.539 .896 .974 r
.63651 .48286 m .62571 .48017 L .60328 .4871 L p F P
0 0 0 r
s
.668 .757 .917 r
.81564 .44178 m .8253 .45402 L .84844 .44666 L p F P
0 0 0 r
s
.669 .764 .921 r
.8253 .45402 m .81564 .44178 L .79258 .44961 L p F P
0 0 0 r
s
.647 .762 .933 r
.45087 .7271 m .46326 .73801 L .48499 .73212 L p F P
0 0 0 r
s
.647 .762 .933 r
.46326 .73801 m .45087 .7271 L .4292 .73303 L p F P
0 0 0 r
s
.676 .789 .934 r
.75973 .44687 m .7697 .45753 L .79258 .44961 L p F P
0 0 0 r
s
.677 .802 .942 r
.7697 .45753 m .75973 .44687 L .73693 .4556 L p F P
0 0 0 r
s
.212 .691 .934 r
.45713 .48838 m .46964 .49316 L .49132 .49421 L p F P
0 0 0 r
s
.351 .732 .986 r
.46964 .49316 m .45713 .48838 L .43563 .486 L p F P
0 0 0 r
s
.664 .746 .911 r
.87176 .43934 m .88106 .45216 L .90445 .44504 L p F P
0 0 0 r
s
.665 .748 .912 r
.88106 .45216 m .87176 .43934 L .84844 .44666 L p F P
0 0 0 r
s
.647 .762 .933 r
.50689 .72619 m .51889 .7371 L .54085 .73121 L p F P
0 0 0 r
s
.647 .762 .933 r
.51889 .7371 m .50689 .72619 L .48499 .73212 L p F P
0 0 0 r
s
.68 .852 .965 r
.70401 .45673 m .71428 .46428 L .73693 .4556 L p F P
0 0 0 r
s
.669 .868 .974 r
.71428 .46428 m .70401 .45673 L .68139 .46617 L p F P
0 0 0 r
s
.647 .762 .933 r
.56299 .72527 m .57458 .7362 L .59678 .7303 L p F P
0 0 0 r
s
.647 .762 .933 r
.57458 .7362 m .56299 .72527 L .54085 .73121 L p F P
0 0 0 r
s
.499 .707 .964 r
.33294 .45457 m .34629 .46634 L .36728 .46563 L p F P
0 0 0 r
s
.564 .724 .949 r
.34629 .46634 m .33294 .45457 L .31202 .45685 L p F P
0 0 0 r
s
.625 .732 .924 r
.24279 .44012 m .25674 .45314 L .27753 .44806 L p F P
0 0 0 r
s
.361 .83 .888 r
.56962 .4921 m .58101 .49247 L .60328 .4871 L p F P
0 0 0 r
s
.173 .706 .722 r
.56962 .4921 m .59211 .48732 L p .57737 .49027 L F P
0 0 0 r
s
.354 .817 .921 r
.56962 .4921 m .54733 .495 L p .562 .4939 L F P
0 0 0 r
s
.185 .712 .85 r
.52528 .4966 m .54733 .495 L p .53198 .49515 L F P
0 0 0 r
s
.185 .712 .85 r
.51327 .49533 m .51957 .496 L p .53198 .49515 L F P
0 0 0 r
s
.185 .712 .85 r
.51957 .496 m .52528 .4966 L p .53198 .49515 L F P
0 0 0 r
s
.185 .712 .85 r
.53551 .49563 m .51327 .49533 L p .53236 .49515 L F P
0 0 0 r
s
.185 .712 .85 r
.54733 .495 m .53551 .49563 L p .53236 .49515 L F P
0 0 0 r
s
.148 .692 .767 r
.53551 .49563 m .54733 .495 L p .54962 .4947 L F P
0 0 0 r
s
.026 0 0 r
.53551 .49563 m .55801 .49416 L p .53872 .49612 L F P
0 0 0 r
s
.026 0 0 r
.52341 .49767 m .53551 .49563 L p .53872 .49612 L F P
0 0 0 r
s
.148 .692 .767 r
.55593 .49352 m .55677 .49377 L .56962 .4921 L p F P
0 0 0 r
s
.148 .692 .767 r
.55801 .49416 m .53551 .49563 L p .55593 .49352 L F P
0 0 0 r
s
.148 .692 .767 r
.56962 .4921 m .56519 .49288 L p .55593 .49352 L F P
0 0 0 r
s
.148 .692 .767 r
.56519 .49288 m .55801 .49416 L p .55681 .49346 L F P
0 0 0 r
s
.173 .706 .722 r
.55801 .49416 m .56962 .4921 L p .57737 .49027 L F P
0 0 0 r
s
.354 .817 .921 r
.58101 .49247 m .56962 .4921 L p .562 .4939 L F P
0 0 0 r
s
.361 .83 .888 r
.59211 .48732 m .56962 .4921 L p .58519 .48979 L F P
0 0 0 r
s
.361 .83 .888 r
.60328 .4871 m .59211 .48732 L p .58519 .48979 L F P
0 0 0 r
s
.254 .759 .727 r
.59211 .48732 m .61475 .48031 L p .59914 .48481 L F P
0 0 0 r
s
.173 .706 .722 r
.58072 .49011 m .55801 .49416 L p .58012 .48972 L F P
0 0 0 r
s
.173 .706 .722 r
.59211 .48732 m .58072 .49011 L p .58012 .48972 L F P
0 0 0 r
s
.254 .759 .727 r
.58072 .49011 m .59211 .48732 L p .59914 .48481 L F P
0 0 0 r
s
.254 .759 .727 r
.60359 .48303 m .58072 .49011 L p .60279 .48375 L F P
0 0 0 r
s
.254 .759 .727 r
.61475 .48031 m .60359 .48303 L p .60279 .48375 L F P
0 0 0 r
s
.32 .79 .685 r
.60359 .48303 m .62656 .47289 L p .60441 .4823 L F P
0 0 0 r
s
.58072 .49011 m .60359 .48303 L p .58134 .49052 L F P
s
.408 .859 .88 r
.59211 .48732 m .60328 .4871 L .62571 .48017 L p F P
0 0 0 r
s
.408 .859 .88 r
.62571 .48017 m .61475 .48031 L .59211 .48732 L p F P
0 0 0 r
s
.59219 .48748 m .56907 .49464 L p .60265 .48335 L F P
s
.60359 .48303 m .59219 .48748 L p .60265 .48335 L F P
s
.55712 .49939 m .56907 .49464 L .59219 .48748 L p F P
s
.59219 .48748 m .5805 .49216 L .55712 .49939 L p F P
s
.36 .814 .696 r
.59219 .48748 m .6154 .47633 L p .58147 .49172 L F P
0 0 0 r
s
.36 .814 .696 r
.5805 .49216 m .59219 .48748 L p .58147 .49172 L F P
0 0 0 r
s
.32 .79 .685 r
.59219 .48748 m .60359 .48303 L p .60441 .4823 L F P
0 0 0 r
s
.56907 .49464 m .58072 .49011 L p .58134 .49052 L F P
s
.55801 .49416 m .58072 .49011 L p .55927 .4949 L F P
s
.54612 .49783 m .55801 .49416 L p .55927 .4949 L F P
s
.148 .692 .767 r
.55593 .49352 m .55681 .49346 L .55801 .49416 L F
.013 0 0 r
.51327 .49533 m .53551 .49563 L p .5213 .49546 L F P
0 0 0 r
s
.269 .746 .934 r
.52528 .4966 m .51327 .49533 L p .50537 .4952 L F P
0 0 0 r
s
.013 0 0 r
.501 .49523 m .51327 .49533 L p .5213 .49546 L F P
0 0 0 r
s
.269 .746 .934 r
.51327 .49533 m .49132 .49421 L p .50537 .4952 L F P
0 0 0 r
s
.647 .762 .933 r
.36038 .72297 m .37348 .73394 L .39491 .72802 L p F P
0 0 0 r
s
.647 .762 .933 r
.37348 .73394 m .36038 .72297 L .33902 .72893 L p F P
0 0 0 r
s
.23 .665 .956 r
.42281 .47907 m .43563 .486 L .45713 .48838 L p F P
0 0 0 r
s
.38 .711 .987 r
.43563 .486 m .42281 .47907 L .4015 .4765 L p F P
0 0 0 r
s
.647 .762 .933 r
.41651 .72205 m .4292 .73303 L .45087 .7271 L p F P
0 0 0 r
s
.647 .762 .933 r
.4292 .73303 m .41651 .72205 L .39491 .72802 L p F P
0 0 0 r
s
.624 .919 .977 r
.64826 .47168 m .65889 .47497 L .68139 .46617 L p F P
0 0 0 r
s
.58 .912 .974 r
.65889 .47497 m .64826 .47168 L .62571 .48017 L p F P
0 0 0 r
s
.554 .715 .947 r
.29843 .44419 m .31202 .45685 L .33294 .45457 L p F P
0 0 0 r
s
.599 .727 .935 r
.31202 .45685 m .29843 .44419 L .27753 .44806 L p F P
0 0 0 r
s
.675 .777 .927 r
.78271 .43823 m .79258 .44961 L .81564 .44178 L p F P
0 0 0 r
s
.676 .789 .934 r
.79258 .44961 m .78271 .43823 L .75973 .44687 L p F P
0 0 0 r
s
.667 .752 .914 r
.83889 .43406 m .84844 .44666 L .87176 .43934 L p F P
0 0 0 r
s
.668 .757 .917 r
.84844 .44666 m .83889 .43406 L .81564 .44178 L p F P
0 0 0 r
s
.647 .762 .933 r
.47271 .72113 m .48499 .73212 L .50689 .72619 L p F P
0 0 0 r
s
.647 .762 .933 r
.48499 .73212 m .47271 .72113 L .45087 .7271 L p F P
0 0 0 r
s
.664 .744 .91 r
.89528 .43203 m .90445 .44504 L .92803 .4379 L p F P
0 0 0 r
s
.664 .746 .911 r
.90445 .44504 m .89528 .43203 L .87176 .43934 L p F P
0 0 0 r
s
.647 .762 .933 r
.52897 .7202 m .54085 .73121 L .56299 .72527 L p F P
0 0 0 r
s
.647 .762 .933 r
.54085 .73121 m .52897 .7202 L .50689 .72619 L p F P
0 0 0 r
s
.685 .833 .954 r
.72677 .44694 m .73693 .4556 L .75973 .44687 L p F P
0 0 0 r
s
.68 .852 .965 r
.73693 .4556 m .72677 .44694 L .70401 .45673 L p F P
0 0 0 r
s
.647 .762 .933 r
.58531 .71928 m .59678 .7303 L .61916 .72435 L p F P
0 0 0 r
s
.647 .762 .933 r
.59678 .7303 m .58531 .71928 L .56299 .72527 L p F P
0 0 0 r
s
.304 .664 .973 r
.38843 .46727 m .4015 .4765 L .42281 .47907 L p F P
0 0 0 r
s
.436 .705 .979 r
.4015 .4765 m .38843 .46727 L .36728 .46563 L p F P
0 0 0 r
s
.647 .762 .933 r
.32562 .71789 m .33902 .72893 L .36038 .72297 L p F P
0 0 0 r
s
.596 .723 .933 r
.26368 .43493 m .27753 .44806 L .29843 .44419 L p F P
0 0 0 r
s
.625 .732 .924 r
.27753 .44806 m .26368 .43493 L .24279 .44012 L p F P
0 0 0 r
s
.074 .625 .827 r
.4789 .49175 m .49132 .49421 L .51327 .49533 L p F P
0 0 0 r
s
.212 .691 .934 r
.49132 .49421 m .4789 .49175 L .45713 .48838 L p F P
0 0 0 r
s
.647 .762 .933 r
.38192 .71696 m .39491 .72802 L .41651 .72205 L p F P
0 0 0 r
s
.647 .762 .933 r
.39491 .72802 m .38192 .71696 L .36038 .72297 L p F P
0 0 0 r
s
.662 .914 .978 r
.67091 .46184 m .68139 .46617 L .70401 .45673 L p F P
0 0 0 r
s
.624 .919 .977 r
.68139 .46617 m .67091 .46184 L .64826 .47168 L p F P
0 0 0 r
s
.397 .675 .972 r
.35399 .45447 m .36728 .46563 L .38843 .46727 L p F P
0 0 0 r
s
.499 .707 .964 r
.36728 .46563 m .35399 .45447 L .33294 .45457 L p F P
0 0 0 r
s
.647 .762 .933 r
.43828 .71604 m .45087 .7271 L .47271 .72113 L p F P
0 0 0 r
s
.647 .762 .933 r
.45087 .7271 m .43828 .71604 L .41651 .72205 L p F P
0 0 0 r
s
.672 .766 .921 r
.80587 .42978 m .81564 .44178 L .83889 .43406 L p F P
0 0 0 r
s
.675 .777 .927 r
.81564 .44178 m .80587 .42978 L .78271 .43823 L p F P
0 0 0 r
s
.666 .749 .912 r
.86234 .42645 m .87176 .43934 L .89528 .43203 L p F P
0 0 0 r
s
.667 .752 .914 r
.87176 .43934 m .86234 .42645 L .83889 .43406 L p F P
0 0 0 r
s
.647 .762 .933 r
.49472 .71511 m .50689 .72619 L .52897 .7202 L p F P
0 0 0 r
s
.647 .762 .933 r
.50689 .72619 m .49472 .71511 L .47271 .72113 L p F P
0 0 0 r
s
.686 .812 .943 r
.74967 .43711 m .75973 .44687 L .78271 .43823 L p F P
0 0 0 r
s
.685 .833 .954 r
.75973 .44687 m .74967 .43711 L .72677 .44694 L p F P
0 0 0 r
s
.664 .743 .909 r
.919 .42474 m .92803 .4379 L .9518 .43072 L p F P
0 0 0 r
s
.664 .744 .91 r
.92803 .4379 m .919 .42474 L .89528 .43203 L p F P
0 0 0 r
s
.647 .762 .933 r
.55123 .71418 m .56299 .72527 L .58531 .71928 L p F P
0 0 0 r
s
.647 .762 .933 r
.56299 .72527 m .55123 .71418 L .52897 .7202 L p F P
0 0 0 r
s
.625 .73 .923 r
.22865 .42678 m .24279 .44012 L .26368 .43493 L p F P
0 0 0 r
s
.483 .691 .959 r
.31942 .44208 m .33294 .45457 L .35399 .45447 L p F P
0 0 0 r
s
.554 .715 .947 r
.33294 .45457 m .31942 .44208 L .29843 .44419 L p F P
0 0 0 r
s
.647 .762 .933 r
.60781 .71324 m .61916 .72435 L .64172 .71835 L p F P
0 0 0 r
s
.647 .762 .933 r
.61916 .72435 m .60781 .71324 L .58531 .71928 L p F P
0 0 0 r
s
.057 .586 .864 r
.44436 .48355 m .45713 .48838 L .4789 .49175 L p F P
0 0 0 r
s
.23 .665 .956 r
.45713 .48838 m .44436 .48355 L .42281 .47907 L p F P
0 0 0 r
s
.647 .762 .933 r
.34709 .71184 m .36038 .72297 L .38192 .71696 L p F P
0 0 0 r
s
.647 .762 .933 r
.36038 .72297 m .34709 .71184 L .32562 .71789 L p F P
0 0 0 r
s
.687 .896 .973 r
.69367 .45105 m .70401 .45673 L .72677 .44694 L p F P
0 0 0 r
s
.662 .914 .978 r
.70401 .45673 m .69367 .45105 L .67091 .46184 L p F P
0 0 0 r
s
.485 .899 .898 r
.61475 .48031 m .62571 .48017 L .64826 .47168 L p F P
0 0 0 r
s
.647 .762 .933 r
.40363 .71091 m .41651 .72205 L .43828 .71604 L p F P
0 0 0 r
s
.647 .762 .933 r
.41651 .72205 m .40363 .71091 L .38192 .71696 L p F P
0 0 0 r
s
.55 .707 .944 r
.28466 .43097 m .29843 .44419 L .31942 .44208 L p F P
0 0 0 r
s
.596 .723 .933 r
.29843 .44419 m .28466 .43097 L .26368 .43493 L p F P
0 0 0 r
s
.647 .762 .933 r
.46024 .70997 m .47271 .72113 L .49472 .71511 L p F P
0 0 0 r
s
.647 .762 .933 r
.47271 .72113 m .46024 .70997 L .43828 .71604 L p F P
0 0 0 r
s
.67 .758 .917 r
.82923 .42156 m .83889 .43406 L .86234 .42645 L p F P
0 0 0 r
s
.672 .766 .921 r
.83889 .43406 m .82923 .42156 L .80587 .42978 L p F P
0 0 0 r
s
.683 .794 .934 r
.77274 .42746 m .78271 .43823 L .80587 .42978 L p F P
0 0 0 r
s
.686 .812 .943 r
.78271 .43823 m .77274 .42746 L .74967 .43711 L p F P
0 0 0 r
s
.665 .746 .911 r
.88599 .41891 m .89528 .43203 L .919 .42474 L p F P
0 0 0 r
s
.666 .749 .912 r
.89528 .43203 m .88599 .41891 L .86234 .42645 L p F P
0 0 0 r
s
.647 .762 .933 r
.51692 .70904 m .52897 .7202 L .55123 .71418 L p F P
0 0 0 r
s
.647 .762 .933 r
.52897 .7202 m .51692 .70904 L .49472 .71511 L p F P
0 0 0 r
s
.128 .59 .922 r
.40977 .4714 m .42281 .47907 L .44436 .48355 L p F P
0 0 0 r
s
.304 .664 .973 r
.42281 .47907 m .40977 .4714 L .38843 .46727 L p F P
0 0 0 r
s
.664 .743 .909 r
.9518 .43072 m .94291 .41742 L .919 .42474 L p F P
0 0 0 r
s
.647 .762 .933 r
.57367 .7081 m .58531 .71928 L .60781 .71324 L p F P
0 0 0 r
s
.647 .762 .933 r
.58531 .71928 m .57367 .7081 L .55123 .71418 L p F P
0 0 0 r
s
.074 .625 .827 r
.51327 .49533 m .501 .49523 L .4789 .49175 L p F P
0 0 0 r
s
.647 .762 .933 r
.63049 .70716 m .64172 .71835 L .66446 .71231 L p F P
0 0 0 r
s
.647 .762 .933 r
.64172 .71835 m .63049 .70716 L .60781 .71324 L p F P
0 0 0 r
s
.698 .87 .963 r
.71653 .43977 m .72677 .44694 L .74967 .43711 L p F P
0 0 0 r
s
.687 .896 .973 r
.72677 .44694 m .71653 .43977 L .69367 .45105 L p F P
0 0 0 r
s
.647 .762 .933 r
.31202 .70669 m .32562 .71789 L .34709 .71184 L p F P
0 0 0 r
s
.597 .72 .93 r
.24963 .4214 m .26368 .43493 L .28466 .43097 L p F P
0 0 0 r
s
.625 .73 .923 r
.26368 .43493 m .24963 .4214 L .22865 .42678 L p F P
0 0 0 r
s
.571 .933 .928 r
.63749 .47106 m .64826 .47168 L .67091 .46184 L p F P
0 0 0 r
s
.485 .899 .898 r
.64826 .47168 m .63749 .47106 L .61475 .48031 L p F P
0 0 0 r
s
.251 .616 .957 r
.37517 .45698 m .38843 .46727 L .40977 .4714 L p F P
0 0 0 r
s
.397 .675 .972 r
.38843 .46727 m .37517 .45698 L .35399 .45447 L p F P
0 0 0 r
s
.647 .762 .933 r
.36873 .70575 m .38192 .71696 L .40363 .71091 L p F P
0 0 0 r
s
.647 .762 .933 r
.38192 .71696 m .36873 .70575 L .34709 .71184 L p F P
0 0 0 r
s
.647 .762 .933 r
.42551 .7048 m .43828 .71604 L .46024 .70997 L p F P
0 0 0 r
s
.647 .762 .933 r
.43828 .71604 m .42551 .7048 L .40363 .71091 L p F P
0 0 0 r
s
.376 .648 .963 r
.34052 .44227 m .35399 .45447 L .37517 .45698 L p F P
0 0 0 r
s
.483 .691 .959 r
.35399 .45447 m .34052 .44227 L .31942 .44208 L p F P
0 0 0 r
s
.668 .752 .914 r
.85279 .41354 m .86234 .42645 L .88599 .41891 L p F P
0 0 0 r
s
.67 .758 .917 r
.86234 .42645 m .85279 .41354 L .82923 .42156 L p F P
0 0 0 r
s
.679 .778 .926 r
.796 .41815 m .80587 .42978 L .82923 .42156 L p F P
0 0 0 r
s
.683 .794 .934 r
.80587 .42978 m .796 .41815 L .77274 .42746 L p F P
0 0 0 r
s
.647 .762 .933 r
.48237 .70386 m .49472 .71511 L .51692 .70904 L p F P
0 0 0 r
s
.647 .762 .933 r
.49472 .71511 m .48237 .70386 L .46024 .70997 L p F P
0 0 0 r
s
.664 .744 .91 r
.90983 .41142 m .919 .42474 L .94291 .41742 L p F P
0 0 0 r
s
.665 .746 .911 r
.919 .42474 m .90983 .41142 L .88599 .41891 L p F P
0 0 0 r
s
.647 .762 .933 r
.53929 .70292 m .55123 .71418 L .57367 .7081 L p F P
0 0 0 r
s
.647 .762 .933 r
.55123 .71418 m .53929 .70292 L .51692 .70904 L p F P
0 0 0 r
s
.627 .729 .921 r
.21431 .41314 m .22865 .42678 L .24963 .4214 L p F P
0 0 0 r
s
.699 .842 .951 r
.73952 .42845 m .74967 .43711 L .77274 .42746 L p F P
0 0 0 r
s
.698 .87 .963 r
.74967 .43711 m .73952 .42845 L .71653 .43977 L p F P
0 0 0 r
s
.647 .762 .933 r
.59629 .70197 m .60781 .71324 L .63049 .70716 L p F P
0 0 0 r
s
.647 .762 .933 r
.60781 .71324 m .59629 .70197 L .57367 .7081 L p F P
0 0 0 r
s
.478 .678 .953 r
.30574 .42877 m .31942 .44208 L .34052 .44227 L p F P
0 0 0 r
s
.55 .707 .944 r
.31942 .44208 m .30574 .42877 L .28466 .43097 L p F P
0 0 0 r
s
.645 .947 .953 r
.66032 .4599 m .67091 .46184 L .69367 .45105 L p F P
0 0 0 r
s
.571 .933 .928 r
.67091 .46184 m .66032 .4599 L .63749 .47106 L p F P
0 0 0 r
s
.057 .586 .864 r
.46623 .48929 m .44436 .48355 L p .44675 .48412 L F P
0 0 0 r
s
.057 .586 .864 r
.4789 .49175 m .46623 .48929 L p .44675 .48412 L F P
0 0 0 r
s
0 .499 .729 r
.46623 .48929 m .4789 .49175 L .501 .49523 L p F P
0 0 0 r
s
0 .499 .729 r
.501 .49523 m .48844 .49521 L .46623 .48929 L p F P
0 0 0 r
s
0 .415 .693 r
.46623 .48929 m .48844 .49521 L p .48602 .49456 L F P
0 0 0 r
s
0 .494 .816 r
.43137 .47778 m .44436 .48355 L .46623 .48929 L p F P
0 0 0 r
s
0 .494 .816 r
.4533 .48569 m .43137 .47778 L p .43275 .47824 L F P
0 0 0 r
s
0 .494 .816 r
.46623 .48929 m .4533 .48569 L p .43275 .47824 L F P
0 0 0 r
s
0 .415 .693 r
.4533 .48569 m .46623 .48929 L p .48602 .49456 L F P
0 0 0 r
s
0 .415 .693 r
.48844 .49521 m .4756 .49383 L .4533 .48569 L p F P
0 0 0 r
s
0 .385 .731 r
.4533 .48569 m .4756 .49383 L p .47421 .49327 L F P
0 0 0 r
s
0 .385 .731 r
.44015 .47968 m .4533 .48569 L p .47421 .49327 L F P
0 0 0 r
s
.647 .762 .933 r
.65335 .70102 m .66446 .71231 L .68738 .70622 L p F P
0 0 0 r
s
.647 .762 .933 r
.66446 .71231 m .65335 .70102 L .63049 .70716 L p F P
0 0 0 r
s
.647 .762 .933 r
.3336 .70055 m .34709 .71184 L .36873 .70575 L p F P
0 0 0 r
s
.647 .762 .933 r
.34709 .71184 m .3336 .70055 L .31202 .70669 L p F P
0 0 0 r
s
.647 .762 .933 r
.39055 .6996 m .40363 .71091 L .42551 .7048 L p F P
0 0 0 r
s
.647 .762 .933 r
.40363 .71091 m .39055 .6996 L .36873 .70575 L p F P
0 0 0 r
s
.552 .701 .939 r
.27072 .41718 m .28466 .43097 L .30574 .42877 L p F P
0 0 0 r
s
.597 .72 .93 r
.28466 .43097 m .27072 .41718 L .24963 .4214 L p F P
0 0 0 r
s
.647 .762 .933 r
.44758 .69865 m .46024 .70997 L .48237 .70386 L p F P
0 0 0 r
s
.647 .762 .933 r
.46024 .70997 m .44758 .69865 L .42551 .7048 L p F P
0 0 0 r
s
.674 .766 .92 r
.81945 .40922 m .82923 .42156 L .85279 .41354 L p F P
0 0 0 r
s
.679 .778 .926 r
.82923 .42156 m .81945 .40922 L .796 .41815 L p F P
0 0 0 r
s
.013 0 0 r
.53551 .49563 m .52341 .49767 L .501 .49523 L p F P
0 0 0 r
s
.666 .748 .912 r
.87656 .40569 m .88599 .41891 L .90983 .41142 L p F P
0 0 0 r
s
.668 .752 .914 r
.88599 .41891 m .87656 .40569 L .85279 .41354 L p F P
0 0 0 r
s
.647 .762 .933 r
.50468 .6977 m .51692 .70904 L .53929 .70292 L p F P
0 0 0 r
s
.647 .762 .933 r
.51692 .70904 m .50468 .6977 L .48237 .70386 L p F P
0 0 0 r
s
.664 .744 .91 r
.94291 .41742 m .93388 .40394 L .90983 .41142 L p F P
0 0 0 r
s
.128 .59 .922 r
.44436 .48355 m .43137 .47778 L .40977 .4714 L p F P
0 0 0 r
s
.693 .936 .965 r
.68322 .44738 m .69367 .45105 L .71653 .43977 L p F P
0 0 0 r
s
.645 .947 .953 r
.69367 .45105 m .68322 .44738 L .66032 .4599 L p F P
0 0 0 r
s
.695 .816 .94 r
.76268 .41745 m .77274 .42746 L .796 .41815 L p F P
0 0 0 r
s
.699 .842 .951 r
.77274 .42746 m .76268 .41745 L .73952 .42845 L p F P
0 0 0 r
s
.647 .762 .933 r
.56185 .69675 m .57367 .7081 L .59629 .70197 L p F P
0 0 0 r
s
.647 .762 .933 r
.57367 .7081 m .56185 .69675 L .53929 .70292 L p F P
0 0 0 r
s
.647 .762 .933 r
.61909 .69579 m .63049 .70716 L .65335 .70102 L p F P
0 0 0 r
s
.647 .762 .933 r
.63049 .70716 m .61909 .69579 L .59629 .70197 L p F P
0 0 0 r
s
.601 .718 .927 r
.2354 .40748 m .24963 .4214 L .27072 .41718 L p F P
0 0 0 r
s
.627 .729 .921 r
.24963 .4214 m .2354 .40748 L .21431 .41314 L p F P
0 0 0 r
s
.647 .762 .933 r
.29822 .69531 m .31202 .70669 L .3336 .70055 L p F P
0 0 0 r
s
.647 .762 .933 r
.6764 .69484 m .68738 .70622 L .71049 .70007 L p F P
0 0 0 r
s
.647 .762 .933 r
.68738 .70622 m .6764 .69484 L .65335 .70102 L p F P
0 0 0 r
s
.073 .529 .9 r
.39654 .46228 m .40977 .4714 L .43137 .47778 L p F P
0 0 0 r
s
.251 .616 .957 r
.40977 .4714 m .39654 .46228 L .37517 .45698 L p F P
0 0 0 r
s
.647 .762 .933 r
.35535 .69436 m .36873 .70575 L .39055 .6996 L p F P
0 0 0 r
s
.647 .762 .933 r
.36873 .70575 m .35535 .69436 L .3336 .70055 L p F P
0 0 0 r
s
.376 .837 .774 r
.60359 .48303 m .61475 .48031 L .63749 .47106 L p F P
0 0 0 r
s
.232 .58 .944 r
.36175 .44523 m .37517 .45698 L .39654 .46228 L p F P
0 0 0 r
s
.376 .648 .963 r
.37517 .45698 m .36175 .44523 L .34052 .44227 L p F P
0 0 0 r
s
.647 .762 .933 r
.41255 .6934 m .42551 .7048 L .44758 .69865 L p F P
0 0 0 r
s
.647 .762 .933 r
.42551 .7048 m .41255 .6934 L .39055 .6996 L p F P
0 0 0 r
s
.715 .908 .963 r
.70619 .43419 m .71653 .43977 L .73952 .42845 L p F P
0 0 0 r
s
.693 .936 .965 r
.71653 .43977 m .70619 .43419 L .68322 .44738 L p F P
0 0 0 r
s
.647 .762 .933 r
.46983 .69244 m .48237 .70386 L .50468 .6977 L p F P
0 0 0 r
s
.647 .762 .933 r
.48237 .70386 m .46983 .69244 L .44758 .69865 L p F P
0 0 0 r
s
.671 .758 .916 r
.84312 .40066 m .85279 .41354 L .87656 .40569 L p F P
0 0 0 r
s
.674 .766 .92 r
.85279 .41354 m .84312 .40066 L .81945 .40922 L p F P
0 0 0 r
s
.376 .63 .953 r
.32691 .42888 m .34052 .44227 L .36175 .44523 L p F P
0 0 0 r
s
.478 .678 .953 r
.34052 .44227 m .32691 .42888 L .30574 .42877 L p F P
0 0 0 r
s
.665 .746 .91 r
.90054 .39796 m .90983 .41142 L .93388 .40394 L p F P
0 0 0 r
s
.666 .748 .912 r
.90983 .41142 m .90054 .39796 L .87656 .40569 L p F P
0 0 0 r
s
.688 .794 .93 r
.78601 .40698 m .796 .41815 L .81945 .40922 L p F P
0 0 0 r
s
.695 .816 .94 r
.796 .41815 m .78601 .40698 L .76268 .41745 L p F P
0 0 0 r
s
.647 .762 .933 r
.52717 .69149 m .53929 .70292 L .56185 .69675 L p F P
0 0 0 r
s
.647 .762 .933 r
.53929 .70292 m .52717 .69149 L .50468 .6977 L p F P
0 0 0 r
s
.631 .729 .919 r
.19976 .39924 m .21431 .41314 L .2354 .40748 L p F P
0 0 0 r
s
.647 .762 .933 r
.58459 .69053 m .59629 .70197 L .61909 .69579 L p F P
0 0 0 r
s
.647 .762 .933 r
.59629 .70197 m .58459 .69053 L .56185 .69675 L p F P
0 0 0 r
s
.486 .67 .945 r
.29189 .41463 m .30574 .42877 L .32691 .42888 L p F P
0 0 0 r
s
.552 .701 .939 r
.30574 .42877 m .29189 .41463 L .27072 .41718 L p F P
0 0 0 r
s
.149 0 0 r
.48844 .49521 m .501 .49523 L .52341 .49767 L p F P
0 0 0 r
s
.647 .762 .933 r
.64208 .68956 m .65335 .70102 L .6764 .69484 L p F P
0 0 0 r
s
.647 .762 .933 r
.65335 .70102 m .64208 .68956 L .61909 .69579 L p F P
0 0 0 r
s
.026 0 0 r
.55801 .49416 m .54612 .49783 L .52341 .49767 L p F P
0 0 0 r
s
.512 .914 .842 r
.62656 .47289 m .63749 .47106 L .66032 .4599 L p F P
0 0 0 r
s
.376 .837 .774 r
.63749 .47106 m .62656 .47289 L .60359 .48303 L p F P
0 0 0 r
s
.647 .762 .933 r
.3199 .68908 m .3336 .70055 L .35535 .69436 L p F P
0 0 0 r
s
.647 .762 .933 r
.3336 .70055 m .3199 .68908 L .29822 .69531 L p F P
0 0 0 r
s
.647 .762 .933 r
.69964 .6886 m .71049 .70007 L .73379 .69388 L p F P
0 0 0 r
s
.647 .762 .933 r
.71049 .70007 m .69964 .6886 L .6764 .69484 L p F P
0 0 0 r
s
.718 .873 .954 r
.72928 .42097 m .73952 .42845 L .76268 .41745 L p F P
0 0 0 r
s
.715 .908 .963 r
.73952 .42845 m .72928 .42097 L .70619 .43419 L p F P
0 0 0 r
s
.647 .762 .933 r
.37728 .68812 m .39055 .6996 L .41255 .6934 L p F P
0 0 0 r
s
.647 .762 .933 r
.39055 .6996 m .37728 .68812 L .35535 .69436 L p F P
0 0 0 r
s
.561 .699 .933 r
.25659 .40285 m .27072 .41718 L .29189 .41463 L p F P
0 0 0 r
s
.601 .718 .927 r
.27072 .41718 m .25659 .40285 L .2354 .40748 L p F P
0 0 0 r
s
.647 .762 .933 r
.43473 .68715 m .44758 .69865 L .46983 .69244 L p F P
0 0 0 r
s
.647 .762 .933 r
.44758 .69865 m .43473 .68715 L .41255 .6934 L p F P
0 0 0 r
s
.668 .751 .913 r
.86701 .39241 m .87656 .40569 L .90054 .39796 L p F P
0 0 0 r
s
.671 .758 .916 r
.87656 .40569 m .86701 .39241 L .84312 .40066 L p F P
0 0 0 r
s
.681 .777 .923 r
.80956 .39713 m .81945 .40922 L .84312 .40066 L p F P
0 0 0 r
s
.688 .794 .93 r
.81945 .40922 m .80956 .39713 L .78601 .40698 L p F P
0 0 0 r
s
.647 .762 .933 r
.49225 .68619 m .50468 .6977 L .52717 .69149 L p F P
0 0 0 r
s
.647 .762 .933 r
.50468 .6977 m .49225 .68619 L .46983 .69244 L p F P
0 0 0 r
s
.665 .746 .91 r
.93388 .40394 m .92472 .3903 L .90054 .39796 L p F P
0 0 0 r
s
.647 .762 .933 r
.54985 .68522 m .56185 .69675 L .58459 .69053 L p F P
0 0 0 r
s
.647 .762 .933 r
.56185 .69675 m .54985 .68522 L .52717 .69149 L p F P
0 0 0 r
s
.629 .96 .903 r
.64958 .46013 m .66032 .4599 L .68322 .44738 L p F P
0 0 0 r
s
.512 .914 .842 r
.66032 .4599 m .64958 .46013 L .62656 .47289 L p F P
0 0 0 r
s
.647 .762 .933 r
.60752 .68425 m .61909 .69579 L .64208 .68956 L p F P
0 0 0 r
s
.647 .762 .933 r
.61909 .69579 m .60752 .68425 L .58459 .69053 L p F P
0 0 0 r
s
.608 .719 .923 r
.22096 .39322 m .2354 .40748 L .25659 .40285 L p F P
0 0 0 r
s
.631 .729 .919 r
.2354 .40748 m .22096 .39322 L .19976 .39924 L p F P
0 0 0 r
s
.712 .84 .943 r
.7525 .40824 m .76268 .41745 L .78601 .40698 L p F P
0 0 0 r
s
.718 .873 .954 r
.76268 .41745 m .7525 .40824 L .72928 .42097 L p F P
0 0 0 r
s
.647 .762 .933 r
.28421 .68377 m .29822 .69531 L .3199 .68908 L p F P
0 0 0 r
s
.647 .762 .933 r
.66526 .68328 m .6764 .69484 L .69964 .6886 L p F P
0 0 0 r
s
.647 .762 .933 r
.6764 .69484 m .66526 .68328 L .64208 .68956 L p F P
0 0 0 r
s
.647 .762 .933 r
.34176 .6828 m .35535 .69436 L .37728 .68812 L p F P
0 0 0 r
s
.647 .762 .933 r
.35535 .69436 m .34176 .6828 L .3199 .68908 L p F P
0 0 0 r
s
.647 .762 .933 r
.72308 .68231 m .73379 .69388 L .75728 .68764 L p F P
0 0 0 r
s
.647 .762 .933 r
.73379 .69388 m .72308 .68231 L .69964 .6886 L p F P
0 0 0 r
s
0 .437 .81 r
.41818 .47012 m .43137 .47778 L .4533 .48569 L p F P
0 0 0 r
s
.073 .529 .9 r
.43137 .47778 m .41818 .47012 L .39654 .46228 L p F P
0 0 0 r
s
.647 .762 .933 r
.39939 .68183 m .41255 .6934 L .43473 .68715 L p F P
0 0 0 r
s
.647 .762 .933 r
.41255 .6934 m .39939 .68183 L .37728 .68812 L p F P
0 0 0 r
s
.58072 .49011 m .56907 .49464 L .54612 .49783 L p F P
s
.073 .494 .896 r
.38316 .45114 m .39654 .46228 L .41818 .47012 L p F P
0 0 0 r
s
.232 .58 .944 r
.39654 .46228 m .38316 .45114 L .36175 .44523 L p F P
0 0 0 r
s
.248 .56 .935 r
.3482 .43176 m .36175 .44523 L .38316 .45114 L p F P
0 0 0 r
s
.376 .63 .953 r
.36175 .44523 m .3482 .43176 L .32691 .42888 L p F P
0 0 0 r
s
.704 .965 .939 r
.67263 .44553 m .68322 .44738 L .70619 .43419 L p F P
0 0 0 r
s
.629 .96 .903 r
.68322 .44738 m .67263 .44553 L .64958 .46013 L p F P
0 0 0 r
s
.647 .762 .933 r
.45709 .68086 m .46983 .69244 L .49225 .68619 L p F P
0 0 0 r
s
.647 .762 .933 r
.46983 .69244 m .45709 .68086 L .43473 .68715 L p F P
0 0 0 r
s
.395 .621 .943 r
.31315 .41427 m .32691 .42888 L .3482 .43176 L p F P
0 0 0 r
s
.486 .67 .945 r
.32691 .42888 m .31315 .41427 L .29189 .41463 L p F P
0 0 0 r
s
.676 .764 .917 r
.83332 .38786 m .84312 .40066 L .86701 .39241 L p F P
0 0 0 r
s
.681 .777 .923 r
.84312 .40066 m .83332 .38786 L .80956 .39713 L p F P
0 0 0 r
s
.666 .747 .911 r
.89111 .38438 m .90054 .39796 L .92472 .3903 L p F P
0 0 0 r
s
.668 .751 .913 r
.90054 .39796 m .89111 .38438 L .86701 .39241 L p F P
0 0 0 r
s
.647 .762 .933 r
.51487 .67988 m .52717 .69149 L .54985 .68522 L p F P
0 0 0 r
s
.647 .762 .933 r
.52717 .69149 m .51487 .67988 L .49225 .68619 L p F P
0 0 0 r
s
.126 0 0 r
.51101 .49986 m .52341 .49767 L .54612 .49783 L p F P
0 0 0 r
s
.149 0 0 r
.52341 .49767 m .51101 .49986 L .48844 .49521 L p F P
0 0 0 r
s
.636 .73 .916 r
.18499 .38509 m .19976 .39924 L .22096 .39322 L p F P
0 0 0 r
s
.503 .668 .937 r
.27787 .39973 m .29189 .41463 L .31315 .41427 L p F P
0 0 0 r
s
.561 .699 .933 r
.29189 .41463 m .27787 .39973 L .25659 .40285 L p F P
0 0 0 r
s
.702 .811 .933 r
.77592 .39631 m .78601 .40698 L .80956 .39713 L p F P
0 0 0 r
s
.712 .84 .943 r
.78601 .40698 m .77592 .39631 L .7525 .40824 L p F P
0 0 0 r
s
.647 .762 .933 r
.57272 .67891 m .58459 .69053 L .60752 .68425 L p F P
0 0 0 r
s
.647 .762 .933 r
.58459 .69053 m .57272 .67891 L .54985 .68522 L p F P
0 0 0 r
s
.647 .762 .933 r
.63064 .67793 m .64208 .68956 L .66526 .68328 L p F P
0 0 0 r
s
.647 .762 .933 r
.64208 .68956 m .63064 .67793 L .60752 .68425 L p F P
0 0 0 r
s
.647 .762 .933 r
.306 .67744 m .3199 .68908 L .34176 .6828 L p F P
0 0 0 r
s
.647 .762 .933 r
.3199 .68908 m .306 .67744 L .28421 .68377 L p F P
0 0 0 r
s
.738 .94 .951 r
.69573 .43003 m .70619 .43419 L .72928 .42097 L p F P
0 0 0 r
s
.704 .965 .939 r
.70619 .43419 m .69573 .43003 L .67263 .44553 L p F P
0 0 0 r
s
.647 .762 .933 r
.68863 .67695 m .69964 .6886 L .72308 .68231 L p F P
0 0 0 r
s
.647 .762 .933 r
.69964 .6886 m .68863 .67695 L .66526 .68328 L p F P
0 0 0 r
s
.647 .762 .933 r
.3638 .67646 m .37728 .68812 L .39939 .68183 L p F P
0 0 0 r
s
.647 .762 .933 r
.37728 .68812 m .3638 .67646 L .34176 .6828 L p F P
0 0 0 r
s
.574 .7 .928 r
.24227 .3881 m .25659 .40285 L .27787 .39973 L p F P
0 0 0 r
s
.608 .719 .923 r
.25659 .40285 m .24227 .3881 L .22096 .39322 L p F P
0 0 0 r
s
.647 .762 .933 r
.7467 .67597 m .75728 .68764 L .78096 .68134 L p F P
0 0 0 r
s
.647 .762 .933 r
.75728 .68764 m .7467 .67597 L .72308 .68231 L p F P
0 0 0 r
s
.647 .762 .933 r
.42169 .67548 m .43473 .68715 L .45709 .68086 L p F P
0 0 0 r
s
.647 .762 .933 r
.43473 .68715 m .42169 .67548 L .39939 .68183 L p F P
0 0 0 r
s
.647 .762 .933 r
.47964 .6745 m .49225 .68619 L .51487 .67988 L p F P
0 0 0 r
s
.647 .762 .933 r
.49225 .68619 m .47964 .6745 L .45709 .68086 L p F P
0 0 0 r
s
.671 .755 .914 r
.85732 .37909 m .86701 .39241 L .89111 .38438 L p F P
0 0 0 r
s
.676 .764 .917 r
.86701 .39241 m .85732 .37909 L .83332 .38786 L p F P
0 0 0 r
s
.666 .747 .911 r
.92472 .3903 m .91542 .37648 L .89111 .38438 L p F P
0 0 0 r
s
.743 .902 .949 r
.7189 .41453 m .72928 .42097 L .7525 .40824 L p F P
0 0 0 r
s
.738 .94 .951 r
.72928 .42097 m .7189 .41453 L .69573 .43003 L p F P
0 0 0 r
s
.691 .788 .925 r
.79954 .38529 m .80956 .39713 L .83332 .38786 L p F P
0 0 0 r
s
.702 .811 .933 r
.80956 .39713 m .79954 .38529 L .77592 .39631 L p F P
0 0 0 r
s
.647 .762 .933 r
.53767 .67352 m .54985 .68522 L .57272 .67891 L p F P
0 0 0 r
s
.647 .762 .933 r
.54985 .68522 m .53767 .67352 L .51487 .67988 L p F P
0 0 0 r
s
.206 0 0 r
.4756 .49383 m .48844 .49521 L .51101 .49986 L p F P
0 0 0 r
s
.617 .72 .92 r
.20631 .37869 m .22096 .39322 L .24227 .3881 L p F P
0 0 0 r
s
.636 .73 .916 r
.22096 .39322 m .20631 .37869 L .18499 .38509 L p F P
0 0 0 r
s
.647 .762 .933 r
.59577 .67254 m .60752 .68425 L .63064 .67793 L p F P
0 0 0 r
s
.647 .762 .933 r
.60752 .68425 m .59577 .67254 L .57272 .67891 L p F P
0 0 0 r
s
.647 .762 .933 r
.26998 .67205 m .28421 .68377 L .306 .67744 L p F P
0 0 0 r
s
.647 .762 .933 r
.65395 .67155 m .66526 .68328 L .68863 .67695 L p F P
0 0 0 r
s
.647 .762 .933 r
.66526 .68328 m .65395 .67155 L .63064 .67793 L p F P
0 0 0 r
s
.647 .762 .933 r
.32797 .67106 m .34176 .6828 L .3638 .67646 L p F P
0 0 0 r
s
.647 .762 .933 r
.34176 .6828 m .32797 .67106 L .306 .67744 L p F P
0 0 0 r
s
.647 .762 .933 r
.7122 .67057 m .72308 .68231 L .7467 .67597 L p F P
0 0 0 r
s
.647 .762 .933 r
.72308 .68231 m .7122 .67057 L .68863 .67695 L p F P
0 0 0 r
s
.497 .9 .779 r
.6154 .47633 m .62656 .47289 L .64958 .46013 L p F P
0 0 0 r
s
.32 .79 .685 r
.62656 .47289 m .6154 .47633 L .59219 .48748 L p F P
0 0 0 r
s
.647 .762 .933 r
.38603 .67008 m .39939 .68183 L .42169 .67548 L p F P
0 0 0 r
s
.647 .762 .933 r
.39939 .68183 m .38603 .67008 L .3638 .67646 L p F P
0 0 0 r
s
.023 0 0 r
.53393 .5017 m .54612 .49783 L .56907 .49464 L p F P
0 0 0 r
s
.126 0 0 r
.54612 .49783 m .53393 .5017 L .51101 .49986 L p F P
0 0 0 r
s
.734 .862 .941 r
.74221 .39973 m .7525 .40824 L .77592 .39631 L p F P
0 0 0 r
s
.743 .902 .949 r
.7525 .40824 m .74221 .39973 L .7189 .41453 L p F P
0 0 0 r
s
.647 .762 .933 r
.77052 .66958 m .78096 .68134 L .80484 .67499 L p F P
0 0 0 r
s
.647 .762 .933 r
.78096 .68134 m .77052 .66958 L .7467 .67597 L p F P
0 0 0 r
s
.248 .56 .935 r
.38316 .45114 m .36966 .43761 L .3482 .43176 L p F P
0 0 0 r
s
.289 .556 .927 r
.33453 .41656 m .3482 .43176 L .36966 .43761 L p F P
0 0 0 r
s
.395 .621 .943 r
.3482 .43176 m .33453 .41656 L .31315 .41427 L p F P
0 0 0 r
s
.427 .622 .934 r
.29925 .39859 m .31315 .41427 L .33453 .41656 L p F P
0 0 0 r
s
.503 .668 .937 r
.31315 .41427 m .29925 .39859 L .27787 .39973 L p F P
0 0 0 r
s
.647 .762 .933 r
.44417 .66909 m .45709 .68086 L .47964 .6745 L p F P
0 0 0 r
s
.647 .762 .933 r
.45709 .68086 m .44417 .66909 L .42169 .67548 L p F P
0 0 0 r
s
0 .437 .81 r
.4533 .48569 m .44015 .47968 L .41818 .47012 L p F P
0 0 0 r
s
.073 .494 .896 r
.41818 .47012 m .40483 .45975 L .38316 .45114 L p F P
0 0 0 r
s
.12 .483 .899 r
.36966 .43761 m .38316 .45114 L .40483 .45975 L p F P
0 0 0 r
s
.668 .75 .912 r
.88154 .37067 m .89111 .38438 L .91542 .37648 L p F P
0 0 0 r
s
.671 .755 .914 r
.89111 .38438 m .88154 .37067 L .85732 .37909 L p F P
0 0 0 r
s
.682 .771 .919 r
.8234 .37514 m .83332 .38786 L .85732 .37909 L p F P
0 0 0 r
s
.691 .788 .925 r
.83332 .38786 m .8234 .37514 L .79954 .38529 L p F P
0 0 0 r
s
.647 .762 .933 r
.50237 .6681 m .51487 .67988 L .53767 .67352 L p F P
0 0 0 r
s
.647 .762 .933 r
.51487 .67988 m .50237 .6681 L .47964 .6745 L p F P
0 0 0 r
s
.641 .732 .914 r
.17 .37073 m .18499 .38509 L .20631 .37869 L p F P
0 0 0 r
s
0 .419 .837 r
.40483 .45975 m .41818 .47012 L .44015 .47968 L p F P
0 0 0 r
s
.525 .672 .93 r
.26368 .38425 m .27787 .39973 L .29925 .39859 L p F P
0 0 0 r
s
.574 .7 .928 r
.27787 .39973 m .26368 .38425 L .24227 .3881 L p F P
0 0 0 r
s
.647 .762 .933 r
.56066 .66711 m .57272 .67891 L .59577 .67254 L p F P
0 0 0 r
s
.647 .762 .933 r
.57272 .67891 m .56066 .66711 L .53767 .67352 L p F P
0 0 0 r
s
.643 .967 .86 r
.63863 .46178 m .64958 .46013 L .67263 .44553 L p F P
0 0 0 r
s
.497 .9 .779 r
.64958 .46013 m .63863 .46178 L .6154 .47633 L p F P
0 0 0 r
s
.647 .762 .933 r
.61902 .66612 m .63064 .67793 L .65395 .67155 L p F P
0 0 0 r
s
.647 .762 .933 r
.63064 .67793 m .61902 .66612 L .59577 .67254 L p F P
0 0 0 r
s
.719 .827 .932 r
.76569 .38605 m .77592 .39631 L .79954 .38529 L p F P
0 0 0 r
s
.734 .862 .941 r
.77592 .39631 m .76569 .38605 L .74221 .39973 L p F P
0 0 0 r
s
.647 .762 .933 r
.29188 .66562 m .306 .67744 L .32797 .67106 L p F P
0 0 0 r
s
.647 .762 .933 r
.306 .67744 m .29188 .66562 L .26998 .67205 L p F P
0 0 0 r
s
.647 .762 .933 r
.67745 .66513 m .68863 .67695 L .7122 .67057 L p F P
0 0 0 r
s
.647 .762 .933 r
.68863 .67695 m .67745 .66513 L .65395 .67155 L p F P
0 0 0 r
s
.589 .704 .923 r
.22775 .37301 m .24227 .3881 L .26368 .38425 L p F P
0 0 0 r
s
.617 .72 .92 r
.24227 .3881 m .22775 .37301 L .20631 .37869 L p F P
0 0 0 r
s
.647 .762 .933 r
.35012 .66463 m .3638 .67646 L .38603 .67008 L p F P
0 0 0 r
s
.647 .762 .933 r
.3638 .67646 m .35012 .66463 L .32797 .67106 L p F P
0 0 0 r
s
.647 .762 .933 r
.73596 .66413 m .7467 .67597 L .77052 .66958 L p F P
0 0 0 r
s
.647 .762 .933 r
.7467 .67597 m .73596 .66413 L .7122 .67057 L p F P
0 0 0 r
s
.647 .762 .933 r
.40844 .66363 m .42169 .67548 L .44417 .66909 L p F P
0 0 0 r
s
.647 .762 .933 r
.42169 .67548 m .40844 .66363 L .38603 .67008 L p F P
0 0 0 r
s
.733 .982 .909 r
.66186 .44484 m .67263 .44553 L .69573 .43003 L p F P
0 0 0 r
s
.643 .967 .86 r
.67263 .44553 m .66186 .44484 L .63863 .46178 L p F P
0 0 0 r
s
.647 .762 .933 r
.79454 .66314 m .80484 .67499 L .82892 .66859 L p F P
0 0 0 r
s
.647 .762 .933 r
.80484 .67499 m .79454 .66314 L .77052 .66958 L p F P
0 0 0 r
s
.647 .762 .933 r
.46683 .66264 m .47964 .6745 L .50237 .6681 L p F P
0 0 0 r
s
.647 .762 .933 r
.47964 .6745 m .46683 .66264 L .44417 .66909 L p F P
0 0 0 r
s
.675 .76 .915 r
.84749 .36572 m .85732 .37909 L .88154 .37067 L p F P
0 0 0 r
s
.682 .771 .919 r
.85732 .37909 m .84749 .36572 L .8234 .37514 L p F P
0 0 0 r
s
.668 .75 .912 r
.91542 .37648 m .90599 .3625 L .88154 .37067 L p F P
0 0 0 r
s
.023 0 0 r
.56907 .49464 m .55712 .49939 L .53393 .5017 L p F P
0 0 0 r
s
.647 .762 .933 r
.5253 .66164 m .53767 .67352 L .56066 .66711 L p F P
0 0 0 r
s
.647 .762 .933 r
.53767 .67352 m .5253 .66164 L .50237 .6681 L p F P
0 0 0 r
s
.77 .96 .93 r
.68509 .42677 m .69573 .43003 L .7189 .41453 L p F P
0 0 0 r
s
.733 .982 .909 r
.69573 .43003 m .68509 .42677 L .66186 .44484 L p F P
0 0 0 r
s
.626 .723 .917 r
.19144 .36395 m .20631 .37869 L .22775 .37301 L p F P
0 0 0 r
s
.641 .732 .914 r
.20631 .37869 m .19144 .36395 L .17 .37073 L p F P
0 0 0 r
s
.704 .799 .924 r
.78939 .37365 m .79954 .38529 L .8234 .37514 L p F P
0 0 0 r
s
.719 .827 .932 r
.79954 .38529 m .78939 .37365 L .76569 .38605 L p F P
0 0 0 r
s
.142 0 0 r
.49832 .5005 m .51101 .49986 L .53393 .5017 L p F P
0 0 0 r
s
.206 0 0 r
.51101 .49986 m .49832 .5005 L .4756 .49383 L p F P
0 0 0 r
s
.647 .762 .933 r
.58384 .66064 m .59577 .67254 L .61902 .66612 L p F P
0 0 0 r
s
.647 .762 .933 r
.59577 .67254 m .58384 .66064 L .56066 .66711 L p F P
0 0 0 r
s
.647 .762 .933 r
.25554 .66014 m .26998 .67205 L .29188 .66562 L p F P
0 0 0 r
s
.647 .762 .933 r
.64246 .65964 m .65395 .67155 L .67745 .66513 L p F P
0 0 0 r
s
.647 .762 .933 r
.65395 .67155 m .64246 .65964 L .61902 .66612 L p F P
0 0 0 r
s
.647 .762 .933 r
.31396 .65914 m .32797 .67106 L .35012 .66463 L p F P
0 0 0 r
s
.647 .762 .933 r
.32797 .67106 m .31396 .65914 L .29188 .66562 L p F P
0 0 0 r
s
.647 .762 .933 r
.70115 .65864 m .7122 .67057 L .73596 .66413 L p F P
0 0 0 r
s
.647 .762 .933 r
.7122 .67057 m .70115 .65864 L .67745 .66513 L p F P
0 0 0 r
s
.774 .92 .935 r
.70836 .40872 m .7189 .41453 L .74221 .39973 L p F P
0 0 0 r
s
.77 .96 .93 r
.7189 .41453 m .70836 .40872 L .68509 .42677 L p F P
0 0 0 r
s
.427 .622 .934 r
.33453 .41656 m .32074 .39983 L .29925 .39859 L p F P
0 0 0 r
s
.464 .631 .926 r
.2852 .38209 m .29925 .39859 L .32074 .39983 L p F P
0 0 0 r
s
.525 .672 .93 r
.29925 .39859 m .2852 .38209 L .26368 .38425 L p F P
0 0 0 r
s
.289 .556 .927 r
.36966 .43761 m .35607 .42166 L .33453 .41656 L p F P
0 0 0 r
s
.343 .564 .92 r
.32074 .39983 m .33453 .41656 L .35607 .42166 L p F P
0 0 0 r
s
.647 .762 .933 r
.37246 .65814 m .38603 .67008 L .40844 .66363 L p F P
0 0 0 r
s
.647 .762 .933 r
.38603 .67008 m .37246 .65814 L .35012 .66463 L p F P
0 0 0 r
s
.647 .762 .933 r
.75992 .65764 m .77052 .66958 L .79454 .66314 L p F P
0 0 0 r
s
.647 .762 .933 r
.77052 .66958 m .75992 .65764 L .73596 .66413 L p F P
0 0 0 r
s
.647 .762 .933 r
.43104 .65714 m .44417 .66909 L .46683 .66264 L p F P
0 0 0 r
s
.647 .762 .933 r
.44417 .66909 m .43104 .65714 L .40844 .66363 L p F P
0 0 0 r
s
.55 .679 .924 r
.24931 .36836 m .26368 .38425 L .2852 .38209 L p F P
0 0 0 r
s
.589 .704 .923 r
.26368 .38425 m .24931 .36836 L .22775 .37301 L p F P
0 0 0 r
s
.647 .762 .933 r
.81877 .65664 m .82892 .66859 L .8532 .66214 L p F P
0 0 0 r
s
.647 .762 .933 r
.82892 .66859 m .81877 .65664 L .79454 .66314 L p F P
0 0 0 r
s
.12 .483 .899 r
.40483 .45975 m .39138 .44616 L .36966 .43761 L p F P
0 0 0 r
s
.193 .489 .9 r
.35607 .42166 m .36966 .43761 L .39138 .44616 L p F P
0 0 0 r
s
.67 .752 .912 r
.87184 .35685 m .88154 .37067 L .90599 .3625 L p F P
0 0 0 r
s
.675 .76 .915 r
.88154 .37067 m .87184 .35685 L .84749 .36572 L p F P
0 0 0 r
s
.646 .734 .913 r
.15478 .35618 m .17 .37073 L .19144 .36395 L p F P
0 0 0 r
s
.647 .762 .933 r
.48969 .65613 m .50237 .6681 L .5253 .66164 L p F P
0 0 0 r
s
.647 .762 .933 r
.50237 .6681 m .48969 .65613 L .46683 .66264 L p F P
0 0 0 r
s
.691 .779 .919 r
.81333 .36247 m .8234 .37514 L .84749 .36572 L p F P
0 0 0 r
s
.704 .799 .924 r
.8234 .37514 m .81333 .36247 L .78939 .37365 L p F P
0 0 0 r
s
.759 .877 .932 r
.73175 .39162 m .74221 .39973 L .76569 .38605 L p F P
0 0 0 r
s
.774 .92 .935 r
.74221 .39973 m .73175 .39162 L .70836 .40872 L p F P
0 0 0 r
s
0 .385 .731 r
.4756 .49383 m .46254 .48951 L .44015 .47968 L p F P
0 0 0 r
s
0 .408 .706 r
.46254 .48951 m .4756 .49383 L .49832 .5005 L p F P
0 0 0 r
s
.647 .762 .933 r
.54842 .65513 m .56066 .66711 L .58384 .66064 L p F P
0 0 0 r
s
.647 .762 .933 r
.56066 .66711 m .54842 .65513 L .5253 .66164 L p F P
0 0 0 r
s
0 .419 .837 r
.44015 .47968 m .42685 .47017 L .40483 .45975 L p F P
0 0 0 r
s
.034 .426 .866 r
.39138 .44616 m .40483 .45975 L .42685 .47017 L p F P
0 0 0 r
s
.647 .762 .933 r
.60722 .65412 m .61902 .66612 L .64246 .65964 L p F P
0 0 0 r
s
.647 .762 .933 r
.61902 .66612 m .60722 .65412 L .58384 .66064 L p F P
0 0 0 r
s
.647 .762 .933 r
.27754 .65362 m .29188 .66562 L .31396 .65914 L p F P
0 0 0 r
s
.647 .762 .933 r
.29188 .66562 m .27754 .65362 L .25554 .66014 L p F P
0 0 0 r
s
0 .397 .808 r
.42685 .47017 m .44015 .47968 L .46254 .48951 L p F P
0 0 0 r
s
.604 .71 .919 r
.21302 .35771 m .22775 .37301 L .24931 .36836 L p F P
0 0 0 r
s
.626 .723 .917 r
.22775 .37301 m .21302 .35771 L .19144 .36395 L p F P
0 0 0 r
s
.647 .762 .933 r
.6661 .65311 m .67745 .66513 L .70115 .65864 L p F P
0 0 0 r
s
.647 .762 .933 r
.67745 .66513 m .6661 .65311 L .64246 .65964 L p F P
0 0 0 r
s
.647 .762 .933 r
.33623 .65261 m .35012 .66463 L .37246 .65814 L p F P
0 0 0 r
s
.647 .762 .933 r
.35012 .66463 m .33623 .65261 L .31396 .65914 L p F P
0 0 0 r
s
.647 .762 .933 r
.72505 .65211 m .73596 .66413 L .75992 .65764 L p F P
0 0 0 r
s
.647 .762 .933 r
.73596 .66413 m .72505 .65211 L .70115 .65864 L p F P
0 0 0 r
s
.739 .839 .926 r
.75531 .37601 m .76569 .38605 L .78939 .37365 L p F P
0 0 0 r
s
.759 .877 .932 r
.76569 .38605 m .75531 .37601 L .73175 .39162 L p F P
0 0 0 r
s
.647 .762 .933 r
.39499 .6516 m .40844 .66363 L .43104 .65714 L p F P
0 0 0 r
s
.647 .762 .933 r
.40844 .66363 m .39499 .6516 L .37246 .65814 L p F P
0 0 0 r
s
.647 .762 .933 r
.78408 .65109 m .79454 .66314 L .81877 .65664 L p F P
0 0 0 r
s
.647 .762 .933 r
.79454 .66314 m .78408 .65109 L .75992 .65764 L p F P
0 0 0 r
s
.647 .762 .933 r
.45383 .65059 m .46683 .66264 L .48969 .65613 L p F P
0 0 0 r
s
.647 .762 .933 r
.46683 .66264 m .45383 .65059 L .43104 .65714 L p F P
0 0 0 r
s
.562 .93 .789 r
.60396 .47998 m .6154 .47633 L .63863 .46178 L p F P
0 0 0 r
s
.36 .814 .696 r
.6154 .47633 m .60396 .47998 L .5805 .49216 L p F P
0 0 0 r
s
.647 .762 .933 r
.84319 .65008 m .8532 .66214 L .87769 .65563 L p F P
0 0 0 r
s
.647 .762 .933 r
.8532 .66214 m .84319 .65008 L .81877 .65664 L p F P
0 0 0 r
s
.52142 .50388 m .53393 .5017 L .55712 .49939 L p F P
s
.142 0 0 r
.53393 .5017 m .52142 .50388 L .49832 .5005 L p F P
0 0 0 r
s
.681 .764 .915 r
.83753 .3523 m .84749 .36572 L .87184 .35685 L p F P
0 0 0 r
s
.691 .779 .919 r
.84749 .36572 m .83753 .3523 L .81333 .36247 L p F P
0 0 0 r
s
.67 .752 .912 r
.90599 .3625 m .89642 .34836 L .87184 .35685 L p F P
0 0 0 r
s
.647 .762 .933 r
.51274 .64958 m .5253 .66164 L .54842 .65513 L p F P
0 0 0 r
s
.647 .762 .933 r
.5253 .66164 m .51274 .64958 L .48969 .65613 L p F P
0 0 0 r
s
.635 .727 .914 r
.17634 .34904 m .19144 .36395 L .21302 .35771 L p F P
0 0 0 r
s
.646 .734 .913 r
.19144 .36395 m .17634 .34904 L .15478 .35618 L p F P
0 0 0 r
s
.647 .762 .933 r
.57173 .64856 m .58384 .66064 L .60722 .65412 L p F P
0 0 0 r
s
.647 .762 .933 r
.58384 .66064 m .57173 .64856 L .54842 .65513 L p F P
0 0 0 r
s
.647 .762 .933 r
.24087 .64806 m .25554 .66014 L .27754 .65362 L p F P
0 0 0 r
s
.718 .808 .921 r
.77908 .36208 m .78939 .37365 L .81333 .36247 L p F P
0 0 0 r
s
.739 .839 .926 r
.78939 .37365 m .77908 .36208 L .75531 .37601 L p F P
0 0 0 r
s
.647 .762 .933 r
.63079 .64755 m .64246 .65964 L .6661 .65311 L p F P
0 0 0 r
s
.647 .762 .933 r
.64246 .65964 m .63079 .64755 L .60722 .65412 L p F P
0 0 0 r
s
.343 .564 .92 r
.35607 .42166 m .34239 .4036 L .32074 .39983 L p F P
0 0 0 r
s
.4 .58 .913 r
.30683 .38196 m .32074 .39983 L .34239 .4036 L p F P
0 0 0 r
s
.464 .631 .926 r
.32074 .39983 m .30683 .38196 L .2852 .38209 L p F P
0 0 0 r
s
.503 .644 .919 r
.27097 .36508 m .2852 .38209 L .30683 .38196 L p F P
0 0 0 r
s
.55 .679 .924 r
.2852 .38209 m .27097 .36508 L .24931 .36836 L p F P
0 0 0 r
s
.706 .985 .855 r
.62741 .46357 m .63863 .46178 L .66186 .44484 L p F P
0 0 0 r
s
.562 .93 .789 r
.63863 .46178 m .62741 .46357 L .60396 .47998 L p F P
0 0 0 r
s
.647 .762 .933 r
.29974 .64704 m .31396 .65914 L .33623 .65261 L p F P
0 0 0 r
s
.647 .762 .933 r
.31396 .65914 m .29974 .64704 L .27754 .65362 L p F P
0 0 0 r
s
.647 .762 .933 r
.68994 .64653 m .70115 .65864 L .72505 .65211 L p F P
0 0 0 r
s
.647 .762 .933 r
.70115 .65864 m .68994 .64653 L .6661 .65311 L p F P
0 0 0 r
s
.647 .762 .933 r
.35868 .64602 m .37246 .65814 L .39499 .6516 L p F P
0 0 0 r
s
.647 .762 .933 r
.37246 .65814 m .35868 .64602 L .33623 .65261 L p F P
0 0 0 r
s
.193 .489 .9 r
.39138 .44616 m .37785 .42932 L .35607 .42166 L p F P
0 0 0 r
s
.274 .507 .897 r
.34239 .4036 m .35607 .42166 L .37785 .42932 L p F P
0 0 0 r
s
.647 .762 .933 r
.74915 .64551 m .75992 .65764 L .78408 .65109 L p F P
0 0 0 r
s
.647 .762 .933 r
.75992 .65764 m .74915 .64551 L .72505 .65211 L p F P
0 0 0 r
s
.575 .689 .919 r
.23472 .35225 m .24931 .36836 L .27097 .36508 L p F P
0 0 0 r
s
.604 .71 .919 r
.24931 .36836 m .23472 .35225 L .21302 .35771 L p F P
0 0 0 r
s
.784 .989 .891 r
.65083 .44423 m .66186 .44484 L .68509 .42677 L p F P
0 0 0 r
s
.706 .985 .855 r
.66186 .44484 m .65083 .44423 L .62741 .46357 L p F P
0 0 0 r
s
.647 .762 .933 r
.41771 .645 m .43104 .65714 L .45383 .65059 L p F P
0 0 0 r
s
.647 .762 .933 r
.43104 .65714 m .41771 .645 L .39499 .6516 L p F P
0 0 0 r
s
.647 .762 .933 r
.80845 .64449 m .81877 .65664 L .84319 .65008 L p F P
0 0 0 r
s
.647 .762 .933 r
.81877 .65664 m .80845 .64449 L .78408 .65109 L p F P
0 0 0 r
s
.651 .735 .911 r
.13932 .34145 m .15478 .35618 L .17634 .34904 L p F P
0 0 0 r
s
.647 .762 .933 r
.47681 .64398 m .48969 .65613 L .51274 .64958 L p F P
0 0 0 r
s
.647 .762 .933 r
.48969 .65613 m .47681 .64398 L .45383 .65059 L p F P
0 0 0 r
s
.81 .962 .908 r
.67421 .4235 m .68509 .42677 L .70836 .40872 L p F P
0 0 0 r
s
.784 .989 .891 r
.68509 .42677 m .67421 .4235 L .65083 .44423 L p F P
0 0 0 r
s
.674 .755 .912 r
.86199 .3429 m .87184 .35685 L .89642 .34836 L p F P
0 0 0 r
s
.681 .764 .915 r
.87184 .35685 m .86199 .3429 L .83753 .3523 L p F P
0 0 0 r
s
.647 .762 .933 r
.86782 .64347 m .87769 .65563 L .90238 .64907 L p F P
0 0 0 r
s
.647 .762 .933 r
.87769 .65563 m .86782 .64347 L .84319 .65008 L p F P
0 0 0 r
s
.647 .762 .933 r
.53598 .64296 m .54842 .65513 L .57173 .64856 L p F P
0 0 0 r
s
.647 .762 .933 r
.54842 .65513 m .53598 .64296 L .51274 .64958 L p F P
0 0 0 r
s
.7 .785 .917 r
.80311 .34974 m .81333 .36247 L .83753 .3523 L p F P
0 0 0 r
s
.718 .808 .921 r
.81333 .36247 m .80311 .34974 L .77908 .36208 L p F P
0 0 0 r
s
.034 .426 .866 r
.42685 .47017 m .41344 .45654 L .39138 .44616 L p F P
0 0 0 r
s
.143 .445 .879 r
.37785 .42932 m .39138 .44616 L .41344 .45654 L p F P
0 0 0 r
s
.805 .923 .915 r
.69761 .40285 m .70836 .40872 L .73175 .39162 L p F P
0 0 0 r
s
.81 .962 .908 r
.70836 .40872 m .69761 .40285 L .67421 .4235 L p F P
0 0 0 r
s
0 .408 .706 r
.49832 .5005 m .48536 .49774 L .46254 .48951 L p F P
0 0 0 r
s
0 .522 .753 r
.48536 .49774 m .49832 .5005 L .52142 .50388 L p F P
0 0 0 r
s
.647 .762 .933 r
.59524 .64194 m .60722 .65412 L .63079 .64755 L p F P
0 0 0 r
s
.647 .762 .933 r
.60722 .65412 m .59524 .64194 L .57173 .64856 L p F P
0 0 0 r
s
.618 .716 .915 r
.19805 .34227 m .21302 .35771 L .23472 .35225 L p F P
0 0 0 r
s
.635 .727 .914 r
.21302 .35771 m .19805 .34227 L .17634 .34904 L p F P
0 0 0 r
s
.647 .762 .933 r
.26298 .64143 m .27754 .65362 L .29974 .64704 L p F P
0 0 0 r
s
.647 .762 .933 r
.27754 .65362 m .26298 .64143 L .24087 .64806 L p F P
0 0 0 r
s
.55712 .49939 m .54484 .50238 L .52142 .50388 L p F P
s
.256 .76 .729 r
.54484 .50238 m .55712 .49939 L .5805 .49216 L p F P
0 0 0 r
s
.647 .762 .933 r
.65457 .64092 m .6661 .65311 L .68994 .64653 L p F P
0 0 0 r
s
.647 .762 .933 r
.6661 .65311 m .65457 .64092 L .63079 .64755 L p F P
0 0 0 r
s
.647 .762 .933 r
.32212 .6404 m .33623 .65261 L .35868 .64602 L p F P
0 0 0 r
s
.647 .762 .933 r
.33623 .65261 m .32212 .6404 L .29974 .64704 L p F P
0 0 0 r
s
.785 .882 .916 r
.72109 .38339 m .73175 .39162 L .75531 .37601 L p F P
0 0 0 r
s
.805 .923 .915 r
.73175 .39162 m .72109 .38339 L .69761 .40285 L p F P
0 0 0 r
s
.647 .762 .933 r
.71397 .63989 m .72505 .65211 L .74915 .64551 L p F P
0 0 0 r
s
.647 .762 .933 r
.72505 .65211 m .71397 .63989 L .68994 .64653 L p F P
0 0 0 r
s
0 .397 .808 r
.46254 .48951 m .44929 .48092 L .42685 .47017 L p F P
0 0 0 r
s
.028 .422 .864 r
.41344 .45654 m .42685 .47017 L .44929 .48092 L p F P
0 0 0 r
s
.647 .762 .933 r
.38133 .63938 m .39499 .6516 L .41771 .645 L p F P
0 0 0 r
s
.647 .762 .933 r
.39499 .6516 m .38133 .63938 L .35868 .64602 L p F P
0 0 0 r
s
.647 .762 .933 r
.77346 .63887 m .78408 .65109 L .80845 .64449 L p F P
0 0 0 r
s
.647 .762 .933 r
.78408 .65109 m .77346 .63887 L .74915 .64551 L p F P
0 0 0 r
s
0 .455 .838 r
.44929 .48092 m .46254 .48951 L .48536 .49774 L p F P
0 0 0 r
s
.647 .762 .933 r
.44061 .63835 m .45383 .65059 L .47681 .64398 L p F P
0 0 0 r
s
.647 .762 .933 r
.45383 .65059 m .44061 .63835 L .41771 .645 L p F P
0 0 0 r
s
.647 .762 .933 r
.83302 .63784 m .84319 .65008 L .86782 .64347 L p F P
0 0 0 r
s
.647 .762 .933 r
.84319 .65008 m .83302 .63784 L .80845 .64449 L p F P
0 0 0 r
s
.759 .844 .916 r
.74473 .3658 m .75531 .37601 L .77908 .36208 L p F P
0 0 0 r
s
.785 .882 .916 r
.75531 .37601 m .74473 .3658 L .72109 .38339 L p F P
0 0 0 r
s
.674 .755 .912 r
.89642 .34836 m .88669 .33404 L .86199 .3429 L p F P
0 0 0 r
s
.647 .762 .933 r
.49998 .63732 m .51274 .64958 L .53598 .64296 L p F P
0 0 0 r
s
.647 .762 .933 r
.51274 .64958 m .49998 .63732 L .47681 .64398 L p F P
0 0 0 r
s
.687 .768 .913 r
.82741 .33875 m .83753 .3523 L .86199 .3429 L p F P
0 0 0 r
s
.7 .785 .917 r
.83753 .3523 m .82741 .33875 L .80311 .34974 L p F P
0 0 0 r
s
.642 .73 .912 r
.161 .33398 m .17634 .34904 L .19805 .34227 L p F P
0 0 0 r
s
.651 .735 .911 r
.17634 .34904 m .161 .33398 L .13932 .34145 L p F P
0 0 0 r
s
.4 .58 .913 r
.34239 .4036 m .32861 .38399 L .30683 .38196 L p F P
0 0 0 r
s
.455 .601 .907 r
.29276 .36343 m .30683 .38196 L .32861 .38399 L p F P
0 0 0 r
s
.503 .644 .919 r
.30683 .38196 m .29276 .36343 L .27097 .36508 L p F P
0 0 0 r
s
.647 .762 .933 r
.89266 .63681 m .90238 .64907 L .92727 .64245 L p F P
0 0 0 r
s
.647 .762 .933 r
.90238 .64907 m .89266 .63681 L .86782 .64347 L p F P
0 0 0 r
s
.539 .66 .914 r
.25654 .34784 m .27097 .36508 L .29276 .36343 L p F P
0 0 0 r
s
.575 .689 .919 r
.27097 .36508 m .25654 .34784 L .23472 .35225 L p F P
0 0 0 r
s
.647 .762 .933 r
.55942 .63629 m .57173 .64856 L .59524 .64194 L p F P
0 0 0 r
s
.647 .762 .933 r
.57173 .64856 m .55942 .63629 L .53598 .64296 L p F P
0 0 0 r
s
.647 .762 .933 r
.22596 .63578 m .24087 .64806 L .26298 .64143 L p F P
0 0 0 r
s
.647 .762 .933 r
.61894 .63526 m .63079 .64755 L .65457 .64092 L p F P
0 0 0 r
s
.647 .762 .933 r
.63079 .64755 m .61894 .63526 L .59524 .64194 L p F P
0 0 0 r
s
.274 .507 .897 r
.37785 .42932 m .36427 .40966 L .34239 .4036 L p F P
0 0 0 r
s
.35 .53 .892 r
.32861 .38399 m .34239 .4036 L .36427 .40966 L p F P
0 0 0 r
s
.647 .762 .933 r
.28529 .63475 m .29974 .64704 L .32212 .6404 L p F P
0 0 0 r
s
.647 .762 .933 r
.29974 .64704 m .28529 .63475 L .26298 .64143 L p F P
0 0 0 r
s
.504 .908 .813 r
.56846 .49507 m .5805 .49216 L .60396 .47998 L p F P
0 0 0 r
s
.256 .76 .729 r
.5805 .49216 m .56846 .49507 L .54484 .50238 L p F P
0 0 0 r
s
.647 .762 .933 r
.67854 .63423 m .68994 .64653 L .71397 .63989 L p F P
0 0 0 r
s
.647 .762 .933 r
.68994 .64653 m .67854 .63423 L .65457 .64092 L p F P
0 0 0 r
s
.733 .813 .914 r
.7686 .35031 m .77908 .36208 L .80311 .34974 L p F P
0 0 0 r
s
.759 .844 .916 r
.77908 .36208 m .7686 .35031 L .74473 .3658 L p F P
0 0 0 r
s
.597 .699 .915 r
.2199 .33607 m .23472 .35225 L .25654 .34784 L p F P
0 0 0 r
s
.618 .716 .915 r
.23472 .35225 m .2199 .33607 L .19805 .34227 L p F P
0 0 0 r
s
.647 .762 .933 r
.34469 .63371 m .35868 .64602 L .38133 .63938 L p F P
0 0 0 r
s
.647 .762 .933 r
.35868 .64602 m .34469 .63371 L .32212 .6404 L p F P
0 0 0 r
s
.647 .762 .933 r
.73822 .6332 m .74915 .64551 L .77346 .63887 L p F P
0 0 0 r
s
.647 .762 .933 r
.74915 .64551 m .73822 .6332 L .71397 .63989 L p F P
0 0 0 r
s
.647 .762 .933 r
.40416 .63268 m .41771 .645 L .44061 .63835 L p F P
0 0 0 r
s
.647 .762 .933 r
.41771 .645 m .40416 .63268 L .38133 .63938 L p F P
0 0 0 r
s
.647 .762 .933 r
.79797 .63216 m .80845 .64449 L .83302 .63784 L p F P
0 0 0 r
s
.647 .762 .933 r
.80845 .64449 m .79797 .63216 L .77346 .63887 L p F P
0 0 0 r
s
.654 .737 .91 r
.12361 .32654 m .13932 .34145 L .161 .33398 L p F P
0 0 0 r
s
.647 .762 .933 r
.46372 .63164 m .47681 .64398 L .49998 .63732 L p F P
0 0 0 r
s
.647 .762 .933 r
.47681 .64398 m .46372 .63164 L .44061 .63835 L p F P
0 0 0 r
s
.143 .445 .879 r
.41344 .45654 m .39996 .43871 L .37785 .42932 L p F P
0 0 0 r
s
.246 .469 .876 r
.36427 .40966 m .37785 .42932 L .39996 .43871 L p F P
0 0 0 r
s
.678 .758 .911 r
.85198 .32878 m .86199 .3429 L .88669 .33404 L p F P
0 0 0 r
s
.687 .768 .913 r
.86199 .3429 m .85198 .32878 L .82741 .33875 L p F P
0 0 0 r
s
.647 .762 .933 r
.85781 .63112 m .86782 .64347 L .89266 .63681 L p F P
0 0 0 r
s
.647 .762 .933 r
.86782 .64347 m .85781 .63112 L .83302 .63784 L p F P
0 0 0 r
s
.647 .762 .933 r
.52335 .63061 m .53598 .64296 L .55942 .63629 L p F P
0 0 0 r
s
.647 .762 .933 r
.53598 .64296 m .52335 .63061 L .49998 .63732 L p F P
0 0 0 r
s
0 .522 .753 r
.52142 .50388 m .50862 .50229 L .48536 .49774 L p F P
0 0 0 r
s
.177 .707 .85 r
.50862 .50229 m .52142 .50388 L .54484 .50238 L p F P
0 0 0 r
s
.647 .762 .933 r
.91772 .63009 m .92727 .64245 L .95238 .63578 L p F P
0 0 0 r
s
.647 .762 .933 r
.92727 .64245 m .91772 .63009 L .89266 .63681 L p F P
0 0 0 r
s
.69 .981 .859 r
.59217 .48191 m .60396 .47998 L .62741 .46357 L p F P
0 0 0 r
s
.504 .908 .813 r
.60396 .47998 m .59217 .48191 L .56846 .49507 L p F P
0 0 0 r
s
.631 .722 .913 r
.18285 .32676 m .19805 .34227 L .2199 .33607 L p F P
0 0 0 r
s
.642 .73 .912 r
.19805 .34227 m .18285 .32676 L .161 .33398 L p F P
0 0 0 r
s
.647 .762 .933 r
.58306 .62957 m .59524 .64194 L .61894 .63526 L p F P
0 0 0 r
s
.647 .762 .933 r
.59524 .64194 m .58306 .62957 L .55942 .63629 L p F P
0 0 0 r
s
.711 .789 .912 r
.79272 .33682 m .80311 .34974 L .82741 .33875 L p F P
0 0 0 r
s
.733 .813 .914 r
.80311 .34974 m .79272 .33682 L .7686 .35031 L p F P
0 0 0 r
s
.647 .762 .933 r
.24819 .62905 m .26298 .64143 L .28529 .63475 L p F P
0 0 0 r
s
.647 .762 .933 r
.26298 .64143 m .24819 .62905 L .22596 .63578 L p F P
0 0 0 r
s
.647 .762 .933 r
.64285 .62853 m .65457 .64092 L .67854 .63423 L p F P
0 0 0 r
s
.647 .762 .933 r
.65457 .64092 m .64285 .62853 L .61894 .63526 L p F P
0 0 0 r
s
.647 .762 .933 r
.30778 .62801 m .32212 .6404 L .34469 .63371 L p F P
0 0 0 r
s
.647 .762 .933 r
.32212 .6404 m .30778 .62801 L .28529 .63475 L p F P
0 0 0 r
s
.794 .993 .876 r
.61586 .46378 m .62741 .46357 L .65083 .44423 L p F P
0 0 0 r
s
.69 .981 .859 r
.62741 .46357 m .61586 .46378 L .59217 .48191 L p F P
0 0 0 r
s
.647 .762 .933 r
.70272 .62749 m .71397 .63989 L .73822 .6332 L p F P
0 0 0 r
s
.647 .762 .933 r
.71397 .63989 m .70272 .62749 L .67854 .63423 L p F P
0 0 0 r
s
.028 .422 .864 r
.44929 .48092 m .43592 .46723 L .41344 .45654 L p F P
0 0 0 r
s
.165 .444 .876 r
.39996 .43871 m .41344 .45654 L .43592 .46723 L p F P
0 0 0 r
s
.647 .762 .933 r
.36745 .62696 m .38133 .63938 L .40416 .63268 L p F P
0 0 0 r
s
.647 .762 .933 r
.38133 .63938 m .36745 .62696 L .34469 .63371 L p F P
0 0 0 r
s
.455 .601 .907 r
.32861 .38399 m .3147 .36351 L .29276 .36343 L p F P
0 0 0 r
s
.503 .625 .904 r
.2785 .34467 m .29276 .36343 L .3147 .36351 L p F P
0 0 0 r
s
.539 .66 .914 r
.29276 .36343 m .2785 .34467 L .25654 .34784 L p F P
0 0 0 r
s
.838 .974 .881 r
.63949 .44221 m .65083 .44423 L .67421 .4235 L p F P
0 0 0 r
s
.794 .993 .876 r
.65083 .44423 m .63949 .44221 L .61586 .46378 L p F P
0 0 0 r
s
.647 .762 .933 r
.76267 .62644 m .77346 .63887 L .79797 .63216 L p F P
0 0 0 r
s
.647 .762 .933 r
.77346 .63887 m .76267 .62644 L .73822 .6332 L p F P
0 0 0 r
s
.845 .942 .885 r
.66305 .41904 m .67421 .4235 L .69761 .40285 L p F P
0 0 0 r
s
.838 .974 .881 r
.67421 .4235 m .66305 .41904 L .63949 .44221 L p F P
0 0 0 r
s
.647 .762 .933 r
.4272 .62592 m .44061 .63835 L .46372 .63164 L p F P
0 0 0 r
s
.647 .762 .933 r
.44061 .63835 m .4272 .62592 L .40416 .63268 L p F P
0 0 0 r
s
.831 .907 .89 r
.68659 .39599 m .69761 .40285 L .72109 .38339 L p F P
0 0 0 r
s
.845 .942 .885 r
.69761 .40285 m .68659 .39599 L .66305 .41904 L p F P
0 0 0 r
s
.35 .53 .892 r
.36427 .40966 m .35061 .38796 L .32861 .38399 L p F P
0 0 0 r
s
.418 .558 .888 r
.3147 .36351 m .32861 .38399 L .35061 .38796 L p F P
0 0 0 r
s
.571 .677 .911 r
.24189 .33062 m .25654 .34784 L .2785 .34467 L p F P
0 0 0 r
s
.597 .699 .915 r
.25654 .34784 m .24189 .33062 L .2199 .33607 L p F P
0 0 0 r
s
.647 .762 .933 r
.82269 .6254 m .83302 .63784 L .85781 .63112 L p F P
0 0 0 r
s
.647 .762 .933 r
.83302 .63784 m .82269 .6254 L .79797 .63216 L p F P
0 0 0 r
s
.806 .872 .896 r
.71019 .37437 m .72109 .38339 L .74473 .3658 L p F P
0 0 0 r
s
.831 .907 .89 r
.72109 .38339 m .71019 .37437 L .68659 .39599 L p F P
0 0 0 r
s
.649 .733 .911 r
.14541 .31879 m .161 .33398 L .18285 .32676 L p F P
0 0 0 r
s
.654 .737 .91 r
.161 .33398 m .14541 .31879 L .12361 .32654 L p F P
0 0 0 r
s
.678 .758 .911 r
.88669 .33404 m .87682 .31952 L .85198 .32878 L p F P
0 0 0 r
s
.647 .762 .933 r
.48702 .62488 m .49998 .63732 L .52335 .63061 L p F P
0 0 0 r
s
.647 .762 .933 r
.49998 .63732 m .48702 .62488 L .46372 .63164 L p F P
0 0 0 r
s
.125 .594 .919 r
.47219 .48997 m .48536 .49774 L .50862 .50229 L p F P
0 0 0 r
s
0 .455 .838 r
.48536 .49774 m .47219 .48997 L .44929 .48092 L p F P
0 0 0 r
s
.647 .762 .933 r
.8828 .62435 m .89266 .63681 L .91772 .63009 L p F P
0 0 0 r
s
.647 .762 .933 r
.89266 .63681 m .8828 .62435 L .85781 .63112 L p F P
0 0 0 r
s
.694 .771 .911 r
.81713 .32499 m .82741 .33875 L .85198 .32878 L p F P
0 0 0 r
s
.711 .789 .912 r
.82741 .33875 m .81713 .32499 L .79272 .33682 L p F P
0 0 0 r
s
.121 .484 .9 r
.43592 .46723 m .44929 .48092 L .47219 .48997 L p F P
0 0 0 r
s
.647 .762 .933 r
.54692 .62383 m .55942 .63629 L .58306 .62957 L p F P
0 0 0 r
s
.647 .762 .933 r
.55942 .63629 m .54692 .62383 L .52335 .63061 L p F P
0 0 0 r
s
.647 .762 .933 r
.94298 .62331 m .95238 .63578 L .97771 .62905 L p F P
0 0 0 r
s
.647 .762 .933 r
.95238 .63578 m .94298 .62331 L .91772 .63009 L p F P
0 0 0 r
s
.647 .762 .933 r
.21083 .62331 m .22596 .63578 L .24819 .62905 L p F P
0 0 0 r
s
.776 .84 .9 r
.73394 .35497 m .74473 .3658 L .7686 .35031 L p F P
0 0 0 r
s
.806 .872 .896 r
.74473 .3658 m .73394 .35497 L .71019 .37437 L p F P
0 0 0 r
s
.647 .762 .933 r
.60691 .62278 m .61894 .63526 L .64285 .62853 L p F P
0 0 0 r
s
.647 .762 .933 r
.61894 .63526 m .60691 .62278 L .58306 .62957 L p F P
0 0 0 r
s
.647 .762 .933 r
.27061 .62226 m .28529 .63475 L .30778 .62801 L p F P
0 0 0 r
s
.647 .762 .933 r
.28529 .63475 m .27061 .62226 L .24819 .62905 L p F P
0 0 0 r
s
.615 .709 .912 r
.20484 .31991 m .2199 .33607 L .24189 .33062 L p F P
0 0 0 r
s
.631 .722 .913 r
.2199 .33607 m .20484 .31991 L .18285 .32676 L p F P
0 0 0 r
s
.647 .762 .933 r
.66697 .62173 m .67854 .63423 L .70272 .62749 L p F P
0 0 0 r
s
.647 .762 .933 r
.67854 .63423 m .66697 .62173 L .64285 .62853 L p F P
0 0 0 r
s
.246 .469 .876 r
.39996 .43871 m .38645 .41726 L .36427 .40966 L p F P
0 0 0 r
s
.334 .496 .87 r
.35061 .38796 m .36427 .40966 L .38645 .41726 L p F P
0 0 0 r
s
.647 .762 .933 r
.33047 .62121 m .34469 .63371 L .36745 .62696 L p F P
0 0 0 r
s
.647 .762 .933 r
.34469 .63371 m .33047 .62121 L .30778 .62801 L p F P
0 0 0 r
s
.461 .881 .926 r
.53223 .50139 m .54484 .50238 L .56846 .49507 L p F P
0 0 0 r
s
.177 .707 .85 r
.54484 .50238 m .53223 .50139 L .50862 .50229 L p F P
0 0 0 r
s
.647 .762 .933 r
.72711 .62068 m .73822 .6332 L .76267 .62644 L p F P
0 0 0 r
s
.647 .762 .933 r
.73822 .6332 m .72711 .62068 L .70272 .62749 L p F P
0 0 0 r
s
.647 .762 .933 r
.39041 .62016 m .40416 .63268 L .4272 .62592 L p F P
0 0 0 r
s
.647 .762 .933 r
.40416 .63268 m .39041 .62016 L .36745 .62696 L p F P
0 0 0 r
s
.747 .812 .904 r
.75791 .33806 m .7686 .35031 L .79272 .33682 L p F P
0 0 0 r
s
.776 .84 .9 r
.7686 .35031 m .75791 .33806 L .73394 .35497 L p F P
0 0 0 r
s
.647 .762 .933 r
.78733 .61963 m .79797 .63216 L .82269 .6254 L p F P
0 0 0 r
s
.647 .762 .933 r
.79797 .63216 m .78733 .61963 L .76267 .62644 L p F P
0 0 0 r
s
.657 .739 .91 r
.10764 .31146 m .12361 .32654 L .14541 .31879 L p F P
0 0 0 r
s
.647 .762 .933 r
.45043 .61911 m .46372 .63164 L .48702 .62488 L p F P
0 0 0 r
s
.647 .762 .933 r
.46372 .63164 m .45043 .61911 L .4272 .62592 L p F P
0 0 0 r
s
.647 .762 .933 r
.84763 .61858 m .85781 .63112 L .8828 .62435 L p F P
0 0 0 r
s
.647 .762 .933 r
.85781 .63112 m .84763 .61858 L .82269 .6254 L p F P
0 0 0 r
s
.682 .759 .91 r
.84182 .31444 m .85198 .32878 L .87682 .31952 L p F P
0 0 0 r
s
.694 .771 .911 r
.85198 .32878 m .84182 .31444 L .81713 .32499 L p F P
0 0 0 r
s
.647 .762 .933 r
.51052 .61805 m .52335 .63061 L .54692 .62383 L p F P
0 0 0 r
s
.647 .762 .933 r
.52335 .63061 m .51052 .61805 L .48702 .62488 L p F P
0 0 0 r
s
.641 .727 .911 r
.16739 .31118 m .18285 .32676 L .20484 .31991 L p F P
0 0 0 r
s
.649 .733 .911 r
.18285 .32676 m .16739 .31118 L .14541 .31879 L p F P
0 0 0 r
s
.647 .762 .933 r
.90801 .61752 m .91772 .63009 L .94298 .62331 L p F P
0 0 0 r
s
.647 .762 .933 r
.91772 .63009 m .90801 .61752 L .8828 .62435 L p F P
0 0 0 r
s
.647 .762 .933 r
.5707 .617 m .58306 .62957 L .60691 .62278 L p F P
0 0 0 r
s
.647 .762 .933 r
.58306 .62957 m .5707 .617 L .54692 .62383 L p F P
0 0 0 r
s
.647 .762 .933 r
.97771 .62905 m .96847 .61647 L .94298 .62331 L p F P
0 0 0 r
s
.647 .762 .933 r
.23317 .61647 m .24819 .62905 L .27061 .62226 L p F P
0 0 0 r
s
.647 .762 .933 r
.24819 .62905 m .23317 .61647 L .21083 .62331 L p F P
0 0 0 r
s
.165 .444 .876 r
.43592 .46723 m .42249 .44839 L .39996 .43871 L p F P
0 0 0 r
s
.275 .464 .864 r
.38645 .41726 m .39996 .43871 L .42249 .44839 L p F P
0 0 0 r
s
.503 .625 .904 r
.3147 .36351 m .30062 .34283 L .2785 .34467 L p F P
0 0 0 r
s
.544 .648 .902 r
.26403 .32606 m .2785 .34467 L .30062 .34283 L p F P
0 0 0 r
s
.571 .677 .911 r
.2785 .34467 m .26403 .32606 L .24189 .33062 L p F P
0 0 0 r
s
.721 .789 .906 r
.78214 .32349 m .79272 .33682 L .81713 .32499 L p F P
0 0 0 r
s
.747 .812 .904 r
.79272 .33682 m .78214 .32349 L .75791 .33806 L p F P
0 0 0 r
s
.647 .762 .933 r
.63096 .61594 m .64285 .62853 L .66697 .62173 L p F P
0 0 0 r
s
.647 .762 .933 r
.64285 .62853 m .63096 .61594 L .60691 .62278 L p F P
0 0 0 r
s
.418 .558 .888 r
.35061 .38796 m .33685 .36516 L .3147 .36351 L p F P
0 0 0 r
s
.475 .588 .887 r
.30062 .34283 m .3147 .36351 L .33685 .36516 L p F P
0 0 0 r
s
.647 .762 .933 r
.29322 .61541 m .30778 .62801 L .33047 .62121 L p F P
0 0 0 r
s
.647 .762 .933 r
.30778 .62801 m .29322 .61541 L .27061 .62226 L p F P
0 0 0 r
s
.647 .762 .933 r
.69129 .61488 m .70272 .62749 L .72711 .62068 L p F P
0 0 0 r
s
.647 .762 .933 r
.70272 .62749 m .69129 .61488 L .66697 .62173 L p F P
0 0 0 r
s
.647 .762 .933 r
.35335 .61435 m .36745 .62696 L .39041 .62016 L p F P
0 0 0 r
s
.647 .762 .933 r
.36745 .62696 m .35335 .61435 L .33047 .62121 L p F P
0 0 0 r
s
.597 .692 .909 r
.22699 .31355 m .24189 .33062 L .26403 .32606 L p F P
0 0 0 r
s
.615 .709 .912 r
.24189 .33062 m .22699 .31355 L .20484 .31991 L p F P
0 0 0 r
s
.679 .964 .935 r
.55608 .49399 m .56846 .49507 L .59217 .48191 L p F P
0 0 0 r
s
.461 .881 .926 r
.56846 .49507 m .55608 .49399 L .53223 .50139 L p F P
0 0 0 r
s
.647 .762 .933 r
.75171 .61382 m .76267 .62644 L .78733 .61963 L p F P
0 0 0 r
s
.647 .762 .933 r
.76267 .62644 m .75171 .61382 L .72711 .62068 L p F P
0 0 0 r
s
.647 .762 .933 r
.41356 .61329 m .4272 .62592 L .45043 .61911 L p F P
0 0 0 r
s
.647 .762 .933 r
.4272 .62592 m .41356 .61329 L .39041 .62016 L p F P
0 0 0 r
s
.647 .762 .933 r
.8122 .61276 m .82269 .6254 L .84763 .61858 L p F P
0 0 0 r
s
.647 .762 .933 r
.82269 .6254 m .8122 .61276 L .78733 .61963 L p F P
0 0 0 r
s
.334 .496 .87 r
.38645 .41726 m .3729 .39322 L .35061 .38796 L p F P
0 0 0 r
s
.406 .525 .866 r
.33685 .36516 m .35061 .38796 L .3729 .39322 L p F P
0 0 0 r
s
.654 .736 .91 r
.12957 .30346 m .14541 .31879 L .16739 .31118 L p F P
0 0 0 r
s
.657 .739 .91 r
.14541 .31879 m .12957 .30346 L .10764 .31146 L p F P
0 0 0 r
s
.647 .762 .933 r
.47386 .61223 m .48702 .62488 L .51052 .61805 L p F P
0 0 0 r
s
.647 .762 .933 r
.48702 .62488 m .47386 .61223 L .45043 .61911 L p F P
0 0 0 r
s
.682 .759 .91 r
.87682 .31952 m .86679 .30477 L .84182 .31444 L p F P
0 0 0 r
s
.383 .759 .991 r
.49557 .49513 m .50862 .50229 L .53223 .50139 L p F P
0 0 0 r
s
.125 .594 .919 r
.50862 .50229 m .49557 .49513 L .47219 .48997 L p F P
0 0 0 r
s
.647 .762 .933 r
.87278 .6117 m .8828 .62435 L .90801 .61752 L p F P
0 0 0 r
s
.647 .762 .933 r
.8828 .62435 m .87278 .6117 L .84763 .61858 L p F P
0 0 0 r
s
.121 .484 .9 r
.47219 .48997 m .45889 .47622 L .43592 .46723 L p F P
0 0 0 r
s
.26 .489 .888 r
.42249 .44839 m .43592 .46723 L .45889 .47622 L p F P
0 0 0 r
s
.647 .762 .933 r
.53423 .61117 m .54692 .62383 L .5707 .617 L p F P
0 0 0 r
s
.647 .762 .933 r
.54692 .62383 m .53423 .61117 L .51052 .61805 L p F P
0 0 0 r
s
.7 .772 .907 r
.80666 .31089 m .81713 .32499 L .84182 .31444 L p F P
0 0 0 r
s
.721 .789 .906 r
.81713 .32499 m .80666 .31089 L .78214 .32349 L p F P
0 0 0 r
s
.647 .762 .933 r
.93343 .61064 m .94298 .62331 L .96847 .61647 L p F P
0 0 0 r
s
.647 .762 .933 r
.94298 .62331 m .93343 .61064 L .90801 .61752 L p F P
0 0 0 r
s
.647 .762 .933 r
.19545 .61064 m .21083 .62331 L .23317 .61647 L p F P
0 0 0 r
s
.63 .718 .91 r
.18953 .30379 m .20484 .31991 L .22699 .31355 L p F P
0 0 0 r
s
.641 .727 .911 r
.20484 .31991 m .18953 .30379 L .16739 .31118 L p F P
0 0 0 r
s
.647 .762 .933 r
.59468 .6101 m .60691 .62278 L .63096 .61594 L p F P
0 0 0 r
s
.647 .762 .933 r
.60691 .62278 m .59468 .6101 L .5707 .617 L p F P
0 0 0 r
s
.799 .974 .907 r
.58002 .48005 m .59217 .48191 L .61586 .46378 L p F P
0 0 0 r
s
.679 .964 .935 r
.59217 .48191 m .58002 .48005 L .55608 .49399 L p F P
0 0 0 r
s
.647 .762 .933 r
.2557 .60957 m .27061 .62226 L .29322 .61541 L p F P
0 0 0 r
s
.647 .762 .933 r
.27061 .62226 m .2557 .60957 L .23317 .61647 L p F P
0 0 0 r
s
.845 .875 .864 r
.67526 .38717 m .68659 .39599 L .71019 .37437 L p F P
0 0 0 r
s
.862 .901 .859 r
.68659 .39599 m .67526 .38717 L .65155 .41211 L p F P
0 0 0 r
s
.862 .901 .859 r
.65155 .41211 m .66305 .41904 L .68659 .39599 L p F P
0 0 0 r
s
.818 .85 .873 r
.69901 .36385 m .71019 .37437 L .73394 .35497 L p F P
0 0 0 r
s
.845 .875 .864 r
.71019 .37437 m .69901 .36385 L .67526 .38717 L p F P
0 0 0 r
s
.298 .591 .945 r
.45889 .47622 m .47219 .48997 L .49557 .49513 L p F P
0 0 0 r
s
.647 .762 .933 r
.65521 .60904 m .66697 .62173 L .69129 .61488 L p F P
0 0 0 r
s
.647 .762 .933 r
.66697 .62173 m .65521 .60904 L .63096 .61594 L p F P
0 0 0 r
s
.867 .927 .863 r
.66305 .41904 m .65155 .41211 L .62779 .43721 L p F P
0 0 0 r
s
.867 .927 .863 r
.62779 .43721 m .63949 .44221 L .66305 .41904 L p F P
0 0 0 r
s
.647 .762 .933 r
.31603 .6085 m .33047 .62121 L .35335 .61435 L p F P
0 0 0 r
s
.647 .762 .933 r
.33047 .62121 m .31603 .6085 L .29322 .61541 L p F P
0 0 0 r
s
.788 .826 .882 r
.72289 .34302 m .73394 .35497 L .75791 .33806 L p F P
0 0 0 r
s
.818 .85 .873 r
.73394 .35497 m .72289 .34302 L .69901 .36385 L p F P
0 0 0 r
s
.851 .954 .879 r
.60395 .46054 m .61586 .46378 L .63949 .44221 L p F P
0 0 0 r
s
.799 .974 .907 r
.61586 .46378 m .60395 .46054 L .58002 .48005 L p F P
0 0 0 r
s
.851 .954 .879 r
.63949 .44221 m .62779 .43721 L .60395 .46054 L p F P
0 0 0 r
s
.647 .762 .933 r
.71582 .60797 m .72711 .62068 L .75171 .61382 L p F P
0 0 0 r
s
.647 .762 .933 r
.72711 .62068 m .71582 .60797 L .69129 .61488 L p F P
0 0 0 r
s
.647 .762 .933 r
.37643 .60744 m .39041 .62016 L .41356 .61329 L p F P
0 0 0 r
s
.647 .762 .933 r
.39041 .62016 m .37643 .60744 L .35335 .61435 L p F P
0 0 0 r
s
.275 .464 .864 r
.42249 .44839 m .40904 .4251 L .38645 .41726 L p F P
0 0 0 r
s
.359 .484 .85 r
.3729 .39322 m .38645 .41726 L .40904 .4251 L p F P
0 0 0 r
s
.647 .762 .933 r
.77652 .6069 m .78733 .61963 L .8122 .61276 L p F P
0 0 0 r
s
.647 .762 .933 r
.78733 .61963 m .77652 .6069 L .75171 .61382 L p F P
0 0 0 r
s
.659 .74 .909 r
.09142 .29617 m .10764 .31146 L .12957 .30346 L p F P
0 0 0 r
s
.647 .762 .933 r
.43692 .60637 m .45043 .61911 L .47386 .61223 L p F P
0 0 0 r
s
.647 .762 .933 r
.45043 .61911 m .43692 .60637 L .41356 .61329 L p F P
0 0 0 r
s
.475 .588 .887 r
.33685 .36516 m .32294 .34217 L .30062 .34283 L p F P
0 0 0 r
s
.524 .618 .888 r
.28633 .32245 m .30062 .34283 L .32294 .34217 L p F P
0 0 0 r
s
.544 .648 .902 r
.30062 .34283 m .28633 .32245 L .26403 .32606 L p F P
0 0 0 r
s
.756 .804 .891 r
.74699 .32497 m .75791 .33806 L .78214 .32349 L p F P
0 0 0 r
s
.788 .826 .882 r
.75791 .33806 m .74699 .32497 L .72289 .34302 L p F P
0 0 0 r
s
.647 .762 .933 r
.83729 .60583 m .84763 .61858 L .87278 .6117 L p F P
0 0 0 r
s
.647 .762 .933 r
.84763 .61858 m .83729 .60583 L .8122 .61276 L p F P
0 0 0 r
s
.578 .671 .902 r
.2493 .30781 m .26403 .32606 L .28633 .32245 L p F P
0 0 0 r
s
.597 .692 .909 r
.26403 .32606 m .2493 .30781 L .22699 .31355 L p F P
0 0 0 r
s
.686 .76 .908 r
.83148 .29979 m .84182 .31444 L .86679 .30477 L p F P
0 0 0 r
s
.7 .772 .907 r
.84182 .31444 m .83148 .29979 L .80666 .31089 L p F P
0 0 0 r
s
.647 .762 .933 r
.49749 .6053 m .51052 .61805 L .53423 .61117 L p F P
0 0 0 r
s
.647 .762 .933 r
.51052 .61805 m .49749 .6053 L .47386 .61223 L p F P
0 0 0 r
s
.648 .732 .91 r
.15166 .29552 m .16739 .31118 L .18953 .30379 L p F P
0 0 0 r
s
.654 .736 .91 r
.16739 .31118 m .15166 .29552 L .12957 .30346 L p F P
0 0 0 r
s
.647 .762 .933 r
.89814 .60476 m .90801 .61752 L .93343 .61064 L p F P
0 0 0 r
s
.647 .762 .933 r
.90801 .61752 m .89814 .60476 L .87278 .6117 L p F P
0 0 0 r
s
.647 .762 .933 r
.55814 .60423 m .5707 .617 L .59468 .6101 L p F P
0 0 0 r
s
.647 .762 .933 r
.5707 .617 m .55814 .60423 L .53423 .61117 L p F P
0 0 0 r
s
.406 .525 .866 r
.3729 .39322 m .35927 .36783 L .33685 .36516 L p F P
0 0 0 r
s
.465 .558 .865 r
.32294 .34217 m .33685 .36516 L .35927 .36783 L p F P
0 0 0 r
s
.647 .762 .933 r
.96847 .61647 m .95908 .60369 L .93343 .61064 L p F P
0 0 0 r
s
.647 .762 .933 r
.2179 .60369 m .23317 .61647 L .2557 .60957 L p F P
0 0 0 r
s
.647 .762 .933 r
.23317 .61647 m .2179 .60369 L .19545 .61064 L p F P
0 0 0 r
s
.647 .762 .933 r
.61887 .60315 m .63096 .61594 L .65521 .60904 L p F P
0 0 0 r
s
.647 .762 .933 r
.63096 .61594 m .61887 .60315 L .59468 .6101 L p F P
0 0 0 r
s
.647 .762 .933 r
.27843 .60261 m .29322 .61541 L .31603 .6085 L p F P
0 0 0 r
s
.647 .762 .933 r
.29322 .61541 m .27843 .60261 L .2557 .60957 L p F P
0 0 0 r
s
.729 .785 .898 r
.77135 .30955 m .78214 .32349 L .80666 .31089 L p F P
0 0 0 r
s
.756 .804 .891 r
.78214 .32349 m .77135 .30955 L .74699 .32497 L p F P
0 0 0 r
s
.618 .706 .908 r
.21183 .2967 m .22699 .31355 L .2493 .30781 L p F P
0 0 0 r
s
.63 .718 .91 r
.22699 .31355 m .21183 .2967 L .18953 .30379 L p F P
0 0 0 r
s
.647 .762 .933 r
.67968 .60208 m .69129 .61488 L .71582 .60797 L p F P
0 0 0 r
s
.647 .762 .933 r
.69129 .61488 m .67968 .60208 L .65521 .60904 L p F P
0 0 0 r
s
.615 .863 .99 r
.51933 .49452 m .53223 .50139 L .55608 .49399 L p F P
0 0 0 r
s
.383 .759 .991 r
.53223 .50139 m .51933 .49452 L .49557 .49513 L p F P
0 0 0 r
s
.647 .762 .933 r
.33903 .60154 m .35335 .61435 L .37643 .60744 L p F P
0 0 0 r
s
.647 .762 .933 r
.35335 .61435 m .33903 .60154 L .31603 .6085 L p F P
0 0 0 r
s
.647 .762 .933 r
.74057 .601 m .75171 .61382 L .77652 .6069 L p F P
0 0 0 r
s
.647 .762 .933 r
.75171 .61382 m .74057 .601 L .71582 .60797 L p F P
0 0 0 r
s
.26 .489 .888 r
.45889 .47622 m .4455 .45644 L .42249 .44839 L p F P
0 0 0 r
s
.354 .489 .856 r
.40904 .4251 m .42249 .44839 L .4455 .45644 L p F P
0 0 0 r
s
.647 .762 .933 r
.39971 .60046 m .41356 .61329 L .43692 .60637 L p F P
0 0 0 r
s
.647 .762 .933 r
.41356 .61329 m .39971 .60046 L .37643 .60744 L p F P
0 0 0 r
s
.647 .762 .933 r
.80154 .59992 m .8122 .61276 L .83729 .60583 L p F P
0 0 0 r
s
.647 .762 .933 r
.8122 .61276 m .80154 .59992 L .77652 .6069 L p F P
0 0 0 r
s
.657 .738 .909 r
.11346 .28797 m .12957 .30346 L .15166 .29552 L p F P
0 0 0 r
s
.659 .74 .909 r
.12957 .30346 m .11346 .28797 L .09142 .29617 L p F P
0 0 0 r
s
.647 .762 .933 r
.46048 .59938 m .47386 .61223 L .49749 .6053 L p F P
0 0 0 r
s
.647 .762 .933 r
.47386 .61223 m .46048 .59938 L .43692 .60637 L p F P
0 0 0 r
s
.359 .484 .85 r
.40904 .4251 m .39557 .39866 L .3729 .39322 L p F P
0 0 0 r
s
.424 .51 .842 r
.35927 .36783 m .3729 .39322 L .39557 .39866 L p F P
0 0 0 r
s
.686 .76 .908 r
.86679 .30477 m .85659 .28974 L .83148 .29979 L p F P
0 0 0 r
s
.647 .762 .933 r
.86259 .59884 m .87278 .6117 L .89814 .60476 L p F P
0 0 0 r
s
.647 .762 .933 r
.87278 .6117 m .86259 .59884 L .83729 .60583 L p F P
0 0 0 r
s
.647 .762 .933 r
.52133 .5983 m .53423 .61117 L .55814 .60423 L p F P
0 0 0 r
s
.647 .762 .933 r
.53423 .61117 m .52133 .5983 L .49749 .6053 L p F P
0 0 0 r
s
.641 .726 .909 r
.17394 .2877 m .18953 .30379 L .21183 .2967 L p F P
0 0 0 r
s
.648 .732 .91 r
.18953 .30379 m .17394 .2877 L .15166 .29552 L p F P
0 0 0 r
s
.647 .762 .933 r
.92373 .59776 m .93343 .61064 L .95908 .60369 L p F P
0 0 0 r
s
.647 .762 .933 r
.93343 .61064 m .92373 .59776 L .89814 .60476 L p F P
0 0 0 r
s
.647 .762 .933 r
.17983 .59776 m .19545 .61064 L .2179 .60369 L p F P
0 0 0 r
s
.706 .77 .902 r
.796 .29633 m .80666 .31089 L .83148 .29979 L p F P
0 0 0 r
s
.729 .785 .898 r
.80666 .31089 m .796 .29633 L .77135 .30955 L p F P
0 0 0 r
s
.647 .762 .933 r
.58225 .59722 m .59468 .6101 L .61887 .60315 L p F P
0 0 0 r
s
.647 .762 .933 r
.59468 .6101 m .58225 .59722 L .55814 .60423 L p F P
0 0 0 r
s
.647 .762 .933 r
.24055 .59668 m .2557 .60957 L .27843 .60261 L p F P
0 0 0 r
s
.647 .762 .933 r
.2557 .60957 m .24055 .59668 L .2179 .60369 L p F P
0 0 0 r
s
.298 .591 .945 r
.49557 .49513 m .48234 .48132 L .45889 .47622 L p F P
0 0 0 r
s
.4 .556 .894 r
.4455 .45644 m .45889 .47622 L .48234 .48132 L p F P
0 0 0 r
s
.647 .762 .933 r
.64326 .59614 m .65521 .60904 L .67968 .60208 L p F P
0 0 0 r
s
.647 .762 .933 r
.65521 .60904 m .64326 .59614 L .61887 .60315 L p F P
0 0 0 r
s
.498 .693 .956 r
.48234 .48132 m .49557 .49513 L .51933 .49452 L p F P
0 0 0 r
s
.524 .618 .888 r
.32294 .34217 m .30882 .31969 L .28633 .32245 L p F P
0 0 0 r
s
.563 .647 .891 r
.27178 .3027 m .28633 .32245 L .30882 .31969 L p F P
0 0 0 r
s
.578 .671 .902 r
.28633 .32245 m .27178 .3027 L .2493 .30781 L p F P
0 0 0 r
s
.647 .762 .933 r
.30135 .5956 m .31603 .6085 L .33903 .60154 L p F P
0 0 0 r
s
.647 .762 .933 r
.31603 .6085 m .30135 .5956 L .27843 .60261 L p F P
0 0 0 r
s
.465 .558 .865 r
.35927 .36783 m .34551 .34227 L .32294 .34217 L p F P
0 0 0 r
s
.515 .591 .869 r
.30882 .31969 m .32294 .34217 L .34551 .34227 L p F P
0 0 0 r
s
.647 .762 .933 r
.70436 .59505 m .71582 .60797 L .74057 .601 L p F P
0 0 0 r
s
.647 .762 .933 r
.71582 .60797 m .70436 .59505 L .67968 .60208 L p F P
0 0 0 r
s
.756 .894 .94 r
.54336 .48702 m .55608 .49399 L .58002 .48005 L p F P
0 0 0 r
s
.615 .863 .99 r
.55608 .49399 m .54336 .48702 L .51933 .49452 L p F P
0 0 0 r
s
.82 .821 .85 r
.68752 .35121 m .69901 .36385 L .72289 .34302 L p F P
0 0 0 r
s
.843 .834 .837 r
.69901 .36385 m .68752 .35121 L .66359 .37554 L p F P
0 0 0 r
s
.843 .834 .837 r
.66359 .37554 m .67526 .38717 L .69901 .36385 L p F P
0 0 0 r
s
.647 .762 .933 r
.36223 .59451 m .37643 .60744 L .39971 .60046 L p F P
0 0 0 r
s
.647 .762 .933 r
.37643 .60744 m .36223 .59451 L .33903 .60154 L p F P
0 0 0 r
s
.792 .807 .865 r
.71156 .32953 m .72289 .34302 L .74699 .32497 L p F P
0 0 0 r
s
.82 .821 .85 r
.72289 .34302 m .71156 .32953 L .68752 .35121 L p F P
0 0 0 r
s
.605 .69 .903 r
.23431 .29 m .2493 .30781 L .27178 .3027 L p F P
0 0 0 r
s
.618 .706 .908 r
.2493 .30781 m .23431 .29 L .21183 .2967 L p F P
0 0 0 r
s
.647 .762 .933 r
.76553 .59397 m .77652 .6069 L .80154 .59992 L p F P
0 0 0 r
s
.647 .762 .933 r
.77652 .6069 m .76553 .59397 L .74057 .601 L p F P
0 0 0 r
s
.661 .741 .909 r
.07493 .28068 m .09142 .29617 L .11346 .28797 L p F P
0 0 0 r
s
.859 .847 .831 r
.67526 .38717 m .66359 .37554 L .63968 .40161 L p F P
0 0 0 r
s
.859 .847 .831 r
.63968 .40161 m .65155 .41211 L .67526 .38717 L p F P
0 0 0 r
s
.647 .762 .933 r
.4232 .59343 m .43692 .60637 L .46048 .59938 L p F P
0 0 0 r
s
.647 .762 .933 r
.43692 .60637 m .4232 .59343 L .39971 .60046 L p F P
0 0 0 r
s
.647 .762 .933 r
.82678 .59288 m .83729 .60583 L .86259 .59884 L p F P
0 0 0 r
s
.647 .762 .933 r
.83729 .60583 m .82678 .59288 L .80154 .59992 L p F P
0 0 0 r
s
.654 .735 .909 r
.13568 .27976 m .15166 .29552 L .17394 .2877 L p F P
0 0 0 r
s
.657 .738 .909 r
.15166 .29552 m .13568 .27976 L .11346 .28797 L p F P
0 0 0 r
s
.354 .489 .856 r
.4455 .45644 m .43209 .43145 L .40904 .4251 L p F P
0 0 0 r
s
.418 .496 .832 r
.39557 .39866 m .40904 .4251 L .43209 .43145 L p F P
0 0 0 r
s
.647 .762 .933 r
.48424 .59234 m .49749 .6053 L .52133 .5983 L p F P
0 0 0 r
s
.647 .762 .933 r
.49749 .6053 m .48424 .59234 L .46048 .59938 L p F P
0 0 0 r
s
.864 .86 .834 r
.65155 .41211 m .63968 .40161 L .61572 .42785 L p F P
0 0 0 r
s
.864 .86 .834 r
.61572 .42785 m .62779 .43721 L .65155 .41211 L p F P
0 0 0 r
s
.761 .792 .878 r
.73582 .31079 m .74699 .32497 L .77135 .30955 L p F P
0 0 0 r
s
.792 .807 .865 r
.74699 .32497 m .73582 .31079 L .71156 .32953 L p F P
0 0 0 r
s
.689 .759 .905 r
.82096 .28478 m .83148 .29979 L .85659 .28974 L p F P
0 0 0 r
s
.706 .77 .902 r
.83148 .29979 m .82096 .28478 L .796 .29633 L p F P
0 0 0 r
s
.647 .762 .933 r
.88812 .59179 m .89814 .60476 L .92373 .59776 L p F P
0 0 0 r
s
.647 .762 .933 r
.89814 .60476 m .88812 .59179 L .86259 .59884 L p F P
0 0 0 r
s
.424 .51 .842 r
.39557 .39866 m .38204 .37061 L .35927 .36783 L p F P
0 0 0 r
s
.476 .539 .842 r
.34551 .34227 m .35927 .36783 L .38204 .37061 L p F P
0 0 0 r
s
.647 .762 .933 r
.54537 .59125 m .55814 .60423 L .58225 .59722 L p F P
0 0 0 r
s
.647 .762 .933 r
.55814 .60423 m .54537 .59125 L .52133 .5983 L p F P
0 0 0 r
s
.826 .889 .888 r
.56752 .47257 m .58002 .48005 L .60395 .46054 L p F P
0 0 0 r
s
.756 .894 .94 r
.58002 .48005 m .56752 .47257 L .54336 .48702 L p F P
0 0 0 r
s
.647 .762 .933 r
.95908 .60369 m .94954 .5907 L .92373 .59776 L p F P
0 0 0 r
s
.647 .762 .933 r
.20239 .5907 m .2179 .60369 L .24055 .59668 L p F P
0 0 0 r
s
.647 .762 .933 r
.2179 .60369 m .20239 .5907 L .17983 .59776 L p F P
0 0 0 r
s
.856 .875 .852 r
.62779 .43721 m .61572 .42785 L .59166 .45223 L p F P
0 0 0 r
s
.856 .875 .852 r
.59166 .45223 m .60395 .46054 L .62779 .43721 L p F P
0 0 0 r
s
.633 .717 .908 r
.19639 .28004 m .21183 .2967 L .23431 .29 L p F P
0 0 0 r
s
.641 .726 .909 r
.21183 .2967 m .19639 .28004 L .17394 .2877 L p F P
0 0 0 r
s
.647 .762 .933 r
.60658 .59016 m .61887 .60315 L .64326 .59614 L p F P
0 0 0 r
s
.647 .762 .933 r
.61887 .60315 m .60658 .59016 L .58225 .59722 L p F P
0 0 0 r
s
.826 .889 .888 r
.60395 .46054 m .59166 .45223 L .56752 .47257 L p F P
0 0 0 r
s
.647 .762 .933 r
.26339 .58961 m .27843 .60261 L .30135 .5956 L p F P
0 0 0 r
s
.647 .762 .933 r
.27843 .60261 m .26339 .58961 L .24055 .59668 L p F P
0 0 0 r
s
.647 .762 .933 r
.66787 .58907 m .67968 .60208 L .70436 .59505 L p F P
0 0 0 r
s
.647 .762 .933 r
.67968 .60208 m .66787 .58907 L .64326 .59614 L p F P
0 0 0 r
s
.733 .778 .889 r
.76033 .29482 m .77135 .30955 L .796 .29633 L p F P
0 0 0 r
s
.761 .792 .878 r
.77135 .30955 m .76033 .29482 L .73582 .31079 L p F P
0 0 0 r
s
.647 .762 .933 r
.32448 .58852 m .33903 .60154 L .36223 .59451 L p F P
0 0 0 r
s
.647 .762 .933 r
.33903 .60154 m .32448 .58852 L .30135 .5956 L p F P
0 0 0 r
s
.647 .762 .933 r
.72925 .58797 m .74057 .601 L .76553 .59397 L p F P
0 0 0 r
s
.647 .762 .933 r
.74057 .601 m .72925 .58797 L .70436 .59505 L p F P
0 0 0 r
s
.647 .762 .933 r
.38564 .58742 m .39971 .60046 L .4232 .59343 L p F P
0 0 0 r
s
.647 .762 .933 r
.39971 .60046 m .38564 .58742 L .36223 .59451 L p F P
0 0 0 r
s
.647 .762 .933 r
.79071 .58688 m .80154 .59992 L .82678 .59288 L p F P
0 0 0 r
s
.647 .762 .933 r
.80154 .59992 m .79071 .58688 L .76553 .59397 L p F P
0 0 0 r
s
.659 .74 .909 r
.09708 .27229 m .11346 .28797 L .13568 .27976 L p F P
0 0 0 r
s
.661 .741 .909 r
.11346 .28797 m .09708 .27229 L .07493 .28068 L p F P
0 0 0 r
s
.647 .762 .933 r
.44689 .58633 m .46048 .59938 L .48424 .59234 L p F P
0 0 0 r
s
.647 .762 .933 r
.46048 .59938 m .44689 .58633 L .4232 .59343 L p F P
0 0 0 r
s
.515 .591 .869 r
.34551 .34227 m .33156 .31746 L .30882 .31969 L p F P
0 0 0 r
s
.555 .624 .875 r
.29446 .29816 m .30882 .31969 L .33156 .31746 L p F P
0 0 0 r
s
.563 .647 .891 r
.30882 .31969 m .29446 .29816 L .27178 .3027 L p F P
0 0 0 r
s
.4 .556 .894 r
.48234 .48132 m .469 .46077 L .4455 .45644 L p F P
0 0 0 r
s
.457 .531 .845 r
.43209 .43145 m .4455 .45644 L .469 .46077 L p F P
0 0 0 r
s
.689 .759 .905 r
.85659 .28974 m .84622 .2744 L .82096 .28478 L p F P
0 0 0 r
s
.647 .762 .933 r
.85225 .58578 m .86259 .59884 L .88812 .59179 L p F P
0 0 0 r
s
.647 .762 .933 r
.86259 .59884 m .85225 .58578 L .82678 .59288 L p F P
0 0 0 r
s
.653 .755 .924 r
.50621 .48061 m .51933 .49452 L .54336 .48702 L p F P
0 0 0 r
s
.498 .693 .956 r
.51933 .49452 m .50621 .48061 L .48234 .48132 L p F P
0 0 0 r
s
.418 .496 .832 r
.43209 .43145 m .41867 .40279 L .39557 .39866 L p F P
0 0 0 r
s
.466 .511 .82 r
.38204 .37061 m .39557 .39866 L .41867 .40279 L p F P
0 0 0 r
s
.594 .672 .894 r
.25696 .28369 m .27178 .3027 L .29446 .29816 L p F P
0 0 0 r
s
.605 .69 .903 r
.27178 .3027 m .25696 .28369 L .23431 .29 L p F P
0 0 0 r
s
.647 .762 .933 r
.50822 .58523 m .52133 .5983 L .54537 .59125 L p F P
0 0 0 r
s
.647 .762 .933 r
.52133 .5983 m .50822 .58523 L .48424 .59234 L p F P
0 0 0 r
s
.649 .731 .909 r
.15808 .2716 m .17394 .2877 L .19639 .28004 L p F P
0 0 0 r
s
.654 .735 .909 r
.17394 .2877 m .15808 .2716 L .13568 .27976 L p F P
0 0 0 r
s
.647 .762 .933 r
.91387 .58468 m .92373 .59776 L .94954 .5907 L p F P
0 0 0 r
s
.647 .762 .933 r
.92373 .59776 m .91387 .58468 L .88812 .59179 L p F P
0 0 0 r
s
.647 .762 .933 r
.16395 .58468 m .17983 .59776 L .20239 .5907 L p F P
0 0 0 r
s
.71 .766 .897 r
.78514 .28119 m .796 .29633 L .82096 .28478 L p F P
0 0 0 r
s
.733 .778 .889 r
.796 .29633 m .78514 .28119 L .76033 .29482 L p F P
0 0 0 r
s
.647 .762 .933 r
.56963 .58413 m .58225 .59722 L .60658 .59016 L p F P
0 0 0 r
s
.647 .762 .933 r
.58225 .59722 m .56963 .58413 L .54537 .59125 L p F P
0 0 0 r
s
.476 .539 .842 r
.38204 .37061 m .3684 .34242 L .34551 .34227 L p F P
0 0 0 r
s
.52 .571 .847 r
.33156 .31746 m .34551 .34227 L .3684 .34242 L p F P
0 0 0 r
s
.647 .762 .933 r
.22515 .58358 m .24055 .59668 L .26339 .58961 L p F P
0 0 0 r
s
.647 .762 .933 r
.24055 .59668 m .22515 .58358 L .20239 .5907 L p F P
0 0 0 r
s
.647 .762 .933 r
.63112 .58303 m .64326 .59614 L .66787 .58907 L p F P
0 0 0 r
s
.647 .762 .933 r
.64326 .59614 m .63112 .58303 L .60658 .59016 L p F P
0 0 0 r
s
.54 .62 .881 r
.469 .46077 m .48234 .48132 L .50621 .48061 L p F P
0 0 0 r
s
.647 .762 .933 r
.28644 .58248 m .30135 .5956 L .32448 .58852 L p F P
0 0 0 r
s
.647 .762 .933 r
.30135 .5956 m .28644 .58248 L .26339 .58961 L p F P
0 0 0 r
s
.625 .706 .904 r
.21902 .2726 m .23431 .29 L .25696 .28369 L p F P
0 0 0 r
s
.633 .717 .908 r
.23431 .29 m .21902 .2726 L .19639 .28004 L p F P
0 0 0 r
s
.647 .762 .933 r
.6927 .58193 m .70436 .59505 L .72925 .58797 L p F P
0 0 0 r
s
.647 .762 .933 r
.70436 .59505 m .6927 .58193 L .66787 .58907 L p F P
0 0 0 r
s
.647 .762 .933 r
.3478 .58138 m .36223 .59451 L .38564 .58742 L p F P
0 0 0 r
s
.647 .762 .933 r
.36223 .59451 m .3478 .58138 L .32448 .58852 L p F P
0 0 0 r
s
.662 .741 .909 r
.05817 .26496 m .07493 .28068 L .09708 .27229 L p F P
0 0 0 r
s
.647 .762 .933 r
.75436 .58083 m .76553 .59397 L .79071 .58688 L p F P
0 0 0 r
s
.647 .762 .933 r
.76553 .59397 m .75436 .58083 L .72925 .58797 L p F P
0 0 0 r
s
.647 .762 .933 r
.40925 .58027 m .4232 .59343 L .44689 .58633 L p F P
0 0 0 r
s
.647 .762 .933 r
.4232 .59343 m .40925 .58027 L .38564 .58742 L p F P
0 0 0 r
s
.813 .789 .83 r
.67571 .3361 m .68752 .35121 L .71156 .32953 L p F P
0 0 0 r
s
.831 .792 .814 r
.68752 .35121 m .67571 .3361 L .65158 .36061 L p F P
0 0 0 r
s
.831 .792 .814 r
.65158 .36061 m .66359 .37554 L .68752 .35121 L p F P
0 0 0 r
s
.789 .785 .849 r
.69996 .31423 m .71156 .32953 L .73582 .31079 L p F P
0 0 0 r
s
.813 .789 .83 r
.71156 .32953 m .69996 .31423 L .67571 .3361 L p F P
0 0 0 r
s
.647 .762 .933 r
.81611 .57972 m .82678 .59288 L .85225 .58578 L p F P
0 0 0 r
s
.647 .762 .933 r
.82678 .59288 m .81611 .57972 L .79071 .58688 L p F P
0 0 0 r
s
.657 .738 .909 r
.11942 .26386 m .13568 .27976 L .15808 .2716 L p F P
0 0 0 r
s
.659 .74 .909 r
.13568 .27976 m .11942 .26386 L .09708 .27229 L p F P
0 0 0 r
s
.647 .762 .933 r
.47078 .57917 m .48424 .59234 L .50822 .58523 L p F P
0 0 0 r
s
.647 .762 .933 r
.48424 .59234 m .47078 .57917 L .44689 .58633 L p F P
0 0 0 r
s
.841 .793 .804 r
.66359 .37554 m .65158 .36061 L .62747 .38687 L p F P
0 0 0 r
s
.841 .793 .804 r
.62747 .38687 m .63968 .40161 L .66359 .37554 L p F P
0 0 0 r
s
.466 .511 .82 r
.41867 .40279 m .4052 .3723 L .38204 .37061 L p F P
0 0 0 r
s
.506 .533 .819 r
.3684 .34242 m .38204 .37061 L .4052 .3723 L p F P
0 0 0 r
s
.692 .757 .902 r
.81025 .26933 m .82096 .28478 L .84622 .2744 L p F P
0 0 0 r
s
.71 .766 .897 r
.82096 .28478 m .81025 .26933 L .78514 .28119 L p F P
0 0 0 r
s
.647 .762 .933 r
.87794 .57861 m .88812 .59179 L .91387 .58468 L p F P
0 0 0 r
s
.647 .762 .933 r
.88812 .59179 m .87794 .57861 L .85225 .58578 L p F P
0 0 0 r
s
.749 .781 .879 r
.53038 .47299 m .54336 .48702 L .56752 .47257 L p F P
0 0 0 r
s
.653 .755 .924 r
.54336 .48702 m .53038 .47299 L .50621 .48061 L p F P
0 0 0 r
s
.761 .778 .866 r
.72439 .29532 m .73582 .31079 L .76033 .29482 L p F P
0 0 0 r
s
.789 .785 .849 r
.73582 .31079 m .72439 .29532 L .69996 .31423 L p F P
0 0 0 r
s
.457 .531 .845 r
.469 .46077 m .45562 .43443 L .43209 .43145 L p F P
0 0 0 r
s
.494 .521 .814 r
.41867 .40279 m .43209 .43145 L .45562 .43443 L p F P
0 0 0 r
s
.647 .762 .933 r
.5324 .57806 m .54537 .59125 L .56963 .58413 L p F P
0 0 0 r
s
.647 .762 .933 r
.54537 .59125 m .5324 .57806 L .50822 .58523 L p F P
0 0 0 r
s
.644 .726 .908 r
.18067 .2635 m .19639 .28004 L .21902 .2726 L p F P
0 0 0 r
s
.649 .731 .909 r
.19639 .28004 m .18067 .2635 L .15808 .2716 L p F P
0 0 0 r
s
.647 .762 .933 r
.94954 .5907 m .93985 .57751 L .91387 .58468 L p F P
0 0 0 r
s
.647 .762 .933 r
.18663 .57751 m .20239 .5907 L .22515 .58358 L p F P
0 0 0 r
s
.647 .762 .933 r
.20239 .5907 m .18663 .57751 L .16395 .58468 L p F P
0 0 0 r
s
.842 .793 .804 r
.63968 .40161 m .62747 .38687 L .6033 .41331 L p F P
0 0 0 r
s
.842 .793 .804 r
.6033 .41331 m .61572 .42785 L .63968 .40161 L p F P
0 0 0 r
s
.647 .762 .933 r
.5941 .57695 m .60658 .59016 L .63112 .58303 L p F P
0 0 0 r
s
.647 .762 .933 r
.60658 .59016 m .5941 .57695 L .56963 .58413 L p F P
0 0 0 r
s
.647 .762 .933 r
.24812 .5764 m .26339 .58961 L .28644 .58248 L p F P
0 0 0 r
s
.647 .762 .933 r
.26339 .58961 m .24812 .5764 L .22515 .58358 L p F P
0 0 0 r
s
.555 .624 .875 r
.33156 .31746 m .31737 .29396 L .29446 .29816 L p F P
0 0 0 r
s
.588 .654 .882 r
.27981 .27773 m .29446 .29816 L .31737 .29396 L p F P
0 0 0 r
s
.594 .672 .894 r
.29446 .29816 m .27981 .27773 L .25696 .28369 L p F P
0 0 0 r
s
.647 .762 .933 r
.65588 .57584 m .66787 .58907 L .6927 .58193 L p F P
0 0 0 r
s
.647 .762 .933 r
.66787 .58907 m .65588 .57584 L .63112 .58303 L p F P
0 0 0 r
s
.52 .571 .847 r
.3684 .34242 m .35458 .31524 L .33156 .31746 L p F P
0 0 0 r
s
.557 .605 .857 r
.31737 .29396 m .33156 .31746 L .35458 .31524 L p F P
0 0 0 r
s
.647 .762 .933 r
.30968 .57529 m .32448 .58852 L .3478 .58138 L p F P
0 0 0 r
s
.647 .762 .933 r
.32448 .58852 m .30968 .57529 L .28644 .58248 L p F P
0 0 0 r
s
.734 .769 .881 r
.74908 .2792 m .76033 .29482 L .78514 .28119 L p F P
0 0 0 r
s
.761 .778 .866 r
.76033 .29482 m .74908 .2792 L .72439 .29532 L p F P
0 0 0 r
s
.831 .792 .815 r
.61572 .42785 m .6033 .41331 L .57903 .43788 L p F P
0 0 0 r
s
.831 .792 .815 r
.57903 .43788 m .59166 .45223 L .61572 .42785 L p F P
0 0 0 r
s
.647 .762 .933 r
.71775 .57473 m .72925 .58797 L .75436 .58083 L p F P
0 0 0 r
s
.647 .762 .933 r
.72925 .58797 m .71775 .57473 L .6927 .58193 L p F P
0 0 0 r
s
.803 .79 .84 r
.5547 .45839 m .56752 .47257 L .59166 .45223 L p F P
0 0 0 r
s
.749 .781 .879 r
.56752 .47257 m .5547 .45839 L .53038 .47299 L p F P
0 0 0 r
s
.647 .762 .933 r
.37134 .57417 m .38564 .58742 L .40925 .58027 L p F P
0 0 0 r
s
.647 .762 .933 r
.38564 .58742 m .37134 .57417 L .3478 .58138 L p F P
0 0 0 r
s
.617 .693 .898 r
.24184 .26537 m .25696 .28369 L .27981 .27773 L p F P
0 0 0 r
s
.625 .706 .904 r
.25696 .28369 m .24184 .26537 L .21902 .2726 L p F P
0 0 0 r
s
.803 .79 .84 r
.59166 .45223 m .57903 .43788 L .5547 .45839 L p F P
0 0 0 r
s
.647 .762 .933 r
.7797 .57362 m .79071 .58688 L .81611 .57972 L p F P
0 0 0 r
s
.647 .762 .933 r
.79071 .58688 m .7797 .57362 L .75436 .58083 L p F P
0 0 0 r
s
.661 .741 .909 r
.08043 .2564 m .09708 .27229 L .11942 .26386 L p F P
0 0 0 r
s
.662 .741 .909 r
.09708 .27229 m .08043 .2564 L .05817 .26496 L p F P
0 0 0 r
s
.647 .762 .933 r
.43307 .57306 m .44689 .58633 L .47078 .57917 L p F P
0 0 0 r
s
.647 .762 .933 r
.44689 .58633 m .43307 .57306 L .40925 .58027 L p F P
0 0 0 r
s
.54 .62 .881 r
.50621 .48061 m .49294 .45958 L .469 .46077 L p F P
0 0 0 r
s
.557 .574 .826 r
.45562 .43443 m .469 .46077 L .49294 .45958 L p F P
0 0 0 r
s
.647 .762 .933 r
.84173 .5725 m .85225 .58578 L .87794 .57861 L p F P
0 0 0 r
s
.647 .762 .933 r
.85225 .58578 m .84173 .5725 L .81611 .57972 L p F P
0 0 0 r
s
.506 .533 .819 r
.4052 .3723 m .39164 .34171 L .3684 .34242 L p F P
0 0 0 r
s
.54 .562 .826 r
.35458 .31524 m .3684 .34242 L .39164 .34171 L p F P
0 0 0 r
s
.692 .757 .902 r
.84622 .2744 m .83567 .25871 L .81025 .26933 L p F P
0 0 0 r
s
.649 .665 .852 r
.49294 .45958 m .50621 .48061 L .53038 .47299 L p F P
0 0 0 r
s
.655 .735 .909 r
.14195 .25543 m .15808 .2716 L .18067 .2635 L p F P
0 0 0 r
s
.657 .738 .909 r
.15808 .2716 m .14195 .25543 L .11942 .26386 L p F P
0 0 0 r
s
.494 .521 .814 r
.45562 .43443 m .44222 .40403 L .41867 .40279 L p F P
0 0 0 r
s
.522 .525 .8 r
.4052 .3723 m .41867 .40279 L .44222 .40403 L p F P
0 0 0 r
s
.647 .762 .933 r
.49489 .57194 m .50822 .58523 L .5324 .57806 L p F P
0 0 0 r
s
.647 .762 .933 r
.50822 .58523 m .49489 .57194 L .47078 .57917 L p F P
0 0 0 r
s
.647 .762 .933 r
.90385 .57139 m .91387 .58468 L .93985 .57751 L p F P
0 0 0 r
s
.647 .762 .933 r
.91387 .58468 m .90385 .57139 L .87794 .57861 L p F P
0 0 0 r
s
.647 .762 .933 r
.14782 .57139 m .16395 .58468 L .18663 .57751 L p F P
0 0 0 r
s
.647 .762 .933 r
.5568 .57083 m .56963 .58413 L .5941 .57695 L p F P
0 0 0 r
s
.647 .762 .933 r
.56963 .58413 m .5568 .57083 L .5324 .57806 L p F P
0 0 0 r
s
.711 .761 .892 r
.77406 .26541 m .78514 .28119 L .81025 .26933 L p F P
0 0 0 r
s
.734 .769 .881 r
.78514 .28119 m .77406 .26541 L .74908 .2792 L p F P
0 0 0 r
s
.647 .762 .933 r
.20951 .57027 m .22515 .58358 L .24812 .5764 L p F P
0 0 0 r
s
.647 .762 .933 r
.22515 .58358 m .20951 .57027 L .18663 .57751 L p F P
0 0 0 r
s
.639 .718 .905 r
.20345 .2555 m .21902 .2726 L .24184 .26537 L p F P
0 0 0 r
s
.644 .726 .908 r
.21902 .2726 m .20345 .2555 L .18067 .2635 L p F P
0 0 0 r
s
.647 .762 .933 r
.61879 .56971 m .63112 .58303 L .65588 .57584 L p F P
0 0 0 r
s
.647 .762 .933 r
.63112 .58303 m .61879 .56971 L .5941 .57695 L p F P
0 0 0 r
s
.647 .762 .933 r
.27128 .56915 m .28644 .58248 L .30968 .57529 L p F P
0 0 0 r
s
.647 .762 .933 r
.28644 .58248 m .27128 .56915 L .24812 .5764 L p F P
0 0 0 r
s
.647 .762 .933 r
.68086 .56859 m .6927 .58193 L .71775 .57473 L p F P
0 0 0 r
s
.647 .762 .933 r
.6927 .58193 m .68086 .56859 L .65588 .57584 L p F P
0 0 0 r
s
.647 .762 .933 r
.33314 .56803 m .3478 .58138 L .37134 .57417 L p F P
0 0 0 r
s
.647 .762 .933 r
.3478 .58138 m .33314 .56803 L .30968 .57529 L p F P
0 0 0 r
s
.647 .762 .933 r
.74301 .56747 m .75436 .58083 L .7797 .57362 L p F P
0 0 0 r
s
.647 .762 .933 r
.75436 .58083 m .74301 .56747 L .71775 .57473 L p F P
0 0 0 r
s
.647 .762 .933 r
.39508 .56691 m .40925 .58027 L .43307 .57306 L p F P
0 0 0 r
s
.647 .762 .933 r
.40925 .58027 m .39508 .56691 L .37134 .57417 L p F P
0 0 0 r
s
.801 .76 .816 r
.66362 .31847 m .67571 .3361 L .69996 .31423 L p F P
0 0 0 r
s
.814 .755 .797 r
.67571 .3361 m .66362 .31847 L .63927 .34234 L p F P
0 0 0 r
s
.814 .755 .797 r
.63927 .34234 m .65158 .36061 L .67571 .3361 L p F P
0 0 0 r
s
.781 .763 .837 r
.68808 .29712 m .69996 .31423 L .72439 .29532 L p F P
0 0 0 r
s
.801 .76 .816 r
.69996 .31423 m .68808 .29712 L .66362 .31847 L p F P
0 0 0 r
s
.522 .525 .8 r
.44222 .40403 m .42878 .37162 L .4052 .3723 L p F P
0 0 0 r
s
.546 .539 .798 r
.39164 .34171 m .4052 .3723 L .42878 .37162 L p F P
0 0 0 r
s
.557 .605 .857 r
.35458 .31524 m .34054 .28974 L .31737 .29396 L p F P
0 0 0 r
s
.588 .638 .868 r
.30289 .27197 m .31737 .29396 L .34054 .28974 L p F P
0 0 0 r
s
.588 .654 .882 r
.31737 .29396 m .30289 .27197 L .27981 .27773 L p F P
0 0 0 r
s
.647 .762 .933 r
.80526 .56634 m .81611 .57972 L .84173 .5725 L p F P
0 0 0 r
s
.647 .762 .933 r
.81611 .57972 m .80526 .56634 L .7797 .57362 L p F P
0 0 0 r
s
.66 .74 .909 r
.10289 .24778 m .11942 .26386 L .14195 .25543 L p F P
0 0 0 r
s
.661 .741 .909 r
.11942 .26386 m .10289 .24778 L .08043 .2564 L p F P
0 0 0 r
s
.647 .762 .933 r
.45711 .56578 m .47078 .57917 L .49489 .57194 L p F P
0 0 0 r
s
.647 .762 .933 r
.47078 .57917 m .45711 .56578 L .43307 .57306 L p F P
0 0 0 r
s
.819 .747 .784 r
.65158 .36061 m .63927 .34234 L .61494 .36785 L p F P
0 0 0 r
s
.819 .747 .784 r
.61494 .36785 m .62747 .38687 L .65158 .36061 L p F P
0 0 0 r
s
.557 .574 .826 r
.49294 .45958 m .47959 .43244 L .45562 .43443 L p F P
0 0 0 r
s
.568 .551 .795 r
.44222 .40403 m .45562 .43443 L .47959 .43244 L p F P
0 0 0 r
s
.54 .562 .826 r
.39164 .34171 m .37793 .31235 L .35458 .31524 L p F P
0 0 0 r
s
.57 .594 .838 r
.34054 .28974 m .35458 .31524 L .37793 .31235 L p F P
0 0 0 r
s
.613 .68 .889 r
.26486 .25834 m .27981 .27773 L .30289 .27197 L p F P
0 0 0 r
s
.617 .693 .898 r
.27981 .27773 m .26486 .25834 L .24184 .26537 L p F P
0 0 0 r
s
.647 .762 .933 r
.86758 .56522 m .87794 .57861 L .90385 .57139 L p F P
0 0 0 r
s
.647 .762 .933 r
.87794 .57861 m .86758 .56522 L .84173 .5725 L p F P
0 0 0 r
s
.693 .755 .899 r
.79935 .2534 m .81025 .26933 L .83567 .25871 L p F P
0 0 0 r
s
.711 .761 .892 r
.81025 .26933 m .79935 .2534 L .77406 .26541 L p F P
0 0 0 r
s
.723 .694 .822 r
.5172 .45181 m .53038 .47299 L .5547 .45839 L p F P
0 0 0 r
s
.649 .665 .852 r
.53038 .47299 m .5172 .45181 L .49294 .45958 L p F P
0 0 0 r
s
.757 .763 .858 r
.71272 .27857 m .72439 .29532 L .74908 .2792 L p F P
0 0 0 r
s
.781 .763 .837 r
.72439 .29532 m .71272 .27857 L .68808 .29712 L p F P
0 0 0 r
s
.647 .762 .933 r
.51922 .56466 m .5324 .57806 L .5568 .57083 L p F P
0 0 0 r
s
.647 .762 .933 r
.5324 .57806 m .51922 .56466 L .49489 .57194 L p F P
0 0 0 r
s
.652 .732 .908 r
.16467 .247 m .18067 .2635 L .20345 .2555 L p F P
0 0 0 r
s
.655 .735 .909 r
.18067 .2635 m .16467 .247 L .14195 .25543 L p F P
0 0 0 r
s
.647 .762 .933 r
.93985 .57751 m .93 .56409 L .90385 .57139 L p F P
0 0 0 r
s
.647 .762 .933 r
.17061 .56409 m .18663 .57751 L .20951 .57027 L p F P
0 0 0 r
s
.647 .762 .933 r
.18663 .57751 m .17061 .56409 L .14782 .57139 L p F P
0 0 0 r
s
.814 .737 .779 r
.62747 .38687 m .61494 .36785 L .59057 .39352 L p F P
0 0 0 r
s
.814 .737 .779 r
.59057 .39352 m .6033 .41331 L .62747 .38687 L p F P
0 0 0 r
s
.647 .762 .933 r
.58141 .56353 m .5941 .57695 L .61879 .56971 L p F P
0 0 0 r
s
.647 .762 .933 r
.5941 .57695 m .58141 .56353 L .5568 .57083 L p F P
0 0 0 r
s
.647 .762 .933 r
.23259 .56297 m .24812 .5764 L .27128 .56915 L p F P
0 0 0 r
s
.647 .762 .933 r
.24812 .5764 m .23259 .56297 L .20951 .57027 L p F P
0 0 0 r
s
.647 .762 .933 r
.64369 .5624 m .65588 .57584 L .68086 .56859 L p F P
0 0 0 r
s
.647 .762 .933 r
.65588 .57584 m .64369 .5624 L .61879 .56971 L p F P
0 0 0 r
s
.639 .61 .804 r
.47959 .43244 m .49294 .45958 L .5172 .45181 L p F P
0 0 0 r
s
.647 .762 .933 r
.29465 .56184 m .30968 .57529 L .33314 .56803 L p F P
0 0 0 r
s
.647 .762 .933 r
.30968 .57529 m .29465 .56184 L .27128 .56915 L p F P
0 0 0 r
s
.634 .71 .901 r
.22643 .24761 m .24184 .26537 L .26486 .25834 L p F P
0 0 0 r
s
.639 .718 .905 r
.24184 .26537 m .22643 .24761 L .20345 .2555 L p F P
0 0 0 r
s
.732 .76 .875 r
.73761 .26267 m .74908 .2792 L .77406 .26541 L p F P
0 0 0 r
s
.757 .763 .858 r
.74908 .2792 m .73761 .26267 L .71272 .27857 L p F P
0 0 0 r
s
.799 .726 .784 r
.6033 .41331 m .59057 .39352 L .56612 .41741 L p F P
0 0 0 r
s
.799 .726 .784 r
.56612 .41741 m .57903 .43788 L .6033 .41331 L p F P
0 0 0 r
s
.647 .762 .933 r
.70606 .56127 m .71775 .57473 L .74301 .56747 L p F P
0 0 0 r
s
.647 .762 .933 r
.71775 .57473 m .70606 .56127 L .68086 .56859 L p F P
0 0 0 r
s
.546 .539 .798 r
.42878 .37162 m .41527 .33915 L .39164 .34171 L p F P
0 0 0 r
s
.568 .561 .806 r
.37793 .31235 m .39164 .34171 L .41527 .33915 L p F P
0 0 0 r
s
.771 .713 .798 r
.54163 .43742 m .5547 .45839 L .57903 .43788 L p F P
0 0 0 r
s
.723 .694 .822 r
.5547 .45839 m .54163 .43742 L .5172 .45181 L p F P
0 0 0 r
s
.647 .762 .933 r
.3568 .56071 m .37134 .57417 L .39508 .56691 L p F P
0 0 0 r
s
.647 .762 .933 r
.37134 .57417 m .3568 .56071 L .33314 .56803 L p F P
0 0 0 r
s
.771 .713 .798 r
.57903 .43788 m .56612 .41741 L .54163 .43742 L p F P
0 0 0 r
s
.647 .762 .933 r
.76851 .56014 m .7797 .57362 L .80526 .56634 L p F P
0 0 0 r
s
.647 .762 .933 r
.7797 .57362 m .76851 .56014 L .74301 .56747 L p F P
0 0 0 r
s
.568 .551 .795 r
.47959 .43244 m .4662 .40101 L .44222 .40403 L p F P
0 0 0 r
s
.578 .545 .782 r
.42878 .37162 m .44222 .40403 L .4662 .40101 L p F P
0 0 0 r
s
.647 .762 .933 r
.41903 .55957 m .43307 .57306 L .45711 .56578 L p F P
0 0 0 r
s
.647 .762 .933 r
.43307 .57306 m .41903 .55957 L .39508 .56691 L p F P
0 0 0 r
s
.647 .762 .933 r
.83104 .55901 m .84173 .5725 L .86758 .56522 L p F P
0 0 0 r
s
.647 .762 .933 r
.84173 .5725 m .83104 .55901 L .80526 .56634 L p F P
0 0 0 r
s
.693 .755 .899 r
.83567 .25871 m .82493 .24263 L .79935 .2534 L p F P
0 0 0 r
s
.658 .738 .909 r
.12554 .23912 m .14195 .25543 L .16467 .247 L p F P
0 0 0 r
s
.66 .74 .909 r
.14195 .25543 m .12554 .23912 L .10289 .24778 L p F P
0 0 0 r
s
.647 .762 .933 r
.48135 .55844 m .49489 .57194 L .51922 .56466 L p F P
0 0 0 r
s
.647 .762 .933 r
.49489 .57194 m .48135 .55844 L .45711 .56578 L p F P
0 0 0 r
s
.647 .762 .933 r
.89367 .55787 m .90385 .57139 L .93 .56409 L p F P
0 0 0 r
s
.647 .762 .933 r
.90385 .57139 m .89367 .55787 L .86758 .56522 L p F P
0 0 0 r
s
.647 .762 .933 r
.13142 .55787 m .14782 .57139 L .17061 .56409 L p F P
0 0 0 r
s
.647 .762 .933 r
.54375 .55731 m .5568 .57083 L .58141 .56353 L p F P
0 0 0 r
s
.647 .762 .933 r
.5568 .57083 m .54375 .55731 L .51922 .56466 L p F P
0 0 0 r
s
.71 .756 .888 r
.76278 .24899 m .77406 .26541 L .79935 .2534 L p F P
0 0 0 r
s
.732 .76 .875 r
.77406 .26541 m .76278 .24899 L .73761 .26267 L p F P
0 0 0 r
s
.57 .594 .838 r
.37793 .31235 m .364 .28502 L .34054 .28974 L p F P
0 0 0 r
s
.595 .626 .852 r
.32621 .26616 m .34054 .28974 L .364 .28502 L p F P
0 0 0 r
s
.588 .638 .868 r
.34054 .28974 m .32621 .26616 L .30289 .27197 L p F P
0 0 0 r
s
.649 .727 .906 r
.18759 .23858 m .20345 .2555 L .22643 .24761 L p F P
0 0 0 r
s
.652 .732 .908 r
.20345 .2555 m .18759 .23858 L .16467 .247 L p F P
0 0 0 r
s
.647 .762 .933 r
.1936 .55674 m .20951 .57027 L .23259 .56297 L p F P
0 0 0 r
s
.647 .762 .933 r
.20951 .57027 m .1936 .55674 L .17061 .56409 L p F P
0 0 0 r
s
.612 .667 .879 r
.2881 .2514 m .30289 .27197 L .32621 .26616 L p F P
0 0 0 r
s
.613 .68 .889 r
.30289 .27197 m .2881 .2514 L .26486 .25834 L p F P
0 0 0 r
s
.647 .762 .933 r
.60624 .55617 m .61879 .56971 L .64369 .5624 L p F P
0 0 0 r
s
.647 .762 .933 r
.61879 .56971 m .60624 .55617 L .58141 .56353 L p F P
0 0 0 r
s
.647 .762 .933 r
.25587 .5556 m .27128 .56915 L .29465 .56184 L p F P
0 0 0 r
s
.647 .762 .933 r
.27128 .56915 m .25587 .5556 L .23259 .56297 L p F P
0 0 0 r
s
.578 .545 .782 r
.4662 .40101 m .45277 .36748 L .42878 .37162 L p F P
0 0 0 r
s
.589 .552 .781 r
.41527 .33915 m .42878 .37162 L .45277 .36748 L p F P
0 0 0 r
s
.639 .61 .804 r
.5172 .45181 m .50389 .42451 L .47959 .43244 L p F P
0 0 0 r
s
.632 .58 .778 r
.4662 .40101 m .47959 .43244 L .50389 .42451 L p F P
0 0 0 r
s
.647 .762 .933 r
.66882 .55503 m .68086 .56859 L .70606 .56127 L p F P
0 0 0 r
s
.647 .762 .933 r
.68086 .56859 m .66882 .55503 L .64369 .5624 L p F P
0 0 0 r
s
.568 .561 .806 r
.41527 .33915 m .40162 .30808 L .37793 .31235 L p F P
0 0 0 r
s
.589 .589 .82 r
.364 .28502 m .37793 .31235 L .40162 .30808 L p F P
0 0 0 r
s
.7 .638 .784 r
.50389 .42451 m .5172 .45181 L .54163 .43742 L p F P
0 0 0 r
s
.786 .736 .807 r
.65127 .29865 m .66362 .31847 L .68808 .29712 L p F P
0 0 0 r
s
.795 .725 .787 r
.66362 .31847 m .65127 .29865 L .62669 .32116 L p F P
0 0 0 r
s
.795 .725 .787 r
.62669 .32116 m .63927 .34234 L .66362 .31847 L p F P
0 0 0 r
s
.647 .762 .933 r
.31823 .55446 m .33314 .56803 L .3568 .56071 L p F P
0 0 0 r
s
.647 .762 .933 r
.33314 .56803 m .31823 .55446 L .29465 .56184 L p F P
0 0 0 r
s
.77 .745 .83 r
.67595 .2784 m .68808 .29712 L .71272 .27857 L p F P
0 0 0 r
s
.786 .736 .807 r
.68808 .29712 m .67595 .2784 L .65127 .29865 L p F P
0 0 0 r
s
.647 .762 .933 r
.73148 .55389 m .74301 .56747 L .76851 .56014 L p F P
0 0 0 r
s
.647 .762 .933 r
.74301 .56747 m .73148 .55389 L .70606 .56127 L p F P
0 0 0 r
s
.796 .711 .771 r
.63927 .34234 m .62669 .32116 L .60216 .34513 L p F P
0 0 0 r
s
.796 .711 .771 r
.60216 .34513 m .61494 .36785 L .63927 .34234 L p F P
0 0 0 r
s
.631 .7 .895 r
.2496 .23979 m .26486 .25834 L .2881 .2514 L p F P
0 0 0 r
s
.634 .71 .901 r
.26486 .25834 m .2496 .23979 L .22643 .24761 L p F P
0 0 0 r
s
.647 .762 .933 r
.38067 .55332 m .39508 .56691 L .41903 .55957 L p F P
0 0 0 r
s
.647 .762 .933 r
.39508 .56691 m .38067 .55332 L .3568 .56071 L p F P
0 0 0 r
s
.647 .762 .933 r
.79423 .55275 m .80526 .56634 L .83104 .55901 L p F P
0 0 0 r
s
.647 .762 .933 r
.80526 .56634 m .79423 .55275 L .76851 .56014 L p F P
0 0 0 r
s
.647 .762 .933 r
.4432 .55218 m .45711 .56578 L .48135 .55844 L p F P
0 0 0 r
s
.647 .762 .933 r
.45711 .56578 m .4432 .55218 L .41903 .55957 L p F P
0 0 0 r
s
.788 .696 .763 r
.61494 .36785 m .60216 .34513 L .5776 .36921 L p F P
0 0 0 r
s
.788 .696 .763 r
.5776 .36921 m .59057 .39352 L .61494 .36785 L p F P
0 0 0 r
s
.749 .75 .852 r
.70081 .26067 m .71272 .27857 L .73761 .26267 L p F P
0 0 0 r
s
.77 .745 .83 r
.71272 .27857 m .70081 .26067 L .67595 .2784 L p F P
0 0 0 r
s
.647 .762 .933 r
.85706 .55161 m .86758 .56522 L .89367 .55787 L p F P
0 0 0 r
s
.647 .762 .933 r
.86758 .56522 m .85706 .55161 L .83104 .55901 L p F P
0 0 0 r
s
.693 .751 .897 r
.78824 .23699 m .79935 .2534 L .82493 .24263 L p F P
0 0 0 r
s
.71 .756 .888 r
.79935 .2534 m .78824 .23699 L .76278 .24899 L p F P
0 0 0 r
s
.657 .736 .908 r
.14838 .23043 m .16467 .247 L .18759 .23858 L p F P
0 0 0 r
s
.658 .738 .909 r
.16467 .247 m .14838 .23043 L .12554 .23912 L p F P
0 0 0 r
s
.647 .762 .933 r
.50581 .55103 m .51922 .56466 L .54375 .55731 L p F P
0 0 0 r
s
.647 .762 .933 r
.51922 .56466 m .50581 .55103 L .48135 .55844 L p F P
0 0 0 r
s
.589 .552 .781 r
.45277 .36748 m .43927 .33389 L .41527 .33915 L p F P
0 0 0 r
s
.6 .568 .789 r
.40162 .30808 m .41527 .33915 L .43927 .33389 L p F P
0 0 0 r
s
.742 .661 .77 r
.5284 .41063 m .54163 .43742 L .56612 .41741 L p F P
0 0 0 r
s
.7 .638 .784 r
.54163 .43742 m .5284 .41063 L .50389 .42451 L p F P
0 0 0 r
s
.647 .762 .933 r
.93 .56409 m .91998 .55046 L .89367 .55787 L p F P
0 0 0 r
s
.647 .762 .933 r
.15432 .55046 m .17061 .56409 L .1936 .55674 L p F P
0 0 0 r
s
.647 .762 .933 r
.17061 .56409 m .15432 .55046 L .13142 .55787 L p F P
0 0 0 r
s
.771 .679 .763 r
.59057 .39352 m .5776 .36921 L .553 .39167 L p F P
0 0 0 r
s
.771 .679 .763 r
.553 .39167 m .56612 .41741 L .59057 .39352 L p F P
0 0 0 r
s
.632 .58 .778 r
.50389 .42451 m .49051 .39292 L .4662 .40101 L p F P
0 0 0 r
s
.629 .567 .767 r
.45277 .36748 m .4662 .40101 L .49051 .39292 L p F P
0 0 0 r
s
.647 .762 .933 r
.56851 .54989 m .58141 .56353 L .60624 .55617 L p F P
0 0 0 r
s
.647 .762 .933 r
.58141 .56353 m .56851 .54989 L .54375 .55731 L p F P
0 0 0 r
s
.742 .661 .77 r
.56612 .41741 m .553 .39167 L .5284 .41063 L p F P
0 0 0 r
s
.647 .762 .933 r
.2168 .54931 m .23259 .56297 L .25587 .5556 L p F P
0 0 0 r
s
.647 .762 .933 r
.23259 .56297 m .2168 .54931 L .1936 .55674 L p F P
0 0 0 r
s
.646 .722 .904 r
.2107 .2302 m .22643 .24761 L .2496 .23979 L p F P
0 0 0 r
s
.649 .727 .906 r
.22643 .24761 m .2107 .2302 L .18759 .23858 L p F P
0 0 0 r
s
.647 .762 .933 r
.6313 .54874 m .64369 .5624 L .66882 .55503 L p F P
0 0 0 r
s
.647 .762 .933 r
.64369 .5624 m .6313 .54874 L .60624 .55617 L p F P
0 0 0 r
s
.727 .751 .871 r
.72591 .24532 m .73761 .26267 L .76278 .24899 L p F P
0 0 0 r
s
.749 .75 .852 r
.73761 .26267 m .72591 .24532 L .70081 .26067 L p F P
0 0 0 r
s
.647 .762 .933 r
.27937 .54817 m .29465 .56184 L .31823 .55446 L p F P
0 0 0 r
s
.647 .762 .933 r
.29465 .56184 m .27937 .54817 L .25587 .5556 L p F P
0 0 0 r
s
.682 .605 .764 r
.49051 .39292 m .50389 .42451 L .5284 .41063 L p F P
0 0 0 r
s
.647 .762 .933 r
.69417 .54759 m .70606 .56127 L .73148 .55389 L p F P
0 0 0 r
s
.647 .762 .933 r
.70606 .56127 m .69417 .54759 L .66882 .55503 L p F P
0 0 0 r
s
.589 .589 .82 r
.40162 .30808 m .38777 .27932 L .364 .28502 L p F P
0 0 0 r
s
.608 .62 .838 r
.34979 .26 m .364 .28502 L .38777 .27932 L p F P
0 0 0 r
s
.595 .626 .852 r
.364 .28502 m .34979 .26 L .32621 .26616 L p F P
0 0 0 r
s
.617 .657 .867 r
.31157 .2444 m .32621 .26616 L .34979 .26 L p F P
0 0 0 r
s
.612 .667 .879 r
.32621 .26616 m .31157 .2444 L .2881 .2514 L p F P
0 0 0 r
s
.647 .762 .933 r
.34202 .54702 m .3568 .56071 L .38067 .55332 L p F P
0 0 0 r
s
.647 .762 .933 r
.3568 .56071 m .34202 .54702 L .31823 .55446 L p F P
0 0 0 r
s
.647 .762 .933 r
.75713 .54644 m .76851 .56014 L .79423 .55275 L p F P
0 0 0 r
s
.647 .762 .933 r
.76851 .56014 m .75713 .54644 L .73148 .55389 L p F P
0 0 0 r
s
.629 .567 .767 r
.49051 .39292 m .47708 .35922 L .45277 .36748 L p F P
0 0 0 r
s
.629 .568 .767 r
.43927 .33389 m .45277 .36748 L .47708 .35922 L p F P
0 0 0 r
s
.647 .762 .933 r
.40476 .54587 m .41903 .55957 L .4432 .55218 L p F P
0 0 0 r
s
.647 .762 .933 r
.41903 .55957 m .40476 .54587 L .38067 .55332 L p F P
0 0 0 r
s
.6 .568 .789 r
.43927 .33389 m .42564 .30183 L .40162 .30808 L p F P
0 0 0 r
s
.613 .591 .805 r
.38777 .27932 m .40162 .30808 L .42564 .30183 L p F P
0 0 0 r
s
.647 .762 .933 r
.82018 .54529 m .83104 .55901 L .85706 .55161 L p F P
0 0 0 r
s
.647 .762 .933 r
.83104 .55901 m .82018 .54529 L .79423 .55275 L p F P
0 0 0 r
s
.693 .751 .897 r
.82493 .24263 m .814 .22617 L .78824 .23699 L p F P
0 0 0 r
s
.631 .691 .888 r
.27299 .23199 m .2881 .2514 L .31157 .2444 L p F P
0 0 0 r
s
.631 .7 .895 r
.2881 .2514 m .27299 .23199 L .2496 .23979 L p F P
0 0 0 r
s
.647 .762 .933 r
.46758 .54471 m .48135 .55844 L .50581 .55103 L p F P
0 0 0 r
s
.647 .762 .933 r
.48135 .55844 m .46758 .54471 L .4432 .55218 L p F P
0 0 0 r
s
.647 .762 .933 r
.88331 .54414 m .89367 .55787 L .91998 .55046 L p F P
0 0 0 r
s
.647 .762 .933 r
.89367 .55787 m .88331 .54414 L .85706 .55161 L p F P
0 0 0 r
s
.647 .762 .933 r
.11475 .54414 m .13142 .55787 L .15432 .55046 L p F P
0 0 0 r
s
.655 .733 .907 r
.17143 .22171 m .18759 .23858 L .2107 .2302 L p F P
0 0 0 r
s
.657 .736 .908 r
.18759 .23858 m .17143 .22171 L .14838 .23043 L p F P
0 0 0 r
s
.707 .75 .885 r
.75128 .23196 m .76278 .24899 L .78824 .23699 L p F P
0 0 0 r
s
.727 .751 .871 r
.76278 .24899 m .75128 .23196 L .72591 .24532 L p F P
0 0 0 r
s
.647 .762 .933 r
.5305 .54356 m .54375 .55731 L .56851 .54989 L p F P
0 0 0 r
s
.647 .762 .933 r
.54375 .55731 m .5305 .54356 L .50581 .55103 L p F P
0 0 0 r
s
.72 .628 .755 r
.51506 .37974 m .5284 .41063 L .553 .39167 L p F P
0 0 0 r
s
.682 .605 .764 r
.5284 .41063 m .51506 .37974 L .49051 .39292 L p F P
0 0 0 r
s
.647 .762 .933 r
.17744 .54298 m .1936 .55674 L .2168 .54931 L p F P
0 0 0 r
s
.647 .762 .933 r
.1936 .55674 m .17744 .54298 L .15432 .55046 L p F P
0 0 0 r
s
.776 .704 .783 r
.6139 .29787 m .62669 .32116 L .65127 .29865 L p F P
0 0 0 r
s
.774 .687 .766 r
.62669 .32116 m .6139 .29787 L .58917 .31975 L p F P
0 0 0 r
s
.774 .687 .766 r
.58917 .31975 m .60216 .34513 L .62669 .32116 L p F P
0 0 0 r
s
.77 .719 .805 r
.63869 .27722 m .65127 .29865 L .67595 .2784 L p F P
0 0 0 r
s
.776 .704 .783 r
.65127 .29865 m .63869 .27722 L .6139 .29787 L p F P
0 0 0 r
s
.671 .59 .756 r
.47708 .35922 m .49051 .39292 L .51506 .37974 L p F P
0 0 0 r
s
.647 .762 .933 r
.59349 .5424 m .60624 .55617 L .6313 .54874 L p F P
0 0 0 r
s
.647 .762 .933 r
.60624 .55617 m .59349 .5424 L .56851 .54989 L p F P
0 0 0 r
s
.765 .668 .756 r
.60216 .34513 m .58917 .31975 L .56445 .34169 L p F P
0 0 0 r
s
.765 .668 .756 r
.56445 .34169 m .5776 .36921 L .60216 .34513 L p F P
0 0 0 r
s
.647 .762 .933 r
.24021 .54182 m .25587 .5556 L .27937 .54817 L p F P
0 0 0 r
s
.647 .762 .933 r
.25587 .5556 m .24021 .54182 L .2168 .54931 L p F P
0 0 0 r
s
.757 .731 .828 r
.6636 .25848 m .67595 .2784 L .70081 .26067 L p F P
0 0 0 r
s
.77 .719 .805 r
.67595 .2784 m .6636 .25848 L .63869 .27722 L p F P
0 0 0 r
s
.629 .568 .767 r
.47708 .35922 m .46358 .32547 L .43927 .33389 L p F P
0 0 0 r
s
.632 .579 .777 r
.42564 .30183 m .43927 .33389 L .46358 .32547 L p F P
0 0 0 r
s
.747 .649 .752 r
.53974 .36222 m .553 .39167 L .5776 .36921 L p F P
0 0 0 r
s
.72 .628 .755 r
.553 .39167 m .53974 .36222 L .51506 .37974 L p F P
0 0 0 r
s
.747 .649 .752 r
.5776 .36921 m .56445 .34169 L .53974 .36222 L p F P
0 0 0 r
s
.647 .762 .933 r
.65658 .54125 m .66882 .55503 L .69417 .54759 L p F P
0 0 0 r
s
.647 .762 .933 r
.66882 .55503 m .65658 .54125 L .6313 .54874 L p F P
0 0 0 r
s
.644 .716 .9 r
.23403 .22182 m .2496 .23979 L .27299 .23199 L p F P
0 0 0 r
s
.646 .722 .904 r
.2496 .23979 m .23403 .22182 L .2107 .2302 L p F P
0 0 0 r
s
.647 .762 .933 r
.30308 .54067 m .31823 .55446 L .34202 .54702 L p F P
0 0 0 r
s
.647 .762 .933 r
.31823 .55446 m .30308 .54067 L .27937 .54817 L p F P
0 0 0 r
s
.647 .762 .933 r
.71975 .54009 m .73148 .55389 L .75713 .54644 L p F P
0 0 0 r
s
.647 .762 .933 r
.73148 .55389 m .71975 .54009 L .69417 .54759 L p F P
0 0 0 r
s
.647 .762 .933 r
.36603 .53951 m .38067 .55332 L .40476 .54587 L p F P
0 0 0 r
s
.647 .762 .933 r
.38067 .55332 m .36603 .53951 L .34202 .54702 L p F P
0 0 0 r
s
.739 .739 .851 r
.68869 .24187 m .70081 .26067 L .72591 .24532 L p F P
0 0 0 r
s
.757 .731 .828 r
.70081 .26067 m .68869 .24187 L .6636 .25848 L p F P
0 0 0 r
s
.647 .762 .933 r
.78301 .53893 m .79423 .55275 L .82018 .54529 L p F P
0 0 0 r
s
.647 .762 .933 r
.79423 .55275 m .78301 .53893 L .75713 .54644 L p F P
0 0 0 r
s
.608 .62 .838 r
.38777 .27932 m .37366 .25315 L .34979 .26 L p F P
0 0 0 r
s
.625 .651 .856 r
.33529 .23714 m .34979 .26 L .37366 .25315 L p F P
0 0 0 r
s
.617 .657 .867 r
.34979 .26 m .33529 .23714 L .31157 .2444 L p F P
0 0 0 r
s
.613 .591 .805 r
.42564 .30183 m .41184 .27221 L .38777 .27932 L p F P
0 0 0 r
s
.625 .62 .825 r
.37366 .25315 m .38777 .27932 L .41184 .27221 L p F P
0 0 0 r
s
.671 .59 .756 r
.51506 .37974 m .50165 .34683 L .47708 .35922 L p F P
0 0 0 r
s
.664 .587 .758 r
.46358 .32547 m .47708 .35922 L .50165 .34683 L p F P
0 0 0 r
s
.647 .762 .933 r
.42906 .53834 m .4432 .55218 L .46758 .54471 L p F P
0 0 0 r
s
.647 .762 .933 r
.4432 .55218 m .42906 .53834 L .40476 .54587 L p F P
0 0 0 r
s
.691 .748 .895 r
.77694 .22012 m .78824 .23699 L .814 .22617 L p F P
0 0 0 r
s
.707 .75 .885 r
.78824 .23699 m .77694 .22012 L .75128 .23196 L p F P
0 0 0 r
s
.647 .762 .933 r
.84636 .53776 m .85706 .55161 L .88331 .54414 L p F P
0 0 0 r
s
.647 .762 .933 r
.85706 .55161 m .84636 .53776 L .82018 .54529 L p F P
0 0 0 r
s
.704 .611 .75 r
.50165 .34683 m .51506 .37974 L .53974 .36222 L p F P
0 0 0 r
s
.647 .762 .933 r
.49219 .53718 m .50581 .55103 L .5305 .54356 L p F P
0 0 0 r
s
.647 .762 .933 r
.50581 .55103 m .49219 .53718 L .46758 .54471 L p F P
0 0 0 r
s
.633 .684 .88 r
.29661 .22413 m .31157 .2444 L .33529 .23714 L p F P
0 0 0 r
s
.631 .691 .888 r
.31157 .2444 m .29661 .22413 L .27299 .23199 L p F P
0 0 0 r
s
.647 .762 .933 r
.91998 .55046 m .9098 .5366 L .88331 .54414 L p F P
0 0 0 r
s
.647 .762 .933 r
.13777 .5366 m .15432 .55046 L .17744 .54298 L p F P
0 0 0 r
s
.647 .762 .933 r
.15432 .55046 m .13777 .5366 L .11475 .54414 L p F P
0 0 0 r
s
.632 .579 .777 r
.46358 .32547 m .44997 .29323 L .42564 .30183 L p F P
0 0 0 r
s
.637 .599 .794 r
.41184 .27221 m .42564 .30183 L .44997 .29323 L p F P
0 0 0 r
s
.647 .762 .933 r
.5554 .53602 m .56851 .54989 L .59349 .5424 L p F P
0 0 0 r
s
.647 .762 .933 r
.56851 .54989 m .5554 .53602 L .5305 .54356 L p F P
0 0 0 r
s
.653 .73 .906 r
.19469 .21296 m .2107 .2302 L .23403 .22182 L p F P
0 0 0 r
s
.655 .733 .907 r
.2107 .2302 m .19469 .21296 L .17143 .22171 L p F P
0 0 0 r
s
.647 .762 .933 r
.20076 .53543 m .2168 .54931 L .24021 .54182 L p F P
0 0 0 r
s
.647 .762 .933 r
.2168 .54931 m .20076 .53543 L .17744 .54298 L p F P
0 0 0 r
s
.72 .743 .87 r
.71401 .2273 m .72591 .24532 L .75128 .23196 L p F P
0 0 0 r
s
.739 .739 .851 r
.72591 .24532 m .71401 .2273 L .68869 .24187 L p F P
0 0 0 r
s
.729 .632 .75 r
.52637 .33091 m .53974 .36222 L .56445 .34169 L p F P
0 0 0 r
s
.704 .611 .75 r
.53974 .36222 m .52637 .33091 L .50165 .34683 L p F P
0 0 0 r
s
.647 .762 .933 r
.6187 .53485 m .6313 .54874 L .65658 .54125 L p F P
0 0 0 r
s
.647 .762 .933 r
.6313 .54874 m .6187 .53485 L .59349 .5424 L p F P
0 0 0 r
s
.647 .762 .933 r
.26383 .53427 m .27937 .54817 L .30308 .54067 L p F P
0 0 0 r
s
.647 .762 .933 r
.27937 .54817 m .26383 .53427 L .24021 .54182 L p F P
0 0 0 r
s
.664 .587 .758 r
.50165 .34683 m .48816 .31385 L .46358 .32547 L p F P
0 0 0 r
s
.66 .594 .77 r
.44997 .29323 m .46358 .32547 L .48816 .31385 L p F P
0 0 0 r
s
.746 .652 .756 r
.55117 .31253 m .56445 .34169 L .58917 .31975 L p F P
0 0 0 r
s
.729 .632 .75 r
.56445 .34169 m .55117 .31253 L .52637 .33091 L p F P
0 0 0 r
s
.647 .762 .933 r
.68209 .53368 m .69417 .54759 L .71975 .54009 L p F P
0 0 0 r
s
.647 .762 .933 r
.69417 .54759 m .68209 .53368 L .65658 .54125 L p F P
0 0 0 r
s
.756 .672 .769 r
.57603 .29297 m .58917 .31975 L .6139 .29787 L p F P
0 0 0 r
s
.746 .652 .756 r
.58917 .31975 m .57603 .29297 L .55117 .31253 L p F P
0 0 0 r
s
.647 .762 .933 r
.327 .5331 m .34202 .54702 L .36603 .53951 L p F P
0 0 0 r
s
.647 .762 .933 r
.34202 .54702 m .327 .5331 L .30308 .54067 L p F P
0 0 0 r
s
.758 .69 .786 r
.60094 .27344 m .6139 .29787 L .63869 .27722 L p F P
0 0 0 r
s
.756 .672 .769 r
.6139 .29787 m .60094 .27344 L .57603 .29297 L p F P
0 0 0 r
s
.692 .606 .755 r
.48816 .31385 m .50165 .34683 L .52637 .33091 L p F P
0 0 0 r
s
.643 .71 .896 r
.25757 .21342 m .27299 .23199 L .29661 .22413 L p F P
0 0 0 r
s
.644 .716 .9 r
.27299 .23199 m .25757 .21342 L .23403 .22182 L p F P
0 0 0 r
s
.647 .762 .933 r
.74557 .53251 m .75713 .54644 L .78301 .53893 L p F P
0 0 0 r
s
.647 .762 .933 r
.75713 .54644 m .74557 .53251 L .71975 .54009 L p F P
0 0 0 r
s
.754 .707 .808 r
.62593 .25487 m .63869 .27722 L .6636 .25848 L p F P
0 0 0 r
s
.758 .69 .786 r
.63869 .27722 m .62593 .25487 L .60094 .27344 L p F P
0 0 0 r
s
.647 .762 .933 r
.39025 .53193 m .40476 .54587 L .42906 .53834 L p F P
0 0 0 r
s
.647 .762 .933 r
.40476 .54587 m .39025 .53193 L .36603 .53951 L p F P
0 0 0 r
s
.647 .762 .933 r
.80913 .53134 m .82018 .54529 L .84636 .53776 L p F P
0 0 0 r
s
.647 .762 .933 r
.82018 .54529 m .80913 .53134 L .78301 .53893 L p F P
0 0 0 r
s
.691 .748 .895 r
.814 .22617 m .80288 .20933 L .77694 .22012 L p F P
0 0 0 r
s
.647 .762 .933 r
.45359 .53076 m .46758 .54471 L .49219 .53718 L p F P
0 0 0 r
s
.647 .762 .933 r
.46758 .54471 m .45359 .53076 L .42906 .53834 L p F P
0 0 0 r
s
.647 .762 .933 r
.87278 .53017 m .88331 .54414 L .9098 .5366 L p F P
0 0 0 r
s
.647 .762 .933 r
.88331 .54414 m .87278 .53017 L .84636 .53776 L p F P
0 0 0 r
s
.647 .762 .933 r
.0978 .53017 m .11475 .54414 L .13777 .5366 L p F P
0 0 0 r
s
.702 .745 .885 r
.73958 .21443 m .75128 .23196 L .77694 .22012 L p F P
0 0 0 r
s
.72 .743 .87 r
.75128 .23196 m .73958 .21443 L .71401 .2273 L p F P
0 0 0 r
s
.637 .599 .794 r
.44997 .29323 m .43621 .26345 L .41184 .27221 L p F P
0 0 0 r
s
.643 .624 .815 r
.39781 .24535 m .41184 .27221 L .43621 .26345 L p F P
0 0 0 r
s
.625 .62 .825 r
.41184 .27221 m .39781 .24535 L .37366 .25315 L p F P
0 0 0 r
s
.636 .649 .846 r
.35927 .22943 m .37366 .25315 L .39781 .24535 L p F P
0 0 0 r
s
.625 .651 .856 r
.37366 .25315 m .35927 .22943 L .33529 .23714 L p F P
0 0 0 r
s
.743 .722 .831 r
.65106 .23782 m .6636 .25848 L .68869 .24187 L p F P
0 0 0 r
s
.754 .707 .808 r
.6636 .25848 m .65106 .23782 L .62593 .25487 L p F P
0 0 0 r
s
.647 .762 .933 r
.51702 .52958 m .5305 .54356 L .5554 .53602 L p F P
0 0 0 r
s
.647 .762 .933 r
.5305 .54356 m .51702 .52958 L .49219 .53718 L p F P
0 0 0 r
s
.715 .626 .757 r
.51291 .29949 m .52637 .33091 L .55117 .31253 L p F P
0 0 0 r
s
.692 .606 .755 r
.52637 .33091 m .51291 .29949 L .48816 .31385 L p F P
0 0 0 r
s
.647 .762 .933 r
.161 .52899 m .17744 .54298 L .20076 .53543 L p F P
0 0 0 r
s
.647 .762 .933 r
.17744 .54298 m .161 .52899 L .13777 .5366 L p F P
0 0 0 r
s
.66 .594 .77 r
.48816 .31385 m .47456 .28228 L .44997 .29323 L p F P
0 0 0 r
s
.66 .61 .788 r
.43621 .26345 m .44997 .29323 L .47456 .28228 L p F P
0 0 0 r
s
.647 .762 .933 r
.58053 .52841 m .59349 .5424 L .6187 .53485 L p F P
0 0 0 r
s
.647 .762 .933 r
.59349 .5424 m .58053 .52841 L .5554 .53602 L p F P
0 0 0 r
s
.685 .611 .767 r
.47456 .28228 m .48816 .31385 L .51291 .29949 L p F P
0 0 0 r
s
.638 .679 .872 r
.32046 .21608 m .33529 .23714 L .35927 .22943 L p F P
0 0 0 r
s
.633 .684 .88 r
.33529 .23714 m .32046 .21608 L .29661 .22413 L p F P
0 0 0 r
s
.652 .726 .903 r
.21815 .20419 m .23403 .22182 L .25757 .21342 L p F P
0 0 0 r
s
.653 .73 .906 r
.23403 .22182 m .21815 .20419 L .19469 .21296 L p F P
0 0 0 r
s
.647 .762 .933 r
.22429 .52782 m .24021 .54182 L .26383 .53427 L p F P
0 0 0 r
s
.647 .762 .933 r
.24021 .54182 m .22429 .52782 L .20076 .53543 L p F P
0 0 0 r
s
.647 .762 .933 r
.64414 .52723 m .65658 .54125 L .68209 .53368 L p F P
0 0 0 r
s
.647 .762 .933 r
.65658 .54125 m .64414 .52723 L .6187 .53485 L p F P
0 0 0 r
s
.73 .646 .764 r
.53779 .28322 m .55117 .31253 L .57603 .29297 L p F P
0 0 0 r
s
.715 .626 .757 r
.55117 .31253 m .53779 .28322 L .51291 .29949 L p F P
0 0 0 r
s
.647 .762 .933 r
.28767 .52664 m .30308 .54067 L .327 .5331 L p F P
0 0 0 r
s
.647 .762 .933 r
.30308 .54067 m .28767 .52664 L .26383 .53427 L p F P
0 0 0 r
s
.729 .732 .853 r
.67637 .2225 m .68869 .24187 L .71401 .2273 L p F P
0 0 0 r
s
.743 .722 .831 r
.68869 .24187 m .67637 .2225 L .65106 .23782 L p F P
0 0 0 r
s
.647 .762 .933 r
.70783 .52605 m .71975 .54009 L .74557 .53251 L p F P
0 0 0 r
s
.647 .762 .933 r
.71975 .54009 m .70783 .52605 L .68209 .53368 L p F P
0 0 0 r
s
.647 .762 .933 r
.35113 .52546 m .36603 .53951 L .39025 .53193 L p F P
0 0 0 r
s
.647 .762 .933 r
.36603 .53951 m .35113 .52546 L .327 .5331 L p F P
0 0 0 r
s
.74 .666 .778 r
.56277 .266 m .57603 .29297 L .60094 .27344 L p F P
0 0 0 r
s
.73 .646 .764 r
.57603 .29297 m .56277 .266 L .53779 .28322 L p F P
0 0 0 r
s
.647 .762 .933 r
.77161 .52487 m .78301 .53893 L .80913 .53134 L p F P
0 0 0 r
s
.647 .762 .933 r
.78301 .53893 m .77161 .52487 L .74557 .53251 L p F P
0 0 0 r
s
.645 .705 .89 r
.28133 .20495 m .29661 .22413 L .32046 .21608 L p F P
0 0 0 r
s
.643 .71 .896 r
.29661 .22413 m .28133 .20495 L .25757 .21342 L p F P
0 0 0 r
s
.647 .762 .933 r
.41469 .52428 m .42906 .53834 L .45359 .53076 L p F P
0 0 0 r
s
.647 .762 .933 r
.42906 .53834 m .41469 .52428 L .39025 .53193 L p F P
0 0 0 r
s
.688 .745 .895 r
.76544 .20284 m .77694 .22012 L .80288 .20933 L p F P
0 0 0 r
s
.702 .745 .885 r
.77694 .22012 m .76544 .20284 L .73958 .21443 L p F P
0 0 0 r
s
.647 .762 .933 r
.83548 .52369 m .84636 .53776 L .87278 .53017 L p F P
0 0 0 r
s
.647 .762 .933 r
.84636 .53776 m .83548 .52369 L .80913 .53134 L p F P
0 0 0 r
s
.704 .629 .77 r
.49935 .26931 m .51291 .29949 L .53779 .28322 L p F P
0 0 0 r
s
.685 .611 .767 r
.51291 .29949 m .49935 .26931 L .47456 .28228 L p F P
0 0 0 r
s
.742 .685 .795 r
.58783 .24878 m .60094 .27344 L .62593 .25487 L p F P
0 0 0 r
s
.74 .666 .778 r
.60094 .27344 m .58783 .24878 L .56277 .266 L p F P
0 0 0 r
s
.647 .762 .933 r
.47833 .5231 m .49219 .53718 L .51702 .52958 L p F P
0 0 0 r
s
.647 .762 .933 r
.49219 .53718 m .47833 .5231 L .45359 .53076 L p F P
0 0 0 r
s
.679 .624 .786 r
.46083 .25302 m .47456 .28228 L .49935 .26931 L p F P
0 0 0 r
s
.66 .61 .788 r
.47456 .28228 m .46083 .25302 L .43621 .26345 L p F P
0 0 0 r
s
.647 .762 .933 r
.9098 .5366 m .89945 .52251 L .87278 .53017 L p F P
0 0 0 r
s
.647 .762 .933 r
.12093 .52251 m .13777 .5366 L .161 .52899 L p F P
0 0 0 r
s
.647 .762 .933 r
.13777 .5366 m .12093 .52251 L .0978 .53017 L p F P
0 0 0 r
s
.66 .632 .81 r
.42223 .23642 m .43621 .26345 L .46083 .25302 L p F P
0 0 0 r
s
.643 .624 .815 r
.43621 .26345 m .42223 .23642 L .39781 .24535 L p F P
0 0 0 r
s
.712 .738 .872 r
.7019 .20881 m .71401 .2273 L .73958 .21443 L p F P
0 0 0 r
s
.729 .732 .853 r
.71401 .2273 m .7019 .20881 L .67637 .2225 L p F P
0 0 0 r
s
.647 .762 .933 r
.54207 .52191 m .5554 .53602 L .58053 .52841 L p F P
0 0 0 r
s
.647 .762 .933 r
.5554 .53602 m .54207 .52191 L .51702 .52958 L p F P
0 0 0 r
s
.649 .651 .838 r
.38351 .22107 m .39781 .24535 L .42223 .23642 L p F P
0 0 0 r
s
.636 .649 .846 r
.39781 .24535 m .38351 .22107 L .35927 .22943 L p F P
0 0 0 r
s
.647 .762 .933 r
.18444 .52132 m .20076 .53543 L .22429 .52782 L p F P
0 0 0 r
s
.647 .762 .933 r
.20076 .53543 m .18444 .52132 L .161 .52899 L p F P
0 0 0 r
s
.739 .702 .816 r
.61301 .23227 m .62593 .25487 L .65106 .23782 L p F P
0 0 0 r
s
.742 .685 .795 r
.62593 .25487 m .61301 .23227 L .58783 .24878 L p F P
0 0 0 r
s
.647 .762 .933 r
.60589 .52073 m .6187 .53485 L .64414 .52723 L p F P
0 0 0 r
s
.647 .762 .933 r
.6187 .53485 m .60589 .52073 L .58053 .52841 L p F P
0 0 0 r
s
.647 .762 .933 r
.24803 .52013 m .26383 .53427 L .28767 .52664 L p F P
0 0 0 r
s
.647 .762 .933 r
.26383 .53427 m .24803 .52013 L .22429 .52782 L p F P
0 0 0 r
s
.717 .648 .779 r
.5243 .2549 m .53779 .28322 L .56277 .266 L p F P
0 0 0 r
s
.704 .629 .77 r
.53779 .28322 m .5243 .2549 L .49935 .26931 L p F P
0 0 0 r
s
.652 .723 .901 r
.24183 .19536 m .25757 .21342 L .28133 .20495 L p F P
0 0 0 r
s
.652 .726 .903 r
.25757 .21342 m .24183 .19536 L .21815 .20419 L p F P
0 0 0 r
s
.646 .676 .865 r
.34457 .20772 m .35927 .22943 L .38351 .22107 L p F P
0 0 0 r
s
.638 .679 .872 r
.35927 .22943 m .34457 .20772 L .32046 .21608 L p F P
0 0 0 r
s
.647 .762 .933 r
.6698 .51954 m .68209 .53368 L .70783 .52605 L p F P
0 0 0 r
s
.647 .762 .933 r
.68209 .53368 m .6698 .51954 L .64414 .52723 L p F P
0 0 0 r
s
.647 .762 .933 r
.31172 .51894 m .327 .5331 L .35113 .52546 L p F P
0 0 0 r
s
.647 .762 .933 r
.327 .5331 m .31172 .51894 L .28767 .52664 L p F P
0 0 0 r
s
.647 .762 .933 r
.73381 .51835 m .74557 .53251 L .77161 .52487 L p F P
0 0 0 r
s
.647 .762 .933 r
.74557 .53251 m .73381 .51835 L .70783 .52605 L p F P
0 0 0 r
s
.73 .717 .838 r
.63834 .21691 m .65106 .23782 L .67637 .2225 L p F P
0 0 0 r
s
.739 .702 .816 r
.65106 .23782 m .63834 .21691 L .61301 .23227 L p F P
0 0 0 r
s
.647 .762 .933 r
.37549 .51775 m .39025 .53193 L .41469 .52428 L p F P
0 0 0 r
s
.647 .762 .933 r
.39025 .53193 m .37549 .51775 L .35113 .52546 L p F P
0 0 0 r
s
.688 .745 .895 r
.80288 .20933 m .79157 .19215 L .76544 .20284 L p F P
0 0 0 r
s
.647 .762 .933 r
.7979 .51716 m .80913 .53134 L .83548 .52369 L p F P
0 0 0 r
s
.647 .762 .933 r
.80913 .53134 m .7979 .51716 L .77161 .52487 L p F P
0 0 0 r
s
.695 .64 .79 r
.48566 .24116 m .49935 .26931 L .5243 .2549 L p F P
0 0 0 r
s
.679 .624 .786 r
.49935 .26931 m .48566 .24116 L .46083 .25302 L p F P
0 0 0 r
s
.725 .667 .792 r
.54938 .23978 m .56277 .266 L .58783 .24878 L p F P
0 0 0 r
s
.717 .648 .779 r
.56277 .266 m .54938 .23978 L .5243 .2549 L p F P
0 0 0 r
s
.647 .762 .933 r
.43935 .51656 m .45359 .53076 L .47833 .5231 L p F P
0 0 0 r
s
.647 .762 .933 r
.45359 .53076 m .43935 .51656 L .41469 .52428 L p F P
0 0 0 r
s
.648 .701 .885 r
.30532 .19633 m .32046 .21608 L .34457 .20772 L p F P
0 0 0 r
s
.645 .705 .89 r
.32046 .21608 m .30532 .19633 L .28133 .20495 L p F P
0 0 0 r
s
.697 .741 .886 r
.72769 .19649 m .73958 .21443 L .76544 .20284 L p F P
0 0 0 r
s
.712 .738 .872 r
.73958 .21443 m .72769 .19649 L .7019 .20881 L p F P
0 0 0 r
s
.647 .762 .933 r
.86208 .51597 m .87278 .53017 L .89945 .52251 L p F P
0 0 0 r
s
.647 .762 .933 r
.87278 .53017 m .86208 .51597 L .83548 .52369 L p F P
0 0 0 r
s
.647 .762 .933 r
.08056 .51597 m .0978 .53017 L .12093 .52251 L p F P
0 0 0 r
s
.676 .643 .809 r
.4469 .22636 m .46083 .25302 L .48566 .24116 L p F P
0 0 0 r
s
.66 .632 .81 r
.46083 .25302 m .4469 .22636 L .42223 .23642 L p F P
0 0 0 r
s
.647 .762 .933 r
.50331 .51537 m .51702 .52958 L .54207 .52191 L p F P
0 0 0 r
s
.647 .762 .933 r
.51702 .52958 m .50331 .51537 L .47833 .5231 L p F P
0 0 0 r
s
.647 .762 .933 r
.14428 .51477 m .161 .52899 L .18444 .52132 L p F P
0 0 0 r
s
.647 .762 .933 r
.161 .52899 m .14428 .51477 L .12093 .52251 L p F P
0 0 0 r
s
.647 .762 .933 r
.56735 .51417 m .58053 .52841 L .60589 .52073 L p F P
0 0 0 r
s
.647 .762 .933 r
.58053 .52841 m .56735 .51417 L .54207 .52191 L p F P
0 0 0 r
s
.662 .656 .834 r
.40801 .21198 m .42223 .23642 L .4469 .22636 L p F P
0 0 0 r
s
.649 .651 .838 r
.42223 .23642 m .40801 .21198 L .38351 .22107 L p F P
0 0 0 r
s
.728 .685 .809 r
.57459 .22462 m .58783 .24878 L .61301 .23227 L p F P
0 0 0 r
s
.725 .667 .792 r
.58783 .24878 m .57459 .22462 L .54938 .23978 L p F P
0 0 0 r
s
.717 .728 .859 r
.66386 .20286 m .67637 .2225 L .7019 .20881 L p F P
0 0 0 r
s
.73 .717 .838 r
.67637 .2225 m .66386 .20286 L .63834 .21691 L p F P
0 0 0 r
s
.647 .762 .933 r
.2081 .51358 m .22429 .52782 L .24803 .52013 L p F P
0 0 0 r
s
.647 .762 .933 r
.22429 .52782 m .2081 .51358 L .18444 .52132 L p F P
0 0 0 r
s
.647 .762 .933 r
.63148 .51298 m .64414 .52723 L .6698 .51954 L p F P
0 0 0 r
s
.647 .762 .933 r
.64414 .52723 m .63148 .51298 L .60589 .52073 L p F P
0 0 0 r
s
.706 .657 .798 r
.51068 .22828 m .5243 .2549 L .54938 .23978 L p F P
0 0 0 r
s
.695 .64 .79 r
.5243 .2549 m .51068 .22828 L .48566 .24116 L p F P
0 0 0 r
s
.647 .762 .933 r
.272 .51238 m .28767 .52664 L .31172 .51894 L p F P
0 0 0 r
s
.647 .762 .933 r
.28767 .52664 m .272 .51238 L .24803 .52013 L p F P
0 0 0 r
s
.652 .719 .898 r
.26573 .18645 m .28133 .20495 L .30532 .19633 L p F P
0 0 0 r
s
.652 .723 .901 r
.28133 .20495 m .26573 .18645 L .24183 .19536 L p F P
0 0 0 r
s
.647 .762 .933 r
.69571 .51178 m .70783 .52605 L .73381 .51835 L p F P
0 0 0 r
s
.647 .762 .933 r
.70783 .52605 m .69571 .51178 L .6698 .51954 L p F P
0 0 0 r
s
.654 .677 .859 r
.36892 .19894 m .38351 .22107 L .40801 .21198 L p F P
0 0 0 r
s
.646 .676 .865 r
.38351 .22107 m .36892 .19894 L .34457 .20772 L p F P
0 0 0 r
s
.647 .762 .933 r
.33599 .51118 m .35113 .52546 L .37549 .51775 L p F P
0 0 0 r
s
.647 .762 .933 r
.35113 .52546 m .33599 .51118 L .31172 .51894 L p F P
0 0 0 r
s
.647 .762 .933 r
.76002 .51058 m .77161 .52487 L .7979 .51716 L p F P
0 0 0 r
s
.647 .762 .933 r
.77161 .52487 m .76002 .51058 L .73381 .51835 L p F P
0 0 0 r
s
.724 .702 .829 r
.59994 .20995 m .61301 .23227 L .63834 .21691 L p F P
0 0 0 r
s
.728 .685 .809 r
.61301 .23227 m .59994 .20995 L .57459 .22462 L p F P
0 0 0 r
s
.684 .743 .895 r
.75374 .18521 m .76544 .20284 L .79157 .19215 L p F P
0 0 0 r
s
.697 .741 .886 r
.76544 .20284 m .75374 .18521 L .72769 .19649 L p F P
0 0 0 r
s
.647 .762 .933 r
.40007 .50998 m .41469 .52428 L .43935 .51656 L p F P
0 0 0 r
s
.647 .762 .933 r
.41469 .52428 m .40007 .50998 L .37549 .51775 L p F P
0 0 0 r
s
.647 .762 .933 r
.82442 .50938 m .83548 .52369 L .86208 .51597 L p F P
0 0 0 r
s
.647 .762 .933 r
.83548 .52369 m .82442 .50938 L .7979 .51716 L p F P
0 0 0 r
s
.688 .656 .813 r
.47179 .21532 m .48566 .24116 L .51068 .22828 L p F P
0 0 0 r
s
.676 .643 .809 r
.48566 .24116 m .47179 .21532 L .4469 .22636 L p F P
0 0 0 r
s
.647 .762 .933 r
.46425 .50877 m .47833 .5231 L .50331 .51537 L p F P
0 0 0 r
s
.647 .762 .933 r
.47833 .5231 m .46425 .50877 L .43935 .51656 L p F P
0 0 0 r
s
.703 .735 .876 r
.68961 .19005 m .7019 .20881 L .72769 .19649 L p F P
0 0 0 r
s
.717 .728 .859 r
.7019 .20881 m .68961 .19005 L .66386 .20286 L p F P
0 0 0 r
s
.652 .699 .88 r
.32955 .1875 m .34457 .20772 L .36892 .19894 L p F P
0 0 0 r
s
.648 .701 .885 r
.34457 .20772 m .32955 .1875 L .30532 .19633 L p F P
0 0 0 r
s
.647 .762 .933 r
.89945 .52251 m .88892 .50817 L .86208 .51597 L p F P
0 0 0 r
s
.647 .762 .933 r
.10381 .50817 m .12093 .52251 L .14428 .51477 L p F P
0 0 0 r
s
.647 .762 .933 r
.12093 .52251 m .10381 .50817 L .08056 .51597 L p F P
0 0 0 r
s
.713 .674 .811 r
.53586 .21486 m .54938 .23978 L .57459 .22462 L p F P
0 0 0 r
s
.706 .657 .798 r
.54938 .23978 m .53586 .21486 L .51068 .22828 L p F P
0 0 0 r
s
.647 .762 .933 r
.52851 .50757 m .54207 .52191 L .56735 .51417 L p F P
0 0 0 r
s
.647 .762 .933 r
.54207 .52191 m .52851 .50757 L .50331 .51537 L p F P
0 0 0 r
s
.647 .762 .933 r
.16785 .50697 m .18444 .52132 L .2081 .51358 L p F P
0 0 0 r
s
.647 .762 .933 r
.18444 .52132 m .16785 .50697 L .14428 .51477 L p F P
0 0 0 r
s
.673 .665 .834 r
.43275 .20215 m .4469 .22636 L .47179 .21532 L p F P
0 0 0 r
s
.662 .656 .834 r
.4469 .22636 m .43275 .20215 L .40801 .21198 L p F P
0 0 0 r
s
.647 .762 .933 r
.59286 .50636 m .60589 .52073 L .63148 .51298 L p F P
0 0 0 r
s
.647 .762 .933 r
.60589 .52073 m .59286 .50636 L .56735 .51417 L p F P
0 0 0 r
s
.717 .716 .849 r
.62546 .1961 m .63834 .21691 L .66386 .20286 L p F P
0 0 0 r
s
.724 .702 .829 r
.63834 .21691 m .62546 .1961 L .59994 .20995 L p F P
0 0 0 r
s
.647 .762 .933 r
.23197 .50576 m .24803 .52013 L .272 .51238 L p F P
0 0 0 r
s
.647 .762 .933 r
.24803 .52013 m .23197 .50576 L .2081 .51358 L p F P
0 0 0 r
s
.647 .762 .933 r
.65731 .50516 m .6698 .51954 L .69571 .51178 L p F P
0 0 0 r
s
.647 .762 .933 r
.6698 .51954 m .65731 .50516 L .63148 .51298 L p F P
0 0 0 r
s
.647 .762 .933 r
.29618 .50455 m .31172 .51894 L .33599 .51118 L p F P
0 0 0 r
s
.647 .762 .933 r
.31172 .51894 m .29618 .50455 L .272 .51238 L p F P
0 0 0 r
s
.647 .762 .933 r
.72185 .50395 m .73381 .51835 L .76002 .51058 L p F P
0 0 0 r
s
.647 .762 .933 r
.73381 .51835 m .72185 .50395 L .69571 .51178 L p F P
0 0 0 r
s
.663 .68 .856 r
.39351 .18969 m .40801 .21198 L .43275 .20215 L p F P
0 0 0 r
s
.654 .677 .859 r
.40801 .21198 m .39351 .18969 L .36892 .19894 L p F P
0 0 0 r
s
.714 .691 .826 r
.5612 .20139 m .57459 .22462 L .59994 .20995 L p F P
0 0 0 r
s
.713 .674 .811 r
.57459 .22462 m .5612 .20139 L .53586 .21486 L p F P
0 0 0 r
s
.654 .717 .894 r
.28986 .17742 m .30532 .19633 L .32955 .1875 L p F P
0 0 0 r
s
.652 .719 .898 r
.30532 .19633 m .28986 .17742 L .26573 .18645 L p F P
0 0 0 r
s
.697 .671 .821 r
.49689 .20358 m .51068 .22828 L .53586 .21486 L p F P
0 0 0 r
s
.688 .656 .813 r
.51068 .22828 m .49689 .20358 L .47179 .21532 L p F P
0 0 0 r
s
.647 .762 .933 r
.36049 .50334 m .37549 .51775 L .40007 .50998 L p F P
0 0 0 r
s
.647 .762 .933 r
.37549 .51775 m .36049 .50334 L .33599 .51118 L p F P
0 0 0 r
s
.684 .743 .895 r
.79157 .19215 m .78006 .17463 L .75374 .18521 L p F P
0 0 0 r
s
.647 .762 .933 r
.78647 .50274 m .7979 .51716 L .82442 .50938 L p F P
0 0 0 r
s
.647 .762 .933 r
.7979 .51716 m .78647 .50274 L .76002 .51058 L p F P
0 0 0 r
s
.691 .739 .888 r
.7156 .17828 m .72769 .19649 L .75374 .18521 L p F P
0 0 0 r
s
.703 .735 .876 r
.72769 .19649 m .7156 .17828 L .68961 .19005 L p F P
0 0 0 r
s
.647 .762 .933 r
.42488 .50213 m .43935 .51656 L .46425 .50877 L p F P
0 0 0 r
s
.647 .762 .933 r
.43935 .51656 m .42488 .50213 L .40007 .50998 L p F P
0 0 0 r
s
.647 .762 .933 r
.85119 .50152 m .86208 .51597 L .88892 .50817 L p F P
0 0 0 r
s
.647 .762 .933 r
.86208 .51597 m .85119 .50152 L .82442 .50938 L p F P
0 0 0 r
s
.647 .762 .933 r
.06303 .50152 m .08056 .51597 L .10381 .50817 L p F P
0 0 0 r
s
.706 .727 .866 r
.65118 .18318 m .66386 .20286 L .68961 .19005 L p F P
0 0 0 r
s
.717 .716 .849 r
.66386 .20286 m .65118 .18318 L .62546 .1961 L p F P
0 0 0 r
s
.647 .762 .933 r
.48937 .50092 m .50331 .51537 L .52851 .50757 L p F P
0 0 0 r
s
.647 .762 .933 r
.50331 .51537 m .48937 .50092 L .46425 .50877 L p F P
0 0 0 r
s
.647 .762 .933 r
.12728 .50031 m .14428 .51477 L .16785 .50697 L p F P
0 0 0 r
s
.647 .762 .933 r
.14428 .51477 m .12728 .50031 L .10381 .50817 L p F P
0 0 0 r
s
.658 .699 .877 r
.35402 .17839 m .36892 .19894 L .39351 .18969 L p F P
0 0 0 r
s
.652 .699 .88 r
.36892 .19894 m .35402 .17839 L .32955 .1875 L p F P
0 0 0 r
s
.682 .675 .837 r
.45772 .19166 m .47179 .21532 L .49689 .20358 L p F P
0 0 0 r
s
.673 .665 .834 r
.47179 .21532 m .45772 .19166 L .43275 .20215 L p F P
0 0 0 r
s
.647 .762 .933 r
.55394 .4997 m .56735 .51417 L .59286 .50636 L p F P
0 0 0 r
s
.647 .762 .933 r
.56735 .51417 m .55394 .4997 L .52851 .50757 L p F P
0 0 0 r
s
.647 .762 .933 r
.19163 .49909 m .2081 .51358 L .23197 .50576 L p F P
0 0 0 r
s
.647 .762 .933 r
.2081 .51358 m .19163 .49909 L .16785 .50697 L p F P
0 0 0 r
s
.711 .706 .844 r
.58671 .18823 m .59994 .20995 L .62546 .1961 L p F P
0 0 0 r
s
.714 .691 .826 r
.59994 .20995 m .58671 .18823 L .5612 .20139 L p F P
0 0 0 r
s
.647 .762 .933 r
.61861 .49848 m .63148 .51298 L .65731 .50516 L p F P
0 0 0 r
s
.647 .762 .933 r
.63148 .51298 m .61861 .49848 L .59286 .50636 L p F P
0 0 0 r
s
.701 .685 .832 r
.52218 .19145 m .53586 .21486 L .5612 .20139 L p F P
0 0 0 r
s
.697 .671 .821 r
.53586 .21486 m .52218 .19145 L .49689 .20358 L p F P
0 0 0 r
s
.647 .762 .933 r
.25606 .49787 m .272 .51238 L .29618 .50455 L p F P
0 0 0 r
s
.647 .762 .933 r
.272 .51238 m .25606 .49787 L .23197 .50576 L p F P
0 0 0 r
s
.647 .762 .933 r
.68337 .49726 m .69571 .51178 L .72185 .50395 L p F P
0 0 0 r
s
.647 .762 .933 r
.69571 .51178 m .68337 .49726 L .65731 .50516 L p F P
0 0 0 r
s
.647 .762 .933 r
.32059 .49665 m .33599 .51118 L .36049 .50334 L p F P
0 0 0 r
s
.647 .762 .933 r
.33599 .51118 m .32059 .49665 L .29618 .50455 L p F P
0 0 0 r
s
.671 .686 .856 r
.41835 .17995 m .43275 .20215 L .45772 .19166 L p F P
0 0 0 r
s
.663 .68 .856 r
.43275 .20215 m .41835 .17995 L .39351 .18969 L p F P
0 0 0 r
s
.647 .762 .933 r
.74823 .49604 m .76002 .51058 L .78647 .50274 L p F P
0 0 0 r
s
.647 .762 .933 r
.76002 .51058 m .74823 .49604 L .72185 .50395 L p F P
0 0 0 r
s
.68 .741 .897 r
.74185 .16729 m .75374 .18521 L .78006 .17463 L p F P
0 0 0 r
s
.691 .739 .888 r
.75374 .18521 m .74185 .16729 L .7156 .17828 L p F P
0 0 0 r
s
.657 .715 .891 r
.31422 .16824 m .32955 .1875 L .35402 .17839 L p F P
0 0 0 r
s
.654 .717 .894 r
.32955 .1875 m .31422 .16824 L .28986 .17742 L p F P
0 0 0 r
s
.647 .762 .933 r
.38521 .49543 m .40007 .50998 L .42488 .50213 L p F P
0 0 0 r
s
.647 .762 .933 r
.40007 .50998 m .38521 .49543 L .36049 .50334 L p F P
0 0 0 r
s
.695 .734 .881 r
.67713 .17115 m .68961 .19005 L .7156 .17828 L p F P
0 0 0 r
s
.706 .727 .866 r
.68961 .19005 m .67713 .17115 L .65118 .18318 L p F P
0 0 0 r
s
.647 .762 .933 r
.81317 .49482 m .82442 .50938 L .85119 .50152 L p F P
0 0 0 r
s
.647 .762 .933 r
.82442 .50938 m .81317 .49482 L .78647 .50274 L p F P
0 0 0 r
s
.647 .762 .933 r
.44992 .49421 m .46425 .50877 L .48937 .50092 L p F P
0 0 0 r
s
.647 .762 .933 r
.46425 .50877 m .44992 .49421 L .42488 .50213 L p F P
0 0 0 r
s
.704 .718 .86 r
.61241 .17561 m .62546 .1961 L .65118 .18318 L p F P
0 0 0 r
s
.711 .706 .844 r
.62546 .1961 m .61241 .17561 L .58671 .18823 L p F P
0 0 0 r
s
.647 .762 .933 r
.88892 .50817 m .87821 .4936 L .85119 .50152 L p F P
0 0 0 r
s
.647 .762 .933 r
.0864 .4936 m .10381 .50817 L .12728 .50031 L p F P
0 0 0 r
s
.647 .762 .933 r
.10381 .50817 m .0864 .4936 L .06303 .50152 L p F P
0 0 0 r
s
.688 .687 .843 r
.48291 .1807 m .49689 .20358 L .52218 .19145 L p F P
0 0 0 r
s
.682 .675 .837 r
.49689 .20358 m .48291 .1807 L .45772 .19166 L p F P
0 0 0 r
s
.647 .762 .933 r
.51472 .49298 m .52851 .50757 L .55394 .4997 L p F P
0 0 0 r
s
.647 .762 .933 r
.52851 .50757 m .51472 .49298 L .48937 .50092 L p F P
0 0 0 r
s
.702 .7 .845 r
.54765 .17925 m .5612 .20139 L .58671 .18823 L p F P
0 0 0 r
s
.701 .685 .832 r
.5612 .20139 m .54765 .17925 L .52218 .19145 L p F P
0 0 0 r
s
.647 .762 .933 r
.15097 .49237 m .16785 .50697 L .19163 .49909 L p F P
0 0 0 r
s
.647 .762 .933 r
.16785 .50697 m .15097 .49237 L .12728 .50031 L p F P
0 0 0 r
s
.663 .701 .875 r
.37873 .16897 m .39351 .18969 L .41835 .17995 L p F P
0 0 0 r
s
.658 .699 .877 r
.39351 .18969 m .37873 .16897 L .35402 .17839 L p F P
0 0 0 r
s
.647 .762 .933 r
.57961 .49176 m .59286 .50636 L .61861 .49848 L p F P
0 0 0 r
s
.647 .762 .933 r
.59286 .50636 m .57961 .49176 L .55394 .4997 L p F P
0 0 0 r
s
.647 .762 .933 r
.21563 .49114 m .23197 .50576 L .25606 .49787 L p F P
0 0 0 r
s
.647 .762 .933 r
.23197 .50576 m .21563 .49114 L .19163 .49909 L p F P
0 0 0 r
s
.647 .762 .933 r
.6446 .49053 m .65731 .50516 L .68337 .49726 L p F P
0 0 0 r
s
.647 .762 .933 r
.65731 .50516 m .6446 .49053 L .61861 .49848 L p F P
0 0 0 r
s
.647 .762 .933 r
.28038 .48991 m .29618 .50455 L .32059 .49665 L p F P
0 0 0 r
s
.647 .762 .933 r
.29618 .50455 m .28038 .48991 L .25606 .49787 L p F P
0 0 0 r
s
.647 .762 .933 r
.70968 .4893 m .72185 .50395 L .74823 .49604 L p F P
0 0 0 r
s
.647 .762 .933 r
.72185 .50395 m .70968 .4893 L .68337 .49726 L p F P
0 0 0 r
s
.677 .694 .858 r
.44342 .16979 m .45772 .19166 L .48291 .1807 L p F P
0 0 0 r
s
.671 .686 .856 r
.45772 .19166 m .44342 .16979 L .41835 .17995 L p F P
0 0 0 r
s
.647 .762 .933 r
.34522 .48868 m .36049 .50334 L .38521 .49543 L p F P
0 0 0 r
s
.647 .762 .933 r
.36049 .50334 m .34522 .48868 L .32059 .49665 L p F P
0 0 0 r
s
.68 .741 .897 r
.78006 .17463 m .76837 .15683 L .74185 .16729 L p F P
0 0 0 r
s
.685 .738 .891 r
.70332 .15986 m .7156 .17828 L .74185 .16729 L p F P
0 0 0 r
s
.695 .734 .881 r
.7156 .17828 m .70332 .15986 L .67713 .17115 L p F P
0 0 0 r
s
.647 .762 .933 r
.77485 .48806 m .78647 .50274 L .81317 .49482 L p F P
0 0 0 r
s
.647 .762 .933 r
.78647 .50274 m .77485 .48806 L .74823 .49604 L p F P
0 0 0 r
s
.696 .728 .875 r
.63832 .16362 m .65118 .18318 L .67713 .17115 L p F P
0 0 0 r
s
.704 .718 .86 r
.65118 .18318 m .63832 .16362 L .61241 .17561 L p F P
0 0 0 r
s
.647 .762 .933 r
.41016 .48745 m .42488 .50213 L .44992 .49421 L p F P
0 0 0 r
s
.647 .762 .933 r
.42488 .50213 m .41016 .48745 L .38521 .49543 L p F P
0 0 0 r
s
.66 .715 .889 r
.33881 .15887 m .35402 .17839 L .37873 .16897 L p F P
0 0 0 r
s
.657 .715 .891 r
.35402 .17839 m .33881 .15887 L .31422 .16824 L p F P
0 0 0 r
s
.691 .698 .852 r
.50831 .16946 m .52218 .19145 L .54765 .17925 L p F P
0 0 0 r
s
.688 .687 .843 r
.52218 .19145 m .50831 .16946 L .48291 .1807 L p F P
0 0 0 r
s
.699 .712 .859 r
.57331 .16723 m .58671 .18823 L .61241 .17561 L p F P
0 0 0 r
s
.702 .7 .845 r
.58671 .18823 m .57331 .16723 L .54765 .17925 L p F P
0 0 0 r
s
.647 .762 .933 r
.84012 .48683 m .85119 .50152 L .87821 .4936 L p F P
0 0 0 r
s
.647 .762 .933 r
.85119 .50152 m .84012 .48683 L .81317 .49482 L p F P
0 0 0 r
s
.647 .762 .933 r
.0452 .48683 m .06303 .50152 L .0864 .4936 L p F P
0 0 0 r
s
.647 .762 .933 r
.47519 .48621 m .48937 .50092 L .51472 .49298 L p F P
0 0 0 r
s
.647 .762 .933 r
.48937 .50092 m .47519 .48621 L .44992 .49421 L p F P
0 0 0 r
s
.647 .762 .933 r
.10999 .4856 m .12728 .50031 L .15097 .49237 L p F P
0 0 0 r
s
.647 .762 .933 r
.12728 .50031 m .10999 .4856 L .0864 .4936 L p F P
0 0 0 r
s
.647 .762 .933 r
.54031 .48498 m .55394 .4997 L .57961 .49176 L p F P
0 0 0 r
s
.647 .762 .933 r
.55394 .4997 m .54031 .48498 L .51472 .49298 L p F P
0 0 0 r
s
.668 .705 .874 r
.40368 .15924 m .41835 .17995 L .44342 .16979 L p F P
0 0 0 r
s
.663 .701 .875 r
.41835 .17995 m .40368 .15924 L .37873 .16897 L p F P
0 0 0 r
s
.647 .762 .933 r
.17488 .48436 m .19163 .49909 L .21563 .49114 L p F P
0 0 0 r
s
.647 .762 .933 r
.19163 .49909 m .17488 .48436 L .15097 .49237 L p F P
0 0 0 r
s
.647 .762 .933 r
.60552 .48374 m .61861 .49848 L .6446 .49053 L p F P
0 0 0 r
s
.647 .762 .933 r
.61861 .49848 m .60552 .48374 L .57961 .49176 L p F P
0 0 0 r
s
.647 .762 .933 r
.23985 .48312 m .25606 .49787 L .28038 .48991 L p F P
0 0 0 r
s
.647 .762 .933 r
.25606 .49787 m .23985 .48312 L .21563 .49114 L p F P
0 0 0 r
s
.647 .762 .933 r
.67083 .4825 m .68337 .49726 L .70968 .4893 L p F P
0 0 0 r
s
.647 .762 .933 r
.68337 .49726 m .67083 .4825 L .6446 .49053 L p F P
0 0 0 r
s
.681 .702 .863 r
.46872 .15931 m .48291 .1807 L .50831 .16946 L p F P
0 0 0 r
s
.677 .694 .858 r
.48291 .1807 m .46872 .15931 L .44342 .16979 L p F P
0 0 0 r
s
.647 .762 .933 r
.30492 .48188 m .32059 .49665 L .34522 .48868 L p F P
0 0 0 r
s
.647 .762 .933 r
.32059 .49665 m .30492 .48188 L .28038 .48991 L p F P
0 0 0 r
s
.677 .74 .899 r
.72976 .14912 m .74185 .16729 L .76837 .15683 L p F P
0 0 0 r
s
.685 .738 .891 r
.74185 .16729 m .72976 .14912 L .70332 .15986 L p F P
0 0 0 r
s
.647 .762 .933 r
.73623 .48126 m .74823 .49604 L .77485 .48806 L p F P
0 0 0 r
s
.647 .762 .933 r
.74823 .49604 m .73623 .48126 L .70968 .4893 L p F P
0 0 0 r
s
.687 .734 .887 r
.66446 .15221 m .67713 .17115 L .70332 .15986 L p F P
0 0 0 r
s
.696 .728 .875 r
.67713 .17115 m .66446 .15221 L .63832 .16362 L p F P
0 0 0 r
s
.693 .722 .872 r
.59918 .15553 m .61241 .17561 L .63832 .16362 L p F P
0 0 0 r
s
.699 .712 .859 r
.61241 .17561 m .59918 .15553 L .57331 .16723 L p F P
0 0 0 r
s
.691 .71 .862 r
.53391 .15814 m .54765 .17925 L .57331 .16723 L p F P
0 0 0 r
s
.691 .698 .852 r
.54765 .17925 m .53391 .15814 L .50831 .16946 L p F P
0 0 0 r
s
.647 .762 .933 r
.37008 .48063 m .38521 .49543 L .41016 .48745 L p F P
0 0 0 r
s
.647 .762 .933 r
.38521 .49543 m .37008 .48063 L .34522 .48868 L p F P
0 0 0 r
s
.647 .762 .933 r
.80173 .48001 m .81317 .49482 L .84012 .48683 L p F P
0 0 0 r
s
.647 .762 .933 r
.81317 .49482 m .80173 .48001 L .77485 .48806 L p F P
0 0 0 r
s
.647 .762 .933 r
.43534 .47939 m .44992 .49421 L .47519 .48621 L p F P
0 0 0 r
s
.647 .762 .933 r
.44992 .49421 m .43534 .47939 L .41016 .48745 L p F P
0 0 0 r
s
.663 .716 .888 r
.36365 .14928 m .37873 .16897 L .40368 .15924 L p F P
0 0 0 r
s
.66 .715 .889 r
.37873 .16897 m .36365 .14928 L .33881 .15887 L p F P
0 0 0 r
s
.647 .762 .933 r
.87821 .4936 m .86732 .47877 L .84012 .48683 L p F P
0 0 0 r
s
.647 .762 .933 r
.06869 .47877 m .0864 .4936 L .10999 .4856 L p F P
0 0 0 r
s
.647 .762 .933 r
.0864 .4936 m .06869 .47877 L .0452 .48683 L p F P
0 0 0 r
s
.647 .762 .933 r
.50069 .47814 m .51472 .49298 L .54031 .48498 L p F P
0 0 0 r
s
.647 .762 .933 r
.51472 .49298 m .50069 .47814 L .47519 .48621 L p F P
0 0 0 r
s
.647 .762 .933 r
.1338 .47752 m .15097 .49237 L .17488 .48436 L p F P
0 0 0 r
s
.647 .762 .933 r
.15097 .49237 m .1338 .47752 L .10999 .4856 L p F P
0 0 0 r
s
.647 .762 .933 r
.56614 .4769 m .57961 .49176 L .60552 .48374 L p F P
0 0 0 r
s
.647 .762 .933 r
.57961 .49176 m .56614 .4769 L .54031 .48498 L p F P
0 0 0 r
s
.672 .71 .876 r
.42886 .14923 m .44342 .16979 L .46872 .15931 L p F P
0 0 0 r
s
.668 .705 .874 r
.44342 .16979 m .42886 .14923 L .40368 .15924 L p F P
0 0 0 r
s
.647 .762 .933 r
.19901 .47627 m .21563 .49114 L .23985 .48312 L p F P
0 0 0 r
s
.647 .762 .933 r
.21563 .49114 m .19901 .47627 L .17488 .48436 L p F P
0 0 0 r
s
.647 .762 .933 r
.63167 .47565 m .6446 .49053 L .67083 .4825 L p F P
0 0 0 r
s
.647 .762 .933 r
.6446 .49053 m .63167 .47565 L .60552 .48374 L p F P
0 0 0 r
s
.647 .762 .933 r
.2643 .47502 m .28038 .48991 L .30492 .48188 L p F P
0 0 0 r
s
.647 .762 .933 r
.28038 .48991 m .2643 .47502 L .23985 .48312 L p F P
0 0 0 r
s
.682 .711 .87 r
.49423 .14862 m .50831 .16946 L .53391 .15814 L p F P
0 0 0 r
s
.681 .702 .863 r
.50831 .16946 m .49423 .14862 L .46872 .15931 L p F P
0 0 0 r
s
.647 .762 .933 r
.69731 .47439 m .70968 .4893 L .73623 .48126 L p F P
0 0 0 r
s
.647 .762 .933 r
.70968 .4893 m .69731 .47439 L .67083 .4825 L p F P
0 0 0 r
s
.679 .738 .895 r
.69084 .1413 m .70332 .15986 L .72976 .14912 L p F P
0 0 0 r
s
.687 .734 .887 r
.70332 .15986 m .69084 .1413 L .66446 .15221 L p F P
0 0 0 r
s
.687 .73 .883 r
.62527 .14422 m .63832 .16362 L .66446 .15221 L p F P
0 0 0 r
s
.693 .722 .872 r
.63832 .16362 m .62527 .14422 L .59918 .15553 L p F P
0 0 0 r
s
.688 .719 .873 r
.55972 .1469 m .57331 .16723 L .59918 .15553 L p F P
0 0 0 r
s
.691 .71 .862 r
.57331 .16723 m .55972 .1469 L .53391 .15814 L p F P
0 0 0 r
s
.677 .74 .899 r
.76837 .15683 m .75647 .13875 L .72976 .14912 L p F P
0 0 0 r
s
.647 .762 .933 r
.32969 .47377 m .34522 .48868 L .37008 .48063 L p F P
0 0 0 r
s
.647 .762 .933 r
.34522 .48868 m .32969 .47377 L .30492 .48188 L p F P
0 0 0 r
s
.647 .762 .933 r
.76303 .47314 m .77485 .48806 L .80173 .48001 L p F P
0 0 0 r
s
.647 .762 .933 r
.77485 .48806 m .76303 .47314 L .73623 .48126 L p F P
0 0 0 r
s
.647 .762 .933 r
.39518 .47251 m .41016 .48745 L .43534 .47939 L p F P
0 0 0 r
s
.647 .762 .933 r
.41016 .48745 m .39518 .47251 L .37008 .48063 L p F P
0 0 0 r
s
.647 .762 .933 r
.82886 .47189 m .84012 .48683 L .86732 .47877 L p F P
0 0 0 r
s
.647 .762 .933 r
.84012 .48683 m .82886 .47189 L .80173 .48001 L p F P
0 0 0 r
s
.647 .762 .933 r
.02706 .47189 m .0452 .48683 L .06869 .47877 L p F P
0 0 0 r
s
.666 .719 .888 r
.38872 .13949 m .40368 .15924 L .42886 .14923 L p F P
0 0 0 r
s
.663 .716 .888 r
.40368 .15924 m .38872 .13949 L .36365 .14928 L p F P
0 0 0 r
s
.647 .762 .933 r
.46076 .47126 m .47519 .48621 L .50069 .47814 L p F P
0 0 0 r
s
.647 .762 .933 r
.47519 .48621 m .46076 .47126 L .43534 .47939 L p F P
0 0 0 r
s
.647 .762 .933 r
.0924 .47063 m .10999 .4856 L .1338 .47752 L p F P
0 0 0 r
s
.647 .762 .933 r
.10999 .4856 m .0924 .47063 L .06869 .47877 L p F P
0 0 0 r
s
.647 .762 .933 r
.52644 .47 m .54031 .48498 L .56614 .4769 L p F P
0 0 0 r
s
.647 .762 .933 r
.54031 .48498 m .52644 .47 L .50069 .47814 L p F P
0 0 0 r
s
.647 .762 .933 r
.15783 .46937 m .17488 .48436 L .19901 .47627 L p F P
0 0 0 r
s
.647 .762 .933 r
.17488 .48436 m .15783 .46937 L .1338 .47752 L p F P
0 0 0 r
s
.675 .715 .879 r
.45428 .13899 m .46872 .15931 L .49423 .14862 L p F P
0 0 0 r
s
.672 .71 .876 r
.46872 .15931 m .45428 .13899 L .42886 .14923 L p F P
0 0 0 r
s
.647 .762 .933 r
.59221 .46874 m .60552 .48374 L .63167 .47565 L p F P
0 0 0 r
s
.647 .762 .933 r
.60552 .48374 m .59221 .46874 L .56614 .4769 L p F P
0 0 0 r
s
.647 .762 .933 r
.22336 .46811 m .23985 .48312 L .2643 .47502 L p F P
0 0 0 r
s
.647 .762 .933 r
.23985 .48312 m .22336 .46811 L .19901 .47627 L p F P
0 0 0 r
s
.682 .719 .877 r
.51997 .13785 m .53391 .15814 L .55972 .1469 L p F P
0 0 0 r
s
.682 .711 .87 r
.53391 .15814 m .51997 .13785 L .49423 .14862 L p F P
0 0 0 r
s
.647 .762 .933 r
.65807 .46748 m .67083 .4825 L .69731 .47439 L p F P
0 0 0 r
s
.647 .762 .933 r
.67083 .4825 m .65807 .46748 L .63167 .47565 L p F P
0 0 0 r
s
.684 .727 .883 r
.58576 .13582 m .59918 .15553 L .62527 .14422 L p F P
0 0 0 r
s
.688 .719 .873 r
.59918 .15553 m .58576 .13582 L .55972 .1469 L p F P
0 0 0 r
s
.68 .735 .892 r
.65159 .13326 m .66446 .15221 L .69084 .1413 L p F P
0 0 0 r
s
.687 .73 .883 r
.66446 .15221 m .65159 .13326 L .62527 .14422 L p F P
0 0 0 r
s
.647 .762 .933 r
.28898 .46685 m .30492 .48188 L .32969 .47377 L p F P
0 0 0 r
s
.647 .762 .933 r
.30492 .48188 m .28898 .46685 L .2643 .47502 L p F P
0 0 0 r
s
.673 .74 .901 r
.71748 .13074 m .72976 .14912 L .75647 .13875 L p F P
0 0 0 r
s
.679 .738 .895 r
.72976 .14912 m .71748 .13074 L .69084 .1413 L p F P
0 0 0 r
s
.647 .762 .933 r
.72403 .46621 m .73623 .48126 L .76303 .47314 L p F P
0 0 0 r
s
.647 .762 .933 r
.73623 .48126 m .72403 .46621 L .69731 .47439 L p F P
0 0 0 r
s
.647 .762 .933 r
.3547 .46558 m .37008 .48063 L .39518 .47251 L p F P
0 0 0 r
s
.647 .762 .933 r
.37008 .48063 m .3547 .46558 L .32969 .47377 L p F P
0 0 0 r
s
.647 .762 .933 r
.79009 .46495 m .80173 .48001 L .82886 .47189 L p F P
0 0 0 r
s
.647 .762 .933 r
.80173 .48001 m .79009 .46495 L .76303 .47314 L p F P
0 0 0 r
s
.647 .762 .933 r
.42051 .46431 m .43534 .47939 L .46076 .47126 L p F P
0 0 0 r
s
.647 .762 .933 r
.43534 .47939 m .42051 .46431 L .39518 .47251 L p F P
0 0 0 r
s
.647 .762 .933 r
.86732 .47877 m .85624 .46368 L .82886 .47189 L p F P
0 0 0 r
s
.647 .762 .933 r
.05067 .46368 m .06869 .47877 L .0924 .47063 L p F P
0 0 0 r
s
.647 .762 .933 r
.06869 .47877 m .05067 .46368 L .02706 .47189 L p F P
0 0 0 r
s
.669 .722 .889 r
.41403 .1295 m .42886 .14923 L .45428 .13899 L p F P
0 0 0 r
s
.666 .719 .888 r
.42886 .14923 m .41403 .1295 L .38872 .13949 L p F P
0 0 0 r
s
.647 .762 .933 r
.48642 .46305 m .50069 .47814 L .52644 .47 L p F P
0 0 0 r
s
.647 .762 .933 r
.50069 .47814 m .48642 .46305 L .46076 .47126 L p F P
0 0 0 r
s
.647 .762 .933 r
.11633 .46241 m .1338 .47752 L .15783 .46937 L p F P
0 0 0 r
s
.647 .762 .933 r
.1338 .47752 m .11633 .46241 L .0924 .47063 L p F P
0 0 0 r
s
.647 .762 .933 r
.55242 .46178 m .56614 .4769 L .59221 .46874 L p F P
0 0 0 r
s
.647 .762 .933 r
.56614 .4769 m .55242 .46178 L .52644 .47 L p F P
0 0 0 r
s
.675 .721 .884 r
.47992 .1286 m .49423 .14862 L .51997 .13785 L p F P
0 0 0 r
s
.675 .715 .879 r
.49423 .14862 m .47992 .1286 L .45428 .13899 L p F P
0 0 0 r
s
.647 .762 .933 r
.18209 .46114 m .19901 .47627 L .22336 .46811 L p F P
0 0 0 r
s
.647 .762 .933 r
.19901 .47627 m .18209 .46114 L .15783 .46937 L p F P
0 0 0 r
s
.647 .762 .933 r
.61852 .46051 m .63167 .47565 L .65807 .46748 L p F P
0 0 0 r
s
.647 .762 .933 r
.63167 .47565 m .61852 .46051 L .59221 .46874 L p F P
0 0 0 r
s
.68 .726 .885 r
.54593 .12708 m .55972 .1469 L .58576 .13582 L p F P
0 0 0 r
s
.682 .719 .877 r
.55972 .1469 m .54593 .12708 L .51997 .13785 L p F P
0 0 0 r
s
.679 .733 .891 r
.61202 .12496 m .62527 .14422 L .65159 .13326 L p F P
0 0 0 r
s
.684 .727 .883 r
.62527 .14422 m .61202 .12496 L .58576 .13582 L p F P
0 0 0 r
s
.647 .762 .933 r
.24795 .45987 m .2643 .47502 L .28898 .46685 L p F P
0 0 0 r
s
.647 .762 .933 r
.2643 .47502 m .24795 .45987 L .22336 .46811 L p F P
0 0 0 r
s
.674 .738 .899 r
.67816 .1226 m .69084 .1413 L .71748 .13074 L p F P
0 0 0 r
s
.68 .735 .892 r
.69084 .1413 m .67816 .1226 L .65159 .13326 L p F P
0 0 0 r
s
.647 .762 .933 r
.68472 .45923 m .69731 .47439 L .72403 .46621 L p F P
0 0 0 r
s
.647 .762 .933 r
.69731 .47439 m .68472 .45923 L .65807 .46748 L p F P
0 0 0 r
s
.673 .74 .901 r
.75647 .13875 m .74437 .12041 L .71748 .13074 L p F P
0 0 0 r
s
.647 .762 .933 r
.3139 .45859 m .32969 .47377 L .3547 .46558 L p F P
0 0 0 r
s
.647 .762 .933 r
.32969 .47377 m .3139 .45859 L .28898 .46685 L p F P
0 0 0 r
s
.647 .762 .933 r
.75101 .45796 m .76303 .47314 L .79009 .46495 L p F P
0 0 0 r
s
.647 .762 .933 r
.76303 .47314 m .75101 .45796 L .72403 .46621 L p F P
0 0 0 r
s
.647 .762 .933 r
.37994 .45732 m .39518 .47251 L .42051 .46431 L p F P
0 0 0 r
s
.647 .762 .933 r
.39518 .47251 m .37994 .45732 L .3547 .46558 L p F P
0 0 0 r
s
.647 .762 .933 r
.81739 .45668 m .82886 .47189 L .85624 .46368 L p F P
0 0 0 r
s
.647 .762 .933 r
.82886 .47189 m .81739 .45668 L .79009 .46495 L p F P
0 0 0 r
s
.647 .762 .933 r
.44608 .45604 m .46076 .47126 L .48642 .46305 L p F P
0 0 0 r
s
.647 .762 .933 r
.46076 .47126 m .44608 .45604 L .42051 .46431 L p F P
0 0 0 r
s
.67 .726 .891 r
.43958 .11934 m .45428 .13899 L .47992 .1286 L p F P
0 0 0 r
s
.669 .722 .889 r
.45428 .13899 m .43958 .11934 L .41403 .1295 L p F P
0 0 0 r
s
.647 .762 .933 r
.0745 .4554 m .0924 .47063 L .11633 .46241 L p F P
0 0 0 r
s
.647 .762 .933 r
.0924 .47063 m .0745 .4554 L .05067 .46368 L p F P
0 0 0 r
s
.647 .762 .933 r
.51232 .45476 m .52644 .47 L .55242 .46178 L p F P
0 0 0 r
s
.647 .762 .933 r
.52644 .47 m .51232 .45476 L .48642 .46305 L p F P
0 0 0 r
s
.647 .762 .933 r
.14049 .45412 m .15783 .46937 L .18209 .46114 L p F P
0 0 0 r
s
.647 .762 .933 r
.15783 .46937 m .14049 .45412 L .11633 .46241 L p F P
0 0 0 r
s
.675 .727 .889 r
.5058 .11811 m .51997 .13785 L .54593 .12708 L p F P
0 0 0 r
s
.675 .721 .884 r
.51997 .13785 m .5058 .11811 L .47992 .1286 L p F P
0 0 0 r
s
.647 .762 .933 r
.57866 .45348 m .59221 .46874 L .61852 .46051 L p F P
0 0 0 r
s
.647 .762 .933 r
.59221 .46874 m .57866 .45348 L .55242 .46178 L p F P
0 0 0 r
s
.677 .731 .891 r
.57212 .11638 m .58576 .13582 L .61202 .12496 L p F P
0 0 0 r
s
.68 .726 .885 r
.58576 .13582 m .57212 .11638 L .54593 .12708 L p F P
0 0 0 r
s
.647 .762 .933 r
.20658 .45284 m .22336 .46811 L .24795 .45987 L p F P
0 0 0 r
s
.647 .762 .933 r
.22336 .46811 m .20658 .45284 L .18209 .46114 L p F P
0 0 0 r
s
.674 .737 .897 r
.63852 .11428 m .65159 .13326 L .67816 .1226 L p F P
0 0 0 r
s
.679 .733 .891 r
.65159 .13326 m .63852 .11428 L .61202 .12496 L p F P
0 0 0 r
s
.647 .762 .933 r
.64509 .45219 m .65807 .46748 L .68472 .45923 L p F P
0 0 0 r
s
.647 .762 .933 r
.65807 .46748 m .64509 .45219 L .61852 .46051 L p F P
0 0 0 r
s
.67 .74 .903 r
.70499 .11214 m .71748 .13074 L .74437 .12041 L p F P
0 0 0 r
s
.674 .738 .899 r
.71748 .13074 m .70499 .11214 L .67816 .1226 L p F P
0 0 0 r
s
.647 .762 .933 r
.27277 .45155 m .28898 .46685 L .3139 .45859 L p F P
0 0 0 r
s
.647 .762 .933 r
.28898 .46685 m .27277 .45155 L .24795 .45987 L p F P
0 0 0 r
s
.647 .762 .933 r
.71161 .45091 m .72403 .46621 L .75101 .45796 L p F P
0 0 0 r
s
.647 .762 .933 r
.72403 .46621 m .71161 .45091 L .68472 .45923 L p F P
0 0 0 r
s
.647 .762 .933 r
.33905 .45026 m .3547 .46558 L .37994 .45732 L p F P
0 0 0 r
s
.647 .762 .933 r
.3547 .46558 m .33905 .45026 L .3139 .45859 L p F P
0 0 0 r
s
.647 .762 .933 r
.77824 .44962 m .79009 .46495 L .81739 .45668 L p F P
0 0 0 r
s
.647 .762 .933 r
.79009 .46495 m .77824 .44962 L .75101 .45796 L p F P
0 0 0 r
s
.647 .762 .933 r
.40542 .44898 m .42051 .46431 L .44608 .45604 L p F P
0 0 0 r
s
.647 .762 .933 r
.42051 .46431 m .40542 .44898 L .37994 .45732 L p F P
0 0 0 r
s
.647 .762 .933 r
.85624 .46368 m .84496 .44833 L .81739 .45668 L p F P
0 0 0 r
s
.647 .762 .933 r
.4719 .44769 m .48642 .46305 L .51232 .45476 L p F P
0 0 0 r
s
.647 .762 .933 r
.48642 .46305 m .4719 .44769 L .44608 .45604 L p F P
0 0 0 r
s
.67 .729 .894 r
.46537 .10905 m .47992 .1286 L .5058 .11811 L p F P
0 0 0 r
s
.67 .726 .891 r
.47992 .1286 m .46537 .10905 L .43958 .11934 L p F P
0 0 0 r
s
.647 .762 .933 r
.09856 .44704 m .11633 .46241 L .14049 .45412 L p F P
0 0 0 r
s
.647 .762 .933 r
.11633 .46241 m .09856 .44704 L .0745 .4554 L p F P
0 0 0 r
s
.647 .762 .933 r
.53847 .44639 m .55242 .46178 L .57866 .45348 L p F P
0 0 0 r
s
.647 .762 .933 r
.55242 .46178 m .53847 .44639 L .51232 .45476 L p F P
0 0 0 r
s
.673 .731 .893 r
.53192 .10759 m .54593 .12708 L .57212 .11638 L p F P
0 0 0 r
s
.675 .727 .889 r
.54593 .12708 m .53192 .10759 L .5058 .11811 L p F P
0 0 0 r
s
.647 .762 .933 r
.16488 .44575 m .18209 .46114 L .20658 .45284 L p F P
0 0 0 r
s
.647 .762 .933 r
.18209 .46114 m .16488 .44575 L .14049 .45412 L p F P
0 0 0 r
s
.673 .735 .897 r
.59856 .10576 m .61202 .12496 L .63852 .11428 L p F P
0 0 0 r
s
.677 .731 .891 r
.61202 .12496 m .59856 .10576 L .57212 .11638 L p F P
0 0 0 r
s
.647 .762 .933 r
.60514 .4451 m .61852 .46051 L .64509 .45219 L p F P
0 0 0 r
s
.647 .762 .933 r
.61852 .46051 m .60514 .4451 L .57866 .45348 L p F P
0 0 0 r
s
.647 .762 .933 r
.2313 .44445 m .24795 .45987 L .27277 .45155 L p F P
0 0 0 r
s
.647 .762 .933 r
.24795 .45987 m .2313 .44445 L .20658 .45284 L p F P
0 0 0 r
s
.671 .739 .902 r
.66527 .10375 m .67816 .1226 L .70499 .11214 L p F P
0 0 0 r
s
.674 .737 .897 r
.67816 .1226 m .66527 .10375 L .63852 .11428 L p F P
0 0 0 r
s
.647 .762 .933 r
.6719 .4438 m .68472 .45923 L .71161 .45091 L p F P
0 0 0 r
s
.647 .762 .933 r
.68472 .45923 m .6719 .4438 L .64509 .45219 L p F P
0 0 0 r
s
.67 .74 .903 r
.74437 .12041 m .73207 .1018 L .70499 .11214 L p F P
0 0 0 r
s
.647 .762 .933 r
.29782 .44315 m .3139 .45859 L .33905 .45026 L p F P
0 0 0 r
s
.647 .762 .933 r
.3139 .45859 m .29782 .44315 L .27277 .45155 L p F P
0 0 0 r
s
.647 .762 .933 r
.73877 .4425 m .75101 .45796 L .77824 .44962 L p F P
0 0 0 r
s
.647 .762 .933 r
.75101 .45796 m .73877 .4425 L .71161 .45091 L p F P
0 0 0 r
s
.647 .762 .933 r
.36444 .44185 m .37994 .45732 L .40542 .44898 L p F P
0 0 0 r
s
.647 .762 .933 r
.37994 .45732 m .36444 .44185 L .33905 .45026 L p F P
0 0 0 r
s
.647 .762 .933 r
.80573 .4412 m .81739 .45668 L .84496 .44833 L p F P
0 0 0 r
s
.647 .762 .933 r
.81739 .45668 m .80573 .4412 L .77824 .44962 L p F P
0 0 0 r
s
.647 .762 .933 r
.43115 .44055 m .44608 .45604 L .4719 .44769 L p F P
0 0 0 r
s
.647 .762 .933 r
.44608 .45604 m .43115 .44055 L .40542 .44898 L p F P
0 0 0 r
s
.67 .733 .897 r
.49139 .09868 m .5058 .11811 L .53192 .10759 L p F P
0 0 0 r
s
.67 .729 .894 r
.5058 .11811 m .49139 .09868 L .46537 .10905 L p F P
0 0 0 r
s
.647 .762 .933 r
.49796 .43925 m .51232 .45476 L .53847 .44639 L p F P
0 0 0 r
s
.647 .762 .933 r
.51232 .45476 m .49796 .43925 L .4719 .44769 L p F P
0 0 0 r
s
.647 .762 .933 r
.12285 .4386 m .14049 .45412 L .16488 .44575 L p F P
0 0 0 r
s
.647 .762 .933 r
.14049 .45412 m .12285 .4386 L .09856 .44704 L p F P
0 0 0 r
s
.671 .735 .898 r
.55827 .09706 m .57212 .11638 L .59856 .10576 L p F P
0 0 0 r
s
.673 .731 .893 r
.57212 .11638 m .55827 .09706 L .53192 .10759 L p F P
0 0 0 r
s
.647 .762 .933 r
.56487 .43795 m .57866 .45348 L .60514 .4451 L p F P
0 0 0 r
s
.647 .762 .933 r
.57866 .45348 m .56487 .43795 L .53847 .44639 L p F P
0 0 0 r
s
.647 .762 .933 r
.18951 .43729 m .20658 .45284 L .2313 .44445 L p F P
0 0 0 r
s
.647 .762 .933 r
.20658 .45284 m .18951 .43729 L .16488 .44575 L p F P
0 0 0 r
s
.67 .738 .901 r
.62524 .09522 m .63852 .11428 L .66527 .10375 L p F P
0 0 0 r
s
.673 .735 .897 r
.63852 .11428 m .62524 .09522 L .59856 .10576 L p F P
0 0 0 r
s
.647 .762 .933 r
.63187 .43664 m .64509 .45219 L .6719 .4438 L p F P
0 0 0 r
s
.647 .762 .933 r
.64509 .45219 m .63187 .43664 L .60514 .4451 L p F P
0 0 0 r
s
.668 .741 .905 r
.69228 .09332 m .70499 .11214 L .73207 .1018 L p F P
0 0 0 r
s
.671 .739 .902 r
.70499 .11214 m .69228 .09332 L .66527 .10375 L p F P
0 0 0 r
s
.647 .762 .933 r
.25626 .43599 m .27277 .45155 L .29782 .44315 L p F P
0 0 0 r
s
.647 .762 .933 r
.27277 .45155 m .25626 .43599 L .2313 .44445 L p F P
0 0 0 r
s
.647 .762 .933 r
.69898 .43533 m .71161 .45091 L .73877 .4425 L p F P
0 0 0 r
s
.647 .762 .933 r
.71161 .45091 m .69898 .43533 L .6719 .4438 L p F P
0 0 0 r
s
.647 .762 .933 r
.32312 .43468 m .33905 .45026 L .36444 .44185 L p F P
0 0 0 r
s
.647 .762 .933 r
.33905 .45026 m .32312 .43468 L .29782 .44315 L p F P
0 0 0 r
s
.647 .762 .933 r
.76618 .43402 m .77824 .44962 L .80573 .4412 L p F P
0 0 0 r
s
.647 .762 .933 r
.77824 .44962 m .76618 .43402 L .73877 .4425 L p F P
0 0 0 r
s
.647 .762 .933 r
.39007 .43337 m .40542 .44898 L .43115 .44055 L p F P
0 0 0 r
s
.647 .762 .933 r
.40542 .44898 m .39007 .43337 L .36444 .44185 L p F P
0 0 0 r
s
.647 .762 .933 r
.84496 .44833 m .83349 .43271 L .80573 .4412 L p F P
0 0 0 r
s
.647 .762 .933 r
.45712 .43205 m .4719 .44769 L .49796 .43925 L p F P
0 0 0 r
s
.647 .762 .933 r
.4719 .44769 m .45712 .43205 L .43115 .44055 L p F P
0 0 0 r
s
.669 .735 .9 r
.51766 .08823 m .53192 .10759 L .55827 .09706 L p F P
0 0 0 r
s
.67 .733 .897 r
.53192 .10759 m .51766 .08823 L .49139 .09868 L p F P
0 0 0 r
s
.647 .762 .933 r
.52427 .43074 m .53847 .44639 L .56487 .43795 L p F P
0 0 0 r
s
.647 .762 .933 r
.53847 .44639 m .52427 .43074 L .49796 .43925 L p F P
0 0 0 r
s
.647 .762 .933 r
.14737 .43008 m .16488 .44575 L .18951 .43729 L p F P
0 0 0 r
s
.647 .762 .933 r
.16488 .44575 m .14737 .43008 L .12285 .4386 L p F P
0 0 0 r
s
.669 .738 .901 r
.58487 .08654 m .59856 .10576 L .62524 .09522 L p F P
0 0 0 r
s
.671 .735 .898 r
.59856 .10576 m .58487 .08654 L .55827 .09706 L p F P
0 0 0 r
s
.647 .762 .933 r
.59152 .42942 m .60514 .4451 L .63187 .43664 L p F P
0 0 0 r
s
.647 .762 .933 r
.60514 .4451 m .59152 .42942 L .56487 .43795 L p F P
0 0 0 r
s
.668 .74 .904 r
.65217 .08473 m .66527 .10375 L .69228 .09332 L p F P
0 0 0 r
s
.67 .738 .901 r
.66527 .10375 m .65217 .08473 L .62524 .09522 L p F P
0 0 0 r
s
.647 .762 .933 r
.21437 .42876 m .2313 .44445 L .25626 .43599 L p F P
0 0 0 r
s
.647 .762 .933 r
.2313 .44445 m .21437 .42876 L .18951 .43729 L p F P
0 0 0 r
s
.647 .762 .933 r
.65887 .4281 m .6719 .4438 L .69898 .43533 L p F P
0 0 0 r
s
.647 .762 .933 r
.6719 .4438 m .65887 .4281 L .63187 .43664 L p F P
0 0 0 r
s
.668 .741 .905 r
.73207 .1018 m .71956 .08292 L .69228 .09332 L p F P
0 0 0 r
s
.647 .762 .933 r
.28146 .42744 m .29782 .44315 L .32312 .43468 L p F P
0 0 0 r
s
.647 .762 .933 r
.29782 .44315 m .28146 .42744 L .25626 .43599 L p F P
0 0 0 r
s
.647 .762 .933 r
.72631 .42678 m .73877 .4425 L .76618 .43402 L p F P
0 0 0 r
s
.647 .762 .933 r
.73877 .4425 m .72631 .42678 L .69898 .43533 L p F P
0 0 0 r
s
.647 .762 .933 r
.34865 .42612 m .36444 .44185 L .39007 .43337 L p F P
0 0 0 r
s
.647 .762 .933 r
.36444 .44185 m .34865 .42612 L .32312 .43468 L p F P
0 0 0 r
s
.647 .762 .933 r
.79386 .42546 m .80573 .4412 L .83349 .43271 L p F P
0 0 0 r
s
.647 .762 .933 r
.80573 .4412 m .79386 .42546 L .76618 .43402 L p F P
0 0 0 r
s
.647 .762 .933 r
.41595 .42479 m .43115 .44055 L .45712 .43205 L p F P
0 0 0 r
s
.647 .762 .933 r
.43115 .44055 m .41595 .42479 L .39007 .43337 L p F P
0 0 0 r
s
.647 .762 .933 r
.48334 .42347 m .49796 .43925 L .52427 .43074 L p F P
0 0 0 r
s
.647 .762 .933 r
.49796 .43925 m .48334 .42347 L .45712 .43205 L p F P
0 0 0 r
s
.668 .738 .902 r
.54418 .07774 m .55827 .09706 L .58487 .08654 L p F P
0 0 0 r
s
.669 .735 .9 r
.55827 .09706 m .54418 .07774 L .51766 .08823 L p F P
0 0 0 r
s
.647 .762 .933 r
.55083 .42214 m .56487 .43795 L .59152 .42942 L p F P
0 0 0 r
s
.647 .762 .933 r
.56487 .43795 m .55083 .42214 L .52427 .43074 L p F P
0 0 0 r
s
.667 .739 .904 r
.61173 .07602 m .62524 .09522 L .65217 .08473 L p F P
0 0 0 r
s
.669 .738 .901 r
.62524 .09522 m .61173 .07602 L .58487 .08654 L p F P
0 0 0 r
s
.647 .762 .933 r
.17213 .42148 m .18951 .43729 L .21437 .42876 L p F P
0 0 0 r
s
.647 .762 .933 r
.18951 .43729 m .17213 .42148 L .14737 .43008 L p F P
0 0 0 r
s
.647 .762 .933 r
.61843 .42081 m .63187 .43664 L .65887 .4281 L p F P
0 0 0 r
s
.647 .762 .933 r
.63187 .43664 m .61843 .42081 L .59152 .42942 L p F P
0 0 0 r
s
.666 .741 .906 r
.67936 .07425 m .69228 .09332 L .71956 .08292 L p F P
0 0 0 r
s
.668 .74 .904 r
.69228 .09332 m .67936 .07425 L .65217 .08473 L p F P
0 0 0 r
s
.647 .762 .933 r
.23947 .42014 m .25626 .43599 L .28146 .42744 L p F P
0 0 0 r
s
.647 .762 .933 r
.25626 .43599 m .23947 .42014 L .21437 .42876 L p F P
0 0 0 r
s
.647 .762 .933 r
.68612 .41948 m .69898 .43533 L .72631 .42678 L p F P
0 0 0 r
s
.647 .762 .933 r
.69898 .43533 m .68612 .41948 L .65887 .4281 L p F P
0 0 0 r
s
.647 .762 .933 r
.3069 .41881 m .32312 .43468 L .34865 .42612 L p F P
0 0 0 r
s
.647 .762 .933 r
.32312 .43468 m .3069 .41881 L .28146 .42744 L p F P
0 0 0 r
s
.647 .762 .933 r
.75391 .41814 m .76618 .43402 L .79386 .42546 L p F P
0 0 0 r
s
.647 .762 .933 r
.76618 .43402 m .75391 .41814 L .72631 .42678 L p F P
0 0 0 r
s
.647 .762 .933 r
.37444 .41748 m .39007 .43337 L .41595 .42479 L p F P
0 0 0 r
s
.647 .762 .933 r
.39007 .43337 m .37444 .41748 L .34865 .42612 L p F P
0 0 0 r
s
.647 .762 .933 r
.83349 .43271 m .82181 .41681 L .79386 .42546 L p F P
0 0 0 r
s
.647 .762 .933 r
.44208 .41614 m .45712 .43205 L .48334 .42347 L p F P
0 0 0 r
s
.647 .762 .933 r
.45712 .43205 m .44208 .41614 L .41595 .42479 L p F P
0 0 0 r
s
.647 .762 .933 r
.50982 .4148 m .52427 .43074 L .55083 .42214 L p F P
0 0 0 r
s
.647 .762 .933 r
.52427 .43074 m .50982 .4148 L .48334 .42347 L p F P
0 0 0 r
s
.667 .739 .904 r
.57095 .0672 m .58487 .08654 L .61173 .07602 L p F P
0 0 0 r
s
.668 .738 .902 r
.58487 .08654 m .57095 .0672 L .54418 .07774 L p F P
0 0 0 r
s
.647 .762 .933 r
.57765 .41346 m .59152 .42942 L .61843 .42081 L p F P
0 0 0 r
s
.647 .762 .933 r
.59152 .42942 m .57765 .41346 L .55083 .42214 L p F P
0 0 0 r
s
.666 .741 .906 r
.63884 .06548 m .65217 .08473 L .67936 .07425 L p F P
0 0 0 r
s
.667 .739 .904 r
.65217 .08473 m .63884 .06548 L .61173 .07602 L p F P
0 0 0 r
s
.647 .762 .933 r
.19713 .41279 m .21437 .42876 L .23947 .42014 L p F P
0 0 0 r
s
.647 .762 .933 r
.21437 .42876 m .19713 .41279 L .17213 .42148 L p F P
0 0 0 r
s
.647 .762 .933 r
.64559 .41212 m .65887 .4281 L .68612 .41948 L p F P
0 0 0 r
s
.647 .762 .933 r
.65887 .4281 m .64559 .41212 L .61843 .42081 L p F P
0 0 0 r
s
.666 .741 .906 r
.71956 .08292 m .70682 .06375 L .67936 .07425 L p F P
0 0 0 r
s
.647 .762 .933 r
.26481 .41144 m .28146 .42744 L .3069 .41881 L p F P
0 0 0 r
s
.647 .762 .933 r
.28146 .42744 m .26481 .41144 L .23947 .42014 L p F P
0 0 0 r
s
.647 .762 .933 r
.71364 .41077 m .72631 .42678 L .75391 .41814 L p F P
0 0 0 r
s
.647 .762 .933 r
.72631 .42678 m .71364 .41077 L .68612 .41948 L p F P
0 0 0 r
s
.647 .762 .933 r
.33259 .4101 m .34865 .42612 L .37444 .41748 L p F P
0 0 0 r
s
.647 .762 .933 r
.34865 .42612 m .33259 .4101 L .3069 .41881 L p F P
0 0 0 r
s
.647 .762 .933 r
.78178 .40943 m .79386 .42546 L .82181 .41681 L p F P
0 0 0 r
s
.647 .762 .933 r
.79386 .42546 m .78178 .40943 L .75391 .41814 L p F P
0 0 0 r
s
.647 .762 .933 r
.40047 .40875 m .41595 .42479 L .44208 .41614 L p F P
0 0 0 r
s
.647 .762 .933 r
.41595 .42479 m .40047 .40875 L .37444 .41748 L p F P
0 0 0 r
s
.647 .762 .933 r
.46846 .4074 m .48334 .42347 L .50982 .4148 L p F P
0 0 0 r
s
.647 .762 .933 r
.48334 .42347 m .46846 .4074 L .44208 .41614 L p F P
0 0 0 r
s
.647 .762 .933 r
.53655 .40605 m .55083 .42214 L .57765 .41346 L p F P
0 0 0 r
s
.647 .762 .933 r
.55083 .42214 m .53655 .40605 L .50982 .4148 L p F P
0 0 0 r
s
.666 .74 .906 r
.59798 .05661 m .61173 .07602 L .63884 .06548 L p F P
0 0 0 r
s
.667 .739 .904 r
.61173 .07602 m .59798 .05661 L .57095 .0672 L p F P
0 0 0 r
s
.647 .762 .933 r
.60474 .4047 m .61843 .42081 L .64559 .41212 L p F P
0 0 0 r
s
.647 .762 .933 r
.61843 .42081 m .60474 .4047 L .57765 .41346 L p F P
0 0 0 r
s
.665 .741 .907 r
.66621 .05491 m .67936 .07425 L .70682 .06375 L p F P
0 0 0 r
s
.666 .741 .906 r
.67936 .07425 m .66621 .05491 L .63884 .06548 L p F P
0 0 0 r
s
.647 .762 .933 r
.22237 .40402 m .23947 .42014 L .26481 .41144 L p F P
0 0 0 r
s
.647 .762 .933 r
.23947 .42014 m .22237 .40402 L .19713 .41279 L p F P
0 0 0 r
s
.647 .762 .933 r
.67303 .40334 m .68612 .41948 L .71364 .41077 L p F P
0 0 0 r
s
.647 .762 .933 r
.68612 .41948 m .67303 .40334 L .64559 .41212 L p F P
0 0 0 r
s
.647 .762 .933 r
.2904 .40266 m .3069 .41881 L .33259 .4101 L p F P
0 0 0 r
s
.647 .762 .933 r
.3069 .41881 m .2904 .40266 L .26481 .41144 L p F P
0 0 0 r
s
.647 .762 .933 r
.74142 .40198 m .75391 .41814 L .78178 .40943 L p F P
0 0 0 r
s
.647 .762 .933 r
.75391 .41814 m .74142 .40198 L .71364 .41077 L p F P
0 0 0 r
s
.647 .762 .933 r
.35853 .4013 m .37444 .41748 L .40047 .40875 L p F P
0 0 0 r
s
.647 .762 .933 r
.37444 .41748 m .35853 .4013 L .33259 .4101 L p F P
0 0 0 r
s
.647 .762 .933 r
.82181 .41681 m .80992 .40062 L .78178 .40943 L p F P
0 0 0 r
s
.647 .762 .933 r
.42676 .39994 m .44208 .41614 L .46846 .4074 L p F P
0 0 0 r
s
.647 .762 .933 r
.44208 .41614 m .42676 .39994 L .40047 .40875 L p F P
0 0 0 r
s
.647 .762 .933 r
.4951 .39858 m .50982 .4148 L .53655 .40605 L p F P
0 0 0 r
s
.647 .762 .933 r
.50982 .4148 m .4951 .39858 L .46846 .4074 L p F P
0 0 0 r
s
.647 .762 .933 r
.56354 .39721 m .57765 .41346 L .60474 .4047 L p F P
0 0 0 r
s
.647 .762 .933 r
.57765 .41346 m .56354 .39721 L .53655 .40605 L p F P
0 0 0 r
s
.665 .741 .907 r
.62527 .04597 m .63884 .06548 L .66621 .05491 L p F P
0 0 0 r
s
.666 .74 .906 r
.63884 .06548 m .62527 .04597 L .59798 .05661 L p F P
0 0 0 r
s
.647 .762 .933 r
.63208 .39585 m .64559 .41212 L .67303 .40334 L p F P
0 0 0 r
s
.647 .762 .933 r
.64559 .41212 m .63208 .39585 L .60474 .4047 L p F P
0 0 0 r
s
.665 .741 .907 r
.70682 .06375 m .69386 .04427 L .66621 .05491 L p F P
0 0 0 r
s
.647 .762 .933 r
.24785 .39516 m .26481 .41144 L .2904 .40266 L p F P
0 0 0 r
s
.647 .762 .933 r
.26481 .41144 m .24785 .39516 L .22237 .40402 L p F P
0 0 0 r
s
.647 .762 .933 r
.70073 .39448 m .71364 .41077 L .74142 .40198 L p F P
0 0 0 r
s
.647 .762 .933 r
.71364 .41077 m .70073 .39448 L .67303 .40334 L p F P
0 0 0 r
s
.647 .762 .933 r
.31624 .39379 m .33259 .4101 L .35853 .4013 L p F P
0 0 0 r
s
.647 .762 .933 r
.33259 .4101 m .31624 .39379 L .2904 .40266 L p F P
0 0 0 r
s
.647 .762 .933 r
.76948 .3931 m .78178 .40943 L .80992 .40062 L p F P
0 0 0 r
s
.647 .762 .933 r
.78178 .40943 m .76948 .3931 L .74142 .40198 L p F P
0 0 0 r
s
.647 .762 .933 r
.38472 .39242 m .40047 .40875 L .42676 .39994 L p F P
0 0 0 r
s
.647 .762 .933 r
.40047 .40875 m .38472 .39242 L .35853 .4013 L p F P
0 0 0 r
s
.647 .762 .933 r
.45331 .39104 m .46846 .4074 L .4951 .39858 L p F P
0 0 0 r
s
.647 .762 .933 r
.46846 .4074 m .45331 .39104 L .42676 .39994 L p F P
0 0 0 r
s
.647 .762 .933 r
.522 .38967 m .53655 .40605 L .56354 .39721 L p F P
0 0 0 r
s
.647 .762 .933 r
.53655 .40605 m .522 .38967 L .4951 .39858 L p F P
0 0 0 r
s
.647 .762 .933 r
.5908 .38829 m .60474 .4047 L .63208 .39585 L p F P
0 0 0 r
s
.647 .762 .933 r
.60474 .4047 m .5908 .38829 L .56354 .39721 L p F P
0 0 0 r
s
.664 .742 .908 r
.65283 .03526 m .66621 .05491 L .69386 .04427 L p F P
0 0 0 r
s
.665 .741 .907 r
.66621 .05491 m .65283 .03526 L .62527 .04597 L p F P
0 0 0 r
s
.647 .762 .933 r
.6597 .38691 m .67303 .40334 L .70073 .39448 L p F P
0 0 0 r
s
.647 .762 .933 r
.67303 .40334 m .6597 .38691 L .63208 .39585 L p F P
0 0 0 r
s
.647 .762 .933 r
.27359 .38622 m .2904 .40266 L .31624 .39379 L p F P
0 0 0 r
s
.647 .762 .933 r
.2904 .40266 m .27359 .38622 L .24785 .39516 L p F P
0 0 0 r
s
.647 .762 .933 r
.7287 .38553 m .74142 .40198 L .76948 .3931 L p F P
0 0 0 r
s
.647 .762 .933 r
.74142 .40198 m .7287 .38553 L .70073 .39448 L p F P
0 0 0 r
s
.647 .762 .933 r
.34233 .38483 m .35853 .4013 L .38472 .39242 L p F P
0 0 0 r
s
.647 .762 .933 r
.35853 .4013 m .34233 .38483 L .31624 .39379 L p F P
0 0 0 r
s
.647 .762 .933 r
.80992 .40062 m .79781 .38414 L .76948 .3931 L p F P
0 0 0 r
s
.647 .762 .933 r
.41117 .38345 m .42676 .39994 L .45331 .39104 L p F P
0 0 0 r
s
.647 .762 .933 r
.42676 .39994 m .41117 .38345 L .38472 .39242 L p F P
0 0 0 r
s
.647 .762 .933 r
.48012 .38206 m .4951 .39858 L .522 .38967 L p F P
0 0 0 r
s
.647 .762 .933 r
.4951 .39858 m .48012 .38206 L .45331 .39104 L p F P
0 0 0 r
s
.647 .762 .933 r
.54917 .38067 m .56354 .39721 L .5908 .38829 L p F P
0 0 0 r
s
.647 .762 .933 r
.56354 .39721 m .54917 .38067 L .522 .38967 L p F P
0 0 0 r
s
.664 .742 .908 r
.69386 .04427 m .68066 .02447 L .65283 .03526 L p F P
0 0 0 r
s
.647 .762 .933 r
.61833 .37928 m .63208 .39585 L .6597 .38691 L p F P
0 0 0 r
s
.647 .762 .933 r
.63208 .39585 m .61833 .37928 L .5908 .38829 L p F P
0 0 0 r
s
.647 .762 .933 r
.68759 .37788 m .70073 .39448 L .7287 .38553 L p F P
0 0 0 r
s
.647 .762 .933 r
.70073 .39448 m .68759 .37788 L .6597 .38691 L p F P
0 0 0 r
s
.647 .762 .933 r
.29958 .37718 m .31624 .39379 L .34233 .38483 L p F P
0 0 0 r
s
.647 .762 .933 r
.31624 .39379 m .29958 .37718 L .27359 .38622 L p F P
0 0 0 r
s
.647 .762 .933 r
.75695 .37649 m .76948 .3931 L .79781 .38414 L p F P
0 0 0 r
s
.647 .762 .933 r
.76948 .3931 m .75695 .37649 L .7287 .38553 L p F P
0 0 0 r
s
.647 .762 .933 r
.36868 .37579 m .38472 .39242 L .41117 .38345 L p F P
0 0 0 r
s
.647 .762 .933 r
.38472 .39242 m .36868 .37579 L .34233 .38483 L p F P
0 0 0 r
s
.647 .762 .933 r
.43788 .37439 m .45331 .39104 L .48012 .38206 L p F P
0 0 0 r
s
.647 .762 .933 r
.45331 .39104 m .43788 .37439 L .41117 .38345 L p F P
0 0 0 r
s
.647 .762 .933 r
.50719 .37299 m .522 .38967 L .54917 .38067 L p F P
0 0 0 r
s
.647 .762 .933 r
.522 .38967 m .50719 .37299 L .48012 .38206 L p F P
0 0 0 r
s
.647 .762 .933 r
.57661 .37158 m .5908 .38829 L .61833 .37928 L p F P
0 0 0 r
s
.647 .762 .933 r
.5908 .38829 m .57661 .37158 L .54917 .38067 L p F P
0 0 0 r
s
.647 .762 .933 r
.64613 .37018 m .6597 .38691 L .68759 .37788 L p F P
0 0 0 r
s
.647 .762 .933 r
.6597 .38691 m .64613 .37018 L .61833 .37928 L p F P
0 0 0 r
s
.647 .762 .933 r
.71575 .36877 m .7287 .38553 L .75695 .37649 L p F P
0 0 0 r
s
.647 .762 .933 r
.7287 .38553 m .71575 .36877 L .68759 .37788 L p F P
0 0 0 r
s
.647 .762 .933 r
.32583 .36806 m .34233 .38483 L .36868 .37579 L p F P
0 0 0 r
s
.647 .762 .933 r
.34233 .38483 m .32583 .36806 L .29958 .37718 L p F P
0 0 0 r
s
.647 .762 .933 r
.79781 .38414 m .78548 .36736 L .75695 .37649 L p F P
0 0 0 r
s
.647 .762 .933 r
.39529 .36665 m .41117 .38345 L .43788 .37439 L p F P
0 0 0 r
s
.647 .762 .933 r
.41117 .38345 m .39529 .36665 L .36868 .37579 L p F P
0 0 0 r
s
.647 .762 .933 r
.46486 .36524 m .48012 .38206 L .50719 .37299 L p F P
0 0 0 r
s
.647 .762 .933 r
.48012 .38206 m .46486 .36524 L .43788 .37439 L p F P
0 0 0 r
s
.647 .762 .933 r
.53453 .36382 m .54917 .38067 L .57661 .37158 L p F P
0 0 0 r
s
.647 .762 .933 r
.54917 .38067 m .53453 .36382 L .50719 .37299 L p F P
0 0 0 r
s
.647 .762 .933 r
.60432 .3624 m .61833 .37928 L .64613 .37018 L p F P
0 0 0 r
s
.647 .762 .933 r
.61833 .37928 m .60432 .3624 L .57661 .37158 L p F P
0 0 0 r
s
.647 .762 .933 r
.6742 .36098 m .68759 .37788 L .71575 .36877 L p F P
0 0 0 r
s
.647 .762 .933 r
.68759 .37788 m .6742 .36098 L .64613 .37018 L p F P
0 0 0 r
s
.647 .762 .933 r
.7442 .35956 m .75695 .37649 L .78548 .36736 L p F P
0 0 0 r
s
.647 .762 .933 r
.75695 .37649 m .7442 .35956 L .71575 .36877 L p F P
0 0 0 r
s
.647 .762 .933 r
.35235 .35885 m .36868 .37579 L .39529 .36665 L p F P
0 0 0 r
s
.647 .762 .933 r
.36868 .37579 m .35235 .35885 L .32583 .36806 L p F P
0 0 0 r
s
.647 .762 .933 r
.42217 .35742 m .43788 .37439 L .46486 .36524 L p F P
0 0 0 r
s
.647 .762 .933 r
.43788 .37439 m .42217 .35742 L .39529 .36665 L p F P
0 0 0 r
s
.647 .762 .933 r
.49211 .356 m .50719 .37299 L .53453 .36382 L p F P
0 0 0 r
s
.647 .762 .933 r
.50719 .37299 m .49211 .356 L .46486 .36524 L p F P
0 0 0 r
s
.647 .762 .933 r
.56215 .35457 m .57661 .37158 L .60432 .3624 L p F P
0 0 0 r
s
.647 .762 .933 r
.57661 .37158 m .56215 .35457 L .53453 .36382 L p F P
0 0 0 r
s
.647 .762 .933 r
.6323 .35314 m .64613 .37018 L .6742 .36098 L p F P
0 0 0 r
s
.647 .762 .933 r
.64613 .37018 m .6323 .35314 L .60432 .3624 L p F P
0 0 0 r
s
.647 .762 .933 r
.70256 .3517 m .71575 .36877 L .7442 .35956 L p F P
0 0 0 r
s
.647 .762 .933 r
.71575 .36877 m .70256 .3517 L .6742 .36098 L p F P
0 0 0 r
s
.647 .762 .933 r
.78548 .36736 m .77293 .35026 L .7442 .35956 L p F P
0 0 0 r
s
.647 .762 .933 r
.37912 .34955 m .39529 .36665 L .42217 .35742 L p F P
0 0 0 r
s
.647 .762 .933 r
.39529 .36665 m .37912 .34955 L .35235 .35885 L p F P
0 0 0 r
s
.647 .762 .933 r
.44932 .34811 m .46486 .36524 L .49211 .356 L p F P
0 0 0 r
s
.647 .762 .933 r
.46486 .36524 m .44932 .34811 L .42217 .35742 L p F P
0 0 0 r
s
.647 .762 .933 r
.51963 .34666 m .53453 .36382 L .56215 .35457 L p F P
0 0 0 r
s
.647 .762 .933 r
.53453 .36382 m .51963 .34666 L .49211 .356 L p F P
0 0 0 r
s
.647 .762 .933 r
.59004 .34522 m .60432 .3624 L .6323 .35314 L p F P
0 0 0 r
s
.647 .762 .933 r
.60432 .3624 m .59004 .34522 L .56215 .35457 L p F P
0 0 0 r
s
.647 .762 .933 r
.66057 .34377 m .6742 .36098 L .70256 .3517 L p F P
0 0 0 r
s
.647 .762 .933 r
.6742 .36098 m .66057 .34377 L .6323 .35314 L p F P
0 0 0 r
s
.647 .762 .933 r
.7312 .34232 m .7442 .35956 L .77293 .35026 L p F P
0 0 0 r
s
.647 .762 .933 r
.7442 .35956 m .7312 .34232 L .70256 .3517 L p F P
0 0 0 r
s
.647 .762 .933 r
.40617 .34015 m .42217 .35742 L .44932 .34811 L p F P
0 0 0 r
s
.647 .762 .933 r
.42217 .35742 m .40617 .34015 L .37912 .34955 L p F P
0 0 0 r
s
.647 .762 .933 r
.47674 .33869 m .49211 .356 L .51963 .34666 L p F P
0 0 0 r
s
.647 .762 .933 r
.49211 .356 m .47674 .33869 L .44932 .34811 L p F P
0 0 0 r
s
.647 .762 .933 r
.54743 .33724 m .56215 .35457 L .59004 .34522 L p F P
0 0 0 r
s
.647 .762 .933 r
.56215 .35457 m .54743 .33724 L .51963 .34666 L p F P
0 0 0 r
s
.647 .762 .933 r
.61822 .33578 m .6323 .35314 L .66057 .34377 L p F P
0 0 0 r
s
.647 .762 .933 r
.6323 .35314 m .61822 .33578 L .59004 .34522 L p F P
0 0 0 r
s
.647 .762 .933 r
.68912 .33432 m .70256 .3517 L .7312 .34232 L p F P
0 0 0 r
s
.647 .762 .933 r
.70256 .3517 m .68912 .33432 L .66057 .34377 L p F P
0 0 0 r
s
.647 .762 .933 r
.77293 .35026 m .76014 .33285 L .7312 .34232 L p F P
0 0 0 r
s
.647 .762 .933 r
.43349 .33065 m .44932 .34811 L .47674 .33869 L p F P
0 0 0 r
s
.647 .762 .933 r
.44932 .34811 m .43349 .33065 L .40617 .34015 L p F P
0 0 0 r
s
.647 .762 .933 r
.50444 .32918 m .51963 .34666 L .54743 .33724 L p F P
0 0 0 r
s
.647 .762 .933 r
.51963 .34666 m .50444 .32918 L .47674 .33869 L p F P
0 0 0 r
s
.647 .762 .933 r
.57551 .32771 m .59004 .34522 L .61822 .33578 L p F P
0 0 0 r
s
.647 .762 .933 r
.59004 .34522 m .57551 .32771 L .54743 .33724 L p F P
0 0 0 r
s
.647 .762 .933 r
.64668 .32624 m .66057 .34377 L .68912 .33432 L p F P
0 0 0 r
s
.647 .762 .933 r
.66057 .34377 m .64668 .32624 L .61822 .33578 L p F P
0 0 0 r
s
.647 .762 .933 r
.71797 .32476 m .7312 .34232 L .76014 .33285 L p F P
0 0 0 r
s
.647 .762 .933 r
.7312 .34232 m .71797 .32476 L .68912 .33432 L p F P
0 0 0 r
s
.647 .762 .933 r
.46109 .32106 m .47674 .33869 L .50444 .32918 L p F P
0 0 0 r
s
.647 .762 .933 r
.47674 .33869 m .46109 .32106 L .43349 .33065 L p F P
0 0 0 r
s
.647 .762 .933 r
.53243 .31958 m .54743 .33724 L .57551 .32771 L p F P
0 0 0 r
s
.647 .762 .933 r
.54743 .33724 m .53243 .31958 L .50444 .32918 L p F P
0 0 0 r
s
.647 .762 .933 r
.60387 .31809 m .61822 .33578 L .64668 .32624 L p F P
0 0 0 r
s
.647 .762 .933 r
.61822 .33578 m .60387 .31809 L .57551 .32771 L p F P
0 0 0 r
s
.647 .762 .933 r
.67543 .3166 m .68912 .33432 L .71797 .32476 L p F P
0 0 0 r
s
.647 .762 .933 r
.68912 .33432 m .67543 .3166 L .64668 .32624 L p F P
0 0 0 r
s
.647 .762 .933 r
.76014 .33285 m .74711 .31511 L .71797 .32476 L p F P
0 0 0 r
s
.647 .762 .933 r
.48897 .31137 m .50444 .32918 L .53243 .31958 L p F P
0 0 0 r
s
.647 .762 .933 r
.50444 .32918 m .48897 .31137 L .46109 .32106 L p F P
0 0 0 r
s
.647 .762 .933 r
.5607 .30987 m .57551 .32771 L .60387 .31809 L p F P
0 0 0 r
s
.647 .762 .933 r
.57551 .32771 m .5607 .30987 L .53243 .31958 L p F P
0 0 0 r
s
.647 .762 .933 r
.63253 .30837 m .64668 .32624 L .67543 .3166 L p F P
0 0 0 r
s
.647 .762 .933 r
.64668 .32624 m .63253 .30837 L .60387 .31809 L p F P
0 0 0 r
s
.647 .762 .933 r
.70448 .30687 m .71797 .32476 L .74711 .31511 L p F P
0 0 0 r
s
.647 .762 .933 r
.71797 .32476 m .70448 .30687 L .67543 .3166 L p F P
0 0 0 r
s
.647 .762 .933 r
.51714 .30158 m .53243 .31958 L .5607 .30987 L p F P
0 0 0 r
s
.647 .762 .933 r
.53243 .31958 m .51714 .30158 L .48897 .31137 L p F P
0 0 0 r
s
.647 .762 .933 r
.58926 .30007 m .60387 .31809 L .63253 .30837 L p F P
0 0 0 r
s
.647 .762 .933 r
.60387 .31809 m .58926 .30007 L .5607 .30987 L p F P
0 0 0 r
s
.647 .762 .933 r
.66148 .29855 m .67543 .3166 L .70448 .30687 L p F P
0 0 0 r
s
.647 .762 .933 r
.67543 .3166 m .66148 .29855 L .63253 .30837 L p F P
0 0 0 r
s
.647 .762 .933 r
.74711 .31511 m .73383 .29703 L .70448 .30687 L p F P
0 0 0 r
s
.647 .762 .933 r
.5456 .29169 m .5607 .30987 L .58926 .30007 L p F P
0 0 0 r
s
.647 .762 .933 r
.5607 .30987 m .5456 .29169 L .51714 .30158 L p F P
0 0 0 r
s
.647 .762 .933 r
.61811 .29016 m .63253 .30837 L .66148 .29855 L p F P
0 0 0 r
s
.647 .762 .933 r
.63253 .30837 m .61811 .29016 L .58926 .30007 L p F P
0 0 0 r
s
.647 .762 .933 r
.69074 .28863 m .70448 .30687 L .73383 .29703 L p F P
0 0 0 r
s
.647 .762 .933 r
.70448 .30687 m .69074 .28863 L .66148 .29855 L p F P
0 0 0 r
s
.647 .762 .933 r
.57436 .2817 m .58926 .30007 L .61811 .29016 L p F P
0 0 0 r
s
.647 .762 .933 r
.58926 .30007 m .57436 .2817 L .5456 .29169 L p F P
0 0 0 r
s
.647 .762 .933 r
.64727 .28016 m .66148 .29855 L .69074 .28863 L p F P
0 0 0 r
s
.647 .762 .933 r
.66148 .29855 m .64727 .28016 L .61811 .29016 L p F P
0 0 0 r
s
.647 .762 .933 r
.73383 .29703 m .72029 .27861 L .69074 .28863 L p F P
0 0 0 r
s
.647 .762 .933 r
.60341 .27161 m .61811 .29016 L .64727 .28016 L p F P
0 0 0 r
s
.647 .762 .933 r
.61811 .29016 m .60341 .27161 L .57436 .2817 L p F P
0 0 0 r
s
.647 .762 .933 r
.67673 .27004 m .69074 .28863 L .72029 .27861 L p F P
0 0 0 r
s
.647 .762 .933 r
.69074 .28863 m .67673 .27004 L .64727 .28016 L p F P
0 0 0 r
s
.647 .762 .933 r
.63277 .2614 m .64727 .28016 L .67673 .27004 L p F P
0 0 0 r
s
.647 .762 .933 r
.64727 .28016 m .63277 .2614 L .60341 .27161 L p F P
0 0 0 r
s
.647 .762 .933 r
.72029 .27861 m .70649 .25982 L .67673 .27004 L p F P
0 0 0 r
s
.647 .762 .933 r
.66244 .25109 m .67673 .27004 L .70649 .25982 L p F P
0 0 0 r
s
.647 .762 .933 r
.67673 .27004 m .66244 .25109 L .63277 .2614 L p F P
0 0 0 r
s
.647 .762 .933 r
.70649 .25982 m .69243 .24067 L .66244 .25109 L p F P
0 0 0 r
s
0 g
.25 Mabswid
.68961 0 m
.97156 .4298 L
s
.97156 .4298 m
1 .63788 L
s
1 .63788 m
.70282 .22771 L
s
.70282 .22771 m
.68961 0 L
s
.03448 .25553 m
0 .47309 L
s
0 .47309 m
.70282 .22771 L
s
.70282 .22771 m
.68961 0 L
s
.68961 0 m
.03448 .25553 L
s
.03448 .25553 m
.68961 0 L
s
.04831 .25013 m
.0531 .25462 L
s
[(-2)] .03875 .24116 1 .93822 Mshowa
.191 .19448 m
.19555 .1992 L
s
[(-1)] .18188 .18504 .96589 1 Mshowa
.34199 .13558 m
.34629 .14054 L
s
[(0)] .3334 .12567 .86593 1 Mshowa
.50206 .07315 m
.50605 .07836 L
s
[(1)] .49408 .06274 .76597 1 Mshowa
.67203 .00686 m
.67566 .01232 L
s
[(2)] .66475 -0.00406 .66601 1 Mshowa
.125 Mabswid
.07622 .23925 m
.07906 .24197 L
s
.10443 .22824 m
.10725 .23099 L
s
.13296 .21712 m
.13576 .21989 L
s
.16182 .20586 m
.16458 .20866 L
s
.22051 .18297 m
.22321 .18583 L
s
.25036 .17133 m
.25303 .17422 L
s
.28055 .15955 m
.28319 .16247 L
s
.31109 .14764 m
.3137 .15058 L
s
.37325 .12339 m
.3758 .1264 L
s
.40489 .11105 m
.40739 .11409 L
s
.43689 .09857 m
.43936 .10163 L
s
.46928 .08594 m
.47171 .08903 L
s
.53523 .06021 m
.53758 .06337 L
s
.56881 .04712 m
.57112 .0503 L
s
.60279 .03386 m
.60506 .03708 L
s
.6372 .02044 m
.63942 .02369 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[259]:=",
  ImageSize->{288, 229.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000iB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00`@3oool4
000005/0oooo00310?ooo`030000003oool0oooo05`0oooo00320?ooo`030000003oool0oooo05/0
oooo00330?ooo`030000003oool0oooo05X0oooo00310?ooo`040000003oool0oooo000005/0oooo
00320?ooo`800000G03oool00=P0oooo100000140?ooo`00f03oool00`000000oooo0?ooo`150?oo
o`00f@3oool00`000000oooo0?ooo`140?ooo`00b`3oool2000000D0oooo100000040?ooo`030000
003oool0oooo04<0oooo00370?ooo`050000003oool000000000003oool00P00000:0?ooo`040000
003oool0oooo000004@0oooo00360?ooo`<000000`3oool2000000/0oooo0P0000150?ooo`00``3o
ool300000080oooo00L000000?ooo`3oool0oooo0000003oool000000540oooo00310?ooo`800000
2@3oool2000000030?ooo`000000oooo04l0oooo002n0?ooo`<000002`3oool010000000oooo0?oo
o`00001@0?ooo`00_03oool3000000T0oooo0P0000020?ooo`050000003oool0oooo0?ooo`000000
C`3oool00;T0oooo0`00000:0?ooo`8000000P2Y_NP00`000000oooo000000040?ooo`030000003o
ool0oooo04`0oooo002D0?ooo`D000007@3oool3000000/0oooo0P0000050:Vmj0800000103oool0
0`000000oooo0?ooo`1<0?ooo`00UP3oool00`000000oooo0?ooo`0K0?ooo`8000002`3oool30000
00L0ZKgX0P0000050?ooo`030000003oool0oooo04/0oooo002F0?ooo`030000003oool0oooo01P0
oooo0`00000;0?ooo`8000000P2Z_NP00`000000ZKgX0:Vmj0060:Vmj0030000003oool0oooo0080
oooo0`00001<0?ooo`00UP3oool00`000000oooo0?ooo`0F0?ooo`800000303oool2000000D0Z[gX
00<000000:Vmj02Y_NP01@2Y_NP2000000D0oooo00<000000?ooo`3oool0BP3oool009H0oooo00<0
00000?ooo`3oool04`3oool3000000/0oooo0`0000070:Zmj0030000002Y_NP0ZKgX00<0ZKgX0P00
00000`2Z_NP000000?ooo`050?ooo`030000003oool0oooo04T0oooo002E0?ooo`8000004P3oool4
000000/0oooo0P0000020:Zmi`030000002Z_NP0Z[gX00H0Z[gX00<000000:Vmj02Y_NP00P000003
0:Zmj08000001P3oool00`000000oooo0?ooo`180?ooo`00Y`3oool2000000`0oooo0`0000040:Zm
i`030000002Z_NP0Z[gX00H0Z[gX0`0000050:Zmj08000001P3oool00`000000oooo0?ooo`180?oo
o`00Y03oool3000000/0oooo0`0000080:Zmi`030000002Z_NP0Z[gX00<0Z[gX0P0000020:Zmi`03
0000002Z_NP0Z[gX00<0Z[gX00<000000:Zmj00000001P3oool00`000000oooo0?ooo`170?ooo`00
XP3oool2000000X0oooo100000020:Zmi`030000002Z_NL0Z[gW00H0Z[gW00<000000:Zmj02Z_NP0
0`0000040:Zmi`030000002Z_NP0Z[gX00<0Z[gX00<000000:Zmj00000001P3oool2000004P0oooo
002O0?ooo`<000002@3oool3000000L0Z[gW00<000000:Zmi`2Z_NL01@2Z_NL3000000P0Z[gW00<0
00000:Zmj02Z_NP00P2Z_NP010000000Z[gX0000000000060?ooo`030000003oool0oooo04H0oooo
002L0?ooo`<000002P3oool200000080ZkcV00<000000:Zmi`2Z_NL01@2Z_NL00`000000Z[gW0:Zm
i`030:Zmi`8000000P2Z_NL00`000000Z[gW0:Zmi`060:Zmi`030000002Z_NP0Z[gX00@000000P2Z
_NL00`000000oooo0?ooo`040?ooo`030000003oool0oooo04D0oooo002J0?ooo`8000002`3oool2
000000@0ZkcV00<000000:Zmi`2Z_NL01P2Z_NL00`000000Z[gW0:Zmi`02000000D0Z[gW00<00000
0:Zmi`2Z_NL01@2Z_NL300000080Z[gW00<000000:Zmi`2Z_NL00P2Z_NL00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo04D0oooo002G0?ooo`<0000000<0oooo0000003oool01`3oool30000
00L0ZkcV00<000000:Zmi`2Z_NL01@2Z_NL3000000L0Z[gW00<000000:Zmi`2Z_NL00`2Z_NL20000
0080ZkgW00@000000:Zmi`2Z_NL00000102Z_NL00`000000oooo0?ooo`040?ooo`030000003oool0
oooo04@0oooo002E0?ooo`8000002`3oool200000080ZkcV00<000000:^liP2[_>H01P2[_>H00`00
0000Z[gW0:Zmi`020:Zmi`8000000P2[_>H00`000000Z[gW0:Zmi`060:Zmi`030000002Z_NL0Z[gW
00800000102[_NL010000000Z[gW0:Zmi`0000050:Zmi`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0@`3oool00940oooo1000000;0?ooo`8000001@2[_>H00`000000ZkcV0:^liP050:^l
iP030000002Z_NL0Z[gW008000001@2[_>H00`000000Z[gW0:Zmi`050:Zmi`<000001`2[_NL00`00
0000Z[gW000000050:Zmi`8000001@3oool2000004@0oooo002?0?ooo`@000002P3oool3000000L0
ZkcV00<000000:^liP2[_>H01@2[_>H3000000L0ZkcV00<000000:Zmi`2Z_NL00`2Z_NL200000080
ZkcV00<000000:^mi`2[_NL01@2[_NL010000000Z[gW0000002Z_NL400000080ZkgW00<000000?oo
o`3oool00P3oool2000004@0oooo002=0?ooo`800000303oool200000080Zk_U00<000000:^liP2[
_>H01P2[_>H00`000000ZkcV0:^liP0400000080ZkcU00<000000:^liP2[_>H01P2[_>H00`000000
Z[gW0:Zmi`02000000@0ZkcV00<000000:^mi`2[_NL01@2[_NL4000000H0ZkgW00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`110?ooo`00JP3oool2000001h0oooo0`00000<0?ooo`800000
1@2[^nD00`000000ZkcV0:^liP050:^liP<000001`2[_>D00`000000ZkcV0:^liP050:^liP<00000
1`2[_>H00`000000ZkgW0:^mi`020:^mi`8000000P2[_NH00`000000ZkgW0:^mi`060:^mi`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0@@3oool006T0oooo00@000000?ooo`3oool00000
6`3oool2000000`0oooo0`0000070:^ki@030000002[_>H0ZkcV00<0ZkcV0P0000020:bki0030000
002[_>D0ZkcU00D0ZkcU00<000000:^liP2[_>H00`2[_>H200000080[;cU00<000000:^liP2[_>H0
1@2[_>H00`000000ZkgW0:^mi`02000000@0ZkgV0P0000070:^mi`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0@03oool006T0oooo00@000000?ooo`3oool00000603oool3000000030?oo
o`000000oooo00T0oooo0P0000020:^ji0030000002[^nD0Zk_U00H0Zk_U00<000000:^liP2[_>H0
0P0000040:bki0030000002[_>D0ZkcU00H0ZkcU00<000000:^liP2[_>H00P0000040:bli@030000
002[_>H0ZkcV00D0ZkcV0`0000060:^miP8000001`2[_NL2000000H0oooo00<000000?ooo`3oool0
?`3oool006T0oooo00@000000?ooo`3oool000005@3oool3000000d0oooo0P0000050:^ji0030000
002[^nD0Zk_U00D0Zk_U0`0000070:bki0030000002[_>D0ZkcU00D0ZkcU0`0000070:bli@030000
002[_>H0ZkcV0080ZkcV0P0000020:bli@030000002[_NH0ZkgV00@0ZkgV00<000000:^miP000000
0P2[_NL400000080ZkgW00<000000?ooo`3oool00`3oool200000400oooo001Y0?ooo`040000003o
ool0oooo000001<0oooo0P00000=0?ooo`<000001`2[^^@00`000000Zk_U0:^ki@030:^ki@800000
0P2/^^<00`000000[;_T0:bki0060:bki0030000002[_>D0ZkcU0080ZkcU0P0000020:fki0030000
002/_>D0[;cU00D0[;cU00<000000:^liP2[_>H00P0000050:bli@030000002[_NH0ZkgV00<0ZkgV
00<000000:^miP0000000P0000060:^mi`030000003oool0oooo00<0oooo0P00000=0?ooo`D00000
;P3oool006X0oooo0P00000A0?ooo`<0000000<0oooo0000003oool0203oool400000080ZkWT00<0
00000:^ji02[^^@01P2[^^@00`000000Zk_U0:^ki@02000000D0[;[S00<000000:bki02/^n@01@2/
^n@00`000000ZkcU0:^li@02000000@0[K_T00<000000:bli@2/_>D01@2/_>D3000000L0[;cU00<0
00000:^miP2[_NH00`2[_NH200000080[;cV00<000000:^mi`2[_NL01@2[_NL00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;P3oool007/0oooo0P00000<
0?ooo`8000001`2[^N@00`000000Zk[T0:^ji0050:^ji0<000001`2/^^<00`000000[;_T0:bki005
0:bki0<000001`2]^n@00`000000[;cU0:bli@020:bli@8000000P2]^n@00`000000[;cU0:bli@06
0:bli@030000002[_NH0ZkgV0080000000D0[;cV0000002/_>H0[;cV000000070:^mi`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0^0?ooo`00N03oool3
000000`0oooo0P0000000`2[^><000000:^ii0060:^ii0030000002[^^@0Zk[T00<0Zk[T0P000002
0:bhhP030000002/^^<0[;[S00H0[;[S00<000000:bki02/^n@0100000020:jihP030000002]^n@0
[K_T00D0[K_T00<000000:bli@2/_>D00P0000050:fki0030000002/_>D0[;cU00D0[;cU0`000003
0:bliP050000002/_>H0[;cV0:bliP0000001P2[_NL2000000H0oooo00<000000?ooo`3oool00`3o
ool4000000@0oooo00<000000?ooo`3oool0;P3oool007H0oooo0`00000<0?ooo`8000000`2[^><0
0`000000ZkWT0:^ii0060:^ii0030000002[^^@0Zk[T008000001@2/^>800`000000[;[S0:bjh`05
0:bjh`<000001P2^^N800`000000[K_T0:fki0050:fki0<000001`2]^n@00`000000[;cU0:bli@03
0:bli@8000000P2^_>@01@000000[;cV0:bliP2/_>H0000000<0[;cV00<000000:^mi`2[_NL01000
00020:bmiP030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0^0?ooo`00L`3oool3000000`0oooo0`0000060:^hh`030000002[^N@0ZkWT00D0ZkWT0`000007
0:bhhP030000002/^^<0[;[S00<0[;[S0P0000000`2^^>0000000:jihP070:jihP030000002]^n@0
[K_T0080[K_T0P0000020:njhP030000002]^n@0[K_T00H0[K_T00<000000:bli@2/_>D00P000004
0:jli0050000002/_>H0[;cV0:bliP0000000`2/_>H3000000L0[;gV00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`800000<03oool00700oooo0`00000=0?ooo`8000000P2Z^><0
0`000000ZkSS0:^hh`050:^hh`030000002[^N@0ZkWT0080ZkWT0P0000020:bgh@030000002/^>80
[;SR00H0[;SR00<000000:bjh`2/^^<00P0000040:jhh0030000002^^N80[[WR00D0[[WR00<00000
0:fki02]^n@00P0000050:njhP030000002]^n@0[K_T00D0[K_T0`0000070:jli0050000002/_>H0
[;cV0000002/_>H00P0000020:fli@030000002/_NH0[;gV00H0[;gV00@000000?ooo`3oool0oooo
0`00000l0?ooo`00KP3oool2000000h0oooo0P0000050:Zhh`030000002[^><0ZkSS00@0ZkSS00<0
00000:^ii02[^N@00P0000050:bgh@030000002/^>80[;SR00D0[;SR0`0000060:jhh0030000002^
^N80[[WR00D0[[WR0`0000070:njhP030000002]^n@0[K_T00<0[K_T0P0000020:njhP030000002^
_>@0[[cT00D0[[cT00<000000:bliP2/_>H00P0000040:fli@030000002/_NH0[;gV00H0[;gV0P00
00050?ooo`030000003oool0oooo03T0oooo001[0?ooo`<000000P3oool2000000T0oooo0`000007
0:Zhh`030000002[^><0ZkSS00@0ZkSS0`0000070:bgh@030000002/^>80[;SR00<0[;SR0P000000
0`2^]]h000000:jhh0070:jhh0030000002^^N80[[WR0080[[WR0P0000020;2hg`030000002_^^80
[k[R00H0[k[R00<000000:fki02]^n@00P0000040:njhP030000002^_>@0[[cT00D0[[cT10000006
0:fli@030000002/_NH0[;gV00<0[;gV0P0000020:fmiP030000003oool0oooo0080oooo00<00000
0?ooo`3oool0>@3oool006T0oooo0P00000<0?ooo`@000000P2Y]n<00`000000Z[SS0:Zhh`060:Zh
h`030000002[^><0ZkSS00<000000P2/]N000`000000[;OQ0:bgh@060:bgh@030000002/^>80[;SR
00800000102^]]h00`000000[[SP0:jhh0050:jhh0030000002^^N80[[WR008000001@2`^=l00`00
0000[k[R0:njhP050:njhP<000001`2_^^800`000000[[cT0:jli0020:jli08000000P2_^n<20000
00H0[KcU00<000000:bmiP2/_NH00`0000040:fmiP030000003oool0oooo00<0oooo00<000000?oo
o`3oool0>03oool006H0oooo0`00000<0?ooo`8000001`2Y]n<00`000000Z[SS0:Zhh`050:Zhh`<0
00001P2/]N000`000000[;OQ0:bgh@050:bgh@<000001P2^]]h00`000000[[SP0:jhh0050:jhh0<0
00001`2`^=l00`000000[k[R0:njhP030:njhP8000000P2a^=l00`000000[k[R0:njhP050:njhP03
0000002^_>@0[[cT00800000102_^n<2000000H0[KcU0`0000080:fmiP030000003oool0oooo00<0
oooo00<000000?ooo`3oool0=`3oool006<0oooo0`0000020?ooo`030000003oool0oooo00P0oooo
0P0000000`2X]n<000000:Vgh`060:Vgh`030000002Z^><0Z[SS00<0Z[SS0P0000000`2[]=l00000
0:beh0060:beh0030000002/]n40[;OQ00<0[;OQ0P0000020:jcg0030000002^]]h0[[KN00D0[[KN
00<000000:jhh02^^>000P2^^>0200000080/;GL00<000000;2hg`2`^=l01P2`^=l00`000000[k[R
0:njhP02000000@0/KSO00<000000:njhP2_^^801@2_^^83000000L0[k_S00<000000:fli@2]_>D0
0P2]_>D200000080[kcT00<000000:fmiP2]_NH01P2]_NH00`000000oooo0?ooo`030?ooo`800000
>03oool00400oooo1@00000L0?ooo`8000003P3oool2000000@0Z;OS00<000000:Vgh`2Y]n<01@2Y
]n<00`000000Z[SS0:Zhh`02000000@0ZkCO00<000000:beh02/]N001@2/]N000`000000[;OQ0:bg
h@02000000@0[[?L00<000000:jfgP2^]]h01@2^]]h00`000000[[SP0:jhh002000000D0/;GL00<0
00000;2hg`2`^=l01@2`^=l3000000L0/KSO00<000000:njhP2_^^800P2_^^8200000080/[[O00<0
00000:nkh`2_^n<01@2_^n<00`000000[KcU0:fli@02000000D0[kcT00<000000:fmiP2]_NH01@2]
_NH2000000@0oooo0P00000h0?ooo`00@P3oool00`000000oooo0?ooo`0I0?ooo`<000003@3oool3
000000H0Z;OS00<000000:Vgh`2Y]n<01@2Y]n<3000000H0ZkCO00<000000:beh02/]N001@2/]N03
000000L0[[?L00<000000:jfgP2^]]h01@2^]]h2000000L0/;GL00<000000;2hg`2`^=l00`2`^=l2
00000080/[KK00<000000;6hg`2a^=l01@2a^=l00`000000[k[R0:njhP02000000@0/[[O00<00000
0:nkh`2_^n<01@2_^n<3000000L0[kcT00<000000:fmiP2]_NH00`2]_NH200000080[[gU00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0e0?ooo`00@P3oool00`000000oooo0?ooo`0G0?oo
o`8000000P3oool00`000000oooo0?ooo`070?ooo`@000000P2X]n@00`000000Z;OS0:Rgh`050:Rg
h`030000002Y]n<0ZKOS00@000000P2Y/ml00`000000ZkCO0:^dg`050:^dg`030000002/]N00[;GP
0080[;GP0P0000020:faf`030000002^/m`0[[?L00H0[[?L00<000000:jfgP2^]]h00P2^]]h20000
00030;2bfP000000/;GL00L0/;GL00<000000;2hg`2`^=l00P0000040;:ff`030000002a^=l0/KSO
00D0/KSO0`0000070;:jg`030000002_^n<0[k_S0080[k_S0`0000000`2a^n4000000:nli0070:nl
i0030000002]_NH0[KgV00800000102^_ND00`000000oooo0?ooo`030?ooo`030000003oool0oooo
03D0oooo000j0?ooo`@00000103oool00`000000oooo0?ooo`0D0?ooo`<00000303oool2000000L0
Z;OT00<000000:Rgh`2X]n<01@2X]n<2000000L0ZK?O00<000000:^dg`2[]=l0102[]=l00`000000
[;GP0:beh002000000@0[K7K00<000000:jcg02^/m`01P2^/m`00`000000[[KN0:jfgP02000000@0
/;;J00<000000;2eg02`]M`01@2`]M`3000000L0/[KK00<000000;6hg`2a^=l00P2a^=l200000080
];OL00<000000;:jg`2b^]l01@2b^]l00`000000[k_S0:nkh`0200000080/K_Q00@000000;6kh@2a
^n4000001`2__>@3000000L0[[gU00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?oo
o`00@P3oool00`000000oooo0?ooo`0A0?ooo`<000003@3oool2000000030:Ngi0000000Z;OT00H0
Z;OT00<000000:Rgh`2X]n<00`2X]n<2000000030:Rbh0000000ZK?O00H0ZK?O00<000000:^dg`2[
]=l0102[]=l3000000L0[K7K00<000000:jcg02^/m`01@2^/m`3000000H0/;;J00<000000;2eg02`
]M`00`2`]M`2000000030;>cf0000000/[KK00L0/[KK00<000000;6hg`2a^=l00P0000050;Bgg003
0000002b^]l0/[[O00D0/[[O0P0000040;6kh@040000002a^n40/K_Q000000D0[kcT0P0000020;2m
h`030000002^_ND0[[gU00D0[[gU00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0c0?oo
o`00@@3oool200000140oooo0P0000020?ooo`030000003oool0oooo00T0oooo0P0000040:Ngi003
0000002X]n@0Z;OT00D0Z;OT00<000000:Rgh`2X]n<00P0000030:Rbh0030000002Y/ml0ZK?O00H0
ZK?O00<000000:^dg`2[]=l00`0000020:^_f`030000002]/M/0[K7K00H0[K7K00<000000:jcg02^
/m`00P2^/m`200000080/:oG00<000000;2bfP2`/]X01@2`/]X00`000000/;GL0;2eg002000000@0
/k?H00<000000;:ff`2b]]/01P2b]]/2000000L0];OL00<000000;:jg`2b^]l00`2b^]l200000003
0;Bjg@000000/K_Q00<0/K_Q00D000000;6kh@2a^n40/K_Q000000020:nli0800000102`_N<00`00
0000[[gU0:jmi@050:jmi@8000001@3oool00`000000oooo0?ooo`0c0?ooo`00D@3oool3000000d0
oooo0`0000060:Ngi0030000002X]n@0Z;OT00D0Z;OT0`0000060:Rbh0030000002Y/ml0ZK?O00D0
ZK?O0`0000050:^_f`030000002]/M/0[K7K00H0[K7K00<000000:jcg02^/m`00P0000040;2_e`03
0000002`/]X0/;;J00D0/;;J0`0000060;>cf0030000002b]]/0/[KK00@0/[KK0P0000000`2f]=P0
00000;Bgg0070;Bgg0030000002b^]l0/[[O00800000102d^]d01@000000/K_Q0;6kh@2a^n400000
00<0/K_Q0`0000070;2mh`030000002^_ND0[[gU0080[[gU0P0000020:nni@070000003oool0oooo
0?ooo`000000oooo0000000d0?ooo`00C`3oool2000000`0oooo100000020:Jhi@030000002W]n@0
YkOT00D0YkOT00<000000:Rgi02X]n@0100000020:Jbh@030000002X/^00Z;;P00D0Z;;P00<00000
0:Vcg`2Y/ml00P2Y/ml200000080ZJkK00<000000:^_f`2[[m/0102[[m/00`000000[K7K0:faf`05
0:faf`<000001`2`[mL00`000000/;;J0;2bfP020;2bfP8000000P2c[m@00`000000/k?H0;>cf005
0;>cf0040000002b]]/0/[KK0;:ff`8000000`2f]=P00`000000];OL0;Bgg0070;Bgg08000001P2d
^]d01P000000/K_Q0;6kh@2a^n4000000;6kh@8000000P2c_>000`000000/;gS0;2mh`050;2mh`03
0000002^_ND0[[gU00800000102__^D00`000000oooo0?ooo`040?ooo`030000003oool0oooo0340
oooo001<0?ooo`<0000000<0oooo0000003oool0203oool3000000L0Y[SU00<000000:Ngi02W]n@0
1@2W]n@2000000L0Y[;Q00<000000:Rbh02X/^00102X/^000`000000ZK?O0:Vcg`02000000@0ZJkK
00<000000:^_f`2[[m/01@2[[m/00`000000[K7K0:faf`020:faf`8000000P2^[=H00`000000/:oG
0;2_e`050;2_e`030000002`/]X0/;;J00800000102c[m@00`000000/k?H0;>cf0050;>cf0040000
002b]]/00000000000H0][CH00<000000;Bgg02d]m`0102d]m`2000000030;Ngf@000000];[M00H0
];[M00<000000;6kh@2a^n400P0000040;>lh0030000002`_N<0/;gS00D0/;gS0`0000070:nni@03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0<@3oool004T0oooo0`00000;0?ooo`<00000
0P2V^NH00`000000Y[SU0:Jhi@050:Jhi@030000002W]n@0YkOT00<0YkOT0P0000000`2U/n800000
0:Jbh@060:Jbh@030000002X/^00Z;;P00@0Z;;P0`0000070:V^f`030000002[[m/0ZjoK00@0ZjoK
00<000000:faf`2]/M/00P0000040:j/eP030000002`[mL0/:oG00H0/:oG0P0000070;>_e0030000
002c/mP0/k?H00D0/k?H00<000000;Jdf02f]=P01`2f]=P010000000];OL0;Bgg02d]m`2000000<0
]kOI00<000000;Bjg@2d^]d01@2d^]d4000000H0/kcP00<000000;2mh`2`_N<00P2`_N<200000080
/[gR00<000000:nni@2__^D01@2__^D00`000000oooo0?ooo`040?ooo`030000003oool0oooo0300
oooo00170?ooo`800000303oool2000000H0Y[WV00<000000:Jhi@2V^>D01@2V^>D00`000000YkOT
0:Ngi002000000<0YK?R00<000000:Jbh@2V/^401P2V/^400`000000Z;;P0:Rbh00300000080YjgK
00<000000:V^f`2Y[]/01P2Y[]/00`000000ZjoK0:^_f`030:^_f`<000001`2^[=H00`000000/:oG
0;2_e`030;2_e`80000000<0/Z_B0000002c[m@01`2c[m@00`000000/k?H0;>cf0020;>cf0800000
00<0][3C0000002f]=P01`2f]=P010000000];OL0000000000060;Ngf@030000002d^]d0];[M0080
];[M0P0000020;Njf`030000002c_>00000000D0/kcP00<000000;2mh`2`_N<00P0000040;:mhP03
0000002__^D0[kkU00D0[kkU0P0000060?ooo`030000003oool0oooo02l0oooo00140?ooo`<00000
00<0oooo0000003oool02@3oool2000000030:Jii`000000Y[WV00D0Y[WV00<000000:Jhi@2V^>D0
1@2V^>D3000000H0YK?R00<000000:Jbh@2V/^401@2V/^43000000D0YjgK00<000000:V^f`2Y[]/0
1P2Y[]/00`000000ZjoK0:^_f`0300000080[:[E00<000000:j/eP2^[=H01P2^[=H01@000000/:oG
0;2_e`2`[mL0000000<0/Z_B00<000000;>_e02c[m@01P2c[m@00`000000/k?H0;>cf002000000@0
][3C00<000000;Jdf02f]=P01@2f]=P2000000P0]kOI00<000000;Bjg@2d^]d00P0000040;Njf`03
0000002c_>00000000D0/kcP0`0000070;:mhP030000002__^D0[kkU00@000000P2`_^D00`000000
oooo0?ooo`020?ooo`800000<@3oool00480oooo0P0000050?ooo`030000003oool0oooo00D0oooo
0P0000040:Jii`030000002V^NH0Y[WV00@0Y[WV00<000000:Jhi@2V^>D0100000020:Fdh`030000
002U/n80YK?R00D0YK?R00<000000:Jbh@2V/^400P2V/^42000000030:F]g@000000YjgK00H0YjgK
00<000000:V^f`2Y[]/01@2Y[]/3000000D0[:[E00<000000:j/eP2^[=H01P2^[=H010000000/:oG
0000000000050;:[dP030000002c[m@0/joD00H0/joD0P0000060;J`d`030000002f]=P0][CH00<0
][CH0P0000020;Vce0030000002g]mT0]kOI00H0]kOI0P0000070;Njf`8000000`2c_>0200000080
][cO00<000000;:mhP2b_N801P2b_N82000000H0/;kU00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0^0?ooo`00?`3oool3000000`0oooo0`0000060:Jii`030000002V^NH0Y[WV00@0Y[WV
0`0000070:Fdh`030000002U/n80YK?R00@0YK?R00<000000:Jbh@2V/^400P0000040:F]g@030000
002W[M/0YjgK00D0YjgK00<000000:V^f`2Y[]/00P2Y[]/2000000030:VWe@000000[:[E00H0[:[E
00<000000:j/eP2^[=H01@2^[=H2000000L0/Z_B00<000000;>_e02c[m@0102c[m@3000000P0][3C
00<000000;Jdf02f]=P00P0000040;Vce0030000002g]mT0]kOI00@0]kOI0`0000080;Njf`800000
00<0/kcP000000000000102f_=l00`000000/[gR0;:mhP040;:mhP80000000<0/kkR0000002`_^D0
1P2`_^D00`000000oooo0?ooo`040?ooo`030000003oool0oooo02d0oooo000l0?ooo`<0000000<0
oooo0000003oool0203oool400000080Yk[W00<000000:Jii`2V^NL01@2V^NL00`000000Y[WV0:Ji
iP0300000080Y;GU00<000000:Fdh`2U]><01@2U]><00`000000YK?R0:FchP040:FchP<000001P2U
[Md00`000000YjgK0:N]f`050:N]f`030000002Y[]/0ZJkK00800000102YYmD00`000000[:[E0:bZ
e@050:bZe@030000002^[=H0[ZcF0080[ZcF0P0000000`2`Ym0000000;:[dP070;:[dP040000002c
[m@0/joD0;>_e08000000`2f[<l00`000000][3C0;J`d`060;J`d`8000001`2i/m@010000000]kOI
0;Ngf@2g]mT2000000<0^[OF00<000000;Njf`2g^]/01P2g^]/2000000L0][cO00@000000;:mhP2b
_N80/[gR0P0000030;>nhP030000002`_^D0/;kU00D0/;kU0P0000050?ooo`030000003oool0oooo
02d0oooo000J0?ooo`@00000703oool2000000/0oooo0`0000070:Nji`030000002V^NL0Y[WW00D0
Y[WW0P0000060:Bei@030000002U]><0YKCS00D0YKCS00<000000:FchP2U/n800`0000020:>]g`03
0000002U[Md0YJgM00D0YJgM00<000000:N]f`2W[M/0102W[M/3000000H0ZJOE00<000000:bZe@2/
Z]D01@2/Z]D00`000000[ZcF0:j/eP02000000@0/:O@00<000000;:[dP2bZm801@2bZm8010000000
/joD0000000000050;J/c`030000002f/=<0][3C00@0][3C0`0000080;Vce0040000002g]mT00000
000000D0^[OF00<000000;Njf`2g^]/0102g^]/4000000L0][cO00@000000;:mhP00000000001P2c
_^800`000000/;kU0;2ni@020;2ni@8000000P2`_nD00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02`0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00000:0?ooo`<000000P2W^nP0
0`000000Yk[W0:Nji`050:Nji`030000002V^NL0Y[WW00<0Y[WW0P0000000`2T]nH000000:Bei@05
0:Bei@030000002U]><0YKCS00D0YKCS0`0000050:>]g`030000002U[Md0YJgM00D0YJgM00<00000
0:N]f`2W[M/0100000020:JVeP030000002YYmD0ZJOE00D0ZJOE00<000000:bZe@2/Z]D0102/Z]D3
000000H0/:O@00<000000;:[dP2bZm801@2bZm82000000P0]Zc?00@000000;J`d`2f/=<0][3C0P00
00030;Z_c`030000002i/m@0^K?D00H0^K?D00<000000;ZgeP2j]mH01P2j]mH010000000]k[K0;Nj
f`2g^]/200000080^[_J0P0000070;Jlg`800000202c_^800`000000/;kU0;2ni@02000000@0/;oU
00<000000?ooo`3oool00`3oool2000002d0oooo000K0?ooo`030000003oool0oooo01L0oooo0P00
00020?ooo`030000003oool0oooo00H0oooo0P0000060:Nkj0030000002W^^L0Yk[W00D0Yk[W00<0
00000:Jii`2V^NL00P0000040:BgiP030000002T]ND0Y;GU00@0Y;GU00<000000:Fdh`2U]><01000
00020::_h@030000002S[Ml0XjgO00@0XjgO00<000000:F]g@2U[Md01@2U[Md2000000H0YZKF00<0
00000:VWe@2YYmD01@2YYmD00`000000[:[E0:bZe@020:bZe@8000000P2]Y<l00`000000/:O@0;2W
d0050;2Wd0030000002bZm80/Z_B0080/Z_B0P0000020;BXc0030000002f[<l0]Zc?00D0]Zc?00@0
00000;J`d`00000000001@2j[ll00`000000^K?D0;Vce0040;Vce080000000<0_K?@0000002j]mH0
1P2j]mH010000000]k[K0000000000040;ZkfP030000002j^mX0000000@0][cO0P0000020;RngP03
0000002c_^80/kkR00D0/kkR0`0000070;2oi@030000003oool0oooo0080oooo0P0000070?ooo`80
0000903oool001@0oooo100000040?ooo`030000003oool0oooo01<0oooo0`00000;0?ooo`800000
00<0Z;cX0000002W^nP01P2W^nP00`000000Yk[W0:Nji`040:Nji`<000001P2T]nH00`000000Y;GU
0:Bei@040:Bei@<000001P2R[n400`000000XjgO0:>]g`050:>]g`030000002U[Md0YJgM0080YJgM
0P0000000`2RY]P000000:JVeP060:JVeP030000002YYmD0ZJOE00D0ZJOE00@000000:bZe@000000
0000102]Y<l00`000000/:O@0;2Wd0050;2Wd0030000002bZm80/Z_B00800000102dZ<`00`000000
]Zc?0;J/c`060;J/c`030000002j[ll0^Zo?00H0^Zo?00@000000;Vce02i/m@0^K?D0P0000030;fc
d0030000002j]mH0^[OF00H0^[OF00<000000;ZkfP2j^mX0102j^mX00`000000^[_J000000020;Jl
g`800000102h_]h00`000000/kkR0;>nhP030;>nhP8000000P2d_n800`000000/;oU0;2oi@050;2o
i@030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000S
0?ooo`006P3oool010000000oooo0?ooo`00000A0?ooo`<00000303oool2000000@0Z;cX00<00000
0:Nkj02W^nP01@2W^nP00`000000Yk[W0:Nji`0300000080YKSW00<000000:BgiP2T]nH01@2T]nH0
0`000000Y;GU0:Bei@0300000080XK3S00<000000::_h@2R[n401@2R[n400`000000XjgO0:>]g`04
0:>]g`030000002U[Md0YJgM008000000`2RY]P00`000000YZKF0:JVeP060:JVeP030000002YYmD0
ZJOE00<0ZJOE0`0000070:fTc`030000002`Ym00/:O@00D0/:O@0P0000070;BXc0030000002f[<l0
]Zc?00<0]Zc?0P0000000`2iZ/X000000;Z_c`060;Z_c`040000002i/m@00000000000H0_K?@00<0
00000;ZgeP2j]mH00`2j]mH2000000030;jhe0000000^[_J00<0^[_J0P0000020;ZkfP8000001`2h
_]h00`000000/kkR0;>nhP02000000@0];oR00<000000;2oi@2`_nD01@2`_nD2000000D0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00000S0?ooo`006`3oool200000100oooo0P00
00020?ooo`030000003oool0oooo00L0oooo0`0000060:Rlj0030000002W^nP0Yk_X00D0Yk_X0`00
00060:Fhi`030000002T]nH0Y;OV00@0Y;OV0`0000050:6`h`030000002R[n40XZoQ00H0XZoQ00<0
00000:>]g`2S[Ml00`2S[Ml3000000H0XZKH00<000000:JVeP2VY]H01@2VY]H00`000000ZJOE0:VW
e@0300000080Z:7?00<000000:fTc`2]Y<l01@2]Y<l00`000000/:O@0;2Wd0030;2Wd080000000<0
/J?:0000002dZ<`01`2dZ<`01@000000]Zc?0;J/c`2f[<l0000000<0^J[:00<000000;Z_c`2j[ll0
1P2j[ll00`000000_K?@0;fcd0070;fcd0050000002j]mH0^[OF0;ZgeP000000102n^=@400000080
^[_J0P0000000`2m_MT000000;RngP070;RngP8000001`2d_n800`000000/;oU0;2oi@020;2oi@80
00000P2a`>D00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000008`3oool002X0oooo0`00000;0?ooo`<000000P2X_>P00`000000Z;cX0:Rlj0050:Rlj003
0000002W^nP0Yk_X00@000000P2V^^L00`000000YKSW0:Fhi`050:Fhi`030000002T]nH0Y;OV00<0
00000P2Q/nD00`000000XK3S0:6`h`040:6`h`030000002R[n40XZoQ00D0XZoQ00<000000:>]g`2S
[Ml00`00000209nVf`030000002RY]P0XZKH00@0XZKH00<000000:JVeP2VY]H01@2VY]H3000000D0
Z:7?00<000000:fTc`2]Y<l01P2]Y<l01@000000/:O@0;2Wd02`Ym00000000<0/J?:00<000000;BX
c02dZ<`01P2dZ<`010000000]Zc?0000000000050;VZbP030000002j[ll0^Zo?00@0^Zo?00<00000
0;f_b`000000202m/m0010000000^[OF0000000000030;jhe0<00000102j^mX200000080_KgI00<0
00000;RngP2h_]h0102h_]h2000000030;[0gP000000];oR00H0];oR00<000000;2oi@2`_nD00P00
00040;70i@030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0240oooo000X0?ooo`8000002`3oool3000000H0Z;cX00<000000:Rlj02X_>P0102X
_>P3000000L0Y[[W00<000000:Fhi`2U^>L0102U^>L3000000H0XK?U00<000000:6`h`2Q/><0102Q
/><00`000000XZoQ0::_h@040::_h@<000001@2OY]/00`000000XZKH0::Vf0050::Vf0030000002V
Y]H0YZKF0080YZKF0P0000000`2TWm0000000:RQc`060:RQc`030000002]Y<l0[JC?00D0[JC?00@0
00000;2Wd000000000001@2aXlX00`000000]:S<0;BXc0060;BXc0030000002iZ/X0^J[:00D0^J[:
00<000000;Z_c`2j[ll00`2j[ll010000000_Jo;0;f_b`0000090;fcd0030000002n^=@0_[SD00<0
00000`2n^=@010000000^[_J0000000000020;fmf@040000002m_MT0_KgI000000<0^;kN0P000003
0;[0gP030000002d_n80];oR00D0];oR0`0000070;70i@030000003oool0oooo0080oooo0P000004
0?ooo`800000903oool002D0oooo0`0000020?ooo`030000003oool0oooo00D0oooo0`0000020:Rm
j0030000002X_>P0Z;cX00D0Z;cX00<000000:Rlj02X_>P00`0000020:Jkj0030000002V^^L0Y[[W
00H0Y[[W00<000000:Fhi`2U^>L00`0000020::eiP030000002Q/nD0XK?U00@0XK?U00<000000:6`
h`2Q/><0102Q/><00`000000XZoQ0::_h@0400000080WJSM00<0000009nVf`2OY]/0102OY]/00`00
0000XZKH0::Vf0040::Vf0030000002VY]H0YZKF00800000102TWm000`000000Z:7?0:RQc`040:RQ
c`030000002]Y<l0[JC?00D0[JC?0P0000070;6SbP030000002dZ<`0]:S<00@0]:S<0`0000080;VZ
bP030000002j[ll0^Zo?00800000102m[l/00`000000_K?@0;fcd0040;fcd080000000<0`KC>0000
000000001`2n^=@2000000@0_KgI00@000000;fmf@000000^;kN0P0000060;[0gP030000002d_n80
];oR0080];oR0P0000020;G1h`030000002a`>D0/L3U00D0/L3U0P0000050?ooo`030000003oool0
oooo02L0oooo000R0?ooo`<000002`3oool2000000H0Z;gX00<000000:Rlj02X_>P0102X_>P30000
00H0Y[_X0P0000060:Jji`<000001P2R]NH00`000000XK?U0:6ci@040:6ci@030000002Q/><0XK3S
0080XK3S1000000609fXg@030000002OY]/0WjKK00D0WjKK00<000000::Vf02RY]P00`2RY]P30000
00H0Y9o@00<000000:RQc`2XXLl01@2XXLl00`000000[JC?0:fTc`020:fTc`80000000<0[Io90000
002aXlX01`2aXlX010000000]:S<0;BXc02dZ<`2000000<0]jG700<000000;VZbP2iZ/X01@2iZ/X0
0`000000^Zo?000000070;f_b`040000002m/m00_K?@0;fcd0H00000102n^=@400000080YL?^00<0
00000;fmf@2m_MT00P2m_MT00`000000_KgI000000080;[0gP030000002d_n80];oR00800000102e
`N<00`000000/L3U0;70i@030;70i@8000000P2a`NH00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02H0oooo000P0?ooo`<000002`3oool2000000030:Vmj0000000Z;gX00H0Z;gX00<00000
0:Rlj02X_>P00`0000020:Nlj0030000002V^nP0Y[_X00H0Y[_X00<000000:Jji`2V^^L00`000002
0:>gi`030000002R]NH0X[GV00@0X[GV00<000000:6ci@2Q/nD0102Q/nD5000000<0W:[Q00<00000
09fXg@2MZ=d01@2MZ=d00`000000WjKK09nVf`0409nVf`030000002RY]P0XZKH00<000000P2OW]<0
0`000000Y9o@0:BOd0040:BOd0030000002XXLl0Z:7?00D0Z:7?00<000000:fTc`2]Y<l00P000004
0:fOb@030000002aXlX0/J?:00D0/J?:00@000000;BXc000000000001@2gYLL00`000000^J[:0;VZ
bP060;VZbP030000002m[l/0_Jo;00H0_Jo;00<000000;fcd00000000`0000040<6dcP@000001P2U
`nh00`000000_KgI0;fmf@020;fmf@80000000<0_koJ0000002j`=h01P2j`=h3000000L0]L7S00<0
00000;70i@2a`>D00P0000040;71iP030000003oool0oooo00<0oooo00<000000?ooo`3oool09P3o
ool001h0oooo0P0000030?ooo`030000003oool0oooo00H0oooo0P0000040:Vmj0030000002X_NP0
Z;gX00D0Z;gX0P0000060:Nlj0030000002V^nP0Y[_X00H0Y[_X0P0000060:>gi`030000002R]NH0
X[GV00@0X[GV00<000000:6ci@2Q/nD00`00000209b^h`030000002LZ^40W:[Q00@0W:[Q00<00000
09fXg@2MZ=d01@2MZ=d00`000000WjKK09nVf`0309nVf`<000001@2OW]<00`000000Y9o@0:BOd005
0:BOd0030000002XXLl0Z:7?00@0Z:7?0`0000060:fOb@030000002aXlX0/J?:00H0/J?:00<00000
0;NUa`2gYLL01P2gYLL00`000000^J[:0;VZbP030;VZbP<00000202m[l/3000000D0`KC>0P000002
0:G3kP030000002U`nh0YL?^00H0YL?^00P000000;fmf@2m_MT000000;nofP000000_koJ000000D0
^/3N0P0000020;_2g`030000002e`N<0]L7S00D0]L7S0`0000070;71iP030000003oool0oooo00<0
oooo00<000000?ooo`3oool09@3oool001h0oooo0P0000090?ooo`<000001P2Y_NP00`000000Z;gX
0:Rmj0030:Rmj080000000<0Z;cX0000002W_>P01P2W_>P00`000000Y[_X0:Jkj0030:Jkj0800000
00<0Y;WX0000002S]nL01@2S]nL00`000000X[GV0::eiP040::eiP<000001@2L[^<00`000000W:[Q
09bZh@0409bZh@030000002MZ=d0WJSM00D0WJSM00<0000009nVf`2OY]/00`00000209^NeP030000
002OW]<0WikC00@0WikC00<000000:BOd02TWm00102TWm000`000000Z:7?0:RQc`020:RQc`800000
00<0Z9c90000002]WlT01`2]WlT00`000000/J?:0;6SbP030;6SbP<00000202gYLL010000000^J[:
0;VZbP2iZ/X2000000<0_J[700<000000;f_b`2m[l/00P2m[l/5000000<0`KC>0`0000040:G3kP03
0000002U`nh0YL?^00H0YL?^0`0000030;nofP030000002o_mX000000080^/3N0P0000040;_2g`03
0000002e`N<0]L7S00<0]L7S0P0000020;K2i0030000002a`NH0/L7V00D0/L7V0P0000040?ooo`80
00009P3oool001h0oooo00<000000?ooo`0000001@3oool300000080ZKgX00<000000:Vmj02Y_NP0
1@2Y_NP00`000000Z;gX0:Rmj002000000@0Z;cX00<000000:Nlj02W_>P01@2W_>P00`000000Y[_X
0:Jkj002000000@0Y;WX00<000000:>gi`2S]nL0102S]nL00`000000X[GV0::eiP0300000080WK7U
00<0000009b^h`2L[^<0102L[^<00`000000W:[Q09bZh@0409bZh@030000002MZ=d0WJSM0080WJSM
1@00000509^NeP030000002OW]<0WikC00@0WikC00<000000:BOd02TWm001@2TWm0010000000Z:7?
0000000000040:RLb@030000002]WlT0[Io900D0[Io900@000000;6SbP2aXlX0/J?:0P0000030;BQ
a@030000002gYLL0]jG700H0]jG70`0000050;fZa`030000002m[l/000000080000000<0_Jo;0000
0032/<T00P32/<T3000000P0YL?^00<000000:G3kP2U`nh01@2U`nh2000000D0_koJ00@000000;no
fP00000000001`2k`]l00`000000]L7S0;G1h`02000000@0]/;T00<000000;71iP2a`NH00`2a`NH2
000000030;71iP000000oooo00@0oooo00<000000?ooo`3oool0903oool001H0oooo0P0000060?oo
o`040000001VIVH0oooo00000080oooo0P0000060:Vmj0030000002Y_NP0ZKgX00@0ZKgX0`000007
0:Rlj0030000002W_>P0YkcX00@0YkcX0`0000060:Bij0030000002S]nL0XkOW00@0XkOW0`000006
09fai@030000002L[^<0W:kS00@0W:kS00<0000009bZh@2LZ^400`2LZ^45000000<0V:3J00<00000
09^NeP2KW]H01@2KW]H00`000000WikC09nNd`0409nNd`030000002TWm00Y9o@00<0Y9o@0`000006
0:RLb@030000002]WlT0[Io900H0[Io90`0000050;BQa@030000002gYLL0]jG700H0]jG700<00000
0;fZa`2mZ/L0102mZ/L3000000<0_Jo;00<000000<:`b@32/<T00P0000020:G3kP030000002U`nh0
YL?^00H0YL?^00@000000:G3kP2U`nh0YL?^100000020:G3kP030000002o_mX0_koJ0080_koJ0P00
00000`31`m/000000;_2g`070;_2g`8000001`2f`^@00`000000/L7V0;71iP02000000@0/L7V00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`005@3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0080IVIV00@000000?ooo`3oool000001`2Y_NP00`000000ZKgX
0:Vmj00300000080Z;gX00<000000:Rlj02X_>P01P2X_>P00`000000YkcX0:Nlj00300000080Y[_X
00<000000:Bij02T^NP01@2T^NP00`000000XkOW0:>gi`0300000080WkCW00<0000009fai@2M/ND0
102M/ND00`000000W:kS09b^h`0409b^h`030000002LZ^40W:[Q00<000000P2FXmh00`000000V:3J
09RPfP0409RPfP030000002KW]H0VikF00@0VikF00<0000009nNd`2OW]<0102OW]<00`000000Y9o@
0:BOd00300000080XiW;00<000000:RLb@2XW<T01@2XW<T00`000000[Io90:fOb@050:fOb@030000
002dXLD0]:7500D0]:7500<000000;NUa`2gYLL0102gYLL2000000030;ZU``000000_J[70080_J[7
0P0000020;fZa`030000002m[l/0000000@000001@2U`nh00`000000YL?^0:G3kP050:G3kP@00000
1`2U`nh010000000_koJ0;nofP2o_mX200000080`L?K00<000000;_2g`2k`]l00`2k`]l200000003
0;_4h@000000]/;T00H0]/;T0`0000060;71iP030000003oool0oooo00@0oooo00<000000?ooo`3o
ool08P3oool001D0oooo00@000000?ooo`3oool00000103oool200000080oooo00<0IVIV0?ooo`00
00000P3oool2000000D0ZKgX0`0000060:Rmj08000001P2X_>P3000000H0Y[_X00<000000:Bij02T
^NP0102T^NP3000000H0WkCW00<0000009fai@2M/ND0102M/ND00`000000W:kS09b^h`0209b^h`@0
00001@2FXmh00`000000V:3J09RPfP0409RPfP030000002KW]H0VikF00D0VikF00<0000009nNd`2O
W]<00`2OW]<3000000D0XiW;00<000000:RLb@2XW<T01@2XW<T00`000000[Io90:fOb@030:fOb@<0
0000202dXLD00`000000]jG70;NUa`020;NUa`040000002jYL<0^ZG30;ZU``@000001@2mZ/L30000
00P0YL?^00<000000:G3kP2U`nh00`2U`nh200000080YL?^00<000000:G3kP2U`nh01P2U`nh01000
0000_koJ0000000000020<73f`0300000031`m/0000000@0^l;O00D000000;_4h@2ka>40^lCQ0000
00050;K2i08000000P2ea>D00`000000/L7V0;71iP050;71iP030000003oool0oooo00<0oooo00<0
00000?ooo`3oool08P3oool001D0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`3oool206IVIP030?ooo`000000oooo0080oooo00<000000:Vmj02Y_NP00P0000020:Vmj0030000
002X_NP0Z;gX00H0Z;gX00<000000:Rlj02X_>P00`0000020:Nlj0030000002V^nP0Y[_X00D0Y[_X
00<000000:Bij02T^NP00`0000020::gj0030000002O]>L0WkCW00@0WkCW00<0000009fai@2M/ND0
102M/ND5000000<0UZOQ00<0000009JSgP2FXmh0102FXmh00`000000V:3J09RPfP0409RPfP030000
002KW]H0VikF00@0VikF00<0000009nNd`2OW]<00`0000000`2LUlh000000:>Ib`060:>Ib`030000
002XW<T0Z9c900D0Z9c900D000000:fOb@2]WlT0[Io9000000030:nLa0030000002dXLD0]:7500D0
]:7500D000000;NUa`2gYLL0]jG7000000020;ZU``@000000`2mZ/L400000080YL?^00<000000:G3
kP2U`nh01`2U`nh00`000000YL?^0:G3kP02000000D0YL?^00<000000:G3kP2U`nh01P2U`nh00`00
0000`L?K0<73f`020<73f`0500000031`m/0`L?K0000002k`]l00P0000050;_4h@030000002f`^@0
]/;T00800000102ea>D00`000000/L7V0;71iP030;71iP80000000<0/<;W0000003oool0103oool0
0`000000oooo0?ooo`0Q0?ooo`005@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo06IVIP80oooo00<0IVIV0?ooo`0000000`3oool2000000D0ZKgX0P0000060:Rmj0<000001P2W
_>P00`000000Y[_X0:Jkj0040:Jkj0<000001P2R]nP00`000000WkCW09ndi`0409ndi`030000002M
/ND0WK7U00<000000P2H[>@00`000000UZOQ09JWh@0309JWh@030000002FXmh0UZ?N00@0UZ?N00<0
000009RPfP2HX=X0102HX=X00`000000VikF09^NeP0209^NePD000001@2LUlh00`000000XiW;0:>I
b`040:>Ib`030000002XW<T0Z9c900D0Z9c900@000000:fOb@0000000000102_W<@00`000000]:75
0;BQa@060;BQa@H000000`2jYL<4000000L0YL?^00<000000:G3kP2U`nh01P2U`nh3000000L0YL?^
00<000000:G3kP2U`nh01P2U`nh2000000@0`L?K00@000000<73f`31`m/00000202ka>42000000L0
]LCU00<000000;71iP2a`NH00P0000030;32i`030000003oool0oooo0080oooo00<000000?ooo`00
00008P3oool001H0oooo0P0000050?ooo`040000003oool0oooo06IVIP<0oooo00@0IVIV0?ooo`00
000000000P3oool00`000000ZKgX0:Vmj0050:Vmj0030000002X_NP0Z;gX00<000000P2X_>P00`00
0000YkcX0:Nlj0050:Nlj0030000002V^nP0Y[_X00<000000P2T^NP00`000000X[OX0::gj0040::g
j0030000002O]>L0WkCW00@0WkCW0`00000509R/i0030000002FYn40UZOQ00@0UZOQ00<0000009JS
gP2FXmh0102FXmh00`000000V:3J09RPfP0309RPfPD000000`2FU]400`000000W9O>09bGcP0409bG
cP030000002SVL/0XiW;00D0XiW;00<000000:RLb@2XW<T0102XW<T2000000L0[ic400<000000;BQ
a@2dXLD01@2dXLD3000000@0^ZG30P0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3
kP2U`nh0102U`nh200000080YL?^00<000000:G3kP2U`nh01P2U`nh010000000YL?^0:G3kP2U`nh4
00000080YL?^00<000000<73f`31`m/00P31`m/2000000030<;7g@000000^lCQ00@0^lCQ0P000000
0`2kan<000000;G4i@060;G4i@<000001P2``^L00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0200oooo000M0?ooo`040000003oool0oooo06IVIP@0oooo0P1VIVH01@3oool000000?ooo`3o
ool0000000H0ZKgX0`0000060:Rlj0030000002W_>P0YkcX00@0YkcX0`0000060:Bij0030000002R
]nP0X[OX00@0X[OX00<0000009ndi`2O]>L00`00000209Z`i`030000002H[>@0V:cT00@0V:cT00<0
000009JWh@2FYn40102FYn400`000000UZ?N09JSgP0309JSgP030000002HX=X0V:3J00<0000000<0
TISF0000002FU]401P2FU]400`000000W9O>09bGcP0409bGcP030000002SVL/0XiW;00@0XiW;00<0
00000:RLb@2XW<T0100000000`2XV<D000000:nLa0060:nLa0030000002dXLD0]:750080]:751000
00040;ZU``8000001@2U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00<00000102U
`nh00`000000YL?^0:G3kP060:G3kP@000001P2U`nh00`000000`L?K0<73f`02000000040<;7g@00
0000`/OM000000@0^lCQ00D000000;_7h`2kan<0^lOS000000050;G4i@80000000<0]<GV0000002`
`^L01P2``^L00`000000oooo0?ooo`040?ooo`030000003oool0oooo01l0oooo000L0?ooo`050000
003oool0oooo0?ooo`1VIVH01P3oool00`1VIVH0oooo000000020?ooo`030000002Y_NP0ZKgX00<0
00000P2X_NP00`000000Z;cX0:Rlj0050:Rlj0030000002W_>P0YkcX00<000000P2U^nP00`000000
Y;WX0:Bij0050:Bij0030000002R]nP0X[OX0080X[OX1000000609Z`i`030000002H[>@0V:cT00@0
V:cT00<0000009JWh@2FYn400`2FYn400`000000UZ?N09JSgP0209JSgP@000001@2AV=H00`000000
UYKA09JFd@0409JFd@030000002LUlh0W9O>00@0W9O>00<000000:>Ib`2SVL/01@2SVL/2000000H0
Z9S500<000000:nLa02_W<@01@2_W<@5000000<0]j31100000070:G3kP030000002U`nh0YL?^00H0
YL?^0`0000080:G3kP030000002U`nh0YL?^00<0YL?^0P0000020:G3kP030000002U`nh0YL?^00H0
YL?^0P0000030<;7g@0500000032amd0`/OM0000002ka>400P0000050;_7h`030000002ea>D0]LCU
00800000102daNH00`000000/<;W0;32i`040;32i`8000001P3oool00`000000oooo0?ooo`0N0?oo
o`00703oool01@000000oooo0?ooo`3oool0IVIV00L0oooo00<0IVIV0?ooo`0000000P3oool20000
00H0Z;gX00<000000:Rlj02X_>P0102X_>P3000000H0YK_X00<000000:Bij02T^NP0102T^NP50000
00<0W[CX00<0000009Z`i`2J/>L0102J/>L00`000000V:cT09R/i00409R/i0030000002FYn40UZOQ
0080UZOQ1P00000308jJf`030000002AV=H0TISF00<0TISF00<0000009JFd@2FU]401@2FU]400`00
0000W9O>09bGcP0409bGcP030000002SVL/0XiW;0080XiW;0`0000070:RHa@030000002_W<@0[ic4
00@0[ic40P0000000`2dXLD00000000000030;NP`@8000000P2U`nh00`000000YL?^0:G3kP060:G3
kP040000002U`nh0YL?^0:G3kP@000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0
YL?^00<000001@2U`nh00`000000YL?^0:G3kP050:G3kP8000001032amd010000000`/OM0<;7g@00
00080;_7h`8000001P2daNH00`000000/<;W0;32i`0400000080[l;X00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0N0?ooo`00703oool200000080oooo00<0IVIV0?ooo`3oool01P3oool0
0`1VIVH0oooo000000020?ooo`030000002X_NP0Z;gX00D0Z;gX00<000000:Rlj02X_>P00`000002
0:Nlj0030000002U^nP0YK_X00D0YK_X00<000000:Bij02T^NP00`0000020:6gj0030000002N]>P0
W[CX00@0W[CX00<0000009Z`i`2J/>L0102J/>L00`000000V:cT09R/i00209R/i0H000000`2>Wml0
0`000000SY[K08jJf`0308jJf`030000002AV=H0TISF00@0TISF00<0000009JFd@2FU]40102FU]40
0`000000W9O>09bGcP0409bGcP030000002SVL/0XiW;008000000`2QU<H00`000000Z9S50:RHa@04
0:RHa@040000002_W<@0[ic40:nLa0<000000P2_W<@00`000000]j310;NP`@03000000D0YL?^00<0
00000:G3kP2U`nh01@2U`nh4000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3000000P0YL?^00<0
00000:G3kP2U`nh00`2U`nh200000080YL?^00<000000<;7g@32amd00P32amd3000000H0^lOS0P00
00000`2jb>D000000;C5iP060;C5iP8000001P2_`^P00`000000oooo0?ooo`020?ooo`030000003o
ool0000001l0oooo000L0?ooo`040000003oool0oooo06IVIPX0oooo00<0IVIV0?ooo`0000000P3o
ool00`000000Z;gX0:Rmj0040:Rmj0<000001P2W_>P00`000000YK_X0:Fkj0040:Fkj0<000001P2Q
]nP00`000000W[CX09jdj00409jdj0030000002J/>L0V[3W0080V[3W1P000003092Ui0030000002>
Wml0SYoO00<0SYoO00<0000008jJf`2>V]/0102>V]/00`000000TISF096HeP03096HeP030000002F
U]40UYKA00D0UYKA00@0000009bGcP2LUlh0W9O>1@0000050:6DaP030000002XV<D0Z9S500D0Z9S5
0`0000030:nLa0D00000202U`nh00`000000YL?^0:G3kP030:G3kP8000000P2U`nh00`000000YL?^
0:G3kP070:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP070:G3kP030000
002U`nh0YL?^008000001@2U`nh00`000000`/OM0000000200000080`/[P00@000000;_7h`2kan<0
^lOS0P0000030;[8i@030000002daNH0]<GV00<0]<GV0P0000000`2caNP000000:o2j0060:o2j003
0000003oool0oooo00@0oooo00<000000?ooo`3oool0703oool001`0oooo00@000000?ooo`3oool0
IVIV2`3oool00`1VIVH0oooo000000020?ooo`030000002X_NP0Z;gX00<000000P2X_NP00`000000
YkcX0:Nlj0050:Nlj0030000002U^nP0YK_X00<000000P2T^^T00`000000XKOX0:6gj0040:6gj003
0000002N]>P0W[CX00@0W[CX1@00000309>[iP030000002@YN@0T:GT00@0T:GT00<0000008jOg`2>
Wml00`2>Wml00`000000SY[K08jJf`0408jJf`030000002AV=H0TISF00<0TISF00<0000009JFd@2F
U]400`2FU]45000000<0VI7900<000000:6DaP2QU<H01@2QU<H010000000Z9S50:RHa@2XV<D40000
00<0[ic4100000020:G3kP030000002U`nh0YL?^00L0YL?^00<000000:G3kP2U`nh00P0000050:G3
kP030000002U`nh0YL?^00H0YL?^0`0000070:G3kP030000002U`nh0YL?^00H0YL?^0`0000070:G3
kP8000000`32b^0010000000`/[P0000002kan<2000000H0^/SU00<000000;C5iP2daNH00P000003
0;?5j0030000002_`^P0[l;X00D0[l;X0P0000050?ooo`030000003oool0oooo01`0oooo000L0?oo
o`040000003oool0oooo06IVIP`0oooo00<0IVIV0?ooo`0000000P3oool2000000H0Z;gX00<00000
0:Nlj02W_>P0102W_>P3000000H0Y;[Y00<000000:6gj02Q]nP0102Q]nP00`000000W[CX09jdj003
00000080V;7X00<0000009>[iP2CZnH0102CZnH00`000000T:GT092Ui003092Ui0030000002>Wml0
SYoO00@0SYoO00<0000008jJf`2>V]/00`2>V]/00`000000TISF096HeP03096HeP030000002FU]40
UYKA00<0000000<0THo>0000002ITLT01P2ITLT00`000000XIC60:6DaP040:6DaP@000000`2XV<D4
000000L0YL?^00<000000:G3kP2U`nh01P2U`nh3000000L0YL?^00<000000:G3kP2U`nh0102U`nh2
00000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP040:G3kP8000000P2U`nh0
0`000000YL?^0:G3kP060:G3kP0300000032b^00`/[P0080`/[P00<000000<;:h00000002@2jb>D2
000000H0/lGX00<000000:o2j02_`^P0100000020:k2j0030000003oool0oooo00<0oooo00<00000
0?ooo`3oool06`3oool001/0oooo0P0000020?ooo`0306IVIP3oool0oooo00/0oooo00<0IVIV0?oo
o`0000000P3oool00`000000Z;gX0:Rmj0050:Rmj0030000002W_>P0YkcX00<000000P2V^nT00`00
0000Y;[Y0:Bjj@040:Bjj@030000002Q]nP0XKOX00@0XKOX0`00000609Raj0030000002CZnH0Tj_V
00<0Tj_V00<00000092Ui02@YN@0102@YN@00`000000SYoO08jOg`0308jOg`030000002>V]/0SY[K
0080SY[K2P000005096?cP030000002ITLT0VI7900@0VI7900<000000:6DaP2QU<H00P2QU<H40000
00<0Z9S50P0000020:G3kP030000002U`nh0YL?^00L0YL?^00@000000:G3kP2U`nh0YL?^10000002
0:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00`0000040:G3kP030000002U`nh0
YL?^00H0YL?^00<000000:G3kP2U`nh00`0000040:G3kP030000002U`nh0YL?^00H0YL?^0P000003
0<;:h080000000<0`LgT0000002jb>D01@2jb>D2000000030;S9i`000000/lGX00H0/lGX0P000006
0:k2j0030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool500000140oooo000K0?oo
o`050000003oool0oooo0?ooo`1VIVH03P3oool00`1VIVH0oooo000000020?ooo`030000002X_NP0
Z;gX00@0Z;gX0`0000060:Jkj@030000002T^^T0Y;[Y00@0Y;[Y00<000000:6gj02Q]nP00`000002
09fej@030000002H/NP0V;7X00@0V;7X00<0000009>[iP2CZnH0102CZnH00`000000T:GT092Ui002
092Ui0`000000P25T]P00`000000RXoC08Z?d`0408Z?d`030000002ASlh0THo>00<0THo>00<00000
09VAb@2ITLT0102ITLT00`000000XIC600000002000000<0XIC600@000000:RHa@00000000001@2U
`nh00`000000YL?^0:G3kP060:G3kP@000001P2U`nh00`000000YL?^0:G3kP060:G3kP<00000202U
`nh00`000000YL?^0:G3kP050:G3kP<00000202U`nh00`000000YL?^0:G3kP030:G3kP8000000P2U
`nh01`000000`/[P00000031cN@000000<7=i0000000102jb>D2000000<0^<WW00<000000;?5j02c
aNP00`2caNP2000000030;75j@000000[/;X00H0[/;X00<000000?ooo`3oool00P3oool2000000P0
oooo00<000000?ooo`3oool04@3oool001/0oooo00D000000?ooo`3oool0oooo06IVIP0?0?ooo`03
06IVIP3oool000000080oooo00<000000:Rmj02X_NP00`0000020:Nlj0030000002V^nT0Y[_Y00D0
Y[_Y00<000000:Bjj@2T^^T00P2T^^T4000000H0WKGY00<0000009Raj02H/NP0102H/NP00`000000
Tj_V09>[iP0209>[iPH000000P26W^<00`000000PiON08>GgP0308>GgP0300000025T]P0QI;H00@0
QI;H00<0000008Z?d`2:Sm<00`2:Sm<00`000000THo>096?cP04096?cP030000002ITLT0VI7900<0
VI790P0000050:6DaP<00000202U`nh00`000000YL?^0:G3kP030:G3kP8000000P2U`nh00`000000
YL?^0:G3kP060:G3kP030000002U`nh0YL?^00<0YL?^0P0000020:G3kP030000002U`nh0YL?^00H0
YL?^00@000000:G3kP2U`nh0YL?^100000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3
kP2U`nh00`0000040:G3kP8000000`31cN@010000000`LgT0000002jb>D2000000H0^<WW00<00000
0;?5j02caNP00P0000030;75j@030000002^`^P0[/;X00<0[/;X0P0000000`2]`^T000000?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool001/0oooo0P0000020?oo
o`0306IVIP3oool0oooo00h0oooo00<0IVIV0?ooo`0000000P3oool2000000H0YkcX00<000000:Jk
j@2V^nT0102V^nT5000000<0XKSY00<0000009fej@2M]NT01@2M]NT00`000000V;7X09Raj00209Ra
j0H000000P2;YNH00`000000QYkS08JNh`0408JNh`0300000023Umh0PiON00<0PiON00<0000008FB
f025T]P00`25T]P00`000000RXoC08Z?d`0408Z?d`030000002ASlh0THo>00<0THo>00<0000009VA
b@2ITLT00`0000000`2ITLT000000:6DaP0400000080YL?^00<000000:G3kP2U`nh01`2U`nh00`00
0000YL?^0:G3kP02000000D0YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP030000
00D0YL?^00<000000:G3kP2U`nh01@2U`nh4000000L0YL?^00<000000:G3kP2U`nh01@2U`nh30000
00P0YL?^00<000000<7=i031cN@00P31cN@00`000000`LgT000000090;S9i`8000001P2aaNT00`00
0000[/;X0:k2j002000000<0[L;Y00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0140oooo000K0?ooo`040000003oool0oooo06IVIQ80oooo00<0IVIV0?oo
o`0000000P3oool00`000000YkcX0:Nlj0050:Nlj0030000002V^nT0Y[_Y00<000000P2T^^T00`00
0000XKSY0:6hj@040:6hj@030000002M]NT0WKGY00@0WKGY1@00000309:]j@030000002;YNH0RjGV
00<0RjGV00<0000008JNh`26W^<00`26W^<00`000000PiON08>GgP0308>GgP0300000025T]P0QI;H
00<0QI;H00<0000008Z?d`2:Sm<0102:Sm<00`000000THo>096?cP03096?cP<000000`2ITLT30000
00L0YL?^00<000000:G3kP2U`nh01P2U`nh3000000L0YL?^00<000000:G3kP2U`nh01@2U`nh30000
00P0YL?^00<000000:G3kP2U`nh00`2U`nh200000080YL?^00<000000:G3kP2U`nh01`2U`nh00`00
0000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000`LgT0<7=i0020<7=
i080000000<0_loW0000002hbNL0102hbNL2000000030;K9j@000000/LGY00H0/LGY0`0000060:g2
j@030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?oo
o`00203oool2000000@0oooo0P0000040?ooo`8000001@3oool010000000IVIV0?ooo`1VIVHC0?oo
o`0306IVIP3oool000000080oooo0P0000050:Nlj0<000001P2T^^T00`000000XKSY0:6hj@040:6h
j@030000002M]NT0WKGY00<000000P2H/^X00`000000TZgY09:]j@0409:]j@030000002;YNH0RjGV
0080RjGV00<0000008JNh`26W^<01026W^<00`000000PiON08>GgP0308>GgP0300000025T]P0QI;H
00<0QI;H00<0000008Z?d`2:Sm<0102:Sm<00`000000THo>0000000200000004096?cP000000VI79
09VAb@8000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@0YL?^0P000002
0:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0
YL?^00L0YL?^00<000000:G3kP2U`nh00P0000050:G3kP030000002U`nh0YL?^00H0YL?^0`000007
0:G3kP030000002U`nh0YL?^00D0YL?^0P0000001@31cN@000000000002ocnL000000080_loW00<0
00000;S9i`2hbNL00P0000040;K9j@030000002aaNT0/LGY0080/LGY0P0000020:o4j@030000002]
`^T0[L;Y00D0[L;Y00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`8000004`3o
ool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`040000
003oool0IVIV06IVIQ@0oooo0P1VIVH01@000000oooo0?ooo`3oool000000080YkcX0P0000020:Jl
j@030000002T^^T0Y;[Y00D0Y;[Y00<000000:6hj@2Q^>T00P2Q^>T4000000H0V;;Z00<0000009:]
j@2B[NT00`2B[NT00`000000RjGV08^UiP0308^UiP0300000026W^<0QYkS00<0QYkS00<0000008>G
gP23Umh00`23Umh00`000000QI;H08FBf00308FBf0030000002:Sm<0RXoC00<0RXoC0`000005096?
cP8000001@2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00<000001@2U`nh00`00
0000YL?^0:G3kP050:G3kP<000001`2U`nh00`000000YL?^0:G3kP060:G3kP<000001`2U`nh00`00
0000YL?^0:G3kP040:G3kP8000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^
00<0YL?^0P0000020:G3kP030000002ocnL0_loW0080_loW00<000000;o?i`2ocnL00P0000060;K9
j@030000002aaNT0/LGY00800000102_a>T00`000000[L;Y0:g2j@030:g2j@80000000@0[<7Y0000
003oool0oooo0P0000000`3oool000000?ooo`0G0?ooo`001`3oool010000000oooo0?ooo`00000;
0?ooo`040000003oool0oooo0?ooo`8000000P3oool00`1VIVH0oooo0?ooo`0D0?ooo`0306IVIP00
000000000080oooo0P0000050:Jlj@030000002T^^T0Y;[Y00@0Y;[Y1@00000309jgjP030000002H
/^X0V;;Z00@0V;;Z00<0000009:]j@2B[NT0102B[NT00`000000RjGV08^UiP0208^UiP0300000026
W^<0QYkS0080QYkS2`00000308FBf0030000002:Sm<0000000X000001`2U`nh00`000000YL?^0:G3
kP050:G3kP<00000202U`nh00`000000YL?^0:G3kP030:G3kP8000000P2U`nh00`000000YL?^0:G3
kP060:G3kP040000002U`nh0YL?^0:G3kP@000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000
002U`nh0YL?^00<00000102U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00800000
1@2U`nh00`000000_loW0;o?i`020;o?i`80000000<0^m3Y0000002fbNT01@2fbNT3000000L0[lCY
00<000000:g2j@2]`^T00P0000030:c1j@030000003oool0oooo00<0oooo00<000000?ooo`3oool0
5P3oool000L0oooo00@000000?ooo`3oool000002@3oool2000000@0oooo00@000000?ooo`3oool0
oooo0`1VIVHE0?ooo`0306IVIP3oool000000080oooo00<000000:Jlj@2V_>T0102V_>T00`000000
Y;[Y0:Bjj@0300000080X[[Y00<0000009jgjP2N]nX0102N]nX00`000000V;;Z09RbjP0409RbjP03
0000002B[NT0TZgY0080TZgY2`00000307VFh`030000001gS]d0MhkM00<0MhkM00<0000007V9e`00
00001P0000020868d@@000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00@0
00000P2U`nh00`000000YL?^0:G3kP070:G3kP030000002U`nh0YL?^008000001@2U`nh00`000000
YL?^0:G3kP050:G3kP@000001`2U`nh00`000000YL?^0:G3kP050:G3kP<00000202U`nh00`000000
YL?^0:G3kP050:G3kP<000001`2U`nh010000000_loW0;o?i`2ocnL2000000<0^m3Y00<000000;K9
j@2fbNT00`0000020;?8jP030000002_a>T0[lCY00D0[lCY0`0000060:c1j@030000003oool0oooo
00<0oooo00<000000?ooo`3oool05@3oool000L0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`1VIVH00P3oool00`1VIVH0oooo0?ooo`0C
0?ooo`0306IVIP3oool000000080oooo00<000000:Jlj@2V_>T00`2V_>T3000000H0X[[Y00<00000
09jgjP2N]nX0102N]nX00`000000V;;Z09RbjP0209RbjPH000000`29Z>T00`000000P9oW082Oi`02
082Oi`030000001iU^<0NIKS00<0NIKS00<0000007N>g@1gS]d00`1gS]d010000000NHWG00000000
000207V9e`D000001`2U`nh00`000000YL?^0:G3kP050:G3kP<000001`2U`nh00`000000YL?^0:G3
kP060:G3kP<000001`2U`nh00`000000YL?^0:G3kP030:G3kP8000000P2U`nh00`000000YL?^0:G3
kP070:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP060:G3kP040000002U
`nh0YL?^0:G3kP@000000P2U`nh00`000000YL?^0:G3kP060:G3kP<000000P2kd>T010000000^m3Y
0;_@j@2kd>T2000000H0/lSZ00<000000:o4j@2_a>T0100000020:k3jP030000002/`NT0[<7Y00@0
[<7Y0P0000050?ooo`030000003oool0oooo01@0oooo00080?ooo`8000002P3oool3000000<0oooo
00@000000?ooo`3oool0IVIV103oool00`1VIVH0oooo0?ooo`0C0?ooo`0306IVIP3oool000000080
oooo00<000000:Jlj@2V_>T00P0000020:Fkj@030000002R^^T0X[[Y00@0X[[Y00<0000009jgjP2N
]nX0102N]nX5000000<0Tk3[00<0000008VXj@29Z>T00`29Z>T00`000000P9oW082Oi`03082Oi`03
0000001iU^<0NIKS00<0NIKS00@0000007N>g@1gS]d0MhkM0`00000307V9e`8000000P2U`nh00`00
0000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00<0YL?^0P0000020:G3kP030000002U`nh0YL?^
00H0YL?^00@000000:G3kP2U`nh0YL?^100000020:G3kP030000002U`nh0YL?^00H0YL?^00<00000
0:G3kP2U`nh00P0000050:G3kP030000002U`nh0YL?^00H0YL?^0`0000070:G3kP030000002U`nh0
YL?^00D0YL?^100000060:G3kP030000002U`nh0YL?^00H0YL?^0P0000040;_@j@<0000000<0]lk[
0000002cb>X01P2cb>X2000000H0[/?Z00<000000:c1j@2/`NT0100000000`2[`>T000000?ooo`03
0?ooo`8000005P3oool001X0oooo0P0000000`3oool0IVIV0?ooo`040?ooo`0306IVIP3oool0oooo
01<0oooo00<0IVIV0?ooo`0000000P3oool2000000D0YK_Y0P0000050::jj@030000002N]nX0W[OZ
00<000000P2J]N/00`000000Tk3[09>`j`0409>`j`0300000029Z>T0RJSY00<0RJSY00<00000082O
i`20WnL00P20WnL00`000000NIKS07VFh`0307VFh`@000000P1gS]d010000000NHWG000000000005
0:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00P0000050:G3kP030000002U`nh0
YL?^00D0YL?^100000070:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP030000002U`nh0
YL?^00@0YL?^0P0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh010000002
0:G3kP030000002U`nh0YL?^00H0YL?^00@000000:G3kP2U`nh0YL?^100000020:G3kP040000002k
d>T0^m3Y0;_@j@8000000P2gc^/00`000000/lSZ0;?8jP030;?8jP80000000<0/<O[0000002^`nX0
1P2^`nX2000000H0Zl3Y00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`006P3o
ool010000000oooo0?ooo`1VIVH60?ooo`0306IVIP3oool0oooo01<0oooo0P1VIVH010000000oooo
0?ooo`0000070:Fkj@040000002R^^T0X[[Y0::jj@@000001P2J]N/00`000000Tk3[09>`j`0309>`
j`0300000029Z>T0RJSY00<0RJSY00<00000082Oi`20WnL00`20WnL00`000000NIKS07VFh`040000
00<0MhkM0`0000080:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP030000002U`nh0YL?^
00<0YL?^0P0000020:G3kP030000002U`nh0YL?^00L0YL?^00<000000:G3kP2U`nh0100000020:G3
kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00`0000040:G3kP030000002U`nh0YL?^
00H0YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^100000060:G3kP060000002kd>T00000
0000002gc^/000000`2gc^/00`000000/lSZ0;?8jP02000000<0/<O[00<000000:k3jP2^`nX00`2^
`nX2000000030:c2jP000000Zl3Y00D0Zl3Y00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0C0?ooo`006@3oool01@000000oooo0?ooo`3oool0IVIV00L0oooo00<0IVIV0?ooo`3oool04`3o
ool00`1VIVH0oooo000000020?ooo`030000002U^nT0YK_Y00@0YK_Y100000030:2ijP030000002J
]N/0V[G[00D0V[G[00<0000009>`j`2C/>/00`2C/>/010000000RJSY08VXj@29Z>T;00000080NIKS
100000020:G3kP030000002U`nh0YL?^00L0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000
002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00P0000050:G3kP030000002U`nh0YL?^00H0YL?^
0`0000070:G3kP030000002U`nh0YL?^00D0YL?^0`0000080:G3kP030000002U`nh0YL?^00<0YL?^
0P0000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`2U`nh200000080YL?^
00<000000:G3kP2U`nh01P2U`nh00`000000]lk[0;O>j`020;O>j`040000002gc^/0]lk[0;O>j`80
00001P2`an/00`000000[/?Z0:k3jP02000000<0[<;Z00<000000:_0j@2[`>T0102[`>T2000000D0
oooo00<000000?ooo`3oool04P3oool001T0oooo0P0000020?ooo`0306IVIP3oool0oooo00H0oooo
00<0IVIV0?ooo`3oool04P3oool206IVIP050?ooo`000000oooo0?ooo`0000000P2U^nT300000080
Y;_Y00<000000:2ijP2P^NX00`2P^NX00`000000V[G[09Zej`0409Zej`X000000`20Y>/400000080
M9WX100000070:G3kP8000001`2U`nh3000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0
YL?^00<000000:G3kP2U`nh0102U`nh200000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000
YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP03000000@0
YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP02000000D0YL?^00<000000:G3kP2U
`nh01@2U`nh2000000@0]lk[0P0000020;C<k0030000002`an/0/<O[00@0/<O[0`0000060:c2jP03
0000002[`>T0Zl3Y00<000000P2[_nT00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140
oooo000I0?ooo`050000003oool0oooo0?ooo`1VIVH02@3oool00`1VIVH0oooo0?ooo`0A0?ooo`05
06IVIP3oool0IVIV0?ooo`0000000P3oool2000000D0Y;_Y00<000000:2ijP2P^NX0102P^NX00`00
0000V[G[09Zej`0300000080U[C/00<0000008b]k02<[N`00`2<[N`00`000000P:C[082Tj`040000
00<0M9WX0P0000020:G3kP030000002U`nh0YL?^00L0YL?^00<000000:G3kP2U`nh0100000020:G3
kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^
00H0YL?^00<000000:G3kP2U`nh00`0000040:G3kP030000002U`nh0YL?^00H0YL?^0`0000070:G3
kP030000002U`nh0YL?^00D0YL?^0`0000080:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3
kP030000002U`nh0YL?^00<0YL?^0P0000020:G3kP060000002gc^/000000000002dc>`000000P2d
c>`00`000000/<O[0;37j`0400000080[/G[00<000000:c2jP2/`^X0102/`^X3000000D0ZkoY00<0
00000?ooo`3oool00P3oool2000001<0oooo000I0?ooo`040000003oool0oooo06IVIP/0oooo0P1V
IVHA0?ooo`0606IVIP3oool0oooo06IVIP3oool000000P3oool00`000000Y;_Y0:Bkj@040:Bkj@03
0000002P^NX0X;WZ0080X;WZ1000000609Jdk0030000002<[N`0S:g/0080S:g/0`000003082Tj`04
0000001dVNP00000000000D0YL?^00<000000:G3kP2U`nh01P2U`nh3000000L0YL?^00<000000:G3
kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3000000P0YL?^00<000000:G3
kP2U`nh00`2U`nh200000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP040000
0080YL?^00<000000:G3kP2U`nh01P2U`nh010000000YL?^0:G3kP2U`nh400000080YL?^00<00000
0:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP02000000@0YL?^0P0000030;C<k0040000002dc>`0
]<c/0;C<k08000001P2^aN/00`000000[<;Z0:c2jP04000000030:_1j@000000ZkoY00H0ZkoY00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`006@3oool010000000oooo0?ooo`1V
IVH=0?ooo`0306IVIP3oool0oooo00d0oooo00<0IVIV0?ooo`3oool00P3oool00`1VIVH0oooo0000
00020?ooo`030000002T^nT0Y;_Y00<0Y;_Y1@00000309fhj`030000002F]>`0U[C/00@0U[C/00<0
000008b]k02<[N`00P0000000`2<[N`00000082Tj`02082Tj`<00000202U`nh00`000000YL?^0:G3
kP030:G3kP8000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00@000000P2U
`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3
kP060:G3kP030000002U`nh0YL?^00<000001@2U`nh00`000000YL?^0:G3kP050:G3kP<000001`2U
`nh00`000000YL?^0:G3kP050:G3kP@000001P2U`nh00`000000YL?^0:G3kP060:G3kP<000001`2U
`nh00`000000]<c/0;C<k0020;C<k0<0000000<0/<W/0000002^aN/01P2^aN/2000000H0Zl7Y00<0
00000:^oj@2[_nT0102[_nT2000000D0oooo00<000000?ooo`3oool03`3oool001P0oooo0P000002
0?ooo`0306IVIP3oool0oooo00`0oooo00<0IVIV0?ooo`3oool0303oool00`1VIVH0oooo0?ooo`03
0?ooo`0306IVIP3oool000000080oooo00<000000:Bkj@2T^nT00P0000020::jjP030000002M^>/0
WKS[00@0WKS[00<0000009Jdk02F]>`00`2F]>`300000080S:g/1@0000020:G3kP030000002U`nh0
YL?^00L0YL?^00<000000:G3kP2U`nh00P0000050:G3kP030000002U`nh0YL?^00D0YL?^0`000007
0:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^0`000008
0:G3kP030000002U`nh0YL?^00<0YL?^0P0000020:G3kP030000002U`nh0YL?^00H0YL?^00<00000
0:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00H0YL?^00@000000:G3kP2U`nh0YL?^1000
00020:G3kP030000002U`nh0YL?^00D0YL?^0P0000020;C<k0<000000P2`bN`00`000000[/G[0:k5
j`030:k5j`80000000<0[L?Z0000002[`NT01@2[`NT00`000000ZkoY0:^oj@0400000080Z[oY00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`006@3oool010000000oooo0?ooo`1V
IVH?0?ooo`0306IVIP3oool0oooo00/0oooo00<0IVIV0?ooo`3oool0103oool206IVIP030000003o
ool0oooo008000001@2R^^X00`000000WKS[09fhj`0409fhj`030000002F]>`0000000P000001`2U
`nh2000000L0YL?^0`0000070:G3kP030000002U`nh0YL?^00<0YL?^0P0000020:G3kP030000002U
`nh0YL?^00H0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00H0YL?^00<0
00000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00L0YL?^00<000000:G3kP2U`nh00P00
00040:G3kP030000002U`nh0YL?^00H0YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^1000
00060:G3kP030000002U`nh0YL?^00D0YL?^100000020;39k0050000002`bN`0/<W/0;39k0000000
0P2^aN/2000000<0[L?Z00<000000:_1j@2[`NT0102[`NT3000000H0Z[oY00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0>0?ooo`00603oool01@000000oooo0?ooo`3oool0IVIV0100oooo
00<0IVIV0?ooo`3oool02P3oool00`1VIVH0oooo0?ooo`060?ooo`0506IVIP000000oooo0?ooo`00
00001P2R^^X00`000000WKS[09fhj`0209fhj`H0000000<0T[?]0000000000000P2U`nh00`000000
YL?^0:G3kP070:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP060:G3kP03
0000002U`nh0YL?^008000001@2U`nh00`000000YL?^0:G3kP050:G3kP<000001`2U`nh00`000000
YL?^0:G3kP050:G3kP<000001`2U`nh00`000000YL?^0:G3kP060:G3kP<000001`2U`nh00`000000
YL?^0:G3kP030:G3kP8000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00@0
00000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00@000000P2U`nh2000000<0
/<W/00<000000;39k02`bN`00`0000060:g3jP030000002[`NT0Zl7Y00<000000P2[`>T00`000000
Z[oY0:Zoj@040:Zoj@8000000`3oool3000000l0oooo000H0?ooo`050000003oool0oooo0?ooo`1V
IVH04@3oool00`1VIVH0oooo0?ooo`090?ooo`0306IVIP3oool0oooo00L0oooo00D0IVIV0000003o
ool0oooo000000050::jjPD000000`2K^>`010000000T[?]0000000000050:G3kP030000002U`nh0
YL?^00H0YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP030000002U`nh0
YL?^00<0YL?^0P0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh010000002
0:G3kP030000002U`nh0YL?^00H0YL?^00@000000:G3kP2U`nh0YL?^100000020:G3kP030000002U
`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`0000040:G3kP030000002U`nh0YL?^00H0YL?^0`00
00070:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP8000000P2`bN`300000080[/K/00<0
00000:g3jP2]`nX0102]`nX3000000H0Zl3Y00<000000:Zoj@2Z_nT00`0000020:Znj0030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3oool001P0oooo0`0000000`3oool0IVIV0?ooo`0A
0?ooo`0306IVIP3oool0oooo00P0oooo00<0IVIV0?ooo`3oool0203oool01@1VIVH000000000003o
ool000000080X[[Z1@00000409^hk0<00000202U`nh00`000000YL?^0:G3kP030:G3kP8000000P2U
`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3
kP060:G3kP030000002U`nh0YL?^008000001@2U`nh00`000000YL?^0:G3kP050:G3kP<000001`2U
`nh00`000000YL?^0:G3kP050:G3kP@000001P2U`nh00`000000YL?^0:G3kP050:G3kP<00000202U
`nh00`000000YL?^0:G3kP030:G3kP8000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U
`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP060:G3kP<000000P2^a^`01@000000[/K/0:k6
k02^a^`000000080[L?Z0`0000020:_2jP030000002[`>T0Zl3Y00@0Zl3Y0`0000050:Znj0030000
003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00100oooo1@0000030?ooo`040000001V
IVH0oooo06IVIQ@0oooo00<0IVIV0?ooo`3oool01`3oool00`1VIVH0oooo0?ooo`090?ooo`0406IV
IP3oool000000?ooo`<00000102Q^^/400000080YL?^00<000000:G3kP2U`nh01`2U`nh00`000000
YL?^0:G3kP02000000D0YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U
`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh00`2U`nh200000080YL?^00<000000:G3kP2U
`nh01P2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000
YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP03000000@0
YL?^00<000000:G3kP2U`nh01P2U`nh3000000H0YL?^00<000000:G3kP2U`nh01P2U`nh300000080
[/K/00@000000:k6k02^a^`0[/K/0`0000050:_2jP030000002[`>T0Zl3Y00@0000000<0Z[oY0000
002Z_^P01P2Z_^P00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo000B0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`1VIVH0IVIV5@3oool206IVIPL0oooo00<0IVIV0?oo
o`3oool02P3oool01@1VIVH000000000003oool0000000<0XK[[0`0000060:G3kP8000001`2U`nh3
000000P0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00H0YL?^00<00000
0:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00P000005
0:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^0`000007
0:G3kP030000002U`nh0YL?^00D0YL?^0`0000080:G3kP030000002U`nh0YL?^00<0YL?^0P000002
0:G3kP030000002U`nh0YL?^00D0YL?^00@000000:G3kP2U`nh0YL?^100000020:G3kP030000002^
a^`0[/K/00@000000P2/a>/00`000000Zl;Z0:_2jP030:_2jP<000001P2Z_nT00`000000Z[kX0:Zn
j0040:Znj08000000`3oool2000000L0oooo100000020?ooo`004P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080IVIV5P3oool00`1VIVH0oooo0?ooo`040?ooo`0306IVIP3oool0
oooo00P0oooo0`0000000`1VIVH0oooo0000000400000080YL?^00<000000:G3kP2U`nh01P2U`nh0
0`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh3000000L0YL?^00<00000
0:G3kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0YL?^00<00000
0:G3kP2U`nh00`2U`nh200000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP04
00000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP0400000080YL?^00<00000
0:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP03000000@0YL?^00<000000:G3kP2U`nh01@2U`nh4
000000H0YL?^0`0000020:c4j`050000002/a>/0[<C[0:c4j`0000000P2[`^X300000080Zl3Y00<0
00000:Zoj@2Z_nT0102Z_nT00`000000Z[kX0:Znj00400000080ZKkX00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo000B0?ooo`030000003oool0
oooo0080oooo0P0000020?ooo`0306IVIP3oool0IVIV01H0oooo00<0IVIV0?ooo`3oool00P3oool0
0`1VIVH0oooo0?ooo`060?ooo`<000000`3oool3000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3
000000L0YL?^00<000000:G3kP2U`nh00`2U`nh200000080YL?^00<000000:G3kP2U`nh01P2U`nh0
0`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP04
00000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP02000000D0YL?^00<00000
0:G3kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0YL?^00<00000
0:G3kP2U`nh01@2U`nh3000000P0YL?^00<000000:G3kP2U`nh00P2U`nh200000080YL?^00<00000
0:G3kP2U`nh01P2U`nh2000000<0[<C[00@000000:c4j`2/a>/0[<C[0P0000050:_0j@030000002Z
_nT0Z[oY00@0Z[oY0`0000060:Vnj0030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`004P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`1VIVH00P3oool00`1VIVH0oooo0?ooo`0D0?ooo`0506IVIP3oool0oooo0?ooo`1VIVH0
1@3oool3000000@0oooo0P0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh0
100000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00P0000050:G3kP030000
002U`nh0YL?^00D0YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP030000
002U`nh0YL?^00D0YL?^0`0000070:G3kP030000002U`nh0YL?^00<0YL?^0P0000020:G3kP030000
002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00H0YL?^
00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh0
0P0000040:G3kP030000002U`nh0YL?^00H0YL?^0P0000030:c4j`060000002/a>/000000000002[
`^X000001P2[`>T00`000000Z[oY0:Zoj@0300000080Z[kY00<000000:Vnj02Y_^P0102Y_^P20000
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`004@3oool2000000@0
oooo00D000000?ooo`3oool0oooo06IVIP030?ooo`0306IVIP3oool0oooo01@0oooo00@0IVIV0?oo
o`3oool0IVIV0P3oool3000000D0oooo0P0000050:G3kP8000001P2U`nh3000000L0YL?^00<00000
0:G3kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh00`2U`nh200000080YL?^00<00000
0:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh0
0`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP02
000000D0YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3
000000H0YL?^00<000000:G3kP2U`nh01P2U`nh3000000L0YL?^00<000000:G3kP2U`nh00`2U`nh2
00000080YL?^00<000000:c4j`2/a>/00P0000030:_2jP030000002[`>T0Zl3Y00@0Zl3Y0`000006
0:Znj@030000002Y_^P0ZKkX00<0000000<0ZKkX0000003oool0103oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo000G0?ooo`80000000<0oooo06IVIP3oool0103oool0
0`1VIVH0oooo0?ooo`0D0?ooo`0306IVIP3oool00000008000001@3oool3000000T0YL?^00<00000
0:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh010000002
0:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00P0000050:G3kP030000002U`nh0
YL?^00D0YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP030000002U`nh0
YL?^00D0YL?^0`0000070:G3kP030000002U`nh0YL?^00<0YL?^0P0000020:G3kP030000002U`nh0
YL?^00H0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^00@00000
0:G3kP2U`nh0YL?^100000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`00
00040:G3kP<000000P2[`^X01@000000Zl;Z0:_2jP2[`^X000000080Zl3Y0`0000020:Zoj@030000
002Z_^T0Z[kY00@0Z[kY0`0000050:Vnj0030000003oool0oooo00@00000103oool2000000<0oooo
000G0?ooo`040000003oool0oooo06IVIPH0oooo00<0IVIV0?ooo`3oool04P3oool30000000306IV
IP3oool0oooo0080oooo0`0000020:G3kP030000002U`nh0YL?^00L0YL?^0`0000060:G3kP800000
1P2U`nh3000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh0
0`2U`nh200000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP0400000080YL?^
00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh0
1P2U`nh00`000000YL?^0:G3kP02000000@0YL?^00<000000:G3kP2U`nh01P2U`nh3000000H0YL?^
00<000000:G3kP2U`nh01@2U`nh4000000H0YL?^00<000000:G3kP2U`nh01@2U`nh3000000P0YL?^
0P0000020:_2jP040000002[`^X0Zl;Z0:_2jP<000001@2Z_nT00`000000Z[kY0:Znj@0400000003
0:Vnj0000000ZKkX00D0ZKkX00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`00
5`3oool010000000oooo0?ooo`1VIVH70?ooo`80IVIV403oool2000000<0oooo00<0IVIV0?ooo`00
00000P0000060:G3kP8000001@2U`nh200000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000
YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP0400000080
YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP02000000D0YL?^00<000000:G3kP2U
`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U
`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh00`2U`nh200000080YL?^00<000000:G3kP2U
`nh01@2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000
YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh200000080Zl;Z100000020:[0j@03
0000002Z_nT0Z[oY00<0Z[oY0`0000060:Vnj0030000002Y_^P0ZKkX00<0ZKkX0P0000040?ooo`80
0000203oool001L0oooo00@000000?ooo`3oool0IVIV2@3oool00`1VIVH0oooo0?ooo`0:0?ooo`<0
00000`3oool400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP02000000D0
YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^0P0000060:G3kP<000001`2U`nh00`000000
YL?^0:G3kP050:G3kP<000001`2U`nh00`000000YL?^0:G3kP030:G3kP8000000P2U`nh00`000000
YL?^0:G3kP060:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP060:G3kP03
0000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00<0
0000102U`nh00`000000YL?^0:G3kP050:G3kP<000001`2U`nh00`000000YL?^0:G3kP050:G3kP<0
00001`2U`nh00`000000YL?^0:G3kP050:G3kP@000000P2Z`>T01@000000Z/3Y0:[0j@2Z`>T00000
0080Z[oY0`0000020:Vnj@030000002Y_^P0ZKkX00@0ZKkX00<000000:Vnj02Y_^P00`0000020?oo
o`@0000000<0IVIV0000003oool01`3oool001H0oooo0P0000020?ooo`0306IVIP3oool0oooo00P0
oooo00<0IVIV0?ooo`3oool01P3oool3000000<0oooo0`0000070:G3kP030000002U`nh0YL?^00D0
YL?^0`0000070:G3kP030000002U`nh0YL?^00<0YL?^0P0000020:G3kP030000002U`nh0YL?^00H0
YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U
`nh0100000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00P0000050:G3kP03
0000002U`nh0YL?^00D0YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP03
0000002U`nh0YL?^00D0YL?^0`0000080:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000
YL?^0:G3kP060:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP060:G3kP03
0000002U`nh0YL?^00@000000P2U`nh2000000<0Z/3Y00<000000:[0j@2Z`>T00`0000050:Vnj@03
0000002Y_^P0ZKkX00@0ZKkX0`0000020?ooo`<00000101VIVH00`3oool000000?ooo`070?ooo`00
5P3oool01@000000oooo0?ooo`3oool0IVIV00/0oooo00<0IVIV0?ooo`3oool00P3oool3000000<0
oooo0`0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh0100000020:G3kP03
0000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00P0000050:G3kP030000002U`nh0YL?^00D0
YL?^0`0000060:G3kP8000001P2U`nh3000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3000000P0
YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U
`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh0100000020:G3kP03
0000002U`nh0YL?^00H0YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP03
0000002U`nh0YL?^00H0YL?^0`0000060:G3kP030000002[`NX000000080Z/3Y0`0000020:Zoj@03
0000002Y_^T0ZKkY00@0ZKkY00<000000:Vnj02Y_^P00`0000020?ooo`<000000`1VIVH00`3oool0
IVIV0?ooo`020?ooo`030000003oool0oooo00H0oooo000F0?ooo`050000003oool0oooo0?ooo`1V
IVH0303oool0101VIVH000000000000000030?ooo`<000001P2U`nh2000000H0YL?^0`0000070:G3
kP8000001P2U`nh3000000L0YL?^00<000000:G3kP2U`nh00`2U`nh200000080YL?^00<000000:G3
kP2U`nh01P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01P2U`nh00`00
0000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh3000000L0YL?^00<000000:G3
kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3
kP2U`nh00`2U`nh200000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP040000
0080YL?^00<000000:G3kP2U`nh01@2U`nh010000000YL?^0:G3kP2U`nh400000080YL?^00<00000
0:G3kP2U`nh01@2U`nh4000000030:Zoj@000000Z[oY0080Z[oY00<000000:Vnj@2Y_^T0102Y_^T3
000000030?ooo`0000000000008000000`1VIVH40?ooo`0306IVIP3oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool001H0oooo00@000000?ooo`3oool0IVIV2`3oool30000000406IVIP3oool0
oooo0?ooo`8000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00<000000P2U
`nh00`000000YL?^0:G3kP070:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3
kP060:G3kP030000002U`nh0YL?^008000001@2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U
`nh2000000H0YL?^0`0000070:G3kP030000002U`nh0YL?^00<0YL?^0P0000020:G3kP030000002U
`nh0YL?^00H0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^00<0
00000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00P00
00040:G3kP030000002U`nh0YL?^00H0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0YL?^1000
00060:G3kP030000002U`nh0YL?^00D0YL?^0`0000030:Zoj@050000002Z_nT0Z[oY0:Zoj@000000
0P2Y_^T3000000040?ooo`0000000000000000@0IVIV203oool01@1VIVH0oooo0?ooo`3oool00000
00L0oooo000F0?ooo`040000003oool0oooo06IVIPP0oooo0`0000040?ooo`0306IVIP0000000000
00D0YL?^0P0000060:G3kP<000001P2U`nh2000000L0YL?^0`0000060:G3kP8000001P2U`nh30000
00P0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3
kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00P0000050:G3
kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3
kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP030000002U`nh0YL?^00<0YL?^0P0000020:G3
kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^
00H0YL?^00<000000:G3kP2U`nh0100000020:G3kP8000000P2Z_nT010000000Z[oY0:Zoj@2Z_nT3
000000040?ooo`0000000000000000<0IVIV303oool01@1VIVH0oooo0?ooo`3oool0000000L0oooo
000E0?ooo`8000000P3oool00`1VIVH0oooo0?ooo`040?ooo`8000001@3oool3000000T0YL?^00<0
00000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh01000
00020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U
`nh0YL?^00H0YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U
`nh0YL?^00D0YL?^0`0000070:G3kP030000002U`nh0YL?^00<0YL?^0P0000020:G3kP030000002U
`nh0YL?^00D0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00H0YL?^00<0
00000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`00
00040:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00H0YL?^0`00
00060:G3kP8000000P2Z_nT8000000<0IVIV3`3oool01@1VIVH0oooo0?ooo`3oool0000000L0oooo
000E0?ooo`050000003oool0oooo0?ooo`1VIVH00`3oool3000000@0oooo0`0000020:G3kP030000
002U`nh0YL?^00L0YL?^0`0000060:G3kP8000001P2U`nh3000000L0YL?^00<000000:G3kP2U`nh0
1@2U`nh3000000H0YL?^00<000000:G3kP2U`nh00`2U`nh200000080YL?^00<000000:G3kP2U`nh0
1P2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^
0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP02000000@0YL?^
00<000000:G3kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^
00<000000:G3kP2U`nh01@2U`nh3000000P0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000
002U`nh0YL?^00D0YL?^00@000000:G3kP2U`nh0YL?^100000020:G3kP030000002U`nh0YL?^00D0
YL?^0`000000103oool0000000000000000406IVIQ80oooo00D0IVIV0?ooo`3oool0oooo00000007
0?ooo`005@3oool01@000000oooo0?ooo`3oool0IVIV00<00000103oool3000000H0YL?^0P000005
0:G3kP8000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00<000000P2U`nh0
0`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP05
0:G3kP030000002U`nh0YL?^008000001@2U`nh00`000000YL?^0:G3kP050:G3kP<000001`2U`nh0
0`000000YL?^0:G3kP040:G3kP<000001`2U`nh00`000000YL?^0:G3kP050:G3kP<000001`2U`nh0
0`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP04
00000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0400000080YL?^00<00000
0:G3kP2U`nh01P2U`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U`nh4000000H0YL?^00<00000
0:G3kP2U`nh01@2U`nh400000080IVIV00<000000?ooo`3oool0503oool01@1VIVH0oooo0?ooo`3o
ool0000000L0oooo000E0?ooo`D00000103oool300000080YL?^00<000000:G3kP2U`nh01P2U`nh0
0`000000YL?^0:G3kP02000000D0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^0P000006
0:G3kP<000001`2U`nh00`000000YL?^0:G3kP040:G3kP<00000202U`nh00`000000YL?^0:G3kP04
00000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<00000
0:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh2
000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U`nh3
000000L0YL?^00<000000:G3kP2U`nh00`2U`nh200000080YL?^00<000000:G3kP2U`nh01@2U`nh0
0`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP04
00000080YL?^00D0000006IVIP3oool0oooo0000000F0?ooo`0506IVIP3oool0oooo0?ooo`000000
1`3oool001D0oooo0P0000000`3oool0IVIV0?ooo`020?ooo`8000001P2U`nh2000000H0YL?^0`00
00080:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U
`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00<000000P2U
`nh00`000000YL?^0:G3kP070:G3kP8000001`2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U
`nh00`000000YL?^0:G3kP050:G3kP<000001`2U`nh00`000000YL?^0:G3kP030:G3kP80000000<0
YL?^0000002U`nh01`2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U
`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3
kP02000000@0YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh01@2U
`nh3000000H0YL?^00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`0506IVIP3o
ool0oooo0?ooo`0000001`3oool000030?ooo`000000000000<000000P3oool2000000@0oooo0P00
00060?ooo`030000003oool0IVIV00@0oooo00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3
kP0300000080YL?^00<000000:G3kP2U`nh01`2U`nh2000000L0YL?^00<000000:G3kP2U`nh01@2U
`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^0P0000050:G3kP80000000<0
YL?^0000002U`nh01`2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U
`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3
kP02000000@0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U
`nh3000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh01000
00020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U
`nh0YL?^00D0YL?^00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`0306IVIP3o
ool0oooo0080oooo00<000000?ooo`3oool0103oool000<0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`0000060?ooo`8000001@3oool2000000H0YL?^0`0000060:G3kP8000001@2U
`nh2000000030:G3kP000000YL?^00L0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U
`nh0YL?^00D0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00H0YL?^00<0
00000:G3kP2U`nh00P0000040:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP030000002U
`nh0YL?^00@0YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP030000002U
`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@000000P2U
`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3
kP050:G3kP<000001P2U`nh00`000000YL?^0:G3kP060:G3kP<000001P2U`nh00`000000YL?^0:G3
kP050:G3kP800000103oool00`000000oooo0?ooo`0B0?ooo`0506IVIP3oool0oooo0?ooo`000000
1P3oool000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`0306IVIP00
0000oooo00D0oooo00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00H0YL?^00<0
00000:G3kP2U`nh00P0000040:G3kP8000001P2U`nh3000000L0YL?^00<000000:G3kP2U`nh0102U
`nh3000000L0YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh01000
00020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U
`nh0YL?^00H0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^0`00
00070:G3kP030000002U`nh0YL?^00@0YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^0`00
00060:G3kP030000002U`nh0YL?^00<0YL?^0P0000020:G3kP030000002U`nh0YL?^00D0YL?^00@0
00000:G3kP2U`nh0YL?^100000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh0
100000020:G3kP050000003oool0oooo0?ooo`000000503oool01@1VIVH0oooo0?ooo`3oool00000
00H0oooo00030?ooo`030000003oool0oooo00P0oooo0P00000:0?ooo`030000003oool0oooo00@0
oooo0P0000060:G3kP8000001P2U`nh3000000P0YL?^00<000000:G3kP2U`nh00`0000020:G3kP03
0000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00H0
YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP03
0000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP03
0000002U`nh0YL?^00<0YL?^0P0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U
`nh00`0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh0100000020:G3kP03
0000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00P0000040:G3kP030000002U`nh0YL?^00D0
YL?^100000060:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000003oool0oooo0080
oooo00<000000?ooo`3oool04@3oool01@1VIVH0oooo0?ooo`3oool0000000H0oooo00030?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`03
0000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00H0
YL?^0`0000060:G3kP8000001P2U`nh3000000H0YL?^0P0000060:G3kP<000001`2U`nh200000080
YL?^0`0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh0100000020:G3kP03
0000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0
YL?^00<000000:G3kP2U`nh00P0000050:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP03
0000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP03
0000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00@0
00000P2U`nh00`000000YL?^0:G3kP050:G3kP030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool01@1VIVH0oooo0?ooo`3oool0000000H0oooo00020?ooo`8000002P3oool3000000/0
oooo00<0000006IVIP3oool0103oool00`000000YL?^0:G3kP050:G3kP<000001P2U`nh200000080
YL?^100000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00`0000020:G3kP03
0000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00H0
YL?^0`0000060:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0
YL?^0`0000070:G3kP030000002U`nh0YL?^00@0YL?^0`0000080:G3kP030000002U`nh0YL?^00@0
00000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000
YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP050:G3kP<0
00001P2U`nh00`000000YL?^0:G3kP060:G3kP<000001P2U`nh00`000000YL?^0:G3kP050:G3kP80
00000`3oool00`000000oooo0?ooo`0@0?ooo`0506IVIP3oool0oooo0?ooo`0000001P3oool001d0
oooo0P0000050?ooo`030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP060:G3kP80
00001`2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3kP050:G3kP<0
00001P2U`nh00`000000YL?^0:G3kP030:G3kP8000000P2U`nh00`000000YL?^0:G3kP050:G3kP03
0000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@0
00000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000
YL?^0:G3kP060:G3kP<000001P2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000
YL?^0:G3kP050:G3kP<000001`2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U
`nh01@2U`nh010000000YL?^0:G3kP2U`nh400000080YL?^00<000000:G3kP2U`nh01@2U`nh00`00
0000YL?^0:G3kP0400000080YL?^00D000000?ooo`3oool0oooo0000000A0?ooo`0506IVIP3oool0
oooo06IVIP0000001P3oool001l0oooo00<000000?ooo`3oool00`3oool2000000L0YL?^00<00000
0:G3kP2U`nh00`2U`nh2000000030:G3kP000000YL?^00L0YL?^00<000000:G3kP2U`nh010000002
0:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0
YL?^00D0YL?^00<000000:G3kP2U`nh00P0000050:G3kP030000002U`nh0YL?^00@0YL?^0`000007
0:G3kP030000002U`nh0YL?^00@0YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^0`000006
0:G3kP8000000P2U`nh400000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP04
00000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0400000080YL?^00<00000
0:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U`nh4000000H0YL?^00<00000
0:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=
0?ooo`@0IVIV00<0oooo0000003oool01@3oool00200oooo00<000000?ooo`3oool00`3oool00`00
0000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00800000102U`nh2000000H0YL?^0`0000070:G3
kP030000002U`nh0YL?^00@0YL?^0`0000070:G3kP030000002U`nh0YL?^00@0YL?^0`0000080:G3
kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^
00<000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00@000000P2U`nh00`00
0000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`00
0000YL?^0:G3kP050:G3kP<000001`2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3
kP2U`nh01@2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01P2U`nh00`00
0000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00T0oooo0`1VIVH00`3oool0IVIV0?ooo`030?ooo`030000003oool0oooo
00<0oooo000Q0?ooo`030000003oool0oooo00<0oooo0P0000060:G3kP<00000202U`nh00`000000
YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP0300000080
YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U
`nh01P2U`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U
`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0
YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U
`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0
YL?^0`0000070:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0
YL?^0P0000030?ooo`030000003oool0oooo00D0oooo101VIVH50?ooo`0506IVIP3oool0oooo0?oo
o`0000001@3oool00280oooo0P0000050?ooo`030000002U`nh0YL?^00<000000P2U`nh2000000L0
YL?^0`0000060:G3kP8000001P2U`nh3000000H0YL?^0P0000060:G3kP<000001P2U`nh200000080
YL?^100000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh0100000020:G3kP03
0000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0
YL?^0`0000070:G3kP030000002U`nh0YL?^00@0YL?^0`0000070:G3kP030000002U`nh0YL?^00@0
YL?^0`0000060:G3kP030000002U`nh0YL?^00<0YL?^0P0000020:G3kP030000002U`nh0YL?^00D0
YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U
`nh0100000000`2U`nh000000:G3kP070:G3kP030000002U`nh0YL?^00@000000P2U`nh01@000000
oooo0?ooo`3oool0000000<0oooo0`1VIVH90?ooo`0506IVIP3oool0oooo0?ooo`0000001@3oool0
02@0oooo00<000000?ooo`3oool00`3oool2000000L0YL?^0P0000020:G3kP<000000P2U`nh00`00
0000YL?^0:G3kP060:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP060:G3
kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP050:G3kP<000001`2U`nh00`00
0000YL?^0:G3kP040:G3kP<000001`2U`nh00`000000YL?^0:G3kP040:G3kP<000001`2U`nh20000
0080YL?^0`0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00`0000020:G3
kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^
00D0YL?^00<000000:G3kP2U`nh00P0000050:G3kP030000002U`nh0YL?^00@0YL?^0`0000070:G3
kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3
kP060000003oool0oooo0?ooo`1VIVH000000P1VIVH<0?ooo`0506IVIP3oool0oooo0?ooo`000000
1@3oool002D0oooo00<000000?ooo`3oool00`3oool2000000L0YL?^0`0000060:G3kP030000002U
`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP8000000P2U
`nh300000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<0
00000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01P2U
`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U
`nh3000000H0YL?^00<000000:G3kP2U`nh0102U`nh3000000P0YL?^00<000000:G3kP2U`nh00`00
00020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh0100000000`2U`nh000000:G3
kP060:G3kP040000002U`nh0YL?^0:G3kP@000000P2U`nh00`000000YL?^0:G3kP040:G3kP800000
0P1VIVH20?ooo`030000003oool0oooo00/0oooo00D0IVIV0?ooo`3oool0oooo000000050?ooo`00
9P3oool00`000000oooo0?ooo`040?ooo`8000000P2U`nh300000080YL?^00<000000:G3kP2U`nh0
1@2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^
0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh0
1@2U`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh0
0`2U`nh200000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0400000080YL?^
00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh0
1@2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01P2U`nh3000000H0YL?^
00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh0102U`nh4000000H0YL?^
00<000000:G3kP2U`nh0100000020:G3kP050000003oool0oooo0?ooo`0000003@3oool01@1VIVH0
oooo0?ooo`3oool0000000D0oooo000W0?ooo`030000001VIVH0oooo00D0oooo0P0000060:G3kP03
0000002U`nh0YL?^00@0YL?^0`0000070:G3kP030000002U`nh0YL?^00@0YL?^0`0000070:G3kP80
00000P2U`nh300000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0400000080
YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U
`nh01@2U`nh00`000000YL?^0:G3kP02000000@0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0
YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0
YL?^0P0000020:G3kP@000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@0
00000P2U`nh00`000000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000
YL?^0:G3kP050:G3kP<000001P2U`nh00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00D0IVIV0?ooo`3oool0oooo000000050?ooo`00:03oool2000000H0oooo00<000000:G3kP2U
`nh01@2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000
YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01P2U`nh3000000H0YL?^00<000000:G3kP2U
`nh0102U`nh3000000L0YL?^00<000000:G3kP2U`nh0102U`nh3000000L0YL?^00<000000:G3kP2U
`nh0102U`nh3000000L0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0
YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U
`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0
YL?^0`0000060:G3kP030000002U`nh0YL?^00@0YL?^0`0000070:G3kP030000002U`nh0YL?^00@0
00000P2U`nh00`000000YL?^0:G3kP050:G3kP030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool01@1VIVH0oooo0?ooo`3oool0000000D0oooo000Z0?ooo`030000003oool0oooo00@0
oooo00<000000:G3kP2U`nh0102U`nh3000000H0YL?^0P0000060:G3kP<000001P2U`nh200000080
YL?^100000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`0000020:G3kP03
0000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00H0
YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP03
0000002U`nh0YL?^00@0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP03
0000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@0
00000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000
YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3kP050:G3kP8000000`3oool00`000000
oooo0?ooo`090?ooo`0306IVIP3oool0oooo0080oooo00<000000?ooo`3oool00P3oool002/0oooo
00<000000?ooo`3oool0103oool00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0
1P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0YL?^
00<000000:G3kP2U`nh0102U`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^
00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^0P0000020:G3kP<000000P2U`nh00`000000YL?^
0:G3kP060:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000
002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^
0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^
0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0400000080YL?^
00D000000?ooo`3oool0oooo0000000;0?ooo`0506IVIP3oool0oooo0?ooo`000000103oool002`0
oooo00<0000006IVIP3oool0103oool2000000H0YL?^0P0000060:G3kP<000001P2U`nh200000080
YL?^0`0000020:G3kP030000002U`nh0YL?^00H0YL?^00<000000:G3kP2U`nh00`0000020:G3kP03
0000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0
YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP03
0000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00@0YL?^0`0000070:G3kP03
0000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@0
00000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000
YL?^0:G3kP040:G3kP<000001P2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D0IVIV0?ooo`3oool0oooo000000040?oo
o`00;@3oool2000000D0oooo00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP0300000080
YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^0P0000060:G3kP<000001P2U`nh00`000000
YL?^0:G3kP040:G3kP<000001`2U`nh00`000000YL?^0:G3kP040:G3kP<000001`2U`nh00`000000
YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0400000080
YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U
`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U
`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00D0
YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`0506IVIP3oool0oooo0?ooo`000000103oool002l0
oooo00<000000?ooo`3oool00`3oool2000000H0YL?^0`0000060:G3kP8000000P2U`nh300000080
YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U
`nh01@2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000
YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U
`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^0P0000020:G3kP<0
00000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000
YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP050:G3kP<0
00001@2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3kP050:G3kP80
00000`3oool00`000000oooo0?ooo`070?ooo`0506IVIP3oool0oooo0?ooo`000000103oool00300
oooo00<000000?ooo`3oool00P3oool00`1VIVH0oooo000000020:G3kP<000000P2U`nh00`000000
YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000
YL?^0:G3kP040:G3kP<000001P2U`nh2000000@0YL?^1@0000060:G3kP8000000P2U`nh300000080
YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U
`nh01@2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0
YL?^00<000000:G3kP2U`nh0102U`nh3000000H0YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0
YL?^00<000000:G3kP2U`nh0100000000`2U`nh000000:G3kP060:G3kP030000002U`nh0YL?^00@0
00000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@000000P2U`nh01@000000
oooo0?ooo`3oool0000000P0oooo00D0IVIV0?ooo`3oool0oooo000000040?ooo`00<@3oool01@00
0000IVIV0?ooo`3oool0IVIV0080oooo0P0000060:G3kP8000000P2U`nh300000080YL?^00<00000
0:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U`nh0
0`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01@2U`nh5000000@0YL?^00<00000
0:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh0102U`nh3000000L0YL?^00<00000
0:G3kP2U`nh0102U`nh3000000L0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0
YL?^00D0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^00<00000
0:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0
YL?^00@0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP050000003oool0
oooo0?ooo`0000001`3oool01@1VIVH0oooo0?ooo`3oool0000000@0oooo000b0?ooo`040000001V
IVH0oooo06IVIP<0oooo00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh0
102U`nh3000000L0YL?^00<000000:G3kP2U`nh0102U`nh3000000H0YL?^0P0000020:G3kP<00000
0P2U`nh00`000000YL?^0:G3kP050:G3kP8000000P2U`nh300000080YL?^00<000000:G3kP2U`nh0
1@2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01P2U`nh00`000000YL?^
0:G3kP0300000080YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh0
1@2U`nh3000000D0YL?^00<000000:G3kP2U`nh01@2U`nh3000000L0YL?^00<000000:G3kP2U`nh0
100000020:G3kP030000002U`nh0YL?^00@0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000
002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^
0P0000030?ooo`030000003oool0oooo00@0oooo00D0IVIV0?ooo`3oool0oooo000000040?ooo`00
<`3oool20000000306IVIP3oool0oooo0080oooo0P0000020:G3kP<000000P2U`nh00`000000YL?^
0:G3kP050:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP060:G3kP030000
002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^
0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3kP040:G3kP<000001P2U`nh2000000@0YL?^
1@0000060:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000
002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00@00000
0P2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3kP040:G3kP<00000
1P2U`nh00`000000YL?^0:G3kP050:G3kP<000001`2U`nh00`000000YL?^0:G3kP04000000030:G3
kP000000oooo0080oooo00<000000?ooo`3oool0103oool01P1VIVH0oooo0?ooo`3oool0IVIV0000
00<0oooo000e0?ooo`030000003oool0oooo00@0oooo0P0000060:G3kP030000002U`nh0YL?^00@0
YL?^0`0000060:G3kP8000001P2U`nh3000000H0YL?^0P0000020:G3kP<000000P2U`nh00`000000
YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP050:G3kP03
0000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP050:G3kPD00000102U`nh00`000000
YL?^0:G3kP040:G3kP<000001P2U`nh00`000000YL?^0:G3kP050:G3kP<000001`2U`nh00`000000
YL?^0:G3kP020:G3kP@000001`2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U
`nh01@2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000
YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00D000000?ooo`3o
ool0oooo000000050?ooo`@0IVIV00<0oooo0000003oool00P3oool003H0oooo00<000000?ooo`3o
ool0103oool00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000
YL?^0:G3kP060:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP050:G3kP<0
00001P2U`nh00`000000YL?^0:G3kP040:G3kP<000001P2U`nh00`000000YL?^0:G3kP050:G3kP<0
00001P2U`nh200000080YL?^0`0000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U
`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh0100000020:G3kP03
0000002U`nh0YL?^00D0YL?^1@0000030:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP03
0000002U`nh0YL?^00D0YL?^0`0000050:G3kP030000002U`nh0YL?^00D0YL?^0`0000070:G3kP03
0000002U`nh0YL?^00@0000000<0YL?^0000002U`nh01P2U`nh00`000000oooo0?ooo`020?ooo`03
0000001VIVH0IVIV0080IVIV00<0oooo06IVIP3oool00P3oool00`000000oooo0?ooo`010?ooo`00
=`3oool00`000000IVIV0?ooo`040?ooo`030000002U`nh0YL?^00@0YL?^0`0000060:G3kP030000
002U`nh0YL?^00D0YL?^0`0000060:G3kP8000000P2U`nh300000080YL?^00<000000:G3kP2U`nh0
1@2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^
0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh0
102U`nh3000000H0YL?^00<000000:G3kP2U`nh0102U`nh3000000L0YL?^00<000000:G3kP2U`nh0
100000020:G3kP030000002U`nh0YL?^00@0YL?^0P0000020:G3kP<000000P2U`nh00`000000YL?^
0:G3kP050:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP040:G3kP030000
002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^
0:G3kP040:G3kP80000000@0oooo06IVIP1VIVH000001@3oool01@1VIVH0oooo0?ooo`3oool00000
00<0oooo000h0?ooo`8000001@3oool00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U
`nh01@2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0
YL?^00<000000:G3kP2U`nh0102U`nh3000000H0YL?^00<000000:G3kP2U`nh0102U`nh3000000L0
YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U
`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`0000020:G3kP03
0000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0YL?^0`0000050:G3kP03
0000002U`nh0YL?^00D0YL?^0`0000070:G3kP030000002U`nh0YL?^0080YL?^100000070:G3kP03
0000002U`nh0YL?^00@0000000<0YL?^0000002U`nh01P2U`nh00`000000YL?^0:G3kP0400000080
YL?^00D000000?ooo`3oool0oooo000000040?ooo`0506IVIP3oool0oooo0?ooo`0000000`3oool0
03X0oooo00<000000?ooo`3oool00`3oool2000000H0YL?^0P0000040:G3kP@000001`2U`nh20000
0080YL?^0`0000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`0000020:G3
kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^
00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00D0YL?^0`0000050:G3kP030000002U`nh0YL?^
00D0YL?^0`0000060:G3kP8000000P2U`nh300000080YL?^00<000000:G3kP2U`nh01@2U`nh00`00
0000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh0102U`nh00`000000YL?^0:G3kP040000
0080YL?^00<000000:G3kP2U`nh01@2U`nh5000000<0YL?^00<000000:G3kP2U`nh01@2U`nh30000
00H0YL?^00<000000:G3kP2U`nh0102U`nh3000000L0YL?^00D000000?ooo`3oool0oooo00000003
0?ooo`0506IVIP3oool0oooo0?ooo`0000000`3oool003/0oooo00<000000?ooo`3oool00`3oool0
0`000000YL?^0:G3kP050:G3kPD000000`2U`nh2000000L0YL?^0`0000060:G3kP030000002U`nh0
YL?^00@0YL?^0`0000060:G3kP800000102U`nh4000000H0YL?^0P0000020:G3kP<000000P2U`nh0
0`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP04
0:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP050:G3kP<000001@2U`nh0
0`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3kP040:G3kP<000001`2U`nh0
0`000000YL?^0:G3kP04000000030:G3kP000000YL?^00H0YL?^00<000000:G3kP2U`nh010000002
0:G3kP030000002U`nh0YL?^00@0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0
YL?^00D0YL?^0P0000030?ooo`040000003oool0oooo06IVIP<0oooo00<000000?ooo`3oool00@3o
ool003`0oooo00<0000006IVIP3oool00`3oool200000080YL?^0`0000020:G3kP030000002U`nh0
YL?^00D0YL?^0P0000020:G3kP<000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0
YL?^00<000000P2U`nh00`000000YL?^0:G3kP050:G3kPD000000`2U`nh00`000000YL?^0:G3kP05
0:G3kP<000001P2U`nh00`000000YL?^0:G3kP040:G3kP<000001`2U`nh00`000000YL?^0:G3kP02
0:G3kP@000001`2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh0102U`nh0
0`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP03
00000080YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3kP2U`nh0102U`nh3
000000H0YL?^00<000000:G3kP2U`nh0102U`nh3000000L0YL?^00<000000:G3kP2U`nh010000000
0`2U`nh000000?ooo`020?ooo`040000003oool0oooo06IVIP<0oooo00<000000?ooo`3oool00@3o
ool003d0oooo00<0000006IVIP3oool0103oool2000000H0YL?^0P0000060:G3kP<000001P2U`nh0
0`000000YL?^0:G3kP040:G3kP<000001P2U`nh200000080YL?^0`0000020:G3kP030000002U`nh0
YL?^00@0YL?^0P0000020:G3kP<000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0
YL?^00<000000P2U`nh00`000000YL?^0:G3kP050:G3kPD000000`2U`nh00`000000YL?^0:G3kP05
0:G3kP<000001P2U`nh00`000000YL?^0:G3kP040:G3kP<000001`2U`nh00`000000YL?^0:G3kP02
0:G3kPD000001P2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh0102U`nh0
0`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP03
00000080YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00L000000?ooo`3oool0oooo0000
003oool0IVIV00@0oooo0@0000010?ooo`40oooo000n0?ooo`8000001@3oool00`000000YL?^0:G3
kP060:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U
`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3
kP040:G3kP<000001P2U`nh00`000000YL?^0:G3kP040:G3kP<000001P2U`nh200000080YL?^0`00
00020:G3kP030000002U`nh0YL?^00@0YL?^0P0000020:G3kP<000000P2U`nh00`000000YL?^0:G3
kP050:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP050:G3kPD00000102U
`nh00`000000YL?^0:G3kP040:G3kP<000001P2U`nh00`000000YL?^0:G3kP040:G3kP<000001`2U
`nh00`000000YL?^0:G3kP020:G3kPD000001P2U`nh00`000000YL?^0:G3kP04000000030:G3kP00
0000YL?^00H0YL?^00<000000?ooo`3oool00P3oool00`000000oooo06IVIP030?ooo`4000000@3o
ool10?ooo`00@03oool00`000000oooo0?ooo`030?ooo`8000001P2U`nh3000000H0YL?^0P000004
0:G3kP@000001P2U`nh200000080YL?^0`0000020:G3kP030000002U`nh0YL?^00D0YL?^00<00000
0:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`000002
0:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00@0YL?^0`000006
0:G3kP030000002U`nh0YL?^00@0YL?^0`0000060:G3kP8000000P2U`nh300000080YL?^00<00000
0:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01@2U`nh0
0`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01@2U`nh5000000@0YL?^00<00000
0:G3kP2U`nh0102U`nh3000000H0YL?^00<000000:G3kP2U`nh0102U`nh2000000<0oooo00<00000
0?ooo`1VIVH00`3oool100000040oooo0@3oool00440oooo00<0000006IVIP3oool0103oool00`00
0000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01@2U`nh5000000<0YL?^00<000000:G3
kP2U`nh01@2U`nh3000000D0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<000000:G3
kP2U`nh00P2U`nh5000000H0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^
00D0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3
kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^0`0000050:G3kP030000002U`nh0YL?^
00D0YL?^0`0000050:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^
00@000000P2U`nh00`000000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00@000000P2U`nh00`00
0000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00@000000P2U`nh01P000000oooo0?ooo`3oool0
000006IVIP<0oooo0@0000010?ooo`40oooo00120?ooo`030000001VIVH0oooo00@0oooo0P000006
0:G3kP8000000P2U`nh300000080YL?^00<000000:G3kP2U`nh0102U`nh200000080YL?^0`000002
0:G3kP030000002U`nh0YL?^00@0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0
YL?^00@0YL?^1@0000040:G3kP030000002U`nh0YL?^00@0YL?^0`0000060:G3kP030000002U`nh0
YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^0080YL?^1@0000060:G3kP030000002U`nh0
YL?^00@000000P2U`nh00`000000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00@000000P2U`nh0
0`000000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP04
0:G3kP<000001P2U`nh00`000000YL?^0:G3kP040:G3kP<000001P2U`nh00`000000YL?^0:G3kP04
0:G3kP<000001`2U`nh01@000000oooo0?ooo`3oool0000000<0oooo0@0000010?ooo`40oooo0013
0?ooo`8000001@3oool00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3kP04
0:G3kP<000001@2U`nh00`000000YL?^0:G3kP040:G3kP<000001`2U`nh00`000000YL?^0:G3kP03
00000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0300000080YL?^00<00000
0:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh0102U`nh5
000000@0YL?^00<000000:G3kP2U`nh0102U`nh3000000H0YL?^00<000000:G3kP2U`nh0102U`nh3
000000L0YL?^00<000000:G3kP2U`nh00P2U`nh4000000L0YL?^00<000000:G3kP2U`nh00`000002
0:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0
YL?^00D0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^0P000002
0?ooo`0506IVIP000000oooo0?ooo`0000000P3oool004D0oooo00<000000?ooo`3oool00`3oool2
00000080YL?^0`0000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`000002
0:G3kP030000002U`nh0YL?^00@0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0
YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^00@0YL?^0`0000060:G3kP030000002U`nh0
YL?^00@0YL?^0`0000070:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP05
0:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0
YL?^00<000000P2U`nh00`000000YL?^0:G3kP050:G3kPD000000`2U`nh00`000000YL?^0:G3kP05
0:G3kP<000001@2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3kP02
0:G3kPD000001P2U`nh00`000000YL?^0:G3kP04000000060:G3kP000000oooo0?ooo`1VIVH00000
0P3oool100000040oooo0@3oool004H0oooo00<0000006IVIP3oool0103oool2000000H0YL?^00<0
00000:G3kP2U`nh0102U`nh3000000H0YL?^00<000000:G3kP2U`nh00P2U`nh4000000H0YL?^0P00
00020:G3kP<000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00<000000P2U
`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3
kP050:G3kP<000001@2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3
kP020:G3kPD000001P2U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh0102U
`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh0102U`nh00`000000YL?^0:G3
kP0400000080YL?^00<000000:G3kP2U`nh0102U`nh5000000@0YL?^00<000000:G3kP2U`nh0102U
`nh3000000H0YL?^00L000000?ooo`1VIVH0oooo0000003oool000000080oooo00170?ooo`030000
001VIVH0oooo00@0oooo00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0300000080YL?^
00<000000:G3kP2U`nh0102U`nh5000000<0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^
00<000000:G3kP2U`nh0102U`nh3000000H0YL?^0P0000040:G3kP@000001P2U`nh200000080YL?^
0`0000020:G3kP030000002U`nh0YL?^00@0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000
002U`nh0YL?^00@0YL?^1@0000040:G3kP030000002U`nh0YL?^00@0YL?^0`0000060:G3kP030000
002U`nh0YL?^00@0YL?^0`0000070:G3kP030000002U`nh0YL?^0080YL?^100000060:G3kP030000
002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00@00000
0P2U`nh00`000000YL?^0:G3kP040:G3kP030000003oool0IVIV0080oooo00<000000?ooo`000000
0@3oool004P0oooo00<0000006IVIP3oool0103oool2000000@0YL?^100000060:G3kP030000002U
`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP040:G3kP8000000P2U`nh300000080YL?^00<0
00000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01@2U
`nh5000000<0YL?^00<000000:G3kP2U`nh01@2U`nh3000000D0YL?^00<000000:G3kP2U`nh0102U
`nh3000000L0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^00<0
00000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`00
00020:G3kP030000002U`nh0YL?^00D0YL?^1@0000030:G3kP030000002U`nh0YL?^00@0YL?^0`00
00060:G3kP030000002U`nh0YL?^00@0YL?^0`0000070:G3kP030000002U`nh0YL?^0080YL?^0`00
0000103oool0IVIV0?ooo`3oool200000040oooo00190?ooo`800000103oool00`1VIVH0oooo0000
0003000000<0YL?^00<000000:G3kP2U`nh0102U`nh3000000H0YL?^00<000000:G3kP2U`nh0102U
`nh3000000H0YL?^0P0000040:G3kP@000001P2U`nh200000080YL?^0`0000020:G3kP030000002U
`nh0YL?^00@0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^00@0YL?^00<0
00000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^0`0000050:G3kP030000002U
`nh0YL?^00D0YL?^0`0000050:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U
`nh0YL?^00@0000000<0YL?^0000002U`nh01P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<0
00000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01@2U
`nh5000000@0oooo00<0IVIV0?ooo`3oool00P0000010?ooo`00B`3oool01@000000oooo0?ooo`3o
ool0IVIV0080oooo00<000000:G3kP2U`nh0102U`nh00`000000YL?^0:G3kP0300000080YL?^00<0
00000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01@2U
`nh5000000<0YL?^00<000000:G3kP2U`nh01@2U`nh3000000D0YL?^00<000000:G3kP2U`nh0102U
`nh3000000L0YL?^00<000000:G3kP2U`nh00P2U`nh4000000H0YL?^0P0000020:G3kP<000000P2U
`nh00`000000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3
kP040:G3kP030000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP040:G3kP<000001P2U
`nh00`000000YL?^0:G3kP040:G3kP<000001P2U`nh00`000000YL?^0:G3kP020:G3kPD000001P2U
`nh00`000000YL?^0:G3kP04000000P0oooo101VIVH200000040oooo001<0?ooo`040000001VIVH0
oooo06IVIP<0oooo00<000000:G3kP2U`nh00`2U`nh3000000H0YL?^0P0000040:G3kP@000001P2U
`nh200000080YL?^0`0000020:G3kP030000002U`nh0YL?^00@0YL?^0P0000020:G3kP<000000P2U
`nh00`000000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3
kP050:G3kPD000000`2U`nh00`000000YL?^0:G3kP050:G3kP<000001@2U`nh00`000000YL?^0:G3
kP040:G3kP<000001`2U`nh00`000000YL?^0:G3kP020:G3kP@000001`2U`nh00`000000YL?^0:G3
kP0300000080YL?^00<000000:G3kP2U`nh0102U`nh00`000000YL?^0:G3kP0400000080YL?^00<0
00000:G3kP2U`nh0102U`nh5000000@0YL?^00<000000:G3kP2U`nh0102U`nh3000000P0oooo101V
IVH4000000<0oooo001=0?ooo`030000001VIVH0IVIV00@0oooo00<000000:G3kP2U`nh00P000002
0:G3kP030000002U`nh0YL?^00D0YL?^1@0000030:G3kP030000002U`nh0YL?^00D0YL?^0`000006
0:G3kP030000002U`nh0YL?^00@0YL?^0`0000060:G3kP030000002U`nh0YL?^0080YL?^10000006
0:G3kP8000000P2U`nh300000080YL?^00<000000:G3kP2U`nh0102U`nh00`000000YL?^0:G3kP04
00000080YL?^00<000000:G3kP2U`nh0102U`nh00`000000YL?^0:G3kP0300000080YL?^00<00000
0:G3kP2U`nh01@2U`nh5000000<0YL?^00<000000:G3kP2U`nh01@2U`nh3000000H0YL?^00<00000
0:G3kP2U`nh00P2U`nh4000000L0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0
YL?^00@0YL?^00<000000:G3kP2U`nh0100000070?ooo`@0IVIV100000070?ooo`00CP3oool00`00
0000IVIV0?ooo`040?ooo`8000001@2U`nh200000080YL?^0`0000020:G3kP030000002U`nh0YL?^
00@0YL?^0P0000020:G3kP<000000P2U`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^
00<000000P2U`nh00`000000YL?^0:G3kP040:G3kPD000000`2U`nh00`000000YL?^0:G3kP050:G3
kP<000001@2U`nh00`000000YL?^0:G3kP040:G3kP<000001`2U`nh00`000000YL?^0:G3kP020:G3
kP@000001P2U`nh200000080YL?^0`0000020:G3kP030000002U`nh0YL?^00@0YL?^00<000000:G3
kP2U`nh0100000020:G3kP030000002U`nh0YL?^00@0YL?^1@0000030:G3kP030000002U`nh0YL?^
00D0YL?^0`0000050:G3kP030000002U`nh0YL?^00@0YL?^0`0000070?ooo`@0IVIV1000000;0?oo
o`00C`3oool2000000D0oooo00<000000:G3kP2U`nh0102U`nh3000000H0YL?^00<000000:G3kP2U
`nh0102U`nh3000000H0YL?^0P0000040:G3kP@000001P2U`nh00`000000YL?^0:G3kP0300000080
YL?^00<000000:G3kP2U`nh0102U`nh200000080YL?^0`0000020:G3kP030000002U`nh0YL?^00@0
YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^1@0000030:G3kP03
0000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000002U`nh0YL?^0080YL?^100000060:G3kP03
0000002U`nh0YL?^00@000000P2U`nh00`000000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00@0
00000P2U`nh00`000000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00<000001`3oool306IVIP@0
00003`3oool00540oooo00<0000006IVIP3oool00`3oool200000080YL?^0P0000020:G3kP030000
002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^
1@0000030:G3kP030000002U`nh0YL?^00@0YL?^0`0000060:G3kP030000002U`nh0YL?^00@0YL?^
0`0000060:G3kP030000002U`nh0YL?^0080YL?^100000060:G3kP8000000P2U`nh300000080YL?^
00<000000:G3kP2U`nh0102U`nh00`000000YL?^0:G3kP0400000080YL?^00<000000:G3kP2U`nh0
102U`nh5000000<0YL?^00<000000:G3kP2U`nh0102U`nh3000000H0YL?^00<000000:G3kP2U`nh0
102U`nh3000000H0YL?^00<000000:G3kP2U`nh00P2U`nh5000000H0oooo101VIVH3000001<0oooo
001B0?ooo`030000001VIVH0oooo00@0oooo0P0000050:G3kP800000102U`nh4000000H0YL?^0P00
00020:G3kP<000000P2U`nh00`000000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00<000000P2U
`nh00`000000YL?^0:G3kP050:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3
kP040:G3kPD000000`2U`nh00`000000YL?^0:G3kP050:G3kP<000001P2U`nh00`000000YL?^0:G3
kP020:G3kP@000001`2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0102U
`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3
kP0300000080YL?^00<000000:G3kP2U`nh0102U`nh5000000L0oooo101VIVH4000001H0oooo001C
0?ooo`030000001VIVH0oooo00@0oooo00<000000:G3kP2U`nh0102U`nh5000000<0YL?^00<00000
0:G3kP2U`nh01@2U`nh3000000D0YL?^00<000000:G3kP2U`nh0102U`nh3000000H0YL?^0P000004
0:G3kP@000001P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0102U`nh2
00000080YL?^0`0000020:G3kP030000002U`nh0YL?^00@0YL?^1@0000030:G3kP030000002U`nh0
YL?^00D0YL?^0`0000050:G3kP030000002U`nh0YL?^00@0YL?^0`0000060:G3kP030000002U`nh0
YL?^0080YL?^1@0000060:G3kP030000002U`nh0YL?^00<00000203oool406IVIP@000006P3oool0
05@0oooo0P0000050?ooo`030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP040:G3
kP8000000P2U`nh300000080YL?^00<000000:G3kP2U`nh0102U`nh00`000000YL?^0:G3kP030000
0080YL?^00<000000:G3kP2U`nh01@2U`nh5000000<0YL?^00<000000:G3kP2U`nh0102U`nh30000
00H0YL?^00<000000:G3kP2U`nh00P2U`nh5000000H0YL?^00<000000:G3kP2U`nh00`0000020:G3
kP030000002U`nh0YL?^00@0YL?^00<000000:G3kP2U`nh0100000020:G3kP030000002U`nh0YL?^
00@0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00@0YL?^1@0000040:G3
kP030000002U`nh0YL?^00@0YL?^0`0000070?ooo`@0IVIV1000000N0?ooo`00EP3oool00`000000
IVIV0?ooo`030?ooo`8000001P2U`nh2000000@0YL?^100000060:G3kP030000002U`nh0YL?^0080
YL?^100000060:G3kP8000000P2U`nh300000080YL?^00<000000:G3kP2U`nh0102U`nh00`000000
YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0102U`nh5000000@0YL?^00<000000:G3kP2U
`nh0102U`nh3000000D0YL?^00<000000:G3kP2U`nh0102U`nh3000000H0YL?^00<000000:G3kP2U
`nh00P2U`nh5000000H0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00@0
YL?^00<000000:G3kP2U`nh0100000000`3oool0IVIV0?ooo`040?ooo`<0IVIV1000000R0?ooo`00
E`3oool00`000000IVIV0?ooo`030?ooo`030000002U`nh0YL?^00D0YL?^1@0000030:G3kP030000
002U`nh0YL?^00@0YL?^1@0000030:G3kP030000002U`nh0YL?^00D0YL?^0`0000060:G3kP030000
002U`nh0YL?^0080YL?^100000060:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^
0:G3kP050:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP040:G3kP030000
002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP040:G3kPD00000102U`nh00`000000YL?^
0:G3kP040:G3kP<000001@2U`nh00`000000YL?^0:G3kP040:G3kP<000001@3oool00`1VIVH0oooo
06IVIP0306IVIP<000009P3oool005P0oooo00<0000006IVIP3oool00`3oool200000080YL?^0`00
00020:G3kP030000002U`nh0YL?^00@0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U
`nh0YL?^00@0YL?^0P0000020:G3kP<000000P2U`nh00`000000YL?^0:G3kP040:G3kPD000000`2U
`nh00`000000YL?^0:G3kP040:G3kP<000001P2U`nh00`000000YL?^0:G3kP040:G3kP<000001P2U
`nh00`000000YL?^0:G3kP020:G3kP@000001P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<0
00000:G3kP2U`nh01@2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0102U
`nh00`000000YL?^0:G3kP03000000H0oooo101VIVH4000002T0oooo001I0?ooo`030000001VIVH0
oooo00@0oooo0P0000060:G3kP030000002U`nh0YL?^00<0YL?^0`0000060:G3kP800000102U`nh4
000000H0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00@0YL?^00<00000
0:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00D0YL?^00<000000:G3kP2U`nh00`000002
0:G3kP030000002U`nh0YL?^00@0YL?^1@0000030:G3kP030000002U`nh0YL?^00@0YL?^0`000006
0:G3kP030000002U`nh0YL?^0080YL?^1@0000060:G3kP030000002U`nh0YL?^0080YL?^10000005
0?ooo`@0IVIV1000000]0?ooo`00FP3oool20000000306IVIP3oool0oooo0080oooo00<000000:G3
kP2U`nh01@2U`nh00`000000YL?^0:G3kP0200000080YL?^00<000000:G3kP2U`nh01@2U`nh50000
00<0YL?^00<000000:G3kP2U`nh0102U`nh3000000H0YL?^00<000000:G3kP2U`nh00P2U`nh40000
00H0YL?^0P0000040:G3kP@000001P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3
kP2U`nh0102U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0102U`nh50000
00@0YL?^00<000000:G3kP2U`nh0102U`nh5000000D0oooo101VIVH400000340oooo001L0?ooo`03
0000001VIVH0oooo00<0oooo0P0000040:G3kP@000001@2U`nh200000080YL?^0`0000020:G3kP03
0000002U`nh0YL?^00@0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00@0
YL?^1@0000030:G3kP030000002U`nh0YL?^00D0YL?^1@0000030:G3kP030000002U`nh0YL?^00@0
YL?^0`0000060:G3kP030000002U`nh0YL?^0080YL?^100000060:G3kP030000002U`nh0YL?^00<0
00000P2U`nh00`000000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00@000001P3oool406IVIP@0
0000=@3oool005d0oooo00<0000006IVIP3oool0103oool4000000<0YL?^00<000000:G3kP2U`nh0
102U`nh3000000H0YL?^00<000000:G3kP2U`nh00P2U`nh4000000H0YL?^0P0000020:G3kP800000
0P2U`nh00`000000YL?^0:G3kP040:G3kP8000000P2U`nh300000080YL?^00<000000:G3kP2U`nh0
102U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0102U`nh5000000<0YL?^
00<000000:G3kP2U`nh0102U`nh3000000H0YL?^00<000000:G3kP2U`nh00P2U`nh4000000L0oooo
0`1VIVH4000003T0oooo001N0?ooo`030000001VIVH0oooo00@0oooo00<000000:G3kP2U`nh0102U
`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0102U`nh5000000<0YL?^00<0
00000:G3kP2U`nh01@2U`nh3000000D0YL?^0P0000040:G3kP@000001P2U`nh00`000000YL?^0:G3
kP020:G3kP@000001P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0102U
`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0102U`nh5000000L0oooo101V
IVH3000003d0oooo001O0?ooo`8000001@3oool2000000<0YL?^100000060:G3kP8000000P2U`nh2
00000080YL?^00<000000:G3kP2U`nh0102U`nh200000080YL?^0`0000020:G3kP030000002U`nh0
YL?^00@0YL?^1@0000030:G3kP030000002U`nh0YL?^00@0YL?^1@0000030:G3kP030000002U`nh0
YL?^00@0YL?^0`0000060:G3kP030000002U`nh0YL?^0080YL?^100000060:G3kP030000002U`nh0
YL?^00<00000203oool406IVIP@00000@03oool00640oooo00<0000006IVIP3oool00`3oool0101V
IVH000000000000000030:G3kP030000002U`nh0YL?^00D0YL?^0`0000050:G3kP800000102U`nh4
000000H0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00@0YL?^00<00000
0:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00@0YL?^00<000000:G3kP2U`nh00`000002
0:G3kP030000002U`nh0YL?^00@0YL?^1@0000030:G3kP030000002U`nh0YL?^00@0YL?^0`000007
0?ooo`@0IVIV100000140?ooo`00HP3oool00`000000IVIV0?ooo`020?ooo`0306IVIP3oool00000
00D0YL?^0P0000020:G3kP<000000P2U`nh00`000000YL?^0:G3kP040:G3kPD000000`2U`nh00`00
0000YL?^0:G3kP040:G3kP<000001P2U`nh00`000000YL?^0:G3kP020:G3kP@000001P2U`nh00`00
0000YL?^0:G3kP020:G3kP@000001P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3
kP2U`nh0102U`nh00`000000YL?^0:G3kP030000000306IVIP3oool0oooo00<0oooo101VIVH40000
04P0oooo001S0?ooo`050000001VIVH0oooo0?ooo`1VIVH00P3oool00`000000YL?^0:G3kP020:G3
kP@000001P2U`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0102U`nh00`00
0000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0102U`nh5000000<0YL?^00<000000:G3
kP2U`nh0102U`nh5000000<0YL?^00<000000:G3kP2U`nh0102U`nh3000000H0YL?^00<000000:G3
kP2U`nh00P2U`nh4000000<0oooo00<0IVIV0?ooo`3oool00`1VIVH4000004`0oooo001T0?ooo`04
0000001VIVH0oooo06IVIP<0oooo100000030:G3kP030000002U`nh0YL?^00@0YL?^0`0000060:G3
kP030000002U`nh0YL?^0080YL?^100000060:G3kP030000002U`nh0YL?^00<000000P2U`nh00`00
0000YL?^0:G3kP040:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP040:G3
kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP040:G3kPD000001P3oool406IV
IP<00000D03oool006D0oooo0P0000000`1VIVH0oooo0?ooo`020?ooo`030000002U`nh0YL?^00@0
YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U`nh0YL?^00@0YL?^1@0000030:G3kP03
0000002U`nh0YL?^00@0YL?^0`0000060:G3kP030000002U`nh0YL?^0080YL?^100000060:G3kP03
0000002U`nh0YL?^0080YL?^100000060:G3kP030000002U`nh0YL?^00<000001`3oool406IVIP@0
0000D`3oool006L0oooo00<0000006IVIP3oool00`3oool2000000<0YL?^100000060:G3kP800000
0P2U`nh200000080YL?^00<000000:G3kP2U`nh0102U`nh00`000000YL?^0:G3kP0300000080YL?^
00<000000:G3kP2U`nh0102U`nh5000000<0YL?^00<000000:G3kP2U`nh0102U`nh5000000<0YL?^
00<000000:G3kP2U`nh0102U`nh3000000H0oooo101VIVH4000005L0oooo001X0?ooo`030000001V
IVH0oooo00@0oooo0`0000030:G3kP8000001@2U`nh4000000D0YL?^0P0000030:G3kP@000001P2U
`nh00`000000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0102U`nh00`000000YL?^0:G3
kP0300000080YL?^00<000000:G3kP2U`nh0102U`nh00`000000YL?^0:G3kP03000000D0oooo101V
IVH4000005/0oooo001Y0?ooo`030000001VIVH0oooo00@0oooo00<000000:G3kP2U`nh0102U`nh5
000000<0YL?^00<000000:G3kP2U`nh0102U`nh4000000<0YL?^00<000000:G3kP2U`nh0102U`nh3
000000H0YL?^00<000000:G3kP2U`nh00P2U`nh4000000H0YL?^00<000000:G3kP2U`nh00P2U`nh4
000000D0oooo0`1VIVH4000005l0oooo001Z0?ooo`80000000<0IVIV0?ooo`3oool00P3oool00`00
0000YL?^0:G3kP0300000080YL?^00<000000:G3kP2U`nh0102U`nh00`000000YL?^0:G3kP030000
0080YL?^00<000000:G3kP2U`nh00`2U`nh200000080YL?^0P0000020:G3kP030000002U`nh0YL?^
00@0YL?^1@0000030:G3kP030000002U`nh0YL?^00@0YL?^1@0000050?ooo`@0IVIV0`00001S0?oo
o`00K03oool00`000000IVIV0?ooo`030?ooo`8000001P2U`nh00`000000YL?^0:G3kP020:G3kP@0
00001P2U`nh00`000000YL?^0:G3kP020:G3kP@000001@2U`nh200000080YL?^0P0000020:G3kP03
0000002U`nh0YL?^00@0YL?^00<000000:G3kP2U`nh00`0000060?ooo`@0IVIV1000001V0?ooo`00
K@3oool00`000000IVIV0?ooo`030?ooo`030000002U`nh0YL?^00@0YL?^1@0000030:G3kP030000
002U`nh0YL?^00@0YL?^1@0000030:G3kP800000102U`nh4000000D0YL?^0P0000030:G3kP@00000
1@3oool406IVIP@00000JP3oool006h0oooo00<0000006IVIP3oool00`3oool200000080YL?^0P00
00020:G3kP030000002U`nh0YL?^00@0YL?^00<000000:G3kP2U`nh00`0000020:G3kP030000002U
`nh0YL?^00@0YL?^1@0000030:G3kP030000002U`nh0YL?^00@0YL?^100000000`1VIVH0oooo0?oo
o`020?ooo`@0IVIV1000001^0?ooo`00K`3oool00`000000IVIV06IVIP040?ooo`8000001@2U`nh2
000000<0YL?^100000060:G3kP030000002U`nh0YL?^00<000000P2U`nh00`000000YL?^0:G3kP04
0:G3kP030000002U`nh0YL?^00<00000103oool00`1VIVH0oooo06IVIP0206IVIP@00000LP3oool0
0700oooo0P0000000`1VIVH0oooo0?ooo`020?ooo`030000002U`nh0YL?^00@0YL?^100000030:G3
kP800000102U`nh4000000H0YL?^00<000000:G3kP2U`nh00P2U`nh4000000D0oooo101VIVH30000
07H0oooo001b0?ooo`030000001VIVH0oooo00<0oooo00<000000:G3kP2U`nh00`0000020:G3kP03
0000002U`nh0YL?^00@0YL?^100000030:G3kP030000002U`nh0YL?^00@0YL?^1@0000050?ooo`@0
IVIV1000001i0?ooo`00L`3oool00`000000IVIV0?ooo`030?ooo`8000001P2U`nh00`000000YL?^
0:G3kP0300000080YL?^00<000000:G3kP2U`nh00`2U`nh00`000000YL?^0:G3kP03000000H0oooo
101VIVH4000007d0oooo001d0?ooo`030000001VIVH0oooo00<0oooo0P0000040:G3kP@000001P2U
`nh010000000YL?^0:G3kP2U`nh4000000D0oooo101VIVH400000840oooo001e0?ooo`80000000<0
IVIV0?ooo`3oool00P3oool4000000<0YL?^00<000000:G3kP2U`nh0102U`nh4000000D0oooo101V
IVH4000008D0oooo001g0?ooo`030000001VIVH0oooo0080oooo00<0IVIV0000002U`nh01@2U`nh0
0`000000YL?^0:G3kP03000000H0oooo0`1VIVH4000008T0oooo001h0?ooo`060000001VIVH0oooo
0?ooo`1VIVH0oooo0P0000030:G3kP@000001@3oool406IVIP<00000S@3oool007T0oooo00L00000
06IVIP3oool0IVIV0?ooo`000000oooo00<000001@3oool406IVIP@00000T03oool007X0oooo00D0
000006IVIP1VIVH0oooo000000030?ooo`0306IVIP3oool0IVIV00<0IVIV1000002D0?ooo`00N`3o
ool20000000306IVIP000000oooo00@0IVIV1000002H0?ooo`00O@3oool20000000306IVIP000000
000000800000W03oool007h0oooo0P00002P0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {228.375, 0}} -> {-0.0759944, 0.0231052, \
0.00358863, 0.00358863}}]
}, Open  ]],

Cell["\<\
DrawWithOptions3D allows us to pick up the overall plot options used by \
ShadowPlot3D. We can insert some of our own graphic elements and overall plot \
options. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Module[{primitives, opts}, \[IndentingNewLine]{primitives, opts} = 
          ShadowPlot3D[
              E\^\(-\((x\^2 + y\^2)\)\), {x, \(-2\), 2}, {y, \(-2\), 2}, 
              ShadowPosition \[Rule] 1, PlotPoints \[Rule] 25] // 
            DrawWithOptions3D; \[IndentingNewLine]Draw3DItems[\
\[IndentingNewLine]{primitives, \[IndentingNewLine]Cadet, 
            ParametricDraw3D[{x, y, 0.5}, {x, \(-2\), 2}, {y, \(-2\), 2}, 
                PlotPoints \[Rule] 25] // 
              UseWireFrame, \[IndentingNewLine]Black, AbsoluteThickness[2], 
            ParametricDraw3D[{0.834  Cos[\[Theta]], 0.834  Sin[\[Theta]], 
                0.5}, {\[Theta], 0, 
                2  \[Pi]}]}, \[IndentingNewLine]Axes \[Rule] True, 
          FaceGrids \[Rule] {{\(-1\), 0, 0}, {0, 1, 0}}, 
          opts]\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[260]:="],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(opts\\)\\\" is similar to existing symbol \\\
\"\\!\\(pts\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\
\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[260]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.46964e-016 1.16608 [
[.09072 .22988 -11.8315 -9 ]
[.09072 .22988 .16848 0 ]
[.21906 .17566 -11.3073 -9 ]
[.21906 .17566 .69269 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.49765 .05807 -5.12945 -9 ]
[.49765 .05807 .87055 0 ]
[.64919 -0.00583 -4.86734 -9 ]
[.64919 -0.00583 1.13266 0 ]
[.00955 .82643 -6.92724 0 ]
[.00955 .82643 5.07276 9 ]
[.12079 .90442 -6.71106 0 ]
[.12079 .90442 5.28894 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31055 1.03745 -3.18209 0 ]
[.31055 1.03745 2.81791 9 ]
[.39213 1.09464 -3.11145 0 ]
[.39213 1.09464 2.88855 9 ]
[.07325 .26228 -6 -2.6177 ]
[.07325 .26228 0 6.3823 ]
[.04788 .42109 -18 -2.75895 ]
[.04788 .42109 0 6.24105 ]
[.01942 .59922 -6 -2.9192 ]
[.01942 .59922 0 6.0808 ]
[-0.01271 .80041 -18 -3.10256 ]
[-0.01271 .80041 0 5.89744 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(-2)] .09072 .22988 .97192 1 Mshowa
.22871 .18658 m
.23354 .19204 L
s
[(-1)] .21906 .17566 .88455 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.50609 .06995 m
.51031 .07589 L
s
[(1)] .49765 .05807 .70982 1 Mshowa
.65689 .00654 m
.66074 .01273 L
s
[(2)] .64919 -0.00583 .62245 1 Mshowa
.125 Mabswid
.12591 .22981 m
.12892 .23297 L
s
.1512 .21917 m
.15419 .22236 L
s
.17676 .20842 m
.17972 .21164 L
s
.2026 .19756 m
.20553 .20081 L
s
.25511 .17548 m
.25797 .17879 L
s
.28179 .16426 m
.28462 .1676 L
s
.30875 .15292 m
.31155 .15628 L
s
.33602 .14146 m
.33878 .14485 L
s
.39145 .11815 m
.39414 .1216 L
s
.41963 .1063 m
.42229 .10978 L
s
.44813 .09432 m
.45074 .09783 L
s
.47695 .0822 m
.47952 .08574 L
s
.53556 .05756 m
.53805 .06115 L
s
.56537 .04502 m
.56782 .04865 L
s
.59553 .03235 m
.59793 .036 L
s
.62603 .01952 m
.62839 .0232 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(-2)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(-1)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(1)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(2)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.03493 .82832 m
.03556 .82399 L
s
.05756 .84424 m
.05816 .83991 L
s
.07969 .85982 m
.08026 .85548 L
s
.10133 .87505 m
.10187 .87071 L
s
.14322 .90453 m
.14371 .90018 L
s
.1635 .9188 m
.16396 .91445 L
s
.18335 .93277 m
.18378 .92842 L
s
.20279 .94645 m
.2032 .9421 L
s
.24048 .97297 m
.24084 .96861 L
s
.25875 .98583 m
.25909 .98147 L
s
.27666 .99844 m
.27697 .99407 L
s
.29422 1.01079 m
.29451 1.00643 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.3611 1.05786 m
.3613 1.05349 L
s
.37703 1.06907 m
.37721 1.0647 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.0867 .25665 m
.09342 .25384 L
s
[(0)] .07325 .26228 1 -0.41829 Mshowa
.06147 .41583 m
.06827 .4132 L
s
[(0.5)] .04788 .42109 1 -0.3869 Mshowa
.03318 .59438 m
.04005 .59197 L
s
[(1)] .01942 .59922 1 -0.35129 Mshowa
.00121 .79609 m
.00817 .79392 L
s
[(1.5)] -0.01271 .80041 1 -0.31054 Mshowa
.125 Mabswid
.08187 .28709 m
.08592 .28542 L
s
.07694 .3182 m
.08099 .31656 L
s
.0719 .35002 m
.07596 .34839 L
s
.06675 .38255 m
.07082 .38095 L
s
.05608 .44988 m
.06016 .44833 L
s
.05055 .48473 m
.05465 .48321 L
s
.0449 .52042 m
.049 .51891 L
s
.03911 .55696 m
.04322 .55548 L
s
.0271 .63274 m
.03123 .63132 L
s
.02087 .67204 m
.02502 .67065 L
s
.01448 .71235 m
.01864 .71099 L
s
.00793 .75368 m
.0121 .75235 L
s
.4 g
.25 Mabswid
.0867 .25665 m
.41763 .59194 L
s
.06147 .41583 m
.41249 .73889 L
s
.03318 .59438 m
.40684 .90042 L
s
.00121 .79609 m
.40061 1.07881 L
s
.09784 .25512 m
.01178 .81203 L
s
.18697 .346 m
.1225 .88995 L
s
.26832 .42896 m
.22183 .95985 L
s
.34287 .50498 m
.31143 1.0229 L
s
.41143 .5749 m
.39267 1.08007 L
s
0 g
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.4 g
.42903 .57797 m
.41317 1.08256 L
s
.54217 .54095 m
.54482 1.05241 L
s
.66043 .50224 m
.68346 1.02065 L
s
.78419 .46174 m
.82967 .98716 L
s
.91382 .41932 m
.98408 .95179 L
s
.41763 .59194 m
.9286 .42575 L
s
.41249 .73889 m
.94962 .57954 L
s
.40684 .90042 m
.97296 .75028 L
s
.40061 1.07881 m
.99902 .94095 L
s
0 g
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
1 .002 0 r
.41156 .57099 m .42216 .58173 L .44003 .57597 L p F P
0 0 0 r
s
1 .005 0 r
.42952 .56522 m .44003 .57597 L .45803 .57021 L p F P
0 0 0 r
s
1 .002 0 r
.44003 .57597 m .42952 .56522 L .41156 .57099 L p F P
0 0 0 r
s
1 .005 0 r
.40083 .56016 m .41156 .57099 L .42952 .56522 L p F P
0 0 0 r
s
1 .011 0 r
.4476 .5595 m .45803 .57021 L .47616 .56449 L p F P
0 0 0 r
s
1 .005 0 r
.45803 .57021 m .4476 .5595 L .42952 .56522 L p F P
0 0 0 r
s
1 .011 0 r
.41886 .55442 m .42952 .56522 L .4476 .5595 L p F P
0 0 0 r
s
1 .005 0 r
.42952 .56522 m .41886 .55442 L .40083 .56016 L p F P
0 0 0 r
s
1 .018 0 r
.46581 .55388 m .47616 .56449 L .49442 .55882 L p F P
0 0 0 r
s
1 .011 0 r
.47616 .56449 m .46581 .55388 L .4476 .5595 L p F P
0 0 0 r
s
1 .011 0 r
.38995 .54926 m .40083 .56016 L .41886 .55442 L p F P
0 0 0 r
s
1 .02 0 r
.43702 .54881 m .4476 .5595 L .46581 .55388 L p F P
0 0 0 r
s
1 .011 0 r
.4476 .5595 m .43702 .54881 L .41886 .55442 L p F P
0 0 0 r
s
1 .029 0 r
.48415 .54839 m .49442 .55882 L .51282 .55323 L p F P
0 0 0 r
s
1 .018 0 r
.49442 .55882 m .48415 .54839 L .46581 .55388 L p F P
0 0 0 r
s
1 .02 0 r
.40806 .54362 m .41886 .55442 L .43702 .54881 L p F P
0 0 0 r
s
1 .011 0 r
.41886 .55442 m .40806 .54362 L .38995 .54926 L p F P
0 0 0 r
s
1 .034 0 r
.4553 .5434 m .46581 .55388 L .48415 .54839 L p F P
0 0 0 r
s
1 .02 0 r
.46581 .55388 m .4553 .5434 L .43702 .54881 L p F P
0 0 0 r
s
1 .044 0 r
.50263 .54307 m .51282 .55323 L .53135 .5477 L p F P
0 0 0 r
s
1 .029 0 r
.51282 .55323 m .50263 .54307 L .48415 .54839 L p F P
0 0 0 r
s
1 .018 0 r
.37892 .5383 m .38995 .54926 L .40806 .54362 L p F P
0 0 0 r
s
1 .036 0 r
.42629 .53822 m .43702 .54881 L .4553 .5434 L p F P
0 0 0 r
s
1 .02 0 r
.43702 .54881 m .42629 .53822 L .40806 .54362 L p F P
0 0 0 r
s
1 .054 0 r
.47373 .53826 m .48415 .54839 L .50263 .54307 L p F P
0 0 0 r
s
1 .034 0 r
.48415 .54839 m .47373 .53826 L .4553 .5434 L p F P
0 0 0 r
s
1 .061 0 r
.52125 .53792 m .53135 .5477 L .55002 .54224 L p F P
0 0 0 r
s
1 .044 0 r
.53135 .5477 m .52125 .53792 L .50263 .54307 L p F P
0 0 0 r
s
1 .034 0 r
.3971 .53284 m .40806 .54362 L .42629 .53822 L p F P
0 0 0 r
s
1 .018 0 r
.40806 .54362 m .3971 .53284 L .37892 .5383 L p F P
0 0 0 r
s
1 .06 0 r
.44465 .53318 m .4553 .5434 L .47373 .53826 L p F P
0 0 0 r
s
1 .036 0 r
.4553 .5434 m .44465 .53318 L .42629 .53822 L p F P
0 0 0 r
s
1 .08 0 r
.49229 .53344 m .50263 .54307 L .52125 .53792 L p F P
0 0 0 r
s
1 .054 0 r
.50263 .54307 m .49229 .53344 L .47373 .53826 L p F P
0 0 0 r
s
1 .082 0 r
.54002 .53293 m .55002 .54224 L .56883 .53681 L p F P
0 0 0 r
s
1 .061 0 r
.55002 .54224 m .54002 .53293 L .52125 .53792 L p F P
0 0 0 r
s
1 .029 0 r
.36774 .52731 m .37892 .5383 L .3971 .53284 L p F P
0 0 0 r
s
1 .06 0 r
.41539 .52779 m .42629 .53822 L .44465 .53318 L p F P
0 0 0 r
s
1 .034 0 r
.42629 .53822 m .41539 .52779 L .3971 .53284 L p F P
0 0 0 r
s
1 .093 0 r
.46314 .52862 m .47373 .53826 L .49229 .53344 L p F P
0 0 0 r
s
1 .06 0 r
.47373 .53826 m .46314 .52862 L .44465 .53318 L p F P
0 0 0 r
s
1 .111 0 r
.511 .52897 m .52125 .53792 L .54002 .53293 L p F P
0 0 0 r
s
1 .08 0 r
.52125 .53792 m .511 .52897 L .49229 .53344 L p F P
0 0 0 r
s
1 .103 0 r
.55893 .52801 m .56883 .53681 L .58779 .53134 L p F P
0 0 0 r
s
1 .082 0 r
.56883 .53681 m .55893 .52801 L .54002 .53293 L p F P
0 0 0 r
s
1 .054 0 r
.38598 .52213 m .3971 .53284 L .41539 .52779 L p F P
0 0 0 r
s
1 .029 0 r
.3971 .53284 m .38598 .52213 L .36774 .52731 L p F P
0 0 0 r
s
1 .098 0 r
.43382 .52334 m .44465 .53318 L .46314 .52862 L p F P
0 0 0 r
s
1 .06 0 r
.44465 .53318 m .43382 .52334 L .41539 .52779 L p F P
0 0 0 r
s
1 .137 0 r
.48178 .52464 m .49229 .53344 L .511 .52897 L p F P
0 0 0 r
s
1 .093 0 r
.49229 .53344 m .48178 .52464 L .46314 .52862 L p F P
0 0 0 r
s
1 .148 0 r
.52987 .5248 m .54002 .53293 L .55893 .52801 L p F P
0 0 0 r
s
1 .111 0 r
.54002 .53293 m .52987 .5248 L .511 .52897 L p F P
0 0 0 r
s
1 .044 0 r
.3564 .51629 m .36774 .52731 L .38598 .52213 L p F P
0 0 0 r
s
1 .123 0 r
.57801 .52307 m .58779 .53134 L .60689 .52575 L p F P
0 0 0 r
s
1 .103 0 r
.58779 .53134 m .57801 .52307 L .55893 .52801 L p F P
0 0 0 r
s
1 .093 0 r
.40434 .51758 m .41539 .52779 L .43382 .52334 L p F P
0 0 0 r
s
1 .054 0 r
.41539 .52779 m .40434 .51758 L .38598 .52213 L p F P
0 0 0 r
s
1 .152 0 r
.45238 .51968 m .46314 .52862 L .48178 .52464 L p F P
0 0 0 r
s
1 .098 0 r
.46314 .52862 m .45238 .51968 L .43382 .52334 L p F P
0 0 0 r
s
1 .191 0 r
.50058 .52127 m .511 .52897 L .52987 .5248 L p F P
0 0 0 r
s
1 .137 0 r
.511 .52897 m .50058 .52127 L .48178 .52464 L p F P
0 0 0 r
s
1 .186 0 r
.5489 .52081 m .55893 .52801 L .57801 .52307 L p F P
0 0 0 r
s
1 .148 0 r
.55893 .52801 m .5489 .52081 L .52987 .5248 L p F P
0 0 0 r
s
1 .14 0 r
.59724 .51795 m .60689 .52575 L .62614 .51996 L p F P
0 0 0 r
s
1 .123 0 r
.60689 .52575 m .59724 .51795 L .57801 .52307 L p F P
0 0 0 r
s
1 .08 0 r
.37469 .51148 m .38598 .52213 L .40434 .51758 L p F P
0 0 0 r
s
1 .044 0 r
.38598 .52213 m .37469 .51148 L .3564 .51629 L p F P
0 0 0 r
s
1 .152 0 r
.42281 .51397 m .43382 .52334 L .45238 .51968 L p F P
0 0 0 r
s
1 .093 0 r
.43382 .52334 m .42281 .51397 L .40434 .51758 L p F P
0 0 0 r
s
1 .223 0 r
.47109 .51697 m .48178 .52464 L .50058 .52127 L p F P
0 0 0 r
s
1 .152 0 r
.48178 .52464 m .47109 .51697 L .45238 .51968 L p F P
0 0 0 r
s
1 .061 0 r
.34489 .50522 m .3564 .51629 L .37469 .51148 L p F P
0 0 0 r
s
1 .253 0 r
.51955 .51844 m .52987 .5248 L .5489 .52081 L p F P
0 0 0 r
s
1 .191 0 r
.52987 .5248 m .51955 .51844 L .50058 .52127 L p F P
0 0 0 r
s
1 .152 0 r
.61661 .5125 m .62614 .51996 L .64552 .5139 L p F P
0 0 0 r
s
1 .14 0 r
.62614 .51996 m .61661 .5125 L .59724 .51795 L p F P
0 0 0 r
s
1 .222 0 r
.5681 .5168 m .57801 .52307 L .59724 .51795 L p F P
0 0 0 r
s
1 .186 0 r
.57801 .52307 m .5681 .5168 L .5489 .52081 L p F P
0 0 0 r
s
1 .137 0 r
.3931 .50762 m .40434 .51758 L .42281 .51397 L p F P
0 0 0 r
s
1 .08 0 r
.40434 .51758 m .3931 .50762 L .37469 .51148 L p F P
0 0 0 r
s
1 .234 0 r
.44143 .51158 m .45238 .51968 L .47109 .51697 L p F P
0 0 0 r
s
1 .152 0 r
.45238 .51968 m .44143 .51158 L .42281 .51397 L p F P
0 0 0 r
s
1 .111 0 r
.36324 .50088 m .37469 .51148 L .3931 .50762 L p F P
0 0 0 r
s
1 .061 0 r
.37469 .51148 m .36324 .50088 L .34489 .50522 L p F P
0 0 0 r
s
1 .31 0 r
.48997 .51525 m .50058 .52127 L .51955 .51844 L p F P
0 0 0 r
s
1 .223 0 r
.50058 .52127 m .48997 .51525 L .47109 .51697 L p F P
0 0 0 r
s
1 .156 0 r
.63612 .50659 m .64552 .5139 L .66504 .50754 L p F P
0 0 0 r
s
1 .152 0 r
.64552 .5139 m .63612 .50659 L .61661 .5125 L p F P
0 0 0 r
s
1 .253 0 r
.58747 .51251 m .59724 .51795 L .61661 .5125 L p F P
0 0 0 r
s
1 .222 0 r
.59724 .51795 m .58747 .51251 L .5681 .5168 L p F P
0 0 0 r
s
1 .318 0 r
.53871 .51594 m .5489 .52081 L .5681 .5168 L p F P
0 0 0 r
s
1 .253 0 r
.5489 .52081 m .53871 .51594 L .51955 .51844 L p F P
0 0 0 r
s
1 .223 0 r
.41162 .5051 m .42281 .51397 L .44143 .51158 L p F P
0 0 0 r
s
1 .137 0 r
.42281 .51397 m .41162 .5051 L .3931 .50762 L p F P
0 0 0 r
s
.372 .62 .628 r
.4172 .72906 m
.40561 .71829 L
s
.4367 .72324 m
.4172 .72906 L
s
1 .082 0 r
.33322 .49406 m .34489 .50522 L .36324 .50088 L p F P
0 0 0 r
s
1 .343 0 r
.46019 .51065 m .47109 .51697 L .48997 .51525 L p F P
0 0 0 r
s
1 .234 0 r
.47109 .51697 m .46019 .51065 L .44143 .51158 L p F P
0 0 0 r
s
1 .152 0 r
.65577 .50015 m .66504 .50754 L .68468 .50087 L p F P
0 0 0 r
s
1 .156 0 r
.66504 .50754 m .65577 .50015 L .63612 .50659 L p F P
0 0 0 r
s
1 .191 0 r
.38168 .49784 m .3931 .50762 L .41162 .5051 L p F P
0 0 0 r
s
1 .111 0 r
.3931 .50762 m .38168 .49784 L .36324 .50088 L p F P
0 0 0 r
s
1 .273 0 r
.607 .50767 m .61661 .5125 L .63612 .50659 L p F P
0 0 0 r
s
1 .253 0 r
.61661 .5125 m .607 .50767 L .58747 .51251 L p F P
0 0 0 r
s
1 .41 0 r
.50905 .51443 m .51955 .51844 L .53871 .51594 L p F P
0 0 0 r
s
1 .31 0 r
.51955 .51844 m .50905 .51443 L .48997 .51525 L p F P
0 0 0 r
s
1 .38 0 r
.55806 .51344 m .5681 .5168 L .58747 .51251 L p F P
0 0 0 r
s
1 .318 0 r
.5681 .5168 m .55806 .51344 L .53871 .51594 L p F P
0 0 0 r
s
.372 .62 .628 r
.4367 .72324 m
.4252 .71239 L
s
.45635 .71738 m
.4367 .72324 L
s
1 .343 0 r
.43027 .50438 m .44143 .51158 L .46019 .51065 L p F P
0 0 0 r
s
1 .223 0 r
.44143 .51158 m .43027 .50438 L .41162 .5051 L p F P
0 0 0 r
s
1 .148 0 r
.35161 .49025 m .36324 .50088 L .38168 .49784 L p F P
0 0 0 r
s
1 .082 0 r
.36324 .50088 m .35161 .49025 L .33322 .49406 L p F P
0 0 0 r
s
1 .14 0 r
.67553 .49317 m .68468 .50087 L .70446 .49393 L p F P
0 0 0 r
s
1 .152 0 r
.68468 .50087 m .67553 .49317 L .65577 .50015 L p F P
0 0 0 r
s
1 .28 0 r
.62667 .50206 m .63612 .50659 L .65577 .50015 L p F P
0 0 0 r
s
1 .273 0 r
.63612 .50659 m .62667 .50206 L .607 .50767 L p F P
0 0 0 r
s
1 .477 0 r
.47915 .51126 m .48997 .51525 L .50905 .51443 L p F P
0 0 0 r
s
1 .343 0 r
.48997 .51525 m .47915 .51126 L .46019 .51065 L p F P
0 0 0 r
s
.372 .62 .628 r
.40561 .71829 m
.4252 .71239 L
s
.40561 .71829 m
.39385 .70736 L
s
1 .31 0 r
.40022 .49667 m .41162 .5051 L .43027 .50438 L p F P
0 0 0 r
s
1 .191 0 r
.41162 .5051 m .40022 .49667 L .38168 .49784 L p F P
0 0 0 r
s
1 .431 0 r
.5776 .51051 m .58747 .51251 L .607 .50767 L p F P
0 0 0 r
s
1 .431 0 r
.59731 .50669 m .5776 .51051 L p .58337 .50995 L F P
0 0 0 r
s
1 .431 0 r
.607 .50767 m .59731 .50669 L p .58337 .50995 L F P
0 0 0 r
s
1 .465 0 r
.61716 .5016 m .59731 .50669 L p .60359 .5057 L F P
0 0 0 r
s
1 .465 0 r
.62667 .50206 m .61716 .5016 L p .60359 .5057 L F P
0 0 0 r
s
1 .477 0 r
.63713 .495 m .61716 .5016 L p .62343 .5003 L F P
0 0 0 r
s
1 .477 0 r
.64646 .49554 m .63713 .495 L p .62343 .5003 L F P
0 0 0 r
s
1 .465 0 r
.65719 .48691 m .63713 .495 L p .64287 .49365 L F P
0 0 0 r
s
1 .465 0 r
.66636 .48811 m .65719 .48691 L p .64287 .49365 L F P
0 0 0 r
s
1 .698 0 r
.65719 .48691 m .67732 .47752 L p .67165 .4801 L F P
0 0 0 r
s
1 .753 0 r
.63713 .495 m .65719 .48691 L p .65098 .48965 L F P
0 0 0 r
s
1 .477 0 r
.61716 .5016 m .62667 .50206 L .64646 .49554 L p F P
0 0 0 r
s
1 .465 0 r
.63713 .495 m .64646 .49554 L .66636 .48811 L p F P
0 0 0 r
s
1 .753 0 r
.62778 .4999 m .63713 .495 L p .65098 .48965 L F P
0 0 0 r
s
1 .698 0 r
.64803 .49085 m .65719 .48691 L p .67165 .4801 L F P
0 0 0 r
s
1 .773 0 r
.61716 .5016 m .63713 .495 L p .63089 .49744 L F P
0 0 0 r
s
1 .465 0 r
.59731 .50669 m .607 .50767 L .62667 .50206 L p F P
0 0 0 r
s
1 .773 0 r
.60759 .50655 m .61716 .5016 L p .63089 .49744 L F P
0 0 0 r
s
1 .753 0 r
.59731 .50669 m .61716 .5016 L p .61141 .50339 L F P
0 0 0 r
s
1 .753 0 r
.58751 .51083 m .59731 .50669 L p .61141 .50339 L F P
0 0 0 r
s
1 .698 0 r
.5776 .51051 m .59731 .50669 L p .59265 .50769 L F P
0 0 0 r
s
1 .38 0 r
.58747 .51251 m .5776 .51051 L p .56272 .51329 L F P
0 0 0 r
s
1 .698 0 r
.56758 .51309 m .5776 .51051 L p .59265 .50769 L F P
0 0 0 r
s
1 .38 0 r
.5776 .51051 m .55806 .51344 L p .56272 .51329 L F P
0 0 0 r
s
1 .103 0 r
.32138 .48275 m .33322 .49406 L .35161 .49025 L p F P
0 0 0 r
s
.372 .62 .628 r
.45635 .71738 m
.44494 .70644 L
s
.47615 .71147 m
.45635 .71738 L
s
1 .515 0 r
.53871 .51594 m .55806 .51344 L p .53544 .514 L F P
0 0 0 r
s
1 .515 0 r
.52834 .51418 m .52988 .51444 L p .53544 .514 L F P
0 0 0 r
s
1 .515 0 r
.52988 .51444 m .53871 .51594 L p .53544 .514 L F P
0 0 0 r
s
1 .515 0 r
.55806 .51344 m .54785 .51397 L .52834 .51418 L p F P
0 0 0 r
s
1 .615 0 r
.54785 .51397 m .55806 .51344 L .5776 .51051 L p F P
0 0 0 r
s
1 .615 0 r
.56758 .51309 m .54785 .51397 L p .57315 .51103 L F P
0 0 0 r
s
1 .615 0 r
.5776 .51051 m .57667 .51075 L p .57315 .51103 L F P
0 0 0 r
s
1 .615 0 r
.57667 .51075 m .56758 .51309 L p .57315 .51103 L F P
0 0 0 r
s
1 .41 0 r
.53871 .51594 m .52834 .51418 L .50905 .51443 L p F P
0 0 0 r
s
1 .123 0 r
.69542 .48572 m .70446 .49393 L .72436 .48678 L p F P
0 0 0 r
s
1 .14 0 r
.70446 .49393 m .69542 .48572 L .67553 .49317 L p F P
0 0 0 r
s
1 .253 0 r
.37008 .48814 m .38168 .49784 L .40022 .49667 L p F P
0 0 0 r
s
1 .148 0 r
.38168 .49784 m .37008 .48814 L .35161 .49025 L p F P
0 0 0 r
s
1 .502 0 r
.44907 .50578 m .46019 .51065 L .47915 .51126 L p F P
0 0 0 r
s
1 .343 0 r
.46019 .51065 m .44907 .50578 L .43027 .50438 L p F P
0 0 0 r
s
1 .273 0 r
.64646 .49554 m .65577 .50015 L .67553 .49317 L p F P
0 0 0 r
s
1 .28 0 r
.65577 .50015 m .64646 .49554 L .62667 .50206 L p F P
0 0 0 r
s
.372 .62 .628 r
.4252 .71239 m
.44494 .70644 L
s
.4252 .71239 m
.41353 .70137 L
s
.47615 .71147 m
.46484 .70045 L
s
.4961 .70552 m
.47615 .71147 L
s
1 .631 0 r
.49832 .51327 m .50905 .51443 L .52834 .51418 L p F P
0 0 0 r
s
1 .477 0 r
.50905 .51443 m .49832 .51327 L .47915 .51126 L p F P
0 0 0 r
s
1 .186 0 r
.3398 .47947 m .35161 .49025 L .37008 .48814 L p F P
0 0 0 r
s
1 .103 0 r
.35161 .49025 m .3398 .47947 L .32138 .48275 L p F P
0 0 0 r
s
1 .103 0 r
.71542 .47794 m .72436 .48678 L .7444 .47951 L p F P
0 0 0 r
s
1 .123 0 r
.72436 .48678 m .71542 .47794 L .69542 .48572 L p F P
0 0 0 r
s
1 .477 0 r
.41888 .49796 m .43027 .50438 L .44907 .50578 L p F P
0 0 0 r
s
1 .31 0 r
.43027 .50438 m .41888 .49796 L .40022 .49667 L p F P
0 0 0 r
s
1 .253 0 r
.66636 .48811 m .67553 .49317 L .69542 .48572 L p F P
0 0 0 r
s
1 .273 0 r
.67553 .49317 m .66636 .48811 L .64646 .49554 L p F P
0 0 0 r
s
.372 .62 .628 r
.39385 .70736 m
.41353 .70137 L
s
.39385 .70736 m
.38192 .69627 L
s
1 .123 0 r
.30937 .4712 m .32138 .48275 L .3398 .47947 L p F P
0 0 0 r
s
.372 .62 .628 r
.44494 .70644 m
.46484 .70045 L
s
.44494 .70644 m
.43337 .69534 L
s
1 .41 0 r
.38863 .48847 m .40022 .49667 L .41888 .49796 L p F P
0 0 0 r
s
1 .253 0 r
.40022 .49667 m .38863 .48847 L .37008 .48814 L p F P
0 0 0 r
s
.372 .62 .628 r
.4961 .70552 m
.48489 .69441 L
s
.5162 .69952 m
.4961 .70552 L
s
1 .082 0 r
.73554 .46997 m .7444 .47951 L .76458 .47219 L p F P
0 0 0 r
s
1 .103 0 r
.7444 .47951 m .73554 .46997 L .71542 .47794 L p F P
0 0 0 r
s
1 .502 0 r
.47915 .51126 m .46807 .50945 L .44907 .50578 L p F P
0 0 0 r
s
1 .698 0 r
.46807 .50945 m .47915 .51126 L .49832 .51327 L p F P
0 0 0 r
s
1 .222 0 r
.68636 .47989 m .69542 .48572 L .71542 .47794 L p F P
0 0 0 r
s
1 .253 0 r
.69542 .48572 m .68636 .47989 L .66636 .48811 L p F P
0 0 0 r
s
1 .318 0 r
.35829 .4783 m .37008 .48814 L .38863 .48847 L p F P
0 0 0 r
s
1 .186 0 r
.37008 .48814 m .35829 .4783 L .3398 .47947 L p F P
0 0 0 r
s
1 .793 0 r
.51774 .51619 m .52834 .51418 L .54785 .51397 L p F P
0 0 0 r
s
1 .631 0 r
.52834 .51418 m .51774 .51619 L .49832 .51327 L p F P
0 0 0 r
s
.372 .62 .628 r
.41353 .70137 m
.43337 .69534 L
s
.41353 .70137 m
.4017 .6902 L
s
.46484 .70045 m
.48489 .69441 L
s
.46484 .70045 m
.45337 .68927 L
s
1 .698 0 r
.43769 .50221 m .44907 .50578 L .46807 .50945 L p F P
0 0 0 r
s
1 .477 0 r
.44907 .50578 m .43769 .50221 L .41888 .49796 L p F P
0 0 0 r
s
.372 .62 .628 r
.5162 .69952 m
.5051 .68833 L
s
.53647 .69348 m
.5162 .69952 L
s
1 .061 0 r
.7558 .46195 m .76458 .47219 L .78491 .46488 L p F P
0 0 0 r
s
1 .082 0 r
.76458 .47219 m .7558 .46195 L .73554 .46997 L p F P
0 0 0 r
s
1 .222 0 r
.32784 .46839 m .3398 .47947 L .35829 .4783 L p F P
0 0 0 r
s
1 .123 0 r
.3398 .47947 m .32784 .46839 L .30937 .4712 L p F P
0 0 0 r
s
1 .186 0 r
.70646 .47111 m .71542 .47794 L .73554 .46997 L p F P
0 0 0 r
s
1 .222 0 r
.71542 .47794 m .70646 .47111 L .68636 .47989 L p F P
0 0 0 r
s
.372 .62 .628 r
.38192 .69627 m
.4017 .6902 L
s
.38192 .69627 m
.36981 .68503 L
s
1 .631 0 r
.40727 .49202 m .41888 .49796 L .43769 .50221 L p F P
0 0 0 r
s
1 .41 0 r
.41888 .49796 m .40727 .49202 L .38863 .48847 L p F P
0 0 0 r
s
1 .14 0 r
.29721 .45933 m .30937 .4712 L .32784 .46839 L p F P
0 0 0 r
s
.372 .62 .628 r
.43337 .69534 m
.45337 .68927 L
s
.43337 .69534 m
.42163 .68409 L
s
1 .698 0 r
.59731 .50669 m .58751 .51083 L .56758 .51309 L p F P
0 0 0 r
s
1 .923 0 r
.48732 .51518 m .49832 .51327 L .51774 .51619 L p F P
0 0 0 r
s
1 .698 0 r
.49832 .51327 m .48732 .51518 L .46807 .50945 L p F P
0 0 0 r
s
.372 .62 .628 r
.48489 .69441 m
.5051 .68833 L
s
.48489 .69441 m
.47352 .68314 L
s
1 .431 0 r
.65719 .48691 m .66636 .48811 L .68636 .47989 L p F P
0 0 0 r
s
1 .044 0 r
.77621 .454 m .78491 .46488 L .80539 .45763 L p F P
0 0 0 r
s
1 .061 0 r
.78491 .46488 m .77621 .454 L .7558 .46195 L p F P
0 0 0 r
s
.372 .62 .628 r
.53647 .69348 m
.52546 .68219 L
s
.55689 .68739 m
.53647 .69348 L
s
1 .515 0 r
.37683 .48015 m .38863 .48847 L .40727 .49202 L p F P
0 0 0 r
s
1 .318 0 r
.38863 .48847 m .37683 .48015 L .35829 .4783 L p F P
0 0 0 r
s
1 .148 0 r
.72667 .46203 m .73554 .46997 L .7558 .46195 L p F P
0 0 0 r
s
1 .186 0 r
.73554 .46997 m .72667 .46203 L .70646 .47111 L p F P
0 0 0 r
s
1 .946 0 r
.53742 .51921 m .54785 .51397 L .56758 .51309 L p F P
0 0 0 r
s
1 .793 0 r
.54785 .51397 m .53742 .51921 L .51774 .51619 L p F P
0 0 0 r
s
1 .38 0 r
.34634 .46806 m .35829 .4783 L .37683 .48015 L p F P
0 0 0 r
s
1 .222 0 r
.35829 .4783 m .34634 .46806 L .32784 .46839 L p F P
0 0 0 r
s
.372 .62 .628 r
.4017 .6902 m
.42163 .68409 L
s
.4017 .6902 m
.38969 .67887 L
s
.45337 .68927 m
.47352 .68314 L
s
.45337 .68927 m
.44173 .67792 L
s
1 .38 0 r
.67732 .47752 m .68636 .47989 L .70646 .47111 L p F P
0 0 0 r
s
1 .431 0 r
.68636 .47989 m .67732 .47752 L .65719 .48691 L p F P
0 0 0 r
s
1 .971 0 r
.45671 .50961 m .46807 .50945 L .48732 .51518 L p F P
0 0 0 r
s
1 .698 0 r
.46807 .50945 m .45671 .50961 L .43769 .50221 L p F P
0 0 0 r
s
1 .753 0 r
.61716 .5016 m .60759 .50655 L .58751 .51083 L p F P
0 0 0 r
s
1 .029 0 r
.79677 .44619 m .80539 .45763 L .82603 .45045 L p F P
0 0 0 r
s
1 .044 0 r
.80539 .45763 m .79677 .44619 L .77621 .454 L p F P
0 0 0 r
s
.372 .62 .628 r
.5051 .68833 m
.52546 .68219 L
s
.5051 .68833 m
.49383 .67697 L
s
1 .253 0 r
.31571 .45685 m .32784 .46839 L .34634 .46806 L p F P
0 0 0 r
s
1 .14 0 r
.32784 .46839 m .31571 .45685 L .29721 .45933 L p F P
0 0 0 r
s
1 .111 0 r
.74699 .45291 m .7558 .46195 L .77621 .454 L p F P
0 0 0 r
s
1 .148 0 r
.7558 .46195 m .74699 .45291 L .72667 .46203 L p F P
0 0 0 r
s
.372 .62 .628 r
.55689 .68739 m
.54599 .67601 L
s
.57747 .68125 m
.55689 .68739 L
s
.36981 .68503 m
.38969 .67887 L
s
.36981 .68503 m
.35753 .67362 L
s
1 .152 0 r
.28489 .44706 m .29721 .45933 L .31571 .45685 L p F P
0 0 0 r
s
1 .923 0 r
.42606 .49945 m .43769 .50221 L .45671 .50961 L p F P
0 0 0 r
s
1 .631 0 r
.43769 .50221 m .42606 .49945 L .40727 .49202 L p F P
0 0 0 r
s
1 .318 0 r
.69752 .46721 m .70646 .47111 L .72667 .46203 L p F P
0 0 0 r
s
1 .38 0 r
.70646 .47111 m .69752 .46721 L .67732 .47752 L p F P
0 0 0 r
s
.372 .62 .628 r
.42163 .68409 m
.44173 .67792 L
s
.42163 .68409 m
.40972 .67266 L
s
.926 1 0 r
.55738 .52127 m .56758 .51309 L .58751 .51083 L p F P
0 0 0 r
s
1 .946 0 r
.56758 .51309 m .55738 .52127 L .53742 .51921 L p F P
0 0 0 r
s
.841 1 0 r
.50686 .52229 m .51774 .51619 L .53742 .51921 L p F P
0 0 0 r
s
1 .923 0 r
.51774 .51619 m .50686 .52229 L .48732 .51518 L p F P
0 0 0 r
s
.372 .62 .628 r
.47352 .68314 m
.49383 .67697 L
s
.47352 .68314 m
.46198 .6717 L
s
1 .018 0 r
.81749 .43855 m .82603 .45045 L .84683 .44333 L p F P
0 0 0 r
s
1 .029 0 r
.82603 .45045 m .81749 .43855 L .79677 .44619 L p F P
0 0 0 r
s
1 .773 0 r
.63713 .495 m .62778 .4999 L .60759 .50655 L p F P
0 0 0 r
s
1 .08 0 r
.76746 .44395 m .77621 .454 L .79677 .44619 L p F P
0 0 0 r
s
1 .111 0 r
.77621 .454 m .76746 .44395 L .74699 .45291 L p F P
0 0 0 r
s
.372 .62 .628 r
.52546 .68219 m
.54599 .67601 L
s
.52546 .68219 m
.5143 .67074 L
s
1 .793 0 r
.39545 .48601 m .40727 .49202 L .42606 .49945 L p F P
0 0 0 r
s
1 .515 0 r
.39545 .48601 m .37683 .48015 L p .40354 .49057 L F P
0 0 0 r
s
1 .615 0 r
.36487 .47129 m .37683 .48015 L .39545 .48601 L p F P
0 0 0 r
s
1 .615 0 r
.38344 .47923 m .36487 .47129 L p .38929 .48305 L F P
0 0 0 r
s
1 .615 0 r
.39545 .48601 m .38344 .47923 L p .38929 .48305 L F P
0 0 0 r
s
1 .698 0 r
.35276 .46141 m .36487 .47129 L .38344 .47923 L p F P
0 0 0 r
s
1 .698 0 r
.37129 .47093 m .35276 .46141 L p .37588 .47484 L F P
0 0 0 r
s
1 .698 0 r
.38344 .47923 m .37129 .47093 L p .37588 .47484 L F P
0 0 0 r
s
1 .753 0 r
.34052 .45011 m .35276 .46141 L .37129 .47093 L p F P
0 0 0 r
s
1 .753 0 r
.35904 .46047 m .34052 .45011 L p .36306 .46536 L F P
0 0 0 r
s
1 .753 0 r
.37129 .47093 m .35904 .46047 L p .36306 .46536 L F P
0 0 0 r
s
.841 1 0 r
.37129 .47093 m .38989 .48685 L p .36662 .46696 L F P
0 0 0 r
s
.841 1 0 r
.35904 .46047 m .37129 .47093 L p .36662 .46696 L F P
0 0 0 r
s
.841 1 0 r
.37759 .47762 m .35904 .46047 L p .37924 .47774 L F P
0 0 0 r
s
.841 1 0 r
.38989 .48685 m .37759 .47762 L p .37924 .47774 L F P
0 0 0 r
s
.262 1 0 r
.37759 .47762 m .39629 .5022 L p .37591 .47749 L F P
0 0 0 r
s
.811 1 0 r
.35904 .46047 m .37759 .47762 L p .35494 .4555 L F P
0 0 0 r
s
.811 1 0 r
.36527 .46459 m .34673 .44748 L p .36692 .4672 L F P
0 0 0 r
s
.811 1 0 r
.37759 .47762 m .36527 .46459 L p .36692 .4672 L F P
0 0 0 r
s
.262 1 0 r
.36527 .46459 m .37759 .47762 L p .37591 .47749 L F P
0 0 0 r
s
.262 1 0 r
.38393 .48917 m .36527 .46459 L p .38194 .4848 L F P
0 0 0 r
s
.262 1 0 r
.39629 .5022 m .38393 .48917 L p .38194 .4848 L F P
0 0 0 r
s
0 1 .354 r
.38393 .48917 m .40289 .52085 L p .38596 .49363 L F P
0 0 0 r
s
.306 1 0 r
.36527 .46459 m .38393 .48917 L p .36358 .46194 L F P
0 0 0 r
s
.926 1 0 r
.37129 .47093 m .38344 .47923 L p .37749 .47535 L F P
0 0 0 r
s
.926 1 0 r
.40212 .49288 m .38989 .48685 L .37129 .47093 L p F P
0 0 0 r
s
.306 1 0 r
.37166 .47062 m .35298 .44774 L p .37043 .4711 L F P
0 0 0 r
s
.306 1 0 r
.38393 .48917 m .37166 .47062 L p .37043 .4711 L F P
0 0 0 r
s
0 1 .354 r
.37166 .47062 m .38393 .48917 L p .38596 .49363 L F P
0 0 0 r
s
0 1 .414 r
.38393 .48917 m .39629 .5022 L .41532 .53387 L p F P
0 0 0 r
s
0 1 .414 r
.40289 .52085 m .38393 .48917 L p .39495 .50486 L F P
0 0 0 r
s
0 1 .414 r
.41532 .53387 m .40289 .52085 L p .39495 .50486 L F P
0 0 0 r
s
0 .891 1 r
.40289 .52085 m .42237 .55781 L p .41105 .53729 L F P
0 0 0 r
s
0 1 .354 r
.3906 .50021 m .37166 .47062 L p .38339 .48949 L F P
0 0 0 r
s
0 1 .354 r
.40289 .52085 m .3906 .50021 L p .38339 .48949 L F P
0 0 0 r
s
0 .891 1 r
.3906 .50021 m .40289 .52085 L p .41105 .53729 L F P
0 0 0 r
s
0 .811 1 r
.40289 .52085 m .41532 .53387 L .43487 .57078 L p F P
0 0 0 r
s
0 .811 1 r
.43487 .57078 m .42237 .55781 L .40289 .52085 L p F P
0 0 0 r
s
0 1 .882 r
.3906 .50021 m .41004 .53475 L p .398 .5112 L F P
0 0 0 r
s
.926 1 0 r
.38344 .47923 m .40212 .49288 L p .37749 .47535 L F P
0 0 0 r
s
.306 1 0 r
.37759 .47762 m .38989 .48685 L .40868 .50977 L p F P
0 0 0 r
s
.306 1 0 r
.40868 .50977 m .39629 .5022 L .37759 .47762 L p F P
0 0 0 r
s
0 1 .882 r
.3785 .47306 m .3906 .50021 L p .398 .5112 L F P
0 0 0 r
s
0 1 .182 r
.37166 .47062 m .3906 .50021 L p .37291 .47013 L F P
0 0 0 r
s
0 1 .182 r
.3595 .44734 m .37166 .47062 L p .37291 .47013 L F P
0 0 0 r
s
.306 1 0 r
.35298 .44774 m .36527 .46459 L p .36358 .46194 L F P
0 0 0 r
s
.811 1 0 r
.34673 .44748 m .35904 .46047 L p .35494 .4555 L F P
0 0 0 r
s
1 .946 0 r
.39545 .48601 m .41419 .4967 L p .38722 .48137 L F P
0 0 0 r
s
1 .946 0 r
.38344 .47923 m .39545 .48601 L p .38722 .48137 L F P
0 0 0 r
s
1 .515 0 r
.40727 .49202 m .39545 .48601 L p .40354 .49057 L F P
0 0 0 r
s
.372 .62 .628 r
.57747 .68125 m
.56668 .66978 L
s
.59822 .67506 m
.57747 .68125 L
s
1 .38 0 r
.37683 .48015 m .36487 .47129 L .34634 .46806 L p F P
0 0 0 r
s
1 .253 0 r
.71779 .45644 m .72667 .46203 L .74699 .45291 L p F P
0 0 0 r
s
1 .318 0 r
.72667 .46203 m .71779 .45644 L .69752 .46721 L p F P
0 0 0 r
s
.372 .62 .628 r
.38969 .67887 m
.40972 .67266 L
s
.38969 .67887 m
.3775 .66737 L
s
1 .431 0 r
.33423 .45714 m .34634 .46806 L .36487 .47129 L p F P
0 0 0 r
s
1 .253 0 r
.34634 .46806 m .33423 .45714 L .31571 .45685 L p F P
0 0 0 r
s
.372 .62 .628 r
.44173 .67792 m
.46198 .6717 L
s
.44173 .67792 m
.42992 .66641 L
s
1 .698 0 r
.66831 .47975 m .64803 .49085 L p .65398 .48814 L F P
0 0 0 r
s
1 .698 0 r
.67732 .47752 m .66831 .47975 L p .65398 .48814 L F P
0 0 0 r
s
1 .615 0 r
.69752 .46721 m .68861 .46722 L .66831 .47975 L p F P
0 0 0 r
s
1 .946 0 r
.66831 .47975 m .68861 .46722 L p .68277 .47129 L F P
0 0 0 r
s
1 .615 0 r
.66831 .47975 m .67732 .47752 L .69752 .46721 L p F P
0 0 0 r
s
1 .946 0 r
.65933 .48762 m .66831 .47975 L p .68277 .47129 L F P
0 0 0 r
s
.926 1 0 r
.64803 .49085 m .66831 .47975 L p .66112 .48496 L F P
0 0 0 r
s
1 .753 0 r
.65719 .48691 m .64803 .49085 L p .63508 .49667 L F P
0 0 0 r
s
.926 1 0 r
.63887 .50108 m .64803 .49085 L p .66112 .48496 L F P
0 0 0 r
s
1 .753 0 r
.64803 .49085 m .62778 .4999 L p .63508 .49667 L F P
0 0 0 r
s
.372 .62 .628 r
.49383 .67697 m
.5143 .67074 L
s
.49383 .67697 m
.48239 .66544 L
s
1 .011 0 r
.83839 .43107 m .84683 .44333 L .8678 .43626 L p F P
0 0 0 r
s
1 .018 0 r
.84683 .44333 m .83839 .43107 L .81749 .43855 L p F P
0 0 0 r
s
1 .054 0 r
.78809 .43528 m .79677 .44619 L .81749 .43855 L p F P
0 0 0 r
s
1 .08 0 r
.79677 .44619 m .78809 .43528 L .76746 .44395 L p F P
0 0 0 r
s
.717 1 0 r
.47601 .5199 m .48732 .51518 L .50686 .52229 L p F P
0 0 0 r
s
1 .971 0 r
.48732 .51518 m .47601 .5199 L .45671 .50961 L p F P
0 0 0 r
s
1 .273 0 r
.30344 .44473 m .31571 .45685 L .33423 .45714 L p F P
0 0 0 r
s
1 .152 0 r
.31571 .45685 m .30344 .44473 L .28489 .44706 L p F P
0 0 0 r
s
.372 .62 .628 r
.54599 .67601 m
.56668 .66978 L
s
.54599 .67601 m
.53493 .66447 L
s
.841 1 0 r
.57757 .52124 m .58751 .51083 L .60759 .50655 L p F P
0 0 0 r
s
.926 1 0 r
.58751 .51083 m .57757 .52124 L .55738 .52127 L p F P
0 0 0 r
s
.372 .62 .628 r
.59822 .67506 m
.58754 .6635 L
s
.61913 .66882 m
.59822 .67506 L
s
1 .191 0 r
.73817 .44564 m .74699 .45291 L .76746 .44395 L p F P
0 0 0 r
s
1 .253 0 r
.74699 .45291 m .73817 .44564 L .71779 .45644 L p F P
0 0 0 r
s
.372 .62 .628 r
.35753 .67362 m
.3775 .66737 L
s
.35753 .67362 m
.34507 .66204 L
s
1 .156 0 r
.27242 .43435 m .28489 .44706 L .30344 .44473 L p F P
0 0 0 r
s
.616 1 0 r
.52673 .5296 m .53742 .51921 L .55738 .52127 L p F P
0 0 0 r
s
.841 1 0 r
.53742 .51921 m .52673 .5296 L .50686 .52229 L p F P
0 0 0 r
s
.372 .62 .628 r
.40972 .67266 m
.42992 .66641 L
s
.40972 .67266 m
.39764 .66107 L
s
.46198 .6717 m
.48239 .66544 L
s
.46198 .6717 m
.45027 .6601 L
s
.717 1 0 r
.44507 .51106 m .45671 .50961 L .47601 .5199 L p F P
0 0 0 r
s
1 .923 0 r
.45671 .50961 m .44507 .51106 L .42606 .49945 L p F P
0 0 0 r
s
1 .034 0 r
.80888 .42694 m .81749 .43855 L .83839 .43107 L p F P
0 0 0 r
s
1 .054 0 r
.81749 .43855 m .80888 .42694 L .78809 .43528 L p F P
0 0 0 r
s
1 .005 0 r
.85946 .42372 m .8678 .43626 L .88893 .42921 L p F P
0 0 0 r
s
1 .011 0 r
.8678 .43626 m .85946 .42372 L .83839 .43107 L p F P
0 0 0 r
s
.372 .62 .628 r
.5143 .67074 m
.53493 .66447 L
s
.5143 .67074 m
.50297 .65912 L
s
1 .137 0 r
.75868 .43515 m .76746 .44395 L .78809 .43528 L p F P
0 0 0 r
s
1 .191 0 r
.76746 .44395 m .75868 .43515 L .73817 .44564 L p F P
0 0 0 r
s
.372 .62 .628 r
.56668 .66978 m
.58754 .6635 L
s
.56668 .66978 m
.55573 .65815 L
s
.61913 .66882 m
.60856 .65717 L
s
.64021 .66253 m
.61913 .66882 L
s
1 .515 0 r
.68861 .46722 m .69752 .46721 L .71779 .45644 L p F P
0 0 0 r
s
.841 1 0 r
.41419 .4967 m .42606 .49945 L .44507 .51106 L p F P
0 0 0 r
s
1 .793 0 r
.42606 .49945 m .41419 .4967 L .39545 .48601 L p F P
0 0 0 r
s
.811 1 0 r
.59793 .51815 m .60759 .50655 L .62778 .4999 L p F P
0 0 0 r
s
.841 1 0 r
.60759 .50655 m .59793 .51815 L .57757 .52124 L p F P
0 0 0 r
s
.372 .62 .628 r
.3775 .66737 m
.39764 .66107 L
s
.3775 .66737 m
.36514 .6557 L
s
1 .431 0 r
.36487 .47129 m .35276 .46141 L .33423 .45714 L p F P
0 0 0 r
s
1 .465 0 r
.322 .44532 m .33423 .45714 L .35276 .46141 L p F P
0 0 0 r
s
1 .273 0 r
.33423 .45714 m .322 .44532 L .30344 .44473 L p F P
0 0 0 r
s
.372 .62 .628 r
.42992 .66641 m
.45027 .6601 L
s
.42992 .66641 m
.41793 .65472 L
s
1 .02 0 r
.82986 .41893 m .83839 .43107 L .85946 .42372 L p F P
0 0 0 r
s
1 .034 0 r
.83839 .43107 m .82986 .41893 L .80888 .42694 L p F P
0 0 0 r
s
.372 .62 .628 r
.48239 .66544 m
.50297 .65912 L
s
.48239 .66544 m
.47079 .65374 L
s
1 .002 0 r
.8807 .41646 m .88893 .42921 L .91023 .42216 L p F P
0 0 0 r
s
1 .005 0 r
.88893 .42921 m .8807 .41646 L .85946 .42372 L p F P
0 0 0 r
s
1 .28 0 r
.29104 .43193 m .30344 .44473 L .322 .44532 L p F P
0 0 0 r
s
1 .156 0 r
.30344 .44473 m .29104 .43193 L .27242 .43435 L p F P
0 0 0 r
s
1 .093 0 r
.77935 .42518 m .78809 .43528 L .80888 .42694 L p F P
0 0 0 r
s
1 .137 0 r
.78809 .43528 m .77935 .42518 L .75868 .43515 L p F P
0 0 0 r
s
1 .41 0 r
.70896 .45398 m .71779 .45644 L .73817 .44564 L p F P
0 0 0 r
s
1 .515 0 r
.71779 .45644 m .70896 .45398 L .68861 .46722 L p F P
0 0 0 r
s
.372 .62 .628 r
.53493 .66447 m
.55573 .65815 L
s
.53493 .66447 m
.52371 .65276 L
s
.58754 .6635 m
.60856 .65717 L
s
.58754 .6635 m
.5767 .65177 L
s
.389 1 0 r
.49566 .53216 m .50686 .52229 L .52673 .5296 L p F P
0 0 0 r
s
.717 1 0 r
.50686 .52229 m .49566 .53216 L .47601 .5199 L p F P
0 0 0 r
s
.841 1 0 r
.61839 .51144 m .62778 .4999 L .64803 .49085 L p F P
0 0 0 r
s
.811 1 0 r
.62778 .4999 m .61839 .51144 L .59793 .51815 L p F P
0 0 0 r
s
.372 .62 .628 r
.64021 .66253 m
.62975 .65079 L
s
.66145 .65619 m
.64021 .66253 L
s
1 .152 0 r
.25979 .42119 m .27242 .43435 L .29104 .43193 L p F P
0 0 0 r
s
.43 1 0 r
.54694 .53557 m .55738 .52127 L .57757 .52124 L p F P
0 0 0 r
s
.616 1 0 r
.55738 .52127 m .54694 .53557 L .52673 .5296 L p F P
0 0 0 r
s
.372 .62 .628 r
.34507 .66204 m
.36514 .6557 L
s
.34507 .66204 m
.33242 .6503 L
s
.39764 .66107 m
.41793 .65472 L
s
.39764 .66107 m
.38537 .64931 L
s
1 .31 0 r
.72937 .44074 m .73817 .44564 L .75868 .43515 L p F P
0 0 0 r
s
1 .41 0 r
.73817 .44564 m .72937 .44074 L .70896 .45398 L p F P
0 0 0 r
s
.372 .62 .628 r
.45027 .6601 m
.47079 .65374 L
s
.45027 .6601 m
.43839 .64832 L
s
1 .011 0 r
.85101 .41118 m .85946 .42372 L .8807 .41646 L p F P
0 0 0 r
s
1 .02 0 r
.85946 .42372 m .85101 .41118 L .82986 .41893 L p F P
0 0 0 r
s
1 .06 0 r
.8002 .41582 m .80888 .42694 L .82986 .41893 L p F P
0 0 0 r
s
1 .093 0 r
.80888 .42694 m .8002 .41582 L .77935 .42518 L p F P
0 0 0 r
s
.372 .62 .628 r
.50297 .65912 m
.52371 .65276 L
s
.50297 .65912 m
.49147 .64733 L
s
1 .002 0 r
.91023 .42216 m .90211 .40923 L .8807 .41646 L p F P
0 0 0 r
s
.372 .62 .628 r
.55573 .65815 m
.5767 .65177 L
s
.55573 .65815 m
.54462 .64634 L
s
.841 1 0 r
.64803 .49085 m .63887 .50108 L .61839 .51144 L p F P
0 0 0 r
s
.372 .62 .628 r
.60856 .65717 m
.62975 .65079 L
s
.60856 .65717 m
.59783 .64535 L
s
1 .223 0 r
.7499 .42804 m .75868 .43515 L .77935 .42518 L p F P
0 0 0 r
s
1 .31 0 r
.75868 .43515 m .7499 .42804 L .72937 .44074 L p F P
0 0 0 r
s
.306 1 0 r
.46438 .52651 m .47601 .5199 L .49566 .53216 L p F P
0 0 0 r
s
.717 1 0 r
.47601 .5199 m .46438 .52651 L .44507 .51106 L p F P
0 0 0 r
s
.372 .62 .628 r
.66145 .65619 m
.65111 .64436 L
s
.68287 .6498 m
.66145 .65619 L
s
.36514 .6557 m
.38537 .64931 L
s
.36514 .6557 m
.35259 .64386 L
s
1 .465 0 r
.35276 .46141 m .34052 .45011 L .322 .44532 L p F P
0 0 0 r
s
1 .477 0 r
.30964 .43245 m .322 .44532 L .34052 .45011 L p F P
0 0 0 r
s
1 .28 0 r
.322 .44532 m .30964 .43245 L .29104 .43193 L p F P
0 0 0 r
s
.372 .62 .628 r
.41793 .65472 m
.43839 .64832 L
s
.41793 .65472 m
.40577 .64286 L
s
1 .036 0 r
.82124 .40702 m .82986 .41893 L .85101 .41118 L p F P
0 0 0 r
s
1 .06 0 r
.82986 .41893 m .82124 .40702 L .8002 .41582 L p F P
0 0 0 r
s
.926 1 0 r
.66831 .47975 m .65933 .48762 L .63887 .50108 L p F P
0 0 0 r
s
1 .273 0 r
.27849 .41846 m .29104 .43193 L .30964 .43245 L p F P
0 0 0 r
s
1 .152 0 r
.29104 .43193 m .27849 .41846 L .25979 .42119 L p F P
0 0 0 r
s
1 .005 0 r
.87235 .40362 m .8807 .41646 L .90211 .40923 L p F P
0 0 0 r
s
1 .011 0 r
.8807 .41646 m .87235 .40362 L .85101 .41118 L p F P
0 0 0 r
s
.372 .62 .628 r
.47079 .65374 m
.49147 .64733 L
s
.47079 .65374 m
.45901 .64187 L
s
1 .946 0 r
.41419 .4967 m .40212 .49288 L .38344 .47923 L p F P
0 0 0 r
s
.389 1 0 r
.43315 .51263 m .44507 .51106 L .46438 .52651 L p F P
0 0 0 r
s
.841 1 0 r
.44507 .51106 m .43315 .51263 L .41419 .4967 L p F P
0 0 0 r
s
.306 1 0 r
.56742 .53854 m .57757 .52124 L .59793 .51815 L p F P
0 0 0 r
s
.43 1 0 r
.57757 .52124 m .56742 .53854 L .54694 .53557 L p F P
0 0 0 r
s
.372 .62 .628 r
.52371 .65276 m
.54462 .64634 L
s
.52371 .65276 m
.51232 .64087 L
s
.616 1 0 r
.40212 .49288 m .41419 .4967 L .43315 .51263 L p F P
0 0 0 r
s
1 .152 0 r
.77059 .4162 m .77935 .42518 L .8002 .41582 L p F P
0 0 0 r
s
1 .223 0 r
.77935 .42518 m .77059 .4162 L .7499 .42804 L p F P
0 0 0 r
s
.372 .62 .628 r
.5767 .65177 m
.59783 .64535 L
s
.5767 .65177 m
.5657 .63987 L
s
1 .14 0 r
.24701 .40762 m .25979 .42119 L .27849 .41846 L p F P
0 0 0 r
s
.372 .62 .628 r
.62975 .65079 m
.65111 .64436 L
s
.62975 .65079 m
.61914 .63887 L
s
1 .793 0 r
.67975 .472 m .68861 .46722 L .70896 .45398 L p F P
0 0 0 r
s
1 .793 0 r
.70896 .45398 m .70015 .45534 L .67975 .472 L p F P
0 0 0 r
s
.841 1 0 r
.67975 .472 m .70015 .45534 L p .6953 .45976 L F P
0 0 0 r
s
1 .946 0 r
.68861 .46722 m .67975 .472 L p .6643 .48416 L F P
0 0 0 r
s
.841 1 0 r
.6709 .48197 m .67975 .472 L p .69101 .46314 L F P
0 0 0 r
s
.841 1 0 r
.6709 .48197 m .69101 .46314 L .68806 .46635 L F
.68806 .46635 m .69101 .46314 L .6953 .45976 L F
.70015 .45534 m .69136 .46083 L .6709 .48197 L p F P
0 0 0 r
s
.389 1 0 r
.6709 .48197 m .68695 .46539 L p .66267 .49594 L F P
0 0 0 r
s
.389 1 0 r
.66267 .49594 m .68695 .46539 L .68291 .47118 L F
.68695 .46539 m .69136 .46083 L p .68291 .47118 L F P
0 0 0 r
s
.389 1 0 r
.69136 .46083 m .68253 .47014 L .6718 .48406 L p F P
0 0 0 r
s
.389 1 0 r
.66198 .49679 m .66208 .49662 L p .66267 .49594 L F P
0 0 0 r
s
.389 1 0 r
.66208 .49662 m .6709 .48197 L p .66267 .49594 L F P
0 0 0 r
s
.389 1 0 r
.6718 .48406 m .66198 .49679 L p .67714 .47824 L F P
0 0 0 r
s
.389 1 0 r
.67714 .47824 m .69136 .46083 L .6718 .48406 L F
0 1 .127 r
.66198 .49679 m .68224 .47051 L p .6537 .51385 L F P
0 0 0 r
s
0 1 .127 r
.6537 .51385 m .68224 .47051 L .68175 .47132 L F
.68224 .47051 m .68253 .47014 L p .68175 .47132 L F P
0 0 0 r
s
0 1 .127 r
.68253 .47014 m .67353 .48211 L .65836 .50634 L p F P
0 0 0 r
s
0 1 .127 r
.65288 .51509 m .65301 .51483 L p .6537 .51385 L F P
0 0 0 r
s
0 1 .127 r
.65301 .51483 m .66198 .49679 L p .6537 .51385 L F P
0 0 0 r
s
0 1 .127 r
.65836 .50634 m .65288 .51509 L p .66362 .49881 L F P
0 0 0 r
s
0 1 .127 r
.66362 .49881 m .68253 .47014 L .65836 .50634 L F
0 1 .671 r
.64345 .53426 m .65288 .51509 L .67353 .48211 L p F P
0 0 0 r
s
0 1 .671 r
.67353 .48211 m .66426 .49464 L .64381 .53359 L p F P
0 0 0 r
s
0 1 .671 r
.64381 .53359 m .64345 .53426 L p .64446 .53251 L F P
0 0 0 r
s
0 1 .671 r
.64446 .53251 m .67353 .48211 L .64381 .53359 L F
1 .923 0 r
.72059 .43873 m .71181 .43981 L .69136 .46083 L p F P
0 0 0 r
s
1 .923 0 r
.69136 .46083 m .70015 .45534 L .71439 .44376 L p F P
0 0 0 r
s
1 .923 0 r
.69136 .46083 m .71439 .44376 L .71022 .44657 L F
.717 1 0 r
.68253 .47014 m .69136 .46083 L .70838 .44334 L p F P
0 0 0 r
s
.717 1 0 r
.70838 .44334 m .71181 .43981 L p .70479 .44708 L F P
0 0 0 r
s
.717 1 0 r
.68253 .47014 m .70838 .44334 L .70479 .44708 L F
.70298 .44374 m .69054 .45979 L p .71131 .44033 L F P
0 0 0 r
s
.717 1 0 r
.69054 .45979 m .68253 .47014 L p .69617 .45601 L F P
0 0 0 r
s
.717 1 0 r
.69617 .45601 m .71131 .44033 L .69054 .45979 L F
.306 1 0 r
.67353 .48211 m .68253 .47014 L .70298 .44374 L p F P
0 0 0 r
s
.306 1 0 r
.69402 .44958 m .67799 .47503 L p .70237 .44453 L F P
0 0 0 r
s
.306 1 0 r
.67799 .47503 m .67353 .48211 L p .68288 .46994 L F P
0 0 0 r
s
.306 1 0 r
.68288 .46994 m .70237 .44453 L .67799 .47503 L F
1 .923 0 r
.71439 .44376 m .72059 .43873 L p .71022 .44657 L F P
0 0 0 r
s
.306 1 0 r
.70298 .44374 m .70288 .4438 L p .70237 .44453 L F P
0 0 0 r
s
.306 1 0 r
.70288 .4438 m .69402 .44958 L p .70237 .44453 L F P
0 0 0 r
s
.717 1 0 r
.71181 .43981 m .71173 .43985 L p .71131 .44033 L F P
0 0 0 r
s
.717 1 0 r
.71173 .43985 m .70298 .44374 L p .71131 .44033 L F P
0 0 0 r
s
1 .946 0 r
.67975 .472 m .65933 .48762 L p .6643 .48416 L F P
0 0 0 r
s
.372 .62 .628 r
.33242 .6503 m
.35259 .64386 L
s
.33242 .6503 m
.31959 .63837 L
s
.077 1 0 r
.51571 .5448 m .52673 .5296 L .54694 .53557 L p F P
0 0 0 r
s
.389 1 0 r
.52673 .5296 m .51571 .5448 L .49566 .53216 L p F P
0 0 0 r
s
.372 .62 .628 r
.68287 .6498 m
.67265 .63787 L
s
.70446 .64336 m
.68287 .6498 L
s
.38537 .64931 m
.40577 .64286 L
s
.38537 .64931 m
.37293 .63737 L
s
.43839 .64832 m
.45901 .64187 L
s
.43839 .64832 m
.42633 .63637 L
s
1 .02 0 r
.84248 .3987 m .85101 .41118 L .87235 .40362 L p F P
0 0 0 r
s
1 .036 0 r
.85101 .41118 m .84248 .3987 L .82124 .40702 L p F P
0 0 0 r
s
1 .631 0 r
.70015 .45534 m .70896 .45398 L .72937 .44074 L p F P
0 0 0 r
s
1 .005 0 r
.90211 .40923 m .89388 .39618 L .87235 .40362 L p F P
0 0 0 r
s
.372 .62 .628 r
.49147 .64733 m
.51232 .64087 L
s
.49147 .64733 m
.4798 .63536 L
s
1 .098 0 r
.79146 .40536 m .8002 .41582 L .82124 .40702 L p F P
0 0 0 r
s
1 .152 0 r
.8002 .41582 m .79146 .40536 L .77059 .4162 L p F P
0 0 0 r
s
.372 .62 .628 r
.54462 .64634 m
.5657 .63987 L
s
.54462 .64634 m
.53334 .63436 L
s
.59783 .64535 m
.61914 .63887 L
s
.59783 .64535 m
.58695 .63335 L
s
1 .477 0 r
.72059 .43873 m .72937 .44074 L .7499 .42804 L p F P
0 0 0 r
s
1 .631 0 r
.72937 .44074 m .72059 .43873 L .70015 .45534 L p F P
0 0 0 r
s
.262 1 0 r
.58811 .53707 m .59793 .51815 L .61839 .51144 L p F P
0 0 0 r
s
.306 1 0 r
.59793 .51815 m .58811 .53707 L .56742 .53854 L p F P
0 0 0 r
s
.372 .62 .628 r
.65111 .64436 m
.67265 .63787 L
s
.65111 .64436 m
.64062 .63234 L
s
.35259 .64386 m
.37293 .63737 L
s
.35259 .64386 m
.33986 .63184 L
s
1 .477 0 r
.34052 .45011 m .3282 .43717 L .30964 .43245 L p F P
0 0 0 r
s
1 .465 0 r
.29718 .41851 m .30964 .43245 L .3282 .43717 L p F P
0 0 0 r
s
1 .273 0 r
.30964 .43245 m .29718 .41851 L .27849 .41846 L p F P
0 0 0 r
s
.372 .62 .628 r
.70446 .64336 m
.69436 .63133 L
s
.72622 .63687 m
.70446 .64336 L
s
.40577 .64286 m
.42633 .63637 L
s
.40577 .64286 m
.39343 .63083 L
s
1 .253 0 r
.26581 .40437 m .27849 .41846 L .29718 .41851 L p F P
0 0 0 r
s
1 .14 0 r
.27849 .41846 m .26581 .40437 L .24701 .40762 L p F P
0 0 0 r
s
1 .773 0 r
.3282 .43717 m .34052 .45011 L .35904 .46047 L p F P
0 0 0 r
s
1 .011 0 r
.86391 .39074 m .87235 .40362 L .89388 .39618 L p F P
0 0 0 r
s
1 .02 0 r
.87235 .40362 m .86391 .39074 L .84248 .3987 L p F P
0 0 0 r
s
1 .343 0 r
.74111 .42298 m .7499 .42804 L .77059 .4162 L p F P
0 0 0 r
s
1 .477 0 r
.7499 .42804 m .74111 .42298 L .72059 .43873 L p F P
0 0 0 r
s
1 .06 0 r
.81254 .39547 m .82124 .40702 L .84248 .3987 L p F P
0 0 0 r
s
1 .098 0 r
.82124 .40702 m .81254 .39547 L .79146 .40536 L p F P
0 0 0 r
s
.372 .62 .628 r
.45901 .64187 m
.4798 .63536 L
s
.45901 .64187 m
.44706 .62982 L
s
.51232 .64087 m
.53334 .63436 L
s
.51232 .64087 m
.50076 .62881 L
s
0 1 .127 r
.4841 .54467 m .49566 .53216 L .51571 .5448 L p F P
0 0 0 r
s
.306 1 0 r
.49566 .53216 m .4841 .54467 L .46438 .52651 L p F P
0 0 0 r
s
1 .123 0 r
.23406 .3937 m .24701 .40762 L .26581 .40437 L p F P
0 0 0 r
s
.372 .62 .628 r
.5657 .63987 m
.58695 .63335 L
s
.5657 .63987 m
.55453 .62779 L
s
.61914 .63887 m
.64062 .63234 L
s
.61914 .63887 m
.60837 .62678 L
s
.306 1 0 r
.60889 .53031 m .61839 .51144 L .63887 .50108 L p F P
0 0 0 r
s
.262 1 0 r
.61839 .51144 m .60889 .53031 L .58811 .53707 L p F P
0 0 0 r
s
1 .234 0 r
.76179 .40859 m .77059 .4162 L .79146 .40536 L p F P
0 0 0 r
s
1 .343 0 r
.77059 .4162 m .76179 .40859 L .74111 .42298 L p F P
0 0 0 r
s
.372 .62 .628 r
.31959 .63837 m
.33986 .63184 L
s
.31959 .63837 m
.30656 .62627 L
s
.67265 .63787 m
.69436 .63133 L
s
.67265 .63787 m
.66227 .62576 L
s
.37293 .63737 m
.39343 .63083 L
s
.37293 .63737 m
.36029 .62525 L
s
0 1 .182 r
.53617 .55565 m .54694 .53557 L .56742 .53854 L p F P
0 0 0 r
s
.077 1 0 r
.54694 .53557 m .53617 .55565 L .51571 .5448 L p F P
0 0 0 r
s
.372 .62 .628 r
.72622 .63687 m
.71624 .62474 L
s
.74816 .63032 m
.72622 .63687 L
s
1 .034 0 r
.83384 .38636 m .84248 .3987 L .86391 .39074 L p F P
0 0 0 r
s
1 .06 0 r
.84248 .3987 m .83384 .38636 L .81254 .39547 L p F P
0 0 0 r
s
.372 .62 .628 r
.42633 .63637 m
.44706 .62982 L
s
.42633 .63637 m
.41409 .62423 L
s
.616 1 0 r
.43315 .51263 m .42099 .51276 L .40212 .49288 L p F P
0 0 0 r
s
.43 1 0 r
.38989 .48685 m .40212 .49288 L .42099 .51276 L p F P
0 0 0 r
s
1 .011 0 r
.89388 .39618 m .88553 .38301 L .86391 .39074 L p F P
0 0 0 r
s
.372 .62 .628 r
.4798 .63536 m
.50076 .62881 L
s
.4798 .63536 m
.46796 .62321 L
s
0 1 .127 r
.45243 .53343 m .46438 .52651 L .4841 .54467 L p F P
0 0 0 r
s
.389 1 0 r
.46438 .52651 m .45243 .53343 L .43315 .51263 L p F P
0 0 0 r
s
.372 .62 .628 r
.53334 .63436 m
.55453 .62779 L
s
.53334 .63436 m
.52189 .62219 L
s
1 .152 0 r
.78267 .39575 m .79146 .40536 L .81254 .39547 L p F P
0 0 0 r
s
1 .234 0 r
.79146 .40536 m .78267 .39575 L .76179 .40859 L p F P
0 0 0 r
s
.43 1 0 r
.62966 .51824 m .63887 .50108 L .65933 .48762 L p F P
0 0 0 r
s
.306 1 0 r
.63887 .50108 m .62966 .51824 L .60889 .53031 L p F P
0 0 0 r
s
.077 1 0 r
.42099 .51276 m .43315 .51263 L .45243 .53343 L p F P
0 0 0 r
s
.372 .62 .628 r
.58695 .63335 m
.60837 .62678 L
s
.58695 .63335 m
.57589 .62117 L
s
1 .465 0 r
.3282 .43717 m .31581 .42257 L .29718 .41851 L p F P
0 0 0 r
s
1 .431 0 r
.2846 .40363 m .29718 .41851 L .31581 .42257 L p F P
0 0 0 r
s
1 .253 0 r
.29718 .41851 m .2846 .40363 L .26581 .40437 L p F P
0 0 0 r
s
.372 .62 .628 r
.64062 .63234 m
.66227 .62576 L
s
.64062 .63234 m
.62996 .62015 L
s
.33986 .63184 m
.36029 .62525 L
s
.33986 .63184 m
.32693 .61964 L
s
1 .222 0 r
.25298 .38979 m .26581 .40437 L .2846 .40363 L p F P
0 0 0 r
s
1 .123 0 r
.26581 .40437 m .25298 .38979 L .23406 .3937 L p F P
0 0 0 r
s
.616 1 0 r
.65034 .50166 m .65933 .48762 L .67975 .472 L p F P
0 0 0 r
s
.43 1 0 r
.65933 .48762 m .65034 .50166 L .62966 .51824 L p F P
0 0 0 r
s
.372 .62 .628 r
.69436 .63133 m
.71624 .62474 L
s
.69436 .63133 m
.6841 .61912 L
s
1 .773 0 r
.35904 .46047 m .34673 .44748 L .3282 .43717 L p F P
0 0 0 r
s
1 .753 0 r
.31581 .42257 m .3282 .43717 L .34673 .44748 L p F P
0 0 0 r
s
.372 .62 .628 r
.39343 .63083 m
.41409 .62423 L
s
.39343 .63083 m
.38089 .61861 L
s
1 .018 0 r
.85536 .37785 m .86391 .39074 L .88553 .38301 L p F P
0 0 0 r
s
1 .034 0 r
.86391 .39074 m .85536 .37785 L .83384 .38636 L p F P
0 0 0 r
s
.372 .62 .628 r
.74816 .63032 m
.73831 .6181 L
s
.77028 .62372 m
.74816 .63032 L
s
.616 1 0 r
.67975 .472 m .6709 .48197 L .65034 .50166 L p F P
0 0 0 r
s
.372 .62 .628 r
.44706 .62982 m
.46796 .62321 L
s
.44706 .62982 m
.43493 .61758 L
s
1 .093 0 r
.80377 .38436 m .81254 .39547 L .83384 .38636 L p F P
0 0 0 r
s
1 .152 0 r
.81254 .39547 m .80377 .38436 L .78267 .39575 L p F P
0 0 0 r
s
1 .103 0 r
.22094 .3795 m .23406 .3937 L .25298 .38979 L p F P
0 0 0 r
s
.372 .62 .628 r
.50076 .62881 m
.52189 .62219 L
s
.50076 .62881 m
.48903 .61656 L
s
.55453 .62779 m
.57589 .62117 L
s
.55453 .62779 m
.5432 .61553 L
s
1 .698 0 r
.71181 .43981 m .72059 .43873 L .74111 .42298 L p F P
0 0 0 r
s
.372 .62 .628 r
.60837 .62678 m
.62996 .62015 L
s
.60837 .62678 m
.59743 .6145 L
s
.30656 .62627 m
.32693 .61964 L
s
.30656 .62627 m
.29334 .61398 L
s
1 .502 0 r
.73231 .42011 m .74111 .42298 L .76179 .40859 L p F P
0 0 0 r
s
1 .698 0 r
.74111 .42298 m .73231 .42011 L .71181 .43981 L p F P
0 0 0 r
s
.372 .62 .628 r
.66227 .62576 m
.6841 .61912 L
s
.66227 .62576 m
.65174 .61347 L
s
0 1 .354 r
.55698 .56239 m .56742 .53854 L .58811 .53707 L p F P
0 0 0 r
s
0 1 .182 r
.56742 .53854 m .55698 .56239 L .53617 .55565 L p F P
0 0 0 r
s
.372 .62 .628 r
.36029 .62525 m
.38089 .61861 L
s
.36029 .62525 m
.34747 .61295 L
s
.71624 .62474 m
.73831 .6181 L
s
.71624 .62474 m
.70611 .61243 L
s
1 .018 0 r
.88553 .38301 m .87708 .36975 L .85536 .37785 L p F P
0 0 0 r
s
.372 .62 .628 r
.41409 .62423 m
.43493 .61758 L
s
.41409 .62423 m
.40167 .61192 L
s
1 .054 0 r
.82512 .37421 m .83384 .38636 L .85536 .37785 L p F P
0 0 0 r
s
1 .093 0 r
.83384 .38636 m .82512 .37421 L .80377 .38436 L p F P
0 0 0 r
s
0 1 .54 r
.5043 .56342 m .51571 .5448 L .53617 .55565 L p F P
0 0 0 r
s
0 1 .127 r
.51571 .5448 m .5043 .56342 L .4841 .54467 L p F P
0 0 0 r
s
1 .343 0 r
.75296 .40244 m .76179 .40859 L .78267 .39575 L p F P
0 0 0 r
s
1 .502 0 r
.76179 .40859 m .75296 .40244 L .73231 .42011 L p F P
0 0 0 r
s
.372 .62 .628 r
.77028 .62372 m
.76056 .6114 L
s
.79258 .61707 m
.77028 .62372 L
s
.46796 .62321 m
.48903 .61656 L
s
.46796 .62321 m
.45593 .61088 L
s
.52189 .62219 m
.5432 .61553 L
s
.52189 .62219 m
.51027 .60985 L
s
1 .431 0 r
.31581 .42257 m .30335 .4065 L .2846 .40363 L p F P
0 0 0 r
s
1 .38 0 r
.2719 .38804 m .2846 .40363 L .30335 .4065 L p F P
0 0 0 r
s
1 .222 0 r
.2846 .40363 m .2719 .38804 L .25298 .38979 L p F P
0 0 0 r
s
.372 .62 .628 r
.57589 .62117 m
.59743 .6145 L
s
.57589 .62117 m
.56467 .60881 L
s
.43 1 0 r
.42099 .51276 m .40868 .50977 L .38989 .48685 L p F P
0 0 0 r
s
1 .186 0 r
.23998 .37487 m .25298 .38979 L .2719 .38804 L p F P
0 0 0 r
s
1 .103 0 r
.25298 .38979 m .23998 .37487 L .22094 .3795 L p F P
0 0 0 r
s
1 .223 0 r
.77381 .38702 m .78267 .39575 L .80377 .38436 L p F P
0 0 0 r
s
1 .343 0 r
.78267 .39575 m .77381 .38702 L .75296 .40244 L p F P
0 0 0 r
s
.372 .62 .628 r
.62996 .62015 m
.65174 .61347 L
s
.62996 .62015 m
.61915 .60777 L
s
1 .753 0 r
.34673 .44748 m .3344 .43193 L .31581 .42257 L p F P
0 0 0 r
s
1 .698 0 r
.30335 .4065 m .31581 .42257 L .3344 .43193 L p F P
0 0 0 r
s
.372 .62 .628 r
.32693 .61964 m
.34747 .61295 L
s
.32693 .61964 m
.3138 .60725 L
s
.6841 .61912 m
.70611 .61243 L
s
.6841 .61912 m
.67369 .60673 L
s
.38089 .61861 m
.40167 .61192 L
s
.38089 .61861 m
.36817 .60621 L
s
1 .029 0 r
.8467 .36499 m .85536 .37785 L .87708 .36975 L p F P
0 0 0 r
s
1 .054 0 r
.85536 .37785 m .8467 .36499 L .82512 .37421 L p F P
0 0 0 r
s
.372 .62 .628 r
.73831 .6181 m
.76056 .6114 L
s
.73831 .6181 m
.7283 .60569 L
s
.43493 .61758 m
.45593 .61088 L
s
.43493 .61758 m
.42261 .60517 L
s
1 .082 0 r
.20763 .36511 m .22094 .3795 L .23998 .37487 L p F P
0 0 0 r
s
.372 .62 .628 r
.79258 .61707 m
.78299 .60464 L
s
.81507 .61036 m
.79258 .61707 L
s
.48903 .61656 m
.51027 .60985 L
s
.48903 .61656 m
.47711 .60412 L
s
0 1 .414 r
.57805 .56297 m .58811 .53707 L .60889 .53031 L p F P
0 0 0 r
s
0 1 .354 r
.58811 .53707 m .57805 .56297 L .55698 .56239 L p F P
0 0 0 r
s
1 .137 0 r
.79492 .37375 m .80377 .38436 L .82512 .37421 L p F P
0 0 0 r
s
1 .223 0 r
.80377 .38436 m .79492 .37375 L .77381 .38702 L p F P
0 0 0 r
s
.077 1 0 r
.45243 .53343 m .44021 .5385 L .42099 .51276 L p F P
0 0 0 r
s
0 1 .182 r
.40868 .50977 m .42099 .51276 L .44021 .5385 L p F P
0 0 0 r
s
.372 .62 .628 r
.5432 .61553 m
.56467 .60881 L
s
.5432 .61553 m
.53169 .60308 L
s
0 1 .671 r
.47217 .55772 m .4841 .54467 L .5043 .56342 L p F P
0 0 0 r
s
0 1 .127 r
.4841 .54467 m .47217 .55772 L .45243 .53343 L p F P
0 0 0 r
s
.841 1 0 r
.3344 .43193 m .34673 .44748 L .36527 .46459 L p F P
0 0 0 r
s
.372 .62 .628 r
.59743 .6145 m
.61915 .60777 L
s
.59743 .6145 m
.58633 .60203 L
s
.29334 .61398 m
.3138 .60725 L
s
.29334 .61398 m
.27991 .60151 L
s
.65174 .61347 m
.67369 .60673 L
s
.65174 .61347 m
.64104 .60098 L
s
0 1 .54 r
.44021 .5385 m .45243 .53343 L .47217 .55772 L p F P
0 0 0 r
s
.372 .62 .628 r
.34747 .61295 m
.36817 .60621 L
s
.34747 .61295 m
.33444 .60046 L
s
.70611 .61243 m
.7283 .60569 L
s
.70611 .61243 m
.69583 .59994 L
s
1 .029 0 r
.87708 .36975 m .86851 .35641 L .8467 .36499 L p F P
0 0 0 r
s
.372 .62 .628 r
.40167 .61192 m
.42261 .60517 L
s
.40167 .61192 m
.38905 .59941 L
s
1 .08 0 r
.8163 .36227 m .82512 .37421 L .8467 .36499 L p F P
0 0 0 r
s
1 .137 0 r
.82512 .37421 m .8163 .36227 L .79492 .37375 L p F P
0 0 0 r
s
.372 .62 .628 r
.76056 .6114 m
.78299 .60464 L
s
.76056 .6114 m
.75068 .59889 L
s
1 .38 0 r
.30335 .4065 m .29079 .38936 L .2719 .38804 L p F P
0 0 0 r
s
1 .318 0 r
.25905 .37198 m .2719 .38804 L .29079 .38936 L p F P
0 0 0 r
s
1 .186 0 r
.2719 .38804 m .25905 .37198 L .23998 .37487 L p F P
0 0 0 r
s
.372 .62 .628 r
.45593 .61088 m
.47711 .60412 L
s
.45593 .61088 m
.44372 .59836 L
s
.81507 .61036 m
.8056 .59783 L
s
.83774 .6036 m
.81507 .61036 L
s
0 1 .354 r
.59921 .55618 m .60889 .53031 L .62966 .51824 L p F P
0 0 0 r
s
0 1 .414 r
.60889 .53031 m .59921 .55618 L .57805 .56297 L p F P
0 0 0 r
s
.372 .62 .628 r
.51027 .60985 m
.53169 .60308 L
s
.51027 .60985 m
.49847 .59731 L
s
1 .698 0 r
.3344 .43193 m .32204 .41415 L .30335 .4065 L p F P
0 0 0 r
s
1 .615 0 r
.29079 .38936 m .30335 .4065 L .32204 .41415 L p F P
0 0 0 r
s
1 .148 0 r
.22681 .35976 m .23998 .37487 L .25905 .37198 L p F P
0 0 0 r
s
1 .082 0 r
.23998 .37487 m .22681 .35976 L .20763 .36511 L p F P
0 0 0 r
s
.372 .62 .628 r
.56467 .60881 m
.58633 .60203 L
s
.56467 .60881 m
.55328 .59625 L
s
1 .698 0 r
.72345 .41923 m .73231 .42011 L .75296 .40244 L p F P
0 0 0 r
s
1 .971 0 r
.73231 .42011 m .72345 .41923 L .70298 .44374 L p F P
0 0 0 r
s
1 .971 0 r
.70298 .44374 m .71181 .43981 L .73231 .42011 L p F P
0 0 0 r
s
0 1 .882 r
.52501 .57994 m .53617 .55565 L .55698 .56239 L p F P
0 0 0 r
s
0 1 .54 r
.53617 .55565 m .52501 .57994 L .5043 .56342 L p F P
0 0 0 r
s
1 .477 0 r
.74405 .39758 m .75296 .40244 L .77381 .38702 L p F P
0 0 0 r
s
1 .698 0 r
.75296 .40244 m .74405 .39758 L .72345 .41923 L p F P
0 0 0 r
s
.372 .62 .628 r
.61915 .60777 m
.64104 .60098 L
s
.61915 .60777 m
.60817 .5952 L
s
.3138 .60725 m
.33444 .60046 L
s
.3138 .60725 m
.30048 .59467 L
s
.67369 .60673 m
.69583 .59994 L
s
.67369 .60673 m
.66312 .59414 L
s
0 1 .182 r
.62031 .54198 m .62966 .51824 L .65034 .50166 L p F P
0 0 0 r
s
0 1 .354 r
.62966 .51824 m .62031 .54198 L .59921 .55618 L p F P
0 0 0 r
s
.372 .62 .628 r
.36817 .60621 m
.38905 .59941 L
s
.36817 .60621 m
.35525 .59361 L
s
1 .044 0 r
.83794 .35215 m .8467 .36499 L .86851 .35641 L p F P
0 0 0 r
s
1 .08 0 r
.8467 .36499 m .83794 .35215 L .8163 .36227 L p F P
0 0 0 r
s
1 .061 0 r
.19413 .35059 m .20763 .36511 L .22681 .35976 L p F P
0 0 0 r
s
1 .31 0 r
.76487 .37908 m .77381 .38702 L .79492 .37375 L p F P
0 0 0 r
s
1 .477 0 r
.77381 .38702 m .76487 .37908 L .74405 .39758 L p F P
0 0 0 r
s
.372 .62 .628 r
.7283 .60569 m
.75068 .59889 L
s
.7283 .60569 m
.71815 .59309 L
s
.077 1 0 r
.6709 .48197 m .66198 .49679 L .64125 .52152 L p F P
0 0 0 r
s
.077 1 0 r
.64125 .52152 m .65034 .50166 L .6709 .48197 L p F P
0 0 0 r
s
.372 .62 .628 r
.42261 .60517 m
.44372 .59836 L
s
.42261 .60517 m
.4101 .59256 L
s
0 1 .182 r
.65034 .50166 m .64125 .52152 L .62031 .54198 L p F P
0 0 0 r
s
.372 .62 .628 r
.78299 .60464 m
.8056 .59783 L
s
.78299 .60464 m
.77324 .59203 L
s
.841 1 0 r
.36527 .46459 m .35298 .44774 L .3344 .43193 L p F P
0 0 0 r
s
.926 1 0 r
.32204 .41415 m .3344 .43193 L .35298 .44774 L p F P
0 0 0 r
s
.372 .62 .628 r
.47711 .60412 m
.49847 .59731 L
s
.47711 .60412 m
.46502 .5915 L
s
.83774 .6036 m
.82841 .59097 L
s
.8606 .59678 m
.83774 .6036 L
s
.53169 .60308 m
.55328 .59625 L
s
1 .191 0 r
.78597 .36354 m .79492 .37375 L .8163 .36227 L p F P
0 0 0 r
s
1 .31 0 r
.79492 .37375 m .78597 .36354 L .76487 .37908 L p F P
0 0 0 r
s
.372 .62 .628 r
.58633 .60203 m
.60817 .5952 L
s
.27991 .60151 m
.30048 .59467 L
s
.27991 .60151 m
.26627 .58884 L
s
.64104 .60098 m
.66312 .59414 L
s
.64104 .60098 m
.63019 .58831 L
s
.33444 .60046 m
.35525 .59361 L
s
.33444 .60046 m
.32122 .58778 L
s
1 .318 0 r
.29079 .38936 m .27812 .37159 L .25905 .37198 L p F P
0 0 0 r
s
1 .253 0 r
.24604 .35573 m .25905 .37198 L .27812 .37159 L p F P
0 0 0 r
s
1 .148 0 r
.25905 .37198 m .24604 .35573 L .22681 .35976 L p F P
0 0 0 r
s
1 .044 0 r
.86851 .35641 m .85983 .34299 L .83794 .35215 L p F P
0 0 0 r
s
.372 .62 .628 r
.69583 .59994 m
.71815 .59309 L
s
.69583 .59994 m
.68538 .58724 L
s
1 .615 0 r
.32204 .41415 m .30965 .39476 L .29079 .38936 L p F P
0 0 0 r
s
1 .515 0 r
.27812 .37159 m .29079 .38936 L .30965 .39476 L p F P
0 0 0 r
s
.372 .62 .628 r
.38905 .59941 m
.4101 .59256 L
s
.38905 .59941 m
.37624 .58671 L
s
.75068 .59889 m
.77324 .59203 L
s
.75068 .59889 m
.74065 .58618 L
s
1 .111 0 r
.80737 .35048 m .8163 .36227 L .83794 .35215 L p F P
0 0 0 r
s
1 .191 0 r
.8163 .36227 m .80737 .35048 L .78597 .36354 L p F P
0 0 0 r
s
0 1 .182 r
.44021 .5385 m .4278 .53933 L .40868 .50977 L p F P
0 0 0 r
s
0 1 .354 r
.39629 .5022 m .40868 .50977 L .4278 .53933 L p F P
0 0 0 r
s
.372 .62 .628 r
.44372 .59836 m
.46502 .5915 L
s
.44372 .59836 m
.43133 .58564 L
s
1 .111 0 r
.21344 .34456 m .22681 .35976 L .24604 .35573 L p F P
0 0 0 r
s
1 .061 0 r
.22681 .35976 m .21344 .34456 L .19413 .35059 L p F P
0 0 0 r
s
.372 .62 .628 r
.8056 .59783 m
.82841 .59097 L
s
.8056 .59783 m
.79599 .58511 L
s
.49847 .59731 m
.52 .59044 L
s
.49847 .59731 m
.48649 .58458 L
s
.8606 .59678 m
.8514 .58404 L
s
.88364 .5899 m
.8606 .59678 L
s
0 .811 1 r
.49248 .58292 m .5043 .56342 L .52501 .57994 L p F P
0 0 0 r
s
0 1 .671 r
.5043 .56342 m .49248 .58292 L .47217 .55772 L p F P
0 0 0 r
s
.372 .62 .628 r
.60817 .5952 m
.63019 .58831 L
s
.926 1 0 r
.35298 .44774 m .34073 .42759 L .32204 .41415 L p F P
0 0 0 r
s
1 .946 0 r
.30965 .39476 m .32204 .41415 L .34073 .42759 L p F P
0 0 0 r
s
.372 .62 .628 r
.30048 .59467 m
.32122 .58778 L
s
.30048 .59467 m
.28695 .5819 L
s
0 .891 1 r
.54616 .59107 m .55698 .56239 L .57805 .56297 L p F P
0 0 0 r
s
.372 .62 .628 r
.57506 .58937 m
.58633 .60203 L
s
0 1 .882 r
.55698 .56239 m .54616 .59107 L .52501 .57994 L p F P
0 0 0 r
s
.372 .62 .628 r
.55328 .59625 m
.57506 .58937 L
s
.5475 .58989 m
.55328 .59625 L
s
.52 .59044 m
.53169 .60308 L
s
1 .044 0 r
.18042 .33596 m .19413 .35059 L .21344 .34456 L p F P
0 0 0 r
s
.372 .62 .628 r
.66312 .59414 m
.68538 .58724 L
s
.66312 .59414 m
.65239 .58136 L
s
.35525 .59361 m
.37624 .58671 L
s
.35525 .59361 m
.34214 .58083 L
s
1 .061 0 r
.82906 .33932 m .83794 .35215 L .85983 .34299 L p F P
0 0 0 r
s
1 .111 0 r
.83794 .35215 m .82906 .33932 L .80737 .35048 L p F P
0 0 0 r
s
.372 .62 .628 r
.71815 .59309 m
.74065 .58618 L
s
.71815 .59309 m
.70783 .58029 L
s
.4101 .59256 m
.43133 .58564 L
s
.4101 .59256 m
.3974 .57975 L
s
.77324 .59203 m
.79599 .58511 L
s
.77324 .59203 m
.76335 .57921 L
s
.46502 .5915 m
.48649 .58458 L
s
0 1 .54 r
.47217 .55772 m .45992 .56848 L .44021 .5385 L p F P
0 0 0 r
s
0 1 .882 r
.4278 .53933 m .44021 .5385 L .45992 .56848 L p F P
0 0 0 r
s
.372 .62 .628 r
.82841 .59097 m
.8514 .58404 L
s
.82841 .59097 m
.81893 .57814 L
s
1 .631 0 r
.73503 .39353 m .74405 .39758 L .76487 .37908 L p F P
0 0 0 r
s
1 .923 0 r
.74405 .39758 m .73503 .39353 L .71447 .41965 L p F P
0 0 0 r
s
1 .923 0 r
.71447 .41965 m .72345 .41923 L .74405 .39758 L p F P
0 0 0 r
s
1 .41 0 r
.75582 .37158 m .76487 .37908 L .78597 .36354 L p F P
0 0 0 r
s
1 .631 0 r
.76487 .37908 m .75582 .37158 L .73503 .39353 L p F P
0 0 0 r
s
.372 .62 .628 r
.52 .59044 m
.53553 .58548 L
s
.51145 .58118 m
.52 .59044 L
s
.88364 .5899 m
.87459 .57706 L
s
.90688 .58297 m
.88364 .5899 L
s
0 .811 1 r
.45992 .56848 m .47217 .55772 L .49248 .58292 L p F P
0 0 0 r
s
.372 .62 .628 r
.45273 .57868 m
.46502 .5915 L
s
1 .515 0 r
.30965 .39476 m .29717 .37448 L .27812 .37159 L p F P
0 0 0 r
s
1 .41 0 r
.26529 .35363 m .27812 .37159 L .29717 .37448 L p F P
0 0 0 r
s
1 .253 0 r
.27812 .37159 m .26529 .35363 L .24604 .35573 L p F P
0 0 0 r
s
1 .191 0 r
.23283 .33949 m .24604 .35573 L .26529 .35363 L p F P
0 0 0 r
s
1 .111 0 r
.24604 .35573 m .23283 .33949 L .21344 .34456 L p F P
0 0 0 r
s
.717 1 0 r
.72345 .41923 m .71447 .41965 L .69402 .44958 L p F P
0 0 0 r
s
.717 1 0 r
.69402 .44958 m .70298 .44374 L .72345 .41923 L p F P
0 0 0 r
s
.372 .62 .628 r
.26627 .58884 m
.28695 .5819 L
s
.26627 .58884 m
.25243 .57598 L
s
1 .253 0 r
.7769 .35353 m .78597 .36354 L .80737 .35048 L p F P
0 0 0 r
s
1 .41 0 r
.78597 .36354 m .7769 .35353 L .75582 .37158 L p F P
0 0 0 r
s
.372 .62 .628 r
.63019 .58831 m
.65239 .58136 L
s
.32122 .58778 m
.34214 .58083 L
s
.32122 .58778 m
.30779 .5749 L
s
1 .061 0 r
.85983 .34299 m .85103 .32947 L .82906 .33932 L p F P
0 0 0 r
s
.372 .62 .628 r
.68538 .58724 m
.70783 .58029 L
s
.68538 .58724 m
.67478 .57436 L
s
1 .08 0 r
.19986 .32935 m .21344 .34456 L .23283 .33949 L p F P
0 0 0 r
s
1 .044 0 r
.21344 .34456 m .19986 .32935 L .18042 .33596 L p F P
0 0 0 r
s
.372 .62 .628 r
.37624 .58671 m
.3974 .57975 L
s
.37624 .58671 m
.36323 .57382 L
s
.74065 .58618 m
.76335 .57921 L
s
.74065 .58618 m
.73047 .57327 L
s
1 .946 0 r
.34073 .42759 m .3285 .40508 L .30965 .39476 L p F P
0 0 0 r
s
1 .793 0 r
.29717 .37448 m .30965 .39476 L .3285 .40508 L p F P
0 0 0 r
s
.372 .62 .628 r
.43133 .58564 m
.45273 .57868 L
s
.43133 .58564 m
.41874 .57273 L
s
.79599 .58511 m
.81893 .57814 L
s
.79599 .58511 m
.78623 .57219 L
s
1 .148 0 r
.79832 .33873 m .80737 .35048 L .82906 .33932 L p F P
0 0 0 r
s
1 .253 0 r
.80737 .35048 m .79832 .33873 L .7769 .35353 L p F P
0 0 0 r
s
.43 1 0 r
.34073 .42759 m .35298 .44774 L .37166 .47062 L p F P
0 0 0 r
s
.372 .62 .628 r
.48649 .58458 m
.49213 .58276 L
s
.47951 .57717 m
.48649 .58458 L
s
.8514 .58404 m
.87459 .57706 L
s
.8514 .58404 m
.84207 .5711 L
s
0 .811 1 r
.56763 .59406 m .57805 .56297 L .59921 .55618 L p F P
0 0 0 r
s
.372 .62 .628 r
.57324 .58733 m
.57506 .58937 L
s
.59702 .58244 m
.60817 .5952 L
s
0 .891 1 r
.57805 .56297 m .56763 .59406 L .54616 .59107 L p F P
0 0 0 r
s
.372 .62 .628 r
.57506 .58937 m
.59702 .58244 L
s
.52997 .57056 m
.53622 .57745 L
s
.53622 .57745 m
.53643 .57769 L
s
0 1 .354 r
.4278 .53933 m .41532 .53387 L .39629 .5022 L p F P
0 0 0 r
s
.372 .62 .628 r
.90688 .58297 m
.89797 .57002 L
s
.93032 .57598 m
.90688 .58297 L
s
1 .029 0 r
.16649 .32124 m .18042 .33596 L .19986 .32935 L p F P
0 0 0 r
s
.372 .62 .628 r
.28695 .5819 m
.30779 .5749 L
s
.28695 .5819 m
.2732 .56893 L
s
.65239 .58136 m
.67478 .57436 L
s
.65239 .58136 m
.64149 .56838 L
s
.34214 .58083 m
.36323 .57382 L
s
.34214 .58083 m
.32882 .56784 L
s
1 .082 0 r
.82006 .32641 m .82906 .33932 L .85103 .32947 L p F P
0 0 0 r
s
1 .148 0 r
.82906 .33932 m .82006 .32641 L .79832 .33873 L p F P
0 0 0 r
s
.372 .62 .628 r
.70783 .58029 m
.73047 .57327 L
s
.70783 .58029 m
.69736 .56729 L
s
1 .41 0 r
.29717 .37448 m .28456 .35404 L .26529 .35363 L p F P
0 0 0 r
s
1 .31 0 r
.25227 .33582 m .26529 .35363 L .28456 .35404 L p F P
0 0 0 r
s
1 .191 0 r
.26529 .35363 m .25227 .33582 L .23283 .33949 L p F P
0 0 0 r
s
.372 .62 .628 r
.3974 .57975 m
.41874 .57273 L
s
.3974 .57975 m
.3845 .56675 L
s
.76335 .57921 m
.78623 .57219 L
s
.76335 .57921 m
.7533 .5662 L
s
.45273 .57868 m
.47013 .57301 L
s
1 .137 0 r
.21941 .32339 m .23283 .33949 L .25227 .33582 L p F P
0 0 0 r
s
1 .08 0 r
.23283 .33949 m .21941 .32339 L .19986 .32935 L p F P
0 0 0 r
s
.372 .62 .628 r
.81893 .57814 m
.84207 .5711 L
s
.81893 .57814 m
.80931 .56511 L
s
0 1 .54 r
.66198 .49679 m .65288 .51509 L .63194 .54563 L p F P
0 0 0 r
s
0 1 .54 r
.63194 .54563 m .64125 .52152 L .66198 .49679 L p F P
0 0 0 r
s
.372 .62 .628 r
.50951 .57715 m
.52997 .57056 L
s
.49608 .56456 m
.50758 .577 L
s
1 .793 0 r
.3285 .40508 m .31623 .38135 L .29717 .37448 L p F P
0 0 0 r
s
1 .631 0 r
.28456 .35404 m .29717 .37448 L .31623 .38135 L p F P
0 0 0 r
s
0 .891 1 r
.58921 .58725 m .59921 .55618 L .62031 .54198 L p F P
0 0 0 r
s
.372 .62 .628 r
.59449 .57955 m
.59702 .58244 L
s
.61916 .57544 m
.63019 .58831 L
s
0 .811 1 r
.59921 .55618 m .58921 .58725 L .56763 .59406 L p F P
0 0 0 r
s
.372 .62 .628 r
.59702 .58244 m
.61916 .57544 L
s
.87459 .57706 m
.89797 .57002 L
s
.87459 .57706 m
.8654 .56401 L
s
.55198 .56346 m
.56204 .57475 L
s
.56204 .57475 m
.5621 .57482 L
s
.43 1 0 r
.37166 .47062 m .3595 .44734 L .34073 .42759 L p F P
0 0 0 r
s
.616 1 0 r
.3285 .40508 m .34073 .42759 L .3595 .44734 L p F P
0 0 0 r
s
0 .381 1 r
.5134 .60543 m .52501 .57994 L .54616 .59107 L p F P
0 0 0 r
s
0 .811 1 r
.52501 .57994 m .5134 .60543 L .49248 .58292 L p F P
0 0 0 r
s
.372 .62 .628 r
.25243 .57598 m
.2732 .56893 L
s
.25243 .57598 m
.23837 .56292 L
s
.92156 .56292 m
.93032 .57598 L
s
0 1 .882 r
.64125 .52152 m .63194 .54563 L .6107 .57059 L p F P
0 0 0 r
s
0 1 .882 r
.6107 .57059 m .62031 .54198 L .64125 .52152 L p F P
0 0 0 r
s
1 .054 0 r
.18606 .31415 m .19986 .32935 L .21941 .32339 L p F P
0 0 0 r
s
1 .029 0 r
.19986 .32935 m .18606 .31415 L .16649 .32124 L p F P
0 0 0 r
s
1 .082 0 r
.85103 .32947 m .8421 .31581 L .82006 .32641 L p F P
0 0 0 r
s
.372 .62 .628 r
.30779 .5749 m
.32882 .56784 L
s
.30779 .5749 m
.29416 .56182 L
s
1 .515 0 r
.74658 .36397 m .75582 .37158 L .7769 .35353 L p F P
0 0 0 r
s
1 .793 0 r
.75582 .37158 m .74658 .36397 L .72581 .38945 L p F P
0 0 0 r
s
1 .793 0 r
.72581 .38945 m .73503 .39353 L .75582 .37158 L p F P
0 0 0 r
s
0 .891 1 r
.62031 .54198 m .6107 .57059 L .58921 .58725 L p F P
0 0 0 r
s
.372 .62 .628 r
.61284 .56807 m
.61916 .57544 L
s
.61916 .57544 m
.64149 .56838 L
s
.67478 .57436 m
.69736 .56729 L
s
.67478 .57436 m
.66401 .56127 L
s
1 .318 0 r
.76767 .34336 m .7769 .35353 L .79832 .33873 L p F P
0 0 0 r
s
1 .515 0 r
.7769 .35353 m .76767 .34336 L .74658 .36397 L p F P
0 0 0 r
s
.372 .62 .628 r
.36323 .57382 m
.3845 .56675 L
s
.36323 .57382 m
.35002 .56072 L
s
0 0 0 r
2 Mabswid
.57449 .57264 m
.5753 .57243 L
s
.372 .62 .628 r
.5 Mabswid
.73047 .57327 m
.7533 .5662 L
s
.73047 .57327 m
.72013 .56017 L
s
.841 1 0 r
.73503 .39353 m .72581 .38945 L .70526 .42017 L p F P
0 0 0 r
s
.841 1 0 r
.70526 .42017 m .71447 .41965 L .73503 .39353 L p F P
0 0 0 r
s
1 .002 0 r
.39361 1.05425 m .40598 1.06315 L .42658 1.05834 L p F P
0 0 0 r
s
.372 .62 .628 r
.78623 .57219 m
.80931 .56511 L
s
.78623 .57219 m
.77632 .55907 L
s
0 1 .882 r
.45992 .56848 m .44744 .57377 L .4278 .53933 L p F P
0 0 0 r
s
.372 .62 .628 r
.44786 .57359 m
.45273 .57868 L
s
0 .891 1 r
.41532 .53387 m .4278 .53933 L .44744 .57377 L p F P
0 0 0 r
s
.372 .62 .628 r
.44025 .56565 m
.44434 .56992 L
s
.41874 .57273 m
.43242 .56823 L
s
.43336 .56792 m
.44025 .56565 L
s
.40595 .55962 m
.41874 .57273 L
s
1 .186 0 r
.78911 .32679 m .79832 .33873 L .82006 .32641 L p F P
0 0 0 r
s
1 .318 0 r
.79832 .33873 m .78911 .32679 L .76767 .34336 L p F P
0 0 0 r
s
.372 .62 .628 r
.84207 .5711 m
.8654 .56401 L
s
.84207 .5711 m
.83259 .55796 L
s
.52997 .57056 m
.55198 .56346 L
s
.51804 .55741 m
.52997 .57056 L
s
1 .018 0 r
.15234 .30643 m .16649 .32124 L .18606 .31415 L p F P
0 0 0 r
s
.372 .62 .628 r
.89797 .57002 m
.92156 .56292 L
s
.89797 .57002 m
.88893 .55686 L
s
.57419 .55631 m
.58545 .56919 L
s
1 .31 0 r
.28456 .35404 m .27176 .33398 L .25227 .33582 L p F P
0 0 0 r
s
1 .223 0 r
.23903 .31838 m .25227 .33582 L .27176 .33398 L p F P
0 0 0 r
s
1 .137 0 r
.25227 .33582 m .23903 .31838 L .21941 .32339 L p F P
0 0 0 r
s
.389 1 0 r
.71447 .41965 m .70526 .42017 L .6848 .45572 L p F P
0 0 0 r
s
.389 1 0 r
.6848 .45572 m .69402 .44958 L .71447 .41965 L p F P
0 0 0 r
s
.372 .62 .628 r
.2732 .56893 m
.29416 .56182 L
s
.2732 .56893 m
.25925 .55575 L
s
.616 1 0 r
.3595 .44734 m .34742 .42074 L .3285 .40508 L p F P
0 0 0 r
s
.841 1 0 r
.31623 .38135 m .3285 .40508 L .34742 .42074 L p F P
0 0 0 r
s
.372 .62 .628 r
.64149 .56838 m
.66401 .56127 L
s
.63041 .5552 m
.64149 .56838 L
s
1 .631 0 r
.31623 .38135 m .30386 .35749 L .28456 .35404 L p F P
0 0 0 r
s
1 .477 0 r
.27176 .33398 m .28456 .35404 L .30386 .35749 L p F P
0 0 0 r
s
2 Mabswid
.59563 .56594 m
.59655 .56559 L
s
.372 .62 .628 r
.5 Mabswid
.32882 .56784 m
.35002 .56072 L
s
.32882 .56784 m
.31528 .55465 L
s
.69736 .56729 m
.72013 .56017 L
s
.69736 .56729 m
.68672 .55409 L
s
1 .093 0 r
.20575 .30746 m .21941 .32339 L .23903 .31838 L p F P
0 0 0 r
s
1 .054 0 r
.21941 .32339 m .20575 .30746 L .18606 .31415 L p F P
0 0 0 r
s
1 .103 0 r
.81091 .3133 m .82006 .32641 L .8421 .31581 L p F P
0 0 0 r
s
1 .186 0 r
.82006 .32641 m .81091 .3133 L .78911 .32679 L p F P
0 0 0 r
s
.372 .62 .628 r
.3845 .56675 m
.40595 .55962 L
s
.3845 .56675 m
.3714 .55354 L
s
.7533 .5662 m
.77632 .55907 L
s
.7533 .5662 m
.74309 .55298 L
s
1 .005 0 r
.41432 1.04937 m .42658 1.05834 L .44735 1.0535 L p F P
0 0 0 r
s
1 .002 0 r
.42658 1.05834 m .41432 1.04937 L .39361 1.05425 L p F P
0 0 0 r
s
0 .194 1 r
.48028 .5997 m .49248 .58292 L .5134 .60543 L p F P
0 0 0 r
s
0 .811 1 r
.49248 .58292 m .48028 .5997 L .45992 .56848 L p F P
0 0 0 r
s
.372 .62 .628 r
.47305 .5703 m
.47354 .57082 L
s
.47532 .57132 m
.47604 .57109 L
s
.45003 .56244 m
.46196 .55852 L
s
.44025 .56565 m
.44077 .56548 L
s
.43293 .55801 m
.44025 .56565 L
s
.80931 .56511 m
.83259 .55796 L
s
.80931 .56511 m
.79954 .55187 L
s
0 .381 1 r
.44744 .57377 m .45992 .56848 L .48028 .5997 L p F P
0 0 0 r
s
.372 .62 .628 r
.47604 .57109 m
.49608 .56456 L
s
.46196 .55852 m
.47305 .5703 L
s
.49608 .56456 m
.51804 .55741 L
s
.49608 .56456 m
.48384 .55132 L
s
.8654 .56401 m
.88893 .55686 L
s
.8654 .56401 m
.85606 .55076 L
s
.55198 .56346 m
.57419 .55631 L
s
.54018 .5502 m
.55198 .56346 L
s
0 1 .127 r
.69402 .44958 m .6848 .45572 L .66426 .49464 L p F P
0 0 0 r
s
0 1 .127 r
.66426 .49464 m .67353 .48211 L .69402 .44958 L p F P
0 0 0 r
s
1 .034 0 r
.17204 .29894 m .18606 .31415 L .20575 .30746 L p F P
0 0 0 r
s
1 .018 0 r
.18606 .31415 m .17204 .29894 L .15234 .30643 L p F P
0 0 0 r
s
.372 .62 .628 r
.91265 .54965 m
.92156 .56292 L
s
.23837 .56292 m
.25925 .55575 L
s
.23837 .56292 m
.22408 .54965 L
s
.62133 .5581 m
.63041 .5552 L
s
.59658 .54909 m
.60671 .56091 L
s
.841 1 0 r
.34742 .42074 m .33537 .39249 L .31623 .38135 L p F P
0 0 0 r
s
1 .923 0 r
.30386 .35749 m .31623 .38135 L .33537 .39249 L p F P
0 0 0 r
s
1 .103 0 r
.8421 .31581 m .83304 .30195 L .81091 .3133 L p F P
0 0 0 r
s
.372 .62 .628 r
.29416 .56182 m
.31528 .55465 L
s
.29416 .56182 m
.2803 .54853 L
s
.66401 .56127 m
.68672 .55409 L
s
.66401 .56127 m
.65306 .54797 L
s
.35002 .56072 m
.3714 .55354 L
s
.35002 .56072 m
.33659 .54741 L
s
1 .005 0 r
.38105 1.04521 m .39361 1.05425 L .41432 1.04937 L p F P
0 0 0 r
s
.372 .62 .628 r
.72013 .56017 m
.74309 .55298 L
s
.72013 .56017 m
.70962 .54686 L
s
0 .096 1 r
.53487 .62125 m .54616 .59107 L .56763 .59406 L p F P
0 0 0 r
s
0 .381 1 r
.54616 .59107 m .53487 .62125 L .5134 .60543 L p F P
0 0 0 r
s
.372 .62 .628 r
.39296 .5463 m
.40595 .55962 L
s
0 0 0 r
2 Mabswid
.43745 .55656 m
.43813 .55694 L
s
.5 Mabswid
1 .011 0 r
.43519 1.04445 m .44735 1.0535 L .46829 1.04862 L p F P
0 0 0 r
s
1 .005 0 r
.44735 1.0535 m .43519 1.04445 L .41432 1.04937 L p F P
0 0 0 r
s
1 .477 0 r
.30386 .35749 m .29131 .33433 L .27176 .33398 L p F P
0 0 0 r
s
1 .343 0 r
.25874 .31463 m .27176 .33398 L .29131 .33433 L p F P
0 0 0 r
s
1 .223 0 r
.27176 .33398 m .25874 .31463 L .23903 .31838 L p F P
0 0 0 r
s
.372 .62 .628 r
.77632 .55907 m
.79954 .55187 L
s
.77632 .55907 m
.76625 .54574 L
s
1 .38 0 r
.75824 .33259 m .76767 .34336 L .78911 .32679 L p F P
0 0 0 r
s
1 .615 0 r
.76767 .34336 m .75824 .33259 L .73712 .35554 L p F P
0 0 0 r
s
1 .615 0 r
.73712 .35554 m .74658 .36397 L .76767 .34336 L p F P
0 0 0 r
s
1 .152 0 r
.22555 .30139 m .23903 .31838 L .25874 .31463 L p F P
0 0 0 r
s
1 .093 0 r
.23903 .31838 m .22555 .30139 L .20575 .30746 L p F P
0 0 0 r
s
.372 .62 .628 r
.46196 .55852 m
.48384 .55132 L
s
.4494 .54518 m
.46196 .55852 L
s
1 .946 0 r
.74658 .36397 m .73712 .35554 L .71632 .38425 L p F P
0 0 0 r
s
1 .946 0 r
.71632 .38425 m .72581 .38945 L .74658 .36397 L p F P
0 0 0 r
s
.372 .62 .628 r
.83259 .55796 m
.85606 .55076 L
s
.83259 .55796 m
.82295 .54462 L
s
1 .011 0 r
.13797 .29149 m .15234 .30643 L .17204 .29894 L p F P
0 0 0 r
s
.372 .62 .628 r
.51804 .55741 m
.54018 .5502 L
s
.51804 .55741 m
.50592 .54406 L
s
1 .222 0 r
.77973 .3144 m .78911 .32679 L .81091 .3133 L p F P
0 0 0 r
s
1 .38 0 r
.78911 .32679 m .77973 .3144 L .75824 .33259 L p F P
0 0 0 r
s
.372 .62 .628 r
.88893 .55686 m
.91265 .54965 L
s
.88893 .55686 m
.87973 .54349 L
s
.57419 .55631 m
.59658 .54909 L
s
.5625 .54293 m
.57419 .55631 L
s
0 0 0 r
2 Mabswid
.61899 .55424 m
.62251 .55198 L
s
.372 .62 .628 r
.5 Mabswid
.25925 .55575 m
.2803 .54853 L
s
.25925 .55575 m
.24507 .54237 L
s
1 .06 0 r
.19186 .29169 m .20575 .30746 L .22555 .30139 L p F P
0 0 0 r
s
1 .034 0 r
.20575 .30746 m .19186 .29169 L .17204 .29894 L p F P
0 0 0 r
s
.372 .62 .628 r
.62713 .55129 m
.62727 .55145 L
s
.62727 .55145 m
.63041 .5552 L
s
0 .891 1 r
.44744 .57377 m .43487 .57078 L .41532 .53387 L p F P
0 0 0 r
s
.372 .62 .628 r
.40595 .55962 m
.42067 .55473 L
s
1 .923 0 r
.33537 .39249 m .32325 .36418 L .30386 .35749 L p F P
0 0 0 r
s
1 .698 0 r
.29131 .33433 m .30386 .35749 L .32325 .36418 L p F P
0 0 0 r
s
.372 .62 .628 r
.31528 .55465 m
.33659 .54741 L
s
.31528 .55465 m
.30154 .54125 L
s
.616 1 0 r
.72581 .38945 m .71632 .38425 L .69574 .41919 L p F P
0 0 0 r
s
.616 1 0 r
.69574 .41919 m .70526 .42017 L .72581 .38945 L p F P
0 0 0 r
s
.372 .62 .628 r
.68672 .55409 m
.70962 .54686 L
s
.68672 .55409 m
.67591 .54068 L
s
0 1 .182 r
.3906 .50021 m .3785 .47306 L .3595 .44734 L p F P
0 0 0 r
s
.077 1 0 r
.34742 .42074 m .3595 .44734 L .3785 .47306 L p F P
0 0 0 r
s
1 .123 0 r
.8016 .29983 m .81091 .3133 L .83304 .30195 L p F P
0 0 0 r
s
1 .222 0 r
.81091 .3133 m .8016 .29983 L .77973 .3144 L p F P
0 0 0 r
s
.372 .62 .628 r
.3714 .55354 m
.39296 .5463 L
s
.3714 .55354 m
.35809 .54012 L
s
1 .011 0 r
.40187 1.04026 m .41432 1.04937 L .43519 1.04445 L p F P
0 0 0 r
s
1 .005 0 r
.41432 1.04937 m .40187 1.04026 L .38105 1.04521 L p F P
0 0 0 r
s
.372 .62 .628 r
.74309 .55298 m
.76625 .54574 L
s
.74309 .55298 m
.73272 .53956 L
s
.43055 .55144 m
.4494 .54518 L
s
.43043 .55148 m
.43055 .55144 L
s
1 .018 0 r
.45624 1.0395 m .46829 1.04862 L .4894 1.04369 L p F P
0 0 0 r
s
1 .011 0 r
.46829 1.04862 m .45624 1.0395 L .43519 1.04445 L p F P
0 0 0 r
s
.372 .62 .628 r
.79954 .55187 m
.82295 .54462 L
s
.79954 .55187 m
.78961 .53843 L
s
.48384 .55132 m
.50592 .54406 L
s
.48384 .55132 m
.47141 .53786 L
s
.85606 .55076 m
.87973 .54349 L
s
.85606 .55076 m
.84657 .5373 L
s
1 .02 0 r
.15777 .2837 m .17204 .29894 L .19186 .29169 L p F P
0 0 0 r
s
1 .011 0 r
.17204 .29894 m .15777 .2837 L .13797 .29149 L p F P
0 0 0 r
s
.372 .62 .628 r
.54018 .5502 m
.5625 .54293 L
s
.54018 .5502 m
.52818 .53673 L
s
.22408 .54965 m
.24507 .54237 L
s
.22408 .54965 m
.20957 .53617 L
s
.90361 .53617 m
.91265 .54965 L
s
1 .343 0 r
.29131 .33433 m .27852 .31238 L .25874 .31463 L p F P
0 0 0 r
s
1 .234 0 r
.24545 .29612 m .25874 .31463 L .27852 .31238 L p F P
0 0 0 r
s
1 .152 0 r
.25874 .31463 m .24545 .29612 L .22555 .30139 L p F P
0 0 0 r
s
.372 .62 .628 r
.58503 .5356 m
.59658 .54909 L
s
1 .123 0 r
.83304 .30195 m .82382 .28778 L .8016 .29983 L p F P
0 0 0 r
s
.077 1 0 r
.3785 .47306 m .36656 .4414 L .34742 .42074 L p F P
0 0 0 r
s
.389 1 0 r
.33537 .39249 m .34742 .42074 L .36656 .4414 L p F P
0 0 0 r
s
.372 .62 .628 r
.2803 .54853 m
.30154 .54125 L
s
.2803 .54853 m
.26623 .53503 L
s
.077 1 0 r
.70526 .42017 m .69574 .41919 L .67522 .45994 L p F P
0 0 0 r
s
.077 1 0 r
.67522 .45994 m .6848 .45572 L .70526 .42017 L p F P
0 0 0 r
s
0 .811 1 r
.65288 .51509 m .64345 .53426 L .62227 .57096 L p F P
0 0 0 r
s
.372 .62 .628 r
.63041 .5552 m
.631 .55501 L
s
0 .811 1 r
.62227 .57096 m .63194 .54563 L .65288 .51509 L p F P
0 0 0 r
s
.372 .62 .628 r
.63158 .55483 m
.65306 .54797 L
s
.65306 .54797 m
.67591 .54068 L
s
.64195 .53447 m
.64201 .53455 L
s
.64276 .53546 m
.64295 .53568 L
s
.64295 .53568 m
.65306 .54797 L
s
.004 0 1 r
.55674 .62682 m .56763 .59406 L .58921 .58725 L p F P
0 0 0 r
s
0 .096 1 r
.56763 .59406 m .55674 .62682 L .53487 .62125 L p F P
0 0 0 r
s
.372 .62 .628 r
.33659 .54741 m
.35809 .54012 L
s
.33659 .54741 m
.32296 .5339 L
s
1 .011 0 r
.36831 1.03604 m .38105 1.04521 L .40187 1.04026 L p F P
0 0 0 r
s
1 .698 0 r
.32325 .36418 m .31096 .33702 L .29131 .33433 L p F P
0 0 0 r
s
1 .502 0 r
.27852 .31238 m .29131 .33433 L .31096 .33702 L p F P
0 0 0 r
s
1 .098 0 r
.21181 .2848 m .22555 .30139 L .24545 .29612 L p F P
0 0 0 r
s
1 .06 0 r
.22555 .30139 m .21181 .2848 L .19186 .29169 L p F P
0 0 0 r
s
.372 .62 .628 r
.70962 .54686 m
.73272 .53956 L
s
.70962 .54686 m
.69895 .53333 L
s
1 .02 0 r
.42285 1.03527 m .43519 1.04445 L .45624 1.0395 L p F P
0 0 0 r
s
1 .011 0 r
.43519 1.04445 m .42285 1.03527 L .40187 1.04026 L p F P
0 0 0 r
s
.372 .62 .628 r
.39296 .5463 m
.41241 .53976 L
s
.76625 .54574 m
.78961 .53843 L
s
.76625 .54574 m
.75602 .53219 L
s
1 .029 0 r
.47746 1.0345 m .4894 1.04369 L .51068 1.03873 L p F P
0 0 0 r
s
1 .018 0 r
.4894 1.04369 m .47746 1.0345 L .45624 1.0395 L p F P
0 0 0 r
s
.372 .62 .628 r
.4494 .54518 m
.47141 .53786 L
s
.43665 .53163 m
.4494 .54518 L
s
1 .005 0 r
.12337 .2764 m .13797 .29149 L .15777 .2837 L p F P
0 0 0 r
s
.372 .62 .628 r
.82295 .54462 m
.84657 .5373 L
s
.82295 .54462 m
.81317 .53106 L
s
.389 1 0 r
.36656 .4414 m .3547 .4076 L .33537 .39249 L p F P
0 0 0 r
s
.717 1 0 r
.32325 .36418 m .33537 .39249 L .3547 .4076 L p F P
0 0 0 r
s
.372 .62 .628 r
.50592 .54406 m
.52818 .53673 L
s
.50592 .54406 m
.4936 .53049 L
s
1 .431 0 r
.74857 .32073 m .75824 .33259 L .77973 .3144 L p F P
0 0 0 r
s
1 .698 0 r
.75824 .33259 m .74857 .32073 L .72737 .34552 L p F P
0 0 0 r
s
1 .698 0 r
.72737 .34552 m .73712 .35554 L .75824 .33259 L p F P
0 0 0 r
s
.372 .62 .628 r
.87973 .54349 m
.90361 .53617 L
s
.87973 .54349 m
.87039 .52992 L
s
1 .036 0 r
.17772 .27602 m .19186 .29169 L .21181 .2848 L p F P
0 0 0 r
s
1 .02 0 r
.19186 .29169 m .17772 .27602 L .15777 .2837 L p F P
0 0 0 r
s
1 .253 0 r
.77014 .30127 m .77973 .3144 L .8016 .29983 L p F P
0 0 0 r
s
1 .431 0 r
.77973 .3144 m .77014 .30127 L .74857 .32073 L p F P
0 0 0 r
s
.319 0 1 r
.50135 .62786 m .5134 .60543 L .53487 .62125 L p F P
0 0 0 r
s
0 .194 1 r
.5134 .60543 m .50135 .62786 L .48028 .5997 L p F P
0 0 0 r
s
.372 .62 .628 r
.5625 .54293 m
.58503 .5356 L
s
.5625 .54293 m
.55063 .52935 L
s
.24507 .54237 m
.26623 .53503 L
s
.24507 .54237 m
.23066 .52878 L
s
0 .381 1 r
.48028 .5997 m .46779 .60972 L .44744 .57377 L p F P
0 0 0 r
s
0 .096 1 r
.43487 .57078 m .44744 .57377 L .46779 .60972 L p F P
0 0 0 r
s
.926 1 0 r
.73712 .35554 m .72737 .34552 L .70649 .37675 L p F P
0 0 0 r
s
.926 1 0 r
.70649 .37675 m .71632 .38425 L .73712 .35554 L p F P
0 0 0 r
s
0 .381 1 r
.63194 .54563 m .62227 .57096 L .60067 .6007 L p F P
0 0 0 r
s
0 .381 1 r
.60067 .6007 m .6107 .57059 L .63194 .54563 L p F P
0 0 0 r
s
.372 .62 .628 r
.59658 .54909 m
.61917 .54181 L
s
.61917 .54181 m
.62534 .54916 L
s
.62534 .54916 m
.62564 .54951 L
s
.61917 .54181 m
.64195 .53447 L
s
.60774 .5282 m
.61917 .54181 L
s
.30154 .54125 m
.32296 .5339 L
s
.30154 .54125 m
.28758 .52763 L
s
.67591 .54068 m
.69895 .53333 L
s
.66492 .52706 m
.67591 .54068 L
s
0 .096 1 r
.57876 .62 m .58921 .58725 L .6107 .57059 L p F P
0 0 0 r
s
.004 0 1 r
.58921 .58725 m .57876 .62 L .55674 .62682 L p F P
0 0 0 r
s
1 .02 0 r
.38923 1.03101 m .40187 1.04026 L .42285 1.03527 L p F P
0 0 0 r
s
1 .011 0 r
.40187 1.04026 m .38923 1.03101 L .36831 1.03604 L p F P
0 0 0 r
s
.372 .62 .628 r
.35809 .54012 m
.37977 .53276 L
s
.35809 .54012 m
.34456 .52649 L
s
1 .14 0 r
.79211 .28585 m .8016 .29983 L .82382 .28778 L p F P
0 0 0 r
s
1 .253 0 r
.8016 .29983 m .79211 .28585 L .77014 .30127 L p F P
0 0 0 r
s
.372 .62 .628 r
.73272 .53956 m
.75602 .53219 L
s
.73272 .53956 m
.72218 .52592 L
s
.717 1 0 r
.3547 .4076 m .34281 .37385 L .32325 .36418 L p F P
0 0 0 r
s
1 .971 0 r
.31096 .33702 m .32325 .36418 L .34281 .37385 L p F P
0 0 0 r
s
1 .034 0 r
.44401 1.03023 m .45624 1.0395 L .47746 1.0345 L p F P
0 0 0 r
s
1 .02 0 r
.45624 1.0395 m .44401 1.03023 L .42285 1.03527 L p F P
0 0 0 r
s
0 1 .54 r
.6848 .45572 m .67522 .45994 L .65455 .50481 L p F P
0 0 0 r
s
0 1 .54 r
.65455 .50481 m .66426 .49464 L .6848 .45572 L p F P
0 0 0 r
s
0 .096 1 r
.6107 .57059 m .60067 .6007 L .57876 .62 L p F P
0 0 0 r
s
1 .502 0 r
.31096 .33702 m .29842 .31173 L .27852 .31238 L p F P
0 0 0 r
s
1 .343 0 r
.26546 .29183 m .27852 .31238 L .29842 .31173 L p F P
0 0 0 r
s
1 .234 0 r
.27852 .31238 m .26546 .29183 L .24545 .29612 L p F P
0 0 0 r
s
1 .152 0 r
.23189 .2784 m .24545 .29612 L .26546 .29183 L p F P
0 0 0 r
s
1 .098 0 r
.24545 .29612 m .23189 .2784 L .21181 .2848 L p F P
0 0 0 r
s
.372 .62 .628 r
.78961 .53843 m
.81317 .53106 L
s
.78961 .53843 m
.77952 .52477 L
s
1 .044 0 r
.49886 1.02946 m .51068 1.03873 L .53215 1.03372 L p F P
0 0 0 r
s
1 .029 0 r
.51068 1.03873 m .49886 1.02946 L .47746 1.0345 L p F P
0 0 0 r
s
1 .011 0 r
.14328 .26837 m .15777 .2837 L .17772 .27602 L p F P
0 0 0 r
s
1 .005 0 r
.15777 .2837 m .14328 .26837 L .12337 .2764 L p F P
0 0 0 r
s
.372 .62 .628 r
.47141 .53786 m
.4936 .53049 L
s
.47141 .53786 m
.45877 .52419 L
s
.84657 .5373 m
.87039 .52992 L
s
.84657 .5373 m
.83693 .52362 L
s
.319 0 1 r
.46779 .60972 m .48028 .5997 L .50135 .62786 L p F P
0 0 0 r
s
.372 .62 .628 r
.52818 .53673 m
.55063 .52935 L
s
.52818 .53673 m
.51599 .52305 L
s
.43 1 0 r
.71632 .38425 m .70649 .37675 L .68582 .415 L p F P
0 0 0 r
s
.43 1 0 r
.68582 .415 m .69574 .41919 L .71632 .38425 L p F P
0 0 0 r
s
.372 .62 .628 r
.20957 .53617 m
.23066 .52878 L
s
.20957 .53617 m
.19483 .52247 L
s
.89442 .52247 m
.90361 .53617 L
s
.58503 .5356 m
.60774 .5282 L
s
.58503 .5356 m
.57328 .5219 L
s
1 .14 0 r
.82382 .28778 m .81443 .27323 L .79211 .28585 L p F P
0 0 0 r
s
1 .06 0 r
.19781 .26854 m .21181 .2848 L .23189 .2784 L p F P
0 0 0 r
s
1 .036 0 r
.21181 .2848 m .19781 .26854 L .17772 .27602 L p F P
0 0 0 r
s
.372 .62 .628 r
.26623 .53503 m
.28758 .52763 L
s
.26623 .53503 m
.25193 .52132 L
s
0 0 0 r
2 Mabswid
.6418 .53477 m
.64356 .53242 L
s
.372 .62 .628 r
.5 Mabswid
.64195 .53447 m
.64217 .5344 L
s
.64365 .53392 m
.64583 .53322 L
s
1 .018 0 r
.35537 1.02672 m .36831 1.03604 L .38923 1.03101 L p F P
0 0 0 r
s
1 .971 0 r
.34281 .37385 m .33077 .34183 L .31096 .33702 L p F P
0 0 0 r
s
1 .698 0 r
.29842 .31173 m .31096 .33702 L .33077 .34183 L p F P
0 0 0 r
s
.372 .62 .628 r
.32296 .5339 m
.34456 .52649 L
s
.32296 .5339 m
.30911 .52017 L
s
0 .891 1 r
.42237 .55781 m .41004 .53475 L .3906 .50021 L p F P
0 0 0 r
s
.372 .62 .628 r
.40772 .53169 m
.4083 .53231 L
s
.41518 .53884 m
.43665 .53163 L
s
.37977 .53276 m
.39296 .5463 L
s
1 .036 0 r
.41032 1.02594 m .42285 1.03527 L .44401 1.03023 L p F P
0 0 0 r
s
1 .02 0 r
.42285 1.03527 m .41032 1.02594 L .38923 1.03101 L p F P
0 0 0 r
s
.372 .62 .628 r
.69895 .53333 m
.72218 .52592 L
s
.69895 .53333 m
.6881 .51959 L
s
1 .054 0 r
.46535 1.02516 m .47746 1.0345 L .49886 1.02946 L p F P
0 0 0 r
s
1 .034 0 r
.47746 1.0345 m .46535 1.02516 L .44401 1.03023 L p F P
0 0 0 r
s
.372 .62 .628 r
.75602 .53219 m
.77952 .52477 L
s
.75602 .53219 m
.74563 .51843 L
s
1 .002 0 r
.10854 .26114 m .12337 .2764 L .14328 .26837 L p F P
0 0 0 r
s
.372 .62 .628 r
.43665 .53163 m
.45877 .52419 L
s
.42369 .51786 m
.43665 .53163 L
s
1 .061 0 r
.52044 1.02437 m .53215 1.03372 L .55379 1.02868 L p F P
0 0 0 r
s
1 .044 0 r
.53215 1.03372 m .52044 1.02437 L .49886 1.02946 L p F P
0 0 0 r
s
.372 .62 .628 r
.81317 .53106 m
.83693 .52362 L
s
.81317 .53106 m
.80323 .51728 L
s
1 .02 0 r
.16334 .26037 m .17772 .27602 L .19781 .26854 L p F P
0 0 0 r
s
1 .011 0 r
.17772 .27602 m .16334 .26037 L .14328 .26837 L p F P
0 0 0 r
s
.372 .62 .628 r
.4936 .53049 m
.51599 .52305 L
s
.4936 .53049 m
.48109 .5167 L
s
.87039 .52992 m
.89442 .52247 L
s
.87039 .52992 m
.8609 .51612 L
s
.55063 .52935 m
.57328 .5219 L
s
.55063 .52935 m
.53857 .51554 L
s
1 .343 0 r
.29842 .31173 m .28559 .28856 L .26546 .29183 L p F P
0 0 0 r
s
1 .223 0 r
.25209 .27258 m .26546 .29183 L .28559 .28856 L p F P
0 0 0 r
s
1 .152 0 r
.26546 .29183 m .25209 .27258 L .23189 .2784 L p F P
0 0 0 r
s
1 .465 0 r
.73863 .30738 m .74857 .32073 L .77014 .30127 L p F P
0 0 0 r
s
1 .753 0 r
.74857 .32073 m .73863 .30738 L .7173 .33324 L p F P
0 0 0 r
s
1 .753 0 r
.7173 .33324 m .72737 .34552 L .74857 .32073 L p F P
0 0 0 r
s
1 .273 0 r
.76033 .28716 m .77014 .30127 L .79211 .28585 L p F P
0 0 0 r
s
1 .465 0 r
.77014 .30127 m .76033 .28716 L .73863 .30738 L p F P
0 0 0 r
s
.372 .62 .628 r
.23066 .52878 m
.25193 .52132 L
s
.23066 .52878 m
.21602 .51496 L
s
.60774 .5282 m
.63065 .52074 L
s
.60774 .5282 m
.59613 .51438 L
s
0 1 .882 r
.41004 .53475 m .39795 .50312 L .3785 .47306 L p F P
0 0 0 r
s
.372 .62 .628 r
.36636 .51901 m
.37977 .53276 L
s
.37977 .53276 m
.40052 .52572 L
s
.40052 .52572 m
.40163 .52534 L
s
0 0 0 r
2 Mabswid
.40554 .52751 m
.40607 .52827 L
s
.40515 .52696 m
.40554 .52751 L
s
.372 .62 .628 r
.5 Mabswid
.40163 .52534 m
.40413 .52795 L
s
.40413 .52795 m
.40772 .53169 L
s
0 1 .54 r
.36656 .4414 m .3785 .47306 L .39795 .50312 L p F P
0 0 0 r
s
0 .811 1 r
.66426 .49464 m .65455 .50481 L .63355 .55068 L p F P
0 0 0 r
s
.372 .62 .628 r
.64583 .53322 m
.65064 .53166 L
s
0 .811 1 r
.63355 .55068 m .64345 .53426 L .66426 .49464 L p F P
0 0 0 r
s
.372 .62 .628 r
.65064 .53166 m
.66492 .52706 L
s
.63065 .52074 m
.64132 .53371 L
s
0 0 0 r
2 Mabswid
.6497 .52305 m
.65 .52255 L
s
.372 .62 .628 r
.5 Mabswid
.28758 .52763 m
.30911 .52017 L
s
.28758 .52763 m
.27339 .5138 L
s
0 1 .182 r
.69574 .41919 m .68582 .415 L .66516 .45984 L p F P
0 0 0 r
s
0 1 .182 r
.66516 .45984 m .67522 .45994 L .69574 .41919 L p F P
0 0 0 r
s
1 .034 0 r
.37639 1.02162 m .38923 1.03101 L .41032 1.02594 L p F P
0 0 0 r
s
1 .018 0 r
.38923 1.03101 m .37639 1.02162 L .35537 1.02672 L p F P
0 0 0 r
s
1 .698 0 r
.33077 .34183 m .31849 .31251 L .29842 .31173 L p F P
0 0 0 r
s
1 .477 0 r
.28559 .28856 m .29842 .31173 L .31849 .31251 L p F P
0 0 0 r
s
1 .093 0 r
.21805 .26131 m .23189 .2784 L .25209 .27258 L p F P
0 0 0 r
s
1 .06 0 r
.23189 .2784 m .21805 .26131 L .19781 .26854 L p F P
0 0 0 r
s
.372 .62 .628 r
.66492 .52706 m
.6881 .51959 L
s
.65394 .51343 m
.65567 .51558 L
s
.65387 .51335 m
.65394 .51343 L
s
.65567 .51558 m
.66492 .52706 L
s
0 0 0 r
2 Mabswid
.40165 .52057 m
.40211 .52141 L
s
.40211 .52141 m
.40515 .52696 L
s
.372 .62 .628 r
.5 Mabswid
.34456 .52649 m
.36636 .51901 L
s
.34456 .52649 m
.33083 .51264 L
s
1 .152 0 r
.78242 .2712 m .79211 .28585 L .81443 .27323 L p F P
0 0 0 r
s
1 .273 0 r
.79211 .28585 m .78242 .2712 L .76033 .28716 L p F P
0 0 0 r
s
1 .06 0 r
.43159 1.02083 m .44401 1.03023 L .46535 1.02516 L p F P
0 0 0 r
s
1 .036 0 r
.44401 1.03023 m .43159 1.02083 L .41032 1.02594 L p F P
0 0 0 r
s
.841 1 0 r
.72737 .34552 m .7173 .33324 L .69627 .36593 L p F P
0 0 0 r
s
.841 1 0 r
.69627 .36593 m .70649 .37675 L .72737 .34552 L p F P
0 0 0 r
s
.372 .62 .628 r
.72218 .52592 m
.74563 .51843 L
s
.72218 .52592 m
.71148 .51205 L
s
.40589 .5239 m
.42369 .51786 L
s
.4021 .52518 m
.40302 .52487 L
s
.40302 .52487 m
.404 .52454 L
s
.404 .52454 m
.40402 .52453 L
s
.40163 .52534 m
.4021 .52518 L
s
.38834 .51147 m
.40023 .52388 L
s
.40023 .52388 m
.40163 .52534 L
s
0 1 .54 r
.39795 .50312 m .38609 .46564 L .36656 .4414 L p F P
0 0 0 r
s
0 1 .127 r
.3547 .4076 m .36656 .4414 L .38609 .46564 L p F P
0 0 0 r
s
1 .08 0 r
.48686 1.02004 m .49886 1.02946 L .52044 1.02437 L p F P
0 0 0 r
s
1 .054 0 r
.49886 1.02946 m .48686 1.02004 L .46535 1.02516 L p F P
0 0 0 r
s
1 .005 0 r
.12855 .25291 m .14328 .26837 L .16334 .26037 L p F P
0 0 0 r
s
1 .002 0 r
.14328 .26837 m .12855 .25291 L .10854 .26114 L p F P
0 0 0 r
s
.372 .62 .628 r
.77952 .52477 m
.80323 .51728 L
s
.77952 .52477 m
.76927 .51089 L
s
.45877 .52419 m
.48109 .5167 L
s
.45877 .52419 m
.44593 .51031 L
s
1 .082 0 r
.5422 1.01925 m .55379 1.02868 L .57561 1.02359 L p F P
0 0 0 r
s
1 .061 0 r
.55379 1.02868 m .5422 1.01925 L .52044 1.02437 L p F P
0 0 0 r
s
0 1 .127 r
.38609 .46564 m .37438 .42548 L .3547 .4076 L p F P
0 0 0 r
s
.306 1 0 r
.34281 .37385 m .3547 .4076 L .37438 .42548 L p F P
0 0 0 r
s
.372 .62 .628 r
.83693 .52362 m
.8609 .51612 L
s
.83693 .52362 m
.82714 .50972 L
s
0 .096 1 r
.46779 .60972 m .45517 .60938 L .43487 .57078 L p F P
0 0 0 r
s
.004 0 1 r
.42237 .55781 m .43487 .57078 L .45517 .60938 L p F P
0 0 0 r
s
.66 0 1 r
.5231 .64814 m .53487 .62125 L .55674 .62682 L p F P
0 0 0 r
s
.319 0 1 r
.53487 .62125 m .5231 .64814 L .50135 .62786 L p F P
0 0 0 r
s
.372 .62 .628 r
.51599 .52305 m
.53857 .51554 L
s
.51599 .52305 m
.5036 .50914 L
s
1 .034 0 r
.18356 .25245 m .19781 .26854 L .21805 .26131 L p F P
0 0 0 r
s
1 .02 0 r
.19781 .26854 m .18356 .25245 L .16334 .26037 L p F P
0 0 0 r
s
2 Mabswid
.65 .52255 m
.65291 .51602 L
s
.372 .62 .628 r
.5 Mabswid
.19483 .52247 m
.21602 .51496 L
s
.19483 .52247 m
.17985 .50855 L
s
.88509 .50855 m
.89442 .52247 L
s
.306 1 0 r
.37438 .42548 m .36267 .38556 L .34281 .37385 L p F P
0 0 0 r
s
.717 1 0 r
.33077 .34183 m .34281 .37385 L .36267 .38556 L p F P
0 0 0 r
s
1 .152 0 r
.81443 .27323 m .80488 .25822 L .78242 .2712 L p F P
0 0 0 r
s
.372 .62 .628 r
.57328 .5219 m
.59613 .51438 L
s
.57328 .5219 m
.56135 .50797 L
s
.25193 .52132 m
.27339 .5138 L
s
.25193 .52132 m
.2374 .50738 L
s
1 .029 0 r
.34222 1.01727 m .35537 1.02672 L .37639 1.02162 L p F P
0 0 0 r
s
.372 .62 .628 r
.63065 .52074 m
.65017 .51439 L
s
.61918 .5068 m
.63065 .52074 L
s
0 0 0 r
2 Mabswid
.39901 .51399 m
.39997 .51638 L
s
.40068 .51815 m
.40165 .52057 L
s
.372 .62 .628 r
.5 Mabswid
.30911 .52017 m
.33083 .51264 L
s
.30911 .52017 m
.29503 .50621 L
s
1 .06 0 r
.3976 1.01647 m .41032 1.02594 L .43159 1.02083 L p F P
0 0 0 r
s
1 .034 0 r
.41032 1.02594 m .3976 1.01647 L .37639 1.02162 L p F P
0 0 0 r
s
.372 .62 .628 r
.6881 .51959 m
.71148 .51205 L
s
.6881 .51959 m
.67708 .50563 L
s
.306 1 0 r
.70649 .37675 m .69627 .36593 L .67543 .40609 L p F P
0 0 0 r
s
.306 1 0 r
.67543 .40609 m .68582 .415 L .70649 .37675 L p F P
0 0 0 r
s
.717 1 0 r
.36267 .38556 m .35085 .34806 L .33077 .34183 L p F P
0 0 0 r
s
1 .923 0 r
.31849 .31251 m .33077 .34183 L .35085 .34806 L p F P
0 0 0 r
s
1 .093 0 r
.45304 1.01568 m .46535 1.02516 L .48686 1.02004 L p F P
0 0 0 r
s
1 .06 0 r
.46535 1.02516 m .45304 1.01568 L .43159 1.02083 L p F P
0 0 0 r
s
1 .477 0 r
.31849 .31251 m .3059 .2862 L .28559 .28856 L p F P
0 0 0 r
s
1 .31 0 r
.27244 .26738 m .28559 .28856 L .3059 .2862 L p F P
0 0 0 r
s
1 .223 0 r
.28559 .28856 m .27244 .26738 L .25209 .27258 L p F P
0 0 0 r
s
.372 .62 .628 r
.36636 .51901 m
.38834 .51147 L
s
.36636 .51901 m
.35273 .50504 L
s
1 .137 0 r
.23842 .2544 m .25209 .27258 L .27244 .26738 L p F P
0 0 0 r
s
1 .093 0 r
.25209 .27258 m .23842 .2544 L .21805 .26131 L p F P
0 0 0 r
s
.372 .62 .628 r
.74563 .51843 m
.76927 .51089 L
s
.74563 .51843 m
.73506 .50445 L
s
1 .111 0 r
.50855 1.01488 m .52044 1.02437 L .5422 1.01925 L p F P
0 0 0 r
s
1 .08 0 r
.52044 1.02437 m .50855 1.01488 L .48686 1.02004 L p F P
0 0 0 r
s
.372 .62 .628 r
.42369 .51786 m
.44593 .51031 L
s
.41052 .50387 m
.42369 .51786 L
s
1 .011 0 r
.14872 .24467 m .16334 .26037 L .18356 .25245 L p F P
0 0 0 r
s
1 .005 0 r
.16334 .26037 m .14872 .24467 L .12855 .25291 L p F P
0 0 0 r
s
.372 .62 .628 r
.80323 .51728 m
.82714 .50972 L
s
.80323 .51728 m
.79312 .50328 L
s
1 .103 0 r
.56414 1.01408 m .57561 1.02359 L .59761 1.01846 L p F P
0 0 0 r
s
1 .082 0 r
.57561 1.02359 m .56414 1.01408 L .5422 1.01925 L p F P
0 0 0 r
s
.372 .62 .628 r
.48109 .5167 m
.5036 .50914 L
s
.48109 .5167 m
.46838 .50269 L
s
0 .194 1 r
.61207 .59321 m .62227 .57096 L .64345 .53426 L p F P
0 0 0 r
s
0 .194 1 r
.64345 .53426 m .63355 .55068 L .61207 .59321 L p F P
0 0 0 r
s
.372 .62 .628 r
.8609 .51612 m
.88509 .50855 L
s
.8609 .51612 m
.85126 .5021 L
s
0 0 0 r
2 Mabswid
.65291 .51602 m
.65323 .51497 L
s
.372 .62 .628 r
.5 Mabswid
.53857 .51554 m
.56135 .50797 L
s
.53857 .51554 m
.52632 .50151 L
s
0 1 .882 r
.67522 .45994 m .66516 .45984 L .64431 .50942 L p F P
0 0 0 r
s
0 1 .882 r
.64431 .50942 m .65455 .50481 L .67522 .45994 L p F P
0 0 0 r
s
2 Mabswid
.65409 .51211 m
.65493 .50935 L
s
.5 Mabswid
1 .28 0 r
.75029 .27192 m .76033 .28716 L .78242 .2712 L p F P
0 0 0 r
s
1 .477 0 r
.76033 .28716 m .75029 .27192 L .72842 .29229 L p F P
0 0 0 r
s
1 .477 0 r
.72842 .29229 m .73863 .30738 L .76033 .28716 L p F P
0 0 0 r
s
1 .054 0 r
.20393 .24465 m .21805 .26131 L .23842 .2544 L p F P
0 0 0 r
s
1 .034 0 r
.21805 .26131 m .20393 .24465 L .18356 .25245 L p F P
0 0 0 r
s
1 .773 0 r
.73863 .30738 m .72842 .29229 L .7069 .31832 L p F P
0 0 0 r
s
1 .773 0 r
.7069 .31832 m .7173 .33324 L .73863 .30738 L p F P
0 0 0 r
s
.372 .62 .628 r
.21602 .51496 m
.2374 .50738 L
s
.21602 .51496 m
.20115 .50092 L
s
1 .923 0 r
.35085 .34806 m .33879 .31423 L .31849 .31251 L p F P
0 0 0 r
s
1 .631 0 r
.3059 .2862 m .31849 .31251 L .33879 .31423 L p F P
0 0 0 r
s
.372 .62 .628 r
.59613 .51438 m
.61918 .5068 L
s
.59613 .51438 m
.58433 .50033 L
s
1 .054 0 r
.36336 1.01208 m .37639 1.02162 L .3976 1.01647 L p F P
0 0 0 r
s
1 .029 0 r
.37639 1.02162 m .36336 1.01208 L .34222 1.01727 L p F P
0 0 0 r
s
2 Mabswid
.39875 .51299 m
.39901 .51399 L
s
.39726 .50727 m
.39819 .51084 L
s
.372 .62 .628 r
.5 Mabswid
.27339 .5138 m
.29503 .50621 L
s
.27339 .5138 m
.25897 .49974 L
s
.66003 .51118 m
.67708 .50563 L
s
.65408 .51312 m
.66003 .51118 L
s
.65391 .51317 m
.65408 .51312 L
s
.64243 .49915 m
.6465 .50421 L
s
.649 .50731 m
.65182 .5108 L
s
1 .098 0 r
.41898 1.01128 m .43159 1.02083 L .45304 1.01568 L p F P
0 0 0 r
s
1 .06 0 r
.43159 1.02083 m .41898 1.01128 L .3976 1.01647 L p F P
0 0 0 r
s
1 .156 0 r
.77254 .25581 m .78242 .2712 L .80488 .25822 L p F P
0 0 0 r
s
1 .28 0 r
.78242 .2712 m .77254 .25581 L .75029 .27192 L p F P
0 0 0 r
s
.372 .62 .628 r
.33083 .51264 m
.35273 .50504 L
s
.33083 .51264 m
.31686 .49856 L
s
.71148 .51205 m
.73506 .50445 L
s
.71148 .51205 m
.7006 .49797 L
s
1 .137 0 r
.47467 1.01048 m .48686 1.02004 L .50855 1.01488 L p F P
0 0 0 r
s
1 .093 0 r
.48686 1.02004 m .47467 1.01048 L .45304 1.01568 L p F P
0 0 0 r
s
.372 .62 .628 r
.38834 .51147 m
.39587 .50889 L
s
.39587 .50889 m
.39712 .50846 L
s
.39712 .50846 m
.39778 .50823 L
s
.39966 .50759 m
.41052 .50387 L
s
.811 1 0 r
.7173 .33324 m .7069 .31832 L .68566 .35121 L p F P
0 0 0 r
s
.811 1 0 r
.68566 .35121 m .69627 .36593 L .7173 .33324 L p F P
0 0 0 r
s
.319 0 1 r
.50135 .62786 m .48895 .64237 L .46779 .60972 L p F P
0 0 0 r
s
.66 0 1 r
.45517 .60938 m .46779 .60972 L .48895 .64237 L p F P
0 0 0 r
s
.372 .62 .628 r
.76927 .51089 m
.79312 .50328 L
s
.76927 .51089 m
.75885 .49678 L
s
1 .148 0 r
.53043 1.00967 m .5422 1.01925 L .56414 1.01408 L p F P
0 0 0 r
s
1 .111 0 r
.5422 1.01925 m .53043 1.00967 L .50855 1.01488 L p F P
0 0 0 r
s
.901 0 1 r
.48895 .64237 m .50135 .62786 L .5231 .64814 L p F P
0 0 0 r
s
.372 .62 .628 r
.44593 .51031 m
.46838 .50269 L
s
.44593 .51031 m
.43289 .49619 L
s
.004 0 1 r
.45517 .60938 m .44258 .59647 L .42237 .55781 L p F P
0 0 0 r
s
0 .096 1 r
.41004 .53475 m .42237 .55781 L .44258 .59647 L p F P
0 0 0 r
s
1 .018 0 r
.16905 .23643 m .18356 .25245 L .20393 .24465 L p F P
0 0 0 r
s
1 .011 0 r
.18356 .25245 m .16905 .23643 L .14872 .24467 L p F P
0 0 0 r
s
.372 .62 .628 r
.82714 .50972 m
.85126 .5021 L
s
.82714 .50972 m
.81719 .4956 L
s
1 .123 0 r
.58627 1.00887 m .59761 1.01846 L .6198 1.01328 L p F P
0 0 0 r
s
1 .103 0 r
.59761 1.01846 m .58627 1.00887 L .56414 1.01408 L p F P
0 0 0 r
s
.779 0 1 r
.54533 .65616 m .55674 .62682 L .57876 .62 L p F P
0 0 0 r
s
.66 0 1 r
.55674 .62682 m .54533 .65616 L .5231 .64814 L p F P
0 0 0 r
s
1 .31 0 r
.3059 .2862 m .29295 .26272 L .27244 .26738 L p F P
0 0 0 r
s
1 .191 0 r
.25895 .24784 m .27244 .26738 L .29295 .26272 L p F P
0 0 0 r
s
1 .137 0 r
.27244 .26738 m .25895 .24784 L .23842 .2544 L p F P
0 0 0 r
s
2 Mabswid
.65592 .50333 m
.65604 .50256 L
s
.6559 .50345 m
.65592 .50333 L
s
.65493 .50935 m
.6559 .50345 L
s
.372 .62 .628 r
.5 Mabswid
.5036 .50914 m
.52632 .50151 L
s
.5036 .50914 m
.49102 .495 L
s
.17985 .50855 m
.20115 .50092 L
s
.17985 .50855 m
.16463 .49441 L
s
.8756 .49441 m
.88509 .50855 L
s
0 1 .354 r
.68582 .415 m .67543 .40609 L .65457 .45329 L p F P
0 0 0 r
s
0 1 .354 r
.65457 .45329 m .66516 .45984 L .68582 .415 L p F P
0 0 0 r
s
1 .156 0 r
.80488 .25822 m .79514 .24269 L .77254 .25581 L p F P
0 0 0 r
s
1 .631 0 r
.33879 .31423 m .32641 .28443 L .3059 .2862 L p F P
0 0 0 r
s
1 .41 0 r
.29295 .26272 m .3059 .2862 L .32641 .28443 L p F P
0 0 0 r
s
.372 .62 .628 r
.56135 .50797 m
.58433 .50033 L
s
.56135 .50797 m
.54923 .49382 L
s
1 .044 0 r
.32888 1.00766 m .34222 1.01727 L .36336 1.01208 L p F P
0 0 0 r
s
.372 .62 .628 r
.2374 .50738 m
.25897 .49974 L
s
.2374 .50738 m
.22264 .49322 L
s
0 0 0 r
2 Mabswid
.39643 .50046 m
.39649 .50091 L
s
.39649 .50091 m
.39726 .50727 L
s
.5 Mabswid
.319 0 1 r
.62227 .57096 m .61207 .59321 L .59011 .62751 L p F P
0 0 0 r
s
.319 0 1 r
.59011 .62751 m .60067 .6007 L .62227 .57096 L p F P
0 0 0 r
s
1 .08 0 r
.22446 .237 m .23842 .2544 L .25895 .24784 L p F P
0 0 0 r
s
1 .054 0 r
.23842 .2544 m .22446 .237 L .20393 .24465 L p F P
0 0 0 r
s
.372 .62 .628 r
.61918 .5068 m
.60752 .49263 L
s
1 .093 0 r
.38467 1.00685 m .3976 1.01647 L .41898 1.01128 L p F P
0 0 0 r
s
1 .054 0 r
.3976 1.01647 m .38467 1.00685 L .36336 1.01208 L p F P
0 0 0 r
s
.372 .62 .628 r
.29503 .50621 m
.31686 .49856 L
s
.29503 .50621 m
.28072 .49203 L
s
1 .152 0 r
.44054 1.00604 m .45304 1.01568 L .47467 1.01048 L p F P
0 0 0 r
s
1 .098 0 r
.45304 1.01568 m .44054 1.00604 L .41898 1.01128 L p F P
0 0 0 r
s
.372 .62 .628 r
.67708 .50563 m
.7006 .49797 L
s
.66588 .49144 m
.67708 .50563 L
s
.35273 .50504 m
.37484 .49738 L
s
.35273 .50504 m
.33889 .49084 L
s
1 .191 0 r
.49648 1.00523 m .50855 1.01488 L .53043 1.00967 L p F P
0 0 0 r
s
1 .137 0 r
.50855 1.01488 m .49648 1.00523 L .47467 1.01048 L p F P
0 0 0 r
s
.372 .62 .628 r
.73506 .50445 m
.75885 .49678 L
s
.73506 .50445 m
.72433 .49024 L
s
.262 1 0 r
.69627 .36593 m .68566 .35121 L .66458 .39158 L p F P
0 0 0 r
s
.262 1 0 r
.66458 .39158 m .67543 .40609 L .69627 .36593 L p F P
0 0 0 r
s
1 .186 0 r
.5525 1.00442 m .56414 1.01408 L .58627 1.00887 L p F P
0 0 0 r
s
1 .148 0 r
.56414 1.01408 m .5525 1.00442 L .53043 1.00967 L p F P
0 0 0 r
s
.389 1 0 r
.38297 .39765 m .3713 .3545 L .35085 .34806 L p F P
0 0 0 r
s
.389 1 0 r
.35085 .34806 m .36267 .38556 L .38297 .39765 L p F P
0 0 0 r
s
.841 1 0 r
.33879 .31423 m .35085 .34806 L .3713 .3545 L p F P
0 0 0 r
s
.372 .62 .628 r
.79312 .50328 m
.81719 .4956 L
s
.79312 .50328 m
.78286 .48905 L
s
0 1 .127 r
.39456 .44399 m .38297 .39765 L .36267 .38556 L p F P
0 0 0 r
s
0 1 .127 r
.36267 .38556 m .37438 .42548 L .39456 .44399 L p F P
0 0 0 r
s
.372 .62 .628 r
.46838 .50269 m
.49102 .495 L
s
.46838 .50269 m
.45546 .48845 L
s
0 0 0 r
2 Mabswid
.65604 .50256 m
.65605 .50211 L
s
.65605 .50211 m
.65609 .50078 L
s
.65609 .50078 m
.65623 .49571 L
s
.5 Mabswid
1 .029 0 r
.18955 .22822 m .20393 .24465 L .22446 .237 L p F P
0 0 0 r
s
1 .018 0 r
.20393 .24465 m .18955 .22822 L .16905 .23643 L p F P
0 0 0 r
s
0 .096 1 r
.44258 .59647 m .43018 .57083 L .41004 .53475 L p F P
0 0 0 r
s
0 .381 1 r
.39795 .50312 m .41004 .53475 L .43018 .57083 L p F P
0 0 0 r
s
1 .14 0 r
.60858 1.00361 m .6198 1.01328 L .64218 1.00806 L p F P
0 0 0 r
s
1 .123 0 r
.6198 1.01328 m .60858 1.00361 L .58627 1.00887 L p F P
0 0 0 r
s
.66 0 1 r
.56777 .64932 m .57876 .62 L .60067 .6007 L p F P
0 0 0 r
s
.779 0 1 r
.57876 .62 m .56777 .64932 L .54533 .65616 L p F P
0 0 0 r
s
.372 .62 .628 r
.85126 .5021 m
.8756 .49441 L
s
.85126 .5021 m
.84146 .48785 L
s
1 .273 0 r
.74002 .25554 m .75029 .27192 L .77254 .25581 L p F P
0 0 0 r
s
1 .465 0 r
.75029 .27192 m .74002 .25554 L .71794 .27546 L p F P
0 0 0 r
s
1 .465 0 r
.71794 .27546 m .72842 .29229 L .75029 .27192 L p F P
0 0 0 r
s
.66 0 1 r
.60067 .6007 m .59011 .62751 L .56777 .64932 L p F P
0 0 0 r
s
1 .753 0 r
.72842 .29229 m .71794 .27546 L .69619 .30074 L p F P
0 0 0 r
s
1 .753 0 r
.69619 .30074 m .7069 .31832 L .72842 .29229 L p F P
0 0 0 r
s
.372 .62 .628 r
.52632 .50151 m
.54923 .49382 L
s
.52632 .50151 m
.51386 .48725 L
s
.841 1 0 r
.3713 .3545 m .3594 .31603 L .33879 .31423 L p F P
0 0 0 r
s
1 .793 0 r
.32641 .28443 m .33879 .31423 L .3594 .31603 L p F P
0 0 0 r
s
0 1 .671 r
.40621 .49081 m .39456 .44399 L .37438 .42548 L p F P
0 0 0 r
s
0 1 .671 r
.37438 .42548 m .38609 .46564 L .40621 .49081 L p F P
0 0 0 r
s
0 .381 1 r
.65455 .50481 m .64431 .50942 L .62306 .56025 L p F P
0 0 0 r
s
0 .381 1 r
.62306 .56025 m .63355 .55068 L .65455 .50481 L p F P
0 0 0 r
s
.372 .62 .628 r
.61918 .5068 m
.64243 .49915 L
s
.20115 .50092 m
.22264 .49322 L
s
.20115 .50092 m
.18603 .48665 L
s
1 .08 0 r
.35012 1.00239 m .36336 1.01208 L .38467 1.00685 L p F P
0 0 0 r
s
1 .044 0 r
.36336 1.01208 m .35012 1.00239 L .32888 1.00766 L p F P
0 0 0 r
s
2 Mabswid
.39643 .50046 m
.39644 .49969 L
s
.39644 .49969 m
.39645 .49956 L
s
.372 .62 .628 r
.5 Mabswid
.58433 .50033 m
.60752 .49263 L
s
.58433 .50033 m
.57234 .48605 L
s
1 .41 0 r
.32641 .28443 m .31367 .25839 L .29295 .26272 L p F P
0 0 0 r
s
1 .253 0 r
.27965 .24157 m .29295 .26272 L .31367 .25839 L p F P
0 0 0 r
s
1 .191 0 r
.29295 .26272 m .27965 .24157 L .25895 .24784 L p F P
0 0 0 r
s
.372 .62 .628 r
.25897 .49974 m
.28072 .49203 L
s
.25897 .49974 m
.24431 .48545 L
s
0 .811 1 r
.41805 .53445 m .40621 .49081 L .38609 .46564 L p F P
0 0 0 r
s
.372 .62 .628 r
.40944 .50272 m
.41052 .50387 L
s
0 .811 1 r
.38609 .46564 m .39795 .50312 L .41805 .53445 L p F P
0 0 0 r
s
.372 .62 .628 r
.37484 .49738 m
.38834 .51147 L
s
0 0 0 r
2 Mabswid
.39645 .49956 m
.39654 .49361 L
s
.5 Mabswid
1 .152 0 r
.40617 1.00158 m .41898 1.01128 L .44054 1.00604 L p F P
0 0 0 r
s
1 .093 0 r
.41898 1.01128 m .40617 1.00158 L .38467 1.00685 L p F P
0 0 0 r
s
0 .381 1 r
.43018 .57083 m .41805 .53445 L .39795 .50312 L p F P
0 0 0 r
s
.372 .62 .628 r
.41052 .50387 m
.43289 .49619 L
s
1 .152 0 r
.76246 .23967 m .77254 .25581 L .79514 .24269 L p F P
0 0 0 r
s
1 .273 0 r
.77254 .25581 m .76246 .23967 L .74002 .25554 L p F P
0 0 0 r
s
.372 .62 .628 r
.65655 .49451 m
.65724 .49428 L
s
.64243 .49915 m
.64963 .49678 L
s
.65585 .49474 m
.65655 .49451 L
s
.31686 .49856 m
.33889 .49084 L
s
.31686 .49856 m
.30267 .48425 L
s
1 .111 0 r
.24515 .22951 m .25895 .24784 L .27965 .24157 L p F P
0 0 0 r
s
1 .08 0 r
.25895 .24784 m .24515 .22951 L .22446 .237 L p F P
0 0 0 r
s
1 .223 0 r
.46229 1.00076 m .47467 1.01048 L .49648 1.00523 L p F P
0 0 0 r
s
1 .152 0 r
.47467 1.01048 m .46229 1.00076 L .44054 1.00604 L p F P
0 0 0 r
s
.372 .62 .628 r
.7006 .49797 m
.72433 .49024 L
s
.7006 .49797 m
.68955 .48365 L
s
.841 1 0 r
.7069 .31832 m .69619 .30074 L .67469 .33253 L p F P
0 0 0 r
s
.841 1 0 r
.67469 .33253 m .68566 .35121 L .7069 .31832 L p F P
0 0 0 r
s
.372 .62 .628 r
.37484 .49738 m
.39248 .49126 L
s
.39248 .49126 m
.39683 .48975 L
s
.39683 .48975 m
.397 .48969 L
s
.36111 .48305 m
.37484 .49738 L
s
1 .253 0 r
.51848 .99995 m .53043 1.00967 L .5525 1.00442 L p F P
0 0 0 r
s
1 .191 0 r
.53043 1.00967 m .51848 .99995 L .49648 1.00523 L p F P
0 0 0 r
s
1 .793 0 r
.3594 .31603 m .34719 .28267 L .32641 .28443 L p F P
0 0 0 r
s
1 .515 0 r
.31367 .25839 m .32641 .28443 L .34719 .28267 L p F P
0 0 0 r
s
.372 .62 .628 r
.75885 .49678 m
.78286 .48905 L
s
.75885 .49678 m
.74827 .48245 L
s
.43289 .49619 m
.45546 .48845 L
s
.43289 .49619 m
.41963 .48185 L
s
1 .222 0 r
.57475 .99913 m .58627 1.00887 L .60858 1.00361 L p F P
0 0 0 r
s
1 .186 0 r
.58627 1.00887 m .57475 .99913 L .5525 1.00442 L p F P
0 0 0 r
s
.372 .62 .628 r
.81719 .4956 m
.84146 .48785 L
s
.81719 .4956 m
.80707 .48124 L
s
.49102 .495 m
.51386 .48725 L
s
.49102 .495 m
.47823 .48064 L
s
1 .152 0 r
.63109 .99831 m .64218 1.00806 L .66474 1.0028 L p F P
0 0 0 r
s
1 .14 0 r
.64218 1.00806 m .63109 .99831 L .60858 1.00361 L p F P
0 0 0 r
s
1 .152 0 r
.79514 .24269 m .78523 .22664 L .76246 .23967 L p F P
0 0 0 r
s
1 .044 0 r
.21021 .22006 m .22446 .237 L .24515 .22951 L p F P
0 0 0 r
s
1 .029 0 r
.22446 .237 m .21021 .22006 L .18955 .22822 L p F P
0 0 0 r
s
.372 .62 .628 r
.16463 .49441 m
.18603 .48665 L
s
.16463 .49441 m
.14916 .48004 L
s
.86595 .48004 m
.8756 .49441 L
s
1 .061 0 r
.31532 .9979 m .32888 1.00766 L .35012 1.00239 L p F P
0 0 0 r
s
.372 .62 .628 r
.54923 .49382 m
.57234 .48605 L
s
.54923 .49382 m
.5369 .47943 L
s
0 .891 1 r
.66516 .45984 m .65457 .45329 L .63348 .50558 L p F P
0 0 0 r
s
.372 .62 .628 r
.64001 .49615 m
.64243 .49915 L
s
0 .891 1 r
.63348 .50558 m .64431 .50942 L .66516 .45984 L p F P
0 0 0 r
s
.372 .62 .628 r
.65788 .49407 m
.65926 .49361 L
s
.65724 .49428 m
.65788 .49407 L
s
.65926 .49361 m
.66588 .49144 L
s
.6309 .48485 m
.63819 .4939 L
s
0 0 0 r
2 Mabswid
.65547 .48885 m
.65558 .48988 L
s
.65583 .49208 m
.65623 .49571 L
s
.39742 .48784 m
.39759 .48675 L
s
.39654 .49361 m
.39697 .49078 L
s
.372 .62 .628 r
.5 Mabswid
.22264 .49322 m
.24431 .48545 L
s
.22264 .49322 m
.20763 .47883 L
s
1 .137 0 r
.37154 .99708 m .38467 1.00685 L .40617 1.00158 L p F P
0 0 0 r
s
1 .08 0 r
.38467 1.00685 m .37154 .99708 L .35012 1.00239 L p F P
0 0 0 r
s
.372 .62 .628 r
.60752 .49263 m
.6309 .48485 L
s
.60752 .49263 m
.59566 .47822 L
s
.28072 .49203 m
.30267 .48425 L
s
.28072 .49203 m
.26618 .47762 L
s
1 .234 0 r
.42784 .99626 m .44054 1.00604 L .46229 1.00076 L p F P
0 0 0 r
s
1 .152 0 r
.44054 1.00604 m .42784 .99626 L .40617 1.00158 L p F P
0 0 0 r
s
0 1 .414 r
.67543 .40609 m .66458 .39158 L .64346 .43901 L p F P
0 0 0 r
s
0 1 .414 r
.64346 .43901 m .65457 .45329 L .67543 .40609 L p F P
0 0 0 r
s
.372 .62 .628 r
.66588 .49144 m
.68955 .48365 L
s
.65571 .47855 m
.66588 .49144 L
s
.6545 .47701 m
.65571 .47855 L
s
1 .31 0 r
.48422 .99544 m .49648 1.00523 L .51848 .99995 L p F P
0 0 0 r
s
1 .223 0 r
.49648 1.00523 m .48422 .99544 L .46229 1.00076 L p F P
0 0 0 r
s
.372 .62 .628 r
.33889 .49084 m
.36111 .48305 L
s
.33889 .49084 m
.32481 .47641 L
s
.66 0 1 r
.48895 .64237 m .47633 .64455 L .45517 .60938 L p F P
0 0 0 r
s
.779 0 1 r
.44258 .59647 m .45517 .60938 L .47633 .64455 L p F P
0 0 0 r
s
.372 .62 .628 r
.72433 .49024 m
.74827 .48245 L
s
.72433 .49024 m
.71342 .4758 L
s
.306 1 0 r
.68566 .35121 m .67469 .33253 L .65332 .3714 L p F P
0 0 0 r
s
.306 1 0 r
.65332 .3714 m .66458 .39158 L .68566 .35121 L p F P
0 0 0 r
s
1 .515 0 r
.34719 .28267 m .33462 .25403 L .31367 .25839 L p F P
0 0 0 r
s
1 .318 0 r
.30055 .23546 m .31367 .25839 L .33462 .25403 L p F P
0 0 0 r
s
1 .253 0 r
.31367 .25839 m .30055 .23546 L .27965 .24157 L p F P
0 0 0 r
s
1 .318 0 r
.54067 .99462 m .5525 1.00442 L .57475 .99913 L p F P
0 0 0 r
s
1 .253 0 r
.5525 1.00442 m .54067 .99462 L .51848 .99995 L p F P
0 0 0 r
s
.372 .62 .628 r
.40522 .48684 m
.41963 .48185 L
s
.39484 .48721 m
.39693 .48943 L
s
.39693 .48943 m
.397 .48951 L
s
1 .148 0 r
.26601 .22215 m .27965 .24157 L .30055 .23546 L p F P
0 0 0 r
s
1 .111 0 r
.27965 .24157 m .26601 .22215 L .24515 .22951 L p F P
0 0 0 r
s
.372 .62 .628 r
.78286 .48905 m
.80707 .48124 L
s
.78286 .48905 m
.77242 .47458 L
s
0 0 0 r
2 Mabswid
.65485 .48639 m
.65547 .48885 L
s
.65376 .48203 m
.65439 .48455 L
s
.5 Mabswid
1 .431 0 r
.70723 .25708 m .71794 .27546 L .74002 .25554 L p F P
0 0 0 r
s
1 .698 0 r
.71794 .27546 m .70723 .25708 L .68521 .28085 L p F P
0 0 0 r
s
1 .698 0 r
.68521 .28085 m .69619 .30074 L .71794 .27546 L p F P
0 0 0 r
s
1 .253 0 r
.72954 .23814 m .74002 .25554 L .76246 .23967 L p F P
0 0 0 r
s
1 .431 0 r
.74002 .25554 m .72954 .23814 L .70723 .25708 L p F P
0 0 0 r
s
1 .253 0 r
.59719 .99379 m .60858 1.00361 L .63109 .99831 L p F P
0 0 0 r
s
1 .222 0 r
.60858 1.00361 m .59719 .99379 L .57475 .99913 L p F P
0 0 0 r
s
.372 .62 .628 r
.45546 .48845 m
.47823 .48064 L
s
.45546 .48845 m
.44232 .47398 L
s
1 0 .712 r
.51088 .66618 m .5231 .64814 L .54533 .65616 L p F P
0 0 0 r
s
.901 0 1 r
.5231 .64814 m .51088 .66618 L .48895 .64237 L p F P
0 0 0 r
s
.372 .62 .628 r
.84146 .48785 m
.86595 .48004 L
s
.84146 .48785 m
.8315 .47337 L
s
.616 1 0 r
.3922 .35954 m .38039 .31682 L .3594 .31603 L p F P
0 0 0 r
s
.616 1 0 r
.3594 .31603 m .3713 .3545 L .3922 .35954 L p F P
0 0 0 r
s
1 .946 0 r
.34719 .28267 m .3594 .31603 L .38039 .31682 L p F P
0 0 0 r
s
1 .156 0 r
.65379 .99297 m .66474 1.0028 L .6875 .99749 L p F P
0 0 0 r
s
1 .152 0 r
.66474 1.0028 m .65379 .99297 L .63109 .99831 L p F P
0 0 0 r
s
.372 .62 .628 r
.51386 .48725 m
.5369 .47943 L
s
.51386 .48725 m
.5012 .47276 L
s
.077 1 0 r
.40382 .40791 m .3922 .35954 L .3713 .3545 L p F P
0 0 0 r
s
.077 1 0 r
.3713 .3545 m .38297 .39765 L .40382 .40791 L p F P
0 0 0 r
s
1 .111 0 r
.33667 .99255 m .35012 1.00239 L .37154 .99708 L p F P
0 0 0 r
s
1 .061 0 r
.35012 1.00239 m .33667 .99255 L .31532 .9979 L p F P
0 0 0 r
s
2 Mabswid
.39759 .48675 m
.39958 .47996 L
s
.372 .62 .628 r
.5 Mabswid
.18603 .48665 m
.20763 .47883 L
s
.18603 .48665 m
.17067 .47215 L
s
1 .061 0 r
.23104 .21195 m .24515 .22951 L .26601 .22215 L p F P
0 0 0 r
s
1 .044 0 r
.24515 .22951 m .23104 .21195 L .21021 .22006 L p F P
0 0 0 r
s
.319 0 1 r
.63355 .55068 m .62306 .56025 L .60127 .60744 L p F P
0 0 0 r
s
.319 0 1 r
.60127 .60744 m .61207 .59321 L .63355 .55068 L p F P
0 0 0 r
s
.372 .62 .628 r
.57234 .48605 m
.59566 .47822 L
s
.57234 .48605 m
.56015 .47154 L
s
1 .14 0 r
.75218 .22285 m .76246 .23967 L .78523 .22664 L p F P
0 0 0 r
s
1 .253 0 r
.76246 .23967 m .75218 .22285 L .72954 .23814 L p F P
0 0 0 r
s
1 .223 0 r
.39315 .99173 m .40617 1.00158 L .42784 .99626 L p F P
0 0 0 r
s
1 .137 0 r
.40617 1.00158 m .39315 .99173 L .37154 .99708 L p F P
0 0 0 r
s
.926 1 0 r
.69619 .30074 m .68521 .28085 L .66342 .31045 L p F P
0 0 0 r
s
.926 1 0 r
.66342 .31045 m .67469 .33253 L .69619 .30074 L p F P
0 0 0 r
s
.372 .62 .628 r
.24431 .48545 m
.26618 .47762 L
s
.24431 .48545 m
.22942 .47093 L
s
1 .946 0 r
.38039 .31682 m .36829 .2802 L .34719 .28267 L p F P
0 0 0 r
s
1 .615 0 r
.33462 .25403 m .34719 .28267 L .36829 .2802 L p F P
0 0 0 r
s
.372 .62 .628 r
.653 .47751 m
.6545 .47701 L
s
.65195 .47786 m
.653 .47751 L
s
.65188 .47788 m
.65195 .47786 L
s
.6309 .48485 m
.64353 .48066 L
s
1 .343 0 r
.44971 .9909 m .46229 1.00076 L .48422 .99544 L p F P
0 0 0 r
s
1 .234 0 r
.46229 1.00076 m .44971 .9909 L .42784 .99626 L p F P
0 0 0 r
s
.372 .62 .628 r
.30267 .48425 m
.32481 .47641 L
s
.30267 .48425 m
.28825 .46971 L
s
.68955 .48365 m
.71342 .4758 L
s
.68955 .48365 m
.67831 .4691 L
s
0 1 .54 r
.41539 .46021 m .40382 .40791 L .38297 .39765 L p F P
0 0 0 r
s
0 1 .54 r
.38297 .39765 m .39456 .44399 L .41539 .46021 L p F P
0 0 0 r
s
1 .41 0 r
.50634 .99007 m .51848 .99995 L .54067 .99462 L p F P
0 0 0 r
s
1 .31 0 r
.51848 .99995 m .50634 .99007 L .48422 .99544 L p F P
0 0 0 r
s
.372 .62 .628 r
.36111 .48305 m
.38353 .47519 L
s
.36111 .48305 m
.34716 .46849 L
s
.74827 .48245 m
.77242 .47458 L
s
.74827 .48245 m
.73751 .46788 L
s
1 .38 0 r
.56304 .98924 m .57475 .99913 L .59719 .99379 L p F P
0 0 0 r
s
1 .318 0 r
.57475 .99913 m .56304 .98924 L .54067 .99462 L p F P
0 0 0 r
s
2 Mabswid
.65342 .48115 m
.65376 .48203 L
s
.5 Mabswid
1 0 .712 r
.47633 .64455 m .48895 .64237 L .51088 .66618 L p F P
0 0 0 r
s
.372 .62 .628 r
.80707 .48124 m
.8315 .47337 L
s
.80707 .48124 m
.79679 .46665 L
s
1 .14 0 r
.78523 .22664 m .77514 .21011 L .75218 .22285 L p F P
0 0 0 r
s
1 .273 0 r
.61982 .98841 m .63109 .99831 L .65379 .99297 L p F P
0 0 0 r
s
1 .253 0 r
.63109 .99831 m .61982 .98841 L .59719 .99379 L p F P
0 0 0 r
s
.372 .62 .628 r
.47823 .48064 m
.5012 .47276 L
s
.47823 .48064 m
.46522 .46604 L
s
1 .318 0 r
.33462 .25403 m .32165 .2293 L .30055 .23546 L p F P
0 0 0 r
s
1 .186 0 r
.28706 .21485 m .30055 .23546 L .32165 .2293 L p F P
0 0 0 r
s
1 .148 0 r
.30055 .23546 m .28706 .21485 L .26601 .22215 L p F P
0 0 0 r
s
1 .082 0 r
.30154 .98799 m .31532 .9979 L .33667 .99255 L p F P
0 0 0 r
s
.372 .62 .628 r
.14916 .48004 m
.17067 .47215 L
s
.14916 .48004 m
.13343 .46542 L
s
.85615 .46542 m
.86595 .48004 L
s
0 0 0 r
2 Mabswid
.39958 .47996 m
.39981 .47943 L
s
.5 Mabswid
1 .152 0 r
.67668 .98757 m .6875 .99749 L .71046 .99214 L p F P
0 0 0 r
s
1 .156 0 r
.6875 .99749 m .67668 .98757 L .65379 .99297 L p F P
0 0 0 r
s
1 .615 0 r
.36829 .2802 m .35583 .2492 L .33462 .25403 L p F P
0 0 0 r
s
1 .38 0 r
.32165 .2293 m .33462 .25403 L .35583 .2492 L p F P
0 0 0 r
s
.372 .62 .628 r
.5369 .47943 m
.56015 .47154 L
s
.5369 .47943 m
.52437 .46481 L
s
1 .191 0 r
.35821 .98716 m .37154 .99708 L .39315 .99173 L p F P
0 0 0 r
s
1 .111 0 r
.37154 .99708 m .35821 .98716 L .33667 .99255 L p F P
0 0 0 r
s
.372 .62 .628 r
.20763 .47883 m
.22942 .47093 L
s
.20763 .47883 m
.19237 .46419 L
s
.43 1 0 r
.67469 .33253 m .66342 .31045 L .64174 .34638 L p F P
0 0 0 r
s
.43 1 0 r
.64174 .34638 m .65332 .3714 L .67469 .33253 L p F P
0 0 0 r
s
0 .811 1 r
.42707 .51327 m .41539 .46021 L .39456 .44399 L p F P
0 0 0 r
s
.372 .62 .628 r
.38353 .47519 m
.392 .48419 L
s
.392 .48419 m
.39484 .48721 L
s
0 .811 1 r
.39456 .44399 m .40621 .49081 L .42707 .51327 L p F P
0 0 0 r
s
.372 .62 .628 r
.42011 .48168 m
.44232 .47398 L
s
0 0 0 r
2 Mabswid
.40108 .47654 m
.40252 .47326 L
s
.372 .62 .628 r
.5 Mabswid
.59566 .47822 m
.61919 .47032 L
s
.59566 .47822 m
.58361 .46358 L
s
1 .343 0 r
.41495 .98632 m .42784 .99626 L .44971 .9909 L p F P
0 0 0 r
s
1 .223 0 r
.42784 .99626 m .41495 .98632 L .39315 .99173 L p F P
0 0 0 r
s
1 .082 0 r
.25205 .20388 m .26601 .22215 L .28706 .21485 L p F P
0 0 0 r
s
1 .061 0 r
.26601 .22215 m .25205 .20388 L .23104 .21195 L p F P
0 0 0 r
s
0 1 .354 r
.66458 .39158 m .65332 .3714 L .63189 .41694 L p F P
0 0 0 r
s
0 1 .354 r
.63189 .41694 m .64346 .43901 L .66458 .39158 L p F P
0 0 0 r
s
.372 .62 .628 r
.26618 .47762 m
.28825 .46971 L
s
.26618 .47762 m
.2514 .46296 L
s
1 .477 0 r
.47176 .98549 m .48422 .99544 L .50634 .99007 L p F P
0 0 0 r
s
1 .343 0 r
.48422 .99544 m .47176 .98549 L .44971 .9909 L p F P
0 0 0 r
s
.372 .62 .628 r
.6557 .47661 m
.67831 .4691 L
s
.6545 .47701 m
.6557 .47661 L
s
.779 0 1 r
.47633 .64455 m .46368 .63168 L .44258 .59647 L p F P
0 0 0 r
s
.66 0 1 r
.43018 .57083 m .44258 .59647 L .46368 .63168 L p F P
0 0 0 r
s
1 .38 0 r
.69631 .23755 m .70723 .25708 L .72954 .23814 L p F P
0 0 0 r
s
1 .615 0 r
.70723 .25708 m .69631 .23755 L .67402 .25926 L p F P
0 0 0 r
s
1 .615 0 r
.67402 .25926 m .68521 .28085 L .70723 .25708 L p F P
0 0 0 r
s
0 .096 1 r
.64431 .50942 m .63348 .50558 L .61194 .5593 L p F P
0 0 0 r
s
0 .096 1 r
.61194 .5593 m .62306 .56025 L .64431 .50942 L p F P
0 0 0 r
s
.372 .62 .628 r
.32481 .47641 m
.34716 .46849 L
s
.32481 .47641 m
.31051 .46173 L
s
1 .515 0 r
.52865 .98465 m .54067 .99462 L .56304 .98924 L p F P
0 0 0 r
s
1 .41 0 r
.54067 .99462 m .52865 .98465 L .50634 .99007 L p F P
0 0 0 r
s
1 .222 0 r
.71887 .21995 m .72954 .23814 L .75218 .22285 L p F P
0 0 0 r
s
1 .38 0 r
.72954 .23814 m .71887 .21995 L .69631 .23755 L p F P
0 0 0 r
s
.372 .62 .628 r
.71342 .4758 m
.73751 .46788 L
s
.71342 .4758 m
.70233 .46112 L
s
0 .811 1 r
.65457 .45329 m .64346 .43901 L .62208 .49158 L p F P
0 0 0 r
s
.372 .62 .628 r
.62938 .48297 m
.6309 .48485 L
s
0 .811 1 r
.62208 .49158 m .63348 .50558 L .65457 .45329 L p F P
0 0 0 r
s
.372 .62 .628 r
.61919 .47032 m
.62685 .47983 L
s
0 0 0 r
2 Mabswid
.65111 .4753 m
.65342 .48115 L
s
.372 .62 .628 r
.5 Mabswid
.65232 .47425 m
.6545 .47701 L
s
.64916 .47025 m
.65232 .47425 L
s
.64705 .46758 m
.64916 .47025 L
s
.64293 .46235 m
.64705 .46758 L
s
0 0 0 r
2 Mabswid
.6508 .47472 m
.65111 .4753 L
s
.64795 .46948 m
.64802 .46962 L
s
.64802 .46962 m
.6508 .47472 L
s
.64753 .46871 m
.64795 .46948 L
s
.372 .62 .628 r
.5 Mabswid
.38353 .47519 m
.39754 .47028 L
s
.39754 .47028 m
.4023 .46861 L
s
.4023 .46861 m
.4058 .46738 L
s
.4058 .46738 m
.40593 .46734 L
s
.3697 .4605 m
.38353 .47519 L
s
1 .431 0 r
.58561 .98381 m .59719 .99379 L .61982 .98841 L p F P
0 0 0 r
s
1 .38 0 r
.59719 .99379 m .58561 .98381 L .56304 .98924 L p F P
0 0 0 r
s
.43 1 0 r
.4136 .36143 m .4018 .3154 L .38039 .31682 L p F P
0 0 0 r
s
.43 1 0 r
.38039 .31682 m .3922 .35954 L .4136 .36143 L p F P
0 0 0 r
s
.926 1 0 r
.36829 .2802 m .38039 .31682 L .4018 .3154 L p F P
0 0 0 r
s
.372 .62 .628 r
.77242 .47458 m
.79679 .46665 L
s
.77242 .47458 m
.76181 .45988 L
s
1 .946 0 r
.68521 .28085 m .67402 .25926 L .65193 .28592 L p F P
0 0 0 r
s
1 .946 0 r
.65193 .28592 m .66342 .31045 L .68521 .28085 L p F P
0 0 0 r
s
.372 .62 .628 r
.44232 .47398 m
.46522 .46604 L
s
.926 1 0 r
.4018 .3154 m .38973 .27625 L .36829 .2802 L p F P
0 0 0 r
s
1 .698 0 r
.35583 .2492 m .36829 .2802 L .38973 .27625 L p F P
0 0 0 r
s
1 .28 0 r
.64265 .98297 m .65379 .99297 L .67668 .98757 L p F P
0 0 0 r
s
1 .273 0 r
.65379 .99297 m .64265 .98297 L .61982 .98841 L p F P
0 0 0 r
s
.901 0 1 r
.57893 .64542 m .59011 .62751 L .61207 .59321 L p F P
0 0 0 r
s
1 0 .712 r
.59011 .62751 m .57893 .64542 L .5562 .66929 L p F P
0 0 0 r
s
1 0 .712 r
.5562 .66929 m .56777 .64932 L .59011 .62751 L p F P
0 0 0 r
s
.901 0 1 r
.61207 .59321 m .60127 .60744 L .57893 .64542 L p F P
0 0 0 r
s
.372 .62 .628 r
.8315 .47337 m
.85615 .46542 L
s
.8315 .47337 m
.82137 .45865 L
s
0 0 0 r
2 Mabswid
.40626 .46694 m
.40639 .46673 L
s
.40252 .47326 m
.40477 .46946 L
s
.5 Mabswid
1 .148 0 r
.32301 .98255 m .33667 .99255 L .35821 .98716 L p F P
0 0 0 r
s
1 .082 0 r
.33667 .99255 m .32301 .98255 L .30154 .98799 L p F P
0 0 0 r
s
.372 .62 .628 r
.5012 .47276 m
.52437 .46481 L
s
.5012 .47276 m
.48833 .45803 L
s
0 .194 1 r
.43898 .5627 m .42707 .51327 L .40621 .49081 L p F P
0 0 0 r
s
0 .194 1 r
.40621 .49081 m .41805 .53445 L .43898 .5627 L p F P
0 0 0 r
s
1 .123 0 r
.74173 .20546 m .75218 .22285 L .77514 .21011 L p F P
0 0 0 r
s
1 .222 0 r
.75218 .22285 m .74173 .20546 L .71887 .21995 L p F P
0 0 0 r
s
1 0 .577 r
.5334 .67617 m .54533 .65616 L .56777 .64932 L p F P
0 0 0 r
s
1 0 .712 r
.54533 .65616 m .5334 .67617 L .51088 .66618 L p F P
0 0 0 r
s
1 .14 0 r
.69977 .98213 m .71046 .99214 L .73361 .98674 L p F P
0 0 0 r
s
1 .152 0 r
.71046 .99214 m .69977 .98213 L .67668 .98757 L p F P
0 0 0 r
s
.372 .62 .628 r
.17067 .47215 m
.19237 .46419 L
s
.17067 .47215 m
.15505 .45741 L
s
1 .31 0 r
.37993 .98171 m .39315 .99173 L .41495 .98632 L p F P
0 0 0 r
s
1 .191 0 r
.39315 .99173 m .37993 .98171 L .35821 .98716 L p F P
0 0 0 r
s
.372 .62 .628 r
.56015 .47154 m
.58361 .46358 L
s
.56015 .47154 m
.54776 .45679 L
s
0 1 .182 r
.42526 .41389 m .4136 .36143 L .3922 .35954 L p F P
0 0 0 r
s
0 1 .182 r
.3922 .35954 m .40382 .40791 L .42526 .41389 L p F P
0 0 0 r
s
1 .38 0 r
.35583 .2492 m .343 .22283 L .32165 .2293 L p F P
0 0 0 r
s
1 .222 0 r
.30832 .20749 m .32165 .2293 L .343 .22283 L p F P
0 0 0 r
s
1 .186 0 r
.32165 .2293 m .30832 .20749 L .28706 .21485 L p F P
0 0 0 r
s
.372 .62 .628 r
.22942 .47093 m
.2514 .46296 L
s
.22942 .47093 m
.21427 .45617 L
s
1 .502 0 r
.43693 .98087 m .44971 .9909 L .47176 .98549 L p F P
0 0 0 r
s
1 .343 0 r
.44971 .9909 m .43693 .98087 L .41495 .98632 L p F P
0 0 0 r
s
.372 .62 .628 r
.64242 .46252 m
.64293 .46235 L
s
.61919 .47032 m
.63255 .46584 L
s
.66 0 1 r
.46368 .63168 m .45119 .60359 L .43018 .57083 L p F P
0 0 0 r
s
.319 0 1 r
.41805 .53445 m .43018 .57083 L .45119 .60359 L p F P
0 0 0 r
s
.372 .62 .628 r
.28825 .46971 m
.31051 .46173 L
s
.28825 .46971 m
.27358 .45493 L
s
1 .698 0 r
.38973 .27625 m .37734 .24341 L .35583 .2492 L p F P
0 0 0 r
s
1 .431 0 r
.343 .22283 m .35583 .2492 L .37734 .24341 L p F P
0 0 0 r
s
1 .103 0 r
.27324 .19581 m .28706 .21485 L .30832 .20749 L p F P
0 0 0 r
s
1 .082 0 r
.28706 .21485 m .27324 .19581 L .25205 .20388 L p F P
0 0 0 r
s
1 .631 0 r
.494 .98003 m .50634 .99007 L .52865 .98465 L p F P
0 0 0 r
s
1 .477 0 r
.50634 .99007 m .494 .98003 L .47176 .98549 L p F P
0 0 0 r
s
.319 0 1 r
.45119 .60359 m .43898 .5627 L .41805 .53445 L p F P
0 0 0 r
s
.372 .62 .628 r
.67831 .4691 m
.70233 .46112 L
s
.67831 .4691 m
.66688 .4543 L
s
.616 1 0 r
.66342 .31045 m .65193 .28592 L .62994 .31794 L p F P
0 0 0 r
s
.616 1 0 r
.62994 .31794 m .64174 .34638 L .66342 .31045 L p F P
0 0 0 r
s
2 Mabswid
.64302 .46232 m
.64753 .46871 L
s
.372 .62 .628 r
.5 Mabswid
.34716 .46849 m
.3697 .4605 L
s
.34716 .46849 m
.33297 .45368 L
s
1 .615 0 r
.55115 .97919 m .56304 .98924 L .58561 .98381 L p F P
0 0 0 r
s
1 .515 0 r
.56304 .98924 m .55115 .97919 L .52865 .98465 L p F P
0 0 0 r
s
.372 .62 .628 r
.73751 .46788 m
.76181 .45988 L
s
.73751 .46788 m
.72656 .45306 L
s
1 .123 0 r
.77514 .21011 m .76488 .19315 L .74173 .20546 L p F P
0 0 0 r
s
.372 .62 .628 r
.40493 .46595 m
.40596 .46706 L
s
.40596 .46706 m
.40607 .46718 L
s
1 .465 0 r
.60838 .97834 m .61982 .98841 L .64265 .98297 L p F P
0 0 0 r
s
1 .431 0 r
.61982 .98841 m .60838 .97834 L .58561 .98381 L p F P
0 0 0 r
s
0 1 .182 r
.65332 .3714 m .64174 .34638 L .62 .38823 L p F P
0 0 0 r
s
0 1 .182 r
.62 .38823 m .63189 .41694 L .65332 .3714 L p F P
0 0 0 r
s
.372 .62 .628 r
.79679 .46665 m
.82137 .45865 L
s
.79679 .46665 m
.78633 .45181 L
s
1 .103 0 r
.28755 .97792 m .30154 .98799 L .32301 .98255 L p F P
0 0 0 r
s
.372 .62 .628 r
.46522 .46604 m
.48833 .45803 L
s
.46522 .46604 m
.452 .45119 L
s
1 .273 0 r
.66568 .9775 m .67668 .98757 L .69977 .98213 L p F P
0 0 0 r
s
1 .28 0 r
.67668 .98757 m .66568 .9775 L .64265 .98297 L p F P
0 0 0 r
s
.372 .62 .628 r
.13343 .46542 m
.15505 .45741 L
s
.13343 .46542 m
.11744 .45057 L
s
.84618 .45057 m
.85615 .46542 L
s
1 .253 0 r
.34466 .97707 m .35821 .98716 L .37993 .98171 L p F P
0 0 0 r
s
1 .148 0 r
.35821 .98716 m .34466 .97707 L .32301 .98255 L p F P
0 0 0 r
s
1 .318 0 r
.68523 .21733 m .69631 .23755 L .71887 .21995 L p F P
0 0 0 r
s
1 .515 0 r
.69631 .23755 m .68523 .21733 L .66267 .23674 L p F P
0 0 0 r
s
1 .515 0 r
.66267 .23674 m .67402 .25926 L .69631 .23755 L p F P
0 0 0 r
s
0 1 .882 r
.43692 .47088 m .42526 .41389 L .40382 .40791 L p F P
0 0 0 r
s
.372 .62 .628 r
.39244 .45244 m
.40248 .46329 L
s
.43616 .46719 m
.44232 .47398 L
s
0 1 .882 r
.40382 .40791 m .41539 .46021 L .43692 .47088 L p F P
0 0 0 r
s
.372 .62 .628 r
.41617 .46375 m
.4199 .46244 L
s
.40248 .46329 m
.40485 .46585 L
s
.40485 .46585 m
.40493 .46595 L
s
0 0 0 r
2 Mabswid
.40639 .46673 m
.41117 .4604 L
s
.372 .62 .628 r
.5 Mabswid
.52437 .46481 m
.54776 .45679 L
s
.52437 .46481 m
.51164 .44994 L
s
1 0 .577 r
.56777 .64932 m .5562 .66929 L .5334 .67617 L p F P
0 0 0 r
s
1 .123 0 r
.72306 .97665 m .73361 .98674 L .75696 .98129 L p F P
0 0 0 r
s
1 .14 0 r
.73361 .98674 m .72306 .97665 L .69977 .98213 L p F P
0 0 0 r
s
1 .793 0 r
.67402 .25926 m .66267 .23674 L .64029 .26013 L p F P
0 0 0 r
s
1 .793 0 r
.64029 .26013 m .65193 .28592 L .67402 .25926 L p F P
0 0 0 r
s
.372 .62 .628 r
.19237 .46419 m
.21427 .45617 L
s
.19237 .46419 m
.17686 .44932 L
s
1 .477 0 r
.40184 .97622 m .41495 .98632 L .43693 .98087 L p F P
0 0 0 r
s
1 .31 0 r
.41495 .98632 m .40184 .97622 L .37993 .98171 L p F P
0 0 0 r
s
.372 .62 .628 r
.58361 .46358 m
.60728 .45555 L
s
.58361 .46358 m
.57136 .44869 L
s
.841 1 0 r
.4236 .31078 m .41151 .27017 L .38973 .27625 L p F P
0 0 0 r
s
.841 1 0 r
.38973 .27625 m .4018 .3154 L .4236 .31078 L p F P
0 0 0 r
s
1 .753 0 r
.37734 .24341 m .38973 .27625 L .41151 .27017 L p F P
0 0 0 r
s
1 .186 0 r
.70803 .20124 m .71887 .21995 L .74173 .20546 L p F P
0 0 0 r
s
1 .318 0 r
.71887 .21995 m .70803 .20124 L .68523 .21733 L p F P
0 0 0 r
s
.372 .62 .628 r
.2514 .46296 m
.27358 .45493 L
s
.2514 .46296 m
.23637 .44807 L
s
1 .698 0 r
.4591 .97538 m .47176 .98549 L .494 .98003 L p F P
0 0 0 r
s
1 .502 0 r
.47176 .98549 m .4591 .97538 L .43693 .98087 L p F P
0 0 0 r
s
.306 1 0 r
.43549 .3587 m .4236 .31078 L .4018 .3154 L p F P
0 0 0 r
s
.306 1 0 r
.4018 .3154 m .4136 .36143 L .43549 .3587 L p F P
0 0 0 r
s
.372 .62 .628 r
.64591 .46135 m
.66688 .4543 L
s
.64438 .46186 m
.64591 .46135 L
s
.64293 .46235 m
.64438 .46186 L
s
1 .431 0 r
.37734 .24341 m .36459 .21575 L .343 .22283 L p F P
0 0 0 r
s
1 .253 0 r
.32979 .19992 m .343 .22283 L .36459 .21575 L p F P
0 0 0 r
s
1 .222 0 r
.343 .22283 m .32979 .19992 L .30832 .20749 L p F P
0 0 0 r
s
1 .793 0 r
.51644 .97453 m .52865 .98465 L .55115 .97919 L p F P
0 0 0 r
s
1 .631 0 r
.52865 .98465 m .51644 .97453 L .494 .98003 L p F P
0 0 0 r
s
.372 .62 .628 r
.31051 .46173 m
.33297 .45368 L
s
.31051 .46173 m
.29596 .44681 L
s
0 .891 1 r
.64346 .43901 m .63189 .41694 L .6102 .46729 L p F P
0 0 0 r
s
.372 .62 .628 r
.61409 .46399 m
.61919 .47032 L
s
0 .891 1 r
.6102 .46729 m .62208 .49158 L .64346 .43901 L p F P
0 0 0 r
s
.372 .62 .628 r
.60728 .45555 m
.61248 .462 L
s
.63974 .4583 m
.64293 .46235 L
s
.63845 .45667 m
.63974 .4583 L
s
0 0 0 r
2 Mabswid
.63885 .45756 m
.64302 .46232 L
s
.63762 .45617 m
.63885 .45756 L
s
.372 .62 .628 r
.5 Mabswid
.70233 .46112 m
.72656 .45306 L
s
.70233 .46112 m
.69105 .44619 L
s
1 .123 0 r
.29463 .18766 m .30832 .20749 L .32979 .19992 L p F P
0 0 0 r
s
1 .103 0 r
.30832 .20749 m .29463 .18766 L .27324 .19581 L p F P
0 0 0 r
s
1 .698 0 r
.57385 .97367 m .58561 .98381 L .60838 .97834 L p F P
0 0 0 r
s
1 .615 0 r
.58561 .98381 m .57385 .97367 L .55115 .97919 L p F P
0 0 0 r
s
.372 .62 .628 r
.3697 .4605 m
.39244 .45244 L
s
.3697 .4605 m
.35564 .44556 L
s
0 0 0 r
2 Mabswid
.41388 .45751 m
.41401 .45736 L
s
.41377 .45762 m
.41388 .45751 L
s
.41401 .45736 m
.41552 .45575 L
s
.41552 .45575 m
.41684 .45434 L
s
.41117 .4604 m
.41377 .45762 L
s
.5 Mabswid
.841 1 0 r
.65193 .28592 m .64029 .26013 L .61801 .28781 L p F P
0 0 0 r
s
.841 1 0 r
.61801 .28781 m .62994 .31794 L .65193 .28592 L p F P
0 0 0 r
s
1 .753 0 r
.41151 .27017 m .39914 .23625 L .37734 .24341 L p F P
0 0 0 r
s
1 .465 0 r
.36459 .21575 m .37734 .24341 L .39914 .23625 L p F P
0 0 0 r
s
.372 .62 .628 r
.76181 .45988 m
.78633 .45181 L
s
.76181 .45988 m
.75102 .44493 L
s
1 0 .712 r
.51088 .66618 m .49834 .67035 L .47633 .64455 L p F P
0 0 0 r
s
1 0 .577 r
.46368 .63168 m .47633 .64455 L .49834 .67035 L p F P
0 0 0 r
s
1 .477 0 r
.63134 .97282 m .64265 .98297 L .66568 .9775 L p F P
0 0 0 r
s
1 .465 0 r
.64265 .98297 m .63134 .97282 L .60838 .97834 L p F P
0 0 0 r
s
.372 .62 .628 r
.43417 .45744 m
.452 .45119 L
s
.4154 .4443 m
.41663 .44566 L
s
.41663 .44566 m
.42041 .44983 L
s
.42041 .44983 m
.42081 .45027 L
s
.42081 .45027 m
.42122 .45072 L
s
1 .103 0 r
.7311 .18767 m .74173 .20546 L .76488 .19315 L p F P
0 0 0 r
s
1 .186 0 r
.74173 .20546 m .7311 .18767 L .70803 .20124 L p F P
0 0 0 r
s
.077 1 0 r
.64174 .34638 m .62994 .31794 L .6079 .35491 L p F P
0 0 0 r
s
.077 1 0 r
.6079 .35491 m .62 .38823 L .64174 .34638 L p F P
0 0 0 r
s
.66 0 1 r
.62306 .56025 m .61194 .5593 L .58982 .60921 L p F P
0 0 0 r
s
.66 0 1 r
.58982 .60921 m .60127 .60744 L .62306 .56025 L p F P
0 0 0 r
s
1 .186 0 r
.30913 .9724 m .32301 .98255 L .34466 .97707 L p F P
0 0 0 r
s
1 .103 0 r
.32301 .98255 m .30913 .9724 L .28755 .97792 L p F P
0 0 0 r
s
.372 .62 .628 r
.82137 .45865 m
.84618 .45057 L
s
.82137 .45865 m
.81108 .44368 L
s
1 .253 0 r
.68891 .97197 m .69977 .98213 L .72306 .97665 L p F P
0 0 0 r
s
1 .273 0 r
.69977 .98213 m .68891 .97197 L .66568 .9775 L p F P
0 0 0 r
s
.372 .62 .628 r
.48833 .45803 m
.51164 .44994 L
s
.48833 .45803 m
.47524 .44305 L
s
1 .41 0 r
.3665 .97154 m .37993 .98171 L .40184 .97622 L p F P
0 0 0 r
s
1 .253 0 r
.37993 .98171 m .3665 .97154 L .34466 .97707 L p F P
0 0 0 r
s
0 1 .354 r
.44728 .41348 m .43549 .3587 L .4136 .36143 L p F P
0 0 0 r
s
0 1 .354 r
.4136 .36143 m .42526 .41389 L .44728 .41348 L p F P
0 0 0 r
s
.372 .62 .628 r
.15505 .45741 m
.17686 .44932 L
s
.15505 .45741 m
.13916 .44242 L
s
1 0 .296 r
.49834 .67035 m .51088 .66618 L .5334 .67617 L p F P
0 0 0 r
s
1 .103 0 r
.74655 .97111 m .75696 .98129 L .78051 .9758 L p F P
0 0 0 r
s
1 .123 0 r
.75696 .98129 m .74655 .97111 L .72306 .97665 L p F P
0 0 0 r
s
.372 .62 .628 r
.54776 .45679 m
.57136 .44869 L
s
.54776 .45679 m
.53516 .44179 L
s
.004 0 1 r
.63348 .50558 m .62208 .49158 L .60024 .54558 L p F P
0 0 0 r
s
.004 0 1 r
.60024 .54558 m .61194 .5593 L .63348 .50558 L p F P
0 0 0 r
s
1 .698 0 r
.42394 .97069 m .43693 .98087 L .4591 .97538 L p F P
0 0 0 r
s
1 .477 0 r
.43693 .98087 m .42394 .97069 L .40184 .97622 L p F P
0 0 0 r
s
0 .381 1 r
.44872 .52888 m .43692 .47088 L .41539 .46021 L p F P
0 0 0 r
s
0 .381 1 r
.41539 .46021 m .42707 .51327 L .44872 .52888 L p F P
0 0 0 r
s
.372 .62 .628 r
.21427 .45617 m
.23637 .44807 L
s
.21427 .45617 m
.19888 .44116 L
s
0 0 0 r
2 Mabswid
.63677 .45536 m
.63685 .45544 L
s
.63685 .45544 m
.63762 .45617 L
s
.372 .62 .628 r
.5 Mabswid
.60728 .45555 m
.61663 .45237 L
s
1 .923 0 r
.48147 .96983 m .494 .98003 L .51644 .97453 L p F P
0 0 0 r
s
1 .698 0 r
.494 .98003 m .48147 .96983 L .4591 .97538 L p F P
0 0 0 r
s
.372 .62 .628 r
.27358 .45493 m
.29596 .44681 L
s
.27358 .45493 m
.25867 .43989 L
s
0 0 0 r
2 Mabswid
.41684 .45434 m
.42336 .44858 L
s
.372 .62 .628 r
.5 Mabswid
.66688 .4543 m
.69105 .44619 L
s
.66688 .4543 m
.65526 .43926 L
s
1 .41 0 r
.65118 .21401 m .66267 .23674 L .68523 .21733 L p F P
0 0 0 r
s
1 .631 0 r
.66267 .23674 m .65118 .21401 L .62855 .23418 L p F P
0 0 0 r
s
1 .631 0 r
.62855 .23418 m .64029 .26013 L .66267 .23674 L p F P
0 0 0 r
s
.811 1 0 r
.44577 .30236 m .4336 .26158 L .41151 .27017 L p F P
0 0 0 r
s
.811 1 0 r
.41151 .27017 m .4236 .31078 L .44577 .30236 L p F P
0 0 0 r
s
1 .773 0 r
.39914 .23625 m .41151 .27017 L .4336 .26158 L p F P
0 0 0 r
s
1 .946 0 r
.53907 .96897 m .55115 .97919 L .57385 .97367 L p F P
0 0 0 r
s
1 .793 0 r
.55115 .97919 m .53907 .96897 L .51644 .97453 L p F P
0 0 0 r
s
1 .103 0 r
.76488 .19315 m .75446 .17585 L .7311 .18767 L p F P
0 0 0 r
s
.372 .62 .628 r
.33297 .45368 m
.35564 .44556 L
s
.33297 .45368 m
.31855 .43863 L
s
1 .253 0 r
.674 .19688 m .68523 .21733 L .70803 .20124 L p F P
0 0 0 r
s
1 .41 0 r
.68523 .21733 m .674 .19688 L .65118 .21401 L p F P
0 0 0 r
s
1 .465 0 r
.39914 .23625 m .38644 .20782 L .36459 .21575 L p F P
0 0 0 r
s
1 .273 0 r
.35148 .19196 m .36459 .21575 L .38644 .20782 L p F P
0 0 0 r
s
1 .253 0 r
.36459 .21575 m .35148 .19196 L .32979 .19992 L p F P
0 0 0 r
s
.372 .62 .628 r
.72656 .45306 m
.75102 .44493 L
s
.72656 .45306 m
.71544 .438 L
s
.389 1 0 r
.62994 .31794 m .61801 .28781 L .5957 .3194 L p F P
0 0 0 r
s
.389 1 0 r
.5957 .3194 m .6079 .35491 L .62994 .31794 L p F P
0 0 0 r
s
1 .753 0 r
.59675 .96812 m .60838 .97834 L .63134 .97282 L p F P
0 0 0 r
s
1 .698 0 r
.60838 .97834 m .59675 .96812 L .57385 .97367 L p F P
0 0 0 r
s
.262 1 0 r
.45778 .35046 m .44577 .30236 L .4236 .31078 L p F P
0 0 0 r
s
.262 1 0 r
.4236 .31078 m .43549 .3587 L .45778 .35046 L p F P
0 0 0 r
s
1 .923 0 r
.64029 .26013 m .62855 .23418 L .60601 .25759 L p F P
0 0 0 r
s
1 .923 0 r
.60601 .25759 m .61801 .28781 L .64029 .26013 L p F P
0 0 0 r
s
.372 .62 .628 r
.39244 .45244 m
.4154 .4443 L
s
.39244 .45244 m
.37851 .43736 L
s
1 .14 0 r
.31622 .17937 m .32979 .19992 L .35148 .19196 L p F P
0 0 0 r
s
1 .123 0 r
.32979 .19992 m .31622 .17937 L .29463 .18766 L p F P
0 0 0 r
s
1 .123 0 r
.27333 .96769 m .28755 .97792 L .30913 .9724 L p F P
0 0 0 r
s
.372 .62 .628 r
.78633 .45181 m
.81108 .44368 L
s
.78633 .45181 m
.7757 .43673 L
s
0 1 .882 r
.63189 .41694 m .62 .38823 L .59802 .43429 L p F P
0 0 0 r
s
0 1 .882 r
.59802 .43429 m .6102 .46729 L .63189 .41694 L p F P
0 0 0 r
s
.372 .62 .628 r
.59517 .44052 m
.60467 .45231 L
s
.62802 .44851 m
.63065 .44762 L
s
.63067 .44761 m
.63116 .44744 L
s
.63065 .44762 m
.63067 .44761 L
s
0 0 0 r
2 Mabswid
.63136 .45031 m
.63677 .45536 L
s
.372 .62 .628 r
.5 Mabswid
.63116 .44744 m
.63173 .44816 L
s
.63173 .44816 m
.63845 .45667 L
s
1 .465 0 r
.65451 .96726 m .66568 .9775 L .68891 .97197 L p F P
0 0 0 r
s
1 .477 0 r
.66568 .9775 m .65451 .96726 L .63134 .97282 L p F P
0 0 0 r
s
1 .773 0 r
.4336 .26158 m .42121 .2275 L .39914 .23625 L p F P
0 0 0 r
s
1 .477 0 r
.38644 .20782 m .39914 .23625 L .42121 .2275 L p F P
0 0 0 r
s
1 .318 0 r
.33089 .96683 m .34466 .97707 L .3665 .97154 L p F P
0 0 0 r
s
1 .186 0 r
.34466 .97707 m .33089 .96683 L .30913 .9724 L p F P
0 0 0 r
s
.372 .62 .628 r
.11744 .45057 m
.13916 .44242 L
s
.11744 .45057 m
.10118 .43546 L
s
.83605 .43546 m
.84618 .45057 L
s
1 .148 0 r
.69703 .18228 m .70803 .20124 L .7311 .18767 L p F P
0 0 0 r
s
1 .253 0 r
.70803 .20124 m .69703 .18228 L .674 .19688 L p F P
0 0 0 r
s
1 .222 0 r
.71234 .96639 m .72306 .97665 L .74655 .97111 L p F P
0 0 0 r
s
1 .253 0 r
.72306 .97665 m .71234 .96639 L .68891 .97197 L p F P
0 0 0 r
s
2 Mabswid
.62428 .4448 m
.63136 .45031 L
s
.372 .62 .628 r
.5 Mabswid
.51164 .44994 m
.53516 .44179 L
s
.51164 .44994 m
.49869 .43483 L
s
1 .631 0 r
.38853 .96596 m .40184 .97622 L .42394 .97069 L p F P
0 0 0 r
s
1 .41 0 r
.40184 .97622 m .38853 .96596 L .3665 .97154 L p F P
0 0 0 r
s
.372 .62 .628 r
.17686 .44932 m
.19888 .44116 L
s
.17686 .44932 m
.16109 .43419 L
s
1 .082 0 r
.77025 .96553 m .78051 .9758 L .80427 .97026 L p F P
0 0 0 r
s
1 .103 0 r
.78051 .9758 m .77025 .96553 L .74655 .97111 L p F P
0 0 0 r
s
0 .891 1 r
.45911 .47315 m .44728 .41348 L .42526 .41389 L p F P
0 0 0 r
s
0 .891 1 r
.42526 .41389 m .43692 .47088 L .45911 .47315 L p F P
0 0 0 r
s
.372 .62 .628 r
.45457 .45029 m
.47524 .44305 L
s
.43856 .4361 m
.44002 .43774 L
s
.44002 .43774 m
.44005 .43777 L
s
.57136 .44869 m
.59517 .44052 L
s
.57136 .44869 m
.5589 .43356 L
s
1 .971 0 r
.44624 .9651 m .4591 .97538 L .48147 .96983 L p F P
0 0 0 r
s
1 .698 0 r
.4591 .97538 m .44624 .9651 L .42394 .97069 L p F P
0 0 0 r
s
2 Mabswid
.43058 .44326 m
.43068 .44318 L
s
.42768 .44539 m
.43058 .44326 L
s
.42336 .44858 m
.42422 .44794 L
s
.372 .62 .628 r
.5 Mabswid
.23637 .44807 m
.25867 .43989 L
s
.23637 .44807 m
.22109 .43292 L
s
.717 1 0 r
.61801 .28781 m .60601 .25759 L .58349 .28394 L p F P
0 0 0 r
s
.717 1 0 r
.58349 .28394 m .5957 .3194 L .61801 .28781 L p F P
0 0 0 r
s
.841 1 0 r
.50403 .96424 m .51644 .97453 L .53907 .96897 L p F P
0 0 0 r
s
1 .923 0 r
.51644 .97453 m .50403 .96424 L .48147 .96983 L p F P
0 0 0 r
s
.372 .62 .628 r
.63116 .44744 m
.65526 .43926 L
s
.319 0 1 r
.46077 .58292 m .44872 .52888 L .42707 .51327 L p F P
0 0 0 r
s
.319 0 1 r
.42707 .51327 m .43898 .5627 L .46077 .58292 L p F P
0 0 0 r
s
.372 .62 .628 r
.29596 .44681 m
.31855 .43863 L
s
.29596 .44681 m
.28117 .43165 L
s
0 1 .414 r
.46975 .40543 m .45778 .35046 L .43549 .3587 L p F P
0 0 0 r
s
0 1 .414 r
.43549 .3587 m .44728 .41348 L .46975 .40543 L p F P
0 0 0 r
s
.841 1 0 r
.4682 .29012 m .45595 .25047 L .4336 .26158 L p F P
0 0 0 r
s
.841 1 0 r
.4336 .26158 m .44577 .30236 L .4682 .29012 L p F P
0 0 0 r
s
1 .753 0 r
.42121 .2275 m .4336 .26158 L .45595 .25047 L p F P
0 0 0 r
s
.926 1 0 r
.5619 .96337 m .57385 .97367 L .59675 .96812 L p F P
0 0 0 r
s
1 .946 0 r
.57385 .97367 m .5619 .96337 L .53907 .96897 L p F P
0 0 0 r
s
.372 .62 .628 r
.69105 .44619 m
.71544 .438 L
s
.69105 .44619 m
.67958 .43101 L
s
0 1 .54 r
.62 .38823 m .6079 .35491 L .58566 .39534 L p F P
0 0 0 r
s
0 1 .54 r
.58566 .39534 m .59802 .43429 L .62 .38823 L p F P
0 0 0 r
s
.372 .62 .628 r
.6192 .43228 m
.62616 .4411 L
s
.62616 .4411 m
.63116 .44744 L
s
1 .082 0 r
.72032 .16961 m .7311 .18767 L .75446 .17585 L p F P
0 0 0 r
s
1 .148 0 r
.7311 .18767 m .72032 .16961 L .69703 .18228 L p F P
0 0 0 r
s
.372 .62 .628 r
.35564 .44556 m
.37851 .43736 L
s
.35564 .44556 m
.34134 .43037 L
s
1 0 .577 r
.49834 .67035 m .48569 .6575 L .46368 .63168 L p F P
0 0 0 r
s
1 0 .712 r
.45119 .60359 m .46368 .63168 L .48569 .6575 L p F P
0 0 0 r
s
1 .477 0 r
.42121 .2275 m .40853 .19892 L .38644 .20782 L p F P
0 0 0 r
s
1 .28 0 r
.37341 .1835 m .38644 .20782 L .40853 .19892 L p F P
0 0 0 r
s
1 .273 0 r
.38644 .20782 m .37341 .1835 L .35148 .19196 L p F P
0 0 0 r
s
1 .773 0 r
.61985 .96251 m .63134 .97282 L .65451 .96726 L p F P
0 0 0 r
s
1 .753 0 r
.63134 .97282 m .61985 .96251 L .59675 .96812 L p F P
0 0 0 r
s
.372 .62 .628 r
.75102 .44493 m
.7757 .43673 L
s
.75102 .44493 m
.74005 .42973 L
s
0 0 0 r
2 Mabswid
.62116 .44276 m
.62428 .4448 L
s
.61643 .43968 m
.62048 .44232 L
s
.5 Mabswid
.306 1 0 r
.48035 .33668 m .4682 .29012 L .44577 .30236 L p F P
0 0 0 r
s
.306 1 0 r
.44577 .30236 m .45778 .35046 L .48035 .33668 L p F P
0 0 0 r
s
1 .477 0 r
.61673 .20891 m .62855 .23418 L .65118 .21401 L p F P
0 0 0 r
s
1 .698 0 r
.62855 .23418 m .61673 .20891 L .59398 .22853 L p F P
0 0 0 r
s
1 .698 0 r
.59398 .22853 m .60601 .25759 L .62855 .23418 L p F P
0 0 0 r
s
1 .222 0 r
.29502 .96207 m .30913 .9724 L .33089 .96683 L p F P
0 0 0 r
s
1 .123 0 r
.30913 .9724 m .29502 .96207 L .27333 .96769 L p F P
0 0 0 r
s
.372 .62 .628 r
.4154 .4443 m
.43609 .43697 L
s
.43609 .43697 m
.43856 .4361 L
s
.40159 .42909 m
.4154 .4443 L
s
1 .31 0 r
.6396 .19163 m .65118 .21401 L .674 .19688 L p F P
0 0 0 r
s
1 .477 0 r
.65118 .21401 m .6396 .19163 L .61673 .20891 L p F P
0 0 0 r
s
1 .152 0 r
.33803 .17083 m .35148 .19196 L .37341 .1835 L p F P
0 0 0 r
s
1 .14 0 r
.35148 .19196 m .33803 .17083 L .31622 .17937 L p F P
0 0 0 r
s
1 .431 0 r
.67787 .96164 m .68891 .97197 L .71234 .96639 L p F P
0 0 0 r
s
1 .465 0 r
.68891 .97197 m .67787 .96164 L .65451 .96726 L p F P
0 0 0 r
s
1 .753 0 r
.45595 .25047 m .44352 .21715 L .42121 .2275 L p F P
0 0 0 r
s
1 .465 0 r
.40853 .19892 m .42121 .2275 L .44352 .21715 L p F P
0 0 0 r
s
.372 .62 .628 r
.81108 .44368 m
.83605 .43546 L
s
.81108 .44368 m
.80061 .42845 L
s
1 0 .712 r
.60127 .60744 m .58982 .60921 L .56715 .64936 L p F P
0 0 0 r
s
1 0 .712 r
.56715 .64936 m .57893 .64542 L .60127 .60744 L p F P
0 0 0 r
s
1 .515 0 r
.35285 .96121 m .3665 .97154 L .38853 .96596 L p F P
0 0 0 r
s
1 .318 0 r
.3665 .97154 m .35285 .96121 L .33089 .96683 L p F P
0 0 0 r
s
2 Mabswid
.43068 .44318 m
.43154 .44265 L
s
.43626 .43974 m
.43876 .43819 L
s
.43154 .44265 m
.43626 .43974 L
s
.5 Mabswid
0 1 .127 r
.6079 .35491 m .5957 .3194 L .57327 .35368 L p F P
0 0 0 r
s
0 1 .127 r
.57327 .35368 m .58566 .39534 L .6079 .35491 L p F P
0 0 0 r
s
1 .971 0 r
.60601 .25759 m .59398 .22853 L .57128 .25023 L p F P
0 0 0 r
s
1 .971 0 r
.57128 .25023 m .58349 .28394 L .60601 .25759 L p F P
0 0 0 r
s
1 .186 0 r
.73598 .96077 m .74655 .97111 L .77025 .96553 L p F P
0 0 0 r
s
1 .222 0 r
.74655 .97111 m .73598 .96077 L .71234 .96639 L p F P
0 0 0 r
s
.372 .62 .628 r
.13916 .44242 m
.16109 .43419 L
s
.13916 .44242 m
.12301 .42717 L
s
0 .096 1 r
.62208 .49158 m .6102 .46729 L .58808 .51894 L p F P
0 0 0 r
s
0 .096 1 r
.58808 .51894 m .60024 .54558 L .62208 .49158 L p F P
0 0 0 r
s
1 .923 0 r
.41075 .96034 m .42394 .97069 L .44624 .9651 L p F P
0 0 0 r
s
1 .631 0 r
.42394 .97069 m .41075 .96034 L .38853 .96596 L p F P
0 0 0 r
s
.372 .62 .628 r
.53516 .44179 m
.5589 .43356 L
s
.53516 .44179 m
.52235 .42653 L
s
1 .191 0 r
.66264 .17653 m .674 .19688 L .69703 .18228 L p F P
0 0 0 r
s
1 .31 0 r
.674 .19688 m .66264 .17653 L .6396 .19163 L p F P
0 0 0 r
s
1 .061 0 r
.79416 .9599 m .80427 .97026 L .82824 .96467 L p F P
0 0 0 r
s
1 .082 0 r
.80427 .97026 m .79416 .9599 L .77025 .96553 L p F P
0 0 0 r
s
.372 .62 .628 r
.19888 .44116 m
.22109 .43292 L
s
.19888 .44116 m
.18322 .42589 L
s
.306 1 0 r
.5957 .3194 m .58349 .28394 L .5609 .31226 L p F P
0 0 0 r
s
.306 1 0 r
.5609 .31226 m .57327 .35368 L .5957 .3194 L p F P
0 0 0 r
s
.717 1 0 r
.46873 .95947 m .48147 .96983 L .50403 .96424 L p F P
0 0 0 r
s
1 .971 0 r
.48147 .96983 m .46873 .95947 L .44624 .9651 L p F P
0 0 0 r
s
.901 0 1 r
.47311 .62743 m .46077 .58292 L .43898 .5627 L p F P
0 0 0 r
s
.901 0 1 r
.43898 .5627 m .45119 .60359 L .47311 .62743 L p F P
0 0 0 r
s
.372 .62 .628 r
.6117 .43485 m
.6192 .43228 L
s
.61059 .43524 m
.6117 .43485 L
s
.60833 .43601 m
.61059 .43524 L
s
.59517 .44052 m
.59974 .43896 L
s
.926 1 0 r
.49081 .27463 m .47849 .23719 L .45595 .25047 L p F P
0 0 0 r
s
.926 1 0 r
.45595 .25047 m .4682 .29012 L .49081 .27463 L p F P
0 0 0 r
s
1 .698 0 r
.44352 .21715 m .45595 .25047 L .47849 .23719 L p F P
0 0 0 r
s
.372 .62 .628 r
.25867 .43989 m
.28117 .43165 L
s
.25867 .43989 m
.24351 .42461 L
s
1 .082 0 r
.75446 .17585 m .74387 .15828 L .72032 .16961 L p F P
0 0 0 r
s
1 0 .15 r
.52105 .68141 m .5334 .67617 L .5562 .66929 L p F P
0 0 0 r
s
1 0 .296 r
.5334 .67617 m .52105 .68141 L .49834 .67035 L p F P
0 0 0 r
s
2 Mabswid
.6162 .43955 m
.61643 .43968 L
s
.60785 .43499 m
.6162 .43955 L
s
.5 Mabswid
.616 1 0 r
.52679 .9586 m .53907 .96897 L .5619 .96337 L p F P
0 0 0 r
s
.841 1 0 r
.53907 .96897 m .52679 .9586 L .50403 .96424 L p F P
0 0 0 r
s
.43 1 0 r
.50308 .31821 m .49081 .27463 L .4682 .29012 L p F P
0 0 0 r
s
.43 1 0 r
.4682 .29012 m .48035 .33668 L .50308 .31821 L p F P
0 0 0 r
s
.372 .62 .628 r
.65526 .43926 m
.67958 .43101 L
s
.64345 .42396 m
.65526 .43926 L
s
1 0 .712 r
.48569 .6575 m .47311 .62743 L .45119 .60359 L p F P
0 0 0 r
s
.717 1 0 r
.58349 .28394 m .57128 .25023 L .54858 .2733 L p F P
0 0 0 r
s
.717 1 0 r
.54858 .2733 m .5609 .31226 L .58349 .28394 L p F P
0 0 0 r
s
.372 .62 .628 r
.31855 .43863 m
.34134 .43037 L
s
.31855 .43863 m
.30388 .42332 L
s
0 1 .354 r
.4925 .3897 m .48035 .33668 L .45778 .35046 L p F P
0 0 0 r
s
0 1 .354 r
.45778 .35046 m .46975 .40543 L .4925 .3897 L p F P
0 0 0 r
s
.841 1 0 r
.58493 .95772 m .59675 .96812 L .61985 .96251 L p F P
0 0 0 r
s
.926 1 0 r
.59675 .96812 m .58493 .95772 L .5619 .96337 L p F P
0 0 0 r
s
2 Mabswid
.43876 .43819 m
.44291 .43604 L
s
.372 .62 .628 r
.5 Mabswid
.71544 .438 m
.74005 .42973 L
s
.71544 .438 m
.70413 .42268 L
s
1 .14 0 r
.25888 .95729 m .27333 .96769 L .29502 .96207 L p F P
0 0 0 r
s
1 .111 0 r
.68589 .16328 m .69703 .18228 L .72032 .16961 L p F P
0 0 0 r
s
1 .191 0 r
.69703 .18228 m .68589 .16328 L .66264 .17653 L p F P
0 0 0 r
s
.372 .62 .628 r
.37851 .43736 m
.40159 .42909 L
s
.37851 .43736 m
.36434 .42203 L
s
0 .096 1 r
.4711 .53397 m .45911 .47315 L .43692 .47088 L p F P
0 0 0 r
s
0 .096 1 r
.43692 .47088 m .44872 .52888 L .4711 .53397 L p F P
0 0 0 r
s
1 .465 0 r
.44352 .21715 m .43085 .18902 L .40853 .19892 L p F P
0 0 0 r
s
1 .273 0 r
.39556 .17444 m .40853 .19892 L .43085 .18902 L p F P
0 0 0 r
s
1 .28 0 r
.40853 .19892 m .39556 .17444 L .37341 .1835 L p F P
0 0 0 r
s
1 .753 0 r
.64315 .95685 m .65451 .96726 L .67787 .96164 L p F P
0 0 0 r
s
1 .773 0 r
.65451 .96726 m .64315 .95685 L .61985 .96251 L p F P
0 0 0 r
s
.779 0 1 r
.61194 .5593 m .60024 .54558 L .57783 .59577 L p F P
0 0 0 r
s
.779 0 1 r
.57783 .59577 m .58982 .60921 L .61194 .5593 L p F P
0 0 0 r
s
1 .698 0 r
.47849 .23719 m .46603 .20541 L .44352 .21715 L p F P
0 0 0 r
s
1 .431 0 r
.43085 .18902 m .44352 .21715 L .46603 .20541 L p F P
0 0 0 r
s
.372 .62 .628 r
.7757 .43673 m
.80061 .42845 L
s
.7757 .43673 m
.76489 .42139 L
s
1 .502 0 r
.5819 .20135 m .59398 .22853 L .61673 .20891 L p F P
0 0 0 r
s
1 .698 0 r
.59398 .22853 m .5819 .20135 L .55906 .21925 L p F P
0 0 0 r
s
1 .698 0 r
.55906 .21925 m .57128 .25023 L .59398 .22853 L p F P
0 0 0 r
s
1 .38 0 r
.3169 .95641 m .33089 .96683 L .35285 .96121 L p F P
0 0 0 r
s
1 .222 0 r
.33089 .96683 m .3169 .95641 L .29502 .96207 L p F P
0 0 0 r
s
0 .811 1 r
.48179 .46531 m .46975 .40543 L .44728 .41348 L p F P
0 0 0 r
s
0 .811 1 r
.44728 .41348 m .45911 .47315 L .48179 .46531 L p F P
0 0 0 r
s
.372 .62 .628 r
.47718 .44237 m
.49869 .43483 L
s
.46193 .42781 m
.46222 .42814 L
s
0 0 0 r
2 Mabswid
.44291 .43604 m
.44754 .43364 L
s
.5 Mabswid
1 .923 0 r
.57128 .25023 m .55906 .21925 L .53627 .23805 L p F P
0 0 0 r
s
1 .923 0 r
.53627 .23805 m .54858 .2733 L .57128 .25023 L p F P
0 0 0 r
s
.372 .62 .628 r
.43856 .4361 m
.44936 .43227 L
s
.44936 .43227 m
.45361 .43076 L
s
.45361 .43076 m
.46193 .42781 L
s
.42489 .42074 m
.43856 .4361 L
s
1 .38 0 r
.70144 .95597 m .71234 .96639 L .73598 .96077 L p F P
0 0 0 r
s
1 .431 0 r
.71234 .96639 m .70144 .95597 L .67787 .96164 L p F P
0 0 0 r
s
1 .343 0 r
.60484 .18485 m .61673 .20891 L .6396 .19163 L p F P
0 0 0 r
s
1 .502 0 r
.61673 .20891 m .60484 .18485 L .5819 .20135 L p F P
0 0 0 r
s
.616 1 0 r
.52584 .2965 m .51352 .25688 L .49081 .27463 L p F P
0 0 0 r
s
.616 1 0 r
.49081 .27463 m .50308 .31821 L .52584 .2965 L p F P
0 0 0 r
s
1 .946 0 r
.47849 .23719 m .49081 .27463 L .51352 .25688 L p F P
0 0 0 r
s
1 .156 0 r
.36005 .16197 m .37341 .1835 L .39556 .17444 L p F P
0 0 0 r
s
1 .152 0 r
.37341 .1835 m .36005 .16197 L .33803 .17083 L p F P
0 0 0 r
s
.372 .62 .628 r
.10118 .43546 m
.12301 .42717 L
s
.10118 .43546 m
.08464 .4201 L
s
.82574 .4201 m
.83605 .43546 L
s
1 .793 0 r
.37499 .95554 m .38853 .96596 L .41075 .96034 L p F P
0 0 0 r
s
1 .515 0 r
.38853 .96596 m .37499 .95554 L .35285 .96121 L p F P
0 0 0 r
s
1 .946 0 r
.51352 .25688 m .50116 .2224 L .47849 .23719 L p F P
0 0 0 r
s
1 .615 0 r
.46603 .20541 m .47849 .23719 L .50116 .2224 L p F P
0 0 0 r
s
2 Mabswid
.59863 .43078 m
.60091 .43182 L
s
.5 Mabswid
1 .148 0 r
.75982 .9551 m .77025 .96553 L .79416 .9599 L p F P
0 0 0 r
s
1 .186 0 r
.77025 .96553 m .75982 .9551 L .73598 .96077 L p F P
0 0 0 r
s
.389 1 0 r
.5609 .31226 m .54858 .2733 L .52584 .2965 L p F P
0 0 0 r
s
.841 1 0 r
.54858 .2733 m .53627 .23805 L .51352 .25688 L p F P
0 0 0 r
s
.841 1 0 r
.51352 .25688 m .52584 .2965 L .54858 .2733 L p F P
0 0 0 r
s
0 1 .127 r
.57327 .35368 m .5609 .31226 L .53819 .34086 L p F P
0 0 0 r
s
.389 1 0 r
.52584 .2965 m .53819 .34086 L .5609 .31226 L p F P
0 0 0 r
s
.372 .62 .628 r
.16109 .43419 m
.18322 .42589 L
s
.16109 .43419 m
.14505 .41881 L
s
.717 1 0 r
.43317 .95466 m .44624 .9651 L .46873 .95947 L p F P
0 0 0 r
s
1 .923 0 r
.44624 .9651 m .43317 .95466 L .41075 .96034 L p F P
0 0 0 r
s
0 1 .182 r
.51537 .36749 m .50308 .31821 L .48035 .33668 L p F P
0 0 0 r
s
0 1 .182 r
.48035 .33668 m .4925 .3897 L .51537 .36749 L p F P
0 0 0 r
s
1 .793 0 r
.50116 .2224 m .51352 .25688 L .53627 .23805 L p F P
0 0 0 r
s
2 Mabswid
.44754 .43364 m
.45052 .43236 L
s
.45148 .43195 m
.45695 .42959 L
s
.5 Mabswid
0 .381 1 r
.6102 .46729 m .59802 .43429 L .57566 .48141 L p F P
0 0 0 r
s
2 Mabswid
.60091 .43182 m
.60785 .43499 L
s
.5 Mabswid
0 .381 1 r
.57566 .48141 m .58808 .51894 L .6102 .46729 L p F P
0 0 0 r
s
1 0 .15 r
.5562 .66929 m .54411 .67446 L .52105 .68141 L p F P
0 0 0 r
s
1 0 .296 r
.57893 .64542 m .56715 .64936 L .54411 .67446 L p F P
0 0 0 r
s
1 0 .296 r
.54411 .67446 m .5562 .66929 L .57893 .64542 L p F P
0 0 0 r
s
1 .044 0 r
.81828 .95422 m .82824 .96467 L .85242 .95903 L p F P
0 0 0 r
s
1 .061 0 r
.82824 .96467 m .81828 .95422 L .79416 .9599 L p F P
0 0 0 r
s
1 .223 0 r
.62791 .16994 m .6396 .19163 L .66264 .17653 L p F P
0 0 0 r
s
1 .343 0 r
.6396 .19163 m .62791 .16994 L .60484 .18485 L p F P
0 0 0 r
s
.077 1 0 r
.53819 .34086 m .52584 .2965 L .50308 .31821 L p F P
0 0 0 r
s
1 0 .15 r
.48569 .6575 m .49834 .67035 L .52105 .68141 L p F P
0 0 0 r
s
.372 .62 .628 r
.22109 .43292 m
.24351 .42461 L
s
.22109 .43292 m
.20555 .41751 L
s
.389 1 0 r
.49142 .95378 m .50403 .96424 L .52679 .9586 L p F P
0 0 0 r
s
.717 1 0 r
.50403 .96424 m .49142 .95378 L .46873 .95947 L p F P
0 0 0 r
s
.077 1 0 r
.50308 .31821 m .51537 .36749 L .53819 .34086 L p F P
0 0 0 r
s
1 .631 0 r
.52394 .20686 m .53627 .23805 L .55906 .21925 L p F P
0 0 0 r
s
1 .793 0 r
.53627 .23805 m .52394 .20686 L .50116 .2224 L p F P
0 0 0 r
s
0 1 .671 r
.58566 .39534 m .57327 .35368 L .55062 .38845 L p F P
0 0 0 r
s
0 1 .127 r
.53819 .34086 m .55062 .38845 L .57327 .35368 L p F P
0 0 0 r
s
.372 .62 .628 r
.6192 .43228 m
.64345 .42396 L
s
.60703 .41687 m
.6192 .43228 L
s
1 .061 0 r
.70938 .15141 m .72032 .16961 L .74387 .15828 L p F P
0 0 0 r
s
1 .111 0 r
.72032 .16961 m .70938 .15141 L .68589 .16328 L p F P
0 0 0 r
s
.43 1 0 r
.54975 .9529 m .5619 .96337 L .58493 .95772 L p F P
0 0 0 r
s
.616 1 0 r
.5619 .96337 m .54975 .9529 L .52679 .9586 L p F P
0 0 0 r
s
.372 .62 .628 r
.28117 .43165 m
.30388 .42332 L
s
.28117 .43165 m
.26613 .41622 L
s
1 .515 0 r
.4887 .19269 m .50116 .2224 L .52394 .20686 L p F P
0 0 0 r
s
1 .615 0 r
.50116 .2224 m .4887 .19269 L .46603 .20541 L p F P
0 0 0 r
s
1 .477 0 r
.5468 .1913 m .55906 .21925 L .5819 .20135 L p F P
0 0 0 r
s
1 .631 0 r
.55906 .21925 m .5468 .1913 L .52394 .20686 L p F P
0 0 0 r
s
.372 .62 .628 r
.67958 .43101 m
.70413 .42268 L
s
.67958 .43101 m
.66792 .41557 L
s
0 0 0 r
2 Mabswid
.59849 .43072 m
.59863 .43078 L
s
.5 Mabswid
1 .38 0 r
.45338 .17827 m .46603 .20541 L .4887 .19269 L p F P
0 0 0 r
s
1 .431 0 r
.46603 .20541 m .45338 .17827 L .43085 .18902 L p F P
0 0 0 r
s
0 .811 1 r
.59802 .43429 m .58566 .39534 L .56313 .43654 L p F P
0 0 0 r
s
2 Mabswid
.58882 .42708 m
.59719 .43023 L
s
.59719 .43023 m
.59849 .43072 L
s
.372 .62 .628 r
.5 Mabswid
.5589 .43356 m
.56613 .43105 L
s
.59054 .43477 m
.5951 .44044 L
s
0 1 .671 r
.55062 .38845 m .56313 .43654 L .58566 .39534 L p F P
0 0 0 r
s
.372 .62 .628 r
.58286 .42525 m
.58364 .42622 L
s
.58175 .42563 m
.58286 .42525 L
s
.811 1 0 r
.60817 .95202 m .61985 .96251 L .64315 .95685 L p F P
0 0 0 r
s
.841 1 0 r
.61985 .96251 m .60817 .95202 L .58493 .95772 L p F P
0 0 0 r
s
.372 .62 .628 r
.34134 .43037 m
.36434 .42203 L
s
.34134 .43037 m
.3268 .41492 L
s
0 .811 1 r
.56313 .43654 m .57566 .48141 L .59802 .43429 L p F P
0 0 0 r
s
1 .253 0 r
.41793 .16478 m .43085 .18902 L .45338 .17827 L p F P
0 0 0 r
s
1 .273 0 r
.43085 .18902 m .41793 .16478 L .39556 .17444 L p F P
0 0 0 r
s
1 .253 0 r
.28068 .95158 m .29502 .96207 L .3169 .95641 L p F P
0 0 0 r
s
1 .14 0 r
.29502 .96207 m .28068 .95158 L .25888 .95729 L p F P
0 0 0 r
s
.372 .62 .628 r
.74005 .42973 m
.76489 .42139 L
s
.74005 .42973 m
.7289 .41427 L
s
1 .137 0 r
.65116 .15652 m .66264 .17653 L .68589 .16328 L p F P
0 0 0 r
s
1 .223 0 r
.66264 .17653 m .65116 .15652 L .62791 .16994 L p F P
0 0 0 r
s
2 Mabswid
.45695 .42959 m
.46693 .42605 L
s
.5 Mabswid
0 1 .54 r
.55062 .38845 m .53819 .34086 L .51537 .36749 L p F P
0 0 0 r
s
1 .698 0 r
.66666 .95114 m .67787 .96164 L .70144 .95597 L p F P
0 0 0 r
s
1 .753 0 r
.67787 .96164 m .66666 .95114 L .64315 .95685 L p F P
0 0 0 r
s
1 .343 0 r
.56977 .17629 m .5819 .20135 L .60484 .18485 L p F P
0 0 0 r
s
1 .477 0 r
.5819 .20135 m .56977 .17629 L .5468 .1913 L p F P
0 0 0 r
s
.372 .62 .628 r
.40159 .42909 m
.42489 .42074 L
s
.40159 .42909 m
.38755 .41362 L
s
1 .615 0 r
.33897 .9507 m .35285 .96121 L .37499 .95554 L p F P
0 0 0 r
s
1 .38 0 r
.35285 .96121 m .33897 .9507 L .3169 .95641 L p F P
0 0 0 r
s
.372 .62 .628 r
.80061 .42845 m
.82574 .4201 L
s
.80061 .42845 m
.78996 .41297 L
s
0 .891 1 r
.50475 .4473 m .4925 .3897 L .46975 .40543 L p F P
0 0 0 r
s
0 .891 1 r
.46975 .40543 m .48179 .46531 L .50475 .4473 L p F P
0 0 0 r
s
.372 .62 .628 r
.50186 .43371 m
.52235 .42653 L
s
.48552 .41945 m
.48725 .42148 L
s
1 .318 0 r
.72523 .95026 m .73598 .96077 L .75982 .9551 L p F P
0 0 0 r
s
1 .38 0 r
.73598 .96077 m .72523 .95026 L .70144 .95597 L p F P
0 0 0 r
s
.372 .62 .628 r
.47094 .42462 m
.48552 .41945 L
s
.46835 .42554 m
.47094 .42462 L
s
.46193 .42781 m
.46835 .42554 L
s
.44839 .41232 m
.46025 .42589 L
s
.46025 .42589 m
.46111 .42688 L
s
.46111 .42688 m
.46193 .42781 L
s
1 .152 0 r
.38228 .15276 m .39556 .17444 L .41793 .16478 L p F P
0 0 0 r
s
1 .156 0 r
.39556 .17444 m .38228 .15276 L .36005 .16197 L p F P
0 0 0 r
s
1 .41 0 r
.51151 .17947 m .52394 .20686 L .5468 .1913 L p F P
0 0 0 r
s
1 .515 0 r
.52394 .20686 m .51151 .17947 L .4887 .19269 L p F P
0 0 0 r
s
.841 1 0 r
.39734 .94982 m .41075 .96034 L .43317 .95466 L p F P
0 0 0 r
s
1 .793 0 r
.41075 .96034 m .39734 .94982 L .37499 .95554 L p F P
0 0 0 r
s
.372 .62 .628 r
.12301 .42717 m
.14505 .41881 L
s
.12301 .42717 m
.10659 .41167 L
s
0 0 0 r
2 Mabswid
.5785 .42393 m
.58882 .42708 L
s
.5 Mabswid
1 .111 0 r
.78388 .94937 m .79416 .9599 L .81828 .95422 L p F P
0 0 0 r
s
1 .148 0 r
.79416 .9599 m .78388 .94937 L .75982 .9551 L p F P
0 0 0 r
s
1 .234 0 r
.59286 .16217 m .60484 .18485 L .62791 .16994 L p F P
0 0 0 r
s
1 .343 0 r
.60484 .18485 m .59286 .16217 L .56977 .17629 L p F P
0 0 0 r
s
.306 1 0 r
.45579 .94893 m .46873 .95947 L .49142 .95378 L p F P
0 0 0 r
s
.717 1 0 r
.46873 .95947 m .45579 .94893 L .43317 .95466 L p F P
0 0 0 r
s
2 Mabswid
.4699 .42521 m
.473 .42432 L
s
.46693 .42605 m
.4699 .42521 L
s
.47387 .42407 m
.47738 .42307 L
s
.372 .62 .628 r
.5 Mabswid
.18322 .42589 m
.20555 .41751 L
s
.18322 .42589 m
.16729 .41037 L
s
0 1 .54 r
.51537 .36749 m .52775 .42074 L .55062 .38845 L p F P
0 0 0 r
s
0 1 .882 r
.52775 .42074 m .51537 .36749 L .4925 .3897 L p F P
0 0 0 r
s
1 .061 0 r
.74387 .15828 m .73311 .14051 L .70938 .15141 L p F P
0 0 0 r
s
.66 0 1 r
.48334 .59067 m .4711 .53397 L .44872 .52888 L p F P
0 0 0 r
s
.66 0 1 r
.44872 .52888 m .46077 .58292 L .48334 .59067 L p F P
0 0 0 r
s
1 .029 0 r
.84261 .94849 m .85242 .95903 L .87681 .95334 L p F P
0 0 0 r
s
1 .044 0 r
.85242 .95903 m .84261 .94849 L .81828 .95422 L p F P
0 0 0 r
s
1 .318 0 r
.47608 .1669 m .4887 .19269 L .51151 .17947 L p F P
0 0 0 r
s
1 .38 0 r
.4887 .19269 m .47608 .1669 L .45338 .17827 L p F P
0 0 0 r
s
.372 .62 .628 r
.58408 .42482 m
.60703 .41687 L
s
.58286 .42525 m
.58408 .42482 L
s
.57033 .40971 m
.58223 .42447 L
s
.58223 .42447 m
.58286 .42525 L
s
0 1 .882 r
.4925 .3897 m .50475 .4473 L .52775 .42074 L p F P
0 0 0 r
s
.372 .62 .628 r
.50932 .41102 m
.51411 .41672 L
s
.51411 .41672 m
.51523 .41805 L
s
.077 1 0 r
.51431 .94805 m .52679 .9586 L .54975 .9529 L p F P
0 0 0 r
s
.389 1 0 r
.52679 .9586 m .51431 .94805 L .49142 .95378 L p F P
0 0 0 r
s
.372 .62 .628 r
.24351 .42461 m
.26613 .41622 L
s
.24351 .42461 m
.22808 .40906 L
s
1 .08 0 r
.67461 .14436 m .68589 .16328 L .70938 .15141 L p F P
0 0 0 r
s
1 .137 0 r
.68589 .16328 m .67461 .14436 L .65116 .15652 L p F P
0 0 0 r
s
1 .31 0 r
.53446 .16619 m .5468 .1913 L .56977 .17629 L p F P
0 0 0 r
s
1 .41 0 r
.5468 .1913 m .53446 .16619 L .51151 .17947 L p F P
0 0 0 r
s
.372 .62 .628 r
.64345 .42396 m
.66792 .41557 L
s
.64345 .42396 m
.63143 .40841 L
s
0 0 0 r
2 Mabswid
.56851 .42153 m
.57459 .42299 L
s
.57459 .42299 m
.5785 .42393 L
s
.56776 .42135 m
.56851 .42153 L
s
.5 Mabswid
0 .811 1 r
.56313 .43654 m .55062 .38845 L .52775 .42074 L p F P
0 0 0 r
s
.372 .62 .628 r
.54472 .41869 m
.54623 .41816 L
s
.5229 .42634 m
.53264 .42292 L
s
.54623 .41816 m
.54682 .41888 L
s
.306 1 0 r
.57292 .94716 m .58493 .95772 L .60817 .95202 L p F P
0 0 0 r
s
.43 1 0 r
.58493 .95772 m .57292 .94716 L .54975 .9529 L p F P
0 0 0 r
s
.372 .62 .628 r
.30388 .42332 m
.3268 .41492 L
s
.30388 .42332 m
.28896 .40775 L
s
.004 0 1 r
.494 .52634 m .48179 .46531 L .45911 .47315 L p F P
0 0 0 r
s
.004 0 1 r
.45911 .47315 m .4711 .53397 L .494 .52634 L p F P
0 0 0 r
s
1 .152 0 r
.2442 .94672 m .25888 .95729 L .28068 .95158 L p F P
0 0 0 r
s
2 Mabswid
.47738 .42307 m
.48824 .42068 L
s
.5 Mabswid
1 .222 0 r
.4405 .1546 m .45338 .17827 L .47608 .1669 L p F P
0 0 0 r
s
1 .253 0 r
.45338 .17827 m .4405 .1546 L .41793 .16478 L p F P
0 0 0 r
s
.372 .62 .628 r
.70413 .42268 m
.7289 .41427 L
s
.70413 .42268 m
.69262 .4071 L
s
.841 1 0 r
.63161 .94627 m .64315 .95685 L .66666 .95114 L p F P
0 0 0 r
s
.811 1 0 r
.64315 .95685 m .63161 .94627 L .60817 .95202 L p F P
0 0 0 r
s
.66 0 1 r
.60024 .54558 m .58808 .51894 L .56544 .56693 L p F P
0 0 0 r
s
.66 0 1 r
.56544 .56693 m .57783 .59577 L .60024 .54558 L p F P
0 0 0 r
s
1 .152 0 r
.61611 .14906 m .62791 .16994 L .65116 .15652 L p F P
0 0 0 r
s
1 .234 0 r
.62791 .16994 m .61611 .14906 L .59286 .16217 L p F P
0 0 0 r
s
.372 .62 .628 r
.36434 .42203 m
.38755 .41362 L
s
.36434 .42203 m
.34993 .40644 L
s
1 .431 0 r
.30268 .94583 m .3169 .95641 L .33897 .9507 L p F P
0 0 0 r
s
1 .253 0 r
.3169 .95641 m .30268 .94583 L .28068 .95158 L p F P
0 0 0 r
s
.372 .62 .628 r
.76489 .42139 m
.78996 .41297 L
s
.76489 .42139 m
.7539 .40579 L
s
0 0 0 r
2 Mabswid
.55668 .41937 m
.56082 .42011 L
s
.56082 .42011 m
.56776 .42135 L
s
.5 Mabswid
1 .615 0 r
.69037 .94538 m .70144 .95597 L .72523 .95026 L p F P
0 0 0 r
s
1 .698 0 r
.70144 .95597 m .69037 .94538 L .66666 .95114 L p F P
0 0 0 r
s
.372 .62 .628 r
.42489 .42074 m
.44839 .41232 L
s
.42489 .42074 m
.41098 .40513 L
s
0 0 0 r
2 Mabswid
.4985 .41903 m
.49918 .41892 L
s
.48824 .42068 m
.4985 .41903 L
s
.49918 .41892 m
.49941 .41888 L
s
.5 Mabswid
1 .946 0 r
.36124 .94494 m .37499 .95554 L .39734 .94982 L p F P
0 0 0 r
s
1 .615 0 r
.37499 .95554 m .36124 .94494 L .33897 .9507 L p F P
0 0 0 r
s
1 .14 0 r
.40473 .14318 m .41793 .16478 L .4405 .1546 L p F P
0 0 0 r
s
1 .152 0 r
.41793 .16478 m .40473 .14318 L .38228 .15276 L p F P
0 0 0 r
s
.372 .62 .628 r
.81526 .40447 m
.82574 .4201 L
s
.08464 .4201 m
.10659 .41167 L
s
1 0 .577 r
.58982 .60921 m .57783 .59577 L .55489 .63617 L p F P
0 0 0 r
s
1 0 .577 r
.55489 .63617 m .56715 .64936 L .58982 .60921 L p F P
0 0 0 r
s
1 .253 0 r
.49895 .15519 m .51151 .17947 L .53446 .16619 L p F P
0 0 0 r
s
1 .318 0 r
.51151 .17947 m .49895 .15519 L .47608 .1669 L p F P
0 0 0 r
s
1 .253 0 r
.74922 .94449 m .75982 .9551 L .78388 .94937 L p F P
0 0 0 r
s
1 .318 0 r
.75982 .9551 m .74922 .94449 L .72523 .95026 L p F P
0 0 0 r
s
1 .223 0 r
.55754 .15322 m .56977 .17629 L .59286 .16217 L p F P
0 0 0 r
s
1 .31 0 r
.56977 .17629 m .55754 .15322 L .53446 .16619 L p F P
0 0 0 r
s
.372 .62 .628 r
.48552 .41945 m
.50932 .41102 L
s
.47212 .40382 m
.48552 .41945 L
s
.389 1 0 r
.41988 .94405 m .43317 .95466 L .45579 .94893 L p F P
0 0 0 r
s
.841 1 0 r
.43317 .95466 m .41988 .94405 L .39734 .94982 L p F P
0 0 0 r
s
2 Mabswid
.55462 .41912 m
.55668 .41937 L
s
.54535 .41801 m
.54609 .4181 L
s
.54609 .4181 m
.55462 .41912 L
s
.49941 .41888 m
.50452 .41836 L
s
.50452 .41836 m
.51079 .41771 L
s
.372 .62 .628 r
.5 Mabswid
.14505 .41881 m
.16729 .41037 L
s
.14505 .41881 m
.12874 .40316 L
s
1 .08 0 r
.80815 .9436 m .81828 .95422 L .84261 .94849 L p F P
0 0 0 r
s
1 .111 0 r
.81828 .95422 m .80815 .9436 L .78388 .94937 L p F P
0 0 0 r
s
1 0 .15 r
.52105 .68141 m .50845 .66852 L .48569 .6575 L p F P
0 0 0 r
s
1 0 .296 r
.47311 .62743 m .48569 .6575 L .50845 .66852 L p F P
0 0 0 r
s
1 .044 0 r
.69829 .13314 m .70938 .15141 L .73311 .14051 L p F P
0 0 0 r
s
1 .08 0 r
.70938 .15141 m .69829 .13314 L .67461 .14436 L p F P
0 0 0 r
s
.372 .62 .628 r
.5516 .41628 m
.57033 .40971 L
s
.54745 .41773 m
.5516 .41628 L
s
.54638 .41811 m
.54745 .41773 L
s
.54623 .41816 m
.54638 .41811 L
s
.53335 .4025 m
.54618 .4181 L
s
.54618 .4181 m
.54623 .41816 L
s
0 1 .127 r
.47861 .94315 m .49142 .95378 L .51431 .94805 L p F P
0 0 0 r
s
.306 1 0 r
.49142 .95378 m .47861 .94315 L .45579 .94893 L p F P
0 0 0 r
s
2 Mabswid
.53386 .41727 m
.54535 .41801 L
s
.5 Mabswid
0 .194 1 r
.57566 .48141 m .56313 .43654 L .54026 .47478 L p F P
0 0 0 r
s
0 .811 1 r
.52775 .42074 m .54026 .47478 L .56313 .43654 L p F P
0 0 0 r
s
2 Mabswid
.51079 .41771 m
.52231 .41717 L
s
.372 .62 .628 r
.5 Mabswid
.20555 .41751 m
.22808 .40906 L
s
.20555 .41751 m
.18974 .40184 L
s
1 .018 0 r
.86715 .94271 m .87681 .95334 L .90142 .9476 L p F P
0 0 0 r
s
1 .029 0 r
.87681 .95334 m .86715 .94271 L .84261 .94849 L p F P
0 0 0 r
s
2 Mabswid
.52526 .4172 m
.52752 .41722 L
s
.528 .41722 m
.52929 .41723 L
s
.52752 .41722 m
.528 .41722 L
s
.52929 .41723 m
.53386 .41727 L
s
.52231 .41717 m
.52526 .4172 L
s
.5 Mabswid
1 .093 0 r
.63954 .13691 m .65116 .15652 L .67461 .14436 L p F P
0 0 0 r
s
1 .152 0 r
.65116 .15652 m .63954 .13691 L .61611 .14906 L p F P
0 0 0 r
s
0 1 .182 r
.53741 .94226 m .54975 .9529 L .57292 .94716 L p F P
0 0 0 r
s
.077 1 0 r
.54975 .9529 m .53741 .94226 L .51431 .94805 L p F P
0 0 0 r
s
.372 .62 .628 r
.60703 .41687 m
.63143 .40841 L
s
.60703 .41687 m
.59466 .40119 L
s
0 .381 1 r
.54026 .47478 m .52775 .42074 L .50475 .4473 L p F P
0 0 0 r
s
1 0 .712 r
.49582 .63728 m .48334 .59067 L .46077 .58292 L p F P
0 0 0 r
s
1 0 .712 r
.46077 .58292 m .47311 .62743 L .49582 .63728 L p F P
0 0 0 r
s
1 .186 0 r
.46326 .14403 m .47608 .1669 L .49895 .15519 L p F P
0 0 0 r
s
1 .222 0 r
.47608 .1669 m .46326 .14403 L .4405 .1546 L p F P
0 0 0 r
s
.372 .62 .628 r
.26613 .41622 m
.28896 .40775 L
s
.26613 .41622 m
.25083 .40053 L
s
.262 1 0 r
.59629 .94137 m .60817 .95202 L .63161 .94627 L p F P
0 0 0 r
s
.306 1 0 r
.60817 .95202 m .59629 .94137 L .57292 .94716 L p F P
0 0 0 r
s
.372 .62 .628 r
.66792 .41557 m
.69262 .4071 L
s
.66792 .41557 m
.65606 .39987 L
s
1 .152 0 r
.58077 .14078 m .59286 .16217 L .61611 .14906 L p F P
0 0 0 r
s
1 .223 0 r
.59286 .16217 m .58077 .14078 L .55754 .15322 L p F P
0 0 0 r
s
0 .096 1 r
.51715 .50592 m .50475 .4473 L .48179 .46531 L p F P
0 0 0 r
s
0 .096 1 r
.48179 .46531 m .494 .52634 L .51715 .50592 L p F P
0 0 0 r
s
.319 0 1 r
.58808 .51894 m .57566 .48141 L .55286 .52516 L p F P
0 0 0 r
s
.319 0 1 r
.55286 .52516 m .56544 .56693 L .58808 .51894 L p F P
0 0 0 r
s
1 .273 0 r
.26611 .94092 m .28068 .95158 L .30268 .94583 L p F P
0 0 0 r
s
1 .152 0 r
.28068 .95158 m .26611 .94092 L .2442 .94672 L p F P
0 0 0 r
s
.372 .62 .628 r
.3268 .41492 m
.34993 .40644 L
s
.3268 .41492 m
.31201 .39921 L
s
1 0 0 r
.50845 .66852 m .52105 .68141 L .54411 .67446 L p F P
0 0 0 r
s
1 .191 0 r
.52198 .14342 m .53446 .16619 L .55754 .15322 L p F P
0 0 0 r
s
1 .253 0 r
.53446 .16619 m .52198 .14342 L .49895 .15519 L p F P
0 0 0 r
s
.926 1 0 r
.65525 .94047 m .66666 .95114 L .69037 .94538 L p F P
0 0 0 r
s
.841 1 0 r
.66666 .95114 m .65525 .94047 L .63161 .94627 L p F P
0 0 0 r
s
.372 .62 .628 r
.7289 .41427 m
.7539 .40579 L
s
.7289 .41427 m
.71755 .39855 L
s
0 .194 1 r
.54026 .47478 m .55286 .52516 L .57566 .48141 L p F P
0 0 0 r
s
1 .698 0 r
.32487 .94002 m .33897 .9507 L .36124 .94494 L p F P
0 0 0 r
s
1 .431 0 r
.33897 .9507 m .32487 .94002 L .30268 .94583 L p F P
0 0 0 r
s
.372 .62 .628 r
.38755 .41362 m
.41098 .40513 L
s
.38755 .41362 m
.37327 .39789 L
s
0 .381 1 r
.50475 .4473 m .51715 .50592 L .54026 .47478 L p F P
0 0 0 r
s
1 0 .296 r
.50845 .66852 m .49582 .63728 L .47311 .62743 L p F P
0 0 0 r
s
1 .515 0 r
.7143 .93957 m .72523 .95026 L .74922 .94449 L p F P
0 0 0 r
s
1 .615 0 r
.72523 .95026 m .7143 .93957 L .69037 .94538 L p F P
0 0 0 r
s
.372 .62 .628 r
.78996 .41297 m
.81526 .40447 L
s
.78996 .41297 m
.77913 .39722 L
s
1 .123 0 r
.42738 .13329 m .4405 .1546 L .46326 .14403 L p F P
0 0 0 r
s
1 .14 0 r
.4405 .1546 m .42738 .13329 L .40473 .14318 L p F P
0 0 0 r
s
.616 1 0 r
.38371 .93912 m .39734 .94982 L .41988 .94405 L p F P
0 0 0 r
s
1 .946 0 r
.39734 .94982 m .38371 .93912 L .36124 .94494 L p F P
0 0 0 r
s
.372 .62 .628 r
.44839 .41232 m
.47212 .40382 L
s
.44839 .41232 m
.43463 .39656 L
s
1 .191 0 r
.77343 .93867 m .78388 .94937 L .80815 .9436 L p F P
0 0 0 r
s
1 .253 0 r
.78388 .94937 m .77343 .93867 L .74922 .94449 L p F P
0 0 0 r
s
.372 .62 .628 r
.10659 .41167 m
.12874 .40316 L
s
0 1 .127 r
.44263 .93822 m .45579 .94893 L .47861 .94315 L p F P
0 0 0 r
s
.389 1 0 r
.45579 .94893 m .44263 .93822 L .41988 .94405 L p F P
0 0 0 r
s
1 .044 0 r
.73311 .14051 m .7222 .12256 L .69829 .13314 L p F P
0 0 0 r
s
.372 .62 .628 r
.50932 .41102 m
.53335 .4025 L
s
.50932 .41102 m
.49607 .39524 L
s
1 .054 0 r
.66318 .12556 m .67461 .14436 L .69829 .13314 L p F P
0 0 0 r
s
1 .093 0 r
.67461 .14436 m .66318 .12556 L .63954 .13691 L p F P
0 0 0 r
s
1 .054 0 r
.83263 .93777 m .84261 .94849 L .86715 .94271 L p F P
0 0 0 r
s
1 .08 0 r
.84261 .94849 m .83263 .93777 L .80815 .9436 L p F P
0 0 0 r
s
.372 .62 .628 r
.16729 .41037 m
.18974 .40184 L
s
.16729 .41037 m
.15109 .39457 L
s
1 .148 0 r
.48621 .13324 m .49895 .15519 L .52198 .14342 L p F P
0 0 0 r
s
1 .186 0 r
.49895 .15519 m .48621 .13324 L .46326 .14403 L p F P
0 0 0 r
s
0 1 .54 r
.50163 .93732 m .51431 .94805 L .53741 .94226 L p F P
0 0 0 r
s
0 1 .127 r
.51431 .94805 m .50163 .93732 L .47861 .94315 L p F P
0 0 0 r
s
.779 0 1 r
.50643 .58325 m .494 .52634 L .4711 .53397 L p F P
0 0 0 r
s
.779 0 1 r
.4711 .53397 m .48334 .59067 L .50643 .58325 L p F P
0 0 0 r
s
1 .098 0 r
.60418 .12893 m .61611 .14906 L .63954 .13691 L p F P
0 0 0 r
s
1 .152 0 r
.61611 .14906 m .60418 .12893 L .58077 .14078 L p F P
0 0 0 r
s
.372 .62 .628 r
.57033 .40971 m
.59466 .40119 L
s
.57033 .40971 m
.5576 .39391 L
s
1 .011 0 r
.89192 .93687 m .90142 .9476 L .92624 .94181 L p F P
0 0 0 r
s
1 .018 0 r
.90142 .9476 m .89192 .93687 L .86715 .94271 L p F P
0 0 0 r
s
1 .137 0 r
.54517 .13179 m .55754 .15322 L .58077 .14078 L p F P
0 0 0 r
s
1 .191 0 r
.55754 .15322 m .54517 .13179 L .52198 .14342 L p F P
0 0 0 r
s
.372 .62 .628 r
.22808 .40906 m
.25083 .40053 L
s
.22808 .40906 m
.2124 .39324 L
s
1 0 .15 r
.56715 .64936 m .55489 .63617 L .53165 .66145 L p F P
0 0 0 r
s
1 0 .15 r
.53165 .66145 m .54411 .67446 L .56715 .64936 L p F P
0 0 0 r
s
0 1 .354 r
.56071 .93642 m .57292 .94716 L .59629 .94137 L p F P
0 0 0 r
s
0 1 .182 r
.57292 .94716 m .56071 .93642 L .53741 .94226 L p F P
0 0 0 r
s
.372 .62 .628 r
.63143 .40841 m
.65606 .39987 L
s
.63143 .40841 m
.61921 .39258 L
s
1 .156 0 r
.22927 .93597 m .2442 .94672 L .26611 .94092 L p F P
0 0 0 r
s
.372 .62 .628 r
.28896 .40775 m
.31201 .39921 L
s
.28896 .40775 m
.27379 .39191 L
s
.306 1 0 r
.61987 .93552 m .63161 .94627 L .65525 .94047 L p F P
0 0 0 r
s
.262 1 0 r
.63161 .94627 m .61987 .93552 L .59629 .94137 L p F P
0 0 0 r
s
.319 0 1 r
.55286 .52516 m .54026 .47478 L .51715 .50592 L p F P
0 0 0 r
s
.372 .62 .628 r
.69262 .4071 m
.71755 .39855 L
s
.69262 .4071 m
.68092 .39125 L
s
1 .465 0 r
.28822 .93507 m .30268 .94583 L .32487 .94002 L p F P
0 0 0 r
s
1 .273 0 r
.30268 .94583 m .28822 .93507 L .26611 .94092 L p F P
0 0 0 r
s
1 0 0 r
.54411 .67446 m .53165 .66145 L .50845 .66852 L p F P
0 0 0 r
s
.372 .62 .628 r
.34993 .40644 m
.37327 .39789 L
s
.34993 .40644 m
.33527 .39058 L
s
1 .946 0 r
.67912 .93462 m .69037 .94538 L .7143 .93957 L p F P
0 0 0 r
s
.926 1 0 r
.69037 .94538 m .67912 .93462 L .65525 .94047 L p F P
0 0 0 r
s
.372 .62 .628 r
.7539 .40579 m
.77913 .39722 L
s
.7539 .40579 m
.74271 .38992 L
s
.926 1 0 r
.34726 .93416 m .36124 .94494 L .38371 .93912 L p F P
0 0 0 r
s
1 .698 0 r
.36124 .94494 m .34726 .93416 L .32487 .94002 L p F P
0 0 0 r
s
1 .103 0 r
.45022 .12315 m .46326 .14403 L .48621 .13324 L p F P
0 0 0 r
s
1 .123 0 r
.46326 .14403 m .45022 .12315 L .42738 .13329 L p F P
0 0 0 r
s
.372 .62 .628 r
.41098 .40513 m
.43463 .39656 L
s
.41098 .40513 m
.39684 .38925 L
s
1 0 .712 r
.57783 .59577 m .56544 .56693 L .54235 .60563 L p F P
0 0 0 r
s
1 0 .712 r
.54235 .60563 m .55489 .63617 L .57783 .59577 L p F P
0 0 0 r
s
1 .41 0 r
.73844 .93371 m .74922 .94449 L .77343 .93867 L p F P
0 0 0 r
s
1 .515 0 r
.74922 .94449 m .73844 .93371 L .7143 .93957 L p F P
0 0 0 r
s
.372 .62 .628 r
.80459 .38858 m
.81526 .40447 L
s
.077 1 0 r
.40638 .93326 m .41988 .94405 L .44263 .93822 L p F P
0 0 0 r
s
.616 1 0 r
.41988 .94405 m .40638 .93326 L .38371 .93912 L p F P
0 0 0 r
s
1 .029 0 r
.68703 .11481 m .69829 .13314 L .7222 .12256 L p F P
0 0 0 r
s
1 .054 0 r
.69829 .13314 m .68703 .11481 L .66318 .12556 L p F P
0 0 0 r
s
.372 .62 .628 r
.47212 .40382 m
.49607 .39524 L
s
.47212 .40382 m
.45849 .38791 L
s
1 .137 0 r
.79785 .9328 m .80815 .9436 L .83263 .93777 L p F P
0 0 0 r
s
1 .191 0 r
.80815 .9436 m .79785 .9328 L .77343 .93867 L p F P
0 0 0 r
s
1 .111 0 r
.50934 .12236 m .52198 .14342 L .54517 .13179 L p F P
0 0 0 r
s
1 .148 0 r
.52198 .14342 m .50934 .12236 L .48621 .13324 L p F P
0 0 0 r
s
1 .06 0 r
.62778 .11766 m .63954 .13691 L .66318 .12556 L p F P
0 0 0 r
s
1 .098 0 r
.63954 .13691 m .62778 .11766 L .60418 .12893 L p F P
0 0 0 r
s
.372 .62 .628 r
.12874 .40316 m
.15109 .39457 L
s
1 .093 0 r
.56854 .12043 m .58077 .14078 L .60418 .12893 L p F P
0 0 0 r
s
1 .137 0 r
.58077 .14078 m .56854 .12043 L .54517 .13179 L p F P
0 0 0 r
s
0 1 .671 r
.46558 .93235 m .47861 .94315 L .50163 .93732 L p F P
0 0 0 r
s
0 1 .127 r
.47861 .94315 m .46558 .93235 L .44263 .93822 L p F P
0 0 0 r
s
.372 .62 .628 r
.53335 .4025 m
.5576 .39391 L
s
.53335 .4025 m
.52024 .38657 L
s
1 .034 0 r
.85734 .9319 m .86715 .94271 L .89192 .93687 L p F P
0 0 0 r
s
1 .054 0 r
.86715 .94271 m .85734 .9319 L .83263 .93777 L p F P
0 0 0 r
s
.372 .62 .628 r
.18974 .40184 m
.2124 .39324 L
s
.18974 .40184 m
.17366 .3859 L
s
0 1 .882 r
.52486 .93144 m .53741 .94226 L .56071 .93642 L p F P
0 0 0 r
s
0 1 .54 r
.53741 .94226 m .52486 .93144 L .50163 .93732 L p F P
0 0 0 r
s
.66 0 1 r
.52971 .56057 m .51715 .50592 L .494 .52634 L p F P
0 0 0 r
s
.66 0 1 r
.494 .52634 m .50643 .58325 L .52971 .56057 L p F P
0 0 0 r
s
.319 0 1 r
.51715 .50592 m .52971 .56057 L .55286 .52516 L p F P
0 0 0 r
s
1 .005 0 r
.91691 .93099 m .92624 .94181 L .95129 .93597 L p F P
0 0 0 r
s
1 .011 0 r
.92624 .94181 m .91691 .93099 L .89192 .93687 L p F P
0 0 0 r
s
.372 .62 .628 r
.59466 .40119 m
.61921 .39258 L
s
.59466 .40119 m
.58207 .38523 L
s
0 1 .414 r
.58422 .93053 m .59629 .94137 L .61987 .93552 L p F P
0 0 0 r
s
0 1 .354 r
.59629 .94137 m .58422 .93053 L .56071 .93642 L p F P
0 0 0 r
s
.372 .62 .628 r
.25083 .40053 m
.27379 .39191 L
s
.25083 .40053 m
.23527 .38456 L
s
.901 0 1 r
.56544 .56693 m .55286 .52516 L .52971 .56057 L p F P
0 0 0 r
s
1 .28 0 r
.2513 .93008 m .26611 .94092 L .28822 .93507 L p F P
0 0 0 r
s
1 .156 0 r
.26611 .94092 m .2513 .93008 L .22927 .93597 L p F P
0 0 0 r
s
.372 .62 .628 r
.65606 .39987 m
.68092 .39125 L
s
.65606 .39987 m
.64399 .38389 L
s
1 0 .15 r
.49582 .63728 m .50845 .66852 L .53165 .66145 L p F P
0 0 0 r
s
1 0 .577 r
.51902 .63005 m .50643 .58325 L .48334 .59067 L p F P
0 0 0 r
s
1 0 .577 r
.48334 .59067 m .49582 .63728 L .51902 .63005 L p F P
0 0 0 r
s
.43 1 0 r
.64366 .92962 m .65525 .94047 L .67912 .93462 L p F P
0 0 0 r
s
.306 1 0 r
.65525 .94047 m .64366 .92962 L .61987 .93552 L p F P
0 0 0 r
s
.372 .62 .628 r
.31201 .39921 m
.33527 .39058 L
s
.31201 .39921 m
.29696 .38322 L
s
.901 0 1 r
.52971 .56057 m .54235 .60563 L .56544 .56693 L p F P
0 0 0 r
s
1 .753 0 r
.31053 .92917 m .32487 .94002 L .34726 .93416 L p F P
0 0 0 r
s
1 .465 0 r
.32487 .94002 m .31053 .92917 L .28822 .93507 L p F P
0 0 0 r
s
.372 .62 .628 r
.71755 .39855 m
.74271 .38992 L
s
.71755 .39855 m
.70601 .38255 L
s
1 .082 0 r
.47327 .11284 m .48621 .13324 L .50934 .12236 L p F P
0 0 0 r
s
1 .103 0 r
.48621 .13324 m .47327 .11284 L .45022 .12315 L p F P
0 0 0 r
s
1 .793 0 r
.70319 .92871 m .7143 .93957 L .73844 .93371 L p F P
0 0 0 r
s
1 .946 0 r
.7143 .93957 m .70319 .92871 L .67912 .93462 L p F P
0 0 0 r
s
.372 .62 .628 r
.37327 .39789 m
.39684 .38925 L
s
.37327 .39789 m
.35875 .38188 L
s
.43 1 0 r
.36985 .92825 m .38371 .93912 L .40638 .93326 L p F P
0 0 0 r
s
.926 1 0 r
.38371 .93912 m .36985 .92825 L .34726 .93416 L p F P
0 0 0 r
s
.372 .62 .628 r
.77913 .39722 m
.80459 .38858 L
s
.77913 .39722 m
.76811 .3812 L
s
1 .08 0 r
.53265 .11154 m .54517 .13179 L .56854 .12043 L p F P
0 0 0 r
s
1 .111 0 r
.54517 .13179 m .53265 .11154 L .50934 .12236 L p F P
0 0 0 r
s
1 .31 0 r
.7628 .9278 m .77343 .93867 L .79785 .9328 L p F P
0 0 0 r
s
1 .41 0 r
.77343 .93867 m .7628 .9278 L .73844 .93371 L p F P
0 0 0 r
s
1 .034 0 r
.65159 .10686 m .66318 .12556 L .68703 .11481 L p F P
0 0 0 r
s
1 .06 0 r
.66318 .12556 m .65159 .10686 L .62778 .11766 L p F P
0 0 0 r
s
1 .06 0 r
.5921 .1094 m .60418 .12893 L .62778 .11766 L p F P
0 0 0 r
s
1 .093 0 r
.60418 .12893 m .5921 .1094 L .56854 .12043 L p F P
0 0 0 r
s
.372 .62 .628 r
.43463 .39656 m
.45849 .38791 L
s
.43463 .39656 m
.42062 .38053 L
s
1 .029 0 r
.7222 .12256 m .71111 .10445 L .68703 .11481 L p F P
0 0 0 r
s
0 1 .54 r
.42925 .92734 m .44263 .93822 L .46558 .93235 L p F P
0 0 0 r
s
.077 1 0 r
.44263 .93822 m .42925 .92734 L .40638 .93326 L p F P
0 0 0 r
s
1 .093 0 r
.82249 .92688 m .83263 .93777 L .85734 .9319 L p F P
0 0 0 r
s
1 .137 0 r
.83263 .93777 m .82249 .92688 L .79785 .9328 L p F P
0 0 0 r
s
.372 .62 .628 r
.49607 .39524 m
.52024 .38657 L
s
.49607 .39524 m
.48258 .37918 L
s
1 0 .15 r
.53165 .66145 m .51902 .63005 L .49582 .63728 L p F P
0 0 0 r
s
0 .811 1 r
.48873 .92642 m .50163 .93732 L .52486 .93144 L p F P
0 0 0 r
s
0 1 .671 r
.50163 .93732 m .48873 .92642 L .46558 .93235 L p F P
0 0 0 r
s
.372 .62 .628 r
.15109 .39457 m
.17366 .3859 L
s
1 .02 0 r
.88227 .92597 m .89192 .93687 L .91691 .93099 L p F P
0 0 0 r
s
1 .034 0 r
.89192 .93687 m .88227 .92597 L .85734 .9319 L p F P
0 0 0 r
s
.372 .62 .628 r
.5576 .39391 m
.58207 .38523 L
s
.5576 .39391 m
.54464 .37783 L
s
1 0 .296 r
.55489 .63617 m .54235 .60563 L .51902 .63005 L p F P
0 0 0 r
s
1 0 .296 r
.51902 .63005 m .53165 .66145 L .55489 .63617 L p F P
0 0 0 r
s
0 .891 1 r
.5483 .92551 m .56071 .93642 L .58422 .93053 L p F P
0 0 0 r
s
0 1 .882 r
.56071 .93642 m .5483 .92551 L .52486 .93144 L p F P
0 0 0 r
s
.372 .62 .628 r
.2124 .39324 m
.23527 .38456 L
s
.2124 .39324 m
.19644 .37716 L
s
1 .002 0 r
.94213 .92505 m .95129 .93597 L .97657 .93008 L p F P
0 0 0 r
s
1 .005 0 r
.95129 .93597 m .94213 .92505 L .91691 .93099 L p F P
0 0 0 r
s
1 .152 0 r
.21409 .92505 m .22927 .93597 L .2513 .93008 L p F P
0 0 0 r
s
.372 .62 .628 r
.61921 .39258 m
.64399 .38389 L
s
.61921 .39258 m
.60678 .37648 L
s
0 1 .354 r
.60794 .92459 m .61987 .93552 L .64366 .92962 L p F P
0 0 0 r
s
0 1 .414 r
.61987 .93552 m .60794 .92459 L .58422 .93053 L p F P
0 0 0 r
s
.372 .62 .628 r
.27379 .39191 m
.29696 .38322 L
s
.27379 .39191 m
.25835 .3758 L
s
1 0 .712 r
.54235 .60563 m .52971 .56057 L .50643 .58325 L p F P
0 0 0 r
s
1 .477 0 r
.27353 .92413 m .28822 .93507 L .31053 .92917 L p F P
0 0 0 r
s
1 .28 0 r
.28822 .93507 m .27353 .92413 L .2513 .93008 L p F P
0 0 0 r
s
.372 .62 .628 r
.68092 .39125 m
.70601 .38255 L
s
.68092 .39125 m
.66901 .37512 L
s
1 0 .712 r
.50643 .58325 m .51902 .63005 L .54235 .60563 L p F P
0 0 0 r
s
.616 1 0 r
.66767 .92367 m .67912 .93462 L .70319 .92871 L p F P
0 0 0 r
s
.43 1 0 r
.67912 .93462 m .66767 .92367 L .64366 .92962 L p F P
0 0 0 r
s
1 .061 0 r
.4965 .10244 m .50934 .12236 L .53265 .11154 L p F P
0 0 0 r
s
1 .082 0 r
.50934 .12236 m .4965 .10244 L .47327 .11284 L p F P
0 0 0 r
s
.372 .62 .628 r
.33527 .39058 m
.35875 .38188 L
s
.33527 .39058 m
.32035 .37445 L
s
.841 1 0 r
.33304 .92321 m .34726 .93416 L .36985 .92825 L p F P
0 0 0 r
s
1 .753 0 r
.34726 .93416 m .33304 .92321 L .31053 .92917 L p F P
0 0 0 r
s
.372 .62 .628 r
.74271 .38992 m
.76811 .3812 L
s
.74271 .38992 m
.73133 .37377 L
s
1 .054 0 r
.55615 .10082 m .56854 .12043 L .5921 .1094 L p F P
0 0 0 r
s
1 .08 0 r
.56854 .12043 m .55615 .10082 L .53265 .11154 L p F P
0 0 0 r
s
1 .631 0 r
.72749 .92275 m .73844 .93371 L .7628 .9278 L p F P
0 0 0 r
s
1 .793 0 r
.73844 .93371 m .72749 .92275 L .70319 .92871 L p F P
0 0 0 r
s
1 .036 0 r
.61586 .09868 m .62778 .11766 L .65159 .10686 L p F P
0 0 0 r
s
1 .06 0 r
.62778 .11766 m .61586 .09868 L .5921 .1094 L p F P
0 0 0 r
s
.372 .62 .628 r
.39684 .38925 m
.42062 .38053 L
s
.39684 .38925 m
.38245 .37309 L
s
1 .018 0 r
.67561 .09641 m .68703 .11481 L .71111 .10445 L p F P
0 0 0 r
s
1 .034 0 r
.68703 .11481 m .67561 .09641 L .65159 .10686 L p F P
0 0 0 r
s
0 1 .182 r
.39265 .92229 m .40638 .93326 L .42925 .92734 L p F P
0 0 0 r
s
.43 1 0 r
.40638 .93326 m .39265 .92229 L .36985 .92825 L p F P
0 0 0 r
s
.372 .62 .628 r
.79375 .37241 m
.80459 .38858 L
s
1 .223 0 r
.78738 .92183 m .79785 .9328 L .82249 .92688 L p F P
0 0 0 r
s
1 .31 0 r
.79785 .9328 m .78738 .92183 L .7628 .9278 L p F P
0 0 0 r
s
.372 .62 .628 r
.45849 .38791 m
.48258 .37918 L
s
.45849 .38791 m
.44463 .37173 L
s
0 .811 1 r
.45233 .92137 m .46558 .93235 L .48873 .92642 L p F P
0 0 0 r
s
0 1 .54 r
.46558 .93235 m .45233 .92137 L .42925 .92734 L p F P
0 0 0 r
s
1 .06 0 r
.84736 .9209 m .85734 .9319 L .88227 .92597 L p F P
0 0 0 r
s
1 .093 0 r
.85734 .9319 m .84736 .9209 L .82249 .92688 L p F P
0 0 0 r
s
.372 .62 .628 r
.52024 .38657 m
.54464 .37783 L
s
.52024 .38657 m
.5069 .37037 L
s
0 .381 1 r
.5121 .92044 m .52486 .93144 L .5483 .92551 L p F P
0 0 0 r
s
0 .811 1 r
.52486 .93144 m .5121 .92044 L .48873 .92642 L p F P
0 0 0 r
s
.372 .62 .628 r
.17366 .3859 m
.19644 .37716 L
s
1 .011 0 r
.90742 .91998 m .91691 .93099 L .94213 .92505 L p F P
0 0 0 r
s
1 .02 0 r
.91691 .93099 m .90742 .91998 L .88227 .92597 L p F P
0 0 0 r
s
0 .811 1 r
.57195 .91952 m .58422 .93053 L .60794 .92459 L p F P
0 0 0 r
s
0 .891 1 r
.58422 .93053 m .57195 .91952 L .5483 .92551 L p F P
0 0 0 r
s
.372 .62 .628 r
.58207 .38523 m
.60678 .37648 L
s
.58207 .38523 m
.56926 .36901 L
s
1 .273 0 r
.23624 .91906 m .2513 .93008 L .27353 .92413 L p F P
0 0 0 r
s
1 .152 0 r
.2513 .93008 m .23624 .91906 L .21409 .92505 L p F P
0 0 0 r
s
1 .002 0 r
.97657 .93008 m .96757 .91906 L .94213 .92505 L p F P
0 0 0 r
s
.372 .62 .628 r
.23527 .38456 m
.25835 .3758 L
s
.23527 .38456 m
.21943 .36832 L
s
0 1 .182 r
.63188 .91859 m .64366 .92962 L .66767 .92367 L p F P
0 0 0 r
s
0 1 .354 r
.64366 .92962 m .63188 .91859 L .60794 .92459 L p F P
0 0 0 r
s
.372 .62 .628 r
.64399 .38389 m
.66901 .37512 L
s
.64399 .38389 m
.63172 .36764 L
s
1 .044 0 r
.51993 .09203 m .53265 .11154 L .55615 .10082 L p F P
0 0 0 r
s
1 .061 0 r
.53265 .11154 m .51993 .09203 L .4965 .10244 L p F P
0 0 0 r
s
1 .773 0 r
.29596 .91813 m .31053 .92917 L .33304 .92321 L p F P
0 0 0 r
s
1 .477 0 r
.31053 .92917 m .29596 .91813 L .27353 .92413 L p F P
0 0 0 r
s
.372 .62 .628 r
.29696 .38322 m
.32035 .37445 L
s
.29696 .38322 m
.28165 .36696 L
s
.841 1 0 r
.6919 .91766 m .70319 .92871 L .72749 .92275 L p F P
0 0 0 r
s
.616 1 0 r
.70319 .92871 m .6919 .91766 L .66767 .92367 L p F P
0 0 0 r
s
1 .034 0 r
.57985 .09026 m .5921 .1094 L .61586 .09868 L p F P
0 0 0 r
s
1 .054 0 r
.5921 .1094 m .57985 .09026 L .55615 .10082 L p F P
0 0 0 r
s
.372 .62 .628 r
.70601 .38255 m
.73133 .37377 L
s
.70601 .38255 m
.69426 .36627 L
s
1 .02 0 r
.63982 .0882 m .65159 .10686 L .67561 .09641 L p F P
0 0 0 r
s
1 .036 0 r
.65159 .10686 m .63982 .0882 L .61586 .09868 L p F P
0 0 0 r
s
.306 1 0 r
.35576 .9172 m .36985 .92825 L .39265 .92229 L p F P
0 0 0 r
s
.841 1 0 r
.36985 .92825 m .35576 .9172 L .33304 .92321 L p F P
0 0 0 r
s
.372 .62 .628 r
.35875 .38188 m
.38245 .37309 L
s
.35875 .38188 m
.34397 .36559 L
s
1 .018 0 r
.71111 .10445 m .69986 .08617 L .67561 .09641 L p F P
0 0 0 r
s
1 .477 0 r
.752 .91674 m .7628 .9278 L .78738 .92183 L p F P
0 0 0 r
s
1 .631 0 r
.7628 .9278 m .752 .91674 L .72749 .92275 L p F P
0 0 0 r
s
.372 .62 .628 r
.76811 .3812 m
.79375 .37241 L
s
.76811 .3812 m
.7569 .3649 L
s
0 1 .882 r
.41565 .91627 m .42925 .92734 L .45233 .92137 L p F P
0 0 0 r
s
0 1 .182 r
.42925 .92734 m .41565 .91627 L .39265 .92229 L p F P
0 0 0 r
s
.372 .62 .628 r
.42062 .38053 m
.44463 .37173 L
s
.42062 .38053 m
.40637 .36422 L
s
1 .152 0 r
.81219 .91581 m .82249 .92688 L .84736 .9209 L p F P
0 0 0 r
s
1 .223 0 r
.82249 .92688 m .81219 .91581 L .78738 .92183 L p F P
0 0 0 r
s
0 .194 1 r
.47562 .91534 m .48873 .92642 L .5121 .92044 L p F P
0 0 0 r
s
0 .811 1 r
.48873 .92642 m .47562 .91534 L .45233 .92137 L p F P
0 0 0 r
s
.372 .62 .628 r
.48258 .37918 m
.5069 .37037 L
s
.48258 .37918 m
.46886 .36285 L
s
1 .036 0 r
.87245 .91487 m .88227 .92597 L .90742 .91998 L p F P
0 0 0 r
s
1 .06 0 r
.88227 .92597 m .87245 .91487 L .84736 .9209 L p F P
0 0 0 r
s
0 .096 1 r
.53567 .91441 m .5483 .92551 L .57195 .91952 L p F P
0 0 0 r
s
0 .381 1 r
.5483 .92551 m .53567 .91441 L .5121 .92044 L p F P
0 0 0 r
s
.372 .62 .628 r
.54464 .37783 m
.56926 .36901 L
s
.54464 .37783 m
.53145 .36147 L
s
1 .005 0 r
.93281 .91394 m .94213 .92505 L .96757 .91906 L p F P
0 0 0 r
s
1 .011 0 r
.94213 .92505 m .93281 .91394 L .90742 .91998 L p F P
0 0 0 r
s
1 .14 0 r
.19866 .91394 m .21409 .92505 L .23624 .91906 L p F P
0 0 0 r
s
.372 .62 .628 r
.19644 .37716 m
.21943 .36832 L
s
0 .891 1 r
.59581 .91347 m .60794 .92459 L .63188 .91859 L p F P
0 0 0 r
s
0 .811 1 r
.60794 .92459 m .59581 .91347 L .57195 .91952 L p F P
0 0 0 r
s
.372 .62 .628 r
.60678 .37648 m
.63172 .36764 L
s
.60678 .37648 m
.59413 .3601 L
s
1 .465 0 r
.25858 .91301 m .27353 .92413 L .29596 .91813 L p F P
0 0 0 r
s
1 .273 0 r
.27353 .92413 m .25858 .91301 L .23624 .91906 L p F P
0 0 0 r
s
.372 .62 .628 r
.25835 .3758 m
.28165 .36696 L
s
.25835 .3758 m
.24264 .35941 L
s
1 .029 0 r
.54357 .08165 m .55615 .10082 L .57985 .09026 L p F P
0 0 0 r
s
1 .044 0 r
.55615 .10082 m .54357 .08165 L .51993 .09203 L p F P
0 0 0 r
s
.077 1 0 r
.65604 .91254 m .66767 .92367 L .6919 .91766 L p F P
0 0 0 r
s
0 1 .182 r
.66767 .92367 m .65604 .91254 L .63188 .91859 L p F P
0 0 0 r
s
.372 .62 .628 r
.66901 .37512 m
.69426 .36627 L
s
.66901 .37512 m
.65689 .35872 L
s
1 .02 0 r
.60376 .07983 m .61586 .09868 L .63982 .0882 L p F P
0 0 0 r
s
1 .034 0 r
.61586 .09868 m .60376 .07983 L .57985 .09026 L p F P
0 0 0 r
s
.811 1 0 r
.31859 .91207 m .33304 .92321 L .35576 .9172 L p F P
0 0 0 r
s
1 .773 0 r
.33304 .92321 m .31859 .91207 L .29596 .91813 L p F P
0 0 0 r
s
.372 .62 .628 r
.32035 .37445 m
.34397 .36559 L
s
.32035 .37445 m
.30518 .35803 L
s
1 .923 0 r
.71634 .9116 m .72749 .92275 L .752 .91674 L p F P
0 0 0 r
s
.841 1 0 r
.72749 .92275 m .71634 .9116 L .6919 .91766 L p F P
0 0 0 r
s
1 .011 0 r
.66401 .0779 m .67561 .09641 L .69986 .08617 L p F P
0 0 0 r
s
1 .02 0 r
.67561 .09641 m .66401 .0779 L .63982 .0882 L p F P
0 0 0 r
s
.372 .62 .628 r
.73133 .37377 m
.7569 .3649 L
s
.73133 .37377 m
.71975 .35734 L
s
0 1 .354 r
.37868 .91114 m .39265 .92229 L .41565 .91627 L p F P
0 0 0 r
s
.306 1 0 r
.39265 .92229 m .37868 .91114 L .35576 .9172 L p F P
0 0 0 r
s
.372 .62 .628 r
.38245 .37309 m
.40637 .36422 L
s
.38245 .37309 m
.3678 .35665 L
s
1 .343 0 r
.77674 .91067 m .78738 .92183 L .81219 .91581 L p F P
0 0 0 r
s
1 .477 0 r
.78738 .92183 m .77674 .91067 L .752 .91674 L p F P
0 0 0 r
s
.372 .62 .628 r
.78271 .35596 m
.79375 .37241 L
s
0 .381 1 r
.43886 .9102 m .45233 .92137 L .47562 .91534 L p F P
0 0 0 r
s
0 1 .882 r
.45233 .92137 m .43886 .9102 L .41565 .91627 L p F P
0 0 0 r
s
.372 .62 .628 r
.44463 .37173 m
.46886 .36285 L
s
.44463 .37173 m
.43052 .35526 L
s
1 .098 0 r
.83721 .90973 m .84736 .9209 L .87245 .91487 L p F P
0 0 0 r
s
1 .152 0 r
.84736 .9209 m .83721 .90973 L .81219 .91581 L p F P
0 0 0 r
s
.319 0 1 r
.49912 .90926 m .5121 .92044 L .53567 .91441 L p F P
0 0 0 r
s
0 .194 1 r
.5121 .92044 m .49912 .90926 L .47562 .91534 L p F P
0 0 0 r
s
.372 .62 .628 r
.5069 .37037 m
.53145 .36147 L
s
.5069 .37037 m
.49333 .35388 L
s
1 .02 0 r
.89778 .90879 m .90742 .91998 L .93281 .91394 L p F P
0 0 0 r
s
1 .036 0 r
.90742 .91998 m .89778 .90879 L .87245 .91487 L p F P
0 0 0 r
s
.004 0 1 r
.55947 .90832 m .57195 .91952 L .59581 .91347 L p F P
0 0 0 r
s
0 .096 1 r
.57195 .91952 m .55947 .90832 L .53567 .91441 L p F P
0 0 0 r
s
1 .005 0 r
.96757 .91906 m .95842 .90785 L .93281 .91394 L p F P
0 0 0 r
s
1 .253 0 r
.22092 .90785 m .23624 .91906 L .25858 .91301 L p F P
0 0 0 r
s
1 .14 0 r
.23624 .91906 m .22092 .90785 L .19866 .91394 L p F P
0 0 0 r
s
.372 .62 .628 r
.56926 .36901 m
.59413 .3601 L
s
.56926 .36901 m
.55623 .35249 L
s
0 1 .882 r
.6199 .90738 m .63188 .91859 L .65604 .91254 L p F P
0 0 0 r
s
0 .891 1 r
.63188 .91859 m .6199 .90738 L .59581 .91347 L p F P
0 0 0 r
s
.372 .62 .628 r
.21943 .36832 m
.24264 .35941 L
s
1 .018 0 r
.56741 .0713 m .57985 .09026 L .60376 .07983 L p F P
0 0 0 r
s
1 .029 0 r
.57985 .09026 m .56741 .0713 L .54357 .08165 L p F P
0 0 0 r
s
1 .753 0 r
.28113 .9069 m .29596 .91813 L .31859 .91207 L p F P
0 0 0 r
s
1 .465 0 r
.29596 .91813 m .28113 .9069 L .25858 .91301 L p F P
0 0 0 r
s
.372 .62 .628 r
.63172 .36764 m
.65689 .35872 L
s
.63172 .36764 m
.61922 .3511 L
s
.389 1 0 r
.68041 .90643 m .6919 .91766 L .71634 .9116 L p F P
0 0 0 r
s
.077 1 0 r
.6919 .91766 m .68041 .90643 L .65604 .91254 L p F P
0 0 0 r
s
.372 .62 .628 r
.28165 .36696 m
.30518 .35803 L
s
.28165 .36696 m
.26608 .35041 L
s
1 .011 0 r
.62788 .0695 m .63982 .0882 L .66401 .0779 L p F P
0 0 0 r
s
1 .02 0 r
.63982 .0882 m .62788 .0695 L .60376 .07983 L p F P
0 0 0 r
s
.262 1 0 r
.34143 .90596 m .35576 .9172 L .37868 .91114 L p F P
0 0 0 r
s
.811 1 0 r
.35576 .9172 m .34143 .90596 L .31859 .91207 L p F P
0 0 0 r
s
.372 .62 .628 r
.69426 .36627 m
.71975 .35734 L
s
.69426 .36627 m
.68231 .34971 L
s
1 .011 0 r
.69986 .08617 m .68842 .06768 L .66401 .0779 L p F P
0 0 0 r
s
1 .698 0 r
.74101 .90549 m .752 .91674 L .77674 .91067 L p F P
0 0 0 r
s
1 .923 0 r
.752 .91674 m .74101 .90549 L .71634 .9116 L p F P
0 0 0 r
s
.372 .62 .628 r
.34397 .36559 m
.3678 .35665 L
s
.34397 .36559 m
.32893 .34901 L
s
0 .891 1 r
.40182 .90502 m .41565 .91627 L .43886 .9102 L p F P
0 0 0 r
s
0 1 .354 r
.41565 .91627 m .40182 .90502 L .37868 .91114 L p F P
0 0 0 r
s
.372 .62 .628 r
.7569 .3649 m
.78271 .35596 L
s
.7569 .3649 m
.74549 .34832 L
s
1 .234 0 r
.8017 .90454 m .81219 .91581 L .83721 .90973 L p F P
0 0 0 r
s
1 .343 0 r
.81219 .91581 m .8017 .90454 L .77674 .91067 L p F P
0 0 0 r
s
.372 .62 .628 r
.40637 .36422 m
.43052 .35526 L
s
.40637 .36422 m
.39187 .34762 L
s
.319 0 1 r
.46228 .90407 m .47562 .91534 L .49912 .90926 L p F P
0 0 0 r
s
0 .381 1 r
.47562 .91534 m .46228 .90407 L .43886 .9102 L p F P
0 0 0 r
s
1 .06 0 r
.86247 .9036 m .87245 .91487 L .89778 .90879 L p F P
0 0 0 r
s
1 .098 0 r
.87245 .91487 m .86247 .9036 L .83721 .90973 L p F P
0 0 0 r
s
.372 .62 .628 r
.46886 .36285 m
.49333 .35388 L
s
.46886 .36285 m
.4549 .34622 L
s
.66 0 1 r
.52284 .90312 m .53567 .91441 L .55947 .90832 L p F P
0 0 0 r
s
.319 0 1 r
.53567 .91441 m .52284 .90312 L .49912 .90926 L p F P
0 0 0 r
s
1 .011 0 r
.92333 .90265 m .93281 .91394 L .95842 .90785 L p F P
0 0 0 r
s
1 .02 0 r
.93281 .91394 m .92333 .90265 L .89778 .90879 L p F P
0 0 0 r
s
1 .123 0 r
.18296 .90265 m .19866 .91394 L .22092 .90785 L p F P
0 0 0 r
s
.372 .62 .628 r
.53145 .36147 m
.55623 .35249 L
s
.53145 .36147 m
.51803 .34482 L
s
0 .096 1 r
.58348 .90217 m .59581 .91347 L .6199 .90738 L p F P
0 0 0 r
s
.004 0 1 r
.59581 .91347 m .58348 .90217 L .55947 .90832 L p F P
0 0 0 r
s
1 .431 0 r
.24339 .9017 m .25858 .91301 L .28113 .9069 L p F P
0 0 0 r
s
1 .253 0 r
.25858 .91301 m .24339 .9017 L .22092 .90785 L p F P
0 0 0 r
s
.372 .62 .628 r
.59413 .3601 m
.61922 .3511 L
s
.59413 .3601 m
.58125 .34342 L
s
0 1 .54 r
.6442 .90122 m .65604 .91254 L .68041 .90643 L p F P
0 0 0 r
s
0 1 .882 r
.65604 .91254 m .6442 .90122 L .6199 .90738 L p F P
0 0 0 r
s
1 .011 0 r
.59147 .06098 m .60376 .07983 L .62788 .0695 L p F P
0 0 0 r
s
1 .018 0 r
.60376 .07983 m .59147 .06098 L .56741 .0713 L p F P
0 0 0 r
s
.372 .62 .628 r
.24264 .35941 m
.26608 .35041 L
s
.841 1 0 r
.30389 .90075 m .31859 .91207 L .34143 .90596 L p F P
0 0 0 r
s
1 .753 0 r
.31859 .91207 m .30389 .90075 L .28113 .9069 L p F P
0 0 0 r
s
.372 .62 .628 r
.65689 .35872 m
.68231 .34971 L
s
.65689 .35872 m
.64456 .34202 L
s
1 .005 0 r
.65222 .05922 m .66401 .0779 L .68842 .06768 L p F P
0 0 0 r
s
1 .011 0 r
.66401 .0779 m .65222 .05922 L .62788 .0695 L p F P
0 0 0 r
s
.717 1 0 r
.70501 .90027 m .71634 .9116 L .74101 .90549 L p F P
0 0 0 r
s
.389 1 0 r
.71634 .9116 m .70501 .90027 L .68041 .90643 L p F P
0 0 0 r
s
.372 .62 .628 r
.30518 .35803 m
.32893 .34901 L
s
.30518 .35803 m
.28973 .34132 L
s
0 1 .414 r
.36448 .89979 m .37868 .91114 L .40182 .90502 L p F P
0 0 0 r
s
.262 1 0 r
.37868 .91114 m .36448 .89979 L .34143 .90596 L p F P
0 0 0 r
s
.372 .62 .628 r
.71975 .35734 m
.74549 .34832 L
s
.71975 .35734 m
.70797 .34062 L
s
1 .502 0 r
.76591 .89932 m .77674 .91067 L .8017 .90454 L p F P
0 0 0 r
s
1 .698 0 r
.77674 .91067 m .76591 .89932 L .74101 .90549 L p F P
0 0 0 r
s
.372 .62 .628 r
.3678 .35665 m
.39187 .34762 L
s
.3678 .35665 m
.3529 .33991 L
s
0 .096 1 r
.42516 .89884 m .43886 .9102 L .46228 .90407 L p F P
0 0 0 r
s
0 .891 1 r
.43886 .9102 m .42516 .89884 L .40182 .90502 L p F P
0 0 0 r
s
.372 .62 .628 r
.77147 .33921 m
.78271 .35596 L
s
1 .152 0 r
.8269 .89836 m .83721 .90973 L .86247 .9036 L p F P
0 0 0 r
s
1 .234 0 r
.83721 .90973 m .8269 .89836 L .8017 .90454 L p F P
0 0 0 r
s
.372 .62 .628 r
.43052 .35526 m
.4549 .34622 L
s
.43052 .35526 m
.41616 .33851 L
s
.901 0 1 r
.48593 .89788 m .49912 .90926 L .52284 .90312 L p F P
0 0 0 r
s
.319 0 1 r
.49912 .90926 m .48593 .89788 L .46228 .90407 L p F P
0 0 0 r
s
1 .034 0 r
.88797 .89741 m .89778 .90879 L .92333 .90265 L p F P
0 0 0 r
s
1 .06 0 r
.89778 .90879 m .88797 .89741 L .86247 .9036 L p F P
0 0 0 r
s
.372 .62 .628 r
.49333 .35388 m
.51803 .34482 L
s
.49333 .35388 m
.47952 .3371 L
s
.779 0 1 r
.54677 .89693 m .55947 .90832 L .58348 .90217 L p F P
0 0 0 r
s
.66 0 1 r
.55947 .90832 m .54677 .89693 L .52284 .90312 L p F P
0 0 0 r
s
1 .222 0 r
.20534 .89645 m .22092 .90785 L .24339 .9017 L p F P
0 0 0 r
s
1 .123 0 r
.22092 .90785 m .20534 .89645 L .18296 .90265 L p F P
0 0 0 r
s
1 .011 0 r
.95842 .90785 m .94912 .89645 L .92333 .90265 L p F P
0 0 0 r
s
0 .381 1 r
.60771 .89597 m .6199 .90738 L .6442 .90122 L p F P
0 0 0 r
s
0 .096 1 r
.6199 .90738 m .60771 .89597 L .58348 .90217 L p F P
0 0 0 r
s
.372 .62 .628 r
.55623 .35249 m
.58125 .34342 L
s
.55623 .35249 m
.54297 .33568 L
s
1 .698 0 r
.26606 .89549 m .28113 .9069 L .30389 .90075 L p F P
0 0 0 r
s
1 .431 0 r
.28113 .9069 m .26606 .89549 L .24339 .9017 L p F P
0 0 0 r
s
1 .005 0 r
.61574 .05067 m .62788 .0695 L .65222 .05922 L p F P
0 0 0 r
s
1 .011 0 r
.62788 .0695 m .61574 .05067 L .59147 .06098 L p F P
0 0 0 r
s
0 1 .127 r
.66873 .89501 m .68041 .90643 L .70501 .90027 L p F P
0 0 0 r
s
0 1 .54 r
.68041 .90643 m .66873 .89501 L .6442 .90122 L p F P
0 0 0 r
s
.372 .62 .628 r
.61922 .3511 m
.64456 .34202 L
s
.61922 .3511 m
.60651 .33427 L
s
.306 1 0 r
.32686 .89453 m .34143 .90596 L .36448 .89979 L p F P
0 0 0 r
s
.841 1 0 r
.34143 .90596 m .32686 .89453 L .30389 .90075 L p F P
0 0 0 r
s
.372 .62 .628 r
.26608 .35041 m
.28973 .34132 L
s
1 .005 0 r
.68842 .06768 m .67679 .04896 L .65222 .05922 L p F P
0 0 0 r
s
1 .971 0 r
.72984 .89405 m .74101 .90549 L .76591 .89932 L p F P
0 0 0 r
s
.717 1 0 r
.74101 .90549 m .72984 .89405 L .70501 .90027 L p F P
0 0 0 r
s
.372 .62 .628 r
.68231 .34971 m
.70797 .34062 L
s
.68231 .34971 m
.67015 .33285 L
s
0 .811 1 r
.38775 .89357 m .40182 .90502 L .42516 .89884 L p F P
0 0 0 r
s
0 1 .414 r
.40182 .90502 m .38775 .89357 L .36448 .89979 L p F P
0 0 0 r
s
.372 .62 .628 r
.32893 .34901 m
.3529 .33991 L
s
.32893 .34901 m
.31362 .33214 L
s
1 .343 0 r
.79104 .89309 m .8017 .90454 L .8269 .89836 L p F P
0 0 0 r
s
1 .502 0 r
.8017 .90454 m .79104 .89309 L .76591 .89932 L p F P
0 0 0 r
s
.372 .62 .628 r
.74549 .34832 m
.77147 .33921 L
s
.74549 .34832 m
.73388 .33144 L
s
.66 0 1 r
.44872 .89261 m .46228 .90407 L .48593 .89788 L p F P
0 0 0 r
s
0 .096 1 r
.46228 .90407 m .44872 .89261 L .42516 .89884 L p F P
0 0 0 r
s
.372 .62 .628 r
.39187 .34762 m
.41616 .33851 L
s
.39187 .34762 m
.37711 .33073 L
s
1 .093 0 r
.85232 .89212 m .86247 .9036 L .88797 .89741 L p F P
0 0 0 r
s
1 .152 0 r
.86247 .9036 m .85232 .89212 L .8269 .89836 L p F P
0 0 0 r
s
1 0 .712 r
.50978 .89164 m .52284 .90312 L .54677 .89693 L p F P
0 0 0 r
s
.901 0 1 r
.52284 .90312 m .50978 .89164 L .48593 .89788 L p F P
0 0 0 r
s
.372 .62 .628 r
.4549 .34622 m
.47952 .3371 L
s
.4549 .34622 m
.44069 .3293 L
s
1 .103 0 r
.167 .89116 m .18296 .90265 L .20534 .89645 L p F P
0 0 0 r
s
1 .018 0 r
.91369 .89116 m .92333 .90265 L .94912 .89645 L p F P
0 0 0 r
s
1 .034 0 r
.92333 .90265 m .91369 .89116 L .88797 .89741 L p F P
0 0 0 r
s
.66 0 1 r
.57093 .89068 m .58348 .90217 L .60771 .89597 L p F P
0 0 0 r
s
.779 0 1 r
.58348 .90217 m .57093 .89068 L .54677 .89693 L p F P
0 0 0 r
s
.372 .62 .628 r
.51803 .34482 m
.54297 .33568 L
s
.51803 .34482 m
.50437 .32788 L
s
1 .38 0 r
.22793 .89019 m .24339 .9017 L .26606 .89549 L p F P
0 0 0 r
s
1 .222 0 r
.24339 .9017 m .22793 .89019 L .20534 .89645 L p F P
0 0 0 r
s
0 .811 1 r
.63217 .88971 m .6442 .90122 L .66873 .89501 L p F P
0 0 0 r
s
0 .381 1 r
.6442 .90122 m .63217 .88971 L .60771 .89597 L p F P
0 0 0 r
s
.372 .62 .628 r
.58125 .34342 m
.60651 .33427 L
s
.58125 .34342 m
.56815 .32645 L
s
.926 1 0 r
.28894 .88922 m .30389 .90075 L .32686 .89453 L p F P
0 0 0 r
s
1 .698 0 r
.30389 .90075 m .28894 .88922 L .26606 .89549 L p F P
0 0 0 r
s
1 .002 0 r
.64024 .04034 m .65222 .05922 L .67679 .04896 L p F P
0 0 0 r
s
1 .005 0 r
.65222 .05922 m .64024 .04034 L .61574 .05067 L p F P
0 0 0 r
s
.306 1 0 r
.69349 .88874 m .70501 .90027 L .72984 .89405 L p F P
0 0 0 r
s
0 1 .127 r
.70501 .90027 m .69349 .88874 L .66873 .89501 L p F P
0 0 0 r
s
.372 .62 .628 r
.64456 .34202 m
.67015 .33285 L
s
.64456 .34202 m
.63201 .32503 L
s
0 1 .354 r
.35004 .88826 m .36448 .89979 L .38775 .89357 L p F P
0 0 0 r
s
.306 1 0 r
.36448 .89979 m .35004 .88826 L .32686 .89453 L p F P
0 0 0 r
s
.372 .62 .628 r
.28973 .34132 m
.31362 .33214 L
s
1 .698 0 r
.7549 .88777 m .76591 .89932 L .79104 .89309 L p F P
0 0 0 r
s
1 .971 0 r
.76591 .89932 m .7549 .88777 L .72984 .89405 L p F P
0 0 0 r
s
.372 .62 .628 r
.70797 .34062 m
.73388 .33144 L
s
.70797 .34062 m
.69598 .3236 L
s
.004 0 1 r
.41123 .88729 m .42516 .89884 L .44872 .89261 L p F P
0 0 0 r
s
0 .811 1 r
.42516 .89884 m .41123 .88729 L .38775 .89357 L p F P
0 0 0 r
s
.372 .62 .628 r
.3529 .33991 m
.37711 .33073 L
s
.3529 .33991 m
.33773 .32288 L
s
1 .223 0 r
.8164 .8868 m .8269 .89836 L .85232 .89212 L p F P
0 0 0 r
s
1 .343 0 r
.8269 .89836 m .8164 .8868 L .79104 .89309 L p F P
0 0 0 r
s
.372 .62 .628 r
.76004 .32217 m
.77147 .33921 L
s
1 0 .712 r
.4725 .88631 m .48593 .89788 L .50978 .89164 L p F P
0 0 0 r
s
.66 0 1 r
.48593 .89788 m .4725 .88631 L .44872 .89261 L p F P
0 0 0 r
s
.372 .62 .628 r
.41616 .33851 m
.44069 .3293 L
s
.41616 .33851 m
.40155 .32145 L
s
1 .054 0 r
.87799 .88583 m .88797 .89741 L .91369 .89116 L p F P
0 0 0 r
s
1 .093 0 r
.88797 .89741 m .87799 .88583 L .85232 .89212 L p F P
0 0 0 r
s
1 0 .577 r
.53387 .88534 m .54677 .89693 L .57093 .89068 L p F P
0 0 0 r
s
1 0 .712 r
.54677 .89693 m .53387 .88534 L .50978 .89164 L p F P
0 0 0 r
s
.372 .62 .628 r
.47952 .3371 m
.50437 .32788 L
s
.47952 .3371 m
.46546 .32001 L
s
1 .018 0 r
.94912 .89645 m .93966 .88485 L .91369 .89116 L p F P
0 0 0 r
s
1 .186 0 r
.1895 .88485 m .20534 .89645 L .22793 .89019 L p F P
0 0 0 r
s
1 .103 0 r
.20534 .89645 m .1895 .88485 L .167 .89116 L p F P
0 0 0 r
s
.319 0 1 r
.59531 .88437 m .60771 .89597 L .63217 .88971 L p F P
0 0 0 r
s
.66 0 1 r
.60771 .89597 m .59531 .88437 L .57093 .89068 L p F P
0 0 0 r
s
1 .615 0 r
.25072 .88388 m .26606 .89549 L .28894 .88922 L p F P
0 0 0 r
s
1 .38 0 r
.26606 .89549 m .25072 .88388 L .22793 .89019 L p F P
0 0 0 r
s
.372 .62 .628 r
.54297 .33568 m
.56815 .32645 L
s
.54297 .33568 m
.52947 .31858 L
s
0 1 .671 r
.65685 .88339 m .66873 .89501 L .69349 .88874 L p F P
0 0 0 r
s
0 .811 1 r
.66873 .89501 m .65685 .88339 L .63217 .88971 L p F P
0 0 0 r
s
.43 1 0 r
.31204 .8829 m .32686 .89453 L .35004 .88826 L p F P
0 0 0 r
s
.926 1 0 r
.32686 .89453 m .31204 .8829 L .28894 .88922 L p F P
0 0 0 r
s
.372 .62 .628 r
.60651 .33427 m
.63201 .32503 L
s
.60651 .33427 m
.59357 .31714 L
s
1 .002 0 r
.67679 .04896 m .66497 .02998 L .64024 .04034 L p F P
0 0 0 r
s
.717 1 0 r
.71848 .88241 m .72984 .89405 L .7549 .88777 L p F P
0 0 0 r
s
.306 1 0 r
.72984 .89405 m .71848 .88241 L .69349 .88874 L p F P
0 0 0 r
s
0 .891 1 r
.37344 .88192 m .38775 .89357 L .41123 .88729 L p F P
0 0 0 r
s
0 1 .354 r
.38775 .89357 m .37344 .88192 L .35004 .88826 L p F P
0 0 0 r
s
.372 .62 .628 r
.67015 .33285 m
.69598 .3236 L
s
.67015 .33285 m
.65776 .31569 L
s
1 .477 0 r
.78019 .88143 m .79104 .89309 L .8164 .8868 L p F P
0 0 0 r
s
1 .698 0 r
.79104 .89309 m .78019 .88143 L .7549 .88777 L p F P
0 0 0 r
s
.372 .62 .628 r
.31362 .33214 m
.33773 .32288 L
s
.779 0 1 r
.43493 .88094 m .44872 .89261 L .4725 .88631 L p F P
0 0 0 r
s
.004 0 1 r
.44872 .89261 m .43493 .88094 L .41123 .88729 L p F P
0 0 0 r
s
.372 .62 .628 r
.73388 .33144 m
.76004 .32217 L
s
.73388 .33144 m
.72206 .31425 L
s
1 .137 0 r
.842 .88045 m .85232 .89212 L .87799 .88583 L p F P
0 0 0 r
s
1 .223 0 r
.85232 .89212 m .842 .88045 L .8164 .8868 L p F P
0 0 0 r
s
.372 .62 .628 r
.37711 .33073 m
.40155 .32145 L
s
.37711 .33073 m
.36208 .31353 L
s
1 0 .296 r
.4965 .87996 m .50978 .89164 L .53387 .88534 L p F P
0 0 0 r
s
1 0 .712 r
.50978 .89164 m .4965 .87996 L .4725 .88631 L p F P
0 0 0 r
s
1 .029 0 r
.90389 .87947 m .91369 .89116 L .93966 .88485 L p F P
0 0 0 r
s
1 .054 0 r
.91369 .89116 m .90389 .87947 L .87799 .88583 L p F P
0 0 0 r
s
1 .082 0 r
.15077 .87947 m .167 .89116 L .1895 .88485 L p F P
0 0 0 r
s
.372 .62 .628 r
.44069 .3293 m
.46546 .32001 L
s
.44069 .3293 m
.42623 .31208 L
s
1 0 .712 r
.55817 .87898 m .57093 .89068 L .59531 .88437 L p F P
0 0 0 r
s
1 0 .577 r
.57093 .89068 m .55817 .87898 L .53387 .88534 L p F P
0 0 0 r
s
1 .318 0 r
.21221 .87849 m .22793 .89019 L .25072 .88388 L p F P
0 0 0 r
s
1 .186 0 r
.22793 .89019 m .21221 .87849 L .1895 .88485 L p F P
0 0 0 r
s
.372 .62 .628 r
.50437 .32788 m
.52947 .31858 L
s
.50437 .32788 m
.49047 .31063 L
s
0 .194 1 r
.61993 .878 m .63217 .88971 L .65685 .88339 L p F P
0 0 0 r
s
.319 0 1 r
.63217 .88971 m .61993 .878 L .59531 .88437 L p F P
0 0 0 r
s
1 .946 0 r
.27373 .87751 m .28894 .88922 L .31204 .8829 L p F P
0 0 0 r
s
1 .615 0 r
.28894 .88922 m .27373 .87751 L .25072 .88388 L p F P
0 0 0 r
s
.372 .62 .628 r
.56815 .32645 m
.59357 .31714 L
s
.56815 .32645 m
.5548 .30918 L
s
0 1 .127 r
.68177 .87701 m .69349 .88874 L .71848 .88241 L p F P
0 0 0 r
s
0 1 .671 r
.69349 .88874 m .68177 .87701 L .65685 .88339 L p F P
0 0 0 r
s
0 1 .182 r
.33535 .87652 m .35004 .88826 L .37344 .88192 L p F P
0 0 0 r
s
.43 1 0 r
.35004 .88826 m .33535 .87652 L .31204 .8829 L p F P
0 0 0 r
s
.372 .62 .628 r
.63201 .32503 m
.65776 .31569 L
s
.63201 .32503 m
.61924 .30773 L
s
1 .923 0 r
.7437 .87603 m .7549 .88777 L .78019 .88143 L p F P
0 0 0 r
s
.717 1 0 r
.7549 .88777 m .7437 .87603 L .71848 .88241 L p F P
0 0 0 r
s
0 .096 1 r
.39705 .87553 m .41123 .88729 L .43493 .88094 L p F P
0 0 0 r
s
0 .891 1 r
.41123 .88729 m .39705 .87553 L .37344 .88192 L p F P
0 0 0 r
s
.372 .62 .628 r
.69598 .3236 m
.72206 .31425 L
s
.69598 .3236 m
.68377 .30627 L
s
1 .31 0 r
.80572 .87504 m .8164 .8868 L .842 .88045 L p F P
0 0 0 r
s
1 .477 0 r
.8164 .8868 m .80572 .87504 L .78019 .88143 L p F P
0 0 0 r
s
.372 .62 .628 r
.33773 .32288 m
.36208 .31353 L
s
1 0 .577 r
.45885 .87454 m .4725 .88631 L .4965 .87996 L p F P
0 0 0 r
s
.779 0 1 r
.4725 .88631 m .45885 .87454 L .43493 .88094 L p F P
0 0 0 r
s
.372 .62 .628 r
.74839 .30481 m
.76004 .32217 L
s
1 .08 0 r
.86783 .87405 m .87799 .88583 L .90389 .87947 L p F P
0 0 0 r
s
1 .137 0 r
.87799 .88583 m .86783 .87405 L .842 .88045 L p F P
0 0 0 r
s
.372 .62 .628 r
.40155 .32145 m
.42623 .31208 L
s
.40155 .32145 m
.38667 .30408 L
s
1 0 .15 r
.52073 .87355 m .53387 .88534 L .55817 .87898 L p F P
0 0 0 r
s
1 0 .296 r
.53387 .88534 m .52073 .87355 L .4965 .87996 L p F P
0 0 0 r
s
1 .029 0 r
.93966 .88485 m .93003 .87306 L .90389 .87947 L p F P
0 0 0 r
s
1 .148 0 r
.17338 .87306 m .1895 .88485 L .21221 .87849 L p F P
0 0 0 r
s
1 .082 0 r
.1895 .88485 m .17338 .87306 L .15077 .87947 L p F P
0 0 0 r
s
.372 .62 .628 r
.46546 .32001 m
.49047 .31063 L
s
.46546 .32001 m
.45115 .30262 L
s
.901 0 1 r
.5827 .87256 m .59531 .88437 L .61993 .878 L p F P
0 0 0 r
s
1 0 .712 r
.59531 .88437 m .5827 .87256 L .55817 .87898 L p F P
0 0 0 r
s
1 .515 0 r
.23512 .87207 m .25072 .88388 L .27373 .87751 L p F P
0 0 0 r
s
1 .318 0 r
.25072 .88388 m .23512 .87207 L .21221 .87849 L p F P
0 0 0 r
s
0 .811 1 r
.64477 .87157 m .65685 .88339 L .68177 .87701 L p F P
0 0 0 r
s
0 .194 1 r
.65685 .88339 m .64477 .87157 L .61993 .878 L p F P
0 0 0 r
s
.372 .62 .628 r
.52947 .31858 m
.5548 .30918 L
s
.52947 .31858 m
.51572 .30116 L
s
.616 1 0 r
.29696 .87107 m .31204 .8829 L .33535 .87652 L p F P
0 0 0 r
s
1 .946 0 r
.31204 .8829 m .29696 .87107 L .27373 .87751 L p F P
0 0 0 r
s
.389 1 0 r
.70692 .87058 m .71848 .88241 L .7437 .87603 L p F P
0 0 0 r
s
0 1 .127 r
.71848 .88241 m .70692 .87058 L .68177 .87701 L p F P
0 0 0 r
s
.372 .62 .628 r
.59357 .31714 m
.61924 .30773 L
s
.59357 .31714 m
.58039 .29969 L
s
0 1 .882 r
.35888 .87008 m .37344 .88192 L .39705 .87553 L p F P
0 0 0 r
s
0 1 .182 r
.37344 .88192 m .35888 .87008 L .33535 .87652 L p F P
0 0 0 r
s
1 .631 0 r
.76916 .86958 m .78019 .88143 L .80572 .87504 L p F P
0 0 0 r
s
1 .923 0 r
.78019 .88143 m .76916 .86958 L .7437 .87603 L p F P
0 0 0 r
s
.372 .62 .628 r
.65776 .31569 m
.68377 .30627 L
s
.65776 .31569 m
.64516 .29823 L
s
.66 0 1 r
.42089 .86908 m .43493 .88094 L .45885 .87454 L p F P
0 0 0 r
s
0 .096 1 r
.43493 .88094 m .42089 .86908 L .39705 .87553 L p F P
0 0 0 r
s
1 .191 0 r
.83149 .86858 m .842 .88045 L .86783 .87405 L p F P
0 0 0 r
s
1 .31 0 r
.842 .88045 m .83149 .86858 L .80572 .87504 L p F P
0 0 0 r
s
.372 .62 .628 r
.72206 .31425 m
.74839 .30481 L
s
.72206 .31425 m
.71002 .29676 L
s
1 0 .15 r
.48299 .86808 m .4965 .87996 L .52073 .87355 L p F P
0 0 0 r
s
1 0 .577 r
.4965 .87996 m .48299 .86808 L .45885 .87454 L p F P
0 0 0 r
s
.372 .62 .628 r
.36208 .31353 m
.38667 .30408 L
s
1 .061 0 r
.13425 .86758 m .15077 .87947 L .17338 .87306 L p F P
0 0 0 r
s
1 .044 0 r
.89391 .86758 m .90389 .87947 L .93003 .87306 L p F P
0 0 0 r
s
1 .08 0 r
.90389 .87947 m .89391 .86758 L .86783 .87405 L p F P
0 0 0 r
s
1 0 .296 r
.54519 .86708 m .55817 .87898 L .5827 .87256 L p F P
0 0 0 r
s
1 0 .15 r
.55817 .87898 m .54519 .86708 L .52073 .87355 L p F P
0 0 0 r
s
.372 .62 .628 r
.42623 .31208 m
.45115 .30262 L
s
.42623 .31208 m
.4115 .29455 L
s
1 .253 0 r
.19621 .86658 m .21221 .87849 L .23512 .87207 L p F P
0 0 0 r
s
1 .148 0 r
.21221 .87849 m .19621 .86658 L .17338 .87306 L p F P
0 0 0 r
s
.319 0 1 r
.60747 .86608 m .61993 .878 L .64477 .87157 L p F P
0 0 0 r
s
.901 0 1 r
.61993 .878 m .60747 .86608 L .5827 .87256 L p F P
0 0 0 r
s
.372 .62 .628 r
.49047 .31063 m
.51572 .30116 L
s
.49047 .31063 m
.47631 .29307 L
s
1 .793 0 r
.25826 .86558 m .27373 .87751 L .29696 .87107 L p F P
0 0 0 r
s
1 .515 0 r
.27373 .87751 m .25826 .86558 L .23512 .87207 L p F P
0 0 0 r
s
0 1 .54 r
.66984 .86508 m .68177 .87701 L .70692 .87058 L p F P
0 0 0 r
s
0 .811 1 r
.68177 .87701 m .66984 .86508 L .64477 .87157 L p F P
0 0 0 r
s
.372 .62 .628 r
.5548 .30918 m
.58039 .29969 L
s
.5548 .30918 m
.54122 .29159 L
s
.077 1 0 r
.3204 .86458 m .33535 .87652 L .35888 .87008 L p F P
0 0 0 r
s
.616 1 0 r
.33535 .87652 m .3204 .86458 L .29696 .87107 L p F P
0 0 0 r
s
.841 1 0 r
.7323 .86408 m .7437 .87603 L .76916 .86958 L p F P
0 0 0 r
s
.389 1 0 r
.7437 .87603 m .7323 .86408 L .70692 .87058 L p F P
0 0 0 r
s
.372 .62 .628 r
.61924 .30773 m
.64516 .29823 L
s
.61924 .30773 m
.60623 .29011 L
s
0 .381 1 r
.38263 .86358 m .39705 .87553 L .42089 .86908 L p F P
0 0 0 r
s
0 1 .882 r
.39705 .87553 m .38263 .86358 L .35888 .87008 L p F P
0 0 0 r
s
1 .41 0 r
.79486 .86307 m .80572 .87504 L .83149 .86858 L p F P
0 0 0 r
s
1 .631 0 r
.80572 .87504 m .79486 .86307 L .76916 .86958 L p F P
0 0 0 r
s
.372 .62 .628 r
.68377 .30627 m
.71002 .29676 L
s
.68377 .30627 m
.67134 .28863 L
s
1 0 .712 r
.44496 .86257 m .45885 .87454 L .48299 .86808 L p F P
0 0 0 r
s
.66 0 1 r
.45885 .87454 m .44496 .86257 L .42089 .86908 L p F P
0 0 0 r
s
1 .111 0 r
.8575 .86207 m .86783 .87405 L .89391 .86758 L p F P
0 0 0 r
s
1 .191 0 r
.86783 .87405 m .8575 .86207 L .83149 .86858 L p F P
0 0 0 r
s
.372 .62 .628 r
.73654 .28715 m
.74839 .30481 L
s
1 0 0 r
.50737 .86156 m .52073 .87355 L .54519 .86708 L p F P
0 0 0 r
s
1 0 .15 r
.52073 .87355 m .50737 .86156 L .48299 .86808 L p F P
0 0 0 r
s
.372 .62 .628 r
.38667 .30408 m
.4115 .29455 L
s
1 .044 0 r
.93003 .87306 m .92024 .86106 L .89391 .86758 L p F P
0 0 0 r
s
1 .111 0 r
.15698 .86106 m .17338 .87306 L .19621 .86658 L p F P
0 0 0 r
s
1 .061 0 r
.17338 .87306 m .15698 .86106 L .13425 .86758 L p F P
0 0 0 r
s
1 0 .712 r
.56987 .86055 m .5827 .87256 L .60747 .86608 L p F P
0 0 0 r
s
1 0 .296 r
.5827 .87256 m .56987 .86055 L .54519 .86708 L p F P
0 0 0 r
s
.372 .62 .628 r
.45115 .30262 m
.47631 .29307 L
s
.45115 .30262 m
.43657 .28491 L
s
1 .41 0 r
.21925 .86005 m .23512 .87207 L .25826 .86558 L p F P
0 0 0 r
s
1 .253 0 r
.23512 .87207 m .21925 .86005 L .19621 .86658 L p F P
0 0 0 r
s
0 .381 1 r
.63247 .85954 m .64477 .87157 L .66984 .86508 L p F P
0 0 0 r
s
.319 0 1 r
.64477 .87157 m .63247 .85954 L .60747 .86608 L p F P
0 0 0 r
s
.841 1 0 r
.28161 .85904 m .29696 .87107 L .3204 .86458 L p F P
0 0 0 r
s
1 .793 0 r
.29696 .87107 m .28161 .85904 L .25826 .86558 L p F P
0 0 0 r
s
.372 .62 .628 r
.51572 .30116 m
.54122 .29159 L
s
.51572 .30116 m
.50173 .28342 L
s
.077 1 0 r
.69515 .85853 m .70692 .87058 L .7323 .86408 L p F P
0 0 0 r
s
0 1 .54 r
.70692 .87058 m .69515 .85853 L .66984 .86508 L p F P
0 0 0 r
s
0 1 .54 r
.34407 .85802 m .35888 .87008 L .38263 .86358 L p F P
0 0 0 r
s
.077 1 0 r
.35888 .87008 m .34407 .85802 L .3204 .86458 L p F P
0 0 0 r
s
.372 .62 .628 r
.58039 .29969 m
.60623 .29011 L
s
.58039 .29969 m
.56697 .28193 L
s
1 .793 0 r
.75793 .85752 m .76916 .86958 L .79486 .86307 L p F P
0 0 0 r
s
.841 1 0 r
.76916 .86958 m .75793 .85752 L .7323 .86408 L p F P
0 0 0 r
s
.319 0 1 r
.40661 .85701 m .42089 .86908 L .44496 .86257 L p F P
0 0 0 r
s
0 .381 1 r
.42089 .86908 m .40661 .85701 L .38263 .86358 L p F P
0 0 0 r
s
.372 .62 .628 r
.64516 .29823 m
.67134 .28863 L
s
.64516 .29823 m
.63232 .28044 L
s
1 .253 0 r
.8208 .8565 m .83149 .86858 L .8575 .86207 L p F P
0 0 0 r
s
1 .41 0 r
.83149 .86858 m .8208 .8565 L .79486 .86307 L p F P
0 0 0 r
s
1 0 .296 r
.46925 .856 m .48299 .86808 L .50737 .86156 L p F P
0 0 0 r
s
1 0 .712 r
.48299 .86808 m .46925 .856 L .44496 .86257 L p F P
0 0 0 r
s
.372 .62 .628 r
.71002 .29676 m
.73654 .28715 L
s
.71002 .29676 m
.69777 .27894 L
s
1 .061 0 r
.88376 .85549 m .89391 .86758 L .92024 .86106 L p F P
0 0 0 r
s
1 .111 0 r
.89391 .86758 m .88376 .85549 L .8575 .86207 L p F P
0 0 0 r
s
1 .044 0 r
.11744 .85549 m .13425 .86758 L .15698 .86106 L p F P
0 0 0 r
s
1 0 .15 r
.53198 .85498 m .54519 .86708 L .56987 .86055 L p F P
0 0 0 r
s
1 0 0 r
.54519 .86708 m .53198 .85498 L .50737 .86156 L p F P
0 0 0 r
s
1 .191 0 r
.17993 .85447 m .19621 .86658 L .21925 .86005 L p F P
0 0 0 r
s
1 .111 0 r
.19621 .86658 m .17993 .85447 L .15698 .86106 L p F P
0 0 0 r
s
.372 .62 .628 r
.4115 .29455 m
.43657 .28491 L
s
.66 0 1 r
.59479 .85396 m .60747 .86608 L .63247 .85954 L p F P
0 0 0 r
s
1 0 .712 r
.60747 .86608 m .59479 .85396 L .56987 .86055 L p F P
0 0 0 r
s
1 .631 0 r
.24252 .85345 m .25826 .86558 L .28161 .85904 L p F P
0 0 0 r
s
1 .41 0 r
.25826 .86558 m .24252 .85345 L .21925 .86005 L p F P
0 0 0 r
s
.372 .62 .628 r
.47631 .29307 m
.50173 .28342 L
s
.47631 .29307 m
.4619 .27519 L
s
0 1 .882 r
.65771 .85294 m .66984 .86508 L .69515 .85853 L p F P
0 0 0 r
s
0 .381 1 r
.66984 .86508 m .65771 .85294 L .63247 .85954 L p F P
0 0 0 r
s
.389 1 0 r
.30519 .85243 m .3204 .86458 L .34407 .85802 L p F P
0 0 0 r
s
.841 1 0 r
.3204 .86458 m .30519 .85243 L .28161 .85904 L p F P
0 0 0 r
s
.372 .62 .628 r
.54122 .29159 m
.56697 .28193 L
s
.54122 .29159 m
.52739 .27368 L
s
.616 1 0 r
.72071 .85192 m .7323 .86408 L .75793 .85752 L p F P
0 0 0 r
s
.077 1 0 r
.7323 .86408 m .72071 .85192 L .69515 .85853 L p F P
0 0 0 r
s
0 .811 1 r
.36796 .85141 m .38263 .86358 L .40661 .85701 L p F P
0 0 0 r
s
0 1 .54 r
.38263 .86358 m .36796 .85141 L .34407 .85802 L p F P
0 0 0 r
s
.372 .62 .628 r
.60623 .29011 m
.63232 .28044 L
s
.60623 .29011 m
.59298 .27218 L
s
1 .515 0 r
.7838 .8509 m .79486 .86307 L .8208 .8565 L p F P
0 0 0 r
s
1 .793 0 r
.79486 .86307 m .7838 .8509 L .75793 .85752 L p F P
0 0 0 r
s
.901 0 1 r
.43082 .85038 m .44496 .86257 L .46925 .856 L p F P
0 0 0 r
s
.319 0 1 r
.44496 .86257 m .43082 .85038 L .40661 .85701 L p F P
0 0 0 r
s
.372 .62 .628 r
.67134 .28863 m
.69777 .27894 L
s
.67134 .28863 m
.65868 .27067 L
s
1 .148 0 r
.84699 .84987 m .8575 .86207 L .88376 .85549 L p F P
0 0 0 r
s
1 .253 0 r
.8575 .86207 m .84699 .84987 L .8208 .8565 L p F P
0 0 0 r
s
1 0 .15 r
.49377 .84936 m .50737 .86156 L .53198 .85498 L p F P
0 0 0 r
s
1 0 .296 r
.50737 .86156 m .49377 .84936 L .46925 .856 L p F P
0 0 0 r
s
.372 .62 .628 r
.72447 .26915 m
.73654 .28715 L
s
1 .061 0 r
.92024 .86106 m .91027 .84885 L .88376 .85549 L p F P
0 0 0 r
s
1 .08 0 r
.14029 .84885 m .15698 .86106 L .17993 .85447 L p F P
0 0 0 r
s
1 .044 0 r
.15698 .86106 m .14029 .84885 L .11744 .85549 L p F P
0 0 0 r
s
1 0 .577 r
.55682 .84833 m .56987 .86055 L .59479 .85396 L p F P
0 0 0 r
s
1 0 .15 r
.56987 .86055 m .55682 .84833 L .53198 .85498 L p F P
0 0 0 r
s
1 .31 0 r
.2031 .84782 m .21925 .86005 L .24252 .85345 L p F P
0 0 0 r
s
1 .191 0 r
.21925 .86005 m .2031 .84782 L .17993 .85447 L p F P
0 0 0 r
s
.372 .62 .628 r
.43657 .28491 m
.4619 .27519 L
s
0 .096 1 r
.61995 .8473 m .63247 .85954 L .65771 .85294 L p F P
0 0 0 r
s
.66 0 1 r
.63247 .85954 m .61995 .8473 L .59479 .85396 L p F P
0 0 0 r
s
1 .923 0 r
.266 .84679 m .28161 .85904 L .30519 .85243 L p F P
0 0 0 r
s
1 .631 0 r
.28161 .85904 m .266 .84679 L .24252 .85345 L p F P
0 0 0 r
s
0 1 .182 r
.68318 .84627 m .69515 .85853 L .72071 .85192 L p F P
0 0 0 r
s
0 1 .882 r
.69515 .85853 m .68318 .84627 L .65771 .85294 L p F P
0 0 0 r
s
.372 .62 .628 r
.50173 .28342 m
.52739 .27368 L
s
.50173 .28342 m
.48747 .26536 L
s
0 1 .127 r
.32899 .84576 m .34407 .85802 L .36796 .85141 L p F P
0 0 0 r
s
.389 1 0 r
.34407 .85802 m .32899 .84576 L .30519 .85243 L p F P
0 0 0 r
s
1 .946 0 r
.74651 .84524 m .75793 .85752 L .7838 .8509 L p F P
0 0 0 r
s
.616 1 0 r
.75793 .85752 m .74651 .84524 L .72071 .85192 L p F P
0 0 0 r
s
.372 .62 .628 r
.56697 .28193 m
.59298 .27218 L
s
.56697 .28193 m
.55331 .26384 L
s
0 .194 1 r
.39208 .84473 m .40661 .85701 L .43082 .85038 L p F P
0 0 0 r
s
0 .811 1 r
.40661 .85701 m .39208 .84473 L .36796 .85141 L p F P
0 0 0 r
s
1 .318 0 r
.80992 .84421 m .8208 .8565 L .84699 .84987 L p F P
0 0 0 r
s
1 .515 0 r
.8208 .8565 m .80992 .84421 L .7838 .8509 L p F P
0 0 0 r
s
.372 .62 .628 r
.63232 .28044 m
.65868 .27067 L
s
.63232 .28044 m
.61925 .26232 L
s
1 0 .712 r
.45526 .84369 m .46925 .856 L .49377 .84936 L p F P
0 0 0 r
s
.901 0 1 r
.46925 .856 m .45526 .84369 L .43082 .85038 L p F P
0 0 0 r
s
1 .029 0 r
.10033 .84318 m .11744 .85549 L .14029 .84885 L p F P
0 0 0 r
s
1 .082 0 r
.87343 .84318 m .88376 .85549 L .91027 .84885 L p F P
0 0 0 r
s
1 .148 0 r
.88376 .85549 m .87343 .84318 L .84699 .84987 L p F P
0 0 0 r
s
.372 .62 .628 r
.69777 .27894 m
.72447 .26915 L
s
.69777 .27894 m
.68529 .2608 L
s
1 0 .296 r
.51853 .84266 m .53198 .85498 L .55682 .84833 L p F P
0 0 0 r
s
1 0 .15 r
.53198 .85498 m .51853 .84266 L .49377 .84936 L p F P
0 0 0 r
s
1 .137 0 r
.16337 .84214 m .17993 .85447 L .2031 .84782 L p F P
0 0 0 r
s
1 .08 0 r
.17993 .85447 m .16337 .84214 L .14029 .84885 L p F P
0 0 0 r
s
.779 0 1 r
.5819 .84162 m .59479 .85396 L .61995 .8473 L p F P
0 0 0 r
s
1 0 .577 r
.59479 .85396 m .5819 .84162 L .55682 .84833 L p F P
0 0 0 r
s
1 .477 0 r
.22649 .8411 m .24252 .85345 L .266 .84679 L p F P
0 0 0 r
s
1 .31 0 r
.24252 .85345 m .22649 .8411 L .2031 .84782 L p F P
0 0 0 r
s
0 .891 1 r
.64535 .84058 m .65771 .85294 L .68318 .84627 L p F P
0 0 0 r
s
0 .096 1 r
.65771 .85294 m .64535 .84058 L .61995 .8473 L p F P
0 0 0 r
s
.372 .62 .628 r
.4619 .27519 m
.48747 .26536 L
s
.717 1 0 r
.28971 .84006 m .30519 .85243 L .32899 .84576 L p F P
0 0 0 r
s
1 .923 0 r
.30519 .85243 m .28971 .84006 L .266 .84679 L p F P
0 0 0 r
s
.43 1 0 r
.70891 .83954 m .72071 .85192 L .74651 .84524 L p F P
0 0 0 r
s
0 1 .182 r
.72071 .85192 m .70891 .83954 L .68318 .84627 L p F P
0 0 0 r
s
.372 .62 .628 r
.52739 .27368 m
.55331 .26384 L
s
.52739 .27368 m
.5133 .25544 L
s
0 1 .671 r
.35302 .83902 m .36796 .85141 L .39208 .84473 L p F P
0 0 0 r
s
0 1 .127 r
.36796 .85141 m .35302 .83902 L .32899 .84576 L p F P
0 0 0 r
s
1 .615 0 r
.77255 .8385 m .7838 .8509 L .80992 .84421 L p F P
0 0 0 r
s
1 .946 0 r
.7838 .8509 m .77255 .8385 L .74651 .84524 L p F P
0 0 0 r
s
.372 .62 .628 r
.59298 .27218 m
.61925 .26232 L
s
.59298 .27218 m
.57949 .25391 L
s
.319 0 1 r
.41643 .83798 m .43082 .85038 L .45526 .84369 L p F P
0 0 0 r
s
0 .194 1 r
.43082 .85038 m .41643 .83798 L .39208 .84473 L p F P
0 0 0 r
s
1 .186 0 r
.83629 .83746 m .84699 .84987 L .87343 .84318 L p F P
0 0 0 r
s
1 .318 0 r
.84699 .84987 m .83629 .83746 L .80992 .84421 L p F P
0 0 0 r
s
.372 .62 .628 r
.65868 .27067 m
.68529 .2608 L
s
.65868 .27067 m
.64578 .25237 L
s
1 0 .577 r
.47993 .83694 m .49377 .84936 L .51853 .84266 L p F P
0 0 0 r
s
1 0 .712 r
.49377 .84936 m .47993 .83694 L .45526 .84369 L p F P
0 0 0 r
s
1 .054 0 r
.12331 .83642 m .14029 .84885 L .16337 .84214 L p F P
0 0 0 r
s
1 .029 0 r
.14029 .84885 m .12331 .83642 L .10033 .84318 L p F P
0 0 0 r
s
1 .082 0 r
.91027 .84885 m .90013 .83642 L .87343 .84318 L p F P
0 0 0 r
s
.372 .62 .628 r
.71218 .25083 m
.72447 .26915 L
s
1 0 .712 r
.54353 .83589 m .55682 .84833 L .5819 .84162 L p F P
0 0 0 r
s
1 0 .296 r
.55682 .84833 m .54353 .83589 L .51853 .84266 L p F P
0 0 0 r
s
1 .223 0 r
.18666 .83537 m .2031 .84782 L .22649 .8411 L p F P
0 0 0 r
s
1 .137 0 r
.2031 .84782 m .18666 .83537 L .16337 .84214 L p F P
0 0 0 r
s
.004 0 1 r
.60722 .83485 m .61995 .8473 L .64535 .84058 L p F P
0 0 0 r
s
.779 0 1 r
.61995 .8473 m .60722 .83485 L .5819 .84162 L p F P
0 0 0 r
s
1 .698 0 r
.25011 .83432 m .266 .84679 L .28971 .84006 L p F P
0 0 0 r
s
1 .477 0 r
.266 .84679 m .25011 .83432 L .22649 .8411 L p F P
0 0 0 r
s
0 1 .354 r
.671 .8338 m .68318 .84627 L .70891 .83954 L p F P
0 0 0 r
s
0 .891 1 r
.68318 .84627 m .671 .8338 L .64535 .84058 L p F P
0 0 0 r
s
.306 1 0 r
.31365 .83327 m .32899 .84576 L .35302 .83902 L p F P
0 0 0 r
s
.717 1 0 r
.32899 .84576 m .31365 .83327 L .28971 .84006 L p F P
0 0 0 r
s
.372 .62 .628 r
.48747 .26536 m
.5133 .25544 L
s
.926 1 0 r
.73488 .83275 m .74651 .84524 L .77255 .8385 L p F P
0 0 0 r
s
.43 1 0 r
.74651 .84524 m .73488 .83275 L .70891 .83954 L p F P
0 0 0 r
s
0 .811 1 r
.37729 .83222 m .39208 .84473 L .41643 .83798 L p F P
0 0 0 r
s
0 1 .671 r
.39208 .84473 m .37729 .83222 L .35302 .83902 L p F P
0 0 0 r
s
.372 .62 .628 r
.55331 .26384 m
.57949 .25391 L
s
.55331 .26384 m
.53939 .24542 L
s
1 .38 0 r
.79885 .8317 m .80992 .84421 L .83629 .83746 L p F P
0 0 0 r
s
1 .615 0 r
.80992 .84421 m .79885 .8317 L .77255 .8385 L p F P
0 0 0 r
s
.66 0 1 r
.44102 .83117 m .45526 .84369 L .47993 .83694 L p F P
0 0 0 r
s
.319 0 1 r
.45526 .84369 m .44102 .83117 L .41643 .83798 L p F P
0 0 0 r
s
.372 .62 .628 r
.61925 .26232 m
.64578 .25237 L
s
.61925 .26232 m
.60594 .24387 L
s
1 .103 0 r
.86292 .83064 m .87343 .84318 L .90013 .83642 L p F P
0 0 0 r
s
1 .186 0 r
.87343 .84318 m .86292 .83064 L .83629 .83746 L p F P
0 0 0 r
s
1 .018 0 r
.08292 .83064 m .10033 .84318 L .12331 .83642 L p F P
0 0 0 r
s
1 0 .712 r
.50484 .83012 m .51853 .84266 L .54353 .83589 L p F P
0 0 0 r
s
1 0 .577 r
.51853 .84266 m .50484 .83012 L .47993 .83694 L p F P
0 0 0 r
s
.372 .62 .628 r
.68529 .2608 m
.71218 .25083 L
s
.68529 .2608 m
.67258 .24232 L
s
1 .093 0 r
.1465 .82959 m .16337 .84214 L .18666 .83537 L p F P
0 0 0 r
s
1 .054 0 r
.16337 .84214 m .1465 .82959 L .12331 .83642 L p F P
0 0 0 r
s
.66 0 1 r
.56877 .82906 m .5819 .84162 L .60722 .83485 L p F P
0 0 0 r
s
1 0 .712 r
.5819 .84162 m .56877 .82906 L .54353 .83589 L p F P
0 0 0 r
s
1 .343 0 r
.21018 .82853 m .22649 .8411 L .25011 .83432 L p F P
0 0 0 r
s
1 .223 0 r
.22649 .8411 m .21018 .82853 L .18666 .83537 L p F P
0 0 0 r
s
0 .811 1 r
.63278 .82801 m .64535 .84058 L .671 .8338 L p F P
0 0 0 r
s
.004 0 1 r
.64535 .84058 m .63278 .82801 L .60722 .83485 L p F P
0 0 0 r
s
1 .971 0 r
.27395 .82748 m .28971 .84006 L .31365 .83327 L p F P
0 0 0 r
s
1 .698 0 r
.28971 .84006 m .27395 .82748 L .25011 .83432 L p F P
0 0 0 r
s
.306 1 0 r
.69689 .82695 m .70891 .83954 L .73488 .83275 L p F P
0 0 0 r
s
0 1 .354 r
.70891 .83954 m .69689 .82695 L .671 .8338 L p F P
0 0 0 r
s
0 1 .127 r
.33782 .82642 m .35302 .83902 L .37729 .83222 L p F P
0 0 0 r
s
.306 1 0 r
.35302 .83902 m .33782 .82642 L .31365 .83327 L p F P
0 0 0 r
s
.372 .62 .628 r
.5133 .25544 m
.53939 .24542 L
s
1 .698 0 r
.7611 .82589 m .77255 .8385 L .79885 .8317 L p F P
0 0 0 r
s
.926 1 0 r
.77255 .8385 m .7611 .82589 L .73488 .83275 L p F P
0 0 0 r
s
0 .381 1 r
.40179 .82536 m .41643 .83798 L .44102 .83117 L p F P
0 0 0 r
s
0 .811 1 r
.41643 .83798 m .40179 .82536 L .37729 .83222 L p F P
0 0 0 r
s
.372 .62 .628 r
.57949 .25391 m
.60594 .24387 L
s
.57949 .25391 m
.56575 .2353 L
s
1 .222 0 r
.8254 .82483 m .83629 .83746 L .86292 .83064 L p F P
0 0 0 r
s
1 .38 0 r
.83629 .83746 m .8254 .82483 L .79885 .8317 L p F P
0 0 0 r
s
.779 0 1 r
.46584 .8243 m .47993 .83694 L .50484 .83012 L p F P
0 0 0 r
s
.66 0 1 r
.47993 .83694 m .46584 .8243 L .44102 .83117 L p F P
0 0 0 r
s
.372 .62 .628 r
.64578 .25237 m
.67258 .24232 L
s
.64578 .25237 m
.63265 .23373 L
s
1 .103 0 r
.90013 .83642 m .8898 .82376 L .86292 .83064 L p F P
0 0 0 r
s
1 .034 0 r
.10602 .82376 m .12331 .83642 L .1465 .82959 L p F P
0 0 0 r
s
1 .018 0 r
.12331 .83642 m .10602 .82376 L .08292 .83064 L p F P
0 0 0 r
s
.901 0 1 r
.53 .82323 m .54353 .83589 L .56877 .82906 L p F P
0 0 0 r
s
1 0 .712 r
.54353 .83589 m .53 .82323 L .50484 .83012 L p F P
0 0 0 r
s
.372 .62 .628 r
.69965 .23216 m
.71218 .25083 L
s
1 .152 0 r
.16993 .8227 m .18666 .83537 L .21018 .82853 L p F P
0 0 0 r
s
1 .093 0 r
.18666 .83537 m .16993 .8227 L .1465 .82959 L p F P
0 0 0 r
s
0 .096 1 r
.59425 .82217 m .60722 .83485 L .63278 .82801 L p F P
0 0 0 r
s
.66 0 1 r
.60722 .83485 m .59425 .82217 L .56877 .82906 L p F P
0 0 0 r
s
1 .502 0 r
.23393 .82163 m .25011 .83432 L .27395 .82748 L p F P
0 0 0 r
s
1 .343 0 r
.25011 .83432 m .23393 .82163 L .21018 .82853 L p F P
0 0 0 r
s
0 1 .414 r
.6586 .8211 m .671 .8338 L .69689 .82695 L p F P
0 0 0 r
s
0 .811 1 r
.671 .8338 m .6586 .8211 L .63278 .82801 L p F P
0 0 0 r
s
.717 1 0 r
.29803 .82056 m .31365 .83327 L .33782 .82642 L p F P
0 0 0 r
s
1 .971 0 r
.31365 .83327 m .29803 .82056 L .27395 .82748 L p F P
0 0 0 r
s
.841 1 0 r
.72304 .82003 m .73488 .83275 L .7611 .82589 L p F P
0 0 0 r
s
.306 1 0 r
.73488 .83275 m .72304 .82003 L .69689 .82695 L p F P
0 0 0 r
s
0 1 .54 r
.36223 .8195 m .37729 .83222 L .40179 .82536 L p F P
0 0 0 r
s
0 1 .127 r
.37729 .83222 m .36223 .8195 L .33782 .82642 L p F P
0 0 0 r
s
1 .431 0 r
.78758 .81896 m .79885 .8317 L .8254 .82483 L p F P
0 0 0 r
s
1 .698 0 r
.79885 .8317 m .78758 .81896 L .7611 .82589 L p F P
0 0 0 r
s
.372 .62 .628 r
.53939 .24542 m
.56575 .2353 L
s
0 .096 1 r
.42652 .81842 m .44102 .83117 L .46584 .8243 L p F P
0 0 0 r
s
0 .381 1 r
.44102 .83117 m .42652 .81842 L .40179 .82536 L p F P
0 0 0 r
s
1 .123 0 r
.85222 .81789 m .86292 .83064 L .8898 .82376 L p F P
0 0 0 r
s
1 .222 0 r
.86292 .83064 m .85222 .81789 L .8254 .82483 L p F P
0 0 0 r
s
1 .011 0 r
.0652 .81789 m .08292 .83064 L .10602 .82376 L p F P
0 0 0 r
s
.372 .62 .628 r
.60594 .24387 m
.63265 .23373 L
s
.60594 .24387 m
.59237 .22507 L
s
.66 0 1 r
.49091 .81735 m .50484 .83012 L .53 .82323 L p F P
0 0 0 r
s
.779 0 1 r
.50484 .83012 m .49091 .81735 L .46584 .8243 L p F P
0 0 0 r
s
1 .06 0 r
.12934 .81681 m .1465 .82959 L .16993 .8227 L p F P
0 0 0 r
s
1 .034 0 r
.1465 .82959 m .12934 .81681 L .10602 .82376 L p F P
0 0 0 r
s
.372 .62 .628 r
.67258 .24232 m
.69965 .23216 L
s
.67258 .24232 m
.65963 .22349 L
s
.319 0 1 r
.5554 .81628 m .56877 .82906 L .59425 .82217 L p F P
0 0 0 r
s
.901 0 1 r
.56877 .82906 m .5554 .81628 L .53 .82323 L p F P
0 0 0 r
s
1 .234 0 r
.19358 .81574 m .21018 .82853 L .23393 .82163 L p F P
0 0 0 r
s
1 .152 0 r
.21018 .82853 m .19358 .81574 L .16993 .8227 L p F P
0 0 0 r
s
0 .891 1 r
.61998 .8152 m .63278 .82801 L .6586 .8211 L p F P
0 0 0 r
s
0 .096 1 r
.63278 .82801 m .61998 .8152 L .59425 .82217 L p F P
0 0 0 r
s
1 .698 0 r
.25791 .81466 m .27395 .82748 L .29803 .82056 L p F P
0 0 0 r
s
1 .502 0 r
.27395 .82748 m .25791 .81466 L .23393 .82163 L p F P
0 0 0 r
s
.262 1 0 r
.68466 .81412 m .69689 .82695 L .72304 .82003 L p F P
0 0 0 r
s
0 1 .414 r
.69689 .82695 m .68466 .81412 L .6586 .8211 L p F P
0 0 0 r
s
.389 1 0 r
.32235 .81358 m .33782 .82642 L .36223 .8195 L p F P
0 0 0 r
s
.717 1 0 r
.33782 .82642 m .32235 .81358 L .29803 .82056 L p F P
0 0 0 r
s
1 .753 0 r
.74944 .81305 m .7611 .82589 L .78758 .81896 L p F P
0 0 0 r
s
.841 1 0 r
.7611 .82589 m .74944 .81305 L .72304 .82003 L p F P
0 0 0 r
s
0 1 .882 r
.38688 .8125 m .40179 .82536 L .42652 .81842 L p F P
0 0 0 r
s
0 1 .54 r
.40179 .82536 m .38688 .8125 L .36223 .8195 L p F P
0 0 0 r
s
1 .253 0 r
.81432 .81196 m .8254 .82483 L .85222 .81789 L p F P
0 0 0 r
s
1 .431 0 r
.8254 .82483 m .81432 .81196 L .78758 .81896 L p F P
0 0 0 r
s
.372 .62 .628 r
.56575 .2353 m
.59237 .22507 L
s
.004 0 1 r
.4515 .81142 m .46584 .8243 L .49091 .81735 L p F P
0 0 0 r
s
0 .096 1 r
.46584 .8243 m .4515 .81142 L .42652 .81842 L p F P
0 0 0 r
s
1 .02 0 r
.08841 .81088 m .10602 .82376 L .12934 .81681 L p F P
0 0 0 r
s
1 .011 0 r
.10602 .82376 m .08841 .81088 L .0652 .81789 L p F P
0 0 0 r
s
1 .123 0 r
.8898 .82376 m .87929 .81088 L .85222 .81789 L p F P
0 0 0 r
s
.372 .62 .628 r
.63265 .23373 m
.65963 .22349 L
s
.63265 .23373 m
.61927 .21474 L
s
.319 0 1 r
.51623 .81034 m .53 .82323 L .5554 .81628 L p F P
0 0 0 r
s
.66 0 1 r
.53 .82323 m .51623 .81034 L .49091 .81735 L p F P
0 0 0 r
s
1 .098 0 r
.15289 .8098 m .16993 .8227 L .19358 .81574 L p F P
0 0 0 r
s
1 .06 0 r
.16993 .8227 m .15289 .8098 L .12934 .81681 L p F P
0 0 0 r
s
.372 .62 .628 r
.68689 .21314 m
.69965 .23216 L
s
0 .381 1 r
.58105 .80926 m .59425 .82217 L .61998 .8152 L p F P
0 0 0 r
s
.319 0 1 r
.59425 .82217 m .58105 .80926 L .5554 .81628 L p F P
0 0 0 r
s
1 .343 0 r
.21746 .80871 m .23393 .82163 L .25791 .81466 L p F P
0 0 0 r
s
1 .234 0 r
.23393 .82163 m .21746 .80871 L .19358 .81574 L p F P
0 0 0 r
s
0 1 .354 r
.64597 .80817 m .6586 .8211 L .68466 .81412 L p F P
0 0 0 r
s
0 .891 1 r
.6586 .8211 m .64597 .80817 L .61998 .8152 L p F P
0 0 0 r
s
1 .923 0 r
.28213 .80763 m .29803 .82056 L .32235 .81358 L p F P
0 0 0 r
s
1 .698 0 r
.29803 .82056 m .28213 .80763 L .25791 .81466 L p F P
0 0 0 r
s
.811 1 0 r
.71099 .80708 m .72304 .82003 L .74944 .81305 L p F P
0 0 0 r
s
.262 1 0 r
.72304 .82003 m .71099 .80708 L .68466 .81412 L p F P
0 0 0 r
s
.077 1 0 r
.3469 .80654 m .36223 .8195 L .38688 .8125 L p F P
0 0 0 r
s
.389 1 0 r
.36223 .8195 m .3469 .80654 L .32235 .81358 L p F P
0 0 0 r
s
1 .465 0 r
.7761 .80599 m .78758 .81896 L .81432 .81196 L p F P
0 0 0 r
s
1 .753 0 r
.78758 .81896 m .7761 .80599 L .74944 .81305 L p F P
0 0 0 r
s
0 .891 1 r
.41176 .80545 m .42652 .81842 L .4515 .81142 L p F P
0 0 0 r
s
0 1 .882 r
.42652 .81842 m .41176 .80545 L .38688 .8125 L p F P
0 0 0 r
s
1 .005 0 r
.04715 .8049 m .0652 .81789 L .08841 .81088 L p F P
0 0 0 r
s
1 .14 0 r
.84132 .8049 m .85222 .81789 L .87929 .81088 L p F P
0 0 0 r
s
1 .253 0 r
.85222 .81789 m .84132 .8049 L .81432 .81196 L p F P
0 0 0 r
s
0 .096 1 r
.47673 .80435 m .49091 .81735 L .51623 .81034 L p F P
0 0 0 r
s
.004 0 1 r
.49091 .81735 m .47673 .80435 L .4515 .81142 L p F P
0 0 0 r
s
.372 .62 .628 r
.59237 .22507 m
.61927 .21474 L
s
1 .036 0 r
.11186 .80381 m .12934 .81681 L .15289 .8098 L p F P
0 0 0 r
s
1 .02 0 r
.12934 .81681 m .11186 .80381 L .08841 .81088 L p F P
0 0 0 r
s
0 .194 1 r
.54179 .80326 m .5554 .81628 L .58105 .80926 L p F P
0 0 0 r
s
.319 0 1 r
.5554 .81628 m .54179 .80326 L .51623 .81034 L p F P
0 0 0 r
s
.372 .62 .628 r
.65963 .22349 m
.68689 .21314 L
s
.65963 .22349 m
.64644 .2043 L
s
1 .152 0 r
.17667 .80271 m .19358 .81574 L .21746 .80871 L p F P
0 0 0 r
s
1 .098 0 r
.19358 .81574 m .17667 .80271 L .15289 .8098 L p F P
0 0 0 r
s
0 1 .882 r
.60695 .80216 m .61998 .8152 L .64597 .80817 L p F P
0 0 0 r
s
0 .381 1 r
.61998 .8152 m .60695 .80216 L .58105 .80926 L p F P
0 0 0 r
s
1 .477 0 r
.24158 .80162 m .25791 .81466 L .28213 .80763 L p F P
0 0 0 r
s
1 .343 0 r
.25791 .81466 m .24158 .80162 L .21746 .80871 L p F P
0 0 0 r
s
.306 1 0 r
.67221 .80107 m .68466 .81412 L .71099 .80708 L p F P
0 0 0 r
s
0 1 .354 r
.68466 .81412 m .67221 .80107 L .64597 .80817 L p F P
0 0 0 r
s
.841 1 0 r
.30659 .80052 m .32235 .81358 L .3469 .80654 L p F P
0 0 0 r
s
1 .923 0 r
.32235 .81358 m .30659 .80052 L .28213 .80763 L p F P
0 0 0 r
s
1 .773 0 r
.73757 .79997 m .74944 .81305 L .7761 .80599 L p F P
0 0 0 r
s
.811 1 0 r
.74944 .81305 m .73757 .79997 L .71099 .80708 L p F P
0 0 0 r
s
0 1 .182 r
.37169 .79942 m .38688 .8125 L .41176 .80545 L p F P
0 0 0 r
s
.077 1 0 r
.38688 .8125 m .37169 .79942 L .3469 .80654 L p F P
0 0 0 r
s
1 .273 0 r
.80303 .79887 m .81432 .81196 L .84132 .8049 L p F P
0 0 0 r
s
1 .465 0 r
.81432 .81196 m .80303 .79887 L .7761 .80599 L p F P
0 0 0 r
s
0 .811 1 r
.4369 .79832 m .4515 .81142 L .47673 .80435 L p F P
0 0 0 r
s
0 .891 1 r
.4515 .81142 m .4369 .79832 L .41176 .80545 L p F P
0 0 0 r
s
1 .14 0 r
.87929 .81088 m .86859 .79777 L .84132 .8049 L p F P
0 0 0 r
s
1 .011 0 r
.07049 .79777 m .08841 .81088 L .11186 .80381 L p F P
0 0 0 r
s
1 .005 0 r
.08841 .81088 m .07049 .79777 L .04715 .8049 L p F P
0 0 0 r
s
0 .381 1 r
.5022 .79721 m .51623 .81034 L .54179 .80326 L p F P
0 0 0 r
s
0 .096 1 r
.51623 .81034 m .5022 .79721 L .47673 .80435 L p F P
0 0 0 r
s
.372 .62 .628 r
.61927 .21474 m
.64644 .2043 L
s
1 .06 0 r
.13554 .79666 m .15289 .8098 L .17667 .80271 L p F P
0 0 0 r
s
1 .036 0 r
.15289 .8098 m .13554 .79666 L .11186 .80381 L p F P
0 0 0 r
s
0 .811 1 r
.56761 .79611 m .58105 .80926 L .60695 .80216 L p F P
0 0 0 r
s
0 .194 1 r
.58105 .80926 m .56761 .79611 L .54179 .80326 L p F P
0 0 0 r
s
.372 .62 .628 r
.67389 .19376 m
.68689 .21314 L
s
1 .223 0 r
.20069 .79556 m .21746 .80871 L .24158 .80162 L p F P
0 0 0 r
s
1 .152 0 r
.21746 .80871 m .20069 .79556 L .17667 .80271 L p F P
0 0 0 r
s
0 1 .182 r
.63311 .795 m .64597 .80817 L .67221 .80107 L p F P
0 0 0 r
s
0 1 .882 r
.64597 .80817 m .63311 .795 L .60695 .80216 L p F P
0 0 0 r
s
1 .631 0 r
.26594 .79445 m .28213 .80763 L .30659 .80052 L p F P
0 0 0 r
s
1 .477 0 r
.28213 .80763 m .26594 .79445 L .24158 .80162 L p F P
0 0 0 r
s
.841 1 0 r
.69871 .79389 m .71099 .80708 L .73757 .79997 L p F P
0 0 0 r
s
.306 1 0 r
.71099 .80708 m .69871 .79389 L .67221 .80107 L p F P
0 0 0 r
s
.616 1 0 r
.33129 .79334 m .3469 .80654 L .37169 .79942 L p F P
0 0 0 r
s
.841 1 0 r
.3469 .80654 m .33129 .79334 L .30659 .80052 L p F P
0 0 0 r
s
1 .477 0 r
.76442 .79279 m .7761 .80599 L .80303 .79887 L p F P
0 0 0 r
s
1 .773 0 r
.7761 .80599 m .76442 .79279 L .73757 .79997 L p F P
0 0 0 r
s
0 1 .354 r
.39673 .79223 m .41176 .80545 L .4369 .79832 L p F P
0 0 0 r
s
0 1 .182 r
.41176 .80545 m .39673 .79223 L .37169 .79942 L p F P
0 0 0 r
s
1 .002 0 r
.02877 .79167 m .04715 .8049 L .07049 .79777 L p F P
0 0 0 r
s
1 .152 0 r
.83022 .79167 m .84132 .8049 L .86859 .79777 L p F P
0 0 0 r
s
1 .273 0 r
.84132 .8049 m .83022 .79167 L .80303 .79887 L p F P
0 0 0 r
s
0 .891 1 r
.46228 .79112 m .47673 .80435 L .5022 .79721 L p F P
0 0 0 r
s
0 .811 1 r
.47673 .80435 m .46228 .79112 L .4369 .79832 L p F P
0 0 0 r
s
1 .02 0 r
.09406 .79056 m .11186 .80381 L .13554 .79666 L p F P
0 0 0 r
s
1 .011 0 r
.11186 .80381 m .09406 .79056 L .07049 .79777 L p F P
0 0 0 r
s
0 .811 1 r
.52793 .79 m .54179 .80326 L .56761 .79611 L p F P
0 0 0 r
s
0 .381 1 r
.54179 .80326 m .52793 .79 L .5022 .79721 L p F P
0 0 0 r
s
1 .093 0 r
.15946 .78945 m .17667 .80271 L .20069 .79556 L p F P
0 0 0 r
s
1 .06 0 r
.17667 .80271 m .15946 .78945 L .13554 .79666 L p F P
0 0 0 r
s
.372 .62 .628 r
.64644 .2043 m
.67389 .19376 L
s
0 1 .54 r
.59368 .78889 m .60695 .80216 L .63311 .795 L p F P
0 0 0 r
s
0 .811 1 r
.60695 .80216 m .59368 .78889 L .56761 .79611 L p F P
0 0 0 r
s
1 .31 0 r
.22495 .78833 m .24158 .80162 L .26594 .79445 L p F P
0 0 0 r
s
1 .223 0 r
.24158 .80162 m .22495 .78833 L .20069 .79556 L p F P
0 0 0 r
s
.43 1 0 r
.65953 .78777 m .67221 .80107 L .69871 .79389 L p F P
0 0 0 r
s
0 1 .182 r
.67221 .80107 m .65953 .78777 L .63311 .795 L p F P
0 0 0 r
s
1 .793 0 r
.29054 .78721 m .30659 .80052 L .33129 .79334 L p F P
0 0 0 r
s
1 .631 0 r
.30659 .80052 m .29054 .78721 L .26594 .79445 L p F P
0 0 0 r
s
1 .753 0 r
.72548 .78665 m .73757 .79997 L .76442 .79279 L p F P
0 0 0 r
s
.841 1 0 r
.73757 .79997 m .72548 .78665 L .69871 .79389 L p F P
0 0 0 r
s
.43 1 0 r
.35623 .78609 m .37169 .79942 L .39673 .79223 L p F P
0 0 0 r
s
.616 1 0 r
.37169 .79942 m .35623 .78609 L .33129 .79334 L p F P
0 0 0 r
s
1 .28 0 r
.79153 .78553 m .80303 .79887 L .83022 .79167 L p F P
0 0 0 r
s
1 .477 0 r
.80303 .79887 m .79153 .78553 L .76442 .79279 L p F P
0 0 0 r
s
0 1 .414 r
.42203 .78497 m .4369 .79832 L .46228 .79112 L p F P
0 0 0 r
s
0 1 .354 r
.4369 .79832 m .42203 .78497 L .39673 .79223 L p F P
0 0 0 r
s
1 .005 0 r
.05224 .78441 m .07049 .79777 L .09406 .79056 L p F P
0 0 0 r
s
1 .002 0 r
.07049 .79777 m .05224 .78441 L .02877 .79167 L p F P
0 0 0 r
s
1 .152 0 r
.86859 .79777 m .85768 .78441 L .83022 .79167 L p F P
0 0 0 r
s
0 1 .882 r
.48792 .78385 m .5022 .79721 L .52793 .79 L p F P
0 0 0 r
s
0 .891 1 r
.5022 .79721 m .48792 .78385 L .46228 .79112 L p F P
0 0 0 r
s
1 .034 0 r
.11787 .78328 m .13554 .79666 L .15946 .78945 L p F P
0 0 0 r
s
1 .02 0 r
.13554 .79666 m .11787 .78328 L .09406 .79056 L p F P
0 0 0 r
s
0 1 .671 r
.55392 .78272 m .56761 .79611 L .59368 .78889 L p F P
0 0 0 r
s
0 .811 1 r
.56761 .79611 m .55392 .78272 L .52793 .79 L p F P
0 0 0 r
s
1 .137 0 r
.18361 .78216 m .20069 .79556 L .22495 .78833 L p F P
0 0 0 r
s
1 .093 0 r
.20069 .79556 m .18361 .78216 L .15946 .78945 L p F P
0 0 0 r
s
.077 1 0 r
.62001 .78159 m .63311 .795 L .65953 .78777 L p F P
0 0 0 r
s
0 1 .54 r
.63311 .795 m .62001 .78159 L .59368 .78889 L p F P
0 0 0 r
s
1 .41 0 r
.24945 .78103 m .26594 .79445 L .29054 .78721 L p F P
0 0 0 r
s
1 .31 0 r
.26594 .79445 m .24945 .78103 L .22495 .78833 L p F P
0 0 0 r
s
.926 1 0 r
.68621 .78046 m .69871 .79389 L .72548 .78665 L p F P
0 0 0 r
s
.43 1 0 r
.69871 .79389 m .68621 .78046 L .65953 .78777 L p F P
0 0 0 r
s
1 .946 0 r
.31539 .7799 m .33129 .79334 L .35623 .78609 L p F P
0 0 0 r
s
1 .793 0 r
.33129 .79334 m .31539 .7799 L .29054 .78721 L p F P
0 0 0 r
s
1 .465 0 r
.75251 .77933 m .76442 .79279 L .79153 .78553 L p F P
0 0 0 r
s
1 .753 0 r
.76442 .79279 m .75251 .77933 L .72548 .78665 L p F P
0 0 0 r
s
.306 1 0 r
.38143 .77877 m .39673 .79223 L .42203 .78497 L p F P
0 0 0 r
s
.43 1 0 r
.39673 .79223 m .38143 .77877 L .35623 .78609 L p F P
0 0 0 r
s
1 .156 0 r
.81892 .7782 m .83022 .79167 L .85768 .78441 L p F P
0 0 0 r
s
1 .28 0 r
.83022 .79167 m .81892 .7782 L .79153 .78553 L p F P
0 0 0 r
s
0 1 .354 r
.44757 .77764 m .46228 .79112 L .48792 .78385 L p F P
0 0 0 r
s
0 1 .414 r
.46228 .79112 m .44757 .77764 L .42203 .78497 L p F P
0 0 0 r
s
1 .011 0 r
.07594 .77707 m .09406 .79056 L .11787 .78328 L p F P
0 0 0 r
s
1 .005 0 r
.09406 .79056 m .07594 .77707 L .05224 .78441 L p F P
0 0 0 r
s
0 1 .54 r
.51382 .7765 m .52793 .79 L .55392 .78272 L p F P
0 0 0 r
s
0 1 .882 r
.52793 .79 m .51382 .7765 L .48792 .78385 L p F P
0 0 0 r
s
1 .054 0 r
.14192 .77593 m .15946 .78945 L .18361 .78216 L p F P
0 0 0 r
s
1 .034 0 r
.15946 .78945 m .14192 .77593 L .11787 .78328 L p F P
0 0 0 r
s
0 1 .127 r
.58016 .77536 m .59368 .78889 L .62001 .78159 L p F P
0 0 0 r
s
0 1 .671 r
.59368 .78889 m .58016 .77536 L .55392 .78272 L p F P
0 0 0 r
s
1 .191 0 r
.20801 .7748 m .22495 .78833 L .24945 .78103 L p F P
0 0 0 r
s
1 .137 0 r
.22495 .78833 m .20801 .7748 L .18361 .78216 L p F P
0 0 0 r
s
.616 1 0 r
.64661 .77423 m .65953 .78777 L .68621 .78046 L p F P
0 0 0 r
s
.077 1 0 r
.65953 .78777 m .64661 .77423 L .62001 .78159 L p F P
0 0 0 r
s
1 .515 0 r
.27419 .77366 m .29054 .78721 L .31539 .7799 L p F P
0 0 0 r
s
1 .41 0 r
.29054 .78721 m .27419 .77366 L .24945 .78103 L p F P
0 0 0 r
s
1 .698 0 r
.71317 .77309 m .72548 .78665 L .75251 .77933 L p F P
0 0 0 r
s
.926 1 0 r
.72548 .78665 m .71317 .77309 L .68621 .78046 L p F P
0 0 0 r
s
.926 1 0 r
.34048 .77252 m .35623 .78609 L .38143 .77877 L p F P
0 0 0 r
s
1 .946 0 r
.35623 .78609 m .34048 .77252 L .31539 .7799 L p F P
0 0 0 r
s
1 .273 0 r
.77982 .77194 m .79153 .78553 L .81892 .7782 L p F P
0 0 0 r
s
1 .465 0 r
.79153 .78553 m .77982 .77194 L .75251 .77933 L p F P
0 0 0 r
s
.262 1 0 r
.40688 .77137 m .42203 .78497 L .44757 .77764 L p F P
0 0 0 r
s
.306 1 0 r
.42203 .78497 m .40688 .77137 L .38143 .77877 L p F P
0 0 0 r
s
1 .156 0 r
.85768 .78441 m .84658 .7708 L .81892 .7782 L p F P
0 0 0 r
s
0 1 .182 r
.47337 .77023 m .48792 .78385 L .51382 .7765 L p F P
0 0 0 r
s
0 1 .354 r
.48792 .78385 m .47337 .77023 L .44757 .77764 L p F P
0 0 0 r
s
1 .018 0 r
.09988 .76966 m .11787 .78328 L .14192 .77593 L p F P
0 0 0 r
s
1 .011 0 r
.11787 .78328 m .09988 .76966 L .07594 .77707 L p F P
0 0 0 r
s
0 1 .127 r
.53997 .76908 m .55392 .78272 L .58016 .77536 L p F P
0 0 0 r
s
0 1 .54 r
.55392 .78272 m .53997 .76908 L .51382 .7765 L p F P
0 0 0 r
s
1 .08 0 r
.16621 .76851 m .18361 .78216 L .20801 .7748 L p F P
0 0 0 r
s
1 .054 0 r
.18361 .78216 m .16621 .76851 L .14192 .77593 L p F P
0 0 0 r
s
.389 1 0 r
.60667 .76793 m .62001 .78159 L .64661 .77423 L p F P
0 0 0 r
s
0 1 .127 r
.62001 .78159 m .60667 .76793 L .58016 .77536 L p F P
0 0 0 r
s
1 .253 0 r
.23265 .76736 m .24945 .78103 L .27419 .77366 L p F P
0 0 0 r
s
1 .191 0 r
.24945 .78103 m .23265 .76736 L .20801 .7748 L p F P
0 0 0 r
s
1 .946 0 r
.67348 .76678 m .68621 .78046 L .71317 .77309 L p F P
0 0 0 r
s
.616 1 0 r
.68621 .78046 m .67348 .76678 L .64661 .77423 L p F P
0 0 0 r
s
1 .615 0 r
.29919 .76621 m .31539 .7799 L .34048 .77252 L p F P
0 0 0 r
s
1 .515 0 r
.31539 .7799 m .29919 .76621 L .27419 .77366 L p F P
0 0 0 r
s
1 .431 0 r
.74039 .76563 m .75251 .77933 L .77982 .77194 L p F P
0 0 0 r
s
1 .698 0 r
.75251 .77933 m .74039 .76563 L .71317 .77309 L p F P
0 0 0 r
s
.841 1 0 r
.36583 .76506 m .38143 .77877 L .40688 .77137 L p F P
0 0 0 r
s
.926 1 0 r
.38143 .77877 m .36583 .76506 L .34048 .77252 L p F P
0 0 0 r
s
1 .152 0 r
.8074 .76448 m .81892 .7782 L .84658 .7708 L p F P
0 0 0 r
s
1 .273 0 r
.81892 .7782 m .8074 .76448 L .77982 .77194 L p F P
0 0 0 r
s
.306 1 0 r
.43258 .7639 m .44757 .77764 L .47337 .77023 L p F P
0 0 0 r
s
.262 1 0 r
.44757 .77764 m .43258 .7639 L .40688 .77137 L p F P
0 0 0 r
s
.077 1 0 r
.49944 .76275 m .51382 .7765 L .53997 .76908 L p F P
0 0 0 r
s
0 1 .182 r
.51382 .7765 m .49944 .76275 L .47337 .77023 L p F P
0 0 0 r
s
1 .029 0 r
.12406 .76217 m .14192 .77593 L .16621 .76851 L p F P
0 0 0 r
s
1 .018 0 r
.14192 .77593 m .12406 .76217 L .09988 .76966 L p F P
0 0 0 r
s
.306 1 0 r
.56639 .76159 m .58016 .77536 L .60667 .76793 L p F P
0 0 0 r
s
0 1 .127 r
.58016 .77536 m .56639 .76159 L .53997 .76908 L p F P
0 0 0 r
s
1 .111 0 r
.19075 .76101 m .20801 .7748 L .23265 .76736 L p F P
0 0 0 r
s
1 .08 0 r
.20801 .7748 m .19075 .76101 L .16621 .76851 L p F P
0 0 0 r
s
.841 1 0 r
.63345 .76043 m .64661 .77423 L .67348 .76678 L p F P
0 0 0 r
s
.389 1 0 r
.64661 .77423 m .63345 .76043 L .60667 .76793 L p F P
0 0 0 r
s
1 .318 0 r
.25754 .75985 m .27419 .77366 L .29919 .76621 L p F P
0 0 0 r
s
1 .253 0 r
.27419 .77366 m .25754 .75985 L .23265 .76736 L p F P
0 0 0 r
s
1 .615 0 r
.70062 .75927 m .71317 .77309 L .74039 .76563 L p F P
0 0 0 r
s
1 .946 0 r
.71317 .77309 m .70062 .75927 L .67348 .76678 L p F P
0 0 0 r
s
1 .698 0 r
.32444 .75869 m .34048 .77252 L .36583 .76506 L p F P
0 0 0 r
s
1 .615 0 r
.34048 .77252 m .32444 .75869 L .29919 .76621 L p F P
0 0 0 r
s
1 .253 0 r
.76789 .7581 m .77982 .77194 L .8074 .76448 L p F P
0 0 0 r
s
1 .431 0 r
.77982 .77194 m .76789 .7581 L .74039 .76563 L p F P
0 0 0 r
s
.811 1 0 r
.39144 .75752 m .40688 .77137 L .43258 .7639 L p F P
0 0 0 r
s
.841 1 0 r
.40688 .77137 m .39144 .75752 L .36583 .76506 L p F P
0 0 0 r
s
1 .152 0 r
.84658 .7708 m .83527 .75694 L .8074 .76448 L p F P
0 0 0 r
s
.43 1 0 r
.45855 .75636 m .47337 .77023 L .49944 .76275 L p F P
0 0 0 r
s
.306 1 0 r
.47337 .77023 m .45855 .75636 L .43258 .7639 L p F P
0 0 0 r
s
.389 1 0 r
.52576 .75519 m .53997 .76908 L .56639 .76159 L p F P
0 0 0 r
s
.077 1 0 r
.53997 .76908 m .52576 .75519 L .49944 .76275 L p F P
0 0 0 r
s
1 .044 0 r
.14848 .7546 m .16621 .76851 L .19075 .76101 L p F P
0 0 0 r
s
1 .029 0 r
.16621 .76851 m .14848 .7546 L .12406 .76217 L p F P
0 0 0 r
s
.717 1 0 r
.59308 .75402 m .60667 .76793 L .63345 .76043 L p F P
0 0 0 r
s
.306 1 0 r
.60667 .76793 m .59308 .75402 L .56639 .76159 L p F P
0 0 0 r
s
1 .148 0 r
.21553 .75343 m .23265 .76736 L .25754 .75985 L p F P
0 0 0 r
s
1 .111 0 r
.23265 .76736 m .21553 .75343 L .19075 .76101 L p F P
0 0 0 r
s
1 .793 0 r
.66051 .75285 m .67348 .76678 L .70062 .75927 L p F P
0 0 0 r
s
.841 1 0 r
.67348 .76678 m .66051 .75285 L .63345 .76043 L p F P
0 0 0 r
s
1 .38 0 r
.28269 .75226 m .29919 .76621 L .32444 .75869 L p F P
0 0 0 r
s
1 .318 0 r
.29919 .76621 m .28269 .75226 L .25754 .75985 L p F P
0 0 0 r
s
1 .38 0 r
.72804 .75167 m .74039 .76563 L .76789 .7581 L p F P
0 0 0 r
s
1 .615 0 r
.74039 .76563 m .72804 .75167 L .70062 .75927 L p F P
0 0 0 r
s
1 .753 0 r
.34995 .75109 m .36583 .76506 L .39144 .75752 L p F P
0 0 0 r
s
1 .698 0 r
.36583 .76506 m .34995 .75109 L .32444 .75869 L p F P
0 0 0 r
s
1 .14 0 r
.79567 .7505 m .8074 .76448 L .83527 .75694 L p F P
0 0 0 r
s
1 .253 0 r
.8074 .76448 m .79567 .7505 L .76789 .7581 L p F P
0 0 0 r
s
.841 1 0 r
.41731 .74991 m .43258 .7639 L .45855 .75636 L p F P
0 0 0 r
s
.811 1 0 r
.43258 .7639 m .41731 .74991 L .39144 .75752 L p F P
0 0 0 r
s
.616 1 0 r
.48478 .74873 m .49944 .76275 L .52576 .75519 L p F P
0 0 0 r
s
.43 1 0 r
.49944 .76275 m .48478 .74873 L .45855 .75636 L p F P
0 0 0 r
s
.717 1 0 r
.55236 .74755 m .56639 .76159 L .59308 .75402 L p F P
0 0 0 r
s
.389 1 0 r
.56639 .76159 m .55236 .74755 L .52576 .75519 L p F P
0 0 0 r
s
1 .061 0 r
.17316 .74696 m .19075 .76101 L .21553 .75343 L p F P
0 0 0 r
s
1 .044 0 r
.19075 .76101 m .17316 .74696 L .14848 .7546 L p F P
0 0 0 r
s
1 .923 0 r
.62005 .74637 m .63345 .76043 L .66051 .75285 L p F P
0 0 0 r
s
.717 1 0 r
.63345 .76043 m .62005 .74637 L .59308 .75402 L p F P
0 0 0 r
s
1 .186 0 r
.24057 .74578 m .25754 .75985 L .28269 .75226 L p F P
0 0 0 r
s
1 .148 0 r
.25754 .75985 m .24057 .74578 L .21553 .75343 L p F P
0 0 0 r
s
1 .515 0 r
.68784 .74519 m .70062 .75927 L .72804 .75167 L p F P
0 0 0 r
s
1 .793 0 r
.70062 .75927 m .68784 .74519 L .66051 .75285 L p F P
0 0 0 r
s
1 .431 0 r
.30809 .74459 m .32444 .75869 L .34995 .75109 L p F P
0 0 0 r
s
1 .38 0 r
.32444 .75869 m .30809 .74459 L .28269 .75226 L p F P
0 0 0 r
s
1 .222 0 r
.75574 .744 m .76789 .7581 L .79567 .7505 L p F P
0 0 0 r
s
1 .38 0 r
.76789 .7581 m .75574 .744 L .72804 .75167 L p F P
0 0 0 r
s
1 .773 0 r
.37572 .74341 m .39144 .75752 L .41731 .74991 L p F P
0 0 0 r
s
1 .753 0 r
.39144 .75752 m .37572 .74341 L .34995 .75109 L p F P
0 0 0 r
s
1 .14 0 r
.83527 .75694 m .82374 .74281 L .79567 .7505 L p F P
0 0 0 r
s
.926 1 0 r
.44345 .74222 m .45855 .75636 L .48478 .74873 L p F P
0 0 0 r
s
.841 1 0 r
.45855 .75636 m .44345 .74222 L .41731 .74991 L p F P
0 0 0 r
s
.841 1 0 r
.51129 .74103 m .52576 .75519 L .55236 .74755 L p F P
0 0 0 r
s
.616 1 0 r
.52576 .75519 m .51129 .74103 L .48478 .74873 L p F P
0 0 0 r
s
1 .971 0 r
.57923 .73984 m .59308 .75402 L .62005 .74637 L p F P
0 0 0 r
s
.717 1 0 r
.59308 .75402 m .57923 .73984 L .55236 .74755 L p F P
0 0 0 r
s
1 .082 0 r
.19809 .73924 m .21553 .75343 L .24057 .74578 L p F P
0 0 0 r
s
1 .061 0 r
.21553 .75343 m .19809 .73924 L .17316 .74696 L p F P
0 0 0 r
s
1 .631 0 r
.64729 .73864 m .66051 .75285 L .68784 .74519 L p F P
0 0 0 r
s
1 .923 0 r
.66051 .75285 m .64729 .73864 L .62005 .74637 L p F P
0 0 0 r
s
1 .222 0 r
.26587 .73805 m .28269 .75226 L .30809 .74459 L p F P
0 0 0 r
s
1 .186 0 r
.28269 .75226 m .26587 .73805 L .24057 .74578 L p F P
0 0 0 r
s
1 .318 0 r
.71545 .73745 m .72804 .75167 L .75574 .744 L p F P
0 0 0 r
s
1 .515 0 r
.72804 .75167 m .71545 .73745 L .68784 .74519 L p F P
0 0 0 r
s
1 .465 0 r
.33376 .73685 m .34995 .75109 L .37572 .74341 L p F P
0 0 0 r
s
1 .431 0 r
.34995 .75109 m .33376 .73685 L .30809 .74459 L p F P
0 0 0 r
s
1 .123 0 r
.78372 .73625 m .79567 .7505 L .82374 .74281 L p F P
0 0 0 r
s
1 .222 0 r
.79567 .7505 m .78372 .73625 L .75574 .744 L p F P
0 0 0 r
s
1 .753 0 r
.40175 .73565 m .41731 .74991 L .44345 .74222 L p F P
0 0 0 r
s
1 .773 0 r
.41731 .74991 m .40175 .73565 L .37572 .74341 L p F P
0 0 0 r
s
1 .946 0 r
.46985 .73445 m .48478 .74873 L .51129 .74103 L p F P
0 0 0 r
s
.926 1 0 r
.48478 .74873 m .46985 .73445 L .44345 .74222 L p F P
0 0 0 r
s
1 .923 0 r
.53806 .73325 m .55236 .74755 L .57923 .73984 L p F P
0 0 0 r
s
.841 1 0 r
.55236 .74755 m .53806 .73325 L .51129 .74103 L p F P
0 0 0 r
s
1 .698 0 r
.60638 .73204 m .62005 .74637 L .64729 .73864 L p F P
0 0 0 r
s
1 .971 0 r
.62005 .74637 m .60638 .73204 L .57923 .73984 L p F P
0 0 0 r
s
1 .103 0 r
.22328 .73144 m .24057 .74578 L .26587 .73805 L p F P
0 0 0 r
s
1 .082 0 r
.24057 .74578 m .22328 .73144 L .19809 .73924 L p F P
0 0 0 r
s
1 .41 0 r
.67481 .73084 m .68784 .74519 L .71545 .73745 L p F P
0 0 0 r
s
1 .631 0 r
.68784 .74519 m .67481 .73084 L .64729 .73864 L p F P
0 0 0 r
s
1 .253 0 r
.29143 .73023 m .30809 .74459 L .33376 .73685 L p F P
0 0 0 r
s
1 .222 0 r
.30809 .74459 m .29143 .73023 L .26587 .73805 L p F P
0 0 0 r
s
1 .186 0 r
.74335 .72963 m .75574 .744 L .78372 .73625 L p F P
0 0 0 r
s
1 .318 0 r
.75574 .744 m .74335 .72963 L .71545 .73745 L p F P
0 0 0 r
s
1 .477 0 r
.35969 .72903 m .37572 .74341 L .40175 .73565 L p F P
0 0 0 r
s
1 .465 0 r
.37572 .74341 m .35969 .72903 L .33376 .73685 L p F P
0 0 0 r
s
1 .123 0 r
.82374 .74281 m .81199 .72842 L .78372 .73625 L p F P
0 0 0 r
s
1 .698 0 r
.42806 .72781 m .44345 .74222 L .46985 .73445 L p F P
0 0 0 r
s
1 .753 0 r
.44345 .74222 m .42806 .72781 L .40175 .73565 L p F P
0 0 0 r
s
1 .793 0 r
.49653 .7266 m .51129 .74103 L .53806 .73325 L p F P
0 0 0 r
s
1 .946 0 r
.51129 .74103 m .49653 .7266 L .46985 .73445 L p F P
0 0 0 r
s
1 .698 0 r
.56512 .72539 m .57923 .73984 L .60638 .73204 L p F P
0 0 0 r
s
1 .923 0 r
.57923 .73984 m .56512 .72539 L .53806 .73325 L p F P
0 0 0 r
s
1 .477 0 r
.63381 .72417 m .64729 .73864 L .67481 .73084 L p F P
0 0 0 r
s
1 .698 0 r
.64729 .73864 m .63381 .72417 L .60638 .73204 L p F P
0 0 0 r
s
1 .123 0 r
.24873 .72356 m .26587 .73805 L .29143 .73023 L p F P
0 0 0 r
s
1 .103 0 r
.26587 .73805 m .24873 .72356 L .22328 .73144 L p F P
0 0 0 r
s
1 .253 0 r
.70262 .72295 m .71545 .73745 L .74335 .72963 L p F P
0 0 0 r
s
1 .41 0 r
.71545 .73745 m .70262 .72295 L .67481 .73084 L p F P
0 0 0 r
s
1 .273 0 r
.31726 .72234 m .33376 .73685 L .35969 .72903 L p F P
0 0 0 r
s
1 .253 0 r
.33376 .73685 m .31726 .72234 L .29143 .73023 L p F P
0 0 0 r
s
1 .103 0 r
.77154 .72173 m .78372 .73625 L .81199 .72842 L p F P
0 0 0 r
s
1 .186 0 r
.78372 .73625 m .77154 .72173 L .74335 .72963 L p F P
0 0 0 r
s
1 .465 0 r
.38589 .72112 m .40175 .73565 L .42806 .72781 L p F P
0 0 0 r
s
1 .477 0 r
.40175 .73565 m .38589 .72112 L .35969 .72903 L p F P
0 0 0 r
s
1 .615 0 r
.45464 .7199 m .46985 .73445 L .49653 .7266 L p F P
0 0 0 r
s
1 .698 0 r
.46985 .73445 m .45464 .7199 L .42806 .72781 L p F P
0 0 0 r
s
1 .631 0 r
.52349 .71867 m .53806 .73325 L .56512 .72539 L p F P
0 0 0 r
s
1 .793 0 r
.53806 .73325 m .52349 .71867 L .49653 .7266 L p F P
0 0 0 r
s
1 .502 0 r
.59246 .71744 m .60638 .73204 L .63381 .72417 L p F P
0 0 0 r
s
1 .698 0 r
.60638 .73204 m .59246 .71744 L .56512 .72539 L p F P
0 0 0 r
s
1 .31 0 r
.66153 .71621 m .67481 .73084 L .70262 .72295 L p F P
0 0 0 r
s
1 .477 0 r
.67481 .73084 m .66153 .71621 L .63381 .72417 L p F P
0 0 0 r
s
1 .14 0 r
.27445 .7156 m .29143 .73023 L .31726 .72234 L p F P
0 0 0 r
s
1 .123 0 r
.29143 .73023 m .27445 .7156 L .24873 .72356 L p F P
0 0 0 r
s
1 .148 0 r
.73072 .71498 m .74335 .72963 L .77154 .72173 L p F P
0 0 0 r
s
1 .253 0 r
.74335 .72963 m .73072 .71498 L .70262 .72295 L p F P
0 0 0 r
s
1 .28 0 r
.34335 .71436 m .35969 .72903 L .38589 .72112 L p F P
0 0 0 r
s
1 .273 0 r
.35969 .72903 m .34335 .71436 L .31726 .72234 L p F P
0 0 0 r
s
1 .103 0 r
.81199 .72842 m .80002 .71375 L .77154 .72173 L p F P
0 0 0 r
s
1 .431 0 r
.41237 .71313 m .42806 .72781 L .45464 .7199 L p F P
0 0 0 r
s
1 .465 0 r
.42806 .72781 m .41237 .71313 L .38589 .72112 L p F P
0 0 0 r
s
1 .515 0 r
.48149 .71189 m .49653 .7266 L .52349 .71867 L p F P
0 0 0 r
s
1 .615 0 r
.49653 .7266 m .48149 .71189 L .45464 .7199 L p F P
0 0 0 r
s
1 .477 0 r
.55073 .71065 m .56512 .72539 L .59246 .71744 L p F P
0 0 0 r
s
1 .631 0 r
.56512 .72539 m .55073 .71065 L .52349 .71867 L p F P
0 0 0 r
s
1 .343 0 r
.62008 .70941 m .63381 .72417 L .66153 .71621 L p F P
0 0 0 r
s
1 .502 0 r
.63381 .72417 m .62008 .70941 L .59246 .71744 L p F P
0 0 0 r
s
1 .191 0 r
.68954 .70817 m .70262 .72295 L .73072 .71498 L p F P
0 0 0 r
s
1 .31 0 r
.70262 .72295 m .68954 .70817 L .66153 .71621 L p F P
0 0 0 r
s
1 .152 0 r
.30044 .70755 m .31726 .72234 L .34335 .71436 L p F P
0 0 0 r
s
1 .14 0 r
.31726 .72234 m .30044 .70755 L .27445 .7156 L p F P
0 0 0 r
s
1 .082 0 r
.75912 .70693 m .77154 .72173 L .80002 .71375 L p F P
0 0 0 r
s
1 .148 0 r
.77154 .72173 m .75912 .70693 L .73072 .71498 L p F P
0 0 0 r
s
1 .273 0 r
.36972 .7063 m .38589 .72112 L .41237 .71313 L p F P
0 0 0 r
s
1 .28 0 r
.38589 .72112 m .36972 .7063 L .34335 .71436 L p F P
0 0 0 r
s
1 .38 0 r
.43912 .70506 m .45464 .7199 L .48149 .71189 L p F P
0 0 0 r
s
1 .431 0 r
.45464 .7199 m .43912 .70506 L .41237 .71313 L p F P
0 0 0 r
s
1 .41 0 r
.50864 .70381 m .52349 .71867 L .55073 .71065 L p F P
0 0 0 r
s
1 .515 0 r
.52349 .71867 m .50864 .70381 L .48149 .71189 L p F P
0 0 0 r
s
1 .343 0 r
.57826 .70256 m .59246 .71744 L .62008 .70941 L p F P
0 0 0 r
s
1 .477 0 r
.59246 .71744 m .57826 .70256 L .55073 .71065 L p F P
0 0 0 r
s
1 .223 0 r
.648 .7013 m .66153 .71621 L .68954 .70817 L p F P
0 0 0 r
s
1 .343 0 r
.66153 .71621 m .648 .7013 L .62008 .70941 L p F P
0 0 0 r
s
1 .111 0 r
.71785 .70005 m .73072 .71498 L .75912 .70693 L p F P
0 0 0 r
s
1 .191 0 r
.73072 .71498 m .71785 .70005 L .68954 .70817 L p F P
0 0 0 r
s
1 .156 0 r
.3267 .69942 m .34335 .71436 L .36972 .7063 L p F P
0 0 0 r
s
1 .152 0 r
.34335 .71436 m .3267 .69942 L .30044 .70755 L p F P
0 0 0 r
s
1 .082 0 r
.80002 .71375 m .78781 .69879 L .75912 .70693 L p F P
0 0 0 r
s
1 .253 0 r
.39637 .69816 m .41237 .71313 L .43912 .70506 L p F P
0 0 0 r
s
1 .273 0 r
.41237 .71313 m .39637 .69816 L .36972 .7063 L p F P
0 0 0 r
s
1 .318 0 r
.46616 .6969 m .48149 .71189 L .50864 .70381 L p F P
0 0 0 r
s
1 .38 0 r
.48149 .71189 m .46616 .6969 L .43912 .70506 L p F P
0 0 0 r
s
1 .31 0 r
.53606 .69563 m .55073 .71065 L .57826 .70256 L p F P
0 0 0 r
s
1 .41 0 r
.55073 .71065 m .53606 .69563 L .50864 .70381 L p F P
0 0 0 r
s
1 .234 0 r
.60608 .69437 m .62008 .70941 L .648 .7013 L p F P
0 0 0 r
s
1 .343 0 r
.62008 .70941 m .60608 .69437 L .57826 .70256 L p F P
0 0 0 r
s
1 .137 0 r
.67621 .6931 m .68954 .70817 L .71785 .70005 L p F P
0 0 0 r
s
1 .223 0 r
.68954 .70817 m .67621 .6931 L .648 .7013 L p F P
0 0 0 r
s
1 .061 0 r
.74645 .69183 m .75912 .70693 L .78781 .69879 L p F P
0 0 0 r
s
1 .111 0 r
.75912 .70693 m .74645 .69183 L .71785 .70005 L p F P
0 0 0 r
s
1 .152 0 r
.35324 .6912 m .36972 .7063 L .39637 .69816 L p F P
0 0 0 r
s
1 .156 0 r
.36972 .7063 m .35324 .6912 L .3267 .69942 L p F P
0 0 0 r
s
1 .222 0 r
.42331 .68993 m .43912 .70506 L .46616 .6969 L p F P
0 0 0 r
s
1 .253 0 r
.43912 .70506 m .42331 .68993 L .39637 .69816 L p F P
0 0 0 r
s
1 .253 0 r
.49349 .68865 m .50864 .70381 L .53606 .69563 L p F P
0 0 0 r
s
1 .318 0 r
.50864 .70381 m .49349 .68865 L .46616 .6969 L p F P
0 0 0 r
s
1 .223 0 r
.56378 .68738 m .57826 .70256 L .60608 .69437 L p F P
0 0 0 r
s
1 .31 0 r
.57826 .70256 m .56378 .68738 L .53606 .69563 L p F P
0 0 0 r
s
1 .152 0 r
.63419 .6861 m .648 .7013 L .67621 .6931 L p F P
0 0 0 r
s
1 .234 0 r
.648 .7013 m .63419 .6861 L .60608 .69437 L p F P
0 0 0 r
s
1 .08 0 r
.70472 .68482 m .71785 .70005 L .74645 .69183 L p F P
0 0 0 r
s
1 .137 0 r
.71785 .70005 m .70472 .68482 L .67621 .6931 L p F P
0 0 0 r
s
1 .061 0 r
.78781 .69879 m .77536 .68353 L .74645 .69183 L p F P
0 0 0 r
s
1 .14 0 r
.38006 .68289 m .39637 .69816 L .42331 .68993 L p F P
0 0 0 r
s
1 .152 0 r
.39637 .69816 m .38006 .68289 L .35324 .6912 L p F P
0 0 0 r
s
1 .186 0 r
.45053 .68161 m .46616 .6969 L .49349 .68865 L p F P
0 0 0 r
s
1 .222 0 r
.46616 .6969 m .45053 .68161 L .42331 .68993 L p F P
0 0 0 r
s
1 .191 0 r
.5211 .68032 m .53606 .69563 L .56378 .68738 L p F P
0 0 0 r
s
1 .253 0 r
.53606 .69563 m .5211 .68032 L .49349 .68865 L p F P
0 0 0 r
s
1 .152 0 r
.5918 .67903 m .60608 .69437 L .63419 .6861 L p F P
0 0 0 r
s
1 .223 0 r
.60608 .69437 m .5918 .67903 L .56378 .68738 L p F P
0 0 0 r
s
1 .093 0 r
.66261 .67774 m .67621 .6931 L .70472 .68482 L p F P
0 0 0 r
s
1 .152 0 r
.67621 .6931 m .66261 .67774 L .63419 .6861 L p F P
0 0 0 r
s
1 .044 0 r
.73354 .67644 m .74645 .69183 L .77536 .68353 L p F P
0 0 0 r
s
1 .08 0 r
.74645 .69183 m .73354 .67644 L .70472 .68482 L p F P
0 0 0 r
s
1 .123 0 r
.40718 .6745 m .42331 .68993 L .45053 .68161 L p F P
0 0 0 r
s
1 .14 0 r
.42331 .68993 m .40718 .6745 L .38006 .68289 L p F P
0 0 0 r
s
1 .148 0 r
.47804 .6732 m .49349 .68865 L .5211 .68032 L p F P
0 0 0 r
s
1 .186 0 r
.49349 .68865 m .47804 .6732 L .45053 .68161 L p F P
0 0 0 r
s
1 .137 0 r
.54902 .6719 m .56378 .68738 L .5918 .67903 L p F P
0 0 0 r
s
1 .191 0 r
.56378 .68738 m .54902 .6719 L .5211 .68032 L p F P
0 0 0 r
s
1 .098 0 r
.62012 .67059 m .63419 .6861 L .66261 .67774 L p F P
0 0 0 r
s
1 .152 0 r
.63419 .6861 m .62012 .67059 L .5918 .67903 L p F P
0 0 0 r
s
1 .054 0 r
.69133 .66929 m .70472 .68482 L .73354 .67644 L p F P
0 0 0 r
s
1 .093 0 r
.70472 .68482 m .69133 .66929 L .66261 .67774 L p F P
0 0 0 r
s
1 .044 0 r
.77536 .68353 m .76267 .66798 L .73354 .67644 L p F P
0 0 0 r
s
1 .103 0 r
.43458 .66601 m .45053 .68161 L .47804 .6732 L p F P
0 0 0 r
s
1 .123 0 r
.45053 .68161 m .43458 .66601 L .40718 .6745 L p F P
0 0 0 r
s
1 .111 0 r
.50585 .6647 m .5211 .68032 L .54902 .6719 L p F P
0 0 0 r
s
1 .148 0 r
.5211 .68032 m .50585 .6647 L .47804 .6732 L p F P
0 0 0 r
s
1 .093 0 r
.57723 .66338 m .5918 .67903 L .62012 .67059 L p F P
0 0 0 r
s
1 .137 0 r
.5918 .67903 m .57723 .66338 L .54902 .6719 L p F P
0 0 0 r
s
1 .06 0 r
.64874 .66206 m .66261 .67774 L .69133 .66929 L p F P
0 0 0 r
s
1 .098 0 r
.66261 .67774 m .64874 .66206 L .62012 .67059 L p F P
0 0 0 r
s
1 .029 0 r
.72037 .66074 m .73354 .67644 L .76267 .66798 L p F P
0 0 0 r
s
1 .054 0 r
.73354 .67644 m .72037 .66074 L .69133 .66929 L p F P
0 0 0 r
s
1 .082 0 r
.46228 .65743 m .47804 .6732 L .50585 .6647 L p F P
0 0 0 r
s
1 .103 0 r
.47804 .6732 m .46228 .65743 L .43458 .66601 L p F P
0 0 0 r
s
1 .08 0 r
.53396 .65611 m .54902 .6719 L .57723 .66338 L p F P
0 0 0 r
s
1 .111 0 r
.54902 .6719 m .53396 .65611 L .50585 .6647 L p F P
0 0 0 r
s
1 .06 0 r
.60576 .65477 m .62012 .67059 L .64874 .66206 L p F P
0 0 0 r
s
1 .093 0 r
.62012 .67059 m .60576 .65477 L .57723 .66338 L p F P
0 0 0 r
s
1 .034 0 r
.67768 .65344 m .69133 .66929 L .72037 .66074 L p F P
0 0 0 r
s
1 .06 0 r
.69133 .66929 m .67768 .65344 L .64874 .66206 L p F P
0 0 0 r
s
1 .029 0 r
.76267 .66798 m .74971 .65211 L .72037 .66074 L p F P
0 0 0 r
s
1 .061 0 r
.49028 .64876 m .50585 .6647 L .53396 .65611 L p F P
0 0 0 r
s
1 .082 0 r
.50585 .6647 m .49028 .64876 L .46228 .65743 L p F P
0 0 0 r
s
1 .054 0 r
.56238 .64742 m .57723 .66338 L .60576 .65477 L p F P
0 0 0 r
s
1 .08 0 r
.57723 .66338 m .56238 .64742 L .53396 .65611 L p F P
0 0 0 r
s
1 .036 0 r
.63459 .64607 m .64874 .66206 L .67768 .65344 L p F P
0 0 0 r
s
1 .06 0 r
.64874 .66206 m .63459 .64607 L .60576 .65477 L p F P
0 0 0 r
s
1 .018 0 r
.70693 .64473 m .72037 .66074 L .74971 .65211 L p F P
0 0 0 r
s
1 .034 0 r
.72037 .66074 m .70693 .64473 L .67768 .65344 L p F P
0 0 0 r
s
1 .044 0 r
.51859 .63999 m .53396 .65611 L .56238 .64742 L p F P
0 0 0 r
s
1 .061 0 r
.53396 .65611 m .51859 .63999 L .49028 .64876 L p F P
0 0 0 r
s
1 .034 0 r
.59111 .63864 m .60576 .65477 L .63459 .64607 L p F P
0 0 0 r
s
1 .054 0 r
.60576 .65477 m .59111 .63864 L .56238 .64742 L p F P
0 0 0 r
s
1 .02 0 r
.66374 .63728 m .67768 .65344 L .70693 .64473 L p F P
0 0 0 r
s
1 .036 0 r
.67768 .65344 m .66374 .63728 L .63459 .64607 L p F P
0 0 0 r
s
1 .018 0 r
.74971 .65211 m .7365 .63592 L .70693 .64473 L p F P
0 0 0 r
s
1 .029 0 r
.54722 .63113 m .56238 .64742 L .59111 .63864 L p F P
0 0 0 r
s
1 .044 0 r
.56238 .64742 m .54722 .63113 L .51859 .63999 L p F P
0 0 0 r
s
1 .02 0 r
.62015 .62976 m .63459 .64607 L .66374 .63728 L p F P
0 0 0 r
s
1 .034 0 r
.63459 .64607 m .62015 .62976 L .59111 .63864 L p F P
0 0 0 r
s
1 .011 0 r
.69322 .62838 m .70693 .64473 L .7365 .63592 L p F P
0 0 0 r
s
1 .02 0 r
.70693 .64473 m .69322 .62838 L .66374 .63728 L p F P
0 0 0 r
s
1 .018 0 r
.57616 .62217 m .59111 .63864 L .62015 .62976 L p F P
0 0 0 r
s
1 .029 0 r
.59111 .63864 m .57616 .62217 L .54722 .63113 L p F P
0 0 0 r
s
1 .011 0 r
.64952 .62078 m .66374 .63728 L .69322 .62838 L p F P
0 0 0 r
s
1 .02 0 r
.66374 .63728 m .64952 .62078 L .62015 .62976 L p F P
0 0 0 r
s
1 .011 0 r
.7365 .63592 m .72302 .61939 L .69322 .62838 L p F P
0 0 0 r
s
1 .011 0 r
.60542 .61311 m .62015 .62976 L .64952 .62078 L p F P
0 0 0 r
s
1 .018 0 r
.62015 .62976 m .60542 .61311 L .57616 .62217 L p F P
0 0 0 r
s
1 .005 0 r
.67922 .61171 m .69322 .62838 L .72302 .61939 L p F P
0 0 0 r
s
1 .011 0 r
.69322 .62838 m .67922 .61171 L .64952 .62078 L p F P
0 0 0 r
s
1 .005 0 r
.63501 .60395 m .64952 .62078 L .67922 .61171 L p F P
0 0 0 r
s
1 .011 0 r
.64952 .62078 m .63501 .60395 L .60542 .61311 L p F P
0 0 0 r
s
1 .005 0 r
.72302 .61939 m .70925 .60253 L .67922 .61171 L p F P
0 0 0 r
s
1 .002 0 r
.66493 .59468 m .67922 .61171 L .70925 .60253 L p F P
0 0 0 r
s
1 .005 0 r
.67922 .61171 m .66493 .59468 L .63501 .60395 L p F P
0 0 0 r
s
1 .002 0 r
.70925 .60253 m .6952 .58531 L .66493 .59468 L p F P
0 0 0 r
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(-2)] .09072 .22988 .97192 1 Mshowa
.22871 .18658 m
.23354 .19204 L
s
[(-1)] .21906 .17566 .88455 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.50609 .06995 m
.51031 .07589 L
s
[(1)] .49765 .05807 .70982 1 Mshowa
.65689 .00654 m
.66074 .01273 L
s
[(2)] .64919 -0.00583 .62245 1 Mshowa
.125 Mabswid
.12591 .22981 m
.12892 .23297 L
s
.1512 .21917 m
.15419 .22236 L
s
.17676 .20842 m
.17972 .21164 L
s
.2026 .19756 m
.20553 .20081 L
s
.25511 .17548 m
.25797 .17879 L
s
.28179 .16426 m
.28462 .1676 L
s
.30875 .15292 m
.31155 .15628 L
s
.33602 .14146 m
.33878 .14485 L
s
.39145 .11815 m
.39414 .1216 L
s
.41963 .1063 m
.42229 .10978 L
s
.44813 .09432 m
.45074 .09783 L
s
.47695 .0822 m
.47952 .08574 L
s
.53556 .05756 m
.53805 .06115 L
s
.56537 .04502 m
.56782 .04865 L
s
.59553 .03235 m
.59793 .036 L
s
.62603 .01952 m
.62839 .0232 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(-2)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(-1)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(1)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(2)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.03493 .82832 m
.03556 .82399 L
s
.05756 .84424 m
.05816 .83991 L
s
.07969 .85982 m
.08026 .85548 L
s
.10133 .87505 m
.10187 .87071 L
s
.14322 .90453 m
.14371 .90018 L
s
.1635 .9188 m
.16396 .91445 L
s
.18335 .93277 m
.18378 .92842 L
s
.20279 .94645 m
.2032 .9421 L
s
.24048 .97297 m
.24084 .96861 L
s
.25875 .98583 m
.25909 .98147 L
s
.27666 .99844 m
.27697 .99407 L
s
.29422 1.01079 m
.29451 1.00643 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.3611 1.05786 m
.3613 1.05349 L
s
.37703 1.06907 m
.37721 1.0647 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[260]:=",
  ImageSize->{265.313, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004900017b000`400?l00000o`00003oo`3oool:
0?ooo`00[`3oool4000005H0oooo002_0?ooo`030000003oool0oooo05L0oooo002`0?ooo`030000
003oool0oooo05H0oooo002a0?ooo`030000003oool0oooo05D0oooo002_0?ooo`040000003oool0
oooo000005H0oooo002`0?ooo`800000E`3oool00?l0oooo2P3oool00?l0oooo2P3oool00?l0oooo
2P3oool00?l0oooo2P3oool00;L0oooo0P00001@0?ooo`00]03oool3000000030?ooo`0000000000
04l0oooo002b0?ooo`<000000`3oool2000004l0oooo002`0?ooo`8000000`3oool01P000000oooo
0?ooo`000000oooo000004h0oooo002]0?ooo`<00000203oool00`000000oooo0000001>0?ooo`00
Z`3oool3000000X0oooo00@000000?ooo`3oool00000C@3oool008T0oooo1@00000K0?ooo`800000
3@3oool01@000000oooo0?ooo`3oool0000004`0oooo002;0?ooo`030000003oool0oooo01L0oooo
1000000<0?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`1:0?ooo`00R`3o
ool00`000000oooo0?ooo`0F0?ooo`<000002`3oool300000080o`000P0000040?ooo`030000003o
ool0oooo04T0oooo002;0?ooo`030000003oool0oooo01@0oooo0P00000<0?ooo`8000001@3o0000
0`000000oooo000000040?ooo`030000003oool0oooo04P0oooo002;0?ooo`030000003oool0oooo
0140oooo0`00000<0?ooo`80000000<0o`400000003o00001@3o0002000000@0oooo00<000000?oo
o`3oool0B03oool008X0oooo0P00000A0?ooo`<00000303oool2000000<0o`4000<000000?l0003o
0000103o0002000000D0oooo00<000000?ooo`3oool0A`3oool009X0oooo0`00000<0?ooo`<00000
1P3o0@000`000000o`000?l000030?l0008000001@3oool00`000000oooo0?ooo`170?ooo`00V03o
ool2000000`0oooo0`0000020?l200030000003o0@00o`4000@0o`4000<000000?l0003o00000`00
00000`3o0@000000000000050?ooo`030000003oool0oooo04H0oooo002F0?ooo`800000303oool2
000000D0o`8000<000000?l1003o0@001@3o0@02000000@0o`400P0000060?ooo`030000003oool0
oooo04D0oooo002C0?ooo`<00000303oool2000000030?l400000000o`8000D0o`8000<000000?l1
003o0@000P3o0@02000000030?l200000000o`4000<0o`4000<000000?l1000000001@3oool00`00
0000oooo0?ooo`150?ooo`00T@3oool2000000d0oooo0P0000030?l400030000003o0P00o`8000@0
o`8000<000000?l1003o0@000P0000030?l200030000003o0@00o`400080o`4000@000000?l1003o
0@0000001@3oool00`000000oooo0?ooo`140?ooo`00SP3oool3000000d0oooo0P0000060?l40003
0000003o0P00o`8000<0o`800`0000060?l200040000003o0@00o`400?l100<0000000<0o`800000
003oool00`3oool00`000000oooo0?ooo`140?ooo`00S03oool2000000<0oooo00<000000?ooo`3o
ool01`3oool300000080o`L000<000000?l4003o10000`3o10000`000000o`800?l2000300000080
o`D000<000000?l2003o0P00103o0P000`000000o`400?l10002000000<0o`8000<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`130?ooo`00RP3oool2000000d0oooo0P0000050?l700030000
003o1000o`@000@0o`@00P0000050?l500030000003o0P00o`8000@0o`800`0000000`3o0P000000
0?l200030?l200030000003oool0oooo00<0oooo00<000000?ooo`3oool0@P3oool006L0oooo0P00
000N0?ooo`<000003@3oool2000000030?l;00000000o`L000D0o`L000@000000?l4003o1000o`@0
0P0000000`3o200000000?l500050?l500030000003o0P00o`8000<000000P3o1@000`000000o`80
000000040?l200030000003oool0oooo00<0oooo00<000000?ooo`3oool0@P3oool006H0oooo00@0
00000?ooo`3oool000006`3oool2000000h0oooo0P0000030?l;00030000003o1`00o`L000@0o`L0
00@000000?l40000000000000`3o20000`000000o`D00?l500050?l5008000001@3o1@000`000000
o`80000000040?l2008000001@3oool00`000000oooo0?ooo`110?ooo`00IP3oool010000000oooo
0?ooo`00000H0?ooo`<000003P3oool2000000H0o`/000<000000?l7003o1`000`3o1`02000000H0
o`P000<000000?l5003o1@000P3o1@02000000030?l900000000o`D000D0o`D00P000000103o0P00
00000000000000020?l400030000003oool0oooo00<0oooo00<000000?ooo`3oool0@03oool006H0
oooo00@000000?ooo`3oool000005P3oool3000000h0oooo0P0000000`3o3`0000000?l;00050?l;
00030000003o1`00o`L000<000000P3o3@000`000000o`P00?l800030?l800030000003o1@00o`D0
008000000`3o2@000`000000o`D00?l500050?l5008000001@3o10000`000000oooo0?ooo`030?oo
o`030000003oool0oooo0400oooo001V0?ooo`040000003oool0oooo000001@0oooo0P00000?0?oo
o`8000000`3o3`000`000000o`/00?l;00050?l;008000001@3o3@000`000000o`P00?l800030?l8
00<000001P3o2@000`000000o`D00?l500020?l500@000001P3o10000`000000oooo0?ooo`030?oo
o`030000003oool0oooo03l0oooo001W0?ooo`8000004P3oool3000000h0oooo0`0000060?l?0003
0000003o2`00o`/00080o`/00P0000000`3o500000000?l=00050?l=00030000003o2000o`P00080
00000P3o3`000`000000o`T00?l900040?l900030000003o1@00o`D0008000000P3o2002000000L0
o`@000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0o0?ooo`00N@3oool3000000h0oooo
0P0000020?lD00030000003o3`00o`l000@0o`l000<000000?l;003o2`000P0000030?lD00030000
003o3@00o`d000D0o`d00P0000040?l?00030000003o2@00o`T000@0o`T00`0000040?l800030000
003o2000000000@0o`@00`0000050?ooo`030000003oool0oooo03h0oooo001f0?ooo`<000003`3o
ool2000000@0oa@000<000000?l?003o3`00103o3`03000000H0oa@000<000000?l=003o3@000P3o
3@02000000030?lG00000000o`l000@0o`l000<000000?l9003o2@000`0000020?l?00030000003o
2000o`P000<0o`P00P0000020?l4008000000`3o1`000`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03d0oooo001d0?ooo`800000403oool2000000030?lJ00000000oa@000@0oa@000<00000
0?l?003o3`000`0000020?lL00030000003o5000oa@000@0oa@000<000000?l=003o3@000P000003
0?lG00030000003o3`00o`l000@0o`l00P0000050?l?00030000003o2000o`P000<0o`P010000005
0?l700030000003oool0oooo00<0oooo00<000000?ooo`3oool0?@3oool00780oooo0`00000?0?oo
o`8000000`3o6P000`000000oa@00?lD00040?lD008000001@3o70000`000000oa@00?lD00050?lD
008000001P3o5`0010000000o`l00?l?003o3`02000000030?lI00000000o`l000D0o`l000<00000
0?l8003o20000`0000000`3o3@0000000?l700060?l700030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0?03oool006l0oooo0`00000?0?ooo`<000001P3o6P0010000000oa@00?lD003o5002
000000030?lU00000000oa`000D0oa`000<000000?lD003o50000P3o5002000000030?lS00000000
oaL000D0oaL000@000000?l?0000000000000`3o6@000`000000o`l00?l?00050?l?008000000P3o
3@0010000000o`d00?l=000000040?l70080000000<0o`/00000003oool00`3oool00`000000oooo
0?ooo`0l0?ooo`00K@3oool200000100oooo0P0000020?lO00030000003o6P00oaX000@0oaX000@0
00000?lD0000000000000`3o9@000`000000oa`00?lL00040?lL00030000003o5000oa@000800000
0`3o8`000`000000oaL00?lG00050?lG00030000003o6@00oaT000@0oaT000<000000?l?003o3`00
0P3o3`02000000050?lG00000000o`d00?l=000000000P3o3@000`000000o`L00?l70002000000<0
o`/000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0k0?ooo`00JP3oool4000000h0oooo
0`0000040?lO00030000003o6P00oaX000D0oaX000<000000?lU003o9@00103o9@000`000000oa`0
0?lL00040?lL008000001P3o8`000`000000oaL00?lG00020?lG00<000001P3o6@000`000000o`l0
0?l?0002000000<0oaL000@000000?l=003o3@0000000`3o3@02000000H0o`/000<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0j0?ooo`00J03oool2000000@0oooo00<000000?ooo`3oool0
203oool300000080ob<000<000000?lO003o7`000`3o7`000`000000oaX00?lJ00020?lJ00800000
00<0obl00000003o9@001@3o9@0010000000oa`00?lL003o7002000000030?l`00000000ob<000D0
ob<000<000000?lG003o5`000P0000030?lV00030000003o6@00oaT000@0oaT00P0000060?lG0004
0000003o3@0000000?l=0080000000<0oa@00000003o2`001@3o2`000`000000oooo0?ooo`030?oo
o`030000003oool0oooo03X0oooo00160?ooo`D000006P3oool3000000l0oooo0P0000050?lS0003
0000003o7`00oal000<0oal000<000000?lJ003o6P000P0000030?l_00030000003o9@00obD000@0
obD000@000000?lL0000000000000`3o<0000`000000ob<00?lS00050?lS008000001@3o9P000`00
0000oaT00?lI00020?lI0080000000<0obH00000003o5`001@3o5`0010000000o`d0000000000003
0?lD00030000003o2`00o`/000@0o`/00P0000050?ooo`030000003oool0oooo03T0oooo00180?oo
o`030000003oool0oooo01P0oooo0P0000020?ooo`030000003oool0oooo00/0oooo0`0000070?lS
00030000003o7`00oal00080oal00`0000060?l_00030000003o9@00obD000<0obD00P0000060?l`
00030000003o8`00ob<00080ob<00P0000000`3o>@0000000?lV00050?lV00040000003o6@000000
000000<0obH000<000000?lG003o5`001@3o5`02000000D0oa@000<000000?l;003o2`000`000002
0?l?00030000003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool004P0oooo00<000000?oo
o`3oool05P3oool200000100oooo0P0000030?lV00030000003o8`00ob<000@0ob<000<000000?lO
003o7`000P0000020?lh00030000003o;`00obl000@0obl000<000000?lU003o9@000`0000020?m0
00030000003o<000oc0000<0oc0000<000000?lS003o8`000P0000030?li00030000003o9P00obH0
00@0obH00P0000060?lV00030000003o5`00oaL00080oaL0100000060?lD008000001@3o3`000`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03P0oooo00100?ooo`@00000103oool00`000000
oooo0?ooo`0C0?ooo`<00000403oool2000000D0obH000<000000?lS003o8`001@3o8`02000000@0
ocP000<000000?l_003o;`001@3o;`02000000D0od0000<000000?l`003o<000103o<002000000H0
ocT000@000000?lV003o9P00obH00P0000000`3o>`0000000?lV00050?lV00030000003o5`00oaL0
008000000`3o8`000`000000oa@00?lD00020?lD0080000000<0oa`00000003o3`001@3o3`000`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03L0oooo00180?ooo`030000003oool0oooo0140
oooo0P0000020?ooo`030000003oool0oooo00/0oooo0`0000020?lW00030000003o9P00obH000<0
obH000<000000?lS003o8`000P3o8`03000000H0ocP000<000000?l_003o;`000P3o;`03000000L0
od0000@000000?l`003o<000oc000P0000000`3oC`0000000?li00050?li00040000003o9P000000
000000<0oc/000<000000?lV003o9P001@3o9P02000000D0ob<000<000000?lD003o50000P000003
0?lL00030000003o3`00o`l000D0o`l000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0g
0?ooo`00A`3oool200000100oooo0`00000?0?ooo`<000001@3o9`000`000000obH00?lV00030?lV
00030000003o8`00ob<0008000000`3o@0000`000000ocP00?lh00030?lh00030000003o;`00obl0
008000000`3oD@000`000000od000?m000040?m000040000003o<0000000000000<0odl000<00000
0?li003o>@001@3o>@000`000000oc/00?lk00040?lk00030000003o9P00obH00080obH00P000000
0`3o>@0000000?lS00040?lS00<000001P3o70000`000000o`l00?l?00020?l?00<000001@3oool0
0`000000oooo0?ooo`0f0?ooo`00E`3oool4000000h0oooo0P0000020?lV00030000003o9`00obL0
00@0obL000<000000?lV003o9P000P3o9P03000000D0od0000<000000?lh003o>000103o>0020000
00D0oe4000<000000?m0003o@0001@3o@0000`000000odl00?m?00040?m?00030000003o>@00ocT0
0080ocT00`0000060?lk00030000003o9P00obH0008000000`3o>@000`000000ob<00?lS00030?lS
00030000003o<000000000H0oa`000<000000?l?003o3`000P0000030?lD00030000003oool0oooo
00<0oooo00<000000?ooo`3oool0=@3oool005D0oooo0P00000?0?ooo`<00000103o9P000`000000
obL00?lW00040?lW00030000003o9P00obH00080000000<0odD00000003o@0001P3o@00010000000
ocP00?lh003o>003000000L0oe4000<000000?m0003o@0000P3o@003000000H0odl000<000000?li
003o>@000P0000030?mG00030000003o>`00oc/000@0oc/00P0000060?li00030000003o8`00ob<0
00<0000000<0oc000000003o70001P3o7002000000D0oa@000<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0e0?ooo`00DP3oool3000000l0oooo0P0000020?lS00030000003o9P00obH000<0
obH000<000000?lW003o9`000`3o9`03000000@0odD000<000000?m0003o@000103o@00010000000
ocP00000000000030?mQ00030000003oD@00oe4000@0oe4000<000000?m0003o@0000P0000030?mX
00030000003oC`00odl000@0odl00P0000050?mG00030000003o>`00oc/000<0oc/000<000000?mG
000000001P3o>@000`000000ob<0000000020?l`00040000003o<000oc00000000@0oa`00`000007
0?lD00030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00500oooo0P0000000`3o
ool000000?ooo`0<0?ooo`<00000103o8`000`000000obH00?lV00030?lV00030000003o9`00obL0
00<0000000<0odL00000003oA@00103oA@000`000000od000?m000050?m000030000003oH@00of40
00<0of4000<000000?mA003oD@001@3oD@02000000D0ofP000<000000?m?003oC`000`3oC`020000
00L0oeL000<000000?lk003o>`000P0000020?mG00030000003o>@00ocT000D0ocT000D000000?l`
003o<000oc00000000020?l`00030000003o7000oa`0008000000`3o9@000`000000oa@00?lD0002
0?lD0080000000<0oaX00000003oool00`3oool00`000000oooo0?ooo`0d0?ooo`00C@3oool30000
00h0oooo0`0000020?lO00030000003o8`00ob<000<0ob<000<000000?lV003o9P000P3o9P030000
00D0odL000<000000?m5003oA@000`3oA@000`000000od000?m000020?m000<000001P3oH@000`00
0000oe400?mA00020?mA00<000001`3oJ0000`000000odl00?m?000200000080ogX000<000000?mG
003oE`00103oE`000`000000oc/0000000050?mG00030000003o>@00ocT00080ocT00P0000001@3o
C`0000000?l`003o<000000000<0oc000P0000050?lU00030000003o5000oa@0008000000`3o6P00
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo001;0?ooo`8000003P3oool30000
00D0oal000<000000?lS003o8`000`3o8`000`000000obH00?lV000200000080odD000<000000?m7
003oA`000`3oA`000`000000odD00?m500030?m500030000003o@000od00008000000`3oKP000`00
0000of400?mQ00030?mQ00030000003oD@00oe40008000000`3oP`000`000000ofP00?mX00040?mX
00030000003oC`00000000@0ogX000<000000?mG003oE`001@3oE`000`000000oeL00?mG00040?mG
00030000003o>@00ocT0008000000`3oC`002@000000oc000?l`003o<00000000?l`00000000od00
000000060?lU008000001P3o6P000`000000oooo0?ooo`030?ooo`030000003oool0oooo0380oooo
00190?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`8000000P3o6P000`000000oal00?lO
00040?lO00030000003o8`00ob<00080ob<00`0000040?m500030000003oA`00odL000@0odL000<0
00000?m5003oA@000P3oA@03000000D0ofh000<000000?mQ003oH@00103oH@02000000D0oh<000<0
00000?mX003oJ0001@3oJ0000`000000ogX00?mj00040?mj00030000003oE`00oeL00080oeL00P00
00000`3oP00000000?mG00050?mG008000001P3oC`000`000000oc000?l`000200000080od0000<0
00000?lU003o9@000`3o9@000`000000obl0000000060?lJ00030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0<P3oool004H0oooo0`00000=0?ooo`<000001@3o6P000`000000oal00?lO0003
0?lO00030000003o8`00ob<00080000000<0od000000003oA@001@3oA@000`000000odL00?m70003
0?m700030000003oA@00odD00080000000<0ogL00000003oKP001P3oKP000`000000of400?mQ0002
0?mQ008000001`3oP`000`000000ofP00?mX00020?mX00<000001P3oNP001@000000oeL00?mG003o
E`00000000<0oh0000<000000?mG003oE`000`3oE`02000000H0odl00P1OWZ000`3o<00000000000
00040?m000030000003o9@00obD0008000000P3o;`000`000000oaX00?lJ00050?lJ00030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0<@3oool002H0oooo1000000J0?ooo`@00000303oool2
00000080oa@000<000000?lJ003o6P000`3o6P000`000000oal00?lO00030?lO00<00000103o@000
0`000000odD00?m500040?m500030000003oA`00odL00080odL00`0000040?mg00030000003oKP00
ofh000@0ofh000<000000?mQ003oH@000P0000020?nM00030000003oP`00oh<000@0oh<000D00000
0?mX003oJ000ofP0000000030?nQ00030000003oNP00ogX000@0ogX00`0000050?n000030000003o
E`00oeL0008000000P3oNP000`000000odl00?m?000305nNX080odl000<0GijP0?m000000000103o
@0000`000000obD0000000050?l_00030000003o6P00oaX00080oaX00`0000050?ooo`030000003o
ool0oooo0340oooo000V0?ooo`030000003oool0oooo01P0oooo0`00000=0?ooo`<00000103o5000
0`000000oaX00?lJ00040?lJ00030000003o7`00oal00080000000<0ocP00000003o@000103o@000
0`000000odD00?m500040?m500030000003oA`00odL00080000000<0ogX00000003oM`00103oM`00
0`000000ofh00?m^00050?m^00800000103oW@000`000000oh<00?n300050?n300<00000103oX@00
0`000000ogX00?mj00040?mj00030000003oP000oh0000D0oh0000<000000?mG00000000103oNP03
05nNX0<0odl00`0000000`1OWZ0000000?m000040?m000030000003o;`00obl000@0obl000<00000
0?lJ003o6P000P0000030?lO00030000003oool0oooo00<0oooo00<000000?ooo`3oool0<03oool0
02L0oooo00<000000?ooo`3oool05@3oool2000000h0oooo0P0000020?l?00030000003o5000oa@0
00<0oa@000<000000?lJ003o6P000`3o6P03000000@0ocP000<000000?m0003o@0000`3o@0000`00
0000odD00?m500030?m500<00000103oNP000`000000ogL00?mg00030?mg00030000003oKP00ofh0
00<0ofh00P0000050?nM00030000003oP`00oh<000D0oh<000<000000?nQ003oX@001@3oX@000`00
0000ogX00?mj00020?mj00800000203oP00010000000ogX00?mj003oNP0205nNX0030?mj00000000
GijP0080odl000@000000?mX003oJ000ofP00P0000030?m000<000001`3o;`02000000D0oal000<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0_0?ooo`00803oool4000000@0oooo00<00000
0?ooo`3oool04P3oool2000000030?ooo`000000oooo00X0oooo0`0000040?l?00030000003o5000
oa@000<0oa@000<000000?lJ003o6P000`0000020?l_00030000003o>000ocP00080ocP000<00000
0?m0003o@0000`3o@0000`000000odD00?m50003000000030?mg00000000ogX000@0ogX000<00000
0?mg003oM`000`3oM`000`000000ofh00?m^0003000000030?nb00000000oid000D0oid000<00000
0?n3003oP`000P3oP`03000000L0oj4000<000000?mj003oNP000P0000020?nb00030000003oP000
oh0000@0oh000P0000000`3oNP00GijP05nNX0030?mj00040000001OWZ000000000000@0ofP00P00
00000`1OWZ000000000000030?mA00030000003o;`00obl00080obl00P0000000`3o>00000000?lO
00050?lO00030000003oool0oooo00<0oooo00<000000?ooo`3oool0;`3oool002H0oooo00@00000
0?ooo`3oool00000403oool3000000d0oooo0P0000020?l;00030000003o3`00o`l000<0o`l000<0
00000?lD003o50000P3o5003000000D0obl000<000000?lh003o>0000`3o>0000`000000od000?m0
00020?m000<000001@3oM`000`000000ogX00?mj00030?mj00030000003oM`00ogL000<0ogL00P00
00050?nb00030000003oW@00oid000<0oid000D000000?n3003oP`00oh<0000000030?o;00030000
003oX@00oj4000D0oj400P0000040?nb00030000003oP000oh0000<0oh0000@0000005nNX01OWZ00
GijP1P3oNP000`000000GijP0?mX00030?mX0080GijP0P0000000`1OWZ00oe400?mA00020?mA0003
0000003o;`00obl0008000000`3o>0000`000000oal00?lO00020?lO0080000000<0ob<00000003o
ool0103oool00`000000oooo0?ooo`0^0?ooo`009`3oool2000000l0oooo0P00000=0?ooo`<00000
103o2`000`000000o`l00?l?00030?l?00030000003o5000oa@0008000000P3o9@000`000000obl0
0?l_00040?l_00030000003o>000ocP00080ocP000<000000?m0003o@0000P0000000`3oKP000000
0?mg00050?mg00030000003oNP00ogX000<0ogX000@000000?mg003oM`00ogL00`0000060?nb0003
0000003oW@00oid000@0oid00`0000040?o;00030000003oX@00oj4000D0oj4000<000000?nb003o
/P00103o/P000`000000oh000?n0000305nNX080ok8000<0GijP0?mj003oNP000`3oNP000`000000
oj4005nNX0020?mX0080GijP00D0ofP0000000000000000005nNX0050?mA008000001P3o>0001000
0000oal00000000000030?lS00030000003oool0oooo00@0oooo00<000000?ooo`3oool0;@3oool0
03D0oooo0`0000020?ooo`030000003oool0oooo00P0oooo0P0000020?l700030000003o2`00o`/0
00<0o`/000@000000?l?003o3`00o`l0100000050?lU00030000003o;`00obl000<0obl000@00000
0?lh003o>000ocP0100000040?m^00030000003oM`00ogL000@0ogL000<000000?mj003oNP000`3o
NP03000000<0ol0000<000000?nb003o/P00103o/P000`000000oid00?nM00030?nM00030000003o
b`00ol/000@0ol/000<000000?nQ003oX@00103oX@02000000H0ok800`1OWZ050?nb000305nNX03o
NP00ogX00080ogX000<000000?nQ003oX@000`1OWZ020?mX00060000003oP`0000000000003oD@00
GijP0`3oD@000`000000of40000000070?lh00030000003o8`00ob<000@0ob<000<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0]0?ooo`00<`3oool2000000d0oooo0`0000040?l700030000
003o2`00o`/000<0o`/0100000030?lL00030000003o9@00obD000<0obD000<000000?l_003o;`00
0`3o;`0400000080of4000<000000?m^003oKP000`3oKP000`000000ogL00?mg00040?mg00030000
003oNP00ogX00080ogX00P0000050?o000030000003o/P00ok8000@0ok8000@000000?nM003oW@00
oid00`0000070?o;00030000003oX@00oj400080oj4000@000000?o/003ok00000000`3o/P0205nN
X0030?nb00000000GijP00D0ok8000@0000005nNX03oNP000000101OWZ001@3oX@00000005nNX03o
J00000000080oh<000D000000?n300000000GijP0?mA000200000080of4000<000000?lh003o>000
0`3o>003000000L0ob<000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0/0?ooo`00<@3o
ool4000000/0oooo0P0000020?l400030000003o1`00o`L000<0o`L000<000000?l;003o2`000P00
00020?lD00030000003o7000oa`000<0oa`000<000000?lU003o9@000`3o9@000`000000obl00?l_
0002000000030?mA00000000of4000@0of4000<000000?m^003oKP000`3oKP000`000000ogL00?mg
00040?mg00060000003oNP0000000000003oa@0000001@3o`0000`000000ok800?nb00050?nb00<0
00000`3olP000`000000ol/00?o;00040?o;00030000003oX@00oj40008000000`3ok00010000000
ok8005nNX01OWZ020?nb0080000000<0GijP0?nb003o/P00103o/P000`000000GijP05nNX0050?nQ
00030000001OWZ00000000<0oh<000<000000?n3000000000P1OWZ050?mQ00050000003o>000ocP0
0?lh000000000`3o@0000`000000ob<00?lS00020?lS00<000001@3oool00`000000oooo0?ooo`0/
0?ooo`00;P3oool3000000`0oooo0`0000040?l400030000003o1`00o`L000<0o`L00`0000050?lD
00030000003o7000oa`000<0oa`000@000000?lU003o9@00obD0100000040?mA00030000003oH@00
of400080of4000<000000?m^003oKP000`3oKP000`000000ogL00?mg00030?mg00<00000103oa@00
0`000000ol000?o000030?o000030000003o/P00ok8000@0ok8000<000000?ob003olP000`3olP00
0`000000ol/00?o;00050?o;00800000103ok00305nNX0<0ok8000D000000?oh003on000000005nN
X0040?nb0080GijP00<0oj4005nNX03oX@001@3oX@000`000000GijP0?n300020?n300060000001O
WZ00GijP0000003oH@00GijP103oH@0010000000ocP00000000000040?m000030000003o8`00ob<0
008000000`3o9P000`000000oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo000/0?ooo`80
00003@3oool200000080o`8000<000000?l4003o10000`3o10000`000000o`L00?l7000200000080
o`d000<000000?lD003o50000`3o50000`000000oa`00?lL00030?lL00@000000`3o@0000`000000
oe400?mA00020?mA00030000003oH@00of4000<0of4000<000000?m^003oKP000`3oKP000`000000
ogL000000002000000030?o000000000olD000@0olD000<000000?o0003o`0000`3o`0000`000000
ok800?nb00020?nb00<000001@3olP000`000000ol/00?o;00050?o;00030000003ok000on`000<0
GijP0P3ok000101OWZ00ok800?nb000000030?oh00040000001OWZ00ok800?nb0080GijP0P000002
0?nQ000305nNX03oX@00oj400080oj400P0000002P1OWZ00oh<00?n3001OWZ0000000?n300000000
oid00000001OWZ050?mQ00030000003o@000od0000D0od000P0000050?lV00030000003oool0oooo
00@0oooo00<000000?ooo`3oool0:P3oool002X0oooo0P0000020?ooo`030000003oool0oooo00L0
oooo0`0000040?l200030000003o1000o`@000<0o`@00`0000050?l=00030000003o5000oa@000<0
oa@000<000000?lL003o70000P0000000`3o<00000000?m000040?m000030000003oD@00oe4000<0
oe4000<000000?mQ003oH@000P3oH@0010000000ofh00?m^003oKP04000000D0ol0000<000000?o5
003oa@000P3oa@000`000000ol000?o000030?o000050000003o/P00ok800?nb000000000`3]o`00
0`000000oo800?ob00030?ob00030000003ob`00ol/00080ol/00P00000305nNX0H0on`000<0GijP
0000003on000103on00305nNX0070?nb00000000on`00?o/00000000oj4005nNX0030?nQ00030000
003ob`00ol/000<0GijP00<0oh<00000000000000P3oW@000`000000of4005nNX0030?mQ00030000
003oKP00000000D0od000P0000070?lV00030000003oool0oooo00<0oooo00<000000?ooo`3oool0
:P3oool002X0oooo0P00000:0?ooo`8000000P3o0@000`000000o`800?l200030?l200030000003o
1000o`@0008000000P3o20000`000000o`d00?l=00040?l=00040000003o5000oa@00?lD00@00000
103o<0000`000000od000?m000030?m000030000003oD@00oe400080oe4000@000000?mQ003oH@00
of401@0000020?nb00030000003o`000ol0000@0ol0000<000000?o5003oa@000`3oa@000`000000
ol000?o000030?o000<00000103]o`000`000000oo800?ob00030?ob00050000003ob`00ol/00?o;
000000000P1OWZ000`3Go`00000005nNX0060?o/00040000001OWZ00ooP00?oh00<0GijP00@00000
0?nb001OWZ0000000`3ok0001P000000oj400?nQ001OWZ00oj40000000<0GijP00D000000?n3001O
WZ00oh<0000000040?nM00030000001OWZ00of40008000000P3oKP0010000000od000?m0003o@002
00000080odD000<000000?lV003o9P000P3o9P02000000030?lW00000000oooo00@0oooo00<00000
0?ooo`3oool0:@3oool002X0oooo0`0000060?ooo`<00000103o0@000`000000o`800?l200030?l2
00<000001@3o20000`000000o`d00?l=00030?l=00@000000`3o8`000`000000oc000?l`00020?l`
00030000003o@000od0000<0od0000@000000?mA003oD@00oe401@0000020?nM00030000003o/P00
ok8000<0ok8000<000000?o0003o`0000`3o`0000`000000olD00?o500030?o500030000003o`000
ol000080ol000P0000060>go00030000003olP00oo8000@0oo800P00000205nNX0<0eol000<00000
05nNX03ok000103ok002000000<0GijP103on0000`000000GijP0?o/00040?o/00030000003oX@00
GijP0080GijP103ob`0010000000GijP0?n3000000040?nM00030000001OWZ00GijP00D0ofh000<0
00000?m000000000103oA@000`000000obH00?lV0002000000<0obL000<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0Y0?ooo`00:P3oool010000000oooo06IVIP0000030?ooo`8000000P3o
00000`000000o`400?l100030?l100030000003o0P00o`80008000000P3o1@000`000000o`P00?l8
00040?l800030000003o3@00o`d0008000000P3o5`000`000000ob<00?lS00020?lS00030000003o
<000oc0000<0oc0000<000000?m0003o@0000P3o@00400000080oh<000<000000?nM003oW@000`3o
W@000`000000ok800?nb00020?nb00030000003o`000ol0000@0ol0000<000000?o5003oa@000`3o
a@001P000000ol00000000000000eol0000000L0kOl000<000000?ob003olP000P3olP0305nNX0D0
eol000<000000?o/001OWZ000`3ok0001P000000GijP05nNX0000000ooP005nNX0@0ooP000<00000
0?o/001OWZ000P3ok00405nNX0030000003ob`00GijP00@0ol/000D000000?n3001OWZ0000000?nM
000405nNX0030000003oKP00GijP00D0ofh000<000000?m5003oA@00103oA@02000000H0obL000<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`00:@3oool01@000000oooo06IVIP1V
IVH0oooo00<00000103o00000`000000o`400?l100030?l100<000001@3o1@000`000000o`P00?l8
00030?l800<00000103o5`000`000000ob<00?lS00030?lS00030000003o<000oc000080oc0000<0
00000?m0003o@0000P0000000`3oJ00000000?n300040?n300030000003oW@00oid00080oid000<0
00000?nb003o/P000P3o/P000`000000ol000?o000040?o000030000003oa@00olD00080olD00`00
00040=Oo00030000003]o`00kOl000@0kOl000<000000?ob001OWZ000P1OWZ020000000305nNX03G
o`00eol000@0eol000@0000005nNX03ok000on`00P1OWZ020;Oo00030000003on000GijP00<0ooP0
0P0000020?o/0080GijP0`3ok00010000000ol/00?o;001OWZ050?o;00040000001OWZ00GijP0000
00<0oid00P0000000`3oKP00GijP0?m^00030?m^008000001@3oA@000`000000odL0000000050?lW
00030000003o9P00000000D0oooo00<000000?ooo`3oool09`3oool00280oooo0P0000050?ooo`04
0000003oool0oooo06IVIP80oooo0P0000050?l000030000003o0@00o`40008000000P3o0P000`00
0000o`D00?l500040?l500030000003o2000o`P0008000000P3o3`000`000000oaL00?lG00030?lG
00030000003o8`00ob<00080ob<000@000000?l`003o<000oc00100000040?mX00030000003oP`00
oh<00080oh<000<000000?nM003oW@000P3oW@000`000000ok800?nb00030?nb00030000003o`000
ol0000@0ol0000H000000?o50000000000000<oo000000050=Oo00030000003]o`00kOl000@0kOl0
0P1OWZ000`3olP0000000000000209go00030000001OWZ00eol000@0eol000@0000005nNX01OWZ00
GijP102go`0010000000ooP00?oh001OWZ020?oh00060000002go`00GijP05nNX03ok000GijP0P3o
k002000000<0ol/000<0GijP0?o;003ob`000`1OWZ020?nM00040000003oW@00oid000000080ok80
00<000000?m^001OWZ000P3oKP0010000000ogL00?mg000000020?m5008000000P3oA`0010000000
obL00?lW003o9`0200000080obH000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?oo
o`008@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080IVIV0P3oool20000
00D0o`000P0000050?l200030000003o1@00o`D000<0o`D00`0000040?l?00030000003o5`00oaL0
00<0oaL000@000000?lS003o8`00ob<01@0000030?m?00030000003oJ000ofP00080ofP000<00000
0?n3003oP`000`3oP`000`000000oid00?nM00020?nM00030000003o/P00ok800080ok8000<00000
0?o0003o`0000`3o`003000000@0col000<000000=Oo003Go`000P3Go`000`000000kOl00>go0002
0>go0080GijP00<0kOl005nNX0000000102Mo`000`000000eol005nNX0020=Oo00<0GijP0P000000
0`1OWZ00]ol00;Oo00030;Oo00050000003on000GijP0?oh000000000P1OWZ0010000000on`00?o/
001OWZ020?o/00030000003Go`0000000080ol/00`1OWZ0020000000oo800?ob00000000oid00000
003oW@0000000`3o/P001@000000ofh005nNX01OWZ00000000<0ogL000<000000?m5000000001@3o
A`000`000000obL0000000050?lV00030000003oool0oooo00<0oooo00<000000?ooo`3oool09P3o
ool00240oooo00@000000?ooo`3oool00000103oool00`000000oooo06IVIP020?ooo`0306IVIP3o
ool0oooo008000000P3o0002000000030?l100000000o`8000D0o`8000<000000?l5003o1@000P00
00020?l900030000003o3`00o`l000<0o`l000@000000?lG003o5`00oaL01@0000030?li00030000
003oC`00odl00080odl000<000000?mX003oJ0000`3oJ0000`000000oh<00?n300020?n300030000
003oW@00oid00080oid000<000000?nb003o/P000`3o/P000`000000ol0000000002000000030=Oo
00000000col000@0col000<000000=Oo003Go`000`3Go`0010000000kOl005nNX01OWZ030>go0003
0000001OWZ00WOl000<0WOl000<000000=Oo003Go`000P1OWZ030=Oo00030000002go`00GijP00D0
]ol000<000000?oh001OWZ000P1OWZ020;Oo00060000003ok000on`00?o/001OWZ0000000P3Go`00
0`000000GijP05nNX0020?o;000805nNX03olP00oo800?ob00000000oid00000001OWZ020?nb00@0
GijP00<000000?mg001OWZ00103oM`000`000000odL00?m700050?m700030000003o9P00obH000D0
obH000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0U0?ooo`008@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0IVIV00<0oooo00<0IVIV0?ooo`3oool00`0000040?l10003
0000003o0P00o`8000<0o`800`0000040?l900030000003o3`00o`l000<0o`l0100000030?lV0003
0000003o>@00ocT00080ocT000<000000?m?003oC`000`3oC`000`000000ofP00?mX00020?mX0003
0000003oP`00oh<000<0oh<000<000000?nM003oW@000P3oW@000`000000ok800?nb0004000000D0
eol000<000000<oo003?o`000P3?o`000`000000eol00=Oo00020=Oo00<0GijP0`3]o`0300000003
05nNX02Mo`00WOl00080WOl000D0000005nNX01OWZ00eol005nNX0020=Oo008000000P2go`000`1O
WZ00]ol00;Oo000405nNX0030000002go`00GijP00<0]ol000@000000?o/003ok000GijP0P3Go`02
05nNX0050000003ob`00ol/00000001OWZ00103olP02000000030?nb001OWZ00GijP00<0ok8000@0
00000?mg003oM`00GijP0`3oM`000`000000ogX0000000040?m70080000000<0odD00000003o9P00
0`3o9P03000000D0oooo00<000000?ooo`3oool09@3oool00240oooo00@000000?ooo`3oool00000
103oool00`000000oooo06IVIP040?ooo`0306IVIP3oool0oooo008000001@3o0@000`000000o`80
0?l2000200000080o`D000<000000?l9003o2@000`3o2@000`000000o`l00?l?000200000080oaT0
00<000000?lV003o9P000P3o9P000`000000ocT00?li00030?li00030000003oC`00odl00080odl0
00<000000?mX003oJ0000`3oJ0000`000000oh<00?n3000:00000080kOl000<000000=Oo003Go`00
103Go`000`000000col00<oo00020<oo00030000003Go`00GijP0080GijP00<0eol00000001OWZ00
0P3]o`001P000000K_l006ko001^o`00000005nNX080WOl00P1OWZ001P000000eol00=Oo001OWZ00
eol000000080Hol000<000000;Oo002go`000P1OWZ030;Oo0080000000<0]ol005nNX02go`000P2g
o`000`000000on`00000000305nNX080eol000<000000?o;000000000P3olP00101OWZ00oo800?ob
003olP020000000305nNX03o/P00GijP0080ok8000<000000?o0000000000P3oM`000`1OWZ00ogL0
000000030?mj00040000003oA`000000000000<0odD000<000000?lV003o9P000P0000030?lS0003
0000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00280oooo0P0000040?ooo`800000
00<0oooo06IVIP3oool0103oool0101VIVH0oooo0?ooo`0000050?l100<00000103o1@000`000000
o`T00?l900030?l900<00000103o6@000`000000obH00?lV00030?lV00030000003o>@00ocT00080
ocT000@000000?m?003oC`00odl02P0000020?o;00030000003olP00oo800080oo8000<000000>go
003]o`000`3]o`000`000000eol00=Oo00030=Oo00040000003?o`00col00<oo00<0GijP1@3Go`00
0`1OWZ0000000000000406ko00040000001OWZ00GijP05nNX080WOl000D000000=Oo003Go`00eol0
05nNX00306?o00050000001OWZ00GijP0;Oo001OWZ000`2go`001@000000]ol00;Oo002go`00GijP
0080]ol00`1OWZ020=Oo000505nNX03Go`00eol00=Oo000000000`3olP000`1OWZ00oo800?ob0002
05nNX0060000003o/P00ok8005nNX03o/P0000000P3o`0000`000000ogL00?mg000205nNX0D0ogX0
00<000000?m5003oA@00103oA@02000000D0ob<000<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0T0?ooo`00:03oool010000000oooo0?ooo`1VIVH60?ooo`0406IVIP3oool0oooo00000080
o`400P0000020?l200030000003o1@00o`D000<0o`D000<000000?l9003o2@000P0000020?l?0003
0000003o6@00oaT000<0oaT000<000000?lV003o9P000P3o9P0010000000ocT00?li003o>@050000
0080ogX000<000000?nQ003oX@000P3oX@000`000000ol/00?o;00030?o;00030000003olP00oo80
0080oo8000<000000>go003]o`000P3]o`000`000000eol00=Oo00030=Oo00040000001OWZ00GijP
05nNX080col000<0GijP0=Oo003Go`000`3Go`0010000000GijP06ko001^o`0405nNX080WOl000@0
GijP09go002Mo`0000000P3Go`0010000000GijP06?o001So`0205nNX0@0]ol000@0GijP0;Oo0000
00000000102go`0205nNX0030;Oo00000000eol000<0eol000@0GijP0=Oo0000000000000`3olP03
05nNX0030000003]o`00000000<0ok8000<0GijP0?o0003o`0000P3o`00205nNX0030000003oNP00
GijP00<0ogX00P0000050?m500030000003o@000000000H0ob<000<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0S0?ooo`00:03oool010000000oooo0?ooo`1VIVH70?ooo`0306IVIP3oool0
oooo008000001@3o0P0010000000o`D00?l5003o1@04000000@0o`l000<000000?lI003o6@000`3o
6@0010000000obH00?lV003o9P05000000<0oeL000<000000?mj003oNP000P3oNP000`000000oj40
0?nQ00020?nQ00030000003ob`00ol/00080ol/000<000000?ob003olP000P3olP000`000000kOl0
0>go00020>go00030000003Go`00eol00080eol00P1OWZ000`000000col00<oo00020<oo000405nN
X03Go`00eol00=Oo00<000000`1OWZ0306ko00040000002Mo`00WOl005nNX0<0WOl00P0000001P1S
o`00GijP05nNX01OWZ00Hol0000000@0]ol000@0GijP0000001>o`0000000P2go`0205nNX0040;Oo
001OWZ000000000000D0eol000<0GijP0000002Mo`000`1OWZ020?ob000305nNX03]o`00kOl00080
00000P3o/P000`1OWZ00ol000?o0000205nNX0050?o000000000ogX00?mj001OWZ000P3oNP001000
0000ogL00?mg000000020?m5008000000P3o@0000`000000ob<00?lS00020?lS0080000000<0oal0
0000003oool0103oool00`000000oooo0?ooo`0R0?ooo`00:03oool00`000000oooo06IVIP090?oo
o`0406IVIP3oool0oooo000000H0o`800`0000030?l800030000003o3`00o`l000<0o`l000@00000
0?lI003o6@00oaT01@0000030?lk00030000003oE`00oeL00080oeL000<000000?mj003oNP000P3o
NP000`000000oj400?nQ00020?nQ00030000003ob`00ol/00080ol/000<000000?ob003olP000P3o
lP000`000000kOl00>go00030>go00070000003Go`00GijP05nNX03Go`00GijP000000050<oo0003
05nNX0000000000000<0GijP0P1^o`000`1OWZ00K_l006ko000206ko00040000002Mo`00WOl005nN
X080WOl00`1OWZ0206?o000405nNX01So`00Hol0000000<0]ol000@0000005nNX01>o`00C_l00P1O
WZ030;Oo000405nNX01So`00Hol0000000@0eol00`1OWZ001P000000oo800?ob003olP00000005nN
X080kOl00P0000000`3o/P00000005nNX00205nNX080ol0000<000000?o5000000000P3oNP000`1O
WZ0000000?mg00020?mg00030000003oA@00000000D0od0000@000000?lS0000000000000`3o7`00
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0280oooo000X0?ooo`030000003oool0IVIV
00X0oooo00<0IVIV0?ooo`3oool00P0000020?l20080000000<0o`@00000003o2000103o20020000
00<0o`l0100000030?lV00030000003o>`00oc/00080oc/000<000000?mG003oE`000`3oE`000`00
0000ogX00?mj00020?mj00030000003oX@00oj400080oj4000<000000?o;003ob`000P3ob`000`00
0000oo800?ob00020?ob00030000003]o`00kOl00080kOl00P1OWZ030=Oo000305nNX0000000col0
00<0col00P00000205nNX0<0C_l000@0000006ko001^o`00GijP0`1^o`000`000000WOl009go0003
05nNX0030000001So`00Hol000<0Hol000<0GijP06?o000000000`2go`001@000000GijP05nNX01O
WZ00000000<0]ol000D0000006?o001OWZ00Hol00000000405nNX080WOl000D0GijP09go00000000
oo80000000020>go000305nNX03]o`00000000<0GijP0P3o`0000`1OWZ00ol00000000020?o50004
0000003oNP00000005nNX0D0ogL000<000000?m0003o@0001@3o@0000`000000oal00?lO00040?lO
00030000003oool0oooo00<0oooo00<000000?ooo`3oool08@3oool002P0oooo00<000000?ooo`1V
IVH02`3oool00`1VIVH0oooo0?ooo`03000000@0o`@000<000000?l8003o20000`3o200400000080
oaL000<000000?lV003o9P000`3o9P000`000000oc/00?lk00020?lk00030000003oE`00oeL00080
oeL000<000000?mj003oNP000P3oNP000`000000oj400?nQ00020?nQ00030000003ob`00ol/00080
ol/000<000000?ob003olP000P3olP000`000000kOl005nNX00205nNX0030000003Go`00eol000<0
eol000<0GijP0000003?o`000P00000205nNX00304ko001OWZ00C_l00080C_l000D0000006ko001^
o`00K_l005nNX00206ko00<0GijP00D0WOl00000001OWZ004ol00000000506?o000305nNX0000000
]ol000<0GijP0P1>o`000`1OWZ0000000;Oo00020;Oo00030000001So`00Hol00080GijP00@00000
0=Oo003Go`0000000P2Mo`001@1OWZ00WOl00000003olP0000000080kOl00P1OWZ02000000060=Oo
00000000ol000?o0001OWZ000000103oa@0010000000ogL005nNX01OWZ030?mg00030000003oKP00
000000@0od000P0000000`3o>00000000?lO00020?lO0080000000<0oaX00000003oool00`3oool0
0`000000oooo0?ooo`0Q0?ooo`00:03oool00`000000oooo06IVIP0<0?ooo`0306IVIP3oool0oooo
008000001@3o10000`000000o`P00?l8000200000080o`d000<000000?lG003o5`000P3o5`000`00
0000obH00?lV00030?lV00050000003o>`00oc/00?lk000000000`3oE`0500000080ogX000<00000
0?nQ003oX@000P3oX@000`000000ol/00?o;00020?o;00030000003olP00oo8000<0GijP0P3]o`00
0`1OWZ00kOl0000000030=Oo00040000001OWZ00000000000080GijP00D0@ol00000001>o`00C_l0
05nNX00204ko00040000001^o`00K_l006ko00<0GijP00P0000009go002Mo`00000001?o001OWZ00
4ol0000000D0Hol00`1OWZ000`000000C_l004ko000204ko000605nNX0000000]ol00;Oo00000000
Hol00P1OWZ001@1So`00GijP0000003Go`00000000@0WOl000<0GijP09go000000000`1OWZ020>go
0080000000<0eol00000003o`0000P3o`0000`1OWZ00olD00?o5000405nNX0050?mg001OWZ00ogL0
0?mg000000000P3oKP000`000000od000?m00002000000<0ocP000@000000?lO0000000000000`3o
6P000`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo000W0?ooo`040000003oool0
oooo06IVIPd0oooo00@0IVIV0?ooo`3oool000001@3o1003000000@0o`d000<000000?lG003o5`00
0`3o5`0010000000obH00?lV003o9P0900000080oh0000<000000?nb003o/P003000000305nNX080
oo8000@000000>go003]o`00GijP1@000000101>o`00GijP05nNX01OWZ0404?o00060000001>o`00
C_l005nNX01>o`0000000`1OWZ0206ko000405nNX01^o`000000000000<04ol000<0GijP0000001S
o`00101OWZ0206?o000305nNX01>o`00C_l000@0C_l000<0GijP0000000000000P1OWZ0306?o0004
05nNX01So`000000000000@0WOl00`1OWZ000`000000kOl00>go00020>go00070000003Go`00eol0
0=Oo00000000ol000000000305nNX0040?o500000000ol0000000080ogL000<0GijP0000003oKP00
0`3oKP02000000H0ocP000<000000?lJ003o6P00103o6P000`000000oooo0?ooo`030?ooo`030000
003oool0oooo01l0oooo000W0?ooo`80000000<0oooo06IVIP3oool03@3oool0101VIVH0oooo0?oo
o`0000020?l4008000000P3o1`000`000000o`d00?l=00030?l=00040000003o5`00oaL00?lG00D0
00000`3o>@001@000000oeL00?mG003oE`00000000@0oh0000D000000?nb003o/P00ok8000000004
0?o/00030000003Go`00GijP0080GijP00<0000009go001OWZ001@000000101^o`00GijP0000001>
o`0305nNX00304ko00000000GijP00@0@ol000@0000004ko001>o`00C_l00P1OWZ000`000000K_l0
06ko000206ko000305nNX01^o`00000000@04ol00`1OWZ0506?o00030000001OWZ00C_l000D0C_l0
0`1OWZ0606?o000305nNX0000000WOl00080WOl00P1OWZ00102Mo`00000005nNX00000030>go0080
000000<0GijP0=Oo003Go`000`1OWZ020?o5000305nNX0000000ol000080ol0000<000000?mg001O
WZ00103oKP000`000000of40000000040?lh0080000000<0obl00000003o6P000P3o6P0200000003
0?lD00000000oooo00<0oooo00<000000?ooo`3oool07`3oool002L0oooo00@000000?ooo`3oool0
IVIV3`3oool00`1VIVH0oooo0?ooo`02000000@0o`L000<000000?l=003o3@000`3o3@04000000<0
ob<000<000000?li003o>@000P3o>@001@000000oeL00?mG003oE`00000000@0oh0000<000000?nb
003o/P000P3o/P000`000000on`00?o/000305nNX0@0eol000D0000005nNX02Mo`00WOl000000003
06ko00<0GijP1@1>o`000`000000GijP04?o000204?o00070000001>o`00GijP05nNX01>o`00GijP
0000000506ko000305nNX00000004ol000<0GijP0P0Co`000`1OWZ00Hol006?o000206?o00040000
0000ob000?lP05nNX080C_l00`1OWZ020000000305nNX01So`00Hol000@0Hol000<0GijP0000002M
o`000P1OWZ0209go000:0000001^o`00GijP06ko00000000kOl00000003Go`0000000=Oo0080GijP
0P0000030?o5000305nNX03o`000ol0000<0ol0000<0000005nNX01OWZ000P3oKP001P000000of40
0?mQ003oH@0000000?lh008000000`3o;`0010000000oaX00000000000030?lD00030000003oool0
oooo00<0oooo00<000000?ooo`3oool07P3oool002L0oooo00<000000?ooo`1VIVH04@3oool0101V
IVH0oooo0?ooo`0000050?l700030000003o3@00o`d0008000000P3o50000`000000ob<00?lS0002
0?lS00030000003o>@00ocT000<0ocT000D000000?mG003oE`00oeL0000000040?n000040000003o
/P00ok800?nb00<0GijP0P3ok0000`1OWZ00eol00=Oo00020=Oo00030000002Mo`00GijP0080WOl0
0`1OWZ0206ko000305nNX01>o`00C_l000<0C_l000<0000004?o001OWZ000P13o`0205nNX0<0C_l0
00<0GijP0000001^o`000`1^o`00100000000?l^05nNX01OWZ0501?o00050000001OWZ00Hol006?o
000000000`00ob0305nNX0<0C_l000<00000003o801OWZ001P1So`0305nNX0@0WOl000`0000006ko
001^o`00GijP0000003]o`0000000=Oo00000000GijP0=Oo001OWZ020<oo00050000003oa@000000
0?o0001OWZ000P3o`00305nNX0040000003oKP00GijP000000D0of4000<000000?l_003o;`00103o
;`000`000000oa@00?lD00040?lD00030000003oool0oooo0080oooo00<000000?ooo`3oool07P3o
ool002L0oooo00<000000?ooo`1VIVH04P3oool0101VIVH0oooo0000000000030?l700@00000103o
50000`000000ob<00?lS00030?lS00030000003o>@00ocT00080ocT000D000000?mG003oE`00oeL0
000000040?n000060000003o/P00GijP05nNX03o/P0000000`3ok0000`1OWZ00eol00=Oo00020=Oo
00030000002Mo`00GijP0080GijP00<0000006ko001^o`000P1^o`000`000000GijP04ko000304ko
000300000013o`00GijP0080GijP00<0@ol00000001>o`000`1>o`000`1OWZ00K_l006ko00020000
0080GijP00<00?l^05nNX00Co`00100Co`001@000000Hol005nNX01So`00000000<0GijP00<00000
04ko001OWZ000P1>o`001@0000000?lP003o80000000GijP0080Hol00`1OWZ0201?o000505nNX02M
o`00WOl009go000000000`1^o`000`1OWZ00K_l00000000205nNX0040=Oo00000000eol005nNX080
col000@000000?o500000000ol000`1OWZ001P000000ok800?nb00000000ofh005nNX0@0of400P00
00000`3oD@0000000?l_00020?l_0080000000<0obD00000003o5000103o5002000000@0oooo00<0
00000?ooo`3oool07@3oool002L0oooo00<000000?ooo`1VIVH04`3oool00`1VIVH0oooo00000003
000000<0o`/000<000000?lD003o50000`3o500010000000ob<00?lS003o8`0>000000070?n0001O
WZ00GijP0?nb001OWZ00ok80000000040?o/000305nNX03Go`00eol000<0GijP0P2Mo`000`1OWZ00
000006ko000306ko00030000001>o`00GijP0080C_l00`1OWZ0204?o000305nNX013o`00000000@0
C_l000<0GijP0000000000000P1OWZ03003o;P030000001OWZ004ol000<04ol000<0000006?o001O
WZ000P1OWZ03003o80030000001>o`00GijP0080C_l000@00000003o8000ob0000000`1OWZ000`1S
o`00000001?o000201?o000505nNX0000000WOl009go000000000`1^o`0305nNX0<0eol00P000000
103?o`00GijP0<oo003?o`0305nNX080ol0000<0GijP0?nb003o/P000P3o/P000`000000of4005nN
X0020?mQ00060000003oD@00oe400?mA00000000obl00P0000030?lU00030000003o5000oa@000<0
00000P3o3`000`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo000V0?ooo`040000
003oool0oooo06IVIQ@0oooo00@0IVIV0?ooo`00000000001@3o2`02000000<0oa@0100000030?l`
00030000003oC`00odl00080odl000D000000?mj003oNP0000000?nb000205nNX0@0000000<0GijP
0?nb000000000`3ok0000`000000GijP05nNX0020=Oo00050000002Mo`00WOl009go001OWZ00101^
o`000`000000C_l005nNX00205nNX080C_l000H0000004?o0013o`00GijP04?o0000000404ko00<0
GijP1@00obh00`0000004ol005nNX00201?o00<0GijP00<00000003o801OWZ001000ob001@000000
C_l005nNX00000000?lP00<0GijP00D0000006?o001OWZ00Hol00000000401?o000305nNX02Mo`00
000000@0GijP00@0K_l00000001OWZ0000000P3Go`0010000000col00<oo003?o`0205nNX0030=Oo
00000000ol000080ol0000L0GijP0?nb003o/P00ok800000003oW@0000000080GijP00<000000?mA
003oD@000`3oD@000`000000obD00?lU00040?lU008000001@3o3`000`000000oooo0?ooo`020?oo
o`030000003oool0oooo01`0oooo000V0?ooo`040000003oool0oooo06IVIQ@0oooo00<0IVIV0?oo
o`3oool00P0000050?l;00@000000P3o70000`000000oc000?l`00020?l`00030000003oC`00odl0
0080odl000<000000?mj001OWZ000P1OWZ030?nb00040000003on000ooP005nNX0@000000P1OWZ00
1@000000GijP0=Oo003Go`00000000@0WOl000<0GijP06ko001^o`000`1OWZ0204ko000405nNX01>
o`00C_l0000000<0@ol000<0GijP0000001>o`000`1OWZ020000000305nNX000obh00?l^00<00?l^
00<0000001?o000Co`000P1OWZ0201?o000400000000ob000?lP05nNX0@00?lP00<0000004ko001O
WZ000P1OWZ03003o80040000001So`00GijP000000D04ol00`1OWZ0406ko00050000001>o`00GijP
0000003Go`000P0000001@3?o`00GijP05nNX03?o`00GijP0080eol000L000000?o000000000ok80
05nNX03o/P00000000<0GijP00<000000?mA001OWZ00103oD@000`000000od00000000030?lU0080
000000<0oa`00000003o3`00103o3`02000000@0oooo00<000000?ooo`3oool06`3oool002H0oooo
0P0000000`3oool0IVIV0?ooo`0D0?ooo`0306IVIP3oool0oooo008000000P3o2`0200000080o`l0
00D000000?lL003o7000oa`0000000050?l`00030000003oC`00odl000<0GijP0P3oNP000`1OWZ00
ok800?nb00020?nb00050000003on000ooP005nNX00000000P1OWZ040000000305nNX03Go`000000
00@0WOl00`1OWZ0206ko00040000001>o`00C_l005nNX080C_l000@0000004?o0013o`00@ol00`1O
WZ02000000800?mJ00<00000003o;P1OWZ001@00obh205nNX00301?o001OWZ004ol0008000000`00
ob000`1OWZ000?lP003o800305nNX00300000000ob00GijP00<00?lP00@0000006?o00000000GijP
0P0Co`0305nNX00301?o00000000GijP00@0K_l000@0000004ko001>o`00GijP0`0000001@1OWZ00
col00<oo00000000GijP00<0eol000@000000?nb003o/P00ok800P1OWZ020?nM00040000003oP`00
000005nNX080oe400P0000020?m000040000003o9@000000000000<0oa`000<000000?l?003o3`00
0`0000020?l;00030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool002H0oooo00<0
00000?ooo`1VIVH05`3oool00`1VIVH0oooo06IVIP03000000@0o`l000<000000?lL003o70000P3o
70000`000000oc000?l`00020?l`00<0GijP0P3oC`001@000000ogX00?mj003oNP00GijP00<0ok80
00<000000?oh003on0000P1OWZ002P000000]ol00;Oo002go`00000006?o00000000GijP0=Oo0000
000305nNX0030000001^o`00GijP0080K_l000L0000004ko001>o`00C_l005nNX01>o`00000000<0
GijP00<0@ol00000001OWZ001@00oeX00`0000000?l^05nNX002003o;P80GijP00D0000001?o000C
o`00GijP00000002003oRP0400000000ob000?lP003o8080GijP0P00ob0200000003003o801OWZ00
0?lP00<00?lP0P00000305nNX0<04ol00P0000001@1OWZ00K_l006ko001^o`00000000<0C_l00`1O
WZ0010000000col00<oo000000020=Oo000505nNX03Go`0000000>go000000000P1OWZ00103oW@00
GijP0?nM000000030?n300030000001OWZ00000000D0od0000<000000?lL003o7000103o70020000
00D0o`/000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`009P3oool00`000000
oooo06IVIP0H0?ooo`80IVIV00<0oooo0000000000001@3o3`0010000000oa`00?lL003o70030000
0080GijP0P0000000`1OWZ00000000000003000000030?mj00000000GijP0080ok800`1OWZ020?oh
000305nNX02go`00]ol00080]ol000<0000006?o001So`000P1OWZ0200000080WOl000D0000005nN
X01^o`00K_l00000000304ko00<0GijP00L0000004?o000000000000003oJ@000000GijP00@00?mJ
00<00000003o;P1OWZ000P1OWZ02003o;P050000000Co`004ol00000001OWZ000P00ohX01P000000
0?lP05nNX01OWZ000?lP05nNX0800?lP00D00000003o8000ob000?lP05nNX002003o80<0GijP0P0C
o`002P1OWZ004ol001?o000Co`000000003o;P000000GijP06ko0000000405nNX0040000001OWZ00
000000000080col000H000000=Oo003Go`00GijP0000003]o`0205nNX0050000003oW@00oid005nN
X00000001@3oP`0205nNX0<0od000P0000000`3o<00000000?lL00020?lL0080000000<0oa@00000
003o2`00103o2`02000000@0oooo00<000000?ooo`3oool06@3oool002H0oooo00<000000?ooo`1V
IVH06@3oool00`1VIVH0oooo0?ooo`02000000<0o`l01@00000305nNX0@0od0000<0000005nNX03o
J0000P3oJ003000000<0GijP00<0ok800000003on0000P3on0000`1OWZ00]ol00;Oo00020;Oo0005
0000001OWZ00GijP06?o001OWZ000P0Co`040000000305nNX01^o`00K_l000<0GijP00<0C_l00000
001OWZ000P000003003oJ@0300000000oeX0GijP00800?mJ0`1OWZ02003o;P0405nNX000obh00?l^
000000804ol000@0000005nNX000ohX00?n:0P1OWZ03003o800405nNX000ob000000000000<00?lP
0`1OWZ02000000<04ol000@0GijP01?o000Co`0000000P00obh010000000GijP05nNX01OWZ0404ko
000600000013o`00GijP0000003?o`0000000`3Go`0305nNX0070>go00000000oo800000003oW@00
000005nNX0020?n300<0GijP00<0ofP00000001OWZ000P0000030?l`00040000003o700000000000
00@0oa@000<000000?l;003o2`000P0000000`3o1`0000000?ooo`030?ooo`030000003oool0oooo
01T0oooo000V0?ooo`030000003oool0IVIV01T0oooo0P1VIVH20?ooo`@000000P3o500305nNX080
obD000<0GijP0000003o@0000P3o@0000`000000ofP005nNX0020?mX00<0GijP00<0oj400?o/001O
WZ000`0000030?oh000305nNX02go`00]ol00080GijP101So`001P1OWZ004ol001?o000Co`000000
003o;P<0GijP10000002003oFP0305nNX000ofT00?mY00<00?mY00H0000005nNX01OWZ00GijP003o
FP000003003o;P0405nNX000obh00?l^003o;P80000000H00?n:05nNX01OWZ00GijP003oRP000004
003o800305nNX00000000?n[00<0GijP0P00ob00101OWZ000000003oRP00000301?o000305nNX00C
o`00000000<0GijP00<0K_l00000001OWZ000`1>o`001P000000@ol004?o001OWZ0000000<oo00@0
GijP00D0000005nNX03]o`00kOl0000000020?ob00030000003oP`00GijP0080GijP00<000000?mX
003oJ0000P3oJ0000`1OWZ00oc000?l`00040?l`00030000003o5000oa@000D0oa@00P0000040?l7
00030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool002D0oooo00@000000?ooo`3o
ool0IVIV603oool0101VIVH0oooo0?ooo`1VIVH20?ooo`8000000`1OWZ000`3o500000000?lU0002
0?lU000305nNX03o9@00000000<0od0000H0000005nNX01OWZ00GijP0?mX000000030?nQ00030?o/
001OWZ00on`000<0000000@0ooP005nNX01OWZ00GijP0P2go`001P000000Hol006?o001So`000000
05nNX0804ol00P1OWZ02003o;P0305nNX00000000?mJ00@00?mJ00@0000005nNX000ofT00?mY0`1O
WZ02003oFP0405nNX000oeX00?mJ000000<00?l^00<0GijP003o;P00obh00`1OWZ02003oRP0305nN
X000ohX0000000@00?lP00@0000005nNX01OWZ0000001000ob00101OWZ000?n:003oRP00000301?o
00<0GijP0`00obh20000000505nNX01>o`00C_l004ko000000000P13o`000`1OWZ00000005nNX003
0=Oo00050000003]o`00kOl005nNX00000000P3olP001P000000GijP05nNX03oP`00GijP000000@0
ofP000<000000?m?001OWZ000`3o<002000000030?lS00000000oa@000<0oa@00`0000050?l70003
0000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool002D0oooo00@000000?ooo`3oool0
IVIV603oool01@1VIVH0oooo0?ooo`3oool0IVIV00<0GijP0P3o5000101OWZ00oa@00?lD00000003
0?lU000305nNX0000000000000<0GijP0P0000000`1OWZ00ofP0000000030?nQ00050000003ok000
GijP0?o/000000000P1OWZ020000000405nNX02go`00]ol0000000<0Hol000H0000001?o001OWZ00
GijP01?o00000003003o;P0305nNX000oeX00?mJ00<00?mJ00@0000005nNX01OWZ00GijP0P00ofT0
100000000?mJ003oFP1OWZ02003oFP0400000000obh00?l^003o;P<0GijP00<00000003oRP00ohX0
0P00ohX0101OWZ000?n:003oRP000002003o8080GijP00<00?n[05nNX00000001000ob0010000000
GijP003oRP00000305nNX00300000000obh0GijP00<00?l^00H0000004ko001>o`00GijP04ko0000
000305nNX00604?o00000000GijP0000003Go`0000000`3]o`000`1OWZ00oo800?ob000205nNX080
ol/000<000000?mX001OWZ000P3oJ00200000080odl00P1OWZ02000000<0ob<000<000000?lD003o
50000P0000030?l=00030000003o1`00o`L00080o`L00P0000040?ooo`030000003oool0oooo01L0
oooo000U0?ooo`030000003oool0IVIV01T0oooo00<0IVIV0?ooo`1OWZ000P1OWZ00101VIVH0oooo
0?ooo`0000020?lD000305nNX0000000000000<000000`1OWZ001`000000oe400?mA003oD@000000
0?n3001OWZ00100000000`3oX@00000005nNX00205nNX0<0]ol00P0000000`1OWZ00]ol000000003
06?o0080GijP00@04ol005nNX00Co`0000001000obh00`1OWZ000?mJ003oFP0305nNX00300000000
ofT0GijP00800?mY00L00000003oFP00oeX00?mJ05nNX000oeX0000000<0GijP00@00?l^0000001O
WZ0000001@00ohX00`1OWZ000?n:0000000205nNX00500000000oj/00?n[05nNX00000000`00ob00
0`0000000?n:05nNX00205nNX0060000000Co`004ol000000000obh0GijP0`00obh20000000404ko
001OWZ00GijP05nNX0@0@ol000@0000005nNX01>o`0000000`3]o`0010000000GijP05nNX01OWZ03
0?o;00060000003oX@00000005nNX03oJ0000000101OWZ000`3oC`00GijP0?lS00050?lS00800000
1@3o3@000`000000o`L00?l7000200000080o`@000<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0F0?ooo`009@3oool20000000306IVIP3oool0oooo01L0oooo0P1OWZ020?ooo`0305nNX03o
ool0IVIV0080oooo0`0000000`1OWZ00oaX00?lJ000205nNX080obl000<0GijP0000003oD@000P3o
D@001P000000oh<00?n3001OWZ00oh<00?o;00<0GijP00@000000?o/001OWZ0000000P2go`001P00
0000C_l00000001OWZ00]ol000000080GijP00H0Hol00000000Co`00GijP01?o00000004003o;P<0
GijP0`00oeX00`0000000?mY05nNX003003oJ@0300000000oeX00?mJ00<0GijP0P00obh200000004
003oh@1OWZ000?oQ000000@00?n:0`1OWZ000`00ob000000003oZ`03003oZ`0305nNX00000000?lP
00<0GijP0P00ohX0101OWZ00000001?o00000003003o;P0305nNX000obh0000000<0GijP00<0C_l0
0000001OWZ000`13o`020000000404ko001OWZ00K_l0000000<0GijP0P3olP00101OWZ00ol/00?o;
000000030?nQ00<0GijP0`3oC`02000000040?li001OWZ00ob<00?lS008000000P3o5`000`000000
o`d00?l=00030?l=00<00000103o10000`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0
oooo000U0?ooo`030000003oool0IVIV01L0oooo0P1OWZ000`1VIVH0oooo0?ooo`020?ooo`0305nN
X03oool0IVIV0080oooo00<000000?lJ001OWZ000P1OWZ000`3o6P0000000?l_00020?l_000305nN
X0000000oe400080oe4000<000000?n3001OWZ000P1OWZ030?o;0080000000<0GijP0000002go`00
0P2go`000`000000C_l005nNX00205nNX0<0Hol000H0000001?o000Co`00GijP00000000obh305nN
X00300000000oeX0GijP00<00?mJ00@00000003oJ@00ofT0GijP0P00ofT305nNX0800?mJ00<0GijP
0000000000001000on400`1OWZ000000003oRP0305nNX0800?n:00<0GijP0000000000001000oj/3
05nNX00300000000ohX00?n:00800?n:00@0GijP003oRP00000000000`00obh305nNX0800?mJ00@0
000004ko00000000GijP0`13o`020000000604ko001OWZ00GijP05nNX01^o`0000000P3olP001@00
0000ol/005nNX0000000oj4000<0GijP00@000000?mj001OWZ00odl00P0000030?li000305nNX000
0000000000@0oaL000<000000?l=003o3@000`0000020?l800030000003o1000o`@00080o`@00P00
00040?ooo`030000003oool0oooo01D0oooo000U0?ooo`030000003oool0IVIV01D0oooo0P1OWZ00
0`3oool0GijP06IVIP050?ooo`0305nNX03oool0IVIV00<0GijP00@000000?lJ001OWZ00oaX01@00
00000`1OWZ0000000000000305nNX0040000003oP`00GijP000000<0ol/00P0000000`1OWZ000000
0;Oo000305nNX080C_l000D0GijP000000000000Hol00000000201?o00<0GijP0`00obh00`000000
0?mJ05nNX003003oFP0300000000ofT00?mY00<0GijP00<00000003oFP00oeX00P00oeX00`1OWZ00
0000003oh@04003oh@<0GijP1P00ohX00`1OWZ000?n[003oZ`0305nNX004003oZ`000000GijP0000
00D00?n:00<0GijP00000000obh00`1OWZ000`00obh0000005nNX002003oFP8000000P13o`001P1O
WZ00@ol00000001OWZ00000005nNX080K_l000<0GijP0000002Mo`000P0000020?o;00040000001O
WZ00GijP0?nQ008000000P3oNP000`1OWZ0000000?li00030?li00040000001OWZ00GijP000000@0
oaL00`0000050?l800030000003o1000o`@0008000000P3o0P000`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01@0oooo000T0?ooo`040000003oool0oooo06IVIQ<0oooo0P1OWZ040?ooo`03
05nNX03oool0oooo00<0oooo0`1OWZ000`1VIVH0oooo0?ooo`030000000405nNX03o7`00oal00000
0080ocP00`1OWZ030?mQ0080000000<0GijP0000003ob`000P3ob`000`000000eol005nNX00205nN
X0030;Oo00000000C_l000<0C_l000<0GijP003o800000000`1OWZ0201?o000305nNX000obh00?l^
00800?l^00<00000003oFP1OWZ000P00oeX305nNX0800?mY00<0GijP00000000oeX00`00oeX01000
0000GijP003oh@00on4305nNX003003oh@000000GijP00D00?n:0P00000205nNX0D00?n[00<0GijP
003oRP00ohX01000ohX305nNX0@00?l^00<0000005nNX000oeX00P00oeX00`000000@ol004?o0003
05nNX00304ko0000000000000080K_l000H0GijP0000002Mo`0000000=Oo0000000205nNX0030?nQ
001OWZ00000000@0ogX000@0000005nNX0000000ocT00`1OWZ020?lV000305nNX03o5`00oaL00080
00000P3o3`000`000000o`P00?l800030?l800<00000103o0P000`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01@0oooo000T0?ooo`040000003oool0oooo06IVIQ00oooo0`1OWZ060?ooo`04
06IVIP1OWZ00oooo0?ooo`80GijP0P3oool00`1OWZ00oooo06IVIP020?ooo`80000000@0oal005nN
X03o7`0000000P1OWZ020?lh000505nNX03oH@00of400?mQ000000000P3oW@000`1OWZ0000000?o;
000305nNX0030=Oo00000000GijP0080]ol000@0000004ko001>o`00C_l00`1OWZ000`00ob000000
01?o000201?o00030000001OWZ000?l^00800?l^00<00000003oFP1OWZ000P1OWZ000`0000000?mY
003oJ@02003oJ@0405nNX000ofT00000003oFP80000000@00>Co05nNX01OWZ00GijP1@00on400`1O
WZ000?n:003oRP02003oRP050000001OWZ00GijP003oZ`1OWZ001@00oj/010000000GijP003oRP00
ohX305nNX00300000000on40GijP00<00?l^00@00000003oFP00oeX0GijP0P00oeX305nNX00504?o
00000000GijP04ko000000000`1^o`0010000000GijP09go0000000205nNX080on`000<0000005nN
X03oNP000P3oNP02000000040?mG001OWZ00GijP05nNX0D0obH000<0GijP0000000000001@3o3`00
0`000000o`P00?l8000200000080o`D000<000000?l2003o0P000P3o0P02000000@0oooo00<00000
0?ooo`3oool04`3oool002@0oooo00@000000?ooo`3oool0IVIV3P3oool205nNX080oooo00<0GijP
0?ooo`3oool00`3oool00`1VIVH0oooo05nNX00205nNX0D0oooo00<0GijP0?ooo`1VIVH00P3oool0
0`000000oal005nNX00205nNX0030000003o>000ocP00080ocP000H0GijP0?mQ003oH@00of400000
003oW@0305nNX0030000003ob`0000000080eol000D0000005nNX01OWZ00000004ko000205nNX004
00000000ob00GijP003o80<0000000@04ol000000000obh0GijP0P00obh205nNX0800?mJ00<0GijP
003oFP0000001000ofT00`1OWZ0000000000000305nNX003003To`000000GijP00D00?oQ00@00000
05nNX000ohX00?n:0P1OWZ02003?o`030000001OWZ000?n[00<00?n[0P00000305nNX0<00?n:00<0
0000003oh@1OWZ000`00obh00`0000000?mJ003oFP0305nNX0800?mY00H0000004?o00000000GijP
04ko0000000306ko00060000001OWZ00GijP05nNX03Go`0000000P3ok0001@000000ok8005nNX03o
NP00000000<0GijP0P000000101OWZ0000000?lV003o9P02000000030?lI001OWZ00000000D0o`l0
0`0000040?l500030000003o0P00o`80008000000P3o0@000`000000oooo0?ooo`020?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0IVIV00`0oooo0`1OWZ050?ooo`80GijP0P3o
ool305nNX080oooo00<0GijP0?ooo`3oool0103oool00`1OWZ00oooo06IVIP0305nNX080oal000<0
GijP000000000000100000000`1OWZ0000000000000205nNX0040000003oW@00GijP0?ob00800000
0P3Go`000`000000Hol006?o000205nNX080C_l000D00000003o8000ob00GijP00000002003oRP<0
00000`1OWZ000`0000000?mJ003oFP02003oFP0305nNX00000000?mY00<00?mY0`1OWZ04003To`03
0000001OWZ000?oQ00@00?oQ00D0000005nNX01OWZ00GijP00000003003?o`0300000000oj/0GijP
00800?n[0`1OWZ000`0000000?n:05nNX002003oRP0700000000on400?oQ003oh@1OWZ000?l^0000
000305nNX0800?mJ00D0GijP003oJ@00ofT00?mY0000000204ko000305nNX01^o`00000000<0GijP
00@000000=Oo001OWZ0000000P3ok0000`000000ok800?nb000305nNX0030?mG0000000000000080
oc/000@0GijP0?lk0000000000000`3o6@0205nNX080o`l00`0000020?l900030000003o1@00o`D0
0080o`D00`0000040?l100030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`1VIVH02P3oool205nNX080oooo00<0GijP0?ooo`3oool0103oool305nNX003
0?ooo`1VIVH0oooo00<0oooo00<0GijP0?ooo`3oool00`3oool305nNX00306IVIP3oool0oooo0080
000000@0GijP0?lS003o8`0000000`3o@00305nNX080ofh00`000000101OWZ00oo80000000000002
0=Oo0080GijP00<0Hol005nNX01>o`000P1>o`001P0000000?lP003o801OWZ000000003oRP<0GijP
0P0000000`1OWZ000?l^00000004003oFP0305nNX000ofT000000080GijP00<00<oo0000001OWZ00
1000i?l00`0000000?oQ05nNX002003oh@<0GijP0P00ohX00`1OWZ000<oo003?o`02003?o`030000
0000oj/00?n[0080GijP00H00000003?o`00col00000003oRP1OWZ02003oRP0400000000on400?oQ
003oh@<0GijP1000oeX00`000000GijP003oJ@02003oJ@80000000d0C_l005nNX01OWZ00000006ko
00000000WOl00000003Go`00000005nNX03ok000000000<0GijP00@000000?n0001OWZ000000103o
>`0010000000GijP0?lV0000000305nNX0040?lI001OWZ000000000000D0o`T000<000000?l5003o
1@000P0000020?l200030000003o0@00o`400080o`400P0000040?ooo`030000003oool0oooo0140
oooo000T0?ooo`80000000<0IVIV0?ooo`3oool01@3oool305nNX0D0oooo0P1OWZ020?ooo`80GijP
0P3oool00`1OWZ00oooo06IVIP050?ooo`0305nNX03oool0oooo0080GijP0P3oool00`1OWZ00oooo
06IVIP020?ooo`030000003o8`00GijP0080ob<00`1OWZ020?m0000405nNX03oKP00ofh000000080
ok8000@0000005nNX03olP0000000P1OWZ001@000000Hol006?o001OWZ0000000080C_l000<00000
003o8000ob000`1OWZ02003oRP0400000000on400?oQ05nNX0H000000`1OWZ03003?o`0300000000
i?l0GijP00<00>Co00<00000003oh@1OWZ000P1OWZ03003oh@80000000<00<oo05nNX00000000P00
col01P000000GijP05nNX000oj/0GijP000000800<oo00H00000003oRP00ohX0GijP00000000on43
05nNX003003oh@000000GijP00@00?mJ00D00000003oJ@1OWZ000?mY0000000305nNX080K_l00P00
00001@2Mo`0000000=Oo00000000on`000<0GijP00T0ok80000000000000oh000000001OWZ00oeL0
0000003o>`000P000000103o9P00GijP05nNX01OWZ020?lI0080000000<0o`l005nNX00000001@3o
2@03000000@0o`8000<000000?l1003o0@000P0000020?l000050000003oool0oooo0?ooo`000000
4`3oool002@0oooo00<000000?ooo`1VIVH0103oool305nNX080oooo00<0GijP0?ooo`3oool01@3o
ool205nNX0D0oooo00<0GijP06IVIP3oool0103oool305nNX0D0oooo00<0GijP0?ooo`1VIVH00P3o
ool010000000GijP05nNX01OWZ060000000405nNX0000000ofh000000080ok800`1OWZ0209go0080
00000P1So`000`1OWZ0000000000000305nNX003003o80000000GijP00800?n:00L00000003oh@00
on400?oQ05nNX00000000>Co00<0GijP00<00000003?o`1OWZ001000col01@0000000>Co05nNX000
00000>Co00d000000`1OWZ00100000000?n[003oZ`000004003?o`0300000000ohX0GijP0080GijP
1000on400`000000GijP003oFP02003oFP0300000000ofT00?mY00<0GijP0P00oeX20000000506ko
00000000GijP09go000000000`1OWZ001@3ok000000005nNX0000000oh00008000000P3oE`000`1O
WZ00oeL00000000305nNX0030?lV001OWZ00obH0008000000`3o3`00101OWZ0000000?l9003o2@03
00000080o`D000<000000?l2003o0P000P3o0P03000000@0o`0000@000000?ooo`3oool0oooo0P00
000B0?ooo`00403oool2000000@0oooo0P0000040?ooo`8000001@3oool010000000oooo06IVIP1V
IVH20?ooo`80GijP1P3oool00`1OWZ00oooo0?ooo`020?ooo`80GijP00<0oooo05nNX03oool01@3o
ool00`1OWZ00oooo0?ooo`0305nNX080oooo00<0GijP0?ooo`3oool0103oool00`1OWZ00oooo06IV
IP0205nNX080000000@0GijP0?lV003o9P000000103oA@000`1OWZ0000000000000205nNX0040?nb
00000000GijP00000080WOl000<0000006?o001So`000`1OWZ02000000800?lP00<0000005nNX000
ohX00P00ohX00`0000000?oQ003oh@0305nNX0<00>Co00L00000003?o`00col0GijP003?o`000000
0<oo00<000000P1OWZ0E000000800<oo00H0000005nNX01OWZ000000003oh@1OWZ04003oh@800000
00<0GijP003oFP00oeX00`1OWZ001@00ofT0000005nNX000oeX0000000800?l^0P00000305nNX0D0
000000<0GijP000000000000103oE`0305nNX0030000003o9P00obH00080000000<0GijP0?lG0000
00000`3o3`0205nNX08000001@3o1@000`000000o`800?l2000200000080o`4000<000000?l0003o
00000P3o0004000000030?ooo`000000oooo0140oooo000?0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`1VIVH30?ooo`0305nNX03oool0
oooo00D0oooo00@0GijP0?ooo`1OWZ00GijP103oool00`1OWZ00oooo0?ooo`030?ooo`<0GijP1@3o
ool00`1OWZ00oooo0?ooo`040?ooo`<0GijP00P0IVIV0?ooo`3oool000000?lV001OWZ00obH00000
00@0odD00`1OWZ001@3oM`0000000000003o/P0000000080GijP00T0WOl00000001OWZ00GijP0000
0000ob00GijP003o800000000`00ob0010000000GijP003oRP00ohX305nNX0800?oQ00<0GijP003T
o`00i?l00P00i?l00`0000000<oo0000000:000000D00?oQ0P000004003?o`T000000P1OWZ030000
0003003oh@1OWZ000?oQ00800?oQ00<00000003To`0000000`1OWZ04003oJ@0500000000oeX0GijP
00000000obh00P1OWZ020000000;06?o001OWZ00]ol00;Oo00000000ooP00000003o/P00GijP0?mj
000000000`1OWZ00103o>@00GijP0?li003o>@0200000080oaL000<0GijP0?lG003o5`000`1OWZ02
0?l8000305nNX0000000000000<0o`D0100000040?l100030000003o0000o`0000<0000000D0oooo
06IVIP3oool0IVIV0000000B0?ooo`003`3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`1VIVH0oooo06IVIP030?ooo`0305nNX03oool0oooo00@0oooo
0P1OWZ070?ooo`0305nNX03oool0oooo0080GijP00<0IVIV0?ooo`1OWZ001P3oool00`1OWZ00oooo
0?ooo`0305nNX080oooo00<0GijP0?ooo`1VIVH00P3oool01@000000obH005nNX03o9P00000000<0
GijP00H0odD00000001OWZ00ogL00000003o`002000000040>go001OWZ00GijP05nNX080000000@0
Hol000000000ob00GijP0P000002003o80050000001OWZ00GijP05nNX00000001000on40101OWZ00
0>Co003To`00i?l9000000@00>Co00<00000003oh@00on400P00on400`000000067o00000007003?
o`0300000000oj/0000000T0000000@00?oQ05nNX000on400?oQ0`1OWZ000`0000000?mJ05nNX003
003oJ@0300000000oeX00?mJ00<0GijP00`00?l^000000000000000006?o001OWZ00]ol00000003o
n00000000?nb0000000305nNX0060000003o>@00ocT00?li00000000GijP0P3o8`000`000000oaL0
0?lG000305nNX0030?l=00000000o`P00080o`P000<0GijP0?l8000000000`0000030?l200030000
003o0@00o`400080o`400`0000030?ooo`<0IVIV00<0oooo0000003oool04@3oool000l0oooo00@0
00000?ooo`3oool000002@3oool2000000D0oooo00<000000?ooo`1VIVH00P3oool01@1VIVH0oooo
0?ooo`3oool0GijP0080oooo0`1OWZ020?ooo`0305nNX03oool0oooo00@0oooo0`1OWZ000`3oool0
IVIV0?ooo`020?ooo`0305nNX03oool0oooo00<0oooo0`1OWZ060?ooo`0605nNX03oool0IVIV0?oo
o`1VIVH000000`1OWZ060000000305nNX03oM`00000000<0GijP00D0kOl00000001OWZ00000001?o
0002000000800?lP00<0GijP003oZ`0000000P1OWZ02003oRP0305nNX00000000?oQ00<00?oQ00<0
000005nNX000i?l01@000003003?o`0300000000i?l00>Co00<00>Co00D00000003oh@00on400?oQ
00000003001Qo`0300000000col00<oo00D00<oo00<00000003?o`00col00`00col00`1OWZ000000
00000003000000<0GijP0`00i?l200000004003oJ@1OWZ000?mY003oJ@<0GijP00`00000003o;P1O
WZ00000001?o00000000Hol00000002go`00GijP0?oh0000000305nNX0040?mj001OWZ0000000?m?
00<0000000@0ob<005nNX03o8`00ob<00`1OWZ020?l=000305nNX03o3@0000000080o`P00P000000
101OWZ00o`@00?l4000000040?l200030000003o0@00o`40008000000`3oool306IVIP030?ooo`1V
IVH0oooo0080oooo00<000000?ooo`3oool03`3oool000l0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0IVIV00<0oooo00@0IVIV0?ooo`3oool0oooo
0P1OWZ060?ooo`0305nNX03oool0oooo00<0GijP0P3oool00`1OWZ00oooo06IVIP040?ooo`0305nN
X03oool0oooo0080GijP0P3oool00`1OWZ00oooo0?ooo`050?ooo`0305nNX03oool0IVIV0080GijP
00D000000?lW001OWZ00obL0000000040?m700<0GijP0P000000103o`00000000000001OWZ020000
000401?o000000000000003o80<0GijP0P000003003oRP0305nNX00000000?oQ00800?oQ0P000000
101OWZ000000000000000006003?o`0300000000i?l00>Co00<00>Co00<00000003oh@0000001000
HOl00`0000000<oo003?o`05003?o`0300000000col00<oo00D00<oo1@0000000`00on40GijP003T
o`03003To`0300000000ofT0GijP0080GijP00<00000003oFP0000000P00obh00`1OWZ0000000000
000200000080]ol00`1OWZ020?mj0080000000L0odl005nNX000000000000?l`00000000ob<000<0
GijP00<000000?lD000000000P3o3@000`1OWZ00o`d00000000200000080o`@00P1OWZ000`3o1000
00000?l200020?l200@000000P3oool306IVIPD0oooo00@0IVIV0?ooo`3oool000004@3oool00100
oooo0P00000:0?ooo`<00000103oool00`000000oooo06IVIP040?ooo`80IVIV0P3oool00`1OWZ00
oooo0?ooo`040?ooo`<0GijP1P3oool00`1OWZ00IVIV0?ooo`030?ooo`<0GijP1@3oool00`1OWZ00
oooo0?ooo`040?ooo`<0GijP00D0IVIV0?ooo`3oool000000?lW000205nNX0080000003oA`00GijP
05nNX03oA`00000005nNX03oNP050000000305nNX00000004ol000<0GijP00@00?lP0000001OWZ00
0?n[0P000003003oRP0305nNX000on400?oQ00D0000000<00>Co00000000col01@00col00`000000
0>Co003To`03003To`8000001@00HOl00`0000000<oo003?o`04003?o`8000001P00col010000000
067o00000000on440000000305nNX000i?l00>Co00<0GijP0P00ofT0101OWZ000?mJ003oFP000002
003o;P040000001OWZ000000000000<0GijP00<0000005nNX03oX@000P0000020?m?00040000001O
WZ00oc000?l`00<0GijP0P000000101OWZ00oa@00?lD000000020?l=00040000001OWZ00o`L00?l7
00<0GijP0P3o10000`1OWZ00000000000002000000<0oooo0`1VIVH80?ooo`0406IVIP3oool0oooo
00000140oooo000R0?ooo`040000003oool0oooo06IVIPH0oooo00<0IVIV0?ooo`3oool00P1OWZ02
0?ooo`80GijP0P3oool00`1OWZ00oooo0?ooo`050?ooo`0305nNX03oool0oooo0080GijP0P3oool0
0`1OWZ00oooo0?ooo`040?ooo`0305nNX03oool0oooo00<0GijP0P3oool00`1OWZ00IVIV06IVIP02
0?ooo`8000000`1OWZ050000000405nNX03oNP0000000?o5008000000`1OWZ001P0Co`0000000000
0000ob00000005nNX0800?n[00@00000003oRP00ohX00?n:0`1OWZ04000000<00>Co00<00000003?
o`00col00`00col00`0000000>Co003To`03003To`0300000000HOl0067o00@0067o00<00000003?
o`00col01000col00`000000037o00000005003?o`0400000000HOl00000003oh@D000000P1OWZ00
0`0000000<oo00000002003oJ@0305nNX000oeX0000000<00?l^00<0000005nNX01OWZ001@000000
103oX@00GijP0000003oJ002000000040?l`001OWZ00GijP05nNX080oc0000@000000?lD003o5000
GijP0`3o5002000000060?l7001OWZ00GijP05nNX03o1`0000000P3o10000`000000GijP0?ooo`03
0?ooo`<0IVIV2`3oool0101VIVH0oooo0?ooo`00000A0?ooo`008P3oool2000000030?ooo`1VIVH0
oooo00H0oooo00@0IVIV0?ooo`3oool0oooo0P1OWZ050?ooo`0305nNX03oool0oooo00@0oooo0`1O
WZ050?ooo`0305nNX03oool0oooo00<0oooo0`1OWZ060?ooo`0305nNX03oool0IVIV00<0GijP0P3o
9P000`1OWZ0000000?m500030?m500040000001OWZ00000000000080GijP00`0000006ko001OWZ00
000001?o000000000?lP00000000oj/0GijP003oZ`00000305nNX0H000001000i?l00`0000000<oo
003?o`03003?o`0300000000i?l00>Co00800>Co0P000007001Qo`0300000000col00<oo00800<oo
00@00000000ao`00<Ol000001000col010000000067o001Qo`000003003oh@H000000P00col20000
0004003oFP1OWZ000000003o;P<0GijP00<0000005nNX00000000P0000001P3oX@0000000000001O
WZ00ofP0000000<0GijP0P3o<0001@1OWZ0000000?lL003o700000000080oa@000<0GijP0000003o
2`000`1OWZ020?l7000305nNX03o1`0000000080000000<0oooo05nNX01OWZ000`1VIVH>0?ooo`04
06IVIP3oool0oooo00000140oooo000R0?ooo`040000003oool0oooo06IVIPP0oooo00D0IVIV0?oo
o`3oool0oooo05nNX0060?ooo`0305nNX03oool0oooo00<0GijP00<0IVIV0?ooo`1OWZ001P3oool0
0`1OWZ00oooo0?ooo`0205nNX080oooo00<0GijP0?ooo`3oool00`3oool01@1VIVH0GijP05nNX01O
WZ00IVIV0080oooo00D000000?lV001OWZ00obH0000000040?m500<0GijP100000000`1^o`00GijP
01?o000300000005003oZ`1OWZ00GijP05nNX000col01P0000000`00on400000003To`03003To`03
00000000col00<oo00<00<oo00L00000003To`00i?l00>Co000000006?l0000000L0067o00D00000
003?o`00col00<oo00000003000ao`0300000000col00<oo00800<oo00T00000001Qo`00HOl0067o
00000000on40000005nNX000i?l00P0000000`1OWZ000000003?o`02003?o`0300000000oeX0GijP
0080GijP00D00?l^000000000000000004ko000400000080ofP00`1OWZ030?m00080000000<0oa`0
05nNX03o70000P3o70000`000000GijP05nNX00205nNX0080?l;00000000o`L00?l700000000GijP
0000003oool305nNX080IVIV00<0GijP0?ooo`3oool03P3oool0101VIVH0oooo0?ooo`00000A0?oo
o`008P3oool00`000000oooo06IVIP0:0?ooo`0506IVIP3oool0oooo0?ooo`1OWZ001@3oool305nN
X0<0oooo00<0IVIV0?ooo`1OWZ001P3oool305nNX0D0oooo0P1OWZ020?ooo`80GijP0P3oool00`1O
WZ00oooo06IVIP020?ooo`80000000<0GijP0000000000000`1OWZ020000000305nNX03oM`000000
00@0000000<0GijP00000000ohX00P1OWZ02003oZ`0305nNX0000000000000<000000`00on400`00
00000>Co003To`02003To`0300000000col00<oo00@00<oo00<00000003To`0000000`006?l00`00
0000067o001Qo`04001Qo`0500000000col00<oo003?o`0000000`00<Ol01@0000000<oo003?o`00
col0000000@0067o00<00000003oh@0000000P00i?l30000000405nNX00000000<oo003?o`80GijP
0P000000101OWZ00000000000000ob03000000030?o;00000000GijP0080GijP0P3o@0000`1OWZ00
0000000000020?lU00030000003o7000GijP00@0GijP00D000000?l;003o2`00GijP0?l;00030000
00040?ooo`1OWZ00GijP05nNX080IVIV0`3oool00`1OWZ00oooo0?ooo`0>0?ooo`0406IVIP3oool0
oooo00000140oooo000R0?ooo`030000003oool0IVIV00/0oooo00D0IVIV0?ooo`3oool0oooo05nN
X0020?ooo`80GijP0P3oool01@1OWZ00oooo0?ooo`3oool0IVIV0080oooo00<0GijP0?ooo`3oool0
0`1OWZ020?ooo`0305nNX03oool0oooo00@0oooo0`1OWZ000`3oool0IVIV0?ooo`020?ooo`0305nN
X03oool0IVIV0080oooo00D0000005nNX01OWZ00GijP000000040?m0000305nNX0000000000000@0
00000`1OWZ02000000<00?n[00<0GijP0000000000000`000003003oh@0500000000i?l00>Co003T
o`0000001P00col2000000@001So00<00000001Qo`00HOl01000HOl0100000000<oo003?o`000005
000ao`0400000000col00<oo000000D0067o00<0000005nNX000i?l00P00i?l50000000605nNX000
i?l00>Co00000000on40GijP0`0000000`1>o`0000000000000205nNX0030000003oD@00oe4000<0
000000<0GijP0?lU003o9@000`1OWZ000`000000GijP0?l?00020?l?00060000003o2`00o`/005nN
X0000000oooo0`1OWZ0206IVIP0305nNX03oool0oooo00@0oooo00<0GijP0?ooo`3oool03@3oool0
1@1VIVH0oooo0?ooo`3oool000000100oooo000R0?ooo`030000003oool0IVIV00`0oooo00@0IVIV
0?ooo`3oool0oooo0P1OWZ050?ooo`80GijP00<0IVIV0?ooo`3oool0101OWZ060?ooo`0305nNX03o
ool0oooo00<0GijP0P3oool00`1OWZ00oooo06IVIP040?ooo`0305nNX03oool0IVIV0080GijP00D0
00000?lS001OWZ00ob<0000000030?m000040000001OWZ000000000000<0GijP00D000000?ooo`1O
WZ000?n:00000002003oZ`H0000000D0067o0000000000000?oQ00000004003To`0300000000col0
0<oo00800<oo0P000005000Ho`0300000000HOl0067o00D0067o0P000006000ao`0400000000col0
0<oo000000D0067o00<00000003To`00i?l00P00i?l00`0000000<oo003?o`0300000008003To`00
00000?oQ003oh@000000GijP0000001>o`0205nNX080000000@0GijP0?mA0000000000000P3o;`00
1@000000GijP05nNX01OWZ0000000080oa@00P0000000`1OWZ00o`l00?l?0003000000<0GijP0P1V
IVH30?ooo`0305nNX03oool0oooo00@0oooo0P1OWZ0>0?ooo`0506IVIP3oool0oooo0?ooo`000000
403oool00280oooo00<000000?ooo`1VIVH03@3oool01@1VIVH0oooo0?ooo`3oool0GijP00H0oooo
101OWZ030?ooo`0305nNX03oool0oooo00@0oooo0`1OWZ050?ooo`0305nNX03oool0IVIV00@0oooo
0`1OWZ000`1VIVH0oooo0?ooo`0200000080GijP0`00000405nNX0H0000000@0GijP000000000000
GijP100000000`00col00000001Qo`02001Qo`@000000P00i?l00`0000000<oo0000000200000003
0040o`00000001So00@001So00<00000001Qo`00HOl01@00HOl2000000H0037o00<00000003?o`00
00001P00HOl00`0000000>Co003To`02003To`0300000000col0000000<0000000D00>Co00000000
on400?oQ0000000305nNX0D0000000<0GijP0?l_003o;`000`1OWZ020000000305nNX03o5000oa@0
00<0oa@000<0GijP0000000000000`1OWZ0206IVIP0305nNX03oool0oooo00@0oooo00<0GijP0?oo
o`3oool00`1OWZ020?ooo`0305nNX03oool0oooo00`0oooo00@0IVIV0?ooo`3oool00000403oool0
0240oooo00@000000?ooo`3oool0IVIV3P3oool0101VIVH0oooo0?ooo`3oool205nNX080oooo0P1O
WZ000`3oool0IVIV05nNX0050?ooo`80GijP0P3oool205nNX080oooo00<0GijP0?ooo`3oool0103o
ool00`1OWZ00IVIV0?ooo`0305nNX080oooo00<0GijP0?ooo`1VIVH00P3oool00`000000oal005nN
X00305nNX0<0ocP000@0GijP0000003oH@00of400`00000305nNX0@000000P00col00`000000067o
001Qo`02001Qo`03000000006?l001So00@0000010010?l00`00000001So000Ho`03000Ho`030000
0000HOl0067o00D0067o00<00000000ao`00<Ol01@00<Ol00`0000000<oo00000005001Qo`030000
00006?l0000000<00>Co00<00000003?o`000000100000001000on40GijP05nNX01OWZ0200000003
05nNX03oH@00of400080000000D0ocP005nNX01OWZ00GijP0?l_0002000000030?lJ00000000GijP
0080oa@00P000000103oool0GijP05nNX01OWZ0206IVIP<0oooo00<0GijP0?ooo`3oool0103oool3
05nNX0D0oooo00<0GijP0?ooo`3oool0303oool0101VIVH0oooo0?ooo`00000@0?ooo`008@3oool0
10000000oooo0?ooo`1VIVH?0?ooo`0306IVIP3oool0oooo0080oooo0P1OWZ030?ooo`0306IVIP3o
ool0GijP00D0oooo0`1OWZ050?ooo`0305nNX03oool0oooo00<0oooo0`1OWZ060?ooo`0305nNX03o
ool0IVIV00<0GijP0P3o7`000`1OWZ000000000000030000000305nNX0000000000000<0GijP0P00
0000101OWZ000000000000000004003?o`0500000000HOl0067o001Qo`00000010006?l00`000000
0@3o0040o`040040o`03000000006?l001So00<001So00<00000001Qo`00HOl00`00HOl2000000P0
037o00<00000001Qo`00HOl01000HOl00`00000001So00000002003To`0400000000col00<oo003?
o`<000000P1OWZ000`00on400000000000020000000605nNX0000000000005nNX0000000GijP0P3o
>0000`1OWZ0000000?lJ00040?lJ000305nNX0000000oooo0080GijP0P1VIVH00`1OWZ00oooo06IV
IP040?ooo`0305nNX03oool0oooo00<0GijP0P3oool00`1OWZ00oooo0?ooo`030?ooo`80GijP3@3o
ool0101VIVH0oooo0?ooo`00000@0?ooo`008@3oool20000000306IVIP3oool0oooo00l0oooo00<0
IVIV0?ooo`3oool00P3oool01@1OWZ00oooo0?ooo`3oool0IVIV0080oooo00<0GijP0?ooo`3oool0
0P1OWZ020?ooo`0305nNX03oool0oooo00@0oooo00<0GijP0?ooo`3oool00P1OWZ000`3oool0IVIV
05nNX0060?ooo`<0GijP00<0IVIV0?ooo`3oool00P000000101OWZ00oaX00?lJ000000020?l_00<0
GijP00<000000?mA000000000`000000101OWZ000000000000000003003?o`0300000000HOl0067o
0080067o00D00000000Ho`006?l001So000000060040o`03000000006?l001So00<001So00<00000
001Qo`00HOl00P00HOl00`000000D@3o00000008000ao`0300000000HOl0067o00<0067o00L00000
000Ho`006?l001So00000000i?l0000000<00<oo100000001P1OWZ0000000000000000000?lP0000
00<0GijP00L0ocP000000000000000000?lO001OWZ0000000080oaX00P0000001@3oool0GijP05nN
X01OWZ00IVIV00<0oooo00<0GijP0?ooo`1VIVH0103oool305nNX0D0oooo00<0GijP0?ooo`3oool0
0`1OWZ020?ooo`0305nNX03oool0oooo00X0oooo00@0IVIV0?ooo`3oool00000403oool00240oooo
00<000000?ooo`1VIVH04P3oool206IVIP<0oooo00@0GijP0?ooo`3oool0IVIV0P3oool305nNX0D0
oooo00<0GijP0?ooo`3oool00`3oool305nNX0<0oooo00@0IVIV0?ooo`1OWZ00GijP0P3oool205nN
X080oooo00<0GijP0?ooo`1VIVH00P3oool00`000000oaX005nNX0020?lJ0080GijP0P3o;`000`1O
WZ000000000000050000000305nNX0000000000000<00<oo00<00000001Qo`00HOl00P00HOl00`00
000001So000Ho`02000Ho`03000000010?l00@3o00<00@3o00<00000000Ho`006?l00`006?l00`00
0000067o001Qo`02001Qo`040000001A0?l0D@3o000000H0037o0P000005001Qo`04000000006?l0
01So000Ho`8000001000col400000004003oh@1OWZ000000003o8080GijP0P3o@0000`1OWZ000000
000000040?lO000305nNX0000000000000<0GijP00<0IVIV0?ooo`1OWZ001@3oool00`1OWZ00oooo
06IVIP0305nNX080oooo00<0GijP0?ooo`3oool00`3oool305nNX0D0oooo00<0GijP0?ooo`3oool0
2P3oool0101VIVH0oooo0?ooo`00000@0?ooo`008@3oool00`000000oooo06IVIP0D0?ooo`0706IV
IP3oool0oooo0?ooo`1OWZ00oooo06IVIP0205nNX080oooo00<0GijP0?ooo`3oool0103oool00`1O
WZ00oooo0?ooo`0205nNX080oooo00D0GijP0?ooo`3oool0oooo06IVIP020?ooo`<0GijP1@3oool0
0`1OWZ00oooo06IVIP020?ooo`040000001OWZ00GijP05nNX0@0000000D0obD005nNX03o9@000000
0?m0000400000003003?o`0000000<oo00800<oo00<00000001Qo`00HOl00P00HOl00`00000001So
000Ho`02000Ho`03000000010?l00@3o00<00@3o00<00000000Ho`006?l00`006?l01@000000067o
001Qo`00HOl0000000<0D@3o00<00000000ao`00<Ol01000<Ol00`000000D@3o00000004001Qo`03
000000006?l001So008001So00<00000003?o`00col00P00col600000080GijP0P3o@00200000003
05nNX03o8`0000000080oal00P00000305nNX00306IVIP3oool0oooo0080oooo00<0GijP0?ooo`3o
ool00P3oool405nNX0D0oooo00<0GijP0?ooo`3oool00`1OWZ020?ooo`0305nNX03oool0oooo00@0
oooo00<0GijP0?ooo`3oool02@3oool01@1VIVH0oooo0?ooo`3oool0000000l0oooo000Q0?ooo`03
0000003oool0IVIV01D0oooo00@0IVIV0?ooo`3oool0oooo0P1OWZ050?ooo`80GijP0`3oool405nN
X0D0oooo0P1OWZ00103oool0IVIV05nNX01OWZ020?ooo`0305nNX03oool0oooo00@0oooo00<0GijP
0?ooo`1VIVH00P1OWZ020000000305nNX03o5000oa@0008000000P3o9@000`1OWZ0000000?m00002
05nNX080000000<00<oo0000000000000P00col00`000000067o001Qo`02001Qo`03000000006?l0
01So008001So00<000000040o`010?l00`010?l00`00000001So000Ho`03000Ho`0400000000HOl0
067o000000@0D@3o00<00000000ao`00<Ol00`00<Ol010000000D@3o0540o`000003001Qo`030000
00006?l001So00<001So0P000002003?o`0300000000i?l00000008000000`1OWZ000`3oA@000000
000000030?lS000305nNX0000000000000<0GijP00<0IVIV0?ooo`1OWZ001@3oool505nNX0<0oooo
00<0GijP0?ooo`3oool00`3oool305nNX0D0oooo00<0GijP0?ooo`3oool0103oool205nNX0X0oooo
00D0IVIV0?ooo`3oool0oooo0000000?0?ooo`00803oool010000000oooo0?ooo`1VIVHF0?ooo`05
06IVIP3oool0oooo0?ooo`1OWZ001P3oool405nNX0<0oooo00<0GijP0?ooo`3oool0103oool305nN
X0@0oooo00<0GijP0?ooo`3oool0103oool305nNX00706IVIP3oool000000000003o5000GijP0?lD
0003000000@0GijP10000002003?o`80000000<00<oo00000000HOl00`00HOl00`00000001So000H
o`02000Ho`03000000010?l00@3o00@00@3o00<00000000Ho`006?l00`006?l2000000D0D@3o00<0
0000000ao`00<Ol00`00<Ol010000000D@3o0540o`000003001Qo`03000000006?l001So008001So
00<000000040o`0000000P00col00`0000000>Co0000000300000004003o803o9P00GijP0?lV00@0
000000@0GijP0000001OWZ00IVIV103oool00`1OWZ00oooo0?ooo`0305nNX080oooo00<0GijP0?oo
o`3oool00`3oool00`1OWZ00oooo0?ooo`0305nNX080oooo00<0GijP0?ooo`3oool0103oool00`1O
WZ00oooo0?ooo`0305nNX080oooo00<0GijP0?ooo`3oool0203oool0101VIVH0oooo0?ooo`00000?
0?ooo`00803oool010000000oooo0?ooo`1VIVHG0?ooo`0506IVIP3oool0IVIV0?ooo`1OWZ000P3o
ool305nNX080oooo00<0GijP0?ooo`3oool00`3oool00`1OWZ00oooo0?ooo`0305nNX0030?ooo`1V
IVH0GijP00D0oooo00<0GijP0?ooo`3oool00`1OWZ020?ooo`0405nNX03oool0IVIV0?ooo`800000
1@1OWZ0010000000oa`00?lL001OWZ04000000800<oo00D00000000ao`0000000<oo00000004001Q
o`05000000006?l001So000Ho`0000001P010?l00`00000001So000Ho`03000Ho`8000001P1A0?l0
1@000000037o000ao`00<Ol0000000@0D@3o00@00000001Qo`00HOl0000010006?l00`0000000@3o
0040o`02000000800>Co100000020?lV000305nNX0000000oooo00<0GijP00<0IVIV0000001OWZ00
1@3oool305nNX0D0oooo00<0GijP0?ooo`3oool00`3oool305nNX0D0oooo00<0GijP0?ooo`3oool0
103oool305nNX0D0oooo00<0GijP0?ooo`3oool0203oool0101VIVH0oooo0?ooo`00000?0?ooo`00
803oool010000000oooo0?ooo`1VIVHH0?ooo`80IVIV0P3oool205nNX0D0oooo00<0GijP0?ooo`3o
ool00`3oool305nNX0@0oooo00<0IVIV05nNX03oool0103oool305nNX0H0oooo00<0GijP0?ooo`1V
IVH00P1OWZ000`000000o`l005nNX0030?l?00040000003o7000oa`005nNX0@0000000@00<oo0000
0000<Ol0037o0P000004001Qo`03000000006?l001So008001So00<000000040o`010?l00`010?l0
0`00000001So000Ho`03000Ho`030000001A0?l0D@3o00D0D@3o00@00000000ao`00<Ol000001@1A
0?l00`000000067o00000004000Ho`03000000010?l00@3o00800@3o00<00000003To`0000001P00
000305nNX00706IVIP3oool0oooo0?ooo`000000oooo05nNX0020?ooo`80GijP0P3oool00`1OWZ00
oooo0?ooo`040?ooo`0305nNX03oool0oooo0080GijP00<0IVIV0?ooo`1OWZ001P3oool00`1OWZ00
oooo0?ooo`0305nNX080oooo00<0GijP0?ooo`3oool00`3oool205nNX0T0oooo00@0IVIV0?ooo`3o
ool000003`3oool00200oooo00<000000?ooo`1VIVH06P3oool01@1VIVH0oooo0?ooo`3oool0GijP
00H0oooo00<0GijP0?ooo`3oool00P1OWZ020?ooo`0305nNX03oool0oooo0080oooo00<0IVIV0?oo
o`1OWZ000P3oool205nNX080oooo00<0GijP0?ooo`3oool0103oool305nNX0070?ooo`1VIVH00000
0000003o3`00GijP0?l?000400000080GijP0`0000000`00col00000000ao`02000ao`0300000000
HOl0067o0080067o00<00000000Ho`006?l00P006?l00`0000000@3o0040o`030040o`0300000000
6?l001So008001So0P0000070540o`0400000000<Ol0037o000000D0D@3o00<00000001Qo`000000
10006?l00`0000000@3o0040o`020040o`<0000000<0067o0000000000000`1OWZ000`1VIVH0oooo
05nNX0040?ooo`030000003oool0GijP0080GijP103oool00`1OWZ00oooo0?ooo`040?ooo`<0GijP
0P3oool0101VIVH0oooo0?ooo`1OWZ040?ooo`@0GijP1@3oool00`1OWZ00oooo0?ooo`0305nNX003
0?ooo`1OWZ00oooo00P0oooo00@0IVIV0?ooo`3oool000003`3oool00200oooo00<000000?ooo`1V
IVH06P3oool206IVIP<0oooo00<0GijP0?ooo`3oool00`3oool305nNX0D0oooo0P1OWZ020?ooo`03
06IVIP1OWZ00GijP0080GijP1@3oool205nNX080oooo0P1OWZ020?ooo`0405nNX01VIVH0IVIV0?oo
o`<0000000<0GijP0?l;003o2`000P1OWZ020?lD00@0000000@00<oo00000000<Ol0037o0`000002
001Qo`03000000006?l001So008001So00<000000040o`010?l00`010?l01`00000001So000Ho`00
6?l000000:P0o`0000001`1A0?l00`000000037o000000070540o`03000000006?l001So00<001So
00D000000040o`010?l00@3o00000002000Ho`0500000000HOl000000000001VIVH01@3oool0201O
WZ00oooo0?ooo`1OWZ00000005nNX03oool0GijP1P3oool00`1OWZ00oooo0?ooo`0305nNX080oooo
00@0GijP0?ooo`3oool0IVIV0P3oool505nNX0<0oooo00<0GijP0?ooo`3oool00`3oool305nNX0D0
oooo00<0GijP0?ooo`3oool01P3oool0101VIVH0oooo0?ooo`00000?0?ooo`00803oool200000003
06IVIP3oool0oooo01P0oooo00<0IVIV0?ooo`1VIVH00`3oool00`1OWZ00oooo0?ooo`0205nNX080
oooo00<0GijP0?ooo`3oool0103oool405nNX0<0oooo00<0GijP0?ooo`3oool0103oool305nNX0@0
oooo00<0GijP0?ooo`1VIVH00P3oool2000000<0GijP00@0o`/00000003o5000oa@0100000001@00
col00000000ao`00<Ol000000080D@3o00@00000001Qo`00HOl000000`006?l00`0000000@3o0040
o`040040o`03000000006?l0000000<0Z03o00<000000540o`1A0?l01@1A0?l2000000L0D@3o00<0
0000000Ho`006?l00P006?l00`0000000@3o0040o`020040o`04000000006?l00000001Qo`800000
00<0oooo05nNX03oool0103oool305nNX0030?ooo`000000oooo0080oooo00<0GijP0?ooo`3oool0
0`3oool305nNX0D0oooo00<0GijP0?ooo`3oool00`1OWZ000`3oool0GijP0?ooo`050?ooo`0305nN
X03oool0oooo00<0GijP00<0oooo05nNX03oool01@3oool00`1OWZ00oooo0?ooo`060?ooo`0406IV
IP3oool0oooo000000l0oooo000O0?ooo`040000003oool0oooo06IVIQX0oooo00@0IVIV0?ooo`3o
ool0IVIV0`3oool205nNX0D0oooo0P1OWZ020?ooo`80GijP0P3oool00`1OWZ00IVIV0?ooo`030?oo
o`80GijP0P3oool205nNX080oooo00<0GijP0?ooo`3oool00`3oool00`1OWZ00IVIV06IVIP0305nN
X0040000003o2`00GijP0?l;00T000000`00<Ol00`000000D@3o0540o`03000000@001So00<00000
0040o`010?l00`010?l2000000@0Z03o00<000000540o`1A0?l01@1A0?l00`000000D@3o0540o`05
0540o`80000010006?l01@0000000@3o0040o`010?l00000008001So00H00000001Qo`0000000000
0?ooo`1OWZ020?ooo`<0GijP0P3oool00`1OWZ00oooo000000030?ooo`0305nNX03oool0oooo00<0
GijP0P3oool00`1OWZ00oooo0?ooo`030?ooo`<0GijP00<0IVIV0?ooo`3oool00P3oool00`1OWZ00
oooo0?ooo`030?ooo`<0GijP1@3oool00`1OWZ00oooo0?ooo`030?ooo`80GijP1`3oool01@1VIVH0
oooo0?ooo`3oool0000000h0oooo000O0?ooo`040000003oool0oooo06IVIQX0oooo00D0IVIV0?oo
o`3oool0oooo06IVIP030?ooo`0305nNX03oool0oooo00@0oooo0`1OWZ040?ooo`0305nNX01VIVH0
oooo00@0oooo0`1OWZ050?ooo`0405nNX03oool0oooo0?ooo`@0GijP00<0IVIV0?ooo`3oool00`00
00000`1OWZ00o`L00?l7000205nNX0<0000000<0067o00000000<Ol00P00<Ol00`000000D@3o0540
o`020540o`<000000P006?l0100000000@3o0040o`010?l3000000D0Z03o00<000000540o`1A0?l0
101A0?l2000000L0D@3o00<000000:P0o`0000000`006?l0200000000@3o0040o`010?l00000000H
o`000000067o0`000000103oool0GijP05nNX01OWZ060?ooo`0405nNX0000000oooo0?ooo`@0GijP
1@3oool00`1OWZ00oooo0?ooo`0305nNX080oooo00<0GijP06IVIP3oool00`3oool00`1OWZ00oooo
0?ooo`0305nNX080oooo00<0GijP0?ooo`3oool00`3oool00`1OWZ00oooo0?ooo`0305nNX080oooo
00<0GijP0?ooo`3oool0103oool01@1VIVH0oooo0?ooo`3oool0000000h0oooo000O0?ooo`040000
003oool0oooo06IVIQX0oooo00<0IVIV0?ooo`3oool00P3oool206IVIP80oooo0P1OWZ020?ooo`80
GijP0P3oool00`1OWZ00oooo0?ooo`030?ooo`0305nNX03oool0oooo00<0GijP0P3oool00`1OWZ00
oooo0?ooo`030?ooo`@0GijP0P3oool0101VIVH0GijP0?ooo`1VIVH20?ooo`8000000`1OWZ020?l7
00H000000P00<Ol00`000000D@3o0540o`020540o`030000002X0?l0Z03o00H000000P370?l00`00
0000Z03o0:P0o`030:P0o`030000001A0?l0D@3o00@0D@3o00<000000>H0o`0000001@1A0?l01000
0000Z03o0:P0o`000002000Ho`05000000010?l00@3o0040o`0000000P006?l00`000000067o0000
000305nNX00306IVIP3oool0GijP00H0oooo00@0GijP0000001OWZ00GijP0`3oool00`1OWZ00oooo
0?ooo`030?ooo`<0GijP1@3oool00`1OWZ00IVIV0?ooo`030?ooo`<0GijP1@3oool00`1OWZ00oooo
0?ooo`020?ooo`@0GijP1@3oool00`1OWZ00oooo0?ooo`050?ooo`0406IVIP3oool0oooo000000h0
oooo000O0?ooo`030000003oool0IVIV01X0oooo00<0IVIV0?ooo`3oool01@3oool0101VIVH0oooo
0?ooo`3oool205nNX0@0oooo00<0GijP0?ooo`3oool00`3oool305nNX0H0oooo00<0GijP0?ooo`3o
ool00P1OWZ020?ooo`0405nNX03oool0oooo06IVIP80oooo0P1OWZ001`1VIVH0oooo05nNX01OWZ00
00000?l7001OWZ000P0000001P3o100000000?l800000000067o00000080037o00<000000540o`1A
0?l00P1A0?l00`000000Z03o0:P0o`020:P0o`03000000370?l0a`3o00<0a`3o00<000000:P0o`2X
0?l0102X0?l00`000000D@3o0540o`020540o`040000003V0?l0iP3o000000D0D@3o00L000000:P0
o`2X0?l0Z03o000000006?l0000000<00@3o00<00000000Ho`0000000P00HOl01@000000oooo0?oo
o`3oool0IVIV0080oooo00<0GijP0?ooo`3oool00`1OWZ000`3oool000000?ooo`050?ooo`0305nN
X03oool0oooo0080GijP0P3oool00`1OWZ00oooo0?ooo`040?ooo`0305nNX01VIVH0oooo0080GijP
0P3oool00`1OWZ00oooo0?ooo`030?ooo`D0GijP0`3oool00`1OWZ00oooo0?ooo`030?ooo`80GijP
1P3oool0101VIVH0oooo0?ooo`00000>0?ooo`007`3oool00`000000oooo06IVIP0J0?ooo`0306IV
IP3oool0oooo00H0oooo00D0IVIV0?ooo`3oool0oooo05nNX0050?ooo`0305nNX03oool0oooo0080
GijP00<0IVIV0?ooo`1OWZ001P3oool305nNX0@0oooo00@0GijP0?ooo`3oool0IVIV0`3oool305nN
X080oooo0`000000101OWZ00o`@00?l4003o100205nNX0<000000P00<Ol00`000000D@3o0540o`02
0540o`050000002X0?l0Z03o0:P0o`0000001P370?l00`000000Z03o0:P0o`030:P0o`050000001A
0?l0D@3o0540o`0000000`3V0?l00`000000D@3o0540o`020540o`030000002X0?l0Z03o0080Z03o
0P0000030040o`05000000006?l001So00000000HOl00P000000101OWZ00oooo0?ooo`1VIVH20?oo
o`<0GijP103oool00`000000GijP0?ooo`040?ooo`<0GijP1@3oool00`1OWZ00oooo0?ooo`020?oo
o`@0GijP1@3oool00`1OWZ00oooo0?ooo`0205nNX080oooo00<0GijP0?ooo`3oool0103oool00`1O
WZ00oooo0?ooo`0205nNX080oooo00<0GijP0?ooo`3oool00`3oool0101VIVH0oooo0?ooo`00000>
0?ooo`007`3oool00`000000oooo06IVIP0J0?ooo`0306IVIP3oool0oooo00L0oooo00D0IVIV0?oo
o`3oool0oooo05nNX0030?ooo`@0GijP0P3oool00`1VIVH0oooo0?ooo`0205nNX080oooo0P1OWZ02
0?ooo`0305nNX03oool0oooo00<0oooo00<0GijP0?ooo`1VIVH00`1OWZ020?ooo`0405nNX01VIVH0
oooo0?ooo`800000101OWZ0300000005001Qo`1A0?l00000000ao`000000101A0?l00`000000Z03o
0:P0o`020:P0o`03000000370?l0a`3o00<0a`3o00<000000:P0o`2X0?l00`2X0?l01@000000D@3o
0540o`1A0?l0000000<0iP3o00<000000540o`1A0?l00P1A0?l00`000000Z03o0:P0o`030:P0o`05
000000010?l00@3o0040o`0000000P006?l01@000000067o0000003oool0GijP0080oooo0`1OWZ02
0?ooo`0305nNX03oool0oooo0080oooo00@0000005nNX03oool0oooo0`1OWZ020?ooo`0305nNX03o
ool0oooo00<0oooo1@1OWZ020?ooo`0306IVIP1OWZ00oooo00@0oooo0`1OWZ040?ooo`0305nNX03o
ool0oooo00@0oooo0`1OWZ050?ooo`0305nNX03oool0oooo0080oooo00@0IVIV0?ooo`3oool00000
3P3oool001l0oooo00<000000?ooo`1VIVH06P3oool00`1VIVH0oooo0?ooo`080?ooo`0406IVIP3o
ool0oooo0?ooo`<0GijP0`3oool0101OWZ00oooo0?ooo`1VIVH30?ooo`<0GijP103oool00`1OWZ00
oooo0?ooo`030?ooo`<0GijP1P3oool00`1OWZ00IVIV0?ooo`0205nNX080000000@0GijP0?l2003o
0P00o`80100000000`00<Ol000000540o`030540o`030000002X0?l0Z03o0080Z03o00<000000<L0
o`370?l00`370?l00`000000Z03o0:P0o`030:P0o`040000001A0?l0D@3o000000D0iP3o00@00000
0540o`1A0?l000001P2X0?l0100000000@3o0040o`000002000Ho`0300000000HOl000000080oooo
0`1OWZ000`3oool0IVIV0?ooo`030?ooo`0505nNX03oool0oooo0?ooo`0000000`1OWZ050?ooo`03
05nNX03oool0oooo00<0GijP00<0oooo05nNX03oool0103oool0101VIVH0GijP0?ooo`3oool305nN
X080oooo00<0GijP0?ooo`3oool00`3oool00`1OWZ00oooo0?ooo`0305nNX080oooo00<0GijP0?oo
o`3oool00`3oool205nNX0<0oooo00@0IVIV0?ooo`3oool000003P3oool001h0oooo00@000000?oo
o`3oool0IVIV6P3oool00`1VIVH0oooo0?ooo`090?ooo`0506IVIP3oool0oooo0?ooo`1OWZ001@3o
ool205nNX080oooo0P1OWZ020?ooo`0305nNX03oool0oooo00<0oooo00<0GijP0?ooo`3oool00P1O
WZ020?ooo`0305nNX03oool0oooo00@0oooo0`1OWZ020?ooo`80000000<0GijP0?l2003o0P000P3o
0P02000000030540o`000000000000@0D@3o00<000000:P0o`2X0?l00P2X0?l00`000000a`3o0<L0
o`030<L0o`030000002X0?l0Z03o00@0Z03o0P0000060>H0o`040000001A0?l0D@3o000000D0Z03o
00D000000<L0o`0000000@3o00000002000Ho`0300000000HOl000000080GijP0P3oool00`1OWZ00
oooo06IVIP040?ooo`@0GijP00@0oooo0000003oool0GijP1@3oool305nNX0D0oooo00<0GijP0?oo
o`3oool00P3oool0101VIVH0GijP05nNX01OWZ050?ooo`0305nNX03oool0oooo0080oooo101OWZ05
0?ooo`0305nNX03oool0oooo00<0GijP00<0oooo05nNX03oool00P3oool01@1VIVH0oooo0?ooo`3o
ool0000000d0oooo000N0?ooo`80000000<0oooo06IVIP3oool06@3oool00`1VIVH0oooo0?ooo`0:
0?ooo`0506IVIP3oool0oooo0?ooo`1OWZ001@3oool305nNX0D0oooo00@0GijP0?ooo`3oool0oooo
101OWZ040?ooo`0306IVIP1OWZ00GijP0080oooo0P1OWZ020?ooo`0405nNX01VIVH0oooo0?ooo`80
000000D0GijP0?l200000000000005nNX002000000030540o`000000000000@0D@3o00D000000:P0
o`2X0?l0Z03o000000060<L0o`030000002X0?l0Z03o00<0Z03o0P0000060>H0o`030000001A0?l0
000000H0Z03o00@000000<L0o`00000000000P006?l30000000305nNX03oool0oooo00<0oooo00<0
GijP06IVIP3oool00`1OWZ000`3oool0GijP0?ooo`020?ooo`040000003oool0oooo05nNX080oooo
0P1OWZ020?ooo`0305nNX03oool0oooo00<0oooo00<0GijP0?ooo`3oool00`1OWZ020?ooo`0305nN
X03oool0oooo00<0oooo1@1OWZ030?ooo`0305nNX03oool0oooo00<0oooo0`1OWZ050?ooo`0405nN
X03oool0oooo06IVIP<0oooo00<000000?ooo`3oool02`3oool001h0oooo00<000000?ooo`1VIVH0
6`3oool00`1VIVH0oooo0?ooo`0;0?ooo`0506IVIP3oool0oooo0?ooo`1OWZ000P3oool205nNX003
06IVIP3oool0GijP00D0oooo101OWZ030?ooo`0305nNX03oool0oooo0080oooo00<0IVIV0?ooo`1O
WZ000P1OWZ050?ooo`0405nNX01VIVH0oooo0?ooo`D0GijP00<0o`400000000000000P1A0?l00`00
0000D@3o0540o`020540o`050000002X0?l0Z03o0:P0o`0000001P370?l00`000000Z03o0:P0o`03
0:P0o`030000003V0?l0iP3o00D0iP3o00<000000540o`0000001@2X0?l010000000a`3o0<L0o`37
0?l4000000030540o`000000GijP00D0oooo0`1OWZ050?ooo`0405nNX03oool0oooo00000080oooo
0`1OWZ050?ooo`0405nNX03oool0oooo0?ooo`@0GijP0P3oool0101VIVH0oooo0?ooo`1OWZ020?oo
o`<0GijP00<0oooo05nNX03oool01@3oool00`1OWZ00oooo0?ooo`0305nNX080oooo00<0GijP0?oo
o`3oool00`3oool0101OWZ00oooo0?ooo`1VIVH30?ooo`030000003oool0oooo00/0oooo000N0?oo
o`030000003oool0IVIV01/0oooo00<0IVIV0?ooo`3oool0303oool0101VIVH0oooo0?ooo`3oool2
05nNX080oooo00@0IVIV0?ooo`3oool0GijP0P3oool205nNX080oooo00<0GijP0?ooo`3oool00`3o
ool205nNX080oooo0P1OWZ020?ooo`0305nNX03oool0oooo00<0oooo101OWZ00103oool000000000
001OWZ030?l10080000000<0D@3o0000000000000`1A0?l00`000000Z03o0:P0o`020:P0o`030000
00370?l0a`3o00<0a`3o00<000000:P0o`2X0?l00P2X0?l2000000P0iP3o00<000000:P0o`2X0?l0
102X0?l01@000000a`3o0<L0o`370?l000000080Z03o0P0000020?ooo`0305nNX03oool0oooo0080
GijP00<0oooo06IVIP1OWZ001@3oool0101OWZ00oooo0?ooo`00000205nNX080oooo00<0GijP0?oo
o`3oool00`3oool405nNX0<0oooo00@0GijP0?ooo`3oool0IVIV0P3oool305nNX0D0oooo00<0GijP
0?ooo`3oool00`3oool305nNX0D0oooo00<0GijP0?ooo`3oool00P3oool305nNX080oooo00@0IVIV
0?ooo`3oool000003@3oool001h0oooo00<000000?ooo`1VIVH06P3oool00`1VIVH0oooo0?ooo`0>
0?ooo`0506IVIP3oool0oooo0?ooo`1OWZ000P3oool00`1VIVH0oooo0?ooo`0305nNX0D0oooo00<0
GijP0?ooo`3oool00P3oool405nNX00306IVIP3oool0oooo0080oooo00<0GijP0?ooo`3oool00P1O
WZ020?ooo`0705nNX01VIVH0oooo0?ooo`000000oooo05nNX00400000080D@3o0P0000020540o`03
0000002X0?l0Z03o0080Z03o00<000000<L0o`370?l00`370?l01@000000Z03o0:P0o`2X0?l00000
0080o`2f00<000000>H0o`3V0?l01@3V0?l00`000000Z03o0:P0o`030:P0o`05000000370?l0a`3o
0<L0o`0000000P2X0?l00`000000D@3o000000020?ooo`<0GijP0`3oool00`1VIVH0oooo05nNX003
0?ooo`@0GijP00<000000?ooo`3oool00P3oool00`1OWZ00oooo0?ooo`0305nNX080oooo00<0GijP
0?ooo`3oool00`3oool00`1OWZ00oooo06IVIP0205nNX080oooo00<0GijP0?ooo`3oool00`3oool0
0`1OWZ00oooo0?ooo`0305nNX080oooo00<0GijP0?ooo`3oool00`3oool505nNX0<0oooo00<0GijP
0?ooo`1VIVH00P3oool00`000000oooo0?ooo`0;0?ooo`007P3oool00`000000oooo06IVIP0J0?oo
o`0306IVIP3oool0oooo00l0oooo00L0IVIV0?ooo`3oool0oooo05nNX03oool0IVIV0080GijP0P3o
ool00`1OWZ00oooo0?ooo`030?ooo`D0GijP0`3oool00`1OWZ00IVIV0?ooo`030?ooo`<0GijP103o
ool00`1OWZ00oooo06IVIP020?ooo`030000001OWZ00GijP0080GijP0P0000000`1A0?l000000>H0
o`02000000030540o`000000Z03o0080Z03o00<000000<L0o`370?l010370?l00`000000Z03o0000
00030?l0]P030000003V0?l0iP3o00@0iP3o0P0000050:P0o`05000000370?l0a`3o0<L0o`000000
0P2X0?l2000000<0GijP0P3oool01P1OWZ00oooo0?ooo`3oool0IVIV0?ooo`@0GijP0`3oool00`1O
WZ0000000?ooo`030?ooo`<0GijP1@3oool00`1OWZ00oooo0?ooo`020?ooo`@0GijP1@3oool0101O
WZ00oooo0?ooo`3oool405nNX0D0oooo00<0GijP0?ooo`3oool00`1OWZ020?ooo`0305nNX03oool0
oooo00<0oooo00<0GijP0?ooo`1VIVH00P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool01000
0000oooo0?ooo`1VIVHJ0?ooo`0306IVIP3oool0oooo0100oooo0P1VIVH20?ooo`80GijP1@3oool0
0`1OWZ00oooo0?ooo`0205nNX080oooo00<0GijP0?ooo`3oool0103oool00`1OWZ00oooo0?ooo`02
05nNX080oooo00<0GijP0?ooo`3oool00`3oool00`1OWZ00oooo06IVIP0205nNX080000000H0GijP
0?l00000000000000540o`0000030>H0o`8000000`2X0?l00`000000a`3o0<L0o`040<L0o`800000
103o0;H00`000000iP3o0>H0o`040>H0o`030000003o0;H0000000<0Z03o00D000000<L0o`370?l0
a`3o000000020:P0o`80000000<0GijP0?ooo`3oool00`3oool00`1OWZ00oooo0?ooo`0305nNX080
oooo00<0GijP0?ooo`3oool00`3oool00`000000oooo0?ooo`0205nNX080oooo00<0GijP0?ooo`3o
ool00`3oool505nNX0<0oooo00<0GijP0?ooo`3oool00`3oool405nNX0<0oooo00<0GijP0?ooo`3o
ool00`3oool305nNX0D0oooo00<0GijP0?ooo`3oool00P3oool305nNX00406IVIP3oool0oooo0000
00d0oooo000M0?ooo`040000003oool0oooo06IVIQX0oooo00<0IVIV0?ooo`3oool04P3oool0101V
IVH0oooo0?ooo`1OWZ050?ooo`<0GijP1@3oool00`1OWZ00oooo0?ooo`030?ooo`<0GijP1@3oool0
101OWZ00oooo0?ooo`3oool405nNX00306IVIP3oool0IVIV008000000P1OWZ03000000@0iP3o0P00
00030:P0o`03000000370?l0a`3o0080a`3o0P0000060?l0]P030000003V0?l0iP3o0080iP3o00@0
00000?l0]P3o0;H000000`2X0?l01@000000a`3o0<L0o`370?l000000080Z03o0P0000000`1OWZ00
oooo0?ooo`030?ooo`<0GijP00<0oooo06IVIP3oool00P3oool00`1OWZ00oooo0?ooo`020?ooo`04
05nNX0000000GijP05nNX0D0oooo00<0GijP0?ooo`3oool00P1OWZ020?ooo`0305nNX03oool0oooo
00<0oooo00<0GijP0?ooo`3oool00`1OWZ020?ooo`0305nNX03oool0oooo00<0oooo00<0GijP0?oo
o`3oool00P1OWZ020?ooo`0305nNX03oool0oooo00<0oooo1@1OWZ030?ooo`0506IVIP3oool0oooo
06IVIP000000303oool001d0oooo00@000000?ooo`3oool0IVIV6P3oool00`1VIVH0oooo0?ooo`0C
0?ooo`0406IVIP3oool0IVIV05nNX080oooo0P1OWZ020?ooo`0305nNX03oool0oooo00@0oooo00<0
GijP0?ooo`3oool00P1OWZ000`1VIVH0oooo05nNX0050?ooo`@0GijP0`3oool01@1OWZ00oooo06IV
IP1VIVH000000080oooo00D0GijP000000000000D@3o000000030>H0o`070000003o0;H000000000
002X0?l000000<L0o`03000000030?l0T`000000o`2f00D0o`2f00<000000>H0o`3V0?l00P3V0?l0
1`000000o`2f0?l0]P3o0;H000000:P0o`0000000`370?l00`000000Z03o0:P0o`0200000080oooo
00<0GijP0?ooo`3oool00P1OWZ020?ooo`0305nNX03oool0IVIV00<0oooo0`1OWZ04000000030?oo
o`1OWZ00oooo00@0oooo0`1OWZ040?ooo`0305nNX03oool0oooo00<0oooo0`1OWZ050?ooo`0305nN
X03oool0oooo0080oooo101OWZ050?ooo`0305nNX03oool0oooo0080GijP1`3oool406IVIP030?oo
o`000000oooo00/0oooo000M0?ooo`030000003oool0IVIV01/0oooo00<0IVIV0?ooo`3oool0503o
ool206IVIP030?ooo`1OWZ00GijP00D0oooo0P1OWZ030?ooo`@0GijP0P3oool0101VIVH0oooo0?oo
o`1OWZ020?ooo`80GijP0P3oool00`1OWZ00oooo0?ooo`030?ooo`0305nNX03oool0IVIV00<0GijP
0P1VIVH3000000@0iP3o00<000000?l0]P3o0;H00`0000040?l0T`030000003o0;H0o`2f00D0o`2f
00@000000>H0o`3V0?l00000103o0;H00`000000Z03o000000030<L0o`030000002X0?l0Z03o0080
000000<0oooo05nNX01OWZ000P1OWZ050?ooo`0405nNX01VIVH0oooo05nNX0L0000000<0oooo0000
001OWZ000P3oool305nNX080oooo00<0GijP0?ooo`3oool00`3oool00`1OWZ00oooo0?ooo`0205nN
X0030?ooo`1VIVH0GijP00D0oooo1@1OWZ030?ooo`0305nNX03oool0oooo00<0oooo0`1OWZ060?oo
o`<0IVIV00<0oooo06IVIP3oool00P3oool00`000000oooo0?ooo`0:0?ooo`007@3oool200000003
06IVIP3oool0oooo01T0oooo00<0IVIV0?ooo`3oool05@3oool0101VIVH0oooo0?ooo`1OWZ060?oo
o`@0GijP0`3oool0101OWZ00oooo0?ooo`1VIVH20?ooo`<0GijP1@3oool0101OWZ00oooo0?ooo`3o
ool405nNX0050000001VIVH0oooo06IVIP3oool00`0000040>H0o`050000003o0;H0o`2f0?l0]P00
00001P3o09<00`000000o`2f0?l0]P040?l0]P040000003V0?l0iP3o000000D0o`2f00<000000<L0
o`370?l00P370?l010000000Z03o00000000000205nNX0<0oooo00<0GijP0?ooo`3oool00`3oool7
000000<0o`0000@000000?ooo`3oool000000P1OWZ050?ooo`0305nNX03oool0oooo0080oooo101O
WZ030?ooo`0306IVIP3oool0GijP0080oooo0P1OWZ020?ooo`0305nNX03oool0oooo00<0oooo00<0
GijP0?ooo`3oool00`1OWZ050?ooo`@0IVIV1@3oool0101VIVH0oooo0?ooo`00000<0?ooo`00503o
ool5000000@0oooo00<0000006IVIP1VIVH06`3oool00`1VIVH0oooo0?ooo`0E0?ooo`80IVIV0P3o
ool205nNX080oooo0P1OWZ020?ooo`0305nNX03oool0oooo00<0oooo00<0GijP0?ooo`1VIVH00P1O
WZ020?ooo`0305nNX03oool0oooo00<0oooo101OWZ030?ooo`0505nNX0000000oooo0?ooo`1VIVH0
0P3oool3000000<0iP3o00D000000?l0]P3o0;H0o`2f000000060?l0T`030000003o0;H0o`2f00@0
o`2f00<000000>H0o`0000001P3o0;H01@000000a`3o0<L0o`370?l000000080Z03o00<000000?oo
o`1OWZ001@3oool00`1OWZ00oooo0?ooo`05000000P0o`0000D0000005nNX0000000oooo05nNX005
0?ooo`D0GijP0`3oool01P1OWZ00oooo0?ooo`3oool0IVIV0?ooo`<0GijP103oool00`1OWZ00oooo
0?ooo`020?ooo`@0GijP1@3oool306IVIPT0oooo00@0IVIV0?ooo`3oool00000303oool001H0oooo
00<000000?ooo`3oool0103oool010000000oooo06IVIP1VIVHI0?ooo`0306IVIP3oool0oooo01D0
oooo00@0IVIV0?ooo`3oool0IVIV0`3oool205nNX0D0oooo00@0GijP0?ooo`3oool0oooo101OWZ05
0?ooo`0305nNX03oool0oooo0080GijP0P3oool00`1OWZ00oooo0?ooo`020?ooo`0406IVIP1OWZ00
oooo0?ooo`<0GijP00<0oooo0000000000000`3V0?l00`000000o`2f0?l0]P020?l0]P030000003o
09<0o`2C00<0o`2C00<000000?l0]P3o0;H01@3o0;H2000000D0o`2f00<000000?l0T`0000000P37
0?l01P000000Z03o000000000000oooo05nNX0@0oooo0P1OWZ04000000<0o`4000<000000?l0003o
00001@3o0002000000040?ooo`000000oooo05nNX080oooo0P1OWZ020?ooo`0305nNX03oool0oooo
00<0oooo00<0GijP0?ooo`3oool00`1OWZ020?ooo`0305nNX03oool0oooo0080oooo1@1OWZ060?oo
o`<0IVIV303oool0101VIVH0oooo0?ooo`00000<0?ooo`005P3oool00`000000oooo0?ooo`030?oo
o`060000003oool0oooo06IVIP3oool0IVIV603oool00`1VIVH0oooo0?ooo`0E0?ooo`0506IVIP3o
ool0oooo0?ooo`1VIVH00`3oool00`1OWZ00oooo0?ooo`030?ooo`@0GijP0P3oool00`1VIVH0GijP
0?ooo`040?ooo`<0GijP1@3oool0101OWZ00oooo0?ooo`3oool405nNX00406IVIP3oool0oooo0?oo
o`<000000`3V0?l01@000000o`2f0?l0]P3o0;H0000000D0o`2C00<000000?l0]P3o0;H01@3o0;H0
0`000000o`2f0?l0]P040?l0]P030000003o09<0o`2C0080000000<0Z03o0000000000000P3oool4
05nNX0@000001`3o0@000`000000o`000?l0000400000080o`4000<000000?ooo`0000000`1OWZ05
0?ooo`0405nNX03oool0oooo0?ooo`@0GijP00<0oooo06IVIP3oool00P3oool00`1OWZ00oooo0?oo
o`0205nNX0L0oooo101VIVH?0?ooo`0406IVIP3oool0oooo000000`0oooo000F0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool0IVIV0P3oool00`1VIVH0oooo0?ooo`0E0?ooo`0306IV
IP3oool0oooo01D0oooo00<0IVIV0?ooo`3oool00P3oool01@1VIVH0oooo0?ooo`3oool0GijP0080
oooo0P1OWZ020?ooo`0705nNX03oool0oooo0?ooo`1VIVH0oooo05nNX0020?ooo`80GijP0P3oool0
0`1OWZ00oooo0?ooo`030?ooo`@0GijP00D0IVIV0000003oool0GijP06IVIP040?ooo`<000000P3V
0?l01@000000o`2f0?l0]P3o0;H0000000H0o`2C00<000000?l0]P3o0;H00`3o0;H2000000D0o`2f
00<000000?l0T`3o09<00P3o09<3000000030?ooo`1OWZ00GijP00D0000000<0o`800000003o0@00
1`3o0@03000000H0o`4000H0000005nNX01OWZ0000000?ooo`1OWZ050?ooo`@0GijP0`3oool00`1O
WZ00oooo06IVIP030?ooo`<0GijP1P3oool306IVIQ<0oooo00D0IVIV0?ooo`3oool0oooo0000000;
0?ooo`005P3oool00`000000oooo0?ooo`030?ooo`030000003oool0IVIV00@0oooo00<0IVIV0?oo
o`3oool0503oool00`1VIVH0oooo0?ooo`0E0?ooo`0306IVIP3oool0oooo00<0oooo00@0IVIV0?oo
o`3oool0oooo0P1OWZ050?ooo`0405nNX03oool0oooo06IVIP@0GijP1@3oool00`1OWZ00oooo0?oo
o`0205nNX080oooo00@0GijP0?ooo`1VIVH000000P3oool00`1OWZ00oooo0?ooo`0205nNX0800000
00@0o`2f0000003V0?l000000`3o0;H00`000000o`2C0?l0T`040?l0T`030000003o0;H0o`2f0080
o`2f00@000000?l0B`3o04/00000103o0;H01@000000o`2C0?l0T`3o09<000000080o`2f1P000005
0?l200030000003o0@00o`4000<0o`400P0000020?l200030000003o0@00o`4000D0o`4000D00000
0?ooo`3oool0000005nNX0020?ooo`<0GijP0P3oool00`1OWZ00oooo0?ooo`020?ooo`0305nNX03o
ool0IVIV00<0GijP1@3oool406IVIQH0oooo00D0IVIV0?ooo`3oool0oooo0000000;0?ooo`005@3o
ool2000000D0oooo00<000000?ooo`1VIVH01@3oool00`1VIVH0oooo0?ooo`0C0?ooo`0306IVIP3o
ool0oooo01D0oooo00<0IVIV0?ooo`3oool0103oool01@1VIVH0oooo0?ooo`3oool0GijP00D0oooo
101OWZ030?ooo`0305nNX03oool0oooo00<0oooo0`1OWZ050?ooo`0405nNX01VIVH000000?ooo`@0
GijP0`3oool2000000030?l0]P000000000000@0o`2f00<000000?l0T`3o09<00`3o09<01@000000
o`2f0?l0]P3o0;H0000000<0o`1;00D000000?l0]P3o0;H0o`2f000000040?l0T`D0000000<0o`@0
0000003o0P001`3o0P000`000000o`400?l10002000000@0o`8000<000000?l1003o0@001@3o0@02
00000080oooo00<0000005nNX01OWZ001@3oool0101OWZ00oooo0?ooo`3oool405nNX0D0oooo0`1V
IVHJ0?ooo`0506IVIP3oool0oooo0?ooo`0000002`3oool001`0oooo00<000000?ooo`1VIVH01P3o
ool206IVIQ<0oooo00<0IVIV0?ooo`3oool05@3oool00`1VIVH0oooo0?ooo`050?ooo`80IVIV0P3o
ool00`1OWZ00oooo0?ooo`0205nNX080oooo00<0GijP06IVIP3oool00`3oool00`1OWZ00oooo0?oo
o`0205nNX080oooo00<0GijP0?ooo`3oool00`3oool405nNX0040?ooo`1VIVH0oooo05nNX0@0oooo
00<000000?l0]P3o0;H00P0000030?l0]P030000003o09<0o`2C00<0o`2C00@000000?l0]P3o0;H0
00001@3o04/01@000000o`2f0?l0]P000000o`2C00D00000103o10000`000000o`800?l200060?l2
00<000001`3o0P000`000000o`400?l1000400000080o`8000D0000005nNX0000000oooo05nNX005
0?ooo`@0GijP0`3oool00`1VIVH0oooo06IVIP0306IVIQd0oooo00D0IVIV0?ooo`3oool0oooo0000
000;0?ooo`00703oool00`000000oooo06IVIP080?ooo`0306IVIP3oool0oooo0100oooo00<0IVIV
0?ooo`3oool05@3oool00`1VIVH0oooo0?ooo`070?ooo`0306IVIP3oool0oooo0080GijP1@3oool0
101OWZ00oooo0?ooo`3oool405nNX0D0oooo00<0GijP0?ooo`3oool00P1OWZ000`1VIVH0oooo05nN
X0020?ooo`0406IVIP3oool0oooo05nNX080oooo00<0GijP0000000000000P3o0;H01@000000o`2f
0?l0]P3o0;H0000000H0o`2C0P0000060?l0B`P000001`3o100010000000o`800?l2003o0P040000
0080o`D000<000000?l2003o0P001@3o0P03000000L0o`8000D000000?ooo`000000oooo05nNX002
0?ooo`80GijP1P3oool306IVIR80oooo00@0IVIV0?ooo`3oool000002`3oool001/0oooo0P000000
0`3oool0IVIV0?ooo`080?ooo`0306IVIP3oool0oooo00l0oooo00<0IVIV0?ooo`3oool05@3oool0
0`1VIVH0oooo0?ooo`080?ooo`0406IVIP3oool0oooo05nNX0D0oooo101OWZ030?ooo`0305nNX03o
ool0oooo00<0oooo0`1OWZ020?ooo`0706IVIP3oool0000005nNX03oool0IVIV0?ooo`0405nNX080
oooo00<000000?l0]P3o0;H00`0000000`3o0;H000000?l0T`040?l0T`8000001@3o04/6000000<0
o`L000<000000?l4003o10001@3o1004000000H0o`D000<000000?l2003o0P000`3o0P0200000080
o`D000<000000?l2003o0P001P3o0P000`000000oooo0000000305nNX0@0oooo101VIVH20?ooo`03
06IVIP3oool0oooo0200oooo00@0IVIV0?ooo`3oool000002`3oool001/0oooo00@000000?ooo`3o
ool0IVIV2P3oool00`1VIVH0oooo0?ooo`0>0?ooo`0306IVIP3oool0oooo01D0oooo00<0IVIV0?oo
o`3oool02@3oool0101VIVH0oooo0?ooo`1OWZ020?ooo`80GijP00<0IVIV0?ooo`1OWZ001@3oool0
0`1OWZ00oooo0?ooo`0205nNX080oooo00H0GijP0?ooo`3oool0IVIV0?ooo`00000405nNX0<0oooo
00D0GijP0?ooo`3oool0oooo000000020?l0]P030000003o04/000000080000000L0o`2C00000000
000000000?l09P000000o`1;00L000001`3o1`000`000000o`@00?l4000400000080o`P000<00000
0?l5003o1@001P3o1@000`000000o`800?l20002000000D0o`D000<000000?l2003o0P001@3o0P02
0000000305nNX0000000oooo0080oooo0`1VIVH60?ooo`0306IVIP3oool0oooo0200oooo00@0IVIV
0?ooo`3oool000002`3oool001/0oooo00@000000?ooo`3oool0IVIV2`3oool00`1VIVH0oooo0?oo
o`0<0?ooo`0306IVIP3oool0oooo01H0oooo00<0IVIV0?ooo`3oool02P3oool00`1VIVH0oooo0?oo
o`0205nNX080oooo00@0IVIV0?ooo`3oool0GijP0`3oool405nNX0D0oooo00<0GijP0?ooo`1VIVH0
0P1OWZ020?ooo`0305nNX03oool0oooo00<0oooo00L0GijP0?ooo`3oool0GijP0000003o0;H00000
00<0o`1;0P0000030?l09PH000000`3o2`000`000000o`L00?l700050?l700<000001`3o20000`00
0000o`D00?l500050?l500<00000203o1@000`000000o`800?l2000400000080o`@000<000000?oo
o`0000000P1VIVH90?ooo`0306IVIP3oool0oooo0200oooo00D0IVIV0?ooo`3oool0oooo0000000:
0?ooo`006`3oool00`000000oooo06IVIP0=0?ooo`80IVIV303oool00`1VIVH0oooo0?ooo`0F0?oo
o`0306IVIP3oool0oooo00/0oooo00@0IVIV0?ooo`3oool0GijP0P3oool00`1VIVH0oooo0?ooo`04
05nNX0<0oooo00<0GijP0?ooo`3oool00`3oool305nNX0060?ooo`000000oooo06IVIP3oool0GijP
0`3oool405nNX080oooo0P0000030?l0B`P000001`3o2`000`000000o`L00?l7000400000080o`d0
00<000000?l8003o20001P3o20000`000000o`D00?l5000400000080o`T000<000000?l5003o1@00
1P3o1@03000000H0o`@000<0000006IVIP0000002`3oool00`1VIVH0oooo0?ooo`0P0?ooo`0506IV
IP3oool0oooo0?ooo`0000002P3oool001/0oooo00<000000?ooo`1VIVH03`3oool00`1VIVH0oooo
0?ooo`090?ooo`0306IVIP3oool0oooo01D0oooo00<0IVIV0?ooo`3oool03@3oool01P1VIVH0oooo
0?ooo`1OWZ00oooo06IVIP80GijP0P3oool00`1OWZ00oooo0?ooo`030?ooo`0305nNX03oool0oooo
0080GijP0P3oool01P1OWZ0000000?ooo`3oool0IVIV0?ooo`@0GijP0`3oool01@1OWZ00oooo0?oo
o`000000o`2f00P000000P3o3`000`000000o`/00?l;00050?l;00<000001`3o3@000`000000o`P0
0?l800050?l800<000001P3o2@000`000000o`D00?l500040?l5008000000P3o20000`000000o`@0
0?l400050?l400030000003oool0000000X0oooo00<0IVIV0?ooo`3oool0803oool01@1VIVH0oooo
0?ooo`3oool0000000X0oooo000K0?ooo`030000003oool0IVIV0100oooo00<0IVIV0?ooo`3oool0
203oool00`1VIVH0oooo0?ooo`0E0?ooo`0306IVIP3oool0oooo00h0oooo00<0IVIV0?ooo`3oool0
0P1OWZ050?ooo`0405nNX03oool0oooo0?ooo`@0GijP103oool0101VIVH0GijP0?ooo`3oool205nN
X080oooo00<0GijP0?ooo`3oool00`3oool00`1OWZ00oooo0?ooo`05000000L0o`l000<000000?l;
003o2`00100000020?lD00030000003o3@00o`d000H0o`d000<000000?l8003o2000100000020?l?
00030000003o2@00o`T000D0o`T000<000000?l5003o1@000`0000040?l800030000003o1000o`@0
00D0o`@00P0000000`3oool000000?ooo`080?ooo`0306IVIP3oool0oooo0200oooo00D0IVIV0?oo
o`3oool0oooo0000000:0?ooo`006`3oool00`000000oooo06IVIP0A0?ooo`0306IVIP3oool0oooo
00L0oooo00<0IVIV0?ooo`3oool05@3oool00`1VIVH0oooo0?ooo`0?0?ooo`0406IVIP3oool0oooo
05nNX0H0oooo0`1OWZ030?ooo`80GijP0`3oool405nNX00306IVIP3oool0oooo0080oooo00@0GijP
0?ooo`3oool0oooo0P1OWZ04000000<0oa@000<000000?l?003o3`00103o3`03000000L0oa@000<0
00000?l=003o3@001@3o3@03000000H0o`l000<000000?l9003o2@001@3o2@03000000P0o`P000<0
00000?l4003o1000100000020?l700030000003oool0000000P0oooo00<0IVIV0?ooo`3oool08@3o
ool0101VIVH0oooo0?ooo`00000:0?ooo`006P3oool010000000oooo0?ooo`1VIVHB0?ooo`80IVIV
1`3oool00`1VIVH0oooo0?ooo`0E0?ooo`0306IVIP3oool0oooo0100oooo00<0IVIV0?ooo`1VIVH0
0P1OWZ020?ooo`80GijP00<0oooo05nNX03oool0103oool405nNX00506IVIP000000oooo05nNX01V
IVH0103oool305nNX0@000001`3o50000`000000o`l00?l?000300000080oa`000<000000?lD003o
50001P3o50000`000000o`d00?l=000400000080oaL000<000000?l?003o3`001@3o3`000`000000
o`T00?l9000400000080o`l000<000000?l8003o20001P3o2003000000H0o`L000@000000?ooo`3o
ool000001`3oool00`1VIVH0oooo0?ooo`0Q0?ooo`0406IVIP3oool0oooo000000X0oooo000J0?oo
o`040000003oool0oooo06IVIQ@0oooo00<0IVIV0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`0E
0?ooo`0306IVIP3oool0oooo0140oooo0P1VIVH20?ooo`80GijP103oool00`1OWZ00oooo0?ooo`02
05nNX080oooo00@0GijP0?ooo`1VIVH000000P3oool0101OWZ00oooo0?ooo`1OWZ05000000030?lJ
00000000oa@000L0oa@00`0000060?lL00030000003o5000oa@000D0oa@00`0000060?lG00030000
003o3`00o`l000D0o`l00`0000070?l?008000000P3o200400000080o`d000<000000?l7003o1`00
1@3o1`0010000000oooo0?ooo`0000060?ooo`0306IVIP3oool0oooo0240oooo00@0IVIV0?ooo`3o
ool000002P3oool001X0oooo00<000000?ooo`1VIVH05P3oool00`1VIVH0oooo0?ooo`030?ooo`03
06IVIP3oool0oooo01D0oooo00<0IVIV0?ooo`3oool04@3oool306IVIP80oooo0P1OWZ030?ooo`<0
GijP1@3oool0101OWZ00IVIV0000003oool205nNX0D000001@3o6P0200000080oa@0100000020?lU
00030000003o7000oa`000D0oa`000<000000?lD003o5000100000020?lS00030000003o5`00oaL0
00D0oaL000<000000?l?003o3`00100000020?lI00030000003o3`00o`l000H0o`l00`0000060?l=
00030000003o1`00o`L000D0o`L00P0000000`3oool000000?ooo`050?ooo`0306IVIP3oool0oooo
0240oooo00D0IVIV0?ooo`3oool0oooo000000090?ooo`006P3oool20000000306IVIP3oool0oooo
01D0oooo00D0IVIV0?ooo`3oool0oooo06IVIP0H0?ooo`0306IVIP3oool0oooo0140oooo00@0IVIV
0?ooo`3oool0IVIV0`3oool305nNX080oooo00<0GijP0?ooo`3oool00`3oool305nNX0@0000000<0
oal00000003o6P001`3o6P03000000H0obD000<000000?lL003o70001@3o7003000000L0ob<000<0
00000?lG003o5`00103o5`03000000L0oaT00P0000020?l?00@000000P3o5`000`000000o`d00?l=
00050?l=00030000003o1`00o`L000@000000P3o2`000`000000oooo000000050?ooo`0306IVIP3o
ool0oooo0240oooo00D0IVIV0?ooo`3oool0oooo000000090?ooo`006P3oool00`000000oooo06IV
IP0H0?ooo`0406IVIP3oool0oooo06IVIQP0oooo00<0IVIV0?ooo`3oool04@3oool01@1VIVH0oooo
0?ooo`3oool0IVIV00<0oooo00<0GijP0?ooo`3oool00P3oool00`1OWZ00oooo0?ooo`0205nNX0@0
00001@3o7`0200000080oaX0100000020?l_00030000003o9@00obD000D0obD000<000000?lL003o
7000100000020?l`00030000003o8`00ob<000H0ob<000<000000?lG003o5`000`0000020?lV0003
0000003o6@00oaT000H0oaT00`0000060?lG00030000003o3@00o`d000D0o`d00`0000060?l;0004
0000003oool0oooo000000@0oooo00<0IVIV0?ooo`3oool08@3oool01@1VIVH0oooo0?ooo`3oool0
000000T0oooo000J0?ooo`030000003oool0IVIV01T0oooo0`1VIVHH0?ooo`0306IVIP3oool0oooo
0140oooo00<0IVIV0?ooo`3oool00P3oool01@1VIVH0oooo0?ooo`3oool0GijP00<0oooo00<0GijP
0000000000000`0000000`3o8`0000000?lO00060?lO00<000001`3o;`000`000000obD00?lU0004
0?lU00<000001`3o<0000`000000ob<00?lS00050?lS00<000001P3o9P0200000080oaT010000002
0?lV00030000003o5`00oaL000D0oaL000<000000?l=003o3@00100000020?lD00030000003o2`00
o`/000D0o`/000@000000?ooo`3oool00000103oool00`1VIVH0oooo0?ooo`0P0?ooo`0506IVIP3o
ool0oooo0?ooo`0000002@3oool001T0oooo00@000000?ooo`3oool0IVIV6`3oool00`1VIVH0oooo
0?ooo`0F0?ooo`0306IVIP3oool0oooo0140oooo00<0IVIV0?ooo`3oool00`3oool01@1VIVH0oooo
0?ooo`3oool0GijP00D000001@3o8`0200000080oal00`0000020?lh00030000003o;`00obl000H0
obl000<000000?lU003o9@000`0000020?m000030000003o<000oc0000H0oc0000<000000?lS003o
8`00100000020?li00030000003o9P00obH000D0obH00`0000060?lV00030000003o5`00oaL000D0
oaL00`0000060?lD00030000003o2`00o`/000D0o`/00P0000020?ooo`050000003oool0oooo0?oo
o`1VIVH08P3oool01@1VIVH0oooo0?ooo`3oool0000000T0oooo000I0?ooo`040000003oool0oooo
06IVIQ/0oooo0P1VIVHG0?ooo`0306IVIP3oool0oooo0140oooo00<0IVIV0?ooo`3oool0103oool0
0`1VIVH0000000000002000000030?lV00000000ob<000L0ob<00`0000060?lh00030000003o;`00
obl000D0obl00`0000060?m000030000003o<000oc0000D0oc000`0000060?li00030000003o9P00
obH000<0obH00P0000020?lk00030000003o9P00obH000D0obH000<000000?lG003o5`0010000002
0?lS00030000003o5000oa@000D0oa@000<000000?l;003o2`00100000020?l?00030000003oool0
000000<0oooo00<0IVIV0?ooo`3oool08@3oool0101VIVH0oooo0?ooo`0000090?ooo`006@3oool0
10000000oooo0?ooo`1VIVHK0?ooo`0306IVIP3oool0IVIV01H0oooo00<0IVIV0?ooo`3oool04@3o
ool00`1VIVH0oooo0?ooo`020?ooo`@000001@3o9P0200000080ob<0100000020?m000030000003o
>000ocP000D0ocP000<000000?l_003o;`00100000020?mA00030000003o@000od0000D0od0000<0
00000?l`003o<000100000020?m?00030000003o>@00ocT000D0ocT000<000000?lV003o9P000P00
00040?lk00030000003o9P00obH000D0obH00`0000060?lS00030000003o5000oa@000D0oa@00`00
00060?l?00040000003oool0oooo00000080oooo00<0IVIV0?ooo`3oool08@3oool0101VIVH0oooo
0?ooo`0000090?ooo`006@3oool00`000000oooo06IVIP0L0?ooo`0406IVIP3oool0oooo06IVIQ@0
oooo00<0IVIV0?ooo`3oool04P3oool00`1VIVH0000000000003000000030?lW00000000obH000H0
obH00`0000060?m000030000003o>000ocP000D0ocP00`0000060?mA00030000003o@000od0000D0
od000`0000070?m?00030000003o>@00ocT00080ocT01@0000070?lk00030000003o9P00obH000@0
00000P3o>@000`000000ob<00?lS00050?lS00030000003o5000oa@000@000000P3o70000`000000
o`l00?l?00050?l?00060000003oool0oooo0000003oool0IVIV8`3oool0101VIVH0oooo0?ooo`00
00090?ooo`006@3oool00`000000oooo06IVIP0L0?ooo`0406IVIP3oool0oooo0?ooo`80IVIV4P3o
ool00`1VIVH0oooo0?ooo`0@0?ooo`D000001@3o9`0200000080obH00`0000020?m500030000003o
@000od0000D0od0000<000000?lh003o>000100000020?mQ00030000003oD@00oe4000D0oe4000<0
00000?m0003o@000100000020?mX00030000003oC`00odl000D0odl01@0000040?mG00030000003o
>`00oc/000D0oc/00`0000060?li00030000003o8`00ob<000D0ob<00`0000060?lL00030000003o
3`00o`l000D0o`l00P0000020?ooo`030000001VIVH0oooo0280oooo00D0IVIV0?ooo`3oool0oooo
000000080?ooo`006@3oool00`000000oooo06IVIP0K0?ooo`0306IVIP3oool0oooo00@0oooo00<0
IVIV0?ooo`3oool03`3oool00`1VIVH0oooo0?ooo`0=0?ooo`H00000203o9`03000000H0odD000<0
00000?m0003o@000103o@003000000L0of4000<000000?mA003oD@00103oD@03000000L0ofP00P00
00020?m?00<000000P3oNP000`000000oeL00?mG00050?mG00030000003o>`00oc/000@000000P3o
E`000`000000ocT00?li00050?li00030000003o8`00ob<000@000000P3o<0000`000000oa`00?lL
00050?lL00030000003o3`00o`l000@000000P3o500010000000oooo0?ooo`00000S0?ooo`0506IV
IP3oool0oooo0?ooo`000000203oool001T0oooo00<000000?ooo`1VIVH06`3oool00`1VIVH0oooo
0?ooo`050?ooo`0306IVIP3oool0oooo00h0oooo00<0IVIV0?ooo`3oool02P3oool4000000D0obH0
0P0000020?lW00@000000P3oA`000`000000odD00?m500050?m500030000003o@000od0000<00000
0P3oKP000`000000of400?mQ00060?mQ00030000003oD@00oe4000<000000P3oP`000`000000ofP0
0?mX00060?mX00<000001P3oNP000`000000oeL00?mG00040?mG00<000001P3oE`000`000000ocT0
0?li00050?li00<000001P3o<0000`000000oa`00?lL00050?lL00<000001`3o500010000000oooo
06IVIP00000R0?ooo`0506IVIP3oool0oooo0?ooo`000000203oool001P0oooo0P0000000`3oool0
IVIV0?ooo`0J0?ooo`0306IVIP3oool0oooo00H0oooo00<0IVIV0?ooo`3oool03@3oool00`1VIVH0
oooo0?ooo`060?ooo`D0000000<0ob<00000003o9P001P3o9P03000000H0odL000<000000?m5003o
A@001@3oA@03000000H0ofh000<000000?mQ003oH@001@3oH@03000000H0oh<00P0000020?mX00@0
00000P3oX@000`000000ogX00?mj00050?mj00030000003oE`00oeL000<000000P3oP0000`000000
oeL00?mG00050?mG00030000003o>@00ocT000@000000P3oC`000`000000oc000?l`00050?l`0003
0000003o7000oa`000@000000P3o9@000`000000oa@00?lD00050?lD0080000000<0IVIV0000003o
ool08@3oool01@1VIVH0oooo0?ooo`3oool0000000P0oooo000H0?ooo`040000003oool0oooo06IV
IQ/0oooo00<0IVIV0?ooo`3oool01`3oool206IVIPd0oooo00<0IVIV0?ooo`3oool00`3oool50000
00D0ob<00P0000020?lV00<000000P3oA@000`000000odL00?m700050?m700030000003oA@00odD0
00@000000P3oM`000`000000ofh00?m^00050?m^00030000003oH@00of4000@000000P3oW@000`00
0000oh<00?n300050?n300<000001P3oX@000`000000ogX00?mj00050?mj00<000001P3oP0000`00
0000oeL00?mG00040?mG00<000001`3oC`000`000000oc000?l`00020?l`00D000001`3o9@000`00
0000oa@00?lD000400000080oaX000<000000?ooo`0000008@3oool01@1VIVH0oooo0?ooo`3oool0
000000P0oooo000H0?ooo`030000003oool0IVIV01`0oooo00<0IVIV0?ooo`3oool02@3oool00`1V
IVH0oooo0?ooo`0:0?ooo`0306IVIP3oool0oooo00H00000203o8`03000000H0odD000<000000?m7
003oA`00103oA`03000000L0ogL000<000000?m^003oKP00103oKP03000000L0oid000<000000?n3
003oP`00100000020?o;00030000003oX@00oj4000D0oj4000<000000?mj003oNP00100000020?nb
00030000003oP000oh0000D0oh0000<000000?mG003oE`000`0000020?mj00030000003oC`00odl0
00D0odl01@0000040?m000030000003o9@00obD000D0obD00`0000060?lJ00040000003oool0oooo
00000240oooo00@0IVIV0?ooo`3oool00000203oool001P0oooo00<000000?ooo`1VIVH0703oool0
0`1VIVH0oooo0?ooo`0:0?ooo`0306IVIP3oool0oooo00T0oooo100000050?lO008000000P3o8`04
00000080od0000<000000?m5003oA@001@3oA@000`000000odL00?m7000300000080ogX000<00000
0?mg003oM`001P3oM`000`000000ofh00?m^000300000080ok8000<000000?nM003oW@001@3oW@03
000000H0ol/000<000000?nQ003oX@001@3oX@03000000H0ok8000<000000?n0003oP0001@3oP003
000000H0ogX00P0000020?m?00<000000P3oJ0000`000000od000?m000050?m000030000003o9@00
obD000@000000P3o;`000`000000oaX00?lJ00050?lJ00040000003oool0oooo00000200oooo00@0
IVIV0?ooo`3oool00000203oool001P0oooo00<000000?ooo`1VIVH0703oool00`1VIVH0oooo0?oo
o`0;0?ooo`0306IVIP3oool0oooo00D0oooo100000000`3o6P0000000?lO00060?lO00<000001`3o
@0000`000000odD00?m500040?m500<000001P3oNP000`000000ogL00?mg00050?mg00<000001P3o
/P0200000080oid00`0000020?ob00030000003ob`00ol/000D0ol/000<000000?nQ003oX@001000
00020?o/00030000003o/P00ok8000D0ok8000<000000?n0003oP000100000020?nb00030000003o
NP00ogX000D0ogX00`0000060?mX00030000003o@000od0000@0od000`0000060?l_00030000003o
6P00oaX000D0oaX00P0000020?ooo`030000003oool0oooo01d0oooo00D0IVIV0?ooo`3oool0oooo
000000070?ooo`00603oool00`000000oooo06IVIP0L0?ooo`0306IVIP3oool0oooo00`0oooo00<0
IVIV0?ooo`3oool01@0000050?lJ008000000P3o7`0300000080ocP000<000000?m0003o@0001P3o
@0000`000000odD00?m5000300000080ogL000<000000?mj003oNP001@3oNP000`000000ogL00?mg
000400000080ol0000<000000?nb003o/P001@3o/P03000000H0oo8000<000000?o;003ob`00103o
b`03000000H0on`000<000000?nb003o/P001@3o/P03000000L0ok8000<000000?mj003oNP001000
00020?nQ00030000003oJ000ofP000D0ofP000<000000?m0003o@0000`0000020?mA00030000003o
;`00obl000D0obl000<000000?lJ003o6P00100000020?lO00030000003oool0000001l0oooo00D0
IVIV0?ooo`3oool0oooo000000070?ooo`005`3oool010000000oooo0?ooo`1VIVHK0?ooo`0306IV
IP3oool0oooo00/0oooo1`0000000`3o500000000?lJ00060?lJ00<000001P3o>002000000H0od00
0`0000060?mg00800000103oNP04000000L0ol0000<000000?nb003o/P00100000020>go00030000
003olP00oo8000D0oo8000<000000?o;003ob`000`0000020=Oo00030000003ok000on`000D0on`0
00<000000?nb003o/P00100000020?oh00030000003o/P00ok8000D0ok800`0000060?nQ00030000
003oJ000ofP000D0ofP00`0000050?mA00030000003o;`00obl000D0obl00`0000070?lO00030000
003oool0000001h0oooo00D0IVIV0?ooo`3oool0oooo000000070?ooo`005`3oool010000000oooo
0?ooo`1VIVHK0?ooo`0306IVIP3oool0oooo00P0oooo1`0000050?lD008000000P3o6P0300000080
obl000<000000?lh003o>0001P3o>0000`000000od000?m0000300000080ofh000<000000?mg003o
M`001@3oM`05000000<0olD000<000000?o0003o`0001@3o`003000000L0kOl000<000000?ob003o
lP00103olP03000000H0eol00P0000040?o/00@000001`3on0000`000000ok800?nb000400000080
on`000<000000?nQ003oX@001@3oX@000`000000ofP00?mX000400000080oh<000<000000?mA003o
D@00103oD@000`000000obl00?l_000400000080ocP000<000000?lO003o7`001@3o7`0200000003
0?ooo`000000oooo01`0oooo00D0IVIV0?ooo`3oool0oooo000000070?ooo`005`3oool00`000000
oooo06IVIP0L0?ooo`0306IVIP3oool0oooo00D0oooo1P0000030?l?00030000003o5000oa@000@0
oa@00`0000060?l_00030000003o>000ocP000D0ocP00`0000060?m^008000000P3oM`0300000080
ol0000<000000?o5003oa@00103oa@0200000080ol000`0000020=Oo00030000003]o`00kOl000H0
kOl000<000000?ob003olP000`00000209go00030000003Go`00eol000D0eol01@0000030;Oo0003
0000003on000ooP000D0ooP00`0000060?o/00030000003oX@00oj4000D0oj400`0000070?n30003
0000003oD@00oe400080oe40100000070?lh00030000003o7`00oal000@000000P3o8`000`000000
oooo0000000L0?ooo`0506IVIP3oool0oooo0?ooo`0000001`3oool001L0oooo00<000000?ooo`1V
IVH0703oool00`1VIVH0oooo0?ooo`020?ooo`H000001`3o3`000`000000oa@00?lD000300000080
obD000<000000?l_003o;`001@3o;`000`000000ocP00?lh000400000080of4000<000000?m^003o
KP001@3oKP03000000H0ol0000<000000?o5003oa@00103oa@03000000H0eol000<000000>go003]
o`001@3]o`03000000H0WOl000<000000=Oo003Go`001000000206?o00030000002go`00]ol000@0
]ol00P0000020?oh00<000000P2go`000`000000on`00?o/00050?o/00030000003oX@00oj4000@0
00000P3ob`000`000000oh<00?n300050?n300D000000`3oH@000`000000ocP00?lh00050?lh00<0
00001P3o8`0010000000oooo0?ooo`00000L0?ooo`0406IVIP3oool0IVIV000000L0oooo000G0?oo
o`80000000<0IVIV0?ooo`3oool06P3oool00`1VIVH0oooo00000005000000<0o`/000<000000?l?
003o3`00103o3`03000000H0obD00P0000040?l_00@000001`3oH@0200000080ofh00`0000020?nb
00030000003o`000ol0000D0ol0000<000000?o5003oa@000`0000020<oo00030000003Go`00eol0
00D0eol000<000000>go003]o`001000000206ko00030000002Mo`00WOl000@0WOl00`00000606?o
00030000002go`00]ol000D0]ol00`0000060;Oo00030000003ok000on`000@0on`00`0000070?o;
00030000003oP`00oh<000@000000P3oW@000`000000of400?mQ00040?mQ00030000003o>000ocP0
00@000000P3o@0000`000000ob<00?lS00050?lS00040000003oool0oooo000001T0oooo101VIVH0
0`3oool000000?ooo`060?ooo`005`3oool00`000000oooo06IVIP0K0?ooo`H000001`3o2`000`00
0000o`l00?l?000300000080oa`000<000000?lU003o9@001@3o9@05000000<0oe4000<000000?mQ
003oH@001P3oH@03000000H0ok8000<000000?o0003o`000103o`003000000H0col00P0000040=Oo
00@000001`1^o`000`000000WOl009go0003000000804ol000<0000006?o001So`001@1So`000`00
0000]ol00;Oo000400000080C_l000<000000;Oo002go`001@2go`000`000000on`00?o/00030000
0080eol000<000000?o;003ob`001@3ob`03000000H0oid000<000000?mQ003oH@00103oH@030000
00H0od0000<000000?lS003o8`001@3o8`02000000030?ooo`000000oooo01@0oooo101VIVH20?oo
o`0506IVIP3oool0oooo0?ooo`0000001P3oool001L0oooo00<000000?ooo`1VIVH0603oool50000
00@0o`L000<000000?l;003o2`00103o2`03000000H0oa`00P0000020?lU00<000000P3o@0000`00
0000oe400?mA00040?mA008000000P3oH@0400000080oid000<000000?nb003o/P001@3o/P000`00
0000ol000?o0000300000080eol000<000000<oo003?o`001@3?o`05000000<0C_l000<0000006ko
001^o`001@1^o`03000000H04ol000<0000006?o001So`00101So`03000000L0C_l000<000000;Oo
002go`000P2go`05000000H0eol000<000000?o;003ob`00100000020?ob00030000003oW@00oid0
00D0oid000<000000?mQ003oH@000`0000020?m^00030000003o@000od0000D0od0000<000000?lS
003o8`00100000020?lV00030000003oool000000140oooo0`1VIVH60?ooo`0506IVIP3oool0oooo
0?ooo`0000001P3oool001H0oooo00@000000?ooo`3oool0IVIV5@3oool6000000L0o`L000<00000
0?l;003o2`000`0000020?lD00030000003o7000oa`000D0oa`00`0000060?m000030000003oD@00
oe4000@0oe400`0000060?nM00030000003o/P00ok8000D0ok800`0000060=Oo008000000P3?o`03
00000080@ol000<0000004ko001>o`00101>o`0200000080K_l00`000002003o;P030000000Co`00
4ol000D04ol000<0000006?o001So`000`000002003o80030000001>o`00C_l000D0C_l01@000004
06?o00030000003Go`00eol000@0eol00`0000060?ob00030000003oW@00oid000D0oid00`000006
0?m^00030000003o@000od000080od001@0000060?lV00040000003oool0oooo000000`0oooo101V
IVH90?ooo`0506IVIP3oool0oooo0?ooo`0000001P3oool001H0oooo00@000000?ooo`3oool0IVIV
4P3oool5000000@0o`@00P0000040?l700@000001P3o500200000080oa`00`0000020?l`00030000
003o@000od0000D0od0000<000000?mA003oD@000`0000020?n300030000003oW@00oid000D0oid0
00<000000?nb003o/P00100000020>go00030000003Go`00eol000D0eol00`00000504?o00030000
001>o`00C_l000D0C_l00`000006003o;P800000100Co`04000000H00?lP0P00000204ko00<00000
0P00ob000`000000Hol006?o000506?o00030000003Go`00eol000<000000P2Mo`000`000000oo80
0?ob00050?ob00030000003oW@00oid000@000000P3o/P000`000000ofh00?m^00040?m^00D00000
103oA@000`000000obH00?lV00040?lV008000000P3oool00`000000oooo0?ooo`050?ooo`@0IVIV
3@3oool01@1VIVH0oooo0?ooo`3oool0000000H0oooo000F0?ooo`030000003oool0IVIV0100oooo
1P0000070?l400D000000`3o3@000`000000oa@00?lD00050?lD00<000001P3o<0000`000000od00
0?m000040?m000<000001P3oP`02000000@0oid0100000070>go00030000003Go`00eol000@00000
0P1>o`000`000000@ol004?o000404?o00030000001>o`00C_l000@000000P00oeX00`0000000?l^
003o;P05003o;PD000000`00ohX00`0000000?lP003o8005003o80<000001@00ob000`000000Hol0
06?o000506?o00<000001P2Mo`000`000000oo800?ob00020?ob00D000001`3o/P000`000000ofh0
0?m^000300000080ogL000<000000?m5003oA@001@3oA@000`000000obH00?lV000300000080obL0
00@000000?ooo`3oool000000P3oool406IVIQ40oooo00D0IVIV0?ooo`3oool0oooo000000060?oo
o`005P3oool00`000000oooo06IVIP0<0?ooo`D000001@3o0P0200000080o`@00`0000020?l80003
0000003o3@00o`d000@0o`d00P0000020?lD00<000000P3o8`000`000000oc000?l`00050?l`0003
0000003o@000od0000<000000P3oJ0000`000000oh<00?n300050?n300D000000`3olP000`000000
kOl00>go00050>go00<000001P1>o`000`000000@ol004?o000404?o00<000001`00oeX00`000000
0?l^003o;P04000000800?oQ00<00000003oRP00ohX01000ohX00`0000000?lP003o800400000080
0?n[00<00000003o8000ob001000ob000`000000Hol006?o0004000000804ol000<0000009go002M
o`00102Mo`05000000@0kOl000<000000?nb003o/P001@3o/P03000000D0ogL000<000000?m5003o
A@001@3oA@03000000H0obL000<000000?ooo`0000000P1VIVHE0?ooo`0506IVIP3oool0oooo0?oo
o`0000001P3oool001H0oooo00<000000?ooo`1VIVH01`3oool7000000030?l100000000o`8000H0
o`800`0000060?l800030000003o3@00o`d000@0o`d00`0000060?lS00800000103o<004000000H0
ofP00P0000020?n300<000000P3ob`000`000000oo800?ob00040?ob008000000P3]o`0300000080
K_l000<0000004ko001>o`001@1>o`000`000000@ol004?o0003000000800?mY00<00000003oFP00
oeX01@00oeX3000000H00?oQ00<00000003oRP00ohX01000ohX3000000L00?n[00<00000003o8000
ob000P00ob04000000L04ol000<0000009go002Mo`000`00000206ko00030000003]o`00kOl000D0
kOl000<000000?nb003o/P00100000020?o000030000003oM`00ogL000@0ogL000<000000?m5003o
A@00100000020?m700030000003o9`00obL000@0obL00P0000000`3oool000000?ooo`0F0?ooo`04
06IVIP3oool0oooo000000H0oooo000F0?ooo`030000003oool0IVIV00D0oooo0P000000103o0000
00000000000000050?l1008000000P3o0P0300000080o`D00P0000060?l800030000003o3@00o`d0
00<000000P3o5`000`000000ob<00?lS00050?lS00D000000`3oC`000`000000ofP00?mX00050?mX
00<000001P3ob`000`000000oo800?ob00040?ob00<000001P1^o`02000000@0C_l010000006003o
J@8000000P00oeX3000000800>Co00<00000003oh@00on401@00on400`0000000?n:003oRP030000
00800<oo00<00000003oZ`00oj/01@00oj/5000000<00?n:00<0000001?o000Co`001@0Co`030000
00H0K_l000<000000>go003]o`00103]o`03000000L0ol0000<000000?mg003oM`000P3oM`040000
00L0odL000<000000?lW003o9`000`0000020?lV00030000003oool0000001H0oooo00D0IVIV0?oo
o`3oool0oooo000000050?ooo`005@3oool010000000oooo0?ooo`1VIVH30?ooo`D000000P3o0002
000000D0o`400`0000070?l5008000000`3o2004000000H0oaL00P0000020?lS00<000000P3o>@00
0`000000odl00?m?00040?m?008000000P3oJ00300000080oj4000<000000?o;003ob`001@3ob`00
0`000000oo800?ob000300000080WOl000<0000006ko001^o`001@1^o`05000000<00?mJ00<00000
003oJ@00ofT01@00ofT3000000H00>Co00<00000003oh@00on401000on43000000H00<oo0P000002
003oZ`<000000P00col00`0000000?n:003oRP04003oRP8000000P0Co`03000000800?l^00<00000
06ko001^o`001@1^o`000`000000kOl00>go000300000080eol000<000000?o0003o`0001@3o`005
000000<0ogX000<000000?m7003oA`001@3oA`03000000D0obH000@000000?ooo`3oool000005@3o
ool01@1VIVH0oooo0?ooo`3oool0000000D0oooo000E0?ooo`<0000000<0IVIV0?ooo`0000000`00
00070?l000030000003o0@00o`40008000000P3o0P02000000L0o`D0100000030?l?008000001P3o
5`03000000H0ocT000<000000?m?003oC`00103oC`03000000H0oj400P0000040?o;00@000001P2M
o`0200000080K_l00`000002003o;P0300000000oeX00?mJ00@00?mJ0P000002003oJ@<000000P00
col00`0000000>Co003To`05003To`0300000000on400?oQ00<000000P00HOl00`0000000<oo003?
o`05003?o`<000001@00col00`0000000?n:003oRP05003oRP<000001P00obh00`000000K_l006ko
000206ko00D000001P3Go`000`000000ol000?o00004000000030?o500000000ogX000H0ogX000<0
00000?m7003oA`00100000020?m500030000003o9P00obH000@0obH000@000000?ooo`3oool00000
503oool01@1VIVH0oooo0?ooo`3oool0000000D0oooo00000`3oool000000000000300000080oooo
0P0000040?ooo`8000001@3oool00`000000IVIV00000002000000@0oooo0P0000040?l000@00000
1P3o0P0200000080o`D00`0000020?l900030000003o3`00o`l000@0o`l00P0000020?lG00800000
0P3o9P000`000000ocT00?li00050?li00030000003oC`00odl000<000000P3oNP000`000000oj40
0?nQ00050?nQ00D000000`3Go`000`000000WOl009go000509go00<000001P00obh00`0000000?mJ
003oFP04003oFP<000001P00col2000000@00>Co10000006001Qo`0300000000col00<oo00@00000
0P00<Ol00`0000000<oo003?o`04003?o`0300000000ohX00?n:00@000000P00on400`0000000?l^
003o;P04003o;PD00000101>o`000`000000eol00=Oo00040=Oo00<000001P3oa@000`000000ogX0
0?mj00040?mj00<000001P3oA@000`000000obH00?lV00020?lV00@000000P3oool00`000000oooo
0?ooo`0A0?ooo`0506IVIP3oool0oooo0?ooo`0000001@3oool000<0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000040?ooo`80000000<0IVIV0000003oool01P3oool4000000<0
o`4000<000000?l2003o0P001@3o0P03000000H0o`T000<000000?l?003o3`00103o3`03000000D0
obH00P0000040?li00@000001P3oNP0200000080oj400`0000020?o/00030000003Go`00eol000@0
eol00P00000209go00<000000P0Co`000`0000000?l^003o;P05003o;P0300000000oeX00?mJ00<0
00000P00i?l00`0000000<oo003?o`05003?o`D000000`006?l00`000000067o001Qo`04001Qo`<0
00001`00<Ol00`0000000<oo003?o`02003?o`@000001`00on400`0000000?l^003o;P0300000080
0?mJ00<0000004ko001>o`001@1>o`000`000000eol00=Oo000300000080col000<000000?o5003o
a@00103oa@000`000000ogX00?mj000400000080ogL000<000000?m5003oA@00103oA@05000000@0
ob<000<000000?ooo`0000004`3oool01@1VIVH0oooo0?ooo`3oool0000000D0oooo00030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool2000000030?ooo`1VIVH0oooo00H0
oooo00<000000?l1003o0@00103o0@0200000080o`800`0000020?l500030000003o2@00o`T000D0
o`T000<000000?l?003o3`000`0000020?lI00030000003o9P00obH000@0obH01@0000030?mG0003
0000003oNP00ogX000D0ogX00`0000060?o/00800000103Go`04000000H04ol00P000004003o;P@0
00001P00i?l00`0000000<oo003?o`04000000800@3o00<00000000Ho`006?l010006?l00`000000
067o001Qo`0300000080D@3o00<00000000ao`00<Ol01@00<Ol5000000<0067o00<00000003oh@00
on401@00on43000000D00?mJ00<0000004ko001>o`001@1>o`03000000H0col000<000000?o5003o
a@000P3oa@04000000L0ogL000<000000?m5003oA@000`0000020?m000030000003o8`00ob<000@0
ob<000@000000?ooo`3oool000004P3oool01@1VIVH0oooo0?ooo`3oool0000000D0oooo00030?oo
o`030000003oool0oooo00P0oooo0P0000070?ooo`80000000<0oooo06IVIP1VIVH01P3oool00`00
0000o`400?l100040?l100<000001P3o1@02000000@0o`T0100000060?lI008000000P3o9P020000
0080oc/000<000000?mG003oE`00103oE`0200000080ogX00`0000020?nb00030000003ok000on`0
00D0on`01@00000306?o00030000000Co`004ol000D04ol01@000003003oh@0300000000i?l00>Co
00@00>Co0`0000070040o`03000000006?l001So008001So100000060540o`8000000P00<Ol30000
0080D@3o00<00000001Qo`00HOl01000HOl00`0000000?oQ003oh@04000000800>Co00<00000003o
FP00oeX01000oeX00`000000C_l004ko000400000080@ol000<000000<oo003?o`00103?o`050000
00<0ol0000<000000?mg003oM`001@3oM`03000000D0od0000<000000?lS003o8`00103o8`020000
0080oooo00<000000?ooo`3oool0403oool0101VIVH0oooo0?ooo`0000050?ooo`000`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0IVIV1P3oool0
0`000000o`400?l1000300000080o`8000<000000?l5003o1@001@3o1@05000000<0o`l000<00000
0?lI003o6@001@3o6@03000000D0oc/00P0000040?mG00@000001P3o/P0200000080on`00`000002
0;Oo00030000001So`00Hol000@0Hol00P00000201?o00<000000P00ohX00`0000000?oQ003oh@04
003oh@0300000000i?l00>Co00<000000P006?l00`0000000@3o0040o`050040o`D000000`2X0?l0
0`000000D@3o0540o`050540o`<000001@1A0?l00`000000067o001Qo`04001Qo`<000001`00i?l0
0`0000000?mJ003oFP02003oFP@000001P13o`000`000000col00<oo000400000080eol000<00000
0?o0003o`000103o`0000`000000ogL00?mg000400000080ofh000<000000?m0003o@000103o@000
0`000000ob<00?lS000300000080oal000@000000?ooo`3oool000004@3oool01@1VIVH0oooo0?oo
o`3oool0000000@0oooo00020?ooo`8000002P3oool3000000T0oooo0P0000000`3oool0IVIV06IV
IP050?ooo`8000001P3o0P0200000080o`D00`0000020?l800030000003o3`00o`l000@0o`l00P00
00020?lI00<000000P3o9P000`000000oc/00?lk00040?lk00D000000`3oP0000`000000ok800?nb
00050?nb00<000001P2go`000`000000Hol006?o000406?o00<000001P00ohX00`0000000?oQ003o
h@02003oh@@000001P006?l2000000800@3o0`0000020<L0o`030000002X0?l0Z03o00@0Z03o0P00
00020540o`<000000P3V0?l00`000000D@3o0540o`040540o`0300000000HOl0067o00<000000P00
6?l00`0000000>Co003To`05003To`D000000`00ofT00`000000@ol004?o000404?o00<000001`3G
o`000`000000ol000?o000020?o000@000001P3oKP000`000000od000?m000020?m000D000001P3o
7`0010000000oooo0?ooo`00000@0?ooo`0506IVIP3oool0oooo0?ooo`000000103oool001`0oooo
0P0000000`3oool0IVIV0?ooo`040?ooo`8000001P3o0P03000000H0o`P00P0000040?l?00@00000
1P3o9P0200000080oc/00P0000020?mG00030000003oP000oh0000@0oh000P0000020?nb00<00000
0P3on0000`000000]ol00;Oo00050;Oo00030000001So`00Hol000<000000P00ob000`0000000?n:
003oRP04003oRPD000000`00HOl00`00000001So000Ho`05000Ho`<000001@370?l00`000000Z03o
0:P0o`050:P0o`<000001P3V0?l00`000000D@3o0540o`020540o`@000001P006?l00`0000000>Co
003To`04000000800<oo00<00000003oJ@00ofT01000ofT00`000000@ol004?o000300000080C_l0
00<000000=Oo003Go`001@3Go`05000000<0ok8000<000000?m^003oKP00103oKP05000000@0ocP0
00<000000?lO003o7`00103o7`02000000030?ooo`000000oooo00l0oooo00D0IVIV0?ooo`3oool0
oooo000000040?ooo`007@3oool2000000030?ooo`1VIVH0oooo00D0oooo0P0000020?l200800000
0P3o1002000000H0o`P01@0000030?lG00030000003o9P00obH000D0obH00`0000050?mG00030000
003oP000oh0000@0oh000`0000060?oh00800000102go`04000000H00?lP00<00000003oRP00ohX0
0`000002003?o`0300000000HOl0067o00@0067o0P000002000Ho`<000000P2X0?l00`000000a`3o
0<L0o`040<L0o`030000002X0?l0Z03o00@000000P3o0;H00`000000iP3o0>H0o`040>H0o`D00000
0`2X0?l00`00000001So000Ho`04000Ho`<000001`00col00`0000000?mY003oJ@02003oJ@@00000
1P1>o`000`000000eol00=Oo0004000000030>go00000000ok8000H0ok8000<000000?m^003oKP00
0`0000020?mQ00030000003o>000ocP000@0ocP000<000000?lO003o7`00100000020?lJ00030000
003oool0000000l0oooo00D0IVIV0?ooo`3oool0oooo000000040?ooo`007`3oool010000000oooo
06IVIP1VIVH60?ooo`8000001P3o100200000080o`P00P0000020?l=00030000003o5`00oaL000@0
oaL00P0000020?lV00<000000P3o>@000`000000oeL00?mG00040?mG00030000003oP000oh0000<0
00000P3o/P000`000000ooP00?oh00050?oh00D000000`1>o`000`0000000?lP003o8004003o80<0
00001P00col2000000@0067o100000060:P0o`03000000370?l0a`3o0080a`3o100000070?l0]P03
0000003V0?l0iP3o00<000000P3o0;H00`000000Z03o0:P0o`040:P0o`03000000006?l001So00<0
00000P010?l00`0000000<oo003?o`05003?o`D000000`00oeX00`000000C_l004ko000404ko00<0
00001P3]o`000`000000ok800?nb00040?nb00<000001P3oH@000`000000ocP00?lh00020?lh00@0
00001`3o6P000`000000oooo0000000>0?ooo`0506IVIP3oool0oooo0?ooo`000000103oool00200
oooo00@000000?ooo`3oool0IVIV1P3oool00`000000o`@00?l400050?l400<000001@3o3@020000
00@0oaL0100000060?li008000000`3oE`04000000H0ok800P0000020?oh00<000000P2go`000`00
0000C_l004ko000404ko000300000000ob000?lP00<000000P00oj/00`0000000<oo003?o`05003?
o`D000000`1A0?l00`000000Z03o0:P0o`040:P0o`D000000`3o09<00`000000o`2f0?l0]P050?l0
]P<000001P3o0;H00`000000Z03o0:P0o`020:P0o`@000001P010?l2000000800<oo0`000002003T
o`0300000000oeX00?mJ00@00?mJ00<0000004ko001>o`000`00000206ko00030000003]o`00kOl0
00@0kOl000<000000?nb003o/P00100000020?nM00030000003oH@00of4000@0of401@0000030?l_
00030000003o6P00oaX000D0oaX00P0000000`3oool000000?ooo`0<0?ooo`0506IVIP3oool0oooo
0?ooo`000000103oool00240oooo0`00000206IVIPD0oooo0P0000020?l400<000000P3o1`000`00
0000o`d00?l=00040?l=00D000000`3o8`000`000000ocT00?li00050?li00@000000`3oNP000`00
0000ok800?nb00050?nb00<000001P2go`02000000<0C_l010000006003oZ`8000000P00col30000
0080037o00<000000540o`1A0?l0101A0?l00`000000Z03o0:P0o`0300000080o`2f00<000000?l0
T`3o09<0103o09<200000080o`2f0`0000020?l0B`030000003o0;H0o`2f00@0o`2f1@0000030<L0
o`03000000010?l00@3o00D00@3o0`000006003To`0300000000oeX00?mJ00800?mJ1000000606ko
00030000003]o`00kOl00080kOl0100000070?nM00030000003oH@00of4000<000000P3oD@000`00
0000obl00?l_00040?l_00030000003o6P00oaX000@000000P3o50000`000000oooo0000000<0?oo
o`0506IVIP3oool0oooo0?ooo`000000103oool001L0oooo100000080?ooo`040000003oool0oooo
06IVIPH0oooo0P0000060?l7008000000P3o3@0200000080oa@000<000000?lS003o8`00103o8`02
00000080ocT00`0000020?m?00030000003oNP00ogX000<0ogX00P0000020?nb00<000000P3ok000
0`000000]ol00;Oo00050;Oo00@000000`00ob000`0000000?n[003oZ`05003oZ`<000001P00<Ol0
0`000000D@3o0540o`020540o`@000001P3o0;H2000000@0o`2C100000060?l0B`030000003o0;H0
o`2f00<000000P3o09<00`000000a`3o0<L0o`040<L0o`03000000010?l00@3o00@000000P006?l0
0`0000000>Co003To`04003To`D000000`00obh00`000000K_l006ko000406ko00D000000`3olP00
0`000000oid00?nM00050?nM00<000001P3oD@000`000000obl00?l_00020?l_00@000001P3o5000
10000000oooo0?ooo`00000<0?ooo`0506IVIP3oool0oooo0?ooo`0000000`3oool001L0oooo00<0
00000?ooo`3oool02P3oool2000000030?ooo`1VIVH0oooo00D0oooo00<000000?l7003o1`001@3o
1`03000000D0oa@00P0000040?lS00@000001P3oC`02000000<0ogX0100000060?o/008000000P2g
o`0300000080Hol000<00000003o8000ob000`00ob02000000800?n[0`000002003?o`0300000000
<Ol0037o00@0037o1@0000030>H0o`030000003o0;H0o`2f00D0o`2f1@0000030?l09P030000003o
04/0o`1;00@0o`1;0`0000060?l0T`03000000370?l0a`3o0080a`3o10000007000Ho`0300000000
i?l00>Co00<000000P00on400`0000000?l^003o;P04003o;P030000001^o`00K_l000<000000P2M
o`000`000000oo800?ob00040?ob00030000003oW@00oid000@000000P3oP`000`000000oe400?mA
00040?mA00D000000`3o9@000`000000oa@00?lD00040?lD0080000000<0oooo0000003oool02`3o
ool01@1VIVH0oooo0?ooo`3oool0000000<0oooo000H0?ooo`030000003oool0oooo00/0oooo00@0
00000?ooo`1VIVH0IVIV1@3oool200000080o`L00`0000020?l;00030000003o5000oa@000@0oa@0
1@0000030?l`00030000003oC`00odl000D0odl0100000030?nQ00030000003ok000on`000D0on`0
0`00000606?o000300000000ob000?lP00800?lP10000006003?o`0300000000<Ol0037o00<00000
0P1A0?l00`000000iP3o0>H0o`040>H0o`8000000P3o0;H300000080o`1;00<000000?l09P3o02H0
103o02H00`000000o`1;0?l0B`0300000080o`0V00<000000?l0T`3o09<0103o09<5000000<0Z03o
00<00000000Ho`006?l01@006?l3000000H00?oQ00<00000003o;P00obh00P00obh4000000H0WOl0
00<000000?ob003olP000P3olP04000000H0oh<000<000000?mA003oD@00100000020?m000030000
003o9@00obD000@0obD000<000000?lD003o50000`0000020?l?00030000003oool0000000/0oooo
00D0IVIV0?ooo`3oool0oooo000000030?ooo`004@3oool4000000@0oooo00<000000?ooo`3oool0
2`3oool2000000030?ooo`1VIVH0oooo00D0oooo0P0000060?l;008000000P3o500200000080oa`0
00<000000?l`003o<000103o<00200000080odl00`0000020?mX00030000003oX@00oj4000<0oj40
0P0000020?o/00<000000P3Go`000`000000Hol006?o000406?o00D000000`00ohX00`0000000<oo
003?o`04003?o`<000001P1A0?l2000000@0iP3o100000060?l0B`030000003o02H0o`0V0080o`0V
100000060?l09P030000003o09<0o`2C00<000000P3o0;H00`000000Z03o0:P0o`040:P0o`030000
00006?l001So00@000000P00HOl00`0000000?oQ003oh@04003oh@D000000`0Co`000`000000WOl0
09go000409go00D000000`3ob`000`000000oh<00?n300040?n300<000001P3o@0000`000000obD0
0?lU00020?lU00D000001@3o3`0010000000oooo0?ooo`00000:0?ooo`0506IVIP3oool0oooo0?oo
o`0000000`3oool001L0oooo00@000000?ooo`3oool000003@3oool2000000030?ooo`1VIVH0IVIV
00D0oooo00<000000?l;003o2`001@3o2`03000000D0oa`00P0000040?l`00@000001P3oJ0000`00
0000oj400?nQ00020?nQ00@000001P3Go`0200000080Hol00P00000201?o000300000000ohX00?n:
00@00?n:0P000002003?o`8000000P00HOl00`000000D@3o0540o`050540o`D000000`3o0;H00`00
0000o`1;0?l0B`040?l0B`D000000`3o00000`000000o`0V0?l09P040?l09P<000001P3o0;H00`00
0000Z03o0:P0o`020:P0o`@000001`00HOl00`0000000?oQ003oh@03000000800?n:00<0000001?o
000Co`00100Co`000`000000WOl009go000300000080eol000<000000?o;003ob`00103ob`000`00
0000oh<00?n3000300000080ofP000<000000?m0003o@000103o@005000000@0oa`000<000000?l?
003o3`000`3o3`0200000080oooo00<000000?ooo`3oool01`3oool01@1VIVH0oooo0?ooo`3oool0
000000<0oooo000H0?ooo`800000403oool010000000oooo0?ooo`1VIVH50?ooo`8000000P3o2`03
00000080o`l000<000000?lL003o7000103o7005000000<0od0000<000000?mX003oJ000103oJ005
000000<0ol/00P0000050=Oo00@000001@0Co`02000000@00?n:10000005001Qo`8000000P1A0?l3
00000080Z03o00<000000?l0]P3o0;H0103o0;H00`000000o`1;0?l0B`0300000080o`0V00<00000
0?l0003o0000103o00000`000000o`0V0?l09P0300000080o`1;00<000000?l0]P3o0;H0103o0;H5
000000<0D@3o00<00000001Qo`00HOl01@00HOl3000000H00?n:00<0000001?o000Co`000P0Co`04
000000H0eol000<000000?o;003ob`000P3ob`04000000H0ofP000<000000?m0003o@0000`000002
0?l`00030000003o7000oa`000@0oa`000<000000?l?003o3`000`0000020?l;00040000003oool0
oooo000000P0oooo00D0IVIV0?ooo`3oool0oooo000000030?ooo`00:`3oool300000080IVIV0`3o
ool0101VIVH0oooo0000000000060?l?008000000P3o700200000080obD000<000000?m0003o@000
103o@00200000080ofP00P0000020?n300030000003ob`00ol/000D0ol/01@00000309go00030000
000Co`004ol000@04ol01@000003003oh@0300000000HOl0067o00@0067o0`0000060:P0o`030000
003o0;H0o`2f0080o`2f100000060?l09P030000003o0000o`000080o`00100000060?l0B`030000
003o0;H0o`2f00<000000P3V0?l00`000000D@3o0540o`040540o`0300000000HOl0067o00@00000
0P00col00`0000000?n:003oRP04003oRPD000000`1So`000`000000eol00=Oo00040=Oo00D00000
0`3oX@02000000@0ofP0100000060?l`00030000003o7000oa`00080oa`0100000060?l;00030000
003oool0000000P0oooo00D0IVIV0?ooo`3oool0oooo000000030?ooo`00;@3oool01P000000oooo
0?ooo`1VIVH0oooo06IVIP<0oooo00<000000?l?003o3`001@3o3`03000000D0obD00P0000040?m0
00@000001@3oP`0200000080ol/00`0000020?ob00030000002Mo`00WOl000@0WOl000<0000001?o
000Co`000`000002003o;P0300000000on400?oQ00@00?oQ00<00000001Qo`00HOl00`000002000H
o`030000002X0?l0Z03o00@0Z03o1@0000030?l0T`030000003o02H0o`0V00@0o`0V1@0000030?l0
9P800000103o04/4000000H0iP3o00<000000540o`1A0?l00P1A0?l4000000H00<oo00<00000003o
RP00ohX010000002003o80030000001So`00Hol000<0Hol000<000000=Oo003Go`00100000020?o/
00030000003oX@00oj4000@0oj401@0000030?m?00030000003o<000oc0000@0oc001@0000030?lD
00030000003o2`00o`/000@0o`/00P0000000`3oool000000?ooo`060?ooo`0506IVIP3oool0oooo
0?ooo`0000000`3oool002h0oooo0P0000000`3oool0IVIV06IVIP040?ooo`8000000P3o3`030000
0080oa@000<000000?lU003o9@00103o9@05000000<0oe4000<000000?n3003oP`00103oP`030000
00H0oo8000<0000009go002Mo`000P2Mo`04000000H00?l^00<00000003oh@00on400P00on440000
00H001So00<000000:P0o`2X0?l00`0000020<L0o`030000003o09<0o`2C00@0o`2C00<000000?l0
9P3o02H00`0000020?l0B`030000003o02H0o`0V00@0o`0V1@0000030?l0]P030000003V0?l0iP3o
00@0iP3o1@000003000ao`8000001000col4000000H00?lP00<0000006?o001So`000P1So`040000
00H0on`000<000000?nQ003oX@00100000020?mj00030000003oC`00odl000<0odl000<000000?l`
003o<000100000020?lS00030000003o5000oa@000<0oa@000<000000?l;003o2`00100000020?l7
00030000003oool0000000L0oooo00D0IVIV0?ooo`3oool0oooo000000020?ooo`00<03oool01000
0000oooo06IVIP0000050?ooo`8000001P3o500200000080obD00P0000020?l_00030000003oD@00
oe4000@0oe400P0000020?n3008000000P3oW@000`000000oo800?ob00040?ob00D000000`1^o`00
0`0000000?l^003o;P04003o;PD000000`00i?l2000000@001So100000060<L0o`8000000`3o09<4
000000H0o`1;00<000000?l09P3o02H00`0000020?l0T`030000003o0;H0o`2f00@0o`2f00<00000
0>H0o`3V0?l00`0000020540o`0300000000<Ol0037o00@0037o1@000003003oZ`0300000000ob00
0?lP00@00?lP1@0000030;Oo00030000003ok000on`000@0on`00`0000060?mj00030000003oC`00
odl00080odl0100000060?lS00030000003o5000oa@00080oa@0100000060?l700040000003oool0
oooo000000H0oooo00D0IVIV0?ooo`3oool0oooo000000020?ooo`00<@3oool2000000030?ooo`1V
IVH0oooo00@0oooo0P0000050?lD00@000001@3o;`02000000@0oe40100000050?nM008000000P3o
lP0200000080kOl000<0000006ko001^o`00101^o`02000000800?l^0P000002003oFP0300000000
i?l00>Co00D00>Co100000030040o`03000000370?l0a`3o00D0a`3o100000030?l0]P800000103o
04/4000000H0o`2C00<000000?l0]P3o0;H00P3o0;H4000000H0D@3o00<00000000ao`00<Ol00`00
0002003?o`0300000000oj/00?n[00@00?n[00<00000003o8000ob000`00000204ko00030000002g
o`00]ol000@0]ol000<000000?o/003ok0000`0000020?nb00030000003oNP00ogX000@0ogX01@00
00030?li00030000003o8`00ob<000@0ob<01@0000030?l=00800000103o1`0300000080oooo00<0
00000?ooo`3oool00`3oool01@1VIVH0oooo0?ooo`3oool000000080oooo000b0?ooo`80000000<0
oooo06IVIP1VIVH01@3oool5000000<0oaX000<000000?l_003o;`00103o;`05000000<0of400P00
00040?nM00@000001@3]o`02000000@0K_l010000005003oFP8000000P00i?l3000000800<oo00<0
00000040o`010?l00`010?l200000080a`3o0`0000020:P0o`030000003o0;H0o`2f00@0o`2f1000
00030?l0]P030000003o09<0o`2C00@0o`2C1@0000030:P0o`030000001A0?l0D@3o00@0D@3o0`00
0006003?o`0300000000oj/00?n[00800?n[1000000604ko00030000002go`00]ol00080]ol01000
00060?nb00030000003oNP00ogX000<000000P3oE`000`000000ocT00?li00040?li00030000003o
8`00ob<000<000000P3o5`000`000000o`d00?l=00040?l=00D000000`3o100010000000oooo0?oo
o`0000040?ooo`0506IVIP3oool0oooo0?ooo`0000000P3oool003@0oooo00@000000?ooo`3oool0
IVIV1P3oool00`000000oaX00?lJ00040?lJ008000000P3o;`0200000080ocP000<000000?mQ003o
H@00103oH@05000000<0ok8000<000000>go003]o`00103]o`05000000<0C_l00P000004003oFP@0
00001P00col00`0000000@3o0040o`020040o`@000001P2X0?l00`000000o`2f0?l0]P0300000080
iP3o00<000000?l0]P3o0;H00`3o0;H200000080o`2C0P0000020<L0o`030000002X0?l0Z03o00@0
Z03o00<000000540o`1A0?l00`000002001Qo`0300000000col00<oo00@00<oo1@000003003o8003
0000001>o`00C_l000@0C_l01@0000030?oh00800000103o/P04000000H0oeL000<000000?li003o
>@000P3o>@04000000H0oaL000<000000?l=003o3@000`0000020?l800030000003o1000o`@000<0
o`@000@000000?ooo`3oool00000103oool01@1VIVH0oooo0?ooo`3oool000000080oooo000e0?oo
o`80000000<0oooo06IVIP3oool01@3oool2000000@0oaX0100000050?lh008000000P3oH@020000
0080ofh000<000000?nb003o/P00103o/P0200000080kOl00P0000020=Oo00030000001>o`00C_l0
00@0C_l01@000003003oJ@0300000000col00<oo00@00<oo1@000003000Ho`030000002X0?l0Z03o
00@0Z03o0`0000060>H0o`030000003o0;H0o`2f0080o`2f100000050<L0o`8000000`2X0?l40000
00H0067o00<00000003?o`00col00`000002003oRP0300000000ob000?lP00@00?lP00<0000004ko
001>o`000`0000020;Oo00030000003on000ooP000@0ooP01@0000030?n000030000003oE`00oeL0
00@0oeL01@0000030?lV00030000003o5`00oaL00080oaL01@0000050?l800030000003o1000o`@0
0080o`@00`0000020?ooo`050000003oool0oooo0?ooo`1VIVH00`3oool100000040oooo0@3oool0
03L0oooo0P00000206IVIPH0oooo100000030?lO00800000103o>004000000D0ofh00P0000040?nb
00@000001@3Go`0200000080C_l00P00000204?o000300000000ofT00?mY00@00?mY00<00000003?
o`00col00`000002003To`03000000006?l001So00@001So00<000000:P0o`2X0?l00`0000020540
o`030000003V0?l0iP3o00@0iP3o1@0000030:P0o`03000000370?l0a`3o00@0a`3o10000003000H
o`8000001000HOl4000000H00?n:00<00000003o8000ob000P00ob04000000H0]ol000<000000?oh
003on0000`0000020?nb00030000003oP000oh0000@0oh0000<000000?mG003oE`000`0000020?lk
00030000003o9P00obH000<0obH01@0000040?l?00030000003o2000o`P000<0o`P01@0000030?l2
0080000000D0oooo0000003oool0oooo06IVIP030?ooo`4000000@3oool10?ooo`00=`3oool20000
0080oooo00<0IVIV0?ooo`3oool0103oool00`000000oal00?lO00040?lO00D000000`3o@0000`00
0000ofh00?m^00040?m^00D000000`3o`002000000@0eol01000000504?o008000000`00ofT40000
00H00>Co00<00000000Ho`006?l00P006?l4000000H0D@3o00<000000>H0o`3V0?l00`0000020540
o`030000002X0?l0Z03o00@0Z03o00<000000<L0o`370?l00`0000020040o`03000000006?l001So
00<001So1@000003003oh@0300000000ohX00?n:00@00?n:1@00000306?o00800000102go`040000
00H0ok8000<000000?n0003oP0000P3oP004000000D0oc/000<000000?lV003o9P000`0000020?lI
00030000003o3`00o`l000@0o`l000<000000?l8003o20000`0000020?l500030000003o0P00o`80
00@0o`800P0000001@3oool000000?ooo`3oool0IVIV00<0oooo0@0000010?ooo`00>@3oool20000
00030?ooo`1VIVH0IVIV00D0oooo0P0000020?lO008000000P3o8`000`000000od000?m000040?m0
00030000003oKP00ofh000<000000P3oM`000`000000ol000?o000040?o000D000000`3?o`000`00
0000@ol004?o000404?o00@000000`00oeX2000000@00>Co1P000003001Qo`800000101A0?l40000
00H0D@3o00<000000:P0o`2X0?l00P2X0?l4000000H00@3o00<00000000Ho`006?l00P000002003T
o`0300000000on400?oQ00@00?oQ00<00000003oRP00ohX00`00000201?o00030000001So`00Hol0
00@0Hol01@0000030?o/00030000003o/P00ok8000@0ok801@0000030?mG00030000003o>`00oc/0
0080oc/0100000060?lI00030000003o3`00o`l00080o`l0100000050?l500030000003o0P00o`80
00@000000P3o0@001@000000oooo0000003oool0IVIV00<0oooo0@0000010?ooo`00>`3oool20000
00030?ooo`1VIVH0oooo00D0oooo0P0000050?lS008000000`3o@004000000H0ogL00P0000020?o0
008000000P3oa@000`000000col00<oo00040<oo000300000013o`00@ol000<000000P1>o`000`00
00000?mJ003oFP04003oFP@000000`00on400`000000067o001Qo`04001Qo`D000000`00<Ol20000
00@0D@3o1P000003000Ho`80000010010?l4000000D00>Co00<00000003oh@00on400P00on440000
00H04ol000<0000006?o001So`000`0000020=Oo00030000003ok000on`000<0on`000<000000?nb
003o/P00100000020?mj00030000003oE`00oeL000<0oeL01@0000030?lV00030000003o6@00oaT0
00@0oaT01@0000030?l900030000003o1@00o`D00080o`D0100000060?l100050000003oool00000
0?ooo`1VIVH00`3oool100000040oooo000l0?ooo`80000000<0oooo06IVIP3oool01@3oool00`00
0000ob<00?lS00040?lS00@000000`3oA@02000000D0ogL0100000050?o5008000000`3?o`040000
00H0C_l000<00000003oFP00oeX00`000002003o;P0300000000on400?oQ00<00?oQ0P000002001Q
o`8000000P00col00`000000037o000ao`04000ao`D000000`00HOl00`00000001So000Ho`04000H
o`D000000`00col00`0000000>Co003To`02003To`H000000`00obh2000000@04ol0100000060=Oo
00040000003ok000on`00?o/00@000001P3oNP000`000000oeL00?mG000300000080ocT000<00000
0?lV003o9P00103o9P000`000000oaT00?lI000300000080o`l000<000000?l9003o2@000`3o2@05
000000<0o`8000<000000?l1003o0@00103o0@02000000030?ooo`000000IVIV00<0oooo0@000001
0?ooo`00<P3oool5000000L0oooo00@000000?ooo`1VIVH0IVIV1@3oool200000080ob<00P000002
0?lV00030000003oA@00odD000@0odD01@0000030?mj00030000003oa@00olD000@0olD010000003
0=Oo00800000101>o`04000000H00?l^00<00000003oh@00on400P00on44000000D00<oo00<00000
000ao`00<Ol00`000002003?o`0300000000HOl0067o00@0067o00<00000000Ho`006?l00`000002
003To`0300000000col00<oo00<00<oo1@000003003oFP0300000000obh00?l^00@00?l^1@000003
09go00800000103Go`05000000<0oj400P0000040?mj00@000001P3o>@000`000000obH00?lV0002
0?lV00@000001@3o3`000`000000o`T00?l9000300000080o`D000<000000?l2003o0P00103o0P00
0`000000o`400?l1000300000080o`0000<000000?ooo`0000000`3oool100000040oooo000d0?oo
o`030000003oool0oooo00P0oooo00@000000?ooo`000000IVIV1P3oool2000000D0obH00P000002
0?m5008000000P3oA`000`000000ogX00?mj00040?mj00030000003oa@00olD000<000000P3o`000
0`000000eol00=Oo00040=Oo00@000000`1^o`000`0000000?l^003o;P04003o;PD000000`00ohX2
000000<00<oo10000006003?o`0300000000HOl0067o0080067o10000006003To`0300000000col0
0<oo008000000P00ofT00`0000000?mJ003oFP04003oFP0300000000obh00?l^00<000000P1^o`00
0`000000WOl009go000409go00D000000`3ob`000`000000oj400?nQ00030?nQ00D000000`3oC`02
000000@0ocT01P0000030?lG00030000003o3`00o`l00080o`l0100000060?l500030000003o0P00
o`800080o`80100000050?l000040000003oool0IVIV00000080oooo0@0000010?ooo`00=03oool0
0`000000oooo0?ooo`090?ooo`80000000<0oooo06IVIP1VIVH01@3oool2000000@0obH010000005
0?m7008000000`3oNP04000000H0ol0000<000000=Oo003Go`000`0000020>go00030000001^o`00
K_l000<0K_l000<00000003o;P00obh00`00000201?o000300000000ohX00?n:00@00?n:10000003
003oZ`0300000000col00<oo00@00<oo1@000003003oh@8000001000i?l4000000D00?mY00<00000
003oFP00oeX00P00oeX4000000H0K_l000<0000009go002Mo`000`0000020?ob00030000003ob`00
ol/000<0ol/000<000000?nQ003oX@000`0000020?mX00030000003oC`00odl000@0odl01@000003
0?lS00030000003o5`00oaL000<0oaL01@0000030?l800800000103o1@06000000<0o`4000<00000
0?l0003o00000P3o00030000000506IVIP3oool000000?ooo`0000000@3oool002`0oooo10000004
0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0IVIV1P3oool4000000<0obL00P00
00040?m700D000000`3oM`02000000@0ol00100000060>go00040000001^o`00K_l006ko00@00000
1P0Co`000`0000000?n:003oRP03000000800?lP00<00000003oZ`00oj/00`00oj/2000000800<oo
0P000002003oRP0300000000on400?oQ00@00?oQ1@000003003oFP0300000000ofT00?mY00<00?mY
1@00000304ko00800000101^o`04000000D0oo8000<000000?o;003ob`000P3ob`04000000H0ofP0
00<000000?m?003oC`000`0000020?l`00030000003o8`00ob<000<0ob<000<000000?lG003o5`00
0`0000020?l=00030000003o2000o`P000@0o`P01@0000030?l200030000003o0@00o`4000<0o`40
1@0000030?ooo`0506IVIP3oool0oooo0000003oool00@00000003@0oooo00<000000?ooo`3oool0
303oool2000000030?ooo`1VIVH0oooo00<0oooo00<0IVIV0?ooo`0000001P3o9`05000000<0odD0
00<000000?mg003oM`00103oM`04000000<0ok800P0000040>go00D000000`2Mo`02000000@04ol0
10000006003o800300000000oj/00?n[00800?n[10000005003oRP0300000000on400?oQ00<00000
0P00obh00`0000000?mJ003oFP04003oFP0300000000ofT00?mY008000000P13o`000`000000C_l0
04ko000404ko00D000000`3]o`000`000000oo800?ob00030?ob00D000000`3oP`02000000@0ofP0
100000050?l`00030000003o8`00ob<00080ob<0100000060?l=00030000003o2000o`P000<00000
0P3o10000`000000o`800?l200030?l200030000003o0@00o`4000<000002@3oool0101VIVH0oooo
0000001VIVH100000000<`3oool200000100oooo0P00000206IVIP80oooo00<0IVIV0?ooo`3oool0
0P0000020?lW008000000P3o9P000`000000odD00?m500040?m500030000003oM`00ogL000<00000
0P3oKP000`000000ok800?nb00030?nb00D000000`3olP000`000000WOl009go000409go00@00000
0`1So`02000000@00?lP1P000003003o808000000`00ohX4000000H00?l^00<00000003oFP00oeX0
0P00oeX4000000D0@ol000<0000004ko001>o`000`0000020=Oo00030000003]o`00kOl000@0kOl0
00<000000?ob003olP000P0000020?nM00030000003oP`00oh<000@0oh<01@0000030?m000030000
003o<000oc0000<0oc001@0000030?lD00800000103o3@04000000D0o`@000<000000?l2003o0P00
0P3o0P04000000X0oooo101VIVH10?ooo`4000000@00000004H0oooo00H000000?ooo`3oool0IVIV
0?ooo`1VIVH40?ooo`8000001@3o9P02000000<0odD0100000060?m^00030000003o/P00ok800080
00000P3oW@000`000000oo800?ob00040?ob00030000002Mo`00WOl000<000000P3Go`000`000000
Hol006?o000306?o00D000000`1>o`000`0000000?lP003o8004003o80@000000`0Co`02000000@0
0?l^1P00000304ko008000000`13o`04000000H0eol000<000000>go003]o`000P3]o`04000000D0
oid000<000000?n3003oP`000`0000020?mA00030000003o@000od0000<0od0000<000000?l`003o
<0000`0000020?lL00030000003o5000oa@000@0oa@01@0000030?l700030000003o1000o`@00080
o`@01P00000:0?ooo`@0IVIV0P3oool00`1VIVH0oooo0000000200000000A`3oool2000000030?oo
o`1VIVH0000000D0oooo0P0000040?lV00D000000`3o@002000000@0ofh0100000050?nM00800000
0`3olP04000000H0eol000<0000006?o001So`000P0000020;Oo00030000001>o`00C_l000@0C_l0
00<00000003o8000ob000`00000206?o00030000000Co`004ol000<04ol01@00000306ko00030000
001>o`00C_l000@0C_l0100000030<oo00800000103Go`06000000<0ok8000<000000?nM003oW@00
0P3oW@04000000D0oe4000<000000?m0003o@0000P3o@004000000H0oa`000<000000?lD003o5000
0`0000020?l;00030000003o1`00o`L000<0o`L01@00000;0?ooo`D0IVIV103oool4000000<0oooo
00190?ooo`040000003oool0000006IVIPH0oooo100000030?lS00030000003o@000od0000@0od00
100000030?mQ00800000103oW@05000000<0ol/00P0000040=Oo00@000001@2go`02000000<0C_l0
1000000606?o00030000000Co`004ol0008000000P2Mo`000`000000K_l006ko000406ko00030000
001>o`00C_l000<000000P3Go`000`000000col00<oo00030<oo00D000000`3o`0000`000000ok80
0?nb00030?nb00D000000`3oH@02000000<0oe401P0000030?lU00800000103o7004000000D0o`/0
00<000000?l7003o1`000`00000<0?ooo`@0IVIV1@3oool4000000L0oooo001:0?ooo`80000000<0
oooo06IVIP3oool01P3oool00`000000ob<00?lS00030?lS00030000003o@000od0000<000000P3o
>0000`000000of400?mQ00030?mQ00D000000`3oP`000`000000ol/00?o;00030?o;00D000000`3o
k002000000@0]ol01@0000030;Oo00800000101So`04000000D0WOl000<0000006ko001^o`000P1^
o`04000000D0eol000<000000<oo003?o`000`0000020?o500030000003o`000ol0000<0ol0000<0
00000?nb003o/P000`0000020?m^00030000003oH@00of4000@0of40100000030?l_00800000103o
9@06000000<0o`l000<000000?l;003o2`000P3o2`04000000/0oooo101VIVH40?ooo`D000002`3o
ool004`0oooo00@000000?ooo`1VIVH0IVIV1P3oool010000000ob<00?lS003o8`04000000H0ocP0
00<000000?mQ003oH@000P0000020?mA00030000003oP`00oh<000@0oh<000<000000?o;003ob`00
0P0000020?nQ00030000003ok000on`000@0on`01@0000030?oh00030000002go`00]ol000<0]ol0
1@0000030=Oo008000000`2Mo`06000000<0kOl00P0000030=Oo00@000001P3oa@0010000000ol00
0?o0003o`004000000H0ofh000<000000?mQ003oH@000`0000020?lh00030000003o;`00obl000<0
obl01@0000030?lD00030000003o3`00o`l000<0o`l01@00000;0?ooo`@0IVIV103oool400000100
oooo001=0?ooo`040000003oool0000006IVIPH0oooo0`0000030?lO00800000103o>004000000D0
oe400P0000030?n300@000001@3oX@0200000080on`00P0000020?nb00030000003on000ooP000@0
ooP000<000000;Oo002go`000P0000020?o/00030000003Go`00eol000@0eol0100000030?ob0080
0000103]o`05000000<0ol000P0000040?o500D000000`3oM`02000000@0ofh0100000050?lh0003
0000003o;`00obl000<000000P3o6P000`000000oa@00?lD00030?lD00030000003o3`00o`l000<0
000000<0oooo06IVIP3oool0203oool506IVIP@0oooo1000000D0?ooo`00CP3oool2000000030?oo
o`1VIVH0IVIV00D0oooo0P0000040?lO00D000000`3o;`02000000@0oe401@0000030?mX00800000
103oX@04000000D0ok8000<000000?oh003on0000P3on004000000D0on`000<000000=Oo003Go`00
0`0000020?o;00030000003olP00oo8000<0oo801@0000030?nb00030000003o`000ol0000<0ol00
1@0000030?mj008000000`3oM`06000000<0od0000<000000?lh003o>0000P3o>004000000D0oaX0
00<000000?lD003o50000P3o5004000000@0oooo00<0IVIV0?ooo`3oool00`3oool406IVIPD0oooo
1000000H0?ooo`00D03oool010000000oooo0?ooo`1VIVH60?ooo`@000000`3o6P000`000000obl0
0?l_00030?l_00D000000`3o@002000000<0ofP01P0000030?mj008000000`3o/P06000000<0ok80
0P0000030?o/00@000001P3ob`000`000000oo800?ob000200000080oid000<000000?nb003o/P00
103o/P000`000000ol000?o0000200000080ogL000<000000?mj003oNP00103oNP04000000<0odD0
0P0000030?m000H000000`3o7`02000000<0oaX01P0000080?ooo`0306IVIP3oool0IVIV00<0IVIV
103oool5000001`0oooo001A0?ooo`80000000<0oooo0000003oool01P3oool00`000000oaX00?lJ
00030?lJ00030000003o;`00obl0008000000P3o9@000`000000od000?m000040?m000@000000`3o
C`000`000000ogX00?mj00040?mj00@000000`3oP002000000@0ok801@0000030?nQ00800000103o
b`04000000D0oid000<000000?nb003o/P000P3o/P04000000D0ogL000<000000?mj003oNP000`00
00020?m700030000003oA@00odD000<0odD0100000030?lS00030000003o7`00oal000@0oal01000
000;0?ooo`D0IVIV103oool400000240oooo001C0?ooo`8000000P1VIVH60?ooo`040000003o6P00
oaX00?lJ00@000001@3o9@0200000080od000P0000020?l`00030000003oC`00odl000<0odl00P00
00020?mj008000000P3oE`000`000000oh000?n000030?n000D000000`3oNP02000000<0oj401P00
00030?n3008000000`3oW@06000000<0ofh000<000000?mg003oM`000P3oM`04000000D0odL000<0
00000?m5003oA@000`0000020?lV00030000003o8`00ob<000<0ob<000<000000?lO003o7`000`00
000;0?ooo`@0IVIV0`3oool00`1VIVH0oooo00000003000002D0oooo001D0?ooo`040000003oool0
oooo06IVIPH0oooo0`0000030?lD00800000103o9@04000000D0oc0000<000000?m?003oC`000P3o
C`04000000D0oeL000<000000?n0003oP0000P0000020?mG00030000003oNP00ogX000@0ogX01000
00030?mX00030000003oP`00oh<000@0oh<0100000030?mQ008000000`3oKP06000000<0odD00P00
00030?m700@000001@3o9P000`000000ob<00?lS00020?lS00@000002P3oool406IVIP@0oooo1@00
000Y0?ooo`00B@3oool2000000X0oooo0P0000000`3oool0000006IVIP050?ooo`8000000`3o5006
000000<0oa`00P0000030?l`00H000000`3o>@02000000<0oeL0100000050?mG00030000003oNP00
ogX000<000000P3oC`000`000000ofP00?mX00030?mX00030000003oP`00oh<000<000000P3oD@00
0`000000of400?mQ00030?mQ00@000000`3o@002000000@0odD01@0000030?lW008000000`3o9P06
000000X0oooo101VIVH40?ooo`@00000;P3oool004P0oooo00@000000?ooo`3oool000002`3oool2
000000030?ooo`1VIVH0oooo00@0oooo00@0IVIV00000000000000000`3o3`02000000@0oa`01@00
00030?lS00800000103o>@05000000<0oc/00P0000030?mG00@000001P3oC`0010000000ofP00?mX
003oJ004000000D0oe4000<000000?mQ003oH@000`0000020?lh00030000003o@000od0000<0od00
1@0000030?lV00030000003o9`00obL000<0obL01000000;0?ooo`D0IVIV103oool400000380oooo
00180?ooo`040000003oool0oooo000000`0oooo0P0000000`3oool0IVIV0?ooo`030?ooo`0306IV
IP3oool0000000H0o`l0100000030?lD00030000003o8`00ob<000<0ob<01@0000030?lV00800000
0`3o>`05000000<0ocT00P0000040?m?00D000000`3o@002000000<0oe40100000060?lh00030000
003o@000od00008000000P3o8`000`000000obH00?lV00030?lV00030000003o9`00obL000<00000
00<0IVIV0?ooo`3oool0203oool406IVIPD0oooo1000000f0?ooo`00B03oool010000000oooo0?oo
o`00000>0?ooo`040000003oool0000006IVIP80oooo00<0IVIV0?ooo`3oool00P0000020?l?0080
00000P3o2`000`000000oa@00?lD00030?lD00030000003o8`00ob<0008000000P3o5`000`000000
obH00?lV00040?lV00@000000`3o9P02000000<0ocT01P0000030?l`008000000`3o@005000000<0
obl00P0000040?lh00@000001@3o8`0010000000obH00?lV003o9P04000000<0oooo00<0IVIV0?oo
o`3oool0103oool406IVIP@0oooo1@00000j0?ooo`00B03oool010000000oooo0?ooo`00000?0?oo
o`80000000@0oooo06IVIP3oool0IVIV103oool2000000D0o`/000@000000?lD003o5000oa@01000
00050?lG00030000003o9P00obH000<000000P3o6@000`000000obH00?lV00030?lV00@000000`3o
8`02000000@0oc001@0000030?lU008000000`3o;`06000000<0oal000<000000?lS003o8`000P3o
8`05000000L0oooo00<0IVIV0?ooo`1VIVH0101VIVH40?ooo`@00000?`3oool004T0oooo0P00000A
0?ooo`80000000<0oooo06IVIP1VIVH01@3oool2000000<0o`/01@0000030?l=008000000`3o5`04
000000H0oaT000<000000?lV003o9P000P0000020?lG00030000003o8`00ob<000<0ob<01@000003
0?lL00030000003o9@00obD000<0obD0100000030?lJ008000000`3o7`06000000X0oooo101VIVH5
0?ooo`@00000@`3oool005h0oooo00@000000?ooo`000000IVIV1P3oool3000000<0o`L00P000003
0?l=00D000000`3o3`02000000@0oaT0100000050?lG00030000003o8`00ob<0008000000P3o5000
0`000000oa`00?lL00030?lL00030000003o9@00obD000<000000P3o50000`000000oaX00?lJ0003
0?lJ00@00000303oool406IVIP80oooo00<0IVIV0?ooo`000000100000170?ooo`00G`3oool20000
00030?ooo`1VIVH0IVIV00D0oooo0P0000030?l700D000000`3o2002000000@0o`l01@0000030?l?
008000000`3o5`04000000D0oa@000@000000?lL003o7000oa`0100000060?lD00030000003o6P00
oaX0008000002`3oool506IVIP@0oooo1000001<0?ooo`00H@3oool010000000oooo0?ooo`1VIVH6
0?ooo`<000000`3o1002000000<0o`P01P0000030?l9008000000`3o3`05000000<0o`d00P000003
0?lD00D000000`3o3`02000000@0oa@0100000090?ooo`@0IVIV1@3oool400000500oooo001R0?oo
o`80000000<0oooo0000003oool01@3oool00`000000o`@00?l400030?l400@000000`3o1@020000
00@0o`T01@0000030?l8008000000`3o3@05000000<0o`/00P0000030?l?00H000002@3oool406IV
IP@0oooo1@00001D0?ooo`00I03oool010000000oooo06IVIP1VIVH50?ooo`030000003o1000o`@0
008000000P3o0P000`000000o`D00?l500030?l500D000000`3o1@02000000<0o`P01@0000030?l7
008000000`3o2`050000000306IVIP3oool0oooo00P0oooo101VIVH40?ooo`@00000F@3oool006D0
oooo00@000000?ooo`3oool0IVIV1@3oool2000000D0o`8000<000000?l5003o1@000P0000020?l2
00030000003o1@00o`D000@0o`D0100000030?l4008000000`3o1`05000000D0oooo00<0IVIV0?oo
o`3oool00`3oool506IVIP@0oooo1000001M0?ooo`00IP3oool2000000030?ooo`000000IVIV00@0
oooo0P0000030?l200@000001@3o0P000`000000o`D00?l5000300000080o`8000<000000?l4003o
10000`3o1004000000X0oooo00<0IVIV0?ooo`1VIVH00`1VIVH50?ooo`@00000H@3oool006P0oooo
00@000000?ooo`3oool0IVIV1@3oool3000000<0o`400P0000030?l200@000001@3o0P000`000000
o`@00?l40003000000`0oooo101VIVH40?ooo`D00000I@3oool006T0oooo0P0000000`3oool0IVIV
0?ooo`040?ooo`8000000`3o0@05000000<0o`400P0000030?l200@000002P3oool506IVIP80oooo
00<0IVIV0?ooo`0000000`00001Z0?ooo`00GP3oool5000000P0oooo0P00000206IVIPD0oooo0`00
00030?l0008000000`3o0@05000000X0oooo101VIVH50?ooo`@00000KP3oool00600oooo00<00000
0?ooo`3oool02@3oool010000000oooo0?ooo`1VIVH40?ooo`0306IVIP000000000000<0o`001@00
000;0?ooo`@0IVIV103oool500000780oooo001P0?ooo`030000003oool0oooo00X0oooo0P000000
0`3oool0IVIV06IVIP020?ooo`0306IVIP3oool0000000<00000303oool406IVIP@0oooo1000001g
0?ooo`00H03oool00`000000oooo0?ooo`0<0?ooo`80000000H0oooo06IVIP3oool0IVIV0?ooo`00
00020?ooo`0306IVIP3oool0oooo00D0oooo1@1VIVH40?ooo`@00000N`3oool00600oooo00<00000
0?ooo`3oool03@3oool2000000050?ooo`1VIVH0IVIV0?ooo`0000000P3oool0101VIVH0oooo0?oo
o`3oool406IVIPD0oooo1000001o0?ooo`00G`3oool200000140oooo00D000000?ooo`000000IVIV
000000020?ooo`@0IVIV103oool5000008<0oooo001c0?ooo`80000000<0oooo0000001VIVH00P1V
IVH30?ooo`@00000R03oool007@0oooo0`0000020?ooo`@00000S03oool007H0oooo0`00002@0?oo
o`00o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?oo
o`00LP3oool4000009<0oooo001b0?ooo`030000003oool0oooo09@0oooo001c0?ooo`030000003o
ool0oooo09<0oooo001d0?ooo`030000003oool0oooo0980oooo001b0?ooo`040000003oool0oooo
000009<0oooo001c0?ooo`800000U03oool00001\
\>"],
  ImageRangeCache->{{{0, 264.313}, {286.938, 0}} -> {-0.0257265, -0.0389943, \
0.00352594, 0.00352594}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{528, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 64, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1843, 56, 394, 13, 50, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 735839, 29699}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 64, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1843, 56, 394, 13, 50, "Usage",
  CellTags->"Function?"],
Cell[2240, 71, 52, 0, 41, "MathCaption"],
Cell[2295, 73, 172, 3, 58, "MathCaption"],
Cell[2470, 78, 141, 4, 41, "MathCaption"],
Cell[2614, 84, 93, 2, 41, "MathCaption"],
Cell[2710, 88, 154, 6, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[2889, 98, 33, 0, 39, "ExampleSection"],
Cell[2925, 100, 166, 3, 49, "Input"],
Cell[3094, 105, 355, 6, 76, "Text"],

Cell[CellGroupData[{
Cell[3474, 115, 354, 6, 97, "Input"],
Cell[3831, 123, 324168, 11988, 236, 208211, 10551, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[328014, 12114, 187, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[328226, 12122, 888, 15, 256, "Input"],
Cell[329117, 12139, 386, 6, 50, "Message"],
Cell[329506, 12147, 405607, 17529, 294, 254783, 15662, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

