(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7524,        219]*)
(*NotebookOutlinePosition[      8420,        251]*)
(*  CellTagsIndexPosition[      8346,        245]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DrawingTransform", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["DrawingTransform",
          "MR"], 
        StyleBox["[",
          "MR"], \(f1, f2\), "]"}]]],
  ", where f1 and f2 are function names of two variables, is a rule that \
transforms primitive graphics by transforming the location specification \
points in specific commands."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "Usage is ",
  Cell[BoxData[
      \(graphics /. DrawingTransform[f1, f2]\)]]
}], "MathCaption"],

Cell[TextData[{
  "The transformation rule for the points is ",
  Cell[BoxData[
      \({x_?NumericQ, y_?NumericQ} \[Rule] {f1[x, y], f2[x, y]}\)]],
  "."
}], "MathCaption"],

Cell["f1 and f2 are usually pure functions.", "MathCaption"],

Cell["\<\
DrawingTransform works on graphics built up from Points, Lines, Polygons, \
Text, Circle, Disk, Rectangle, Raster and RasterArray.\
\>", "MathCaption"],

Cell[TextData[{
  "For Circle, Disk, Rectangle, Raster and RasterArray only the location of \
the objects is changed. Circles will still be circles and Rasters will still \
be rectangular. For a more general transformation of these objects first use \
",
  ButtonBox["ToPointPrimitives",
    ButtonData:>{"ToPointPrimitives"},
    ButtonStyle->"AddOnsLink"],
  " to convert them to Line and Polygon primitives."
}], "MathCaption"],

Cell[TextData[{
  "For Spline objects first use the routine ",
  ButtonBox["SplineToLine",
    ButtonData:>{"SplineToLine"},
    ButtonStyle->"AddOnsLink"],
  " to convert to Line objects."
}], "MathCaption"],

Cell[TextData[{
  "DrawingTransform can be used to convert rectangular ContourPlots to \
circular or other shaped plots. See the example in ",
  ButtonBox["FineGrainPolygons",
    ButtonData:>{"FineGrainPolygons"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell["\<\
It may be necessary to fine grain any polygons or fine grain points in a Line \
to obtain smooth transformations. Think of the points as the \"hinges\" where \
the Line can be bent.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["FineGrainPoints",
    ButtonData:>{"FineGrainPoints"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FineGrainLines",
    ButtonData:>{"FineGrainLines"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["FineGrainPolygons",
    ButtonData:>{"FineGrainPolygons"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToPointPrimitives",
    ButtonData:>{"ToPointPrimitives"},
    ButtonStyle->"AddOnsLink"],
  " ."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
This does a FilledPlot between two curves in the \[Theta]-r plane. \
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{FilledDraw[{1, 
              2 + Cos[2  \[Theta]]}, \ {\[Theta], 0, \ 2  \[Pi]}, 
            Fills \[Rule] Cadet]}, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]AxesLabel \[Rule] {\[Theta], 
            r}];\)\)], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
We really want a filled plot of the curves in the x-y plane. We couldn't \
easily obtain it directly, but we can transform from the \[Theta]-r plane to \
the x-y plane using DrawingTransform. Notice that in the plot above all \
points had \[Theta] as the first coordinate and r as the second coordinate.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{FilledDraw[{1, 
                2 + Cos[2  \[Theta]]}, \ {\[Theta], 0, \ 2  \[Pi]}, 
              Fills \[Rule] Cadet, PlotPoints \[Rule] 75] /. 
            DrawingTransform[#2\ Cos[#1] &, #2\ Sin[#1] &]}, \
\[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Background \[Rule] 
          Melon];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[TextData[{
  "The following illustrates the transformation of all the primitives. The \
objects in the lower row are shifted up and to the right. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a slight rendering error for Raster and RasterArray."
}], "Text"],

Cell[BoxData[
    \(\(Module[{g}, \
\[IndentingNewLine]Draw2D[\[IndentingNewLine]{AbsolutePointSize[4], 
            LightCoral, \[IndentingNewLine]\[IndentingNewLine]g = {Polygon[{{\
\(-1\), \(-1\)}, {1, \(-1\)}, {1, 1}, {\(-1\), 
                      1}}], \[IndentingNewLine]Raster[
                  Table[i\ j, {i, 0, 10}, {j, 0, 10}], {{1, \(-1\)}, {3, 
                      1}}, {0, 100}], \[IndentingNewLine]RasterArray[
                  Table[\(ColorMix[
                        TurquoiseBlue, \(ColorMix[Magenta, AureolineYellow]\)[
                          j/10]]\)[i/10], {i, 0, 10}, {j, 0, 
                      10}], {{3, \(-1\)}, {5, 
                      1}}], \[IndentingNewLine]Rectangle[{3/2, \(-1\)/2}, {5/
                      2, 1/2}], \[IndentingNewLine]Black, \
\[IndentingNewLine]Line[{{\(-1\), 
                      1}, {1, \(-1\)}}], \[IndentingNewLine]Text["\<X\>", \
{0.5, 0.5}, {\(-1\), \(-1\)}], \[IndentingNewLine]LightSeaGreen, 
                Disk[{0, 0}, 1/2], \[IndentingNewLine]Black, 
                Circle[{0, 0}, 1/2], 
                Point[{0, 
                    0}]\[IndentingNewLine]}, \[IndentingNewLine]\
\[IndentingNewLine]Peacock, \[IndentingNewLine]g /. 
              DrawingTransform[#1 + 2 &, #2 + 
                    2 &]}, \[IndentingNewLine]\[IndentingNewLine]AspectRatio \
\[Rule] Automatic, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]ImageSize \[Rule] 500]];\)\)], "Input",
  CellLabel->"In[4]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{602, 712},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 63, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1842, 56, 406, 12, 50, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 8175, 236}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 63, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1842, 56, 406, 12, 50, "Usage",
  CellTags->"Function?"],
Cell[2251, 70, 114, 4, 41, "MathCaption"],
Cell[2368, 76, 173, 5, 58, "MathCaption"],
Cell[2544, 83, 60, 0, 41, "MathCaption"],
Cell[2607, 85, 161, 3, 58, "MathCaption"],
Cell[2771, 90, 430, 9, 75, "MathCaption"],
Cell[3204, 101, 208, 6, 41, "MathCaption"],
Cell[3415, 109, 271, 7, 58, "MathCaption"],
Cell[3689, 118, 212, 4, 58, "MathCaption"],
Cell[3904, 124, 488, 18, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[4417, 146, 34, 0, 39, "ExampleSection"],
Cell[4454, 148, 97, 2, 29, "Input"],
Cell[4554, 152, 91, 2, 25, "Text"],
Cell[4648, 156, 320, 6, 89, "Input"],
Cell[4971, 164, 327, 5, 59, "Text"],
Cell[5301, 171, 415, 8, 109, "Input"],
Cell[5719, 181, 279, 6, 42, "Text"],
Cell[6001, 189, 1495, 26, 469, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

