(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5683,        151]*)
(*NotebookOutlinePosition[      6362,        174]*)
(*  CellTagsIndexPosition[      6318,        170]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Curve With Asymptotes", "Title"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input"],

Cell[CellGroupData[{

Cell["Curve With Asymptotes", "Subsection"],

Cell[TextData[{
  "We draw the curve ",
  Cell[BoxData[
      \(y \[Equal] \(x\^3 + 1\)\/x\)]],
  " and its asymptotic curves."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(x\^3 + 1\)\/x // Apart\)], "Input"],

Cell[BoxData[
    \(1\/x + x\^2\)], "Output"]
}, Open  ]],

Cell["\<\
Each branch of a curve is separately drawn so as to avoid the unwanted return \
line.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Blue, \[IndentingNewLine]Draw[\(x\^3 + 1\)\
\/x, {x, \(-4\), 0}], \[IndentingNewLine]Draw[\(x\^3 + 1\)\/x, {x, 0, 
              4}], \[IndentingNewLine]EnglishRed, 
          Draw[x\^2, {x, \(-4\), 4}], \[IndentingNewLine]Draw[
            1\/x, {x, \(-4\), 0}], \[IndentingNewLine]Draw[
            1\/x, {x, 0, 
              4}], \[IndentingNewLine]Black, \[IndentingNewLine]Text[
            y == x\^2, {0.213994, \(-0.306352\)}], \[IndentingNewLine]Text[
            y == 1\/x, {2.6988, 0.801006}], \[IndentingNewLine]Text[
            y == 1\/x, {\(-3.1621\), \(-0.981571\)}]}, \
\[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]PlotRange \[Rule] {{\(-4.001\), 
              4}, {\(-4.001\), 8}}, \[IndentingNewLine]Background \[Rule] 
          Smoke, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {x, y}, 
        PlotLabel \[Rule] \*"\"\<y \[Equal] (\!\(x\^3\)+1)/x and Its \
Asymptotes\>\"", 
        TextStyle \[Rule] {FontSize \[Rule] 12, 
            FontWeight \[Rule] "\<Bold\>"}, 
        ImageSize \[Rule] {400, 500}];\)\)], "Input",
  GeneratedCell->False],

Cell["\<\
Nice plots are almost always developed in stages. With this plot, I drew the \
curves first and then clicked off good positions for the labeling of each \
curve. To do this, click on the plot. Then hold down Ctrl, position the \
cursor to the position you want and click. Then use Copy (from the Edit menu, \
or from the right click context menu.) Then paste the point coordinates into \
the desired position in the Show statement.\
\>", "Text"],

Cell[TextData[{
  "In the plot above, the return lines at ",
  Cell[BoxData[
      \(x \[Equal] 0\)]],
  " were eliminated by drawing two of the functions over two separate ranges. \
A second method for eliminating the return lines is to draw each of the \
functions over a single interval that includes the return line, and then use \
",
  ButtonBox["SplitLineOnVertical",
    ButtonData:>{"SplitLineOnVertical"},
    ButtonStyle->"AddOnsLink"],
  " to eliminate the return line. SplitLineOnVertical will break any line \
into two lines whenever a vertical jump between two points exceeds the \
specified value. Other variations are SplitLineOnDistance and \
SplitLineOnSlope."
}], "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Blue, 
          Draw[\(x\^3 + 1\)\/x, {x, \(-4\), 
                4}] /. \[InvisibleSpace]SplitLineOnVertical[8], 
          EnglishRed, \[IndentingNewLine]Draw[x\^2, {x, \(-4\), 4}], 
          Draw[1\/x, {x, \(-4\), 4}] /. \[InvisibleSpace]SplitLineOnVertical[
              8], \[IndentingNewLine]Black, 
          Text[y == x\^2, {0.213994, \(-0.306352\)}], \[IndentingNewLine]Text[
            y == 1\/x, {2.6988, 0.801006}], \[IndentingNewLine]Text[
            y == 1\/x, {\(-3.1621\), \(-0.981571\)}]}, \
\[IndentingNewLine]AspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] {{\(-4.001\), 4}, {\(-4.001\), 8}}, 
        Background \[Rule] Smoke, Frame \[Rule] True, 
        FrameLabel \[Rule] {x, y}, 
        PlotLabel \[Rule] \*"\"\<y \[Equal] (\!\(x\^3\)+1)/x and Its \
Asymptotes\>\"", 
        TextStyle \[Rule] {FontSize \[Rule] 12, 
            FontWeight \[Rule] "\<Bold\>"}, 
        ImageSize \[Rule] {400, 500}];\)\)], "Input",
  GeneratedCell->False]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
WindowSize->{580, 732},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 38, 0, 67, "Title"],
Cell[1746, 52, 73, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[1844, 57, 43, 0, 52, "Subsection"],
Cell[1890, 59, 139, 5, 33, "Text"],

Cell[CellGroupData[{
Cell[2054, 68, 57, 1, 65, "Input"],
Cell[2114, 71, 45, 1, 62, "Output"]
}, Open  ]],
Cell[2174, 75, 109, 3, 29, "Text"],
Cell[2286, 80, 1198, 21, 505, "Input"],
Cell[3487, 103, 455, 7, 86, "Text"],
Cell[3945, 112, 690, 15, 105, "Text"],
Cell[4638, 129, 1029, 19, 353, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

