(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10058,        232]*)
(*NotebookOutlinePosition[     10747,        256]*)
(*  CellTagsIndexPosition[     10703,        252]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Figure Eight Curve with Curvature", "Title"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input"],

Cell[CellGroupData[{

Cell["Figure Eight Curve and Curvature", "Subsection"],

Cell["\<\
In this example it may help to use the Hide Categories button at the top of \
Help and to enlarge the window frame to full size to obtain a good view of \
the graphics.\
\>", "Text"],

Cell[TextData[{
  "We wish to show the relation between a parametric curve, the curvature at \
any point on the curve and the rate of turning of the unit tangent vector to \
the curve. The example is taken from Alfred Gray, ",
  StyleBox["Modern Differential Geometry of Curves and Surfaces with \
Mathematica",
    FontSlant->"Italic"],
  ". The following statements define a figure eight curve, the J operator \
which rotates a vector by 90\[Degree] and the curvature of a plane curve."
}], "Text"],

Cell[BoxData[{
    \(eight[t_] := {Sin[t], Sin[t] Cos[t]}\), "\n", 
    \(J[{p1_, p2_}] := {\(-p2\), p1}\), "\n", 
    \(\(\[Kappa][\[Alpha]_]\)[
        t_] := \(\[Alpha]''\)[t] . J[\(\[Alpha]'\)[t]]\/\((\(\[Alpha]'\)[t] . \
\(\[Alpha]'\)[t])\)\^\(3/2\)\)}], "Input"],

Cell["The curvature of a figure eight curve is given by...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[Kappa][eight]\)[t]\)], "Input"],

Cell[BoxData[
    \(\(\(-4\)\ Cos[t]\^2\ Sin[t] - Sin[t]\ \((\(-Cos[t]\^2\) + \
Sin[t]\^2)\)\)\/\((Cos[t]\^2 + \((Cos[t]\^2 - Sin[t]\^2)\)\^2)\)\^\(3/2\)\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "We are going to show the relationship between curvature and the turning of \
the velocity tangent vector by putting three graphs on one piece of paper. \
The first graph will show the figure eight curve with a tangent vector at a \
point. The unit tangent vector is shown at 1/3 scale so it will fit nicely on \
the graph. The second graph will show the curvature as a function of the \
parametric parameter. The third graph will show the tangent vector moved to \
the origin. The three graphs are defined by laying down rectangles on the \
paper, and then inserting graphics in the rectangles using the DontShow \
statement from DrawingPaper. The DontShow statement simply turns off the side \
plot that would normally be produced with a Show statement. It is a shorthand \
method for inserting the ",
  Cell[BoxData[
      \(DisplayFunction \[Rule] Identity\)]],
  " statement that would normally be required. Descriptive labels are added \
under each graph. The graphics were developed with many re-evaluations. First \
I laid out the rectangles. Then I developed and fine-tuned each of the \
separate plots. The first  plot is done for a specific value of the curve \
parameter, t0."
}], "Text"],

Cell[BoxData[{\(t0 = 0;\), "\n", 
    RowBox[{
      RowBox[{"vec", "=", 
        RowBox[{
          SuperscriptBox["eight", "\[Prime]",
            MultilineFunction->None], "[", "t0", "]"}]}], 
      ";", \(vec = vec\/\(\@\(vec . vec\)\ 3\)\), 
      ";"}], "\n", \(Draw2D[{Rectangle[{1, 4.5}, {6, 7.5}, 
            DontShow[
              Graphics[{Blue, 
                  ParametricDraw[Evaluate[eight[tt]], {tt, 0, 2\ \[Pi]}], 
                  AbsolutePointSize[5], Black, Point[eight[t0]], Red, 
                  Arrow[eight[t0], eight[t0] + vec, 
                    HeadCenter \[Rule] 1\/2]}], 
              AspectRatio \[Rule] Automatic, 
              PlotRange \[Rule] {{\(-1\), 1}, {\(-\(1\/2\)\), 
                      1\/2}}\ 1.2]], \
\[IndentingNewLine]\[IndentingNewLine]Rectangle[{0.5, 1}, {3.5, 3}, 
            DontShow[
              Graphics[{Draw[\(\[Kappa][eight]\)[tt], {tt, 0, 2\ \[Pi]}], 
                  AbsolutePointSize[5], 
                  Point[{t0, \(\[Kappa][eight]\)[t0]}]}], 
              Axes \[Rule] 
                True]], \[IndentingNewLine]\[IndentingNewLine]Rectangle[{4, 
              1}, {6.5, 3.5}, 
            DontShow[
              Graphics[{Red, Arrow[{0, 0}, vec, HeadCenter \[Rule] 1\/2], 
                  Black, AbsolutePointSize[5], Point[{0, 0}]}], 
              AspectRatio \[Rule] Automatic, Axes \[Rule] True, 
              Ticks \[Rule] None, 
              PlotRange \[Rule] 1\/3\ {{\(-1\), 1}, {\(-1\), 1}}]], 
          Text["\<Point Trajectory and Tangent Vector\>", {3.5, 4.25}], 
          Text["\<Curvature at Point\>", {2, 0.7}], 
          Text["\<Turning of Tangent Vector\>", {5.5, 0.7}]}, 
        AspectRatio \[Rule] Automatic, PlotRange \[Rule] {{0, 7}, {0, 8}}, 
        Background \[Rule] Linen, 
        ImageSize \[Rule] 
          500, \[IndentingNewLine]TextStyle \[Rule] {FontSize \[Rule] 12, 
            FontWeight \[Rule] "\<Bold\>"}, \[IndentingNewLine]PlotLabel \
\[Rule] "\<\nFigure Eight Curvature\>"];\)}], "Input",
  GeneratedCell->False],

Cell["\<\
The three rectangles will be indicated if you click on the plot. Now we have \
all the elements for an animation. Just make a frame definition from the \
above code, with t0 as a parameter.\
\>", "Text"],

Cell[BoxData[
    RowBox[{\(frame[t0_]\), ":=", "\[IndentingNewLine]", 
      RowBox[{"Module", "[", 
        RowBox[{\({vec}\), ",", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"vec", "=", 
              RowBox[{
                SuperscriptBox["eight", "\[Prime]",
                  MultilineFunction->None], "[", "t0", "]"}]}], 
            ";", \(vec = vec\/\(\@\(vec . vec\)\ 3\)\), ";", 
            "\n", \(Draw2D[{Rectangle[{1, 4.5}, {6, 7.5}, 
                  DontShow[
                    Graphics[{Blue, 
                        ParametricDraw[
                          Evaluate[eight[tt]], {tt, 0, 2\ \[Pi]}], 
                        AbsolutePointSize[5], Black, Point[eight[t0]], Red, 
                        Arrow[eight[t0], eight[t0] + vec, 
                          HeadCenter \[Rule] 1\/2]}], 
                    AspectRatio \[Rule] Automatic, 
                    PlotRange \[Rule] {{\(-1\), 1}, {\(-\(1\/2\)\), 
                            1\/2}}\ 1.2]], \[IndentingNewLine]\
\[IndentingNewLine]Rectangle[{0.5, 1}, {3.5, 3}, 
                  DontShow[
                    Graphics[{Draw[\(\[Kappa][eight]\)[tt], {tt, 0, 
                            2\ \[Pi]}], AbsolutePointSize[5], 
                        Point[{t0, \(\[Kappa][eight]\)[t0]}]}], 
                    Axes \[Rule] 
                      True]], \
\[IndentingNewLine]\[IndentingNewLine]Rectangle[{4, 1}, {6.5, 3.5}, 
                  DontShow[
                    Graphics[{Red, 
                        Arrow[{0, 0}, vec, HeadCenter \[Rule] 1\/2], Black, 
                        AbsolutePointSize[5], Point[{0, 0}]}], 
                    AspectRatio \[Rule] Automatic, Axes \[Rule] True, 
                    Ticks \[Rule] None, 
                    PlotRange \[Rule] 1\/3\ {{\(-1\), 1}, {\(-1\), 1}}]], 
                Text["\<Point Trajectory and Tangent Vector\>", {3.5, 4.25}], 
                Text["\<Curvature at Point\>", {2, 0.7}], 
                Text["\<Turning of Tangent Vector\>", {5.5, 0.7}]}, 
              AspectRatio \[Rule] Automatic, 
              PlotRange \[Rule] {{0, 7}, {0, 8}}, Background \[Rule] Linen, 
              ImageSize \[Rule] 
                500, \[IndentingNewLine]TextStyle \[Rule] {FontSize \[Rule] 
                    12, FontWeight \[Rule] "\<Bold\>"}, \
\[IndentingNewLine]PlotLabel \[Rule] "\<\nFigure Eight Curvature\>"]\)}]}], 
        "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[{
    \(Animate[
      frame[t], {t, 0, 2  \[Pi], 2  \[Pi]/50}]\), "\[IndentingNewLine]", 
    \(\(SelectionMove[EvaluationNotebook[], All, 
        GeneratedCell];\)\), "\[IndentingNewLine]", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\[IndentingNewLine]", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"],

Cell["\<\
The tangent vector turns fastest where the curvature is greatest. There is \
nothing better than a three ring circus, especially when what is happening in \
one ring is intimately related to what is happening in the other two rings. \
Strictly, the animation should be done as a function of an arc-length \
parameter,s, but s is not significantly different than t in this case, and \
using t saves a great deal of numerical work.\
\>", "Text"],

Cell[BoxData[
    \(Clear[eight, J, \[Kappa], t0, vec, frame]\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
WindowSize->{604, 731},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "Classroom.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 50, 0, 67, "Title"],
Cell[1770, 51, 73, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[1868, 56, 54, 0, 52, "Subsection"],
Cell[1925, 58, 192, 4, 48, "Text"],
Cell[2120, 64, 500, 9, 86, "Text"],
Cell[2623, 75, 268, 5, 105, "Input"],
Cell[2894, 82, 68, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[2987, 86, 55, 1, 50, "Input"],
Cell[3045, 89, 169, 3, 69, "Output"]
}, Open  ]],
Cell[3229, 95, 1218, 19, 219, "Text"],
Cell[4450, 116, 2044, 40, 653, "Input"],
Cell[6497, 158, 213, 4, 48, "Text"],
Cell[6713, 164, 2446, 45, 696, "Input"],
Cell[9162, 211, 347, 6, 110, "Input"],
Cell[9512, 219, 453, 7, 86, "Text"],
Cell[9968, 228, 74, 1, 50, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

