(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14868,        335]*)
(*NotebookOutlinePosition[     15557,        359]*)
(*  CellTagsIndexPosition[     15513,        355]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["A Fancy Contour Plot", "Title"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input"],

Cell[CellGroupData[{

Cell["A Fancy Contour Plot", "Subsection"],

Cell["\<\
This example can be better observed by enlarging the Help window to full \
screen size.\
\>", "Text"],

Cell["Here is a function....", "Text"],

Cell[BoxData[
    \(f[x_, y_] := x\^2 + y\^3 - 3  x\ y\)], "Input"],

Cell["...and a regular ContourPlot of the function.", "Text"],

Cell[BoxData[
    \(\(ContourPlot[
        f[x, y], {x, \(-5\), 5}, {y, \(-5\), 
          5}, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue, \[IndentingNewLine]PlotPoints \[Rule] 
          51, \[IndentingNewLine]ImageSize \[Rule] 500];\)\)], "Input"],

Cell["\<\
It would be nice to see a little more detail in the central section. We \
switch to the DrawingPaper paradigm, and after a little experimentation come \
up with the following list of contours.\
\>", "Text"],

Cell[BoxData[{
    \(\(contours = 
        Union[Range[\(-150\), 225, 375/16], 
          Range[\(-10\), 10, 3]];\)\), "\n", 
    \(\(Draw2D[\[IndentingNewLine]{ContourDraw[
            f[x, y], {x, \(-5\), 5}, {y, \(-5\), 
              5}, \[IndentingNewLine]Contours \[Rule] 
              contours, \[IndentingNewLine]ColorFunction \[Rule] 
              Hue, \[IndentingNewLine]PlotPoints \[Rule] 
              51]}, \[IndentingNewLine]\[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 
              5}, {\(-5\), 5}}, \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            y}, \[IndentingNewLine]PlotLabel \[Rule] 
          f[x, y], \[IndentingNewLine]ImageSize \[Rule] 500];\)\)}], "Input"],

Cell["\<\
This is better, but the central region is basically all the same color. It \
would be better if the different contour regions were better distinguished in \
color or shading. ContourColors provides better differentiation. For it to \
work properly, it is also necessary to add PlotRange to the ContourDraw \
statement.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[{ContourDraw[
            f[x, y], {x, \(-5\), 5}, {y, \(-5\), 
              5}, \[IndentingNewLine]Contours \[Rule] contours, 
            ColorFunction \[Rule] \((ContourColors[#1, contours] &)\), 
            PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 5}, {First[contours], 
                  Last[contours]}}, \[IndentingNewLine]PlotPoints \[Rule] 
              51]}, \[IndentingNewLine]\[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, 
        PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 
              5}}, \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            y}, \[IndentingNewLine]PlotLabel \[Rule] 
          f[x, y], \[IndentingNewLine]ImageSize \[Rule] 500];\)\)], "Input"],

Cell["\<\
We now draw gradient vectors on top of the contour plot using \
DrawGradientField.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[{ContourDraw[
            f[x, y], {x, \(-5\), 5}, {y, \(-5\), 
              5}, \[IndentingNewLine]Contours \[Rule] contours, 
            ColorFunction \[Rule] \((ContourColors[#1, contours] &)\), 
            PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 5}, {First[contours], 
                  Last[contours]}}, \[IndentingNewLine]PlotPoints \[Rule] 
              51], \[IndentingNewLine]White, \
\[IndentingNewLine]DrawGradientField[
            f[x, y], {x, \(-4\), 4}, {y, \(-5\), 3.5}, ScaleFactor \[Rule] 2, 
            HeadCenter \[Rule] 
              0.5]}, \[IndentingNewLine]\[IndentingNewLine]AspectRatio \
\[Rule] Automatic, \[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 
              5}, {\(-5\), 5}}, Background \[Rule] Linen, 
        Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            y}, \[IndentingNewLine]PlotLabel \[Rule] 
          f[x, y], \[IndentingNewLine]ImageSize \[Rule] 500];\)\)], "Input"],

Cell[TextData[{
  "We will now add a legend to the plot. The contour plot is put into one \
Rectangle and the legend will be put into another Rectangle. The legend code \
uses the ColorFunctionScaling option for Raster. This is a new Version 4 \
feature, so the following plots will not work properly in Version 3 of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". First we create the two plots with the display suppressed."
}], "Text"],

Cell[BoxData[
    \(\(contourplot = 
        DontShow[
          Graphics[{ContourDraw[
                f[x, y], {x, \(-5\), 5}, {y, \(-5\), 
                  5}, \[IndentingNewLine]Contours \[Rule] 
                  contours, \[IndentingNewLine]ColorFunction \[Rule] \
\((ContourColors[#1, contours] &)\), 
                PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 
                      5}, {First[contours], 
                      Last[contours]}}, \[IndentingNewLine]PlotPoints \[Rule] 
                  51], \[IndentingNewLine]White, \
\[IndentingNewLine]DrawGradientField[
                f[x, y], {x, \(-4\), 4}, {y, \(-5\), 3.5}, 
                ScaleFactor \[Rule] 2, 
                HeadCenter \[Rule] 
                  0.5]}], \[IndentingNewLine]\[IndentingNewLine]AspectRatio \
\[Rule] Automatic, \[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 
                  5}, {\(-5\), 5}} 
              1.03, \[IndentingNewLine]PlotRegion \[Rule] {{0, 0.95}, {0, 
                0.98}}, \[IndentingNewLine]TextStyle \[Rule] {FontSize \
\[Rule] 12, 
              FontWeight \[Rule] "\<Bold\>"}, \[IndentingNewLine]Background \
\[Rule] Linen, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
              y}, \[IndentingNewLine]PlotLabel \[Rule] f[x, y]];\)\)], "Input"],

Cell[TextData[{
  "This is the code for the legend. The regular ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Legend command from the Legend package is not always easy to use and does \
not, in this case, quite accommodate what is desired. So we make our own \
legend using the Raster function and Text statements. One should carefully \
check the Raster documentation here. We use the extra arguments in the Raster \
function to place the raster array within our plot range, and to specify the \
minimun and maximum values, which will be used in scaling. (This is the same \
as the third range in PlotRange used in the ContourDraw command.) The \
ColorFunction is the same ContourColors command used in the ContourDraw. \
Naturally, it took a little work to develop the legend."
}], "Text"],

Cell[BoxData[
    \(\(legend = \((array2 = N[Partition[contours, 1]]; 
          DontShow[
            Graphics[{Raster[
                  array2, {{3.5, 0}, {5.5, 9}}, {First[contours], 
                    Last[contours]}, 
                  ColorFunction \[Rule] \((ContourColors[#1, contours] &)\), 
                  ColorFunctionScaling \[Rule] True], 
                Table[Text[
                    NumberForm[
                      array2\[LeftDoubleBracket]i, 
                        1\[RightDoubleBracket], {3, 
                        1}], {3.5, \(9\ \((i - 1)\)\)\/24}, {1, 0}], {i, 1, 
                    Length[array2], 2}], 
                Table[Text[
                    NumberForm[
                      array2\[LeftDoubleBracket]i, 
                        1\[RightDoubleBracket], {3, 
                        1}], {5.5, \(9\ \((i - 1)\)\)\/24}, {\(-1\), 0}], {i, 
                    2, Length[array2], 2}], 
                Text["\<Contour Values\>", {4.5, 9.5}], 
                Table[Line[{{3.5, \(i\ 9\)\/24}, {5.5, \(i\ 9\)\/24}}], {i, 
                    0, Length[array2]}]}], 
            AspectRatio \[Rule] 
              Automatic, \[IndentingNewLine]PlotRange \[Rule] {{1.5, 
                  7.5}, {\(-1\), 
                  11}}, \[IndentingNewLine]TextStyle \[Rule] {FontSize \
\[Rule] 12, 
                FontWeight \[Rule] "\<Bold\>"}, \[IndentingNewLine]Background \
\[Rule] Linen\[IndentingNewLine]])\);\)\)], "Input",
  GeneratedCell->False],

Cell["The contour plot and legend are now combined in one plot.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Rectangle[{0, 0}, {5, 5}, 
            contourplot], \[IndentingNewLine]Rectangle[{5, 0}, {6.9, 5}, 
            legend]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]PlotRange \[Rule] {{0, 7}, {0, 
              5.2}}, \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 600];\)\)], "Input",
  GeneratedCell->False],

Cell["\<\
It might be nicer to have a grid on the contour plot. We eliminate the \
gradient vector field to keep the graphics simple. The easiest way to color \
the grid lines is to use CustomGridLines. \
\>", "Text"],

Cell[BoxData[
    \(\(contourplot2 = 
        DontShow[
          Graphics[{ContourDraw[f[x, y], {x, \(-5\), 5}, {y, \(-5\), 5}, 
                Contours \[Rule] contours, 
                ColorFunction \[Rule] \((ContourColors[#1, contours] &)\), 
                PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 
                      5}, {First[contours], Last[contours]}}, 
                PlotPoints \[Rule] 
                  51]}], \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 
                  5}, {\(-5\), 5}} 
              1.03, \[IndentingNewLine]PlotRegion \[Rule] {{0, 0.95}, {0, 
                0.98}}, \[IndentingNewLine]TextStyle \[Rule] {FontSize \
\[Rule] 12, 
              FontWeight \[Rule] "\<Bold\>"}, \[IndentingNewLine]Background \
\[Rule] Linen, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
              y}, \[IndentingNewLine]PlotLabel \[Rule] f[x, y], 
          GridLines \[Rule] {CustomGridLines[#1 &, {\(-4\), 4, 
                  2}, {LightBeige}], 
              CustomGridLines[#1 &, {\(-4\), 4, 
                  2}, {LightBeige}]}, \[IndentingNewLine]AxesFront \[Rule] 
            True];\)\)], "Input"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Rectangle[{0, 0}, {5, 5}, 
            contourplot2], \[IndentingNewLine]Rectangle[{5, 0}, {6.9, 5}, 
            legend]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]PlotRange \[Rule] {{0, 7}, {0, 
              5.2}}, \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 600];\)\)], "Input",
  GeneratedCell->False],

Cell[TextData[{
  "Instead of having a legend we may just wish to label the contour lines. \
This can be done using the ",
  ButtonBox["DrawLineLabels",
    ButtonData:>{"DrawLineLabels"},
    ButtonStyle->"AddOnsLink"],
  " routine. Here we first generate the contour graphics and save the graphic \
primitives in grafprimitives. We then apply DrawLineLabels to grafprimitives. \
We supply the function f, defined above, which will calculate the value of a \
contour when applied to a point on the contour; and a positioning function, \
",
  Cell[BoxData[
      \(Random[Real, {0.3, 0.7}] &\)]],
  ", which will generate random positions for the labels somewhere in the \
middle section of each line. The DrawLLFormat option provides a formatting \
function for the label value. The option DrawLLTextOptions provides options \
for the Text statements that display each label value. In this case I put the \
label on a LightBlue background in a IndianRed size 10 font."
}], "Text"],

Cell[BoxData[
    \(\(Module[{grafprimitives}, 
        Draw2D[{grafprimitives = 
              ContourDraw[f[x, y], {x, \(-5\), 5}, {y, \(-5\), 5}, 
                Contours \[Rule] contours, 
                ColorFunction \[Rule] \((ContourColors[#1, contours] &)\), 
                PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 
                      5}, {First[contours], Last[contours]}}, 
                PlotPoints \[Rule] 51], 
            grafprimitives // 
              DrawLineLabels[f, Random[Real, {0.3, 0.7}] &, 
                DrawLLFormat \[Rule] Round, 
                DrawLLTextOptions \[Rule] {Background \[Rule] LightBlue, 
                    TextStyle \[Rule] {FontSize \[Rule] 10, 
                        FontColor \[Rule] 
                          IndianRed}}]}, \[IndentingNewLine]\
\[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 
                  5}, {\(-5\), 5}} 
              1.03, \[IndentingNewLine]PlotRegion \[Rule] {{0, 0.95}, {0, 
                0.98}}, \[IndentingNewLine]TextStyle \[Rule] {FontSize \
\[Rule] 12, 
              FontWeight \[Rule] "\<Bold\>"}, \[IndentingNewLine]Background \
\[Rule] Linen, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
              y}, \[IndentingNewLine]PlotLabel \[Rule] 
            f[x, y], \[IndentingNewLine]ImageSize \[Rule] 600]];\)\)], "Input"],

Cell[BoxData[
    \(Clear[f, contours, contourplot, contourplot2, legend]\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
WindowSize->{743, 710},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "Classroom.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 37, 0, 67, "Title"],
Cell[1757, 51, 73, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[1855, 56, 42, 0, 52, "Subsection"],
Cell[1900, 58, 111, 3, 29, "Text"],
Cell[2014, 63, 38, 0, 29, "Text"],
Cell[2055, 65, 67, 1, 50, "Input"],
Cell[2125, 68, 61, 0, 29, "Text"],
Cell[2189, 70, 262, 5, 110, "Input"],
Cell[2454, 77, 216, 4, 48, "Text"],
Cell[2673, 83, 863, 15, 310, "Input"],
Cell[3539, 100, 342, 6, 67, "Text"],
Cell[3884, 108, 830, 14, 250, "Input"],
Cell[4717, 124, 106, 3, 29, "Text"],
Cell[4826, 129, 988, 17, 270, "Input"],
Cell[5817, 148, 448, 8, 67, "Text"],
Cell[6268, 158, 1326, 25, 370, "Input"],
Cell[7597, 185, 804, 13, 124, "Text"],
Cell[8404, 200, 1489, 30, 368, "Input"],
Cell[9896, 232, 73, 0, 29, "Text"],
Cell[9972, 234, 442, 7, 170, "Input"],
Cell[10417, 243, 217, 4, 48, "Text"],
Cell[10637, 249, 1253, 23, 350, "Input"],
Cell[11893, 274, 443, 7, 170, "Input"],
Cell[12339, 283, 981, 18, 124, "Text"],
Cell[13323, 303, 1440, 26, 390, "Input"],
Cell[14766, 331, 86, 1, 50, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

