(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1009689,      16378]*)
(*NotebookOutlinePosition[   1010368,      16401]*)
(*  CellTagsIndexPosition[   1010324,      16397]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["The Gently Turning Curve of Maria Agnesi", "Title"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input"],

Cell[CellGroupData[{

Cell["The Gently Turning Curve of Maria Agnesi", "Subsection"],

Cell["\<\
A nice piece of graphics often involves a rather long Show statement to \
generate all of its parts. Sometimes we would prefer to hide the generating \
statement. This can be done by selecting the cell and closing it. Use the \
menu item Cell/Cell Properties/Cell Open, or the keystrokes Alt-C R C. (This \
is not the same as opening and closing a cell group.) A closed cell shows as \
a thin bracket on the right hand side. A closed cell can be evaluated. All of \
the graphic production cells in this example are closed up to show how \
graphics and exposition can be nicely mixed. Evaluate the following closed \
cell to see the defining properties of a curve studied by the mathematician \
Maria Gaetana Agnesi.\
\>", "Text"],

Cell[BoxData[{
    \(\(a0 = 3;\)\), "\[IndentingNewLine]", 
    \(\(x0 = 5;\)\), "\[IndentingNewLine]", 
    \(\(Show[
        Graphics[\n\t{Peru, 
            Circle[{0, a0}, 
              a0], \[IndentingNewLine]Line[{{\(-10\), 2  a0}, {10, 
                  2  a0}}], \[IndentingNewLine]Black, 
            Line[{{0, 0}, {x0, 2  a0}}], Line[{{x0, 0}, {x0, 2  a0}}], 
            Line[{{\(4\ a0\^2\ x0\)\/\(4\ a0\^2 + x0\^2\), \(8\ a0\^3\)\/\(4\ \
a0\^2 + x0\^2\)}, {x0, \(8\ a0\^3\)\/\(4\ a0\^2 + x0\^2\)}}], 
            Line[{{0, 0}, {0, 2  a0}}], \[IndentingNewLine]AbsolutePointSize[
              5], Point[{0, a0}], Point[{x0, 2  a0}], 
            Point[{\(4\ a0\^2\ x0\)\/\(4\ a0\^2 + x0\^2\), \(8\ a0\^3\)\/\(4\ \
a0\^2 + x0\^2\)}], 
            Point[{x0, \(8\ a0\^3\)\/\(4\ a0\^2 + x0\^2\)}], \
\[IndentingNewLine]Text["\<A\>", {x0, 2  a0}, {0, \(-1\)}], 
            Text["\<C\>", {0, a0}, {1.5, 0}], 
            Text["\<Q\>", {\(4\ a0\^2\ x0\)\/\(4\ a0\^2 + x0\^2\), \(8\ a0\^3\
\)\/\(4\ a0\^2 + x0\^2\)}, {1.5, 0}], 
            Text["\<P(x,y)\>", {x0, \(8\ a0\^3\)\/\(4\ a0\^2 + x0\^2\)}, \
{\(-1.5\), 0}], Text["\<a\>", {0, a0/2}, {1.5, 0}], 
            Text["\<x\>", {x0/2, 0}, {0, 1.5}], 
            Text["\<y\>", {x0, \(4\ a0\^3\)\/\(4\ a0\^2 + x0\^2\)}, \
{\(-1.5\), 
                0}], \[IndentingNewLine]Text["\<Definition of the Gently \
Turning Curve of Maria Agnesi\>", {0, 2.5  a0}]}], \n\n
        AspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] {{\(-3\), 3} a0, {\(-0.3\), 3} a0}, 
        Background \[Rule] Linen, \n{Axes \[Rule] {True, False}, 
          Ticks \[Rule] None, 
          TextStyle \[Rule] {FontFamily \[Rule] "\<Helvetica\>", 
              FontSize \[Rule] 12, FontWeight \[Rule] "\<Bold\>"}, 
          ImageSize \[Rule] 500}];\)\)}], "Input",
  CellOpen->False,
  GeneratedCell->False],

Cell[TextData[{
  "We draw a circle of radius a, tangent to the x-axis at the origin. We draw \
another tangent at the top of the circle. A point ",
  Cell[BoxData[
      \(P[x, y]\)]],
  " on Agnesi's curve is obtained by first drawing a vertical at x, which \
intersects the top tangent at point A. We then draw a line from the origin to \
A, which intersects the circle at point Q. The coordinate y is then defined \
to be the y coordinate of Q. Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", we can easily solve for y as a function of x. The circle coordinates \
will be called xx and y."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eqns = {xx\^2 + \((y - a)\)\^2 \[Equal] a\^2, 
        y \[Equal] \((2  a/x)\)\ xx}\)], "Input"],

Cell[BoxData[
    \({xx\^2 + \((\(-a\) + y)\)\^2 \[Equal] a\^2, 
      y \[Equal] \(2\ a\ xx\)\/x}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ysols = Solve[eqns, y, xx]\)], "Input"],

Cell[BoxData[
    \({{y \[Rule] 
          0}, {y \[Rule] \(8\ a\^3\)\/\(4\ a\^2 + x\^2\)}}\)], "Output"]
}, Open  ]],

Cell["\<\
We can then parametrize Agnesi's curve using x as the parameter...\
\>", "Text"],

Cell[BoxData[
    \(\(agnesi[a_]\)[x_] := {x, \(8\ a\^3\)\/\(4\ a\^2 + x\^2\)}\)], "Input"],

Cell["\<\
...and draw a new graphic with the curve, but without the point labeling.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a0 = 3;\)\), "\[IndentingNewLine]", 
    \(\(x0 = 5;\)\), "\[IndentingNewLine]", 
    \(\(Show[
        Graphics[\n\t{Peru, 
            Circle[{0, a0}, 
              a0], \[IndentingNewLine]Line[{{\(-10\), 2  a0}, {10, 
                  2  a0}}], \[IndentingNewLine]Blue, 
            ParametricDraw[\(agnesi[a0]\)[x] // Evaluate, {x, \(-3\) a0, 
                3  a0}], \[IndentingNewLine]Black, 
            Line[{{0, 0}, {x0, 2  a0}}], Line[{{x0, 0}, {x0, 2  a0}}], 
            Line[{{\(4\ a0\^2\ x0\)\/\(4\ a0\^2 + x0\^2\), \(8\ a0\^3\)\/\(4\ \
a0\^2 + x0\^2\)}, {x0, \(8\ a0\^3\)\/\(4\ a0\^2 + x0\^2\)}}], 
            Line[{{0, 0}, {0, 2  a0}}], \[IndentingNewLine]AbsolutePointSize[
              5], Point[{0, a0}], Point[{x0, 2  a0}], 
            Point[{\(4\ a0\^2\ x0\)\/\(4\ a0\^2 + x0\^2\), \(8\ a0\^3\)\/\(4\ \
a0\^2 + x0\^2\)}], 
            Point[{x0, \(8\ a0\^3\)\/\(4\ a0\^2 + x0\^2\)}], \
\[IndentingNewLine]Text["\<The Gently Turning Curve of Maria Agnesi\>", {0, 
                2.5  a0}]}], \n\nAspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] {{\(-3\), 3} a0, {\(-0.3\), 3} a0}, 
        Background \[Rule] Linen, \n{Axes \[Rule] {True, False}, 
          Ticks \[Rule] None, 
          TextStyle \[Rule] {FontFamily \[Rule] "\<Helvetica\>", 
              FontSize \[Rule] 12, FontWeight \[Rule] "\<Bold\>"}, 
          ImageSize \[Rule] 500}];\)\)}], "Input",
  GeneratedCell->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.77778 .38333 L
s
.77778 .05 m
.77778 .38333 L
s
.66393 .24672 m
.77778 .24672 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.77778 .38333 Mdot
.66393 .24672 Mdot
.77778 .24672 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V2P3=QCl20?[`iP80000000<0n_3V0<f5
?`3=QCl0203=QCmm0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00>L0n_3V1P3=QCl<0?[`iP03
0000003jl>H0000000X0n_3V1`3=QCmf0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00>D0n_3V
0P3=QClB0?[`iP030000003jl>H000000140n_3V0P3=QCmd0?[`iP030000003jl>H0n_3V06d0n_3V
0@3oool00>40n_3V103=QClD0?[`iP040000003jl>H0n_3V00000180n_3V0`3=QCma0?[`iP030000
003jl>H0n_3V06d0n_3V0@3oool00=d0n_3V103=QClH0?[`iP050000003jl>H0n_3V0?[`iP000000
503jl>H40<f5?fd0n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00f`3jl>H20<f5?a`0n_3V00<0
00000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0E0?[`iP80cHDoJ`3jl>H00`000000n_3V0?[`
iP1]0?[`iP40oooo003I0?[`iP80cHDo7P3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0
n_3V01H0n_3V0P3=QCmY0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00=L0n_3V0P3=QClP0?[`
iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H05`3jl>H20<f5?fL0n_3V00<000000?[`
iP3jl>H0K@3jl>H10?ooo`00e@3jl>H20<f5?b80n_3V00<000000?[`iP3jl>H0103jl>H00`000000
n_3V0?[`iP0I0?[`iP80cHDoI@3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo003C0?[`iP80cHDo
903jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V01X0n_3V0P3=QCmS0?[`iP030000
003jl>H0n_3V06d0n_3V0@3oool00=40n_3V0P3=QClV0?[`iP030000003jl>H0n_3V00H0n_3V00<0
00000?[`iP3jl>H06`3jl>H20<f5?f40n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00c`3jl>H2
0<f5?bP0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0L0?[`iP80cHDoG`3jl>H0
0`000000n_3V0?[`iP1]0?[`iP40oooo003>0?[`iP030<f5?`3jl>H0n_3V02P0n_3V00<000000?[`
iP3jl>H0203jl>H00`000000n_3V0?[`iP0M0?[`iP030<f5?`3jl>H0n_3V05`0n_3V00<000000?[`
iP3jl>H0K@3jl>H10?ooo`00c03jl>H20<f5?b/0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000
n_3V0?[`iP0M0?[`iP80cHDoG03jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo003:0?[`iP80cHDo
;@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V01l0n_3V0P3=QCmJ0?[`iP030000
003jl>H0n_3V06d0n_3V0@3oool00<T0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`
iP0:0?[`iP030000003jl>H0n_3V0200n_3V00<0cHDo0?[`iP3jl>H0E`3jl>H00`000000n_3V0?[`
iP1]0?[`iP40oooo00370?[`iP80cHDo<03jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0
n_3V0200n_3V0P3=QCmG0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00<H0n_3V00<0cHDo0?[`
iP3jl>H0<03jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V0240n_3V00<0cHDo0?[`
iP3jl>H0E03jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo00350?[`iP030<f5?`3jl>H0n_3V0340
n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V05<0
n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00a03jl>H00`3=QCl0n_3V0?[`iP0b0?[`iP030000
003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H08@3jl>H00`3=QCl0n_3V0?[`iP1B0?[`iP030000
003jl>H0n_3V06d0n_3V0@3oool00<80n_3V0P3=QCle0?[`iP030000003jl>H0n_3V00h0n_3V00<0
00000?[`iP3jl>H08P3jl>H20<f5?e80n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00`@3jl>H0
0`3=QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H08P3jl>H0
0`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00<00n_3V00<0cHDo0?[`
iP3jl>H0=P3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V0280n_3V00<0cHDo0?[`
iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo002o0?[`iP030<f5?`3jl>H0n_3V03L0
n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0R0?[`iP80cHDoC`3jl>H00`000000
n_3V0?[`iP1]0?[`iP40oooo002n0?[`iP030<f5?`3jl>H0n_3V03P0n_3V00<000000?[`iP3jl>H0
4P3jl>H00`000000n_3V0?[`iP0S0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0
K@3jl>H10?ooo`00_@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V01<0n_3V00<0
00000?[`iP3jl>H08`3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V06d0n_3V0@3o
ool00;`0n_3V00<0cHDo0?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP0C0?[`iP030000003jl>H0
n_3V02@0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo002k0?[`
iP030<f5?`3jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP0S0?[`
iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00^P3jl>H00`3=QCl0
n_3V0?[`iP0l0?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H08`3jl>H00`3=QCl0
n_3V0?[`iP190?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00;T0n_3V00<0cHDo0?[`iP3jl>H0
?@3jl>H00`000000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V02<0n_3V0P3=QCm90?[`iP030000
003jl>H0n_3V06d0n_3V0@3oool00;P0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`
iP0G0?[`iP030000003jl>H0n_3V02<0n_3V00<0cHDo0?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`
iP1]0?[`iP40oooo002h0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0603jl>H0
0`000000n_3V0?[`iP0S0?[`iP030<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H0K@3jl>H1
0?ooo`00]`3jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V01P0n_3V00<000000?[`
iP3jl>H0903jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00;H0
n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V02<0
n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo002f0?[`iP030<f5
?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP0S0?[`iP030<f5
?`3jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00]@3jl>H00`3=QCl0n_3V0?[`
iP110?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H08`3jl>H00`3=QCl0n_3V0?[`
iP130?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00;@0n_3V00<0cHDo0?[`iP3jl>H0@P3jl>H0
0`000000n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V02<0n_3V00<0cHDo0?[`iP3jl>H0@P3jl>H0
0`000000n_3V0?[`iP1]0?[`iP40oooo002c0?[`iP030<f5?`3jl>H0n_3V04<0n_3V00<000000?[`
iP3jl>H07@3jl>H00`000000n_3V0?[`iP0S0?[`iP030<f5?`3jl>H0n_3V0440n_3V00<000000?[`
iP3jl>H0K@3jl>H10?ooo`00/P3jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V01d0
n_3V00<000000?[`iP3jl>H08`3jl>H00`3=QCl0n_3V0?[`iP110?[`iP030000003jl>H0n_3V06d0
n_3V0@3oool00;80n_3V00<0cHDo0?[`iP3jl>H0A03jl>H00`000000n_3V0?[`iP0N0?[`iP030000
003jl>H0n_3V02<0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo
002a0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H07`3jl>H00`000000n_3V0?[`
iP0R0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00/@3jl>H0
0`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H08P3jl>H0
0`3=QCl0n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00;00n_3V00<0cHDo0?[`
iP3jl>H0AP3jl>H00`000000n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V0240n_3V00<0cHDo0?[`
iP3jl>H0?`3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo002`0?[`iP030<f5?`3jl>H0n_3V04H0
n_3V00<000000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V03h0
n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00[`3jl>H00`3=QCl0n_3V0?[`iP170?[`iP030000
003jl>H0n_3V0280n_3V00<000000?[`iP3jl>H08@3jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP030000
003jl>H0n_3V06d0n_3V0@3oool00:l0n_3V00<0cHDo0?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`
iP0S0?[`iP030000003jl>H0n_3V0240n_3V00<0cHDo0?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`
iP1]0?[`iP40oooo002^0?[`iP030<f5?`3jl>H0n_3V04P0n_3V00<000000?[`iP3jl>H0903jl>H0
0`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V03`0n_3V00<000000?[`iP3jl>H0K@3jl>H1
0?ooo`00[@3jl>H00`3=QCl0n_3V0?[`iP190?[`iP030000003jl>H0n_3V02D0n_3V00<000000?[`
iP3jl>H0803jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00:d0
n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V0200
n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo002/0?[`iP030<f5
?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP0O0?[`iP030<f5
?`3jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00[03jl>H00`3=QCl0n_3V0?[`
iP1:0?[`iP030000003jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H0803jl>H00`3=QCl0n_3V0?[`
iP0j0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00080003oZP3jl>H00`3=QCl0n_3V0?[`iP1:
0?[`iP030000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H07`3jl>H00`3=QCl0n_3V0?[`iP0j
0?[`iP030000003jl>H0n_3V06X0n_3V0P000?l10?[`iP40oooo00020?[`iP<0003oY`3jl>H00`3=
QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V02T0n_3V00<000000?[`iP3jl>H07P3jl>H00`3=
QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V06L0n_3V0`000?l30?[`iP40oooo00050?[`iP@0
003oXP3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3j
l>H07@3jl>H00`3=QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V06<0n_3V10000?l60?[`iP40
oooo00090?[`iP<0003oW`3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V02/0n_3V
00<000000?[`iP3jl>H07@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V0600n_3V
0`000?l:0?[`iP40oooo000<0?[`iP<0003oV`3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003j
l>H0n_3V02`0n_3V00<000000?[`iP3jl>H0703jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003j
l>H0n_3V05d0n_3V0`000?l=0?[`iP40oooo000?0?[`iP@0003oU`3jl>H00`3=QCl0n_3V0?[`iP1<
0?[`iP030000003jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H07@3jl>H00`3=QCl0n_3V0?[`iP0h
0?[`iP030000003jl>H0n_3V05T0n_3V10000?l@0?[`iP40oooo000C0?[`iP<0003oU03jl>H00`3=
QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H0703jl>H00`3=
QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V05H0n_3V0`000?lD0?[`iP40oooo000F0?[`iP<0
003oT@3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V02h0n_3V00<000000?[`iP3j
l>H06`3jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V05<0n_3V0`000?lG0?[`iP40
oooo000I0?[`iP<0003oS@3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V02l0n_3V
00<000000?[`iP3jl>H06P3jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V0500n_3V
0`000?lJ0?[`iP40oooo000L0?[`iP<0003oRP3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003j
l>H0n_3V0300n_3V00<000000?[`iP3jl>H06P3jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003j
l>H0n_3V04d0n_3V0`000?lM0?[`iP40oooo000O0?[`iP@0003oQP3jl>H00`3=QCl0n_3V0?[`iP1=
0?[`iP030000003jl>H0n_3V0340n_3V00<000000?[`iP3jl>H06@3jl>H00`3=QCl0n_3V0?[`iP0g
0?[`iP030000003jl>H0n_3V04X0n_3V0`000?lP0?[`iP40oooo000S0?[`iP<0003oP`3jl>H00`3=
QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V0340n_3V00<000000?[`iP3jl>H06@3jl>H00`3=
QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V04L0n_3V0`000?lS0?[`iP40oooo000V0?[`iP<0
003oO`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V0380n_3V00<000000?[`iP3j
l>H0603jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V04@0n_3V0`000?lV0?[`iP40
oooo000Y0?[`iP<0003oO03jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V03<0n_3V
00<000000?[`iP3jl>H0603jl>H00`3=QCl0n_3V0?[`iP0f0?[`iP030000003jl>H0n_3V0440n_3V
0`000?lY0?[`iP40oooo000/0?[`iP80003oNP3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003j
l>H0n_3V03@0n_3V00<000000?[`iP3jl>H05`3jl>H00`3=QCl0n_3V0?[`iP0f0?[`iP030000003j
l>H0n_3V03l0n_3V0P000?l/0?[`iP40oooo000^0?[`iP80003oN03jl>H00`3=QCl0n_3V0?[`iP1>
0?[`iP030000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H05P3jl>H00`3=QCl0n_3V0?[`iP0f
0?[`iP030000003jl>H0n_3V03d0n_3V0P000?l^0?[`iP40oooo000`0?[`iP<0003oM03jl>H00`3=
QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V03H0n_3V00<000000?[`iP3jl>H05@3jl>H00`3=
QCl0n_3V0?[`iP0f0?[`iP030000003jl>H0n_3V03X0n_3V0`000?l`0?[`iP40oooo000c0?[`iP80
003oLP3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V03H0n_3V00<000000?[`iP3j
l>H05P3jl>H00`3=QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V03P0n_3V0P000?lc0?[`iP40
oooo000e0?[`iP80003oL03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V03L0n_3V
00<000000?[`iP3jl>H05@3jl>H00`3=QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V03H0n_3V
0P000?le0?[`iP40oooo000g0?[`iP<0003oK@3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003j
l>H0n_3V03P0n_3V00<000000?[`iP3jl>H0503jl>H00`3=QCl0n_3V0?[`iP0e0?[`iP030000003j
l>H0n_3V03<0n_3V0`000?lg0?[`iP40oooo000j0?[`iP80003oJ`3jl>H00`3=QCl0n_3V0?[`iP1?
0?[`iP030000003jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H04`3jl>H00`3=QCl0n_3V0?[`iP0e
0?[`iP030000003jl>H0n_3V0340n_3V0P000?lj0?[`iP40oooo000l0?[`iP80003oJ@3jl>H00`3=
QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V03X0n_3V00<000000?[`iP3jl>H04P3jl>H00`3=
QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V02l0n_3V0P000?ll0?[`iP40oooo000n0?[`iP<0
003oI@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V03/0n_3V00<000000?[`iP3j
l>H04@3jl>H00`3=QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V02`0n_3V0`000?ln0?[`iP40
oooo00110?[`iP80003oH`3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V03/0n_3V
00<000000?[`iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0n_3V02X0n_3V
0P000?m10?[`iP40oooo00130?[`iP80003oH@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003j
l>H0n_3V03`0n_3V00<000000?[`iP3jl>H04@3jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000003j
l>H0n_3V02P0n_3V0P000?m30?[`iP40oooo00150?[`iP80003oG`3jl>H00`3=QCl0n_3V0?[`iP1@
0?[`iP030000003jl>H0n_3V03d0n_3V00<000000?[`iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP0d
0?[`iP030000003jl>H0n_3V02H0n_3V0P000?m50?[`iP40oooo00170?[`iP80003oG@3jl>H00`3=
QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H03`3jl>H00`3=
QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0n_3V02@0n_3V0P000?m70?[`iP40oooo00190?[`iP<0
003oFP3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V03l0n_3V00<000000?[`iP3j
l>H03P3jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0n_3V0280n_3V0P000?m90?[`iP40
oooo001<0?[`iP80003oF03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0400n_3V
00<000000?[`iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0n_3V0200n_3V
0P000?m;0?[`iP40oooo001>0?[`iP80003oEP3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP<00000@@3j
l>H00`000000n_3V0?[`iP0=0?[`iP030<f5?`3jl>H0n_3V03@0n_3V00<000000?[`iP3jl>H07P3j
l>H20000odd0n_3V0@3oool00500n_3V0P000?mD0?[`iP030<f5?`3jl>H0n_3V04h0n_3V1@000011
0?[`iP030000003jl>H0n_3V00`0n_3V00<0cHDo0?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP0L
0?[`iP80003oC`3jl>H10?ooo`00DP3jl>H20000oe80n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H50000
0480n_3V00<000000?[`iP3jl>H02`3jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0n_3V
01X0n_3V0P000?mA0?[`iP40oooo001D0?[`iP80003oD03jl>H00`3=QCl0n_3V0?[`iP1>0?[`iPD0
0000@`3jl>H00`000000n_3V0?[`iP0:0?[`iP030<f5?`3jl>H0n_3V03@0n_3V00<000000?[`iP3j
l>H0603jl>H20000oe<0n_3V0@3oool005H0n_3V0P000?m>0?[`iP030<f5?`3jl>H0n_3V04l0n_3V
0`0000150?[`iP030000003jl>H0n_3V00T0n_3V00<0cHDo0?[`iP3jl>H0=03jl>H00`000000n_3V
0?[`iP0F0?[`iP80003oE@3jl>H10?ooo`00F03jl>H20000od`0n_3V00<0cHDo0?[`iP3jl>H0D03j
l>H00`000000n_3V0?[`iP140?[`iP030000003jl>H0n_3V00T0n_3V00<0cHDo0?[`iP3jl>H0=03j
l>H00`000000n_3V0?[`iP0D0?[`iP80003oE`3jl>H10?ooo`00FP3jl>H00`000?l0n_3V0?[`iP19
0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP08
0?[`iP030<f5?`3jl>H0n_3V03@0n_3V00<000000?[`iP3jl>H04P3jl>H20000oeT0n_3V0@3oool0
05/0n_3V0P000?m90?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0AP3jl>H00`00
0000n_3V0?[`iP070?[`iP030<f5?`3jl>H0n_3V03@0n_3V00<000000?[`iP3jl>H0403jl>H20000
oe/0n_3V0@3oool005d0n_3V0P000?m70?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3j
l>H0A`3jl>H00`000000n_3V0?[`iP060?[`iP030<f5?`3jl>H0n_3V03@0n_3V00<000000?[`iP3j
l>H03P3jl>H20000oed0n_3V0@3oool005l0n_3V0P000?m50?[`iP030<f5?`3jl>H0n_3V0500n_3V
00<000000?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP050?[`iP030<f5?`3jl>H0n_3V03@0n_3V
00<000000?[`iP3jl>H0303jl>H20000oel0n_3V0@3oool00640n_3V00<0003o0?[`iP3jl>H0@P3j
l>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V04T0n_3V00<000000?[`iP3jl>H0103j
l>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0n_3V00X0n_3V0P000?mQ0?[`iP40oooo001R
0?[`iP80003o@P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V04T0n_3V00<00000
0?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0n_3V00P0n_3V0P000?mS
0?[`iP40oooo001T0?[`iP80003o@03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V
04X0n_3V00<000000?[`iP3jl>H00P3jl>H00`3=QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V
00H0n_3V0P000?mU0?[`iP40oooo001V0?[`iP80003o?`3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP03
0000003jl>H0n_3V04/0n_3V00D000000?[`iP3jl>H0n_3V0<f5?`0g0?[`iP030000003jl>H0n_3V
00@0n_3V0P000?mW0?[`iP40oooo001X0?[`iP030000o`3jl>H0n_3V03`0n_3V00<0cHDo0?[`iP3j
l>H0C`3jl>H00`000000n_3V0?[`iP1<0?[`iP040000003jl>H0n_3V0<f5?cL0n_3V00<000000?[`
iP3jl>H00`3jl>H00`000?l0n_3V0?[`iP1W0?[`iP40oooo001Y0?[`iP80003o?03jl>H00`3=QCl0
n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04d0n_3V1000000e0?[`iP<000000P3jl>H20000ofX0
n_3V0@3oool006/0n_3V0P000?lj0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0
C@3jl>H5000003<0n_3V1@0000000`000?l0n_3V0?[`iP1Z0?[`iP40oooo001]0?[`iP030000o`3j
l>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1=0?[`iSd00000K@3j
l>H10?ooo`00KP3jl>H20000ocL0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1=
0?[`iPD00000<`3jl>H5000006d0n_3V0@3oool00700n_3V0P000?lf0?[`iP030<f5?`3jl>H0n_3V
04h0n_3V00<000000?[`iP3jl>H0CP3jl>H3000003@0n_3V00@0003o0000000000000000KP3jl>H1
0?ooo`00LP3jl>H00`000?l0n_3V0?[`iP0c0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`
iP3jl>H0CP3jl>H0103=QCl0n_3V0?[`iP00000a0?[`iP80003o0P3jl>H00`000000n_3V0?[`iP1]
0?[`iP40oooo001c0?[`iP80003o<`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V
04h0n_3V00D0cHDo0?[`iP3jl>H0n_3V0000000_0?[`iP030000o`3jl>H0n_3V0080n_3V00<00000
0?[`iP3jl>H0K@3jl>H10?ooo`00M@3jl>H20000oc40n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`00
0000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0:P3jl>H20000
o`D0n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00M`3jl>H00`000?l0n_3V0?[`iP0_0?[`iP03
0<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP030?[`iP03
0000003jl>H0n_3V02P0n_3V0P000?l70?[`iP030000003jl>H0n_3V06d0n_3V0@3oool007P0n_3V
0P000?l_0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V
0?[`iP040?[`iP030000003jl>H0n_3V02H0n_3V00<0003o0?[`iP3jl>H01`3jl>H00`000000n_3V
0?[`iP1]0?[`iP40oooo001j0?[`iP80003o;@3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003j
l>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0S0?[`iP80003o2P3j
l>H00`000000n_3V0?[`iP1]0?[`iP40oooo001l0?[`iP030000o`3jl>H0n_3V02X0n_3V00<0cHDo
0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V00L0n_3V00<00000
0?[`iP3jl>H08@3jl>H00`000?l0n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool0
07d0n_3V0P000?l[0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=
QCl0n_3V0?[`iP080?[`iP030000003jl>H0n_3V01h0n_3V0P000?l=0?[`iP030000003jl>H0n_3V
06d0n_3V0@3oool007l0n_3V0P000?lY0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3j
l>H0C03jl>H00`3=QCl0n_3V0?[`iP090?[`iP030000003jl>H0n_3V01/0n_3V0P000?l?0?[`iP03
0000003jl>H0n_3V06d0n_3V0@3oool00840n_3V00<0003o0?[`iP3jl>H09P3jl>H00`3=QCl0n_3V
0?[`iP1<0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H02@3jl>H00`000000n_3V
0?[`iP0J0?[`iP030000o`3jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00PP3j
l>H20000obH0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP1;0?[`iP030<f5?`3j
l>H0n_3V00/0n_3V00<000000?[`iP3jl>H05`3jl>H20000oa80n_3V00<000000?[`iP3jl>H0K@3j
l>H10?ooo`00Q03jl>H20000obD0n_3V00<0cHDo0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP1;
0?[`iP030<f5?`3jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H05@3jl>H00`000?l0n_3V0?[`iP0B
0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool008H0n_3V00<0003o0?[`iP3jl>H08P3jl>H00`3=
QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H03P3jl>H00`00
0000n_3V0?[`iP0B0?[`iP80003o5@3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo00270?[`iP80
003o8`3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3j
l>H03`3jl>H00`000000n_3V0?[`iP0?0?[`iP80003o5`3jl>H00`000000n_3V0?[`iP1]0?[`iP40
oooo00290?[`iP80003o8@3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V04X0n_3V
00<0cHDo0?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0=0?[`iP030000o`3jl>H0n_3V01L0n_3V
00<000000?[`iP3jl>H0K@3jl>H10?ooo`00R`3jl>H20000oal0n_3V00<0cHDo0?[`iP3jl>H0BP3j
l>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0100n_3V00<000000?[`iP3jl>H02`3j
l>H20000oaX0n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00S@3jl>H00`000?l0n_3V0?[`iP0L
0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP0B
0?[`iP030000003jl>H0n_3V00T0n_3V00<0003o0?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP1]
0?[`iP40oooo002>0?[`iP80003o7@3jl>H00`3=QCl0n_3V0?[`iP190?[`iP030000003jl>H0n_3V
04T0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP060?[`iP80003o7@3jl>H00`00
0000n_3V0?[`iP1]0?[`iP40oooo002@0?[`iP80003o703jl>H00`3=QCl0n_3V0?[`iP180?[`iP03
0000003jl>H0n_3V04P0n_3V00<0cHDo0?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP030?[`iP80
003o7`3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo002B0?[`iP030000o`3jl>H0n_3V01T0n_3V
00<0cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP170?[`iP030<f5?`3jl>H0n_3V01L0n_3V
00D000000?[`iP3jl>H0n_3V0000o`0Q0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool009<0n_3V
0P000?lJ0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H0A`3jl>H00`3=QCl0n_3V
0?[`iP0H0?[`iP03000000000?l0003o0280n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00U@3j
l>H00`000?l0n_3V0?[`iP0G0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H0AP3j
l>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V0280n_3V00<000000?[`iP3jl>H0K@3j
l>H10?ooo`00UP3jl>H20000oaP0n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP16
0?[`iP030<f5?`3jl>H0n_3V01L0n_3V0P000?l00`3jl>H000000?[`iP0R0?[`iP030000003jl>H0
n_3V06d0n_3V0@3oool009P0n_3V00<0003o0?[`iP3jl>H05@3jl>H00`3=QCl0n_3V0?[`iP160?[`
iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H05`3jl>H00`000?l0n_3V0?[`iP020?[`
iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00V@3jl>H20000oaH0
n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V01D0
n_3V0P000?l60?[`iP030000003jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00
V`3jl>H00`000?l0n_3V0?[`iP0C0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0
A03jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP030000o`3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0
7P3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo002L0?[`iP80003o503jl>H00`3=QCl0n_3V0?[`
iP140?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H20000o`/0n_3V00<0
00000?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo002N0?[`iP030000o`3jl>H0
n_3V0180n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP130?[`iP030<f5?`3jl>H0
n_3V01<0n_3V00<0003o0?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0M0?[`iP030000003jl>H0
n_3V06d0n_3V0@3oool009l0n_3V0P000?lB0?[`iP030<f5?`3jl>H0n_3V04<0n_3V00<000000?[`
iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP80003o3`3jl>H00`000000n_3V0?[`iP0L0?[`
iP030000003jl>H0n_3V06d0n_3V0@3oool00:40n_3V00<0003o0?[`iP3jl>H0403jl>H00`3=QCl0
n_3V0?[`iP120?[`iP030000003jl>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H04@3jl>H00`000?l0
n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00
XP3jl>H20000oa40n_3V00<0cHDo0?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP110?[`iP030<f5
?`3jl>H0n_3V0100n_3V0P000?lD0?[`iP030000003jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H0
K@3jl>H10?ooo`00Y03jl>H00`000?l0n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<0
00000?[`iP3jl>H0@03jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP030000o`3jl>H0n_3V01D0n_3V00<0
00000?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo002U0?[`iP80003o3`3jl>H0
0`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H03`3jl>H2
0000oaT0n_3V00<000000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo002W0?[`
iP030000o`3jl>H0n_3V00d0n_3V00<0cHDo0?[`iP3jl>H0?`3jl>H00`000000n_3V0?[`iP0o0?[`
iP030<f5?`3jl>H0n_3V00h0n_3V00<0003o0?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0H0?[`
iP030000003jl>H0n_3V06d0n_3V0@3oool00:P0n_3V0P000?l>0?[`iP030<f5?`3jl>H0n_3V03h0
n_3V00<000000?[`iP3jl>H0?P3jl>H00`3=QCl0n_3V0?[`iP0=0?[`iP80003o7@3jl>H00`000000
n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00:X0n_3V0P000?l<0?[`iP030<f5
?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP80003o
803jl>H00`000000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00:`0n_3V00<0
003o0?[`iP3jl>H02P3jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V03d0n_3V00<0
cHDo0?[`iP3jl>H02P3jl>H20000ob<0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`
iP1]0?[`iP40oooo002]0?[`iP80003o2`3jl>H20<f5?cd0n_3V00<000000?[`iP3jl>H0>`3jl>H2
0<f5?``0n_3V00<0003o0?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0
n_3V06d0n_3V0@3oool00:l0n_3V0P000?l:0?[`iP030<f5?`3jl>H0n_3V03/0n_3V00<000000?[`
iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`iP0:0?[`iP80003o:03jl>H00`000000n_3V0?[`iP0C0?[`
iP030000003jl>H0n_3V06d0n_3V0@3oool00;40n_3V00<0003o0?[`iP3jl>H0203jl>H00`3=QCl0
n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H0203jl>H20000obX0
n_3V00<000000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo002b0?[`iP80003o
2@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V03T0n_3V00<0cHDo0?[`iP3jl>H0
1`3jl>H20000obd0n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo
002d0?[`iP80003o203jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V03P0n_3V00<0
cHDo0?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP0^0?[`iP030000003jl>H0n_3V0140n_3V00<0
00000?[`iP3jl>H0K@3jl>H10?ooo`00]P3jl>H00`000?l0n_3V0?[`iP060?[`iP030<f5?`3jl>H0
n_3V03L0n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V0?[`iP060?[`iP80003o<P3jl>H0
0`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00;L0n_3V0P000?l70?[`
iP80cHDo=`3jl>H00`000000n_3V0?[`iP0e0?[`iP80cHDo1`3jl>H20000ocD0n_3V00<000000?[`
iP3jl>H03`3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo002i0?[`iP80003o1P3jl>H00`3=QCl0
n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V03@0n_3V00<0cHDo0?[`iP3jl>H01@3jl>H20000ocP0
n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo002k0?[`iP030000
o`3jl>H0n_3V00@0n_3V00<0cHDo0?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP0d0?[`iP030<f5
?`3jl>H0n_3V00@0n_3V00<0003o0?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP0>0?[`iP030000
003jl>H0n_3V06d0n_3V0@3oool00;`0n_3V0P000?l50?[`iP80cHDo=03jl>H00`000000n_3V0?[`
iP0b0?[`iP80cHDo1@3jl>H20000oc`0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`
iP1]0?[`iP40oooo002n0?[`iP80003o1@3jl>H00`3=QCl0n_3V0?[`iP0a0?[`iP030000003jl>H0
n_3V0340n_3V00<0cHDo0?[`iP3jl>H00`3jl>H20000ocl0n_3V00<000000?[`iP3jl>H0303jl>H0
0`000000n_3V0?[`iP1]0?[`iP40oooo00300?[`iP030000o`3jl>H0n_3V00<0n_3V00<0cHDo0?[`
iP3jl>H0<03jl>H00`000000n_3V0?[`iP0`0?[`iP030<f5?`3jl>H0n_3V0080n_3V0P000?m20?[`
iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00`@3jl>H20000o`@0
n_3V00<0cHDo0?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0_0?[`iP040<f5?`3jl>H0n_3V0?[`
iP80003oA@3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00<<0
n_3V0P000?l30?[`iP80cHDo;`3jl>H00`000000n_3V0?[`iP0]0?[`iP80cHDo0`3jl>H00`000?l0
n_3V0?[`iP160?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00
a@3jl>H20000o`<0n_3V00<0cHDo0?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0/0?[`iP040<f5
?`3jl>H0n_3V0?[`iP80003oB@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V06d0
n_3V0@3oool00<L0n_3V0P000?l20?[`iP80cHDo;03jl>H00`000000n_3V0?[`iP0Z0?[`iP80cHDo
0P3jl>H20000od`0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP1]0?[`iP40oooo
00390?[`iP80003o0P3jl>H20<f5?bX0n_3V00<000000?[`iP3jl>H0:03jl>H20<f5?`80n_3V0P00
0?m?0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00b`3jl>H2
0000o`80n_3V00<0cHDo0?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP0W0?[`iP030<f5?`3jl>H0
n_3V0080003oDP3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V06d0n_3V0@3oool0
0<d0n_3V0P000?l00`3jl>H0cHDo0<f5?`0W0?[`iP030000003jl>H0n_3V02D0n_3V0P3=QCl00`3j
l>H0003o0000o`1E0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0K@3jl>H10?oo
o`00c`3jl>H30000o`80cHDo9@3jl>H00`000000n_3V0?[`iP0S0?[`iP80cHDo00<0n_3V0000o`00
0?l0F03jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00=80n_3V
0`000?l00`3=QCl0n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V0240n_3V0P3=QCl00`3jl>H0003o
0000o`1J0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0K@3jl>H10?ooo`00e@3j
l>H20000o`030<f5?`3jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H07`3jl>H20<f5?`<0003oG@3j
l>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V06d0n_3V0@3oool00=L0n_3V0`000?lO
0?[`iP030000003jl>H0n_3V01d0n_3V0P3=QCl20000of40n_3V00<000000?[`iP3jl>H00P3jl>H0
0`000000n_3V0?[`iP1]0?[`iP40oooo003J0?[`iP<0003o00<0cHDo0?[`iP3jl>H06@3jl>H00`00
0000n_3V0?[`iP0I0?[`iP<0cHDo0`000?mT0?[`iP050000003jl>H0n_3V0?[`iP000000K`3jl>H1
0?ooo`00g@3jl>H30000oaT0n_3V00<000000?[`iP3jl>H05`3jl>H00`3=QCl0003o0000o`020000
ofP0n_3V00@000000?[`iP3jl>H00000K`3jl>H10?ooo`00h03jl>H40000oaD0n_3V00<000000?[`
iP3jl>H04`3jl>H00`3=QCl0003o0000o`020000ofd0n_3V00<000000?[`iP000000K`3jl>H10?oo
o`00i03jl>H40000oa40n_3V00<000000?[`iP3jl>H03`3jl>H00`3=QCl0003o0000o`020000og40
n_3V1000001^0?[`iP40oooo003X0?[`iP@0003o3@3jl>H00`000000n_3V0?[`iP0;0?[`iPD0003o
M@3jl>H5000006d0n_3V0@3oool00>`0cHDo3@000?l00`000000003o0000o`0;0000ogX0cHDo1@00
001/0<f5?`40n_3V0@3oool00?l0n_3VPP3jl>H5000006d0n_3V0@3oool00?l0n_3VP`3jl>H30000
06h0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00]P3jl>H20000
000306IRGP3<a;/0n_3V02/0n_3V00H0e<c306IRGP000000000008V4OP3Tfm9U0?[`iP060=C<``1V
HUh0000000000029Q7h0i=_BW03jl>H10?ooo`00^03jl>H00`1VHUh000000=cDb`0[0?[`iP0604a9
A@33^k<0n_3V0>cRf@000000RHAnI@3jl>H01P1<BDD0`k^c0?[`iP3/h]T0000008V4OY`0n_3V0@3o
ool008<0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V00@0[jRQ04a9A@000000RHAn1`3j
l>H01P3Le</0NGE`000000000000RHAn0<c4^`80n_3V00@0[jRQ04a9A@000000RHAn0P3jl>H20000
0080n_3V0P0000001@3jl>H0c<Bk0000001iMG00n_3V008000000P3jl>H20000000306IRGP3jl>H0
n_3V00L0n_3V0P0000030?[`iP040<c4^`1<BDD0IV9N0>CKdP80000000<0n_3V0000000000000`3j
l>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P0000020?[`iP0308V4
OP1VHUh0c<Bk008000001`3jl>H01@3Le</0NGE`0000001<BDD0Y9fF0080n_3V00@0c<Bk04a9A@1V
HUh0i=_B0P0000000`3jl>H00000000000040?[`iP030:BMUP000000Y9fF00<0n_3V00@0[jRQ04a9
A@000000RHAn1`3jl>H0102_Z:40C4U504a9A@2_Z:420?[`iP8000001P3jl>H2000000050?[`iP33
^k<000000<>k/`3jl>H00P0000001@3jl>H0c<Bk04a9A@1<BDD0[jRQ0080000000<0n_3V00000000
00000`3jl>H2000000050?[`iP3<a;/0C4U504a9A@2_Z:400P0000040?[`iP80000000<0k>;I0?[`
iP3/h]T00P0000020?[`iP0308V4OP1VHUh0c<Bk0080000000<0n_3V0000000000000P3jl>H20000
0080n_3V00@0[jRQ04a9A@000000RHAn0P3jl>H01`3/h]T0Ui6;000000000000NGE`0>CKdP3jl>H0
0P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000001`3jl>H0[jRQ0000
0033^k<0i=_B00000029Q7h01@3jl>H01@3Tfm80000009NAR`3jl>H0^K:Z0080000000P0n_3V0:nX
X@000000`k^c0>CKdP000000RHAn0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H0c<Bk00000002000000030>CKdP3jl>H0n_3V00H0n_3V0P0000030?[`iP0406IR
GP000000i=_B0;VbZP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H0
00000000003jl>H200000080n_3V0P0000001@3jl>H0Y9fF00000033^k<0Y9fF008000001P3jl>H0
303Tfm80000009NAR`3jl>H0e<c300000029Q7h0n_3V06IRGP000000i=_B0;VbZP80000000<0n_3V
000000000000103jl>H3000000080>cRf@3jl>H0[jRQ00000033^k<0i=_B00000029Q7h50?[`iP07
0;VbZP000000`k^c0<>k/`000000^K:Z0?[`iP02000000H0n_3V0P0000001@3jl>H0Ui6;0000002G
TH/0n_3V0080000000D0n_3V04a9A@000000i=_B0<>k/`02000000030?[`iP000000000000<0n_3V
0P0000001@3jl>H0C4U50000003Tfm80`k^c00800000103jl>H03029Q7h000000=C<``3jl>H0e<c3
00000029Q7h0n_3V0:BMUP000000`k^c0:BMUP80000000<0n_3V0000000000000P3jl>H20000000?
0?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP3jl>H0NGE`0000003Tfm80k>;I0000001VHUh0n_3V
00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V04a9A@00
00002@3jl>H00`2GTH/000000=cDb`020?[`iP80000000<0n_3V04a9A@0000001@3jl>H200000080
n_3V0P0000000`3jl>H00000000000020?[`iP80000000H0n_3V09NAR`000000RHAn0000002_Z:48
0?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP8000000P3jl>H2000000030?[`iP1<BDD000000080n_3V0P00
00060?[`iP0309NAR`000000i=_B00D0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3j
l>H0202i/ZX0000008V4OP000000^K:Z0?[`iP1<BDD000002@3jl>H01`1VHUh000000?[`iP3jl>H0
000006IRGP3jl>H00P0000060?[`iP80000000D0n_3V04a9A@000000C4U50?[`iP02000000030?[`
iP00000000000080n_3V0P0000000`3jl>H00000000000030?[`iP80000000<0n_3V000000000000
0P3jl>H2000000@0n_3V00<0[jRQ0000000000000`000000102_Z:40n_3V04a9A@0000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP1<BDD0000000L0n_3V00D0e<c30:BMUP00
0000C4U50?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H200000003
0?[`iP000000000000@000001@3jl>H00`1<BDD000000?[`iP020?[`iP80000000<0n_3V00000000
0000100000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000006
0?[`iP1<BDD000000>cRf@000000IV9N203jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V
0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00
00000`3jl>H00000000000020?[`iP8000001P3jl>H2000000H0n_3V0P0000020?[`iP80000000<0
n_3V0000000000000`3jl>H204a9A@040>cRf@1<BDD0C4U50?[`iPH000001@3jl>H200000080n_3V
0P0000000`3jl>H00000000000060?[`iP80000000D0i=_B0000002GTH/000000>CKdP0200000005
0?[`iP3<a;/0000009NAR`3Tfm800P0000000`3jl>H00000000000030?[`iP80000000D0n_3V0<c4
^`000000Ui6;0>CKdP02000000@0n_3V00P0e<c300000029Q7h0n_3V09NAR`000000e<c30?[`iP80
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000400000003
0?[`iP3<a;/0C4U50080000000<0C4U50<c4^`3jl>H00P0000240?[`iP40oooo00230?[`iP800000
0`3jl>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP030000001VHUh0n_3V00@0n_3V
0P0000020?[`iP<0000000<0n_3V04a9A@0000000P3jl>H00`000000IV9N0?[`iP0200000080n_3V
0P0000000`3jl>H00000000000020?[`iP80000000L0g=C;00000029Q7h0n_3V08V4OP000000i=_B
00L0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V0P0000020?[`
iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V04a9A@0000000P3jl>H2
000000H0n_3V0P0000060?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V00T0c<Bk
0000002TWIH0n_3V0:BMUP000000c<Bk04a9A@0000000P3jl>H00`000000IV9N0?[`iP040?[`iP07
06IRGP000000n_3V0?[`iP000000IV9N0?[`iP02000000H0n_3V0P0000001@3<a;/000000=cDb`00
0000c<Bk008000000P3jl>H00`3Le</0[jRQ07UeL002000000030?[`iP000000000000<0n_3V0P00
00020?[`iP030=cDb`2_Z:40NGE`008000001@3jl>H01@000000C4U50?[`iP1<BDD000000080n_3V
00@0C4U50000003jl>H0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V04a9A@00
00000P3jl>H01`000000IV9N0?[`iP1<BDD0000007UeL03<a;/00`3jl>H2000008@0n_3V0@3oool0
08<0n_3V0P0000030?[`iP80000000/0Y9fF0>CKdP000000IV9N0?[`iP2i/ZX000000<>k/`3<a;/0
00000;VbZP050?[`iP0304a9A@000000n_3V00D0n_3V00L0^K:Z00000033^k<0c<Bk0000002i/ZX0
n_3V0080000000D0^K:Z0>CKdP000000C4U50?[`iP0200000080n_3V0P0000001`2_Z:4000000<>k
/`3jl>H0`k^c0000002_Z:401`3jl>H2000000<0n_3V0P0000020?[`iP80000000@0n_3V00000000
0000e<c30P3jl>H2000000050;VbZP3Tfm80000004a9A@3jl>H00P000000303jl>H000000000002i
/ZX0i=_B0000001<BDD0n_3V0:BMUP000000`k^c0:BMUP8000001P3jl>H00`1<BDD000000?[`iP05
0?[`iP8000000P3jl>H20000000B0?[`iP00000000000=C<``3jl>H0IV9N0000003/h]T0n_3V0>cR
f@000000IV9N0;VbZP000000`k^c0<c4^`000000^K:Z1@3jl>H01`2i/ZX000000<>k/`33^k<00000
0;VbZP3jl>H00P0000060?[`iP80000000D0Y9fF06IRGP3jl>H0IV9N0:BMUP02000000080?[`iP1i
MG00e<c30?[`iP3Tfm80000004a9A@3jl>H2000000030=C<``3jl>H0n_3V0080000000L0n_3V07Ue
L03Dc<<0n_3V0>CKdP000000C4U500D0n_3V00D0NGE`0000003<a;/0000006IRGP020?[`iP040:BM
UP000000`k^c0:BMUP80000001H0n_3V000000000000^K:Z0>CKdP000000C4U50?[`iP2i/ZX00000
0<>k/`3<a;/000000;VbZP3jl>H0IV9N0000003jl>H0i=_B0000001iMG00n_3V0P0000240?[`iP40
oooo00230?[`iP8000000`3jl>H2000000040=cDb`29Q7h0C4U50<c4^`80n_3V00@0[jRQ00000000
0000[jRQ1P3jl>H00`2GTH/000000>CKdP060?[`iP040:nXX@00000000000:nXX@80n_3V0P000000
103<a;/0NGE`04a9A@3<a;/40000000:0?[`iP000000000006IRGP000000k>;I0?[`iP3/h]T00000
06IRGPL0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP000000000008V4OP1iMG00n_3V
0P0000001@3<a;/0NGE`04a9A@3<a;/0n_3V0080000000L0n_3V000000000000c<Bk07UeL01<BDD0
c<Bk0080n_3V00<0RHAn06IRGP3<a;/00P0000060?[`iP0309NAR`000000i=_B00D0n_3V0P000002
0?[`iP80000000@0n_3V000000000000RHAn0P0000002029Q7h0n_3V0?[`iP3jl>H0RHAn0000003L
e</0[jRQ0P0000000`2_Z:40n_3V0?[`iP050?[`iP050:nXX@1<BDD000000:nXX@3jl>H010000005
0?[`iP80000000D0IV9N0:BMUP3jl>H0Ui6;06IRGP02000000030?[`iP3Tfm80RHAn0080000000<0
IV9N0=C<``3jl>H00P0000000`29Q7h0NGE`0?[`iP02000000030?[`iP3Tfm80RHAn0080000000<0
IV9N0=C<``3jl>H0103jl>H01@2TWIH0000008V4OP000000Y9fF00<0n_3V00<0RHAn06IRGP3<a;/0
0P0000001`3jl>H000000000003<a;/0NGE`04a9A@3<a;/00P3jl>H0102_Z:4000000000002_Z:42
0?[`iP070>CKdP1iMG00000000000029Q7h0i=_B0?[`iP02000008@0n_3V0@3oool008<0n_3V0P00
00030?[`iP800000403jl>H01`3Tfm80000009NAR`3jl>H0e<c30000001iMG003`3jl>H200000080
n_3V0P00000>0?[`iP800000;03jl>H01`3Tfm80000009NAR`3jl>H0e<c300000029Q7h09@3jl>H2
000000H0n_3V0`0000000`3<a;/0n_3V0<>k/`03000001/0n_3V00D0c<Bk00000000000000000<>k
/`2T0?[`iP40oooo00210?[`iPH0000000<0n_3V0000000000004@3jl>H01P3Le</0NGE`00000000
0000Ui6;0>cRf@l0n_3V00@0g=C;08V4OP3jl>H0n_3V0P00000<0?[`iPH00000503jl>H2000001D0
n_3V00D0g=C;07UeL000000000000:BMUP0V0?[`iP040<c4^`1VHUh0000008V4OP@0n_3V0`000000
0`3/h]T0n_3V0=cDb`03000000d0n_3V0P00000<0?[`iP050>cRf@00000000000000003Tfm807P3j
l>H2000008@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}]
}, Open  ]],

Cell["This produces an animation.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[frame];\)\), "\[IndentingNewLine]", 
    \(\(frame[x0_, 
          a0_] := \[IndentingNewLine]Module[{x}, \[IndentingNewLine]Show[
            Graphics[\n\t{Peru, 
                Circle[{0, a0}, 
                  a0], \[IndentingNewLine]Line[{{\(-10\), 2  a0}, {10, 
                      2  a0}}], \[IndentingNewLine]Blue, 
                ParametricDraw[\(agnesi[a0]\)[x] // Evaluate, {x, \(-3\) a0, 
                    3  a0}], \[IndentingNewLine]Black, 
                Line[{{0, 0}, {x0, 2  a0}}], Line[{{x0, 0}, {x0, 2  a0}}], 
                Line[{{\(4\ a0\^2\ x0\)\/\(4\ a0\^2 + x0\^2\), \(8\ a0\^3\)\/\
\(4\ a0\^2 + x0\^2\)}, {x0, \(8\ a0\^3\)\/\(4\ a0\^2 + x0\^2\)}}], 
                Line[{{0, 0}, {0, 
                      2  a0}}], \[IndentingNewLine]AbsolutePointSize[5], 
                Point[{0, a0}], Point[{x0, 2  a0}], 
                Point[{\(4\ a0\^2\ x0\)\/\(4\ a0\^2 + x0\^2\), \(8\ a0\^3\)\/\
\(4\ a0\^2 + x0\^2\)}], 
                Point[{x0, \(8\ a0\^3\)\/\(4\ a0\^2 + x0\^2\)}], \
\[IndentingNewLine]Text["\<The Gently Turning Curve of Maria Agnesi\>", {0, 
                    2.5  a0}]}], \n\nAspectRatio \[Rule] Automatic, 
            PlotRange \[Rule] {{\(-3\), 3} a0, {\(-0.3\), 3} a0}, 
            Background \[Rule] Linen, \n{Axes \[Rule] {True, False}, 
              Ticks \[Rule] None, 
              TextStyle \[Rule] {FontFamily \[Rule] "\<Helvetica\>", 
                  FontSize \[Rule] 12, FontWeight \[Rule] "\<Bold\>"}, 
              ImageSize \[Rule] 500}]];\)\), "\[IndentingNewLine]", 
    \(Animate[frame[x, 3], {x, \(-9\), 9}]\), "\[IndentingNewLine]", 
    \(\(SelectionMove[EvaluationNotebook[], All, 
        GeneratedCell];\)\), "\[IndentingNewLine]", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\[IndentingNewLine]", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input",
  GeneratedCell->False],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(frame\\)\\\" is similar to existing symbol \
\\\"\\!\\(Frame\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message",
  AnimationDisplayTime->0.371293],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
0 .38333 L
s
0 .05 m
0 .38333 L
s
.34615 .15256 m
0 .15256 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
0 .38333 Mdot
.34615 .15256 Mdot
0 .15256 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool000030000003jl>H0n_3V0>X0n_3V2P3=QCl30000
0080n_3V2P3=QCo]0?[`iP40oooo00000`000000n_3V0?[`iP3T0?[`iPH0cHDo2@3jl>H010000000
n_3V0?[`iP00000<0?[`iPL0cHDoiP3jl>H10?ooo`0000<000000?[`iP3jl>H0hP3jl>H20<f5?`d0
n_3V0P0000030?[`iP030000003jl>H0n_3V0140n_3V0P3=QCoT0?[`iP40oooo00000`000000n_3V
0?[`iP3N0?[`iP@0cHDo3P3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V01<0n_3V
0`3=QCoQ0?[`iP40oooo00000`000000n_3V0?[`iP3J0?[`iP@0cHDo403jl>H2000000H0n_3V00<0
00000?[`iP3jl>H05P3jl>H40<f5?md0n_3V0@3oool000030000003jl>H0n_3V0=P0n_3V0P3=QClC
0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H06P3jl>H20<f5?m/0n_3V0@3oool0
00030000003jl>H0n_3V0=H0n_3V0P3=QClC0?[`iP8000002@3jl>H00`000000n_3V0?[`iP0L0?[`
iP80cHDof@3jl>H10?ooo`0000<000000?[`iP3jl>H0e03jl>H20<f5?a@0n_3V00<000000?[`iP3j
l>H02@3jl>H00`000000n_3V0?[`iP0N0?[`iP80cHDoe`3jl>H10?ooo`0000<000000?[`iP3jl>H0
dP3jl>H20<f5?a@0n_3V0P00000<0?[`iP030000003jl>H0n_3V0200n_3V0P3=QCoE0?[`iP40oooo
00000`000000n_3V0?[`iP3@0?[`iP80cHDo5@3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003j
l>H0n_3V0280n_3V0P3=QCoC0?[`iP40oooo00000`000000n_3V0?[`iP3>0?[`iP80cHDo5@3jl>H2
000000l0n_3V00<000000?[`iP3jl>H0903jl>H20<f5?m40n_3V0@3oool000030000003jl>H0n_3V
0<`0n_3V0P3=QClF0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H09P3jl>H20<f5
?ll0n_3V0@3oool000030000003jl>H0n_3V0</0n_3V00<0cHDo0?[`iP3jl>H0503jl>H200000180
n_3V00<000000?[`iP3jl>H0:03jl>H00`3=QCl0n_3V0?[`iP3<0?[`iP40oooo00000`000000n_3V
0?[`iP390?[`iP80cHDo5P3jl>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V02T0n_3V
0P3=QCo<0?[`iP40oooo00000`000000n_3V0?[`iP370?[`iP80cHDo5P3jl>H2000001D0n_3V00<0
00000?[`iP3jl>H0:`3jl>H20<f5?lX0n_3V0@3oool000030000003jl>H0n_3V0<H0n_3V00<0cHDo
0?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V02d0n_3V00<0cHDo
0?[`iP3jl>H0a`3jl>H10?ooo`0000<000000?[`iP3jl>H0a03jl>H20<f5?aH0n_3V0P00000H0?[`
iP030000003jl>H0n_3V02h0n_3V0P3=QCo70?[`iP40oooo00000`000000n_3V0?[`iP330?[`iP03
0<f5?`3jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP0`0?[`iP03
0<f5?`3jl>H0n_3V0<@0n_3V0@3oool000030000003jl>H0n_3V0<80n_3V00<0cHDo0?[`iP3jl>H0
503jl>H2000001/0n_3V00<000000?[`iP3jl>H0<@3jl>H00`3=QCl0n_3V0?[`iP330?[`iP40oooo
00000`000000n_3V0?[`iP310?[`iP030<f5?`3jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H06`3j
l>H00`000000n_3V0?[`iP0b0?[`iP030<f5?`3jl>H0n_3V0<80n_3V0@3oool000030000003jl>H0
n_3V0;l0n_3V0P3=QClE0?[`iP8000007P3jl>H00`000000n_3V0?[`iP0c0?[`iP80cHDo`P3jl>H1
0?ooo`0000<000000?[`iP3jl>H0_P3jl>H00`3=QCl0n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V
01h0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP300?[`iP40oooo00000`000000
n_3V0?[`iP2m0?[`iP030<f5?`3jl>H0n_3V01<0n_3V0P00000Q0?[`iP030000003jl>H0n_3V03D0
n_3V00<0cHDo0?[`iP3jl>H0_`3jl>H10?ooo`0000<000000?[`iP3jl>H0_03jl>H00`3=QCl0n_3V
0?[`iP0C0?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0=P3jl>H20<f5?kl0n_3V
0@3oool000030000003jl>H0n_3V0;/0n_3V00<0cHDo0?[`iP3jl>H04P3jl>H2000002@0n_3V00<0
00000?[`iP3jl>H0>03jl>H00`3=QCl0n_3V0?[`iP2l0?[`iP40oooo00000`000000n_3V0?[`iP2j
0?[`iP030<f5?`3jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP0i
0?[`iP030<f5?`3jl>H0n_3V0;/0n_3V0@3oool000030000003jl>H0n_3V0;T0n_3V00<0cHDo0?[`
iP3jl>H04@3jl>H2000002L0n_3V00<000000?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`iP2j0?[`
iP40oooo00000`000000n_3V0?[`iP2h0?[`iP030<f5?`3jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H09`3jl>H00`000000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V0;X0n_3V0@3oool000030000
003jl>H0n_3V0;L0n_3V00<0cHDo0?[`iP3jl>H0403jl>H2000002X0n_3V00<000000?[`iP3jl>H0
>`3jl>H00`3=QCl0n_3V0?[`iP2i0?[`iP40oooo00000`000000n_3V0?[`iP2f0?[`iP030<f5?`3j
l>H0n_3V0100n_3V00<000000?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`iP0l0?[`iP80cHDo^@3j
l>H10?ooo`0000<000000?[`iP3jl>H0]@3jl>H00`3=QCl0n_3V0?[`iP0?0?[`iP800000;@3jl>H0
0`000000n_3V0?[`iP0m0?[`iP030<f5?`3jl>H0n_3V0;L0n_3V0@3oool000030000003jl>H0n_3V
0;D0n_3V00<0cHDo0?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V
03h0n_3V00<0cHDo0?[`iP3jl>H0]P3jl>H10?ooo`0000<000000?[`iP3jl>H0]03jl>H00`3=QCl0
n_3V0?[`iP0=0?[`iP800000<03jl>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V0;D0
n_3V0@3oool000030000003jl>H0n_3V0;<0n_3V00<0cHDo0?[`iP3jl>H03@3jl>H00`000000n_3V
0?[`iP0`0?[`iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H0]@3jl>H10?ooo`0000<0
00000?[`iP3jl>H0/`3jl>H00`3=QCl0n_3V0?[`iP0;0?[`iP800000<`3jl>H00`000000n_3V0?[`
iP100?[`iP030<f5?`3jl>H0n_3V0;@0n_3V0@3oool000030000003jl>H0n_3V0;80n_3V00<0cHDo
0?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0c0?[`iP030000003jl>H0n_3V0440n_3V00<0cHDo
0?[`iP3jl>H0/`3jl>H10?ooo`0000<000000?[`iP3jl>H0/@3jl>H00`3=QCl0n_3V0?[`iP0:0?[`
iP800000=P3jl>H00`000000n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V0;80n_3V0@3oool00003
0000003jl>H0n_3V0;00n_3V00<0cHDo0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0f0?[`iP03
0000003jl>H0n_3V04<0n_3V00<0cHDo0?[`iP3jl>H0/@3jl>H10?ooo`0000<000000?[`iP3jl>H0
[`3jl>H00`3=QCl0n_3V0?[`iP090?[`iP800000>@3jl>H00`000000n_3V0?[`iP130?[`iP030<f5
?`3jl>H0n_3V0;40n_3V0@3oool000030000003jl>H0n_3V0:l0n_3V00<0cHDo0?[`iP3jl>H0203j
l>H00`000000n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H0/03j
l>H10?ooo`0000<000000?[`iP3jl>H0[P3jl>H00`3=QCl0n_3V0?[`iP070?[`iP800000?03jl>H0
0`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0n_3V0;00n_3V0@3oool000030000003jl>H0n_3V
0:h0n_3V00<0cHDo0?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP0l0?[`iP030000003jl>H0n_3V
04D0n_3V00<0cHDo0?[`iP3jl>H0[`3jl>H10?ooo`0000<000000?[`iP3jl>H0[@3jl>H00`3=QCl0
n_3V0?[`iP050?[`iP800000?`3jl>H00`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V0:l0
n_3V0@3oool000030000003jl>H0n_3V0:d0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V
0?[`iP0o0?[`iP030000003jl>H0n_3V04H0n_3V00<0cHDo0?[`iP3jl>H0[P3jl>H10?ooo`0000<0
00000?[`iP3jl>H0[03jl>H00`3=QCl0n_3V0?[`iP030?[`iP800000@P3jl>H00`000000n_3V0?[`
iP160?[`iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool000030000003jl>H0n_3V0:`0n_3V00<0cHDo
0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP120?[`iP030000003jl>H0n_3V04L0n_3V00<0cHDo
0?[`iP3jl>H0[@3jl>H10?ooo`0000<000000?[`iP3jl>H0Z`3jl>H0103=QCl0n_3V0?[`iP3jl>H2
000004D0n_3V00<000000?[`iP3jl>H0B03jl>H00`3=QCl0n_3V0?[`iP2/0?[`iP40oooo00000`00
0000n_3V0?[`iP2Z0?[`iP050<f5?`3jl>H0n_3V0?[`iP000000A`3jl>H00`000000n_3V0?[`iP18
0?[`iP030<f5?`3jl>H0n_3V0:`0n_3V0@3oool000030000003jl>H0n_3V0:X0n_3V00@0cHDo0?[`
iP0000000000B03jl>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V0:/0n_3V0@3oool0
00030000003jl>H0n_3V0:P0n_3V1000001:0?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`
iP3jl>H0Z`3jl>H10?ooo`000P00002X0?[`iPD00000BP3jl>H00`000000n_3V0?[`iP1:0?[`iP03
0<f5?`3jl>H0n_3V0:X0n_3V0@3oool00:l00000BP3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5
?`3jl>H0n_3V0:L0n_3V0P000?l10?[`iP40oooo0002000000<0003oY03jl>H6000004X0n_3V00<0
00000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2T0?[`iP<0003o0`3jl>H10?ooo`0000<00000
0?[`iP3jl>H00P3jl>H40000oil0n_3V00<000000?[`iP3jl>H00`00001;0?[`iP030000003jl>H0
n_3V04X0n_3V00<0cHDo0?[`iP3jl>H0X03jl>H40000o`H0n_3V0@3oool000030000003jl>H0n_3V
00H0n_3V0`000?nJ0?[`iP8000000`3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V
04/0n_3V00<0cHDo0?[`iP3jl>H0W03jl>H30000o`X0n_3V0@3oool000030000003jl>H0n_3V00T0
n_3V0`000?nF0?[`iP030000003jl>H0n_3V0080n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000
n_3V0?[`iP1;0?[`iP030<f5?`3jl>H0n_3V09T0n_3V0`000?l=0?[`iP40oooo00000`000000n_3V
0?[`iP0<0?[`iP@0003oT03jl>H2000000D0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V
0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V09@0n_3V10000?l@0?[`iP40oooo00000`000000n_3V0?[`
iP0@0?[`iP<0003oS03jl>H00`000000n_3V0?[`iP050?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<0
00000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP2A0?[`iP<0003o503jl>H10?ooo`0000<00000
0?[`iP3jl>H04`3jl>H30000ohL0n_3V0P0000080?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<00000
0?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP2>0?[`iP<0003o5`3jl>H10?ooo`0000<000000?[`
iP3jl>H05P3jl>H30000oh<0n_3V00<000000?[`iP3jl>H01`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`
iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0R`3jl>H30000oaX0n_3V0@3oool00003
0000003jl>H0n_3V01T0n_3V0`000?mn0?[`iP8000002P3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP03
0000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0Q`3jl>H30000oad0n_3V0@3oool000030000
003jl>H0n_3V01`0n_3V10000?mi0?[`iP030000003jl>H0n_3V00X0n_3V00<0cHDo0?[`iP3jl>H0
C@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V08@0n_3V0`000?lP0?[`iP40oooo
00000`000000n_3V0?[`iP0P0?[`iP<0003oM03jl>H2000000d0n_3V00<0cHDo0?[`iP3jl>H0C@3j
l>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V0840n_3V0`000?lS0?[`iP40oooo0000
0`000000n_3V0?[`iP0S0?[`iP<0003oL03jl>H00`000000n_3V0?[`iP0<0?[`iP030<f5?`3jl>H0
n_3V04h0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP1n0?[`iP<0003o9P3jl>H1
0?ooo`0000<000000?[`iP3jl>H09P3jl>H30000of/0n_3V0P00000?0?[`iP030<f5?`3jl>H0n_3V
04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP1j0?[`iP<0003o:@3jl>H10?oo
o`0000<000000?[`iP3jl>H0:@3jl>H20000ofP0n_3V00<000000?[`iP3jl>H03`3jl>H00`3=QCl0
n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0N03jl>H20000ob`0
n_3V0@3oool000030000003jl>H0n_3V02/0n_3V0P000?mT0?[`iP8000004P3jl>H00`3=QCl0n_3V
0?[`iP1>0?[`iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0MP3jl>H20000obh0n_3V
0@3oool000030000003jl>H0n_3V02d0n_3V0`000?mP0?[`iP030000003jl>H0n_3V0140n_3V00<0
cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V07<0n_3V0`00
0?l`0?[`iP40oooo00000`000000n_3V0?[`iP0`0?[`iP80003oG03jl>H2000001@0n_3V00<0cHDo
0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V0700n_3V0P000?lc
0?[`iP40oooo00000`000000n_3V0?[`iP0b0?[`iP80003oF@3jl>H00`000000n_3V0?[`iP0D0?[`
iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1^0?[`
iP80003o=@3jl>H10?ooo`0000<000000?[`iP3jl>H0=03jl>H30000oe@0n_3V0P00000G0?[`iP03
0<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1[0?[`iP<0
003o=`3jl>H10?ooo`0000<000000?[`iP3jl>H0=`3jl>H20000oe40n_3V00<000000?[`iP3jl>H0
5`3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0
J@3jl>H20000ocX0n_3V0@3oool000030000003jl>H0n_3V03T0n_3V0P000?m=0?[`iP8000006P3j
l>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0I`3j
l>H20000oc`0n_3V0@3oool000030000003jl>H0n_3V03/0n_3V0`000?m90?[`iP030000003jl>H0
n_3V01T0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0
n_3V06@0n_3V0`000?ln0?[`iP40oooo00000`000000n_3V0?[`iP0n0?[`iP80003oA@3jl>H20000
01`0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V
0640n_3V0P000?m10?[`iP40oooo00000`000000n_3V0?[`iP100?[`iP80003o@P3jl>H00`000000
n_3V0?[`iP0L0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0
n_3V0?[`iP1O0?[`iP80003o@`3jl>H10?ooo`0000<000000?[`iP3jl>H0@P3jl>H20000och0n_3V
0P00000O0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V
0?[`iP1M0?[`iP80003oA@3jl>H10?ooo`0000<000000?[`iP3jl>H0A03jl>H20000oc/0n_3V00<0
00000?[`iP3jl>H07`3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0
cHDo0?[`iP3jl>H0F`3jl>H20000odL0n_3V0@3oool000030000003jl>H0n_3V04H0n_3V0`000?lf
0?[`iP8000008P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo
0?[`iP3jl>H0F@3jl>H20000odT0n_3V0@3oool000030000003jl>H0n_3V04T0n_3V0P000?lc0?[`
iP030000003jl>H0n_3V0280n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`
iP030<f5?`3jl>H0n_3V05L0n_3V0P000?m;0?[`iP40oooo00000`000000n_3V0?[`iP1;0?[`iP80
003o;`3jl>H2000002D0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H300000540n_3V00<0cHDo0?[`iP3j
l>H0E@3jl>H20000odd0n_3V0@3oool000030000003jl>H0n_3V04d0n_3V0P000?l/0?[`iP030000
003jl>H0n_3V02D0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H500000500n_3V00<0cHDo0?[`iP3jl>H0
D`3jl>H20000odl0n_3V0@3oool000030000003jl>H0n_3V04l0n_3V0P000?lX0?[`iP800000:03j
l>H00`3=QCl0n_3V0?[`iP1>0?[`iPD00000D03jl>H00`3=QCl0n_3V0?[`iP1A0?[`iP80003oD@3j
l>H10?ooo`0000<000000?[`iP3jl>H0D@3jl>H20000obD0n_3V00<000000?[`iP3jl>H0:03jl>H0
0`3=QCl0n_3V0?[`iP1>0?[`iPD00000D03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP80003oD`3jl>H1
0?ooo`0000<000000?[`iP3jl>H0D`3jl>H20000ob40n_3V0P00000[0?[`iP030<f5?`3jl>H0n_3V
04l0n_3V0`00001A0?[`iP030<f5?`3jl>H0n_3V04d0n_3V0P000?mE0?[`iP40oooo00000`000000
n_3V0?[`iP1E0?[`iP80003o7P3jl>H00`000000n_3V0?[`iP0[0?[`iP030<f5?`3jl>H0n_3V0500
n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP80003oE`3jl>H10?ooo`00
00<000000?[`iP3jl>H0E`3jl>H00`000?l0n_3V0?[`iP0I0?[`iP800000;P3jl>H00`3=QCl0n_3V
0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H20000oeT0n_3V
0@3oool000030000003jl>H0n_3V05P0n_3V0P000?lH0?[`iP030000003jl>H0n_3V02h0n_3V00<0
cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04L0n_3V0P00
0?mK0?[`iP40oooo00000`000000n_3V0?[`iP1J0?[`iP80003o503jl>H200000340n_3V00<0cHDo
0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04D0n_3V0P000?mM
0?[`iP40oooo00000`000000n_3V0?[`iP1L0?[`iP80003o4@3jl>H00`000000n_3V0?[`iP0a0?[`
iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP130?[`
iP80003oG`3jl>H10?ooo`0000<000000?[`iP3jl>H0GP3jl>H00`000?l0n_3V0?[`iP0<0?[`iP80
0000=03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3j
l>H0@@3jl>H20000of40n_3V0@3oool000030000003jl>H0n_3V05l0n_3V0P000?l;0?[`iP030000
003jl>H0n_3V03@0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5
?`3jl>H0n_3V03l0n_3V0P000?mS0?[`iP40oooo00000`000000n_3V0?[`iP1Q0?[`iP80003o1`3j
l>H2000003L0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3j
l>H0n_3V03h0n_3V0P000?mU0?[`iP40oooo00000`000000n_3V0?[`iP1S0?[`iP80003o103jl>H0
0`000000n_3V0?[`iP0h0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H0
0`3=QCl0n_3V0?[`iP0l0?[`iP80003oI`3jl>H10?ooo`0000<000000?[`iP3jl>H0I@3jl>H01000
0?l0n_3V00000000000k0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H0
0`3=QCl0n_3V0?[`iP0k0?[`iP030000o`3jl>H0n_3V06L0n_3V0@3oool000030000003jl>H0n_3V
06H0n_3V00<000000000o`3jl>H0>`3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V
04l0n_3V00<0cHDo0?[`iP3jl>H0>@3jl>H20000ofX0n_3V0@3oool000030000003jl>H0n_3V06@0
n_3V0P0000020?[`iP80003o>P3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0
n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000?l0n_3V0?[`iP1Z0?[`iP40oooo00000`000000n_3V
0?[`iP1S0?[`iP030000003jl>H0n_3V00@0n_3V00<0003o0?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V
0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0=P3jl>H20000ofd0n_3V
0@3oool000030000003jl>H0n_3V0640n_3V0P0000080?[`iP80003o=`3jl>H00`3=QCl0n_3V0?[`
iP1?0?[`iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0=@3jl>H20000ofl0n_3V0@3o
ool000030000003jl>H0n_3V0600n_3V00<000000?[`iP3jl>H02P3jl>H20000ocH0n_3V00<0cHDo
0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V03@0n_3V00<0003o
0?[`iP3jl>H0K`3jl>H10?ooo`0000<000000?[`iP3jl>H0GP3jl>H2000000l0n_3V00<0003o0?[`
iP3jl>H0<`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`
iP3jl>H0<P3jl>H20000og80n_3V0@3oool000030000003jl>H0n_3V05d0n_3V00<000000?[`iP3j
l>H0403jl>H20000oc<0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>0?[`iP03
0<f5?`3jl>H0n_3V0340n_3V00<0003o0?[`iP3jl>H0LP3jl>H10?ooo`0000<000000?[`iP3jl>H0
F`3jl>H2000001D0n_3V0P000?la0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0
C@3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP80003oM@3jl>H10?ooo`0000<000000?[`iP3jl>H0FP3j
l>H00`000000n_3V0?[`iP0G0?[`iP030000o`3jl>H0n_3V02l0n_3V00<0cHDo0?[`iP3jl>H0C@3j
l>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V02h0n_3V0P000?mg0?[`iP40oooo0000
0`000000n_3V0?[`iP1H0?[`iP8000006`3jl>H20000obl0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H0
0`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V02d0n_3V00<0003o0?[`iP3jl>H0M`3jl>H1
0?ooo`0000<000000?[`iP3jl>H0E`3jl>H00`000000n_3V0?[`iP0M0?[`iP80003o;@3jl>H00`3=
QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H20000
ogX0n_3V0@3oool000030000003jl>H0n_3V05D0n_3V0P00000R0?[`iP030000o`3jl>H0n_3V02X0
n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02/0
n_3V00<0003o0?[`iP3jl>H0NP3jl>H10?ooo`0000<000000?[`iP3jl>H0E03jl>H00`000000n_3V
0?[`iP0S0?[`iP80003o:`3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04`0n_3V
00<0cHDo0?[`iP3jl>H0:@3jl>H20000ogd0n_3V0@3oool000030000003jl>H0n_3V0580n_3V0P00
000X0?[`iP80003o:@3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04`0n_3V00<0
cHDo0?[`iP3jl>H09`3jl>H20000ogl0n_3V0@3oool000030000003jl>H0n_3V0540n_3V00<00000
0?[`iP3jl>H0:P3jl>H00`000?l0n_3V0?[`iP0V0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<00000
0?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0V0?[`iP030000o`3jl>H0n_3V07l0n_3V0@3oool0
00030000003jl>H0n_3V04l0n_3V0P00000^0?[`iP80003o9P3jl>H00`3=QCl0n_3V0?[`iP1<0?[`
iP030000003jl>H0n_3V04/0n_3V00<0cHDo0?[`iP3jl>H09@3jl>H20000oh80n_3V0@3oool00003
0000003jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0<03jl>H20000obD0n_3V00<0cHDo0?[`iP3j
l>H0B`3jl>H00`000000n_3V0?[`iP1;0?[`iP030<f5?`3jl>H0n_3V02@0n_3V00<0003o0?[`iP3j
l>H0PP3jl>H10?ooo`0000<000000?[`iP3jl>H0C03jl>H2000003D0n_3V00<0003o0?[`iP3jl>H0
8P3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H0
8`3jl>H20000ohD0n_3V0@3oool000030000003jl>H0n_3V04/0n_3V00<000000?[`iP3jl>H0=P3j
l>H20000ob<0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3j
l>H0n_3V0240n_3V0P000?n70?[`iP40oooo00000`000000n_3V0?[`iP190?[`iP800000>`3jl>H2
0000ob40n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0
n_3V0200n_3V00<0003o0?[`iP3jl>H0Q`3jl>H10?ooo`0000<000000?[`iP3jl>H0B03jl>H00`00
0000n_3V0?[`iP0m0?[`iP80003o7`3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V
04X0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H20000ohX0n_3V0@3oool000030000003jl>H0n_3V04H0
n_3V0P0000120?[`iP030000o`3jl>H0n_3V01`0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000
n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V01h0n_3V00<0003o0?[`iP3jl>H0RP3jl>H10?ooo`00
00<000000?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP130?[`iP80003o7@3jl>H00`3=QCl0n_3V
0?[`iP190?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3jl>H0703jl>H20000ohd0n_3V
0@3oool000030000003jl>H0n_3V04<0n_3V0P0000180?[`iP80003o703jl>H00`3=QCl0n_3V0?[`
iP180?[`iP030000003jl>H0n_3V04P0n_3V00<0cHDo0?[`iP3jl>H06`3jl>H20000ohl0n_3V0@3o
ool000030000003jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0BP3jl>H00`000?l0n_3V0?[`iP0I
0?[`iP030<f5?`3jl>H0n_3V04P0n_3V00<000000?[`iP3jl>H0A`3jl>H00`3=QCl0n_3V0?[`iP0K
0?[`iP030000o`3jl>H0n_3V08l0n_3V0@3oool000030000003jl>H0n_3V0400n_3V0P00001>0?[`
iP80003o6P3jl>H00`3=QCl0n_3V0?[`iP170?[`iP030000003jl>H0n_3V04L0n_3V00<0cHDo0?[`
iP3jl>H06@3jl>H20000oi80n_3V0@3oool000030000003jl>H0n_3V03l0n_3V00<000000?[`iP3j
l>H0D03jl>H00`000?l0n_3V0?[`iP0G0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<000000?[`iP3j
l>H0AP3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000o`3jl>H0n_3V0980n_3V0@3oool000030000
003jl>H0n_3V03d0n_3V0P00001D0?[`iP80003o603jl>H00`3=QCl0n_3V0?[`iP160?[`iP030000
003jl>H0n_3V04H0n_3V00<0cHDo0?[`iP3jl>H05`3jl>H20000oiD0n_3V0@3oool000030000003j
l>H0n_3V03`0n_3V00<000000?[`iP3jl>H0EP3jl>H00`000?l0n_3V0?[`iP0E0?[`iP030<f5?`3j
l>H0n_3V04H0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP0G0?[`iP030000o`3j
l>H0n_3V09D0n_3V0@3oool000030000003jl>H0n_3V03X0n_3V0P00001J0?[`iP80003o5P3jl>H0
0`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H05@3jl>H2
0000oiP0n_3V0@3oool000030000003jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H0G03jl>H00`00
0?l0n_3V0?[`iP0C0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0A03jl>H00`3=
QCl0n_3V0?[`iP0E0?[`iP030000o`3jl>H0n_3V09P0n_3V0@3oool000030000003jl>H0n_3V03L0
n_3V0P00001P0?[`iP80003o503jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V04@0
n_3V00<0cHDo0?[`iP3jl>H04`3jl>H20000oi/0n_3V0@3oool000030000003jl>H0n_3V03H0n_3V
00<000000?[`iP3jl>H0HP3jl>H00`000?l0n_3V0?[`iP0B0?[`iP030<f5?`3jl>H0n_3V04<0n_3V
00<000000?[`iP3jl>H0@`3jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP030000o`3jl>H0n_3V09/0n_3V
0@3oool000030000003jl>H0n_3V03@0n_3V0P00001V0?[`iP80003o4P3jl>H00`3=QCl0n_3V0?[`
iP130?[`iP030000003jl>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H04P3jl>H20000oih0n_3V0@3o
ool000030000003jl>H0n_3V03<0n_3V00<000000?[`iP3jl>H0J03jl>H00`000?l0n_3V0?[`iP0@
0?[`iP030<f5?`3jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP0A
0?[`iP030000o`3jl>H0n_3V09h0n_3V0@3oool000030000003jl>H0n_3V0340n_3V0P00001/0?[`
iP80003o4@3jl>H00`3=QCl0n_3V0?[`iP110?[`iP030000003jl>H0n_3V0440n_3V00<0cHDo0?[`
iP3jl>H0403jl>H20000oj40n_3V0@3oool000030000003jl>H0n_3V0300n_3V00<000000?[`iP3j
l>H0KP3jl>H00`000?l0n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3j
l>H0@03jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP030000o`3jl>H0n_3V0:40n_3V0@3oool000030000
003jl>H0n_3V02h0n_3V0P00001b0?[`iP80003o3`3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000
003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H03`3jl>H20000oj@0n_3V0@3oool000030000003j
l>H0n_3V02d0n_3V00<000000?[`iP3jl>H0M03jl>H00`000?l0n_3V0?[`iP0=0?[`iP030<f5?`3j
l>H0n_3V03l0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=QCl0n_3V0?[`iP0>0?[`iP030000o`3j
l>H0n_3V0:@0n_3V0@3oool000030000003jl>H0n_3V02/0n_3V0P00001h0?[`iP80003o3P3jl>H0
0`3=QCl0n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03h0n_3V00<0cHDo0?[`iP3jl>H03@3jl>H2
0000ojL0n_3V0@3oool000030000003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H0NP3jl>H20000
o``0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0m0?[`iP030<f5?`3jl>H0n_3V
00`0n_3V0P000?nY0?[`iP40oooo00000`000000n_3V0?[`iP0X0?[`iP800000O`3jl>H00`000?l0
n_3V0?[`iP0:0?[`iP030<f5?`3jl>H0n_3V03d0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3=QCl0
n_3V0?[`iP0:0?[`iP80003oZ`3jl>H10?ooo`0000<000000?[`iP3jl>H09`3jl>H00`000000n_3V
0?[`iP200?[`iP80003o2`3jl>H20<f5?cd0n_3V00<000000?[`iP3jl>H0>`3jl>H20<f5?``0n_3V
00<0003o0?[`iP3jl>H0Z`3jl>H10?ooo`0000<000000?[`iP3jl>H09@3jl>H2000008D0n_3V0P00
0?l:0?[`iP030<f5?`3jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`
iP0:0?[`iP80003o[P3jl>H10?ooo`0000<000000?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP27
0?[`iP030000o`3jl>H0n_3V00P0n_3V00<0cHDo0?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP0j
0?[`iP030<f5?`3jl>H0n_3V00P0n_3V0P000?n`0?[`iP40oooo00000`000000n_3V0?[`iP0R0?[`
iP800000R`3jl>H20000o`T0n_3V00<0cHDo0?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP0i0?[`
iP030<f5?`3jl>H0n_3V00L0n_3V0P000?nb0?[`iP40oooo00000`000000n_3V0?[`iP0Q0?[`iP03
0000003jl>H0n_3V08d0n_3V0P000?l80?[`iP030<f5?`3jl>H0n_3V03P0n_3V00<000000?[`iP3j
l>H0>03jl>H00`3=QCl0n_3V0?[`iP070?[`iP030000o`3jl>H0n_3V0;80n_3V0@3oool000030000
003jl>H0n_3V01l0n_3V0P00002B0?[`iP030000o`3jl>H0n_3V00H0n_3V00<0cHDo0?[`iP3jl>H0
=`3jl>H00`000000n_3V0?[`iP0g0?[`iP030<f5?`3jl>H0n_3V00H0n_3V0P000?ne0?[`iP40oooo
00000`000000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V09<0n_3V0P000?l70?[`iP80cHDo=`3j
l>H00`000000n_3V0?[`iP0e0?[`iP80cHDo1`3jl>H20000okL0n_3V0@3oool000030000003jl>H0
n_3V01`0n_3V0P00002H0?[`iP80003o1P3jl>H00`3=QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0
n_3V03@0n_3V00<0cHDo0?[`iP3jl>H01@3jl>H20000okT0n_3V0@3oool000030000003jl>H0n_3V
01/0n_3V00<000000?[`iP3jl>H0VP3jl>H00`000?l0n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V
03@0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000o`3jl>H0n_3V
0;T0n_3V0@3oool000030000003jl>H0n_3V01T0n_3V0P00002N0?[`iP80003o1@3jl>H20<f5?c@0
n_3V00<000000?[`iP3jl>H0<P3jl>H20<f5?`D0n_3V0P000?nl0?[`iP40oooo00000`000000n_3V
0?[`iP0H0?[`iP030000003jl>H0n_3V0:00n_3V0P000?l50?[`iP030<f5?`3jl>H0n_3V0340n_3V
00<000000?[`iP3jl>H0<@3jl>H00`3=QCl0n_3V0?[`iP030?[`iP80003o_P3jl>H10?ooo`0000<0
00000?[`iP3jl>H05P3jl>H200000:D0n_3V00<0003o0?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`
iP0`0?[`iP030000003jl>H0n_3V0300n_3V00<0cHDo0?[`iP3jl>H00P3jl>H20000ol00n_3V0@3o
ool000030000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0YP3jl>H20000o`@0n_3V00<0cHDo
0?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0_0?[`iP040<f5?`3jl>H0n_3V0?[`iP80003o`P3j
l>H10?ooo`0000<000000?[`iP3jl>H04`3jl>H200000:/0n_3V0P000?l30?[`iP80cHDo;`3jl>H0
0`000000n_3V0?[`iP0]0?[`iP80cHDo0`3jl>H00`000?l0n_3V0?[`iP320?[`iP40oooo00000`00
0000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V0:d0n_3V0P000?l30?[`iP030<f5?`3jl>H0n_3V
02`0n_3V00<000000?[`iP3jl>H0;03jl>H0103=QCl0n_3V0?[`iP3jl>H20000olD0n_3V0@3oool0
00030000003jl>H0n_3V0100n_3V0P00002b0?[`iP80003o0P3jl>H20<f5?b`0n_3V00<000000?[`
iP3jl>H0:P3jl>H20<f5?`80n_3V0P000?o70?[`iP40oooo00000`000000n_3V0?[`iP0?0?[`iP03
0000003jl>H0n_3V0;@0n_3V0P000?l20?[`iP80cHDo:P3jl>H00`000000n_3V0?[`iP0X0?[`iP80
cHDo0P3jl>H20000olT0n_3V0@3oool000030000003jl>H0n_3V00d0n_3V0P00002i0?[`iP80003o
0P3jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V02L0n_3V00<0cHDo0?[`iP3jl>H0
0P000?o;0?[`iP40oooo00000`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V0;/0n_3V0P00
0?l00`3jl>H0cHDo0<f5?`0W0?[`iP030000003jl>H0n_3V02D0n_3V0P3=QCl00`3jl>H0003o0000
o`3=0?[`iP40oooo00000`000000n_3V0?[`iP0:0?[`iP800000`03jl>H30000o`80cHDo9@3jl>H0
0`000000n_3V0?[`iP0S0?[`iP80cHDo00<0n_3V0000o`000?l0c`3jl>H10?ooo`0000<000000?[`
iP3jl>H02@3jl>H00`000000n_3V0?[`iP330?[`iP<0003o00<0cHDo0?[`iP3jl>H08@3jl>H00`00
0000n_3V0?[`iP0Q0?[`iP80cHDo00<0n_3V0000o`000?l0d@3jl>H10?ooo`0000<000000?[`iP3j
l>H01`3jl>H200000<T0n_3V0P000?l00`3=QCl0n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V01l0
n_3V0P3=QCl30000om<0n_3V0@3oool000030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0
b`3jl>H30000oal0n_3V00<000000?[`iP3jl>H07@3jl>H20<f5?`80003oeP3jl>H10?ooo`0000<0
00000?[`iP3jl>H0103jl>H200000=40n_3V0`000?l00`3=QCl0n_3V0?[`iP0I0?[`iP030000003j
l>H0n_3V01T0n_3V0`3=QCl30000omP0n_3V0@3oool000030000003jl>H0n_3V00<0n_3V00<00000
0?[`iP3jl>H0e03jl>H30000oaT0n_3V00<000000?[`iP3jl>H05`3jl>H00`3=QCl0003o0000o`02
0000om/0n_3V0@3oool000040000003jl>H0n_3V0?[`iP800000fP3jl>H40000oaD0n_3V00<00000
0?[`iP3jl>H04`3jl>H00`3=QCl0003o0000o`020000oml0n_3V0@3oool000040000003jl>H0n_3V
00000>00n_3V10000?lA0?[`iP030000003jl>H0n_3V00l0n_3V00<0cHDo0000o`000?l00P000?oS
0?[`iP40oooo000300000>D0n_3V10000?l=0?[`iP030000003jl>H0n_3V00/0n_3V1@000?oW0?[`
iP40oooo000200000>X0cHDo3@000?l00`000000003o0000o`0;0000on/0cHDo0@3jl>H10?ooo`00
0P00003o0?[`i_80n_3V0@3oool000030000003jl>H0n_3V0?l0n_3Vl@3jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo002f0?[`iP80000000<0IV9N0<c4^`3jl>H0:`3j
l>H01P3Dc<<0IV9N000000000000RHAn0>CKdVD0n_3V00H0e<c306IRGP000000000008V4OP3Tfm:L
0?[`iP40oooo002h0?[`iP0306IRGP000000g=C;02/0n_3V00H0C4U50<>k/`3jl>H0k>;I00000029
Q7iU0?[`iP0604a9A@33^k<0n_3V0>cRf@000000RHAnW03jl>H10?ooo`00P`3jl>H2000000<0n_3V
0P0000020?[`iP8000000P3jl>H0102_Z:40C4U500000029Q7h70?[`iP060=cDb`1iMG0000000000
0029Q7h0c<Bk0P3jl>H0102_Z:40C4U500000029Q7h20?[`iP8000000P3jl>H2000000050?[`iP3<
a;/0000007UeL03jl>H00P0000020?[`iP80000000<0IV9N0?[`iP3jl>H01`3jl>H2000000<0n_3V
00@0c<Bk04a9A@1VHUh0i=_B0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H200000004
0?[`iP00000000000?[`iP8000000P3jl>H200000080n_3V00<0RHAn06IRGP3<a;/00P0000070?[`
iP050=cDb`1iMG00000004a9A@2TWIH00P3jl>H0103<a;/0C4U506IRGP3Tfm82000000030?[`iP00
0000000000@0n_3V00<0Y9fF0000002TWIH00`3jl>H0102_Z:40C4U500000029Q7h70?[`iP040:nX
X@1<BDD0C4U50:nXX@80n_3V0P0000060?[`iP80000000D0n_3V0<>k/`000000`k^c0?[`iP020000
00050?[`iP3<a;/0C4U504a9A@2_Z:400P0000000`3jl>H00000000000030?[`iP80000000D0n_3V
0<c4^`1<BDD0C4U50:nXX@02000000@0n_3V0P0000000`3/h]T0n_3V0>cRf@0200000080n_3V00<0
RHAn06IRGP3<a;/00P0000000`3jl>H00000000000020?[`iP8000000P3jl>H0102_Z:40C4U50000
0029Q7h20?[`iP070>cRf@2GTH/000000000001iMG00i=_B0?[`iP02000008@0n_3V0@3oool008<0
n_3V0P0000030?[`iP8000000P3jl>H2000000070?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP05
0?[`iP050>CKdP000000Ui6;0?[`iP2i/ZX00P000000203jl>H0[jRQ00000033^k<0i=_B00000029
Q7h0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP3<a;/00000
0080000000<0i=_B0?[`iP3jl>H01P3jl>H2000000<0n_3V00@0IV9N0000003Tfm80^K:Z0P000000
0`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3j
l>H2000000050?[`iP2TWIH000000<>k/`2TWIH00P0000060?[`iP0<0>CKdP000000Ui6;0?[`iP3D
c<<0000008V4OP3jl>H0IV9N0000003Tfm80^K:Z0P0000000`3jl>H00000000000040?[`iP<00000
00P0k>;I0?[`iP2_Z:4000000<>k/`3Tfm80000008V4OPD0n_3V00L0^K:Z00000033^k<0`k^c0000
002i/ZX0n_3V008000001P3jl>H2000000050?[`iP2GTH/0000009NAR`3jl>H00P0000001@3jl>H0
C4U50000003Tfm80`k^c0080000000<0n_3V0000000000000`3jl>H2000000050?[`iP1<BDD00000
0>CKdP33^k<00P0000040?[`iP0<08V4OP000000e<c30?[`iP3Dc<<0000008V4OP3jl>H0Y9fF0000
0033^k<0Y9fF0P0000000`3jl>H00000000000020?[`iP80000000l0n_3V0:nXX@000000`k^c0>CK
dP000000RHAn0?[`iP1iMG0000000>CKdP3/h]T0000006IRGP3jl>H00P0000240?[`iP40oooo0023
0?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0C4U5000000090?[`iP0309NAR`000000
g=C;0080n_3V0P0000000`3jl>H0C4U5000000050?[`iP8000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000001P3jl>H0Ui6;00000029Q7h000000:nXX@P0n_3V0P0000030?[`iP800000
0P3jl>H2000000030?[`iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000
n_3V0P0000020?[`iP80000000<0n_3V04a9A@0000000P3jl>H2000000H0n_3V00<0Ui6;0000003T
fm801@3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP080;VbZP000000RHAn0000
002i/ZX0n_3V04a9A@0000090?[`iP0706IRGP000000n_3V0?[`iP000000IV9N0?[`iP02000000H0
n_3V0P0000001@3jl>H0C4U50000001<BDD0n_3V0080000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000<0n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H00`2_
Z:40000000000003000000040:nXX@3jl>H0C4U500000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V04a9A@0000001`3jl>H01@3Dc<<0Y9fF0000001<BDD0n_3V00800000Q03j
l>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V00000000000010000005
0?[`iP0304a9A@000000n_3V0080n_3V0P0000000`3jl>H0000000000004000000030?[`iP000000
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000H0n_3V04a9A@000000k>;I0000
001VHUh80?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP800000
0P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000060?[`iP8000001P3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP80
C4U500@0k>;I04a9A@1<BDD0n_3V1P0000050?[`iP8000000P3jl>H2000000030?[`iP0000000000
00H0n_3V0P0000001@3Tfm80000009NAR`000000i=_B0080000000D0n_3V0<c4^`000000Ui6;0>CK
dP02000000030?[`iP000000000000<0n_3V0P0000001@3jl>H0c<Bk0000002GTH/0i=_B00800000
103jl>H0203Dc<<0000008V4OP3jl>H0Ui6;0000003Dc<<0n_3V0P0000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP000000000000@0000000<0n_3V0<c4^`1<BDD00P000000
0`1<BDD0c<Bk0?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H20000
00030?[`iP1<BDD000000080n_3V00<0000006IRGP3jl>H0103jl>H200000080n_3V0`0000000`3j
l>H0C4U5000000020?[`iP030000001VHUh0n_3V008000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000001`3Le</0000008V4OP3jl>H0RHAn0000003Tfm801`3jl>H2000000<0n_3V0P00
00020?[`iP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000
003jl>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP8000001P3jl>H2000000H0n_3V
0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H02@3<a;/000000:BMUP3jl>H0Y9fF0000
003<a;/0C4U5000000020?[`iP030000001VHUh0n_3V00@0n_3V00L0IV9N0000003jl>H0n_3V0000
001VHUh0n_3V008000001P3jl>H2000000050<c4^`000000g=C;0000003<a;/00P0000020?[`iP03
0=cDb`2_Z:40NGE`0080000000<0n_3V0000000000000`3jl>H200000080n_3V00<0g=C;0:nXX@1i
MG000P0000050?[`iP050000001<BDD0n_3V04a9A@0000000P3jl>H0101<BDD000000?[`iP3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP070000001VHUh0
n_3V04a9A@000000NGE`0<c4^`030?[`iP800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P00
00002`2TWIH0i=_B0000001VHUh0n_3V0;VbZP000000`k^c0<c4^`000000^K:Z00D0n_3V00<0C4U5
0000003jl>H01@3jl>H01`2i/ZX000000<>k/`3<a;/000000;VbZP3jl>H00P0000001@2i/ZX0i=_B
0000001<BDD0n_3V008000000P3jl>H2000000070:nXX@000000`k^c0?[`iP33^k<000000:nXX@07
0?[`iP8000000`3jl>H200000080n_3V0P000000103jl>H000000000003Dc<<20?[`iP80000000D0
^K:Z0>CKdP000000C4U50?[`iP020000000<0?[`iP00000000000;VbZP3Tfm80000004a9A@3jl>H0
Y9fF00000033^k<0Y9fF0P0000060?[`iP0304a9A@000000n_3V00D0n_3V0P0000020?[`iP800000
0180n_3V000000000000e<c30?[`iP1VHUh000000>cRf@3jl>H0k>;I0000001VHUh0^K:Z00000033
^k<0c<Bk0000002i/ZX50?[`iP070;VbZP000000`k^c0<>k/`000000^K:Z0?[`iP02000000H0n_3V
0P0000001@2TWIH0IV9N0?[`iP1VHUh0Y9fF0080000000P0n_3V07UeL03Dc<<0n_3V0>CKdP000000
C4U50?[`iP80000000<0e<c30?[`iP3jl>H00P0000001`3jl>H0NGE`0=C<``3jl>H0i=_B0000001<
BDD01@3jl>H01@1iMG0000000<c4^`000000IV9N0080n_3V00@0Y9fF00000033^k<0Y9fF0P000000
5P3jl>H000000000002i/ZX0i=_B0000001<BDD0n_3V0;VbZP000000`k^c0<c4^`000000^K:Z0?[`
iP1VHUh000000?[`iP3Tfm80000007UeL03jl>H2000008@0n_3V0@3oool008<0n_3V0P0000030?[`
iP80000000@0g=C;08V4OP1<BDD0c<Bk0P3jl>H0102_Z:4000000000002_Z:460?[`iP0309NAR`00
0000i=_B00H0n_3V00@0[jRQ000000000000[jRQ0P3jl>H2000000040<c4^`1iMG00C4U50<c4^`@0
000000X0n_3V000000000000IV9N0000003/h]T0n_3V0>cRf@000000IV9N1`3jl>H2000000<0n_3V
0P0000020?[`iP80000000H0n_3V000000000000RHAn07UeL03jl>H2000000050<c4^`1iMG00C4U5
0<c4^`3jl>H00P0000001`3jl>H000000000003<a;/0NGE`04a9A@3<a;/00P3jl>H00`29Q7h0IV9N
0<c4^`02000000H0n_3V00<0Ui6;0000003Tfm801@3jl>H200000080n_3V0P000000103jl>H00000
00000029Q7h20000000808V4OP3jl>H0n_3V0?[`iP29Q7h000000=cDb`2_Z:42000000030:nXX@3j
l>H0n_3V00D0n_3V00D0[jRQ04a9A@000000[jRQ0?[`iP04000000D0n_3V0P0000001@1VHUh0Y9fF
0?[`iP2GTH/0IV9N0080000000<0n_3V0>CKdP29Q7h00P0000000`1VHUh0e<c30?[`iP0200000003
08V4OP1iMG00n_3V0080000000<0n_3V0>CKdP29Q7h00P0000000`1VHUh0e<c30?[`iP040?[`iP05
0:BMUP000000RHAn0000002TWIH00`3jl>H00`29Q7h0IV9N0<c4^`02000000070?[`iP0000000000
0<c4^`1iMG00C4U50<c4^`020?[`iP040:nXX@00000000000:nXX@80n_3V00L0i=_B07UeL0000000
000008V4OP3Tfm80n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P00000@0?[`iP07
0>CKdP000000Ui6;0?[`iP3Dc<<0000007UeL00?0?[`iP8000000P3jl>H2000000h0n_3V0P00000/
0?[`iP070>CKdP000000Ui6;0?[`iP3Dc<<0000008V4OP0U0?[`iP8000001P3jl>H3000000030<c4
^`3jl>H0`k^c00<000006`3jl>H01@3<a;/00000000000000000`k^c0:@0n_3V0@3oool00840n_3V
1P0000000`3jl>H000000000000A0?[`iP060=cDb`1iMG0000000000002GTH/0k>;I3`3jl>H0103L
e</0RHAn0?[`iP3jl>H2000000`0n_3V1P00000D0?[`iP8000005@3jl>H01@3Le</0NGE`00000000
0000Y9fF02H0n_3V00@0c<Bk06IRGP000000RHAn103jl>H3000000030>cRf@3jl>H0g=C;00<00000
3@3jl>H2000000`0n_3V00D0k>;I00000000000000000>CKdP0N0?[`iP800000Q03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.04348 .38333 L
s
.04348 .05 m
.04348 .38333 L
s
.34125 .16591 m
.04348 .16591 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.04348 .38333 Mdot
.34125 .16591 Mdot
.04348 .16591 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool001H0n_3V00<000000?[`iP3jl>H0e03jl>H:0<f5
?`<000000P3jl>H:0<f5?nd0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0cP3jl>H60<f5?`T0
n_3V00@000000?[`iP3jl>H00000303jl>H70<f5?nH0n_3V0@3oool001H0n_3V00<000000?[`iP3j
l>H0c03jl>H20<f5?`h0n_3V00D000000?[`iP3jl>H0n_3V0000000C0?[`iP80cHDoi03jl>H10?oo
o`005P3jl>H00`000000n_3V0?[`iP380?[`iP@0cHDo3P3jl>H2000000@0n_3V00<000000?[`iP3j
l>H04`3jl>H30<f5?n40n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0a03jl>H40<f5?a40n_3V
00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0F0?[`iP@0cHDog@3jl>H10?ooo`005P3j
l>H00`000000n_3V0?[`iP320?[`iP80cHDo503jl>H00`000000n_3V0?[`iP050?[`iP030000003j
l>H0n_3V01X0n_3V0P3=QCoK0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V0<00n_3V0P3=QClD
0?[`iP800000203jl>H00`000000n_3V0?[`iP0L0?[`iP80cHDof@3jl>H10?ooo`005P3jl>H00`00
0000n_3V0?[`iP2n0?[`iP80cHDo5@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
01h0n_3V0P3=QCoG0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V0;`0n_3V0P3=QClF0?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0803jl>H20<f5?mD0n_3V0@3oool001H0n_3V
00<000000?[`iP3jl>H0^P3jl>H20<f5?aH0n_3V0P00000<0?[`iP030000003jl>H0n_3V0280n_3V
0P3=QCoC0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V0;P0n_3V0P3=QClG0?[`iP030000003j
l>H0n_3V00`0n_3V00<000000?[`iP3jl>H0903jl>H20<f5?m40n_3V0@3oool001H0n_3V00<00000
0?[`iP3jl>H0]P3jl>H20<f5?aL0n_3V0P00000?0?[`iP030000003jl>H0n_3V02H0n_3V0P3=QCo?
0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V0;D0n_3V00<0cHDo0?[`iP3jl>H05P3jl>H00`00
0000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V02P0n_3V00<0cHDo0?[`iP3jl>H0c03jl>H10?oo
o`005P3jl>H00`000000n_3V0?[`iP2c0?[`iP80cHDo603jl>H00`000000n_3V0?[`iP0@0?[`iP03
0000003jl>H0n_3V02T0n_3V0P3=QCo<0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V0;40n_3V
0P3=QClH0?[`iP8000004`3jl>H00`000000n_3V0?[`iP0[0?[`iP80cHDobP3jl>H10?ooo`005P3j
l>H00`000000n_3V0?[`iP2`0?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H04`3j
l>H00`000000n_3V0?[`iP0]0?[`iP030<f5?`3jl>H0n_3V0<L0n_3V0@3oool001H0n_3V00<00000
0?[`iP3jl>H0[P3jl>H20<f5?aT0n_3V00<000000?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP0^
0?[`iP80cHDoa`3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP2]0?[`iP030<f5?`3jl>H0n_3V
01L0n_3V0P00000G0?[`iP030000003jl>H0n_3V0300n_3V00<0cHDo0?[`iP3jl>H0a03jl>H10?oo
o`005P3jl>H00`000000n_3V0?[`iP2/0?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<000000?[`iP3j
l>H05`3jl>H00`000000n_3V0?[`iP0a0?[`iP030<f5?`3jl>H0n_3V0<<0n_3V0@3oool001H0n_3V
00<000000?[`iP3jl>H0Z`3jl>H00`3=QCl0n_3V0?[`iP0F0?[`iP8000006P3jl>H00`000000n_3V
0?[`iP0b0?[`iP030<f5?`3jl>H0n_3V0<80n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0Z@3j
l>H20<f5?aP0n_3V00<000000?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP0c0?[`iP80cHDo`P3j
l>H10?ooo`005P3jl>H00`000000n_3V0?[`iP2X0?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<00000
0?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP0d0?[`iP030<f5?`3jl>H0n_3V0<00n_3V0@3oool0
01H0n_3V00<000000?[`iP3jl>H0Y`3jl>H00`3=QCl0n_3V0?[`iP0F0?[`iP8000007P3jl>H00`00
0000n_3V0?[`iP0e0?[`iP030<f5?`3jl>H0n_3V0;l0n_3V0@3oool001H0n_3V00<000000?[`iP3j
l>H0YP3jl>H00`3=QCl0n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3j
l>H0=P3jl>H20<f5?kl0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0Y@3jl>H00`3=QCl0n_3V
0?[`iP0F0?[`iP030000003jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0>03jl>H00`3=QCl0n_3V
0?[`iP2l0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V0:@0n_3V00<0cHDo0?[`iP3jl>H05@3j
l>H200000280n_3V00<000000?[`iP3jl>H0>@3jl>H00`3=QCl0n_3V0?[`iP2k0?[`iP40oooo000F
0?[`iP030000003jl>H0n_3V0:<0n_3V00<0cHDo0?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0R
0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H0^P3jl>H10?ooo`005P3jl>H00`00
0000n_3V0?[`iP2R0?[`iP030<f5?`3jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H08`3jl>H00`00
0000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V0;X0n_3V0@3oool001H0n_3V00<000000?[`iP3j
l>H0X@3jl>H00`3=QCl0n_3V0?[`iP0D0?[`iP8000009P3jl>H00`000000n_3V0?[`iP0k0?[`iP03
0<f5?`3jl>H0n_3V0;T0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0X03jl>H00`3=QCl0n_3V
0?[`iP0D0?[`iP030000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0?03jl>H20<f5?kT0n_3V
0@3oool001H0n_3V00<000000?[`iP3jl>H0W`3jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP800000:@3j
l>H00`000000n_3V0?[`iP0m0?[`iP030<f5?`3jl>H0n_3V0;L0n_3V0@3oool001H0n_3V00<00000
0?[`iP3jl>H0W`3jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V02T0n_3V00<00000
0?[`iP3jl>H0?P3jl>H00`3=QCl0n_3V0?[`iP2f0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V
09h0n_3V00<0cHDo0?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V
03l0n_3V00<0cHDo0?[`iP3jl>H0]@3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP2M0?[`iP03
0<f5?`3jl>H0n_3V0140n_3V0P00000]0?[`iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3j
l>H0]@3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP2M0?[`iP030<f5?`3jl>H0n_3V0100n_3V
00<000000?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP100?[`iP030<f5?`3jl>H0n_3V0;@0n_3V
0@3oool001H0n_3V00<000000?[`iP3jl>H0W03jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP030000003j
l>H0n_3V02h0n_3V00<000000?[`iP3jl>H0@@3jl>H00`3=QCl0n_3V0?[`iP2c0?[`iP40oooo000F
0?[`iP030000003jl>H0n_3V09/0n_3V00<0cHDo0?[`iP3jl>H03`3jl>H200000340n_3V00<00000
0?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP2b0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V
09X0n_3V00<0cHDo0?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP0a0?[`iP030000003jl>H0n_3V
04<0n_3V00<0cHDo0?[`iP3jl>H0/@3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP2I0?[`iP03
0<f5?`3jl>H0n_3V00h0n_3V0P00000d0?[`iP030000003jl>H0n_3V04<0n_3V00<0cHDo0?[`iP3j
l>H0/@3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP2I0?[`iP030<f5?`3jl>H0n_3V00d0n_3V
00<000000?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0n_3V0;00n_3V
0@3oool001H0n_3V00<000000?[`iP3jl>H0V03jl>H00`3=QCl0n_3V0?[`iP0=0?[`iP030000003j
l>H0n_3V03D0n_3V00<000000?[`iP3jl>H0A03jl>H00`3=QCl0n_3V0?[`iP2`0?[`iP40oooo000F
0?[`iP030000003jl>H0n_3V09P0n_3V00<0cHDo0?[`iP3jl>H02`3jl>H2000003P0n_3V00<00000
0?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP2_0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V
09L0n_3V00<0cHDo0?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V
04D0n_3V00<0cHDo0?[`iP3jl>H0[`3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP2G0?[`iP03
0<f5?`3jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP160?[`iP03
0<f5?`3jl>H0n_3V0:h0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0UP3jl>H00`3=QCl0n_3V
0?[`iP090?[`iP800000?03jl>H00`000000n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V0:h0n_3V
0@3oool001H0n_3V00<000000?[`iP3jl>H0UP3jl>H00`3=QCl0n_3V0?[`iP080?[`iP030000003j
l>H0n_3V03`0n_3V00<000000?[`iP3jl>H0A`3jl>H00`3=QCl0n_3V0?[`iP2]0?[`iP40oooo000F
0?[`iP030000003jl>H0n_3V09D0n_3V00<0cHDo0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0m
0?[`iP030000003jl>H0n_3V04P0n_3V00<0cHDo0?[`iP3jl>H0[03jl>H10?ooo`005P3jl>H00`00
0000n_3V0?[`iP2D0?[`iP030<f5?`3jl>H0n_3V00L0n_3V0P0000100?[`iP030000003jl>H0n_3V
04P0n_3V00<0cHDo0?[`iP3jl>H0[03jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP2D0?[`iP03
0<f5?`3jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP190?[`iP03
0<f5?`3jl>H0n_3V0:/0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0T`3jl>H00`3=QCl0n_3V
0?[`iP050?[`iP800000@`3jl>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V0:/0n_3V
0@3oool001H0n_3V00<000000?[`iP3jl>H0T`3jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000003j
l>H0n_3V04<0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2Z0?[`iP40oooo0002
0000oa@0n_3V00<000000?[`iP3jl>H0T`3jl>H00`3=QCl0n_3V0?[`iP030?[`iP030000003jl>H0
n_3V04@0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2W0?[`iP80003o0@3jl>H1
0?ooo`000P3jl>H30000oa40n_3V00<000000?[`iP3jl>H0T`3jl>H0103=QCl0n_3V0?[`iP3jl>H2
000004L0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2T0?[`iP<0003o0`3jl>H1
0?ooo`001@3jl>H40000o`d0n_3V00<000000?[`iP3jl>H0TP3jl>H01@3=QCl0n_3V0?[`iP3jl>H0
000004T0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2P0?[`iP@0003o1P3jl>H1
0?ooo`002@3jl>H30000o`X0n_3V00<000000?[`iP3jl>H0TP3jl>H0103=QCl0n_3V0?[`iP00001:
0?[`iP030000003jl>H0n_3V04/0n_3V00<0cHDo0?[`iP3jl>H0W03jl>H30000o`X0n_3V0@3oool0
00`0n_3V0`000?l60?[`iP<00000T@3jl>H5000004/0n_3V00<000000?[`iP3jl>H0B`3jl>H00`3=
QCl0n_3V0?[`iP2I0?[`iP<0003o3@3jl>H10?ooo`003`3jl>H40000o`030?[`iP000000000000<0
0000S`3jl>H5000004`0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP2D0?[`iP@0
003o403jl>H10?ooo`004`3jl>H00`000?l000000000002G000004`0n_3V00<000000?[`iP3jl>H0
C03jl>H00`3=QCl0n_3V0?[`iP2A0?[`iP<0003o503jl>H10?ooo`00503jl>H5000008l0n_3V1@00
001<0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0SP3jl>H30000oaL0n_3V0@3o
ool001D0n_3V0`000000103jl>H0003o0000o`000?n;0?[`iP030000003jl>H0000000800000C@3j
l>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V08/0n_3V0`000?lJ0?[`iP40oooo000F
0?[`iP030000003jl>H0n_3V00<0n_3V0`000?n60?[`iP8000000P3jl>H00`3=QCl0n_3V0?[`iP1=
0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0Q`3jl>H30000oad0n_3V0@3oool0
01H0n_3V00<000000?[`iP3jl>H01P3jl>H40000oh40n_3V00<000000?[`iP3jl>H00P3jl>H00`3=
QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0Q03jl>H30000
ob00n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H02P3jl>H30000ogd0n_3V00<000000?[`iP3j
l>H00`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3j
l>H0P@3jl>H30000ob<0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H03@3jl>H30000ogP0n_3V
0P0000050?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V
0?[`iP1n0?[`iP<0003o9P3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0@0?[`iP<0003oM03j
l>H00`000000n_3V0?[`iP050?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3j
l>H00`3=QCl0n_3V0?[`iP1j0?[`iP<0003o:@3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0C
0?[`iP80003oL@3jl>H00`000000n_3V0?[`iP060?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<00000
0?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP1h0?[`iP80003o;03jl>H10?ooo`005P3jl>H00`00
0000n_3V0?[`iP0E0?[`iP80003oK@3jl>H2000000T0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`00
0000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V07H0n_3V0P000?l^0?[`iP40oooo000F0?[`iP03
0000003jl>H0n_3V01L0n_3V0`000?mY0?[`iP030000003jl>H0n_3V00P0n_3V00<0cHDo0?[`iP3j
l>H0C`3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V07<0n_3V0`000?l`0?[`iP40
oooo000F0?[`iP030000003jl>H0n_3V01X0n_3V0P000?mU0?[`iP8000002`3jl>H00`3=QCl0n_3V
0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0L03jl>H20000oc<0n_3V
0@3oool001H0n_3V00<000000?[`iP3jl>H0703jl>H20000of80n_3V00<000000?[`iP3jl>H02`3j
l>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0KP3j
l>H20000ocD0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H07P3jl>H30000oeh0n_3V00<00000
0?[`iP3jl>H0303jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo
0?[`iP3jl>H0J`3jl>H30000ocL0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H08@3jl>H20000
oeX0n_3V0P00000?0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=
QCl0n_3V0?[`iP1Y0?[`iP80003o>P3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0S0?[`iP80
003oE`3jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3j
l>H0C`3jl>H00`3=QCl0n_3V0?[`iP1W0?[`iP80003o?03jl>H10?ooo`005P3jl>H00`000000n_3V
0?[`iP0U0?[`iP<0003oD`3jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V0500n_3V
00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1T0?[`iP<0003o?P3jl>H10?ooo`005P3j
l>H00`000000n_3V0?[`iP0X0?[`iP80003oC`3jl>H200000180n_3V00<0cHDo0?[`iP3jl>H0D03j
l>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V0640n_3V0P000?m10?[`iP40oooo000F
0?[`iP030000003jl>H0n_3V02X0n_3V0P000?m<0?[`iP030000003jl>H0n_3V0180n_3V00<0cHDo
0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05l0n_3V0P000?m3
0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V02`0n_3V0P000?m90?[`iP030000003jl>H0n_3V
01<0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V
05d0n_3V0P000?m50?[`iP40oooo000F0?[`iP030000003jl>H0n_3V02h0n_3V0P000?m50?[`iP80
00005P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3j
l>H0F`3jl>H20000odL0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0<03jl>H30000od40n_3V
00<000000?[`iP3jl>H05P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V
00<0cHDo0?[`iP3jl>H0F@3jl>H20000odT0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0<`3j
l>H20000ocd0n_3V0P00000I0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03j
l>H00`3=QCl0n_3V0?[`iP1G0?[`iP80003oB`3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0e
0?[`iP80003o>P3jl>H00`000000n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V04l0n_3V0`00001A
0?[`iP030<f5?`3jl>H0n_3V05D0n_3V0P000?m=0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V
03L0n_3V0P000?lg0?[`iP030000003jl>H0n_3V01X0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H50000
0500n_3V00<0cHDo0?[`iP3jl>H0D`3jl>H20000odl0n_3V0@3oool001H0n_3V00<000000?[`iP3j
l>H0>@3jl>H20000oc<0n_3V0P00000M0?[`iP030<f5?`3jl>H0n_3V04h0n_3V1@00001@0?[`iP03
0<f5?`3jl>H0n_3V0540n_3V0P000?mA0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V03/0n_3V
0P000?l`0?[`iP030000003jl>H0n_3V01d0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H500000500n_3V
00<0cHDo0?[`iP3jl>H0C`3jl>H20000oe<0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0?@3j
l>H20000obd0n_3V00<000000?[`iP3jl>H07P3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP<00000D@3j
l>H00`3=QCl0n_3V0?[`iP1=0?[`iP80003oE@3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0o
0?[`iP80003o:@3jl>H200000240n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@
0?[`iP030<f5?`3jl>H0n_3V04/0n_3V0P000?mG0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V
0440n_3V00<0003o0?[`iP3jl>H09@3jl>H00`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V
0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP190?[`iP80003oF@3jl>H10?oo
o`005P3jl>H00`000000n_3V0?[`iP120?[`iP80003o8`3jl>H2000002@0n_3V00<0cHDo0?[`iP3j
l>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04L0n_3V0P000?mK0?[`iP40
oooo000F0?[`iP030000003jl>H0n_3V04@0n_3V0P000?lP0?[`iP030000003jl>H0n_3V02@0n_3V
00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04D0n_3V
0P000?mM0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V04H0n_3V0P000?lM0?[`iP030000003j
l>H0n_3V02D0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3j
l>H0n_3V04<0n_3V0P000?mO0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V04P0n_3V00<0003o
0?[`iP3jl>H0603jl>H2000002P0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@
0?[`iP030<f5?`3jl>H0n_3V0440n_3V0P000?mQ0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V
04T0n_3V0P000?lG0?[`iP030000003jl>H0n_3V02P0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`00
0000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V03l0n_3V0P000?mS0?[`iP40oooo000F0?[`iP03
0000003jl>H0n_3V04/0n_3V0P000?lD0?[`iP030000003jl>H0n_3V02T0n_3V00<0cHDo0?[`iP3j
l>H0D03jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V03h0n_3V0P000?mU0?[`iP40
oooo000F0?[`iP030000003jl>H0n_3V04d0n_3V0P000?l@0?[`iP800000;@3jl>H00`3=QCl0n_3V
0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0?03jl>H20000ofL0n_3V
0@3oool001H0n_3V00<000000?[`iP3jl>H0C`3jl>H00`000?l0n_3V0?[`iP0<0?[`iP030000003j
l>H0n_3V02d0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3j
l>H0n_3V03/0n_3V00<0003o0?[`iP3jl>H0I`3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP1@
0?[`iP80003o2`3jl>H00`000000n_3V0?[`iP0^0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<00000
0?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP80003oJP3jl>H10?ooo`005P3jl>H00`00
0000n_3V0?[`iP1B0?[`iP80003o1`3jl>H200000340n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`00
0000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V03P0n_3V00<0003o0?[`iP3jl>H0JP3jl>H10?oo
o`005P3jl>H00`000000n_3V0?[`iP1D0?[`iP030000o`3jl>H0n_3V00<0n_3V00<000000?[`iP3j
l>H0<@3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3j
l>H0=P3jl>H20000ofd0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0E@3jl>H20000o`030?[`
iP000000000003@0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5
?`3jl>H0n_3V03D0n_3V0P000?m_0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V05L0n_3V00<0
00000000o`3jl>H0=@3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04h0n_3V00<0
cHDo0?[`iP3jl>H0=03jl>H00`000?l0n_3V0?[`iP1_0?[`iP40oooo000F0?[`iP030000003jl>H0
n_3V05H0n_3V00@000000?[`iP3jl>H0003o=@3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003j
l>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0<P3jl>H20000og80n_3V0@3oool001H0n_3V00<00000
0?[`iP3jl>H0E03jl>H2000000@0n_3V0P000?lc0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<00000
0?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0a0?[`iP030000o`3jl>H0n_3V0780n_3V0@3oool0
01H0n_3V00<000000?[`iP3jl>H0D`3jl>H00`000000n_3V0?[`iP060?[`iP80003o<@3jl>H00`3=
QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0<03jl>H20000
ogD0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0DP3jl>H00`000000n_3V0?[`iP090?[`iP03
0000o`3jl>H0n_3V02l0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1=0?[`iP03
0<f5?`3jl>H0n_3V02h0n_3V0P000?mg0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V0500n_3V
0P00000=0?[`iP80003o;`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V04d0n_3V
00<0cHDo0?[`iP3jl>H0;@3jl>H00`000?l0n_3V0?[`iP1g0?[`iP40oooo000F0?[`iP030000003j
l>H0n_3V04l0n_3V00<000000?[`iP3jl>H03`3jl>H20000obd0n_3V00<0cHDo0?[`iP3jl>H0C@3j
l>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V02/0n_3V0P000?mj0?[`iP40oooo000F
0?[`iP030000003jl>H0n_3V04d0n_3V0P00000D0?[`iP030000o`3jl>H0n_3V02X0n_3V00<0cHDo
0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02/0n_3V00<0003o
0?[`iP3jl>H0NP3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V
01D0n_3V0P000?l[0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=
QCl0n_3V0?[`iP0Y0?[`iP80003oO@3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP1;0?[`iP03
0000003jl>H0n_3V01P0n_3V0P000?lY0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3j
l>H0C03jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP80003oO`3jl>H10?ooo`005P3jl>H00`000000n_3V
0?[`iP190?[`iP8000007@3jl>H00`000?l0n_3V0?[`iP0V0?[`iP030<f5?`3jl>H0n_3V04`0n_3V
00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0V0?[`iP030000o`3jl>H0n_3V07l0n_3V
0@3oool001H0n_3V00<000000?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP0N0?[`iP80003o9P3j
l>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04/0n_3V00<0cHDo0?[`iP3jl>H09@3j
l>H20000oh80n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`iP0Q
0?[`iP80003o9@3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V04/0n_3V00<0cHDo
0?[`iP3jl>H0903jl>H00`000?l0n_3V0?[`iP220?[`iP40oooo000F0?[`iP030000003jl>H0n_3V
04D0n_3V0P00000V0?[`iP030000o`3jl>H0n_3V0280n_3V00<0cHDo0?[`iP3jl>H0B`3jl>H00`00
0000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V02<0n_3V0P000?n50?[`iP40oooo000F0?[`iP03
0000003jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H09`3jl>H20000ob<0n_3V00<0cHDo0?[`iP3j
l>H0BP3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0240n_3V0P000?n70?[`iP40
oooo000F0?[`iP030000003jl>H0n_3V04<0n_3V00<000000?[`iP3jl>H0:P3jl>H20000ob40n_3V
00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0200n_3V
00<0003o0?[`iP3jl>H0Q`3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP110?[`iP800000;`3j
l>H20000oal0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3j
l>H0n_3V01h0n_3V0P000?n:0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V0400n_3V00<00000
0?[`iP3jl>H0<@3jl>H00`000?l0n_3V0?[`iP0L0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<00000
0?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP0N0?[`iP030000o`3jl>H0n_3V08X0n_3V0@3oool0
01H0n_3V00<000000?[`iP3jl>H0?P3jl>H2000003D0n_3V0P000?lM0?[`iP030<f5?`3jl>H0n_3V
04T0n_3V00<000000?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP0L0?[`iP80003oS@3jl>H10?oo
o`005P3jl>H00`000000n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V03L0n_3V0P000?lL0?[`iP03
0<f5?`3jl>H0n_3V04P0n_3V00<000000?[`iP3jl>H0B03jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP80
003oS`3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0l0?[`iP030000003jl>H0n_3V03X0n_3V
00<0003o0?[`iP3jl>H06@3jl>H00`3=QCl0n_3V0?[`iP180?[`iP030000003jl>H0n_3V04L0n_3V
00<0cHDo0?[`iP3jl>H06`3jl>H00`000?l0n_3V0?[`iP2?0?[`iP40oooo000F0?[`iP030000003j
l>H0n_3V03X0n_3V0P00000n0?[`iP80003o6P3jl>H00`3=QCl0n_3V0?[`iP170?[`iP030000003j
l>H0n_3V04L0n_3V00<0cHDo0?[`iP3jl>H06@3jl>H20000oi80n_3V0@3oool001H0n_3V00<00000
0?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP100?[`iP030000o`3jl>H0n_3V01L0n_3V00<0cHDo
0?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V01T0n_3V00<0003o
0?[`iP3jl>H0TP3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V
0480n_3V0P000?lH0?[`iP030<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H0AP3jl>H00`3=
QCl0n_3V0?[`iP0G0?[`iP80003oU@3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0f0?[`iP80
0000A`3jl>H00`000?l0n_3V0?[`iP0E0?[`iP030<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3j
l>H0A@3jl>H00`3=QCl0n_3V0?[`iP0G0?[`iP030000o`3jl>H0n_3V09D0n_3V0@3oool001H0n_3V
00<000000?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP180?[`iP80003o5P3jl>H00`3=QCl0n_3V
0?[`iP150?[`iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H05@3jl>H20000oiP0n_3V
0@3oool001H0n_3V00<000000?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP1;0?[`iP030000o`3j
l>H0n_3V01<0n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP140?[`iP030<f5?`3j
l>H0n_3V01D0n_3V00<0003o0?[`iP3jl>H0V03jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0b
0?[`iP800000C`3jl>H20000oa@0n_3V00<0cHDo0?[`iP3jl>H0A03jl>H00`000000n_3V0?[`iP14
0?[`iP030<f5?`3jl>H0n_3V01<0n_3V0P000?nK0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V
0340n_3V00<000000?[`iP3jl>H0D@3jl>H00`000?l0n_3V0?[`iP0B0?[`iP030<f5?`3jl>H0n_3V
04<0n_3V00<000000?[`iP3jl>H0@`3jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP030000o`3jl>H0n_3V
09/0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0;`3jl>H2000005D0n_3V0P000?lB0?[`iP03
0<f5?`3jl>H0n_3V04<0n_3V00<000000?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP80
003oWP3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0^0?[`iP030000003jl>H0n_3V05L0n_3V
00<0003o0?[`iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V0480n_3V
00<0cHDo0?[`iP3jl>H04@3jl>H00`000?l0n_3V0?[`iP2N0?[`iP40oooo000F0?[`iP030000003j
l>H0n_3V02d0n_3V00<000000?[`iP3jl>H0F@3jl>H20000oa40n_3V00<0cHDo0?[`iP3jl>H0@@3j
l>H00`000000n_3V0?[`iP110?[`iP030<f5?`3jl>H0n_3V0100n_3V0P000?nQ0?[`iP40oooo000F
0?[`iP030000003jl>H0n_3V02/0n_3V0P00001N0?[`iP030000o`3jl>H0n_3V00l0n_3V00<0cHDo
0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP100?[`iP030<f5?`3jl>H0n_3V0100n_3V00<0003o
0?[`iP3jl>H0X@3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V
05l0n_3V0P000?l?0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=
QCl0n_3V0?[`iP0?0?[`iP80003oY03jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0Y0?[`iP03
0000003jl>H0n_3V0680n_3V00<0003o0?[`iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP03
0000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H03P3jl>H00`000?l0n_3V0?[`iP2T0?[`iP40
oooo000F0?[`iP030000003jl>H0n_3V02L0n_3V0P00001V0?[`iP80003o3P3jl>H00`3=QCl0n_3V
0?[`iP0n0?[`iP030000003jl>H0n_3V03h0n_3V00<0cHDo0?[`iP3jl>H03@3jl>H20000ojL0n_3V
0@3oool001H0n_3V00<000000?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP1X0?[`iP80003o303j
l>H00`3=QCl0n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03d0n_3V00<0cHDo0?[`iP3jl>H0303j
l>H20000ojT0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0903jl>H2000006d0n_3V00<0003o
0?[`iP3jl>H02P3jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V03d0n_3V00<0cHDo
0?[`iP3jl>H02P3jl>H20000oj/0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H08`3jl>H00`00
0000n_3V0?[`iP1^0?[`iP80003o2`3jl>H20<f5?cd0n_3V00<000000?[`iP3jl>H0>`3jl>H20<f5
?``0n_3V00<0003o0?[`iP3jl>H0Z`3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0R0?[`iP03
0000003jl>H0n_3V0740n_3V0P000?l:0?[`iP030<f5?`3jl>H0n_3V03/0n_3V00<000000?[`iP3j
l>H0>P3jl>H00`3=QCl0n_3V0?[`iP0:0?[`iP80003o[P3jl>H10?ooo`005P3jl>H00`000000n_3V
0?[`iP0P0?[`iP800000MP3jl>H00`000?l0n_3V0?[`iP080?[`iP030<f5?`3jl>H0n_3V03X0n_3V
00<000000?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`iP080?[`iP80003o/03jl>H10?ooo`005P3j
l>H00`000000n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V07L0n_3V0P000?l90?[`iP030<f5?`3j
l>H0n_3V03T0n_3V00<000000?[`iP3jl>H0>@3jl>H00`3=QCl0n_3V0?[`iP070?[`iP80003o/P3j
l>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V07X0n_3V0P000?l8
0?[`iP030<f5?`3jl>H0n_3V03P0n_3V00<000000?[`iP3jl>H0>03jl>H00`3=QCl0n_3V0?[`iP07
0?[`iP030000o`3jl>H0n_3V0;80n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0703jl>H20000
07l0n_3V00<0003o0?[`iP3jl>H01P3jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V
03L0n_3V00<0cHDo0?[`iP3jl>H01P3jl>H20000okD0n_3V0@3oool001H0n_3V00<000000?[`iP3j
l>H06`3jl>H00`000000n_3V0?[`iP200?[`iP80003o1`3jl>H20<f5?cL0n_3V00<000000?[`iP3j
l>H0=@3jl>H20<f5?`L0n_3V0P000?ng0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V01X0n_3V
00<000000?[`iP3jl>H0P`3jl>H20000o`H0n_3V00<0cHDo0?[`iP3jl>H0=@3jl>H00`000000n_3V
0?[`iP0d0?[`iP030<f5?`3jl>H0n_3V00D0n_3V0P000?ni0?[`iP40oooo000F0?[`iP030000003j
l>H0n_3V01P0n_3V0P0000280?[`iP030000o`3jl>H0n_3V00@0n_3V00<0cHDo0?[`iP3jl>H0=03j
l>H00`000000n_3V0?[`iP0d0?[`iP030<f5?`3jl>H0n_3V00@0n_3V00<0003o0?[`iP3jl>H0^@3j
l>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V08T0n_3V0P000?l5
0?[`iP80cHDo=03jl>H00`000000n_3V0?[`iP0b0?[`iP80cHDo1@3jl>H20000ok`0n_3V0@3oool0
01H0n_3V00<000000?[`iP3jl>H05@3jl>H2000008h0n_3V0P000?l50?[`iP030<f5?`3jl>H0n_3V
0340n_3V00<000000?[`iP3jl>H0<@3jl>H00`3=QCl0n_3V0?[`iP030?[`iP80003o_P3jl>H10?oo
o`005P3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V0900n_3V00<0003o0?[`iP3j
l>H00`3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V0300n_3V00<0cHDo0?[`iP3j
l>H00P3jl>H20000ol00n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H04`3jl>H00`000000n_3V
0?[`iP2B0?[`iP80003o103jl>H00`3=QCl0n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V02l0n_3V
00@0cHDo0?[`iP3jl>H0n_3V0P000?o20?[`iP40oooo000F0?[`iP030000003jl>H0n_3V0140n_3V
0P00002G0?[`iP80003o0`3jl>H20<f5?bl0n_3V00<000000?[`iP3jl>H0;@3jl>H20<f5?`<0n_3V
00<0003o0?[`iP3jl>H0`P3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003j
l>H0n_3V09T0n_3V0P000?l30?[`iP030<f5?`3jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0;03j
l>H0103=QCl0n_3V0?[`iP3jl>H20000olD0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H03`3j
l>H00`000000n_3V0?[`iP2L0?[`iP80003o0P3jl>H20<f5?b`0n_3V00<000000?[`iP3jl>H0:P3j
l>H20<f5?`80n_3V0P000?o70?[`iP40oooo000F0?[`iP030000003jl>H0n_3V00d0n_3V0P00002Q
0?[`iP80003o0P3jl>H20<f5?bX0n_3V00<000000?[`iP3jl>H0:03jl>H20<f5?`80n_3V0P000?o9
0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0X`3jl>H20000
o`80n_3V00<0cHDo0?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP0W0?[`iP030<f5?`3jl>H0n_3V
0080003ob`3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP0:0?[`iP800000Z03jl>H20000o`03
0?[`iP3=QCl0cHDo02L0n_3V00<000000?[`iP3jl>H09@3jl>H20<f5?`030?[`iP000?l0003o0<d0
n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP2Z0?[`iP<0003o
0P3=QClU0?[`iP030000003jl>H0n_3V02<0n_3V0P3=QCl00`3jl>H0003o0000o`3?0?[`iP40oooo
000F0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0[P3jl>H30000o`030<f5?`3j
l>H0n_3V0240n_3V00<000000?[`iP3jl>H08@3jl>H20<f5?`030?[`iP000?l0003o0=40n_3V0@3o
ool001H0n_3V00<000000?[`iP3jl>H01P3jl>H200000;@0n_3V0P000?l00`3=QCl0n_3V0?[`iP0O
0?[`iP030000003jl>H0n_3V01l0n_3V0P3=QCl30000om<0n_3V0@3oool001H0n_3V00<000000?[`
iP3jl>H01@3jl>H00`000000n_3V0?[`iP2f0?[`iP<0003o7`3jl>H00`000000n_3V0?[`iP0M0?[`
iP80cHDo0P000?oF0?[`iP40oooo000F0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3j
l>H0^P3jl>H30000o`030<f5?`3jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06@3jl>H30<f5?`<0
003of03jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP020?[`iP800000`03jl>H30000oaT0n_3V
00<000000?[`iP3jl>H05`3jl>H00`3=QCl0003o0000o`020000om/0n_3V0@3oool001H0n_3V00D0
00000?[`iP3jl>H0n_3V000000350?[`iP@0003o5@3jl>H00`000000n_3V0?[`iP0C0?[`iP030<f5
?`000?l0003o0080003og`3jl>H10?ooo`005@3jl>H3000000030?[`iP000000n_3V0<T0n_3V1000
0?lA0?[`iP030000003jl>H0n_3V00l0n_3V00<0cHDo0000o`000?l00P000?oS0?[`iP40oooo000D
0?[`iPD00000c`3jl>H40000o`d0n_3V00<000000?[`iP3jl>H02`3jl>H50000onL0n_3V0@3oool0
01@0cHDo1@00003C0<f5?`d0003o00<000000000o`000?l02`000?o[0<f5?`40n_3V0@3oool001@0
n_3V1@00003o0?[`i]/0n_3V0@3oool001D0n_3V0`00003o0?[`i]`0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00]P3jl>H20000000306IRGP3<a;/0n_3V02/0n_3V
00H0e<c306IRGP000000000008V4OP3Tfm9U0?[`iP060=C<``1VHUh0000000000029Q7h0i=_BW03j
l>H10?ooo`00^03jl>H00`1VHUh000000=cDb`0[0?[`iP0604a9A@33^k<0n_3V0>cRf@000000RHAn
I@3jl>H01P1<BDD0`k^c0?[`iP3/h]T0000008V4OY`0n_3V0@3oool008<0n_3V0P0000030?[`iP80
00000P3jl>H200000080n_3V00@0[jRQ04a9A@000000RHAn1`3jl>H01P3Le</0NGE`000000000000
RHAn0<c4^`80n_3V00@0[jRQ04a9A@000000RHAn0P3jl>H200000080n_3V0P0000001@3jl>H0c<Bk
0000001iMG00n_3V008000000P3jl>H20000000306IRGP3jl>H0n_3V00L0n_3V0P0000030?[`iP04
0<c4^`1<BDD0IV9N0>CKdP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000103j
l>H000000000003jl>H200000080n_3V0P0000020?[`iP0308V4OP1VHUh0c<Bk008000001`3jl>H0
1@3Le</0NGE`0000001<BDD0Y9fF0080n_3V00@0c<Bk04a9A@1VHUh0i=_B0P0000000`3jl>H00000
000000040?[`iP030:BMUP000000Y9fF00<0n_3V00@0[jRQ04a9A@000000RHAn1`3jl>H0102_Z:40
C4U504a9A@2_Z:420?[`iP8000001P3jl>H2000000050?[`iP33^k<000000<>k/`3jl>H00P000000
1@3jl>H0c<Bk04a9A@1<BDD0[jRQ0080000000<0n_3V0000000000000`3jl>H2000000050?[`iP3<
a;/0C4U504a9A@2_Z:400P0000040?[`iP80000000<0k>;I0?[`iP3/h]T00P0000020?[`iP0308V4
OP1VHUh0c<Bk0080000000<0n_3V0000000000000P3jl>H200000080n_3V00@0[jRQ04a9A@000000
RHAn0P3jl>H01`3/h]T0Ui6;000000000000NGE`0>CKdP3jl>H00P0000240?[`iP40oooo00230?[`
iP8000000`3jl>H200000080n_3V0P0000001`3jl>H0[jRQ00000033^k<0i=_B00000029Q7h01@3j
l>H01@3Tfm80000009NAR`3jl>H0^K:Z0080000000P0n_3V0:nXX@000000`k^c0>CKdP000000RHAn
0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0c<Bk00000002
000000030>CKdP3jl>H0n_3V00H0n_3V0P0000030?[`iP0406IRGP000000i=_B0;VbZP80000000<0
n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V
0P0000001@3jl>H0Y9fF00000033^k<0Y9fF008000001P3jl>H0303Tfm80000009NAR`3jl>H0e<c3
00000029Q7h0n_3V06IRGP000000i=_B0;VbZP80000000<0n_3V000000000000103jl>H300000008
0>cRf@3jl>H0[jRQ00000033^k<0i=_B00000029Q7h50?[`iP070;VbZP000000`k^c0<>k/`000000
^K:Z0?[`iP02000000H0n_3V0P0000001@3jl>H0Ui6;0000002GTH/0n_3V0080000000D0n_3V04a9
A@000000i=_B0<>k/`02000000030?[`iP000000000000<0n_3V0P0000001@3jl>H0C4U50000003T
fm80`k^c00800000103jl>H03029Q7h000000=C<``3jl>H0e<c300000029Q7h0n_3V0:BMUP000000
`k^c0:BMUP80000000<0n_3V0000000000000P3jl>H20000000?0?[`iP2_Z:4000000<>k/`3Tfm80
000008V4OP3jl>H0NGE`0000003Tfm80k>;I0000001VHUh0n_3V00800000Q03jl>H10?ooo`00P`3j
l>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V04a9A@0000002@3jl>H00`2GTH/000000=cD
b`020?[`iP80000000<0n_3V04a9A@0000001@3jl>H200000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000H0n_3V09NAR`000000RHAn0000002_Z:480?[`iP8000000`3jl>H200000080
n_3V0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`
iP8000000P3jl>H2000000030?[`iP1<BDD000000080n_3V0P0000060?[`iP0309NAR`000000i=_B
00D0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H0202i/ZX0000008V4OP000000
^K:Z0?[`iP1<BDD000002@3jl>H01`1VHUh000000?[`iP3jl>H0000006IRGP3jl>H00P0000060?[`
iP80000000D0n_3V04a9A@000000C4U50?[`iP02000000030?[`iP00000000000080n_3V0P000000
0`3jl>H00000000000030?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V00<0[jRQ
0000000000000`000000102_Z:40n_3V04a9A@0000020?[`iP80000000<0n_3V0000000000000P3j
l>H2000000030?[`iP1<BDD0000000L0n_3V00D0e<c30:BMUP000000C4U50?[`iP02000008@0n_3V
0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP000000000000@000001@3j
l>H00`1<BDD000000?[`iP020?[`iP80000000<0n_3V000000000000100000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000060?[`iP1<BDD000000>cRf@000000
IV9N203jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H200000080
n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`
iP8000001P3jl>H2000000H0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H204a9
A@040>cRf@1<BDD0C4U50?[`iPH000001@3jl>H200000080n_3V0P0000000`3jl>H0000000000006
0?[`iP80000000D0i=_B0000002GTH/000000>CKdP02000000050?[`iP3<a;/0000009NAR`3Tfm80
0P0000000`3jl>H00000000000030?[`iP80000000D0n_3V0<c4^`000000Ui6;0>CKdP02000000@0
n_3V00P0e<c300000029Q7h0n_3V09NAR`000000e<c30?[`iP8000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H0000000000004000000030?[`iP3<a;/0C4U50080000000<0
C4U50<c4^`3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P000000
0`3jl>H0C4U5000000020?[`iP030000001VHUh0n_3V00@0n_3V0P0000020?[`iP<0000000<0n_3V
04a9A@0000000P3jl>H00`000000IV9N0?[`iP0200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000L0g=C;00000029Q7h0n_3V08V4OP000000i=_B00L0n_3V0P0000030?[`iP800000
0P3jl>H2000000030?[`iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000
n_3V0P0000020?[`iP80000000<0n_3V04a9A@0000000P3jl>H2000000H0n_3V0P0000060?[`iP80
00000P3jl>H2000000030?[`iP00000000000080n_3V00T0c<Bk0000002TWIH0n_3V0:BMUP000000
c<Bk04a9A@0000000P3jl>H00`000000IV9N0?[`iP040?[`iP0706IRGP000000n_3V0?[`iP000000
IV9N0?[`iP02000000H0n_3V0P0000001@3<a;/000000=cDb`000000c<Bk008000000P3jl>H00`3L
e</0[jRQ07UeL002000000030?[`iP000000000000<0n_3V0P0000020?[`iP030=cDb`2_Z:40NGE`
008000001@3jl>H01@000000C4U50?[`iP1<BDD000000080n_3V00@0C4U50000003jl>H0n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V04a9A@0000000P3jl>H01`000000IV9N0?[`
iP1<BDD0000007UeL03<a;/00`3jl>H2000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP800000
00/0Y9fF0>CKdP000000IV9N0?[`iP2i/ZX000000<>k/`3<a;/000000;VbZP050?[`iP0304a9A@00
0000n_3V00D0n_3V00L0^K:Z00000033^k<0c<Bk0000002i/ZX0n_3V0080000000D0^K:Z0>CKdP00
0000C4U50?[`iP0200000080n_3V0P0000001`2_Z:4000000<>k/`3jl>H0`k^c0000002_Z:401`3j
l>H2000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000e<c30P3jl>H2000000050;Vb
ZP3Tfm80000004a9A@3jl>H00P000000303jl>H000000000002i/ZX0i=_B0000001<BDD0n_3V0:BM
UP000000`k^c0:BMUP8000001P3jl>H00`1<BDD000000?[`iP050?[`iP8000000P3jl>H20000000B
0?[`iP00000000000=C<``3jl>H0IV9N0000003/h]T0n_3V0>cRf@000000IV9N0;VbZP000000`k^c
0<c4^`000000^K:Z1@3jl>H01`2i/ZX000000<>k/`33^k<000000;VbZP3jl>H00P0000060?[`iP80
000000D0Y9fF06IRGP3jl>H0IV9N0:BMUP02000000080?[`iP1iMG00e<c30?[`iP3Tfm80000004a9
A@3jl>H2000000030=C<``3jl>H0n_3V0080000000L0n_3V07UeL03Dc<<0n_3V0>CKdP000000C4U5
00D0n_3V00D0NGE`0000003<a;/0000006IRGP020?[`iP040:BMUP000000`k^c0:BMUP80000001H0
n_3V000000000000^K:Z0>CKdP000000C4U50?[`iP2i/ZX000000<>k/`3<a;/000000;VbZP3jl>H0
IV9N0000003jl>H0i=_B0000001iMG00n_3V0P0000240?[`iP40oooo00230?[`iP8000000`3jl>H2
000000040=cDb`29Q7h0C4U50<c4^`80n_3V00@0[jRQ000000000000[jRQ1P3jl>H00`2GTH/00000
0>CKdP060?[`iP040:nXX@00000000000:nXX@80n_3V0P000000103<a;/0NGE`04a9A@3<a;/40000
000:0?[`iP000000000006IRGP000000k>;I0?[`iP3/h]T0000006IRGPL0n_3V0P0000030?[`iP80
00000P3jl>H2000000060?[`iP000000000008V4OP1iMG00n_3V0P0000001@3<a;/0NGE`04a9A@3<
a;/0n_3V0080000000L0n_3V000000000000c<Bk07UeL01<BDD0c<Bk0080n_3V00<0RHAn06IRGP3<
a;/00P0000060?[`iP0309NAR`000000i=_B00D0n_3V0P0000020?[`iP80000000@0n_3V00000000
0000RHAn0P0000002029Q7h0n_3V0?[`iP3jl>H0RHAn0000003Le</0[jRQ0P0000000`2_Z:40n_3V
0?[`iP050?[`iP050:nXX@1<BDD000000:nXX@3jl>H0100000050?[`iP80000000D0IV9N0:BMUP3j
l>H0Ui6;06IRGP02000000030?[`iP3Tfm80RHAn0080000000<0IV9N0=C<``3jl>H00P0000000`29
Q7h0NGE`0?[`iP02000000030?[`iP3Tfm80RHAn0080000000<0IV9N0=C<``3jl>H0103jl>H01@2T
WIH0000008V4OP000000Y9fF00<0n_3V00<0RHAn06IRGP3<a;/00P0000001`3jl>H000000000003<
a;/0NGE`04a9A@3<a;/00P3jl>H0102_Z:4000000000002_Z:420?[`iP070>CKdP1iMG0000000000
0029Q7h0i=_B0?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP800000403jl>H01`3T
fm80000009NAR`3jl>H0e<c30000001iMG003`3jl>H200000080n_3V0P00000>0?[`iP800000;03j
l>H01`3Tfm80000009NAR`3jl>H0e<c300000029Q7h09@3jl>H2000000H0n_3V0`0000000`3<a;/0
n_3V0<>k/`03000001/0n_3V00D0c<Bk00000000000000000<>k/`2T0?[`iP40oooo00210?[`iPH0
000000<0n_3V0000000000004@3jl>H01P3Le</0NGE`000000000000Ui6;0>cRf@l0n_3V00@0g=C;
08V4OP3jl>H0n_3V0P00000<0?[`iPH00000503jl>H2000001D0n_3V00D0g=C;07UeL00000000000
0:BMUP0V0?[`iP040<c4^`1VHUh0000008V4OP@0n_3V0`0000000`3/h]T0n_3V0=cDb`03000000d0
n_3V0P00000<0?[`iP050>cRf@00000000000000003Tfm807P3jl>H2000008@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.08696 .38333 L
s
.08696 .05 m
.08696 .38333 L
s
.33709 .18147 m
.08696 .18147 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.08696 .38333 Mdot
.33709 .18147 Mdot
.08696 .18147 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool002/0n_3V00<000000?[`iP3jl>H0_`3jl>H:0<f5
?`030?[`iP00000000000080n_3V2P3=QCo]0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V0;T0
n_3V1P3=QCl90?[`iP80000000<0n_3V0000003jl>H02`3jl>H70<f5?nH0n_3V0@3oool002/0n_3V
00<000000?[`iP3jl>H0]`3jl>H20<f5?`h0n_3V00D000000?[`iP3jl>H0n_3V0000000C0?[`iP80
cHDoi03jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP2c0?[`iP@0cHDo3`3jl>H00`000000n_3V
0?[`iP020?[`iP030000003jl>H0n_3V01<0n_3V0`3=QCoQ0?[`iP40oooo000[0?[`iP030000003j
l>H0n_3V0:l0n_3V103=QClB0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H05P3j
l>H40<f5?md0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0[@3jl>H20<f5?a@0n_3V0P000006
0?[`iP030000003jl>H0n_3V01X0n_3V0P3=QCoK0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V
0:/0n_3V0P3=QClE0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0703jl>H20<f5
?mT0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0Z@3jl>H20<f5?aH0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP0N0?[`iP80cHDoe`3jl>H10?ooo`00:`3jl>H00`000000n_3V
0?[`iP2W0?[`iP80cHDo5`3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V0200n_3V
0P3=QCoE0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V0:D0n_3V0P3=QClG0?[`iP8000002`3j
l>H00`000000n_3V0?[`iP0R0?[`iP80cHDod`3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP2S
0?[`iP80cHDo603jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V02@0n_3V0P3=QCoA
0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V0:40n_3V0P3=QClI0?[`iP030000003jl>H0n_3V
00`0n_3V00<000000?[`iP3jl>H09P3jl>H20<f5?ll0n_3V0@3oool002/0n_3V00<000000?[`iP3j
l>H0X03jl>H00`3=QCl0n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3j
l>H0:03jl>H00`3=QCl0n_3V0?[`iP3<0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V09h0n_3V
0P3=QClJ0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0:@3jl>H20<f5?l`0n_3V
0@3oool002/0n_3V00<000000?[`iP3jl>H0W03jl>H20<f5?aX0n_3V0P00000A0?[`iP030000003j
l>H0n_3V02/0n_3V0P3=QCo:0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V09/0n_3V00<0cHDo
0?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V02d0n_3V00<0cHDo
0?[`iP3jl>H0a`3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP2I0?[`iP80cHDo6`3jl>H00`00
0000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V02h0n_3V0P3=QCo70?[`iP40oooo000[0?[`iP03
0000003jl>H0n_3V09P0n_3V00<0cHDo0?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP0C0?[`iP03
0000003jl>H0n_3V0300n_3V00<0cHDo0?[`iP3jl>H0a03jl>H10?ooo`00:`3jl>H00`000000n_3V
0?[`iP2G0?[`iP030<f5?`3jl>H0n_3V01T0n_3V0P00000F0?[`iP030000003jl>H0n_3V0340n_3V
00<0cHDo0?[`iP3jl>H0``3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP2F0?[`iP030<f5?`3j
l>H0n_3V01T0n_3V00<000000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP0b0?[`iP030<f5?`3j
l>H0n_3V0<80n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0U03jl>H20<f5?a/0n_3V00<00000
0?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP0c0?[`iP80cHDo`P3jl>H10?ooo`00:`3jl>H00`00
0000n_3V0?[`iP2C0?[`iP030<f5?`3jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H0603jl>H00`00
0000n_3V0?[`iP0d0?[`iP030<f5?`3jl>H0n_3V0<00n_3V0@3oool002/0n_3V00<000000?[`iP3j
l>H0TP3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP8000006`3jl>H00`000000n_3V0?[`iP0e0?[`iP03
0<f5?`3jl>H0n_3V0;l0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0T@3jl>H00`3=QCl0n_3V
0?[`iP0I0?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0=P3jl>H20<f5?kl0n_3V
0@3oool002/0n_3V00<000000?[`iP3jl>H0T03jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000003j
l>H0n_3V01`0n_3V00<000000?[`iP3jl>H0>03jl>H00`3=QCl0n_3V0?[`iP2l0?[`iP40oooo000[
0?[`iP030000003jl>H0n_3V08l0n_3V00<0cHDo0?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0M
0?[`iP030000003jl>H0n_3V03T0n_3V00<0cHDo0?[`iP3jl>H0^`3jl>H10?ooo`00:`3jl>H00`00
0000n_3V0?[`iP2>0?[`iP030<f5?`3jl>H0n_3V01P0n_3V0P00000P0?[`iP030000003jl>H0n_3V
03X0n_3V00<0cHDo0?[`iP3jl>H0^P3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP2=0?[`iP03
0<f5?`3jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H0803jl>H00`000000n_3V0?[`iP0j0?[`iP03
0<f5?`3jl>H0n_3V0;X0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0S03jl>H00`3=QCl0n_3V
0?[`iP0H0?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0>`3jl>H00`3=QCl0n_3V
0?[`iP2i0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V08/0n_3V00<0cHDo0?[`iP3jl>H0603j
l>H00`000000n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V03`0n_3V0P3=QCni0?[`iP40oooo000[
0?[`iP030000003jl>H0n_3V08X0n_3V00<0cHDo0?[`iP3jl>H05`3jl>H2000002D0n_3V00<00000
0?[`iP3jl>H0?@3jl>H00`3=QCl0n_3V0?[`iP2g0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V
08X0n_3V00<0cHDo0?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP0U0?[`iP030000003jl>H0n_3V
03h0n_3V00<0cHDo0?[`iP3jl>H0]P3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP290?[`iP03
0<f5?`3jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP0o0?[`iP03
0<f5?`3jl>H0n_3V0;D0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0R03jl>H00`3=QCl0n_3V
0?[`iP0F0?[`iP030000003jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=QCl0n_3V
0?[`iP2e0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V08P0n_3V00<0cHDo0?[`iP3jl>H0503j
l>H2000002X0n_3V00<000000?[`iP3jl>H0@03jl>H00`3=QCl0n_3V0?[`iP2d0?[`iP40oooo000[
0?[`iP030000003jl>H0n_3V08L0n_3V00<0cHDo0?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP0Z
0?[`iP030000003jl>H0n_3V0440n_3V00<0cHDo0?[`iP3jl>H0/`3jl>H10?ooo`00:`3jl>H00`00
0000n_3V0?[`iP260?[`iP030<f5?`3jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0:`3jl>H00`00
0000n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V0;80n_3V0@3oool002/0n_3V00<000000?[`iP3j
l>H0Q@3jl>H00`3=QCl0n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V02`0n_3V00<000000?[`iP3j
l>H0@`3jl>H00`3=QCl0n_3V0?[`iP2a0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V08@0n_3V
00<0cHDo0?[`iP3jl>H04`3jl>H2000002l0n_3V00<000000?[`iP3jl>H0@`3jl>H00`3=QCl0n_3V
0?[`iP2a0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V08@0n_3V00<0cHDo0?[`iP3jl>H04P3j
l>H00`000000n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H0/03j
l>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP230?[`iP030<f5?`3jl>H0n_3V0180n_3V00<00000
0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0n_3V0;00n_3V0@3oool0
02/0n_3V00<000000?[`iP3jl>H0P`3jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V
0340n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP2_0?[`iP40oooo000[0?[`iP03
0000003jl>H0n_3V0880n_3V00<0cHDo0?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0b0?[`iP03
0000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H0[`3jl>H10?ooo`00:`3jl>H00`000000n_3V
0?[`iP220?[`iP030<f5?`3jl>H0n_3V00l0n_3V0P00000e0?[`iP030000003jl>H0n_3V04H0n_3V
00<0cHDo0?[`iP3jl>H0[P3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP210?[`iP030<f5?`3j
l>H0n_3V00l0n_3V00<000000?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP160?[`iP030<f5?`3j
l>H0n_3V0:h0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0P@3jl>H00`3=QCl0n_3V0?[`iP0>
0?[`iP030000003jl>H0n_3V03H0n_3V00<000000?[`iP3jl>H0A`3jl>H00`3=QCl0n_3V0?[`iP2]
0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V0800n_3V00<0cHDo0?[`iP3jl>H03P3jl>H00`00
0000n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V04P0n_3V00<0cHDo0?[`iP3jl>H0[03jl>H10?oo
o`00:`3jl>H00`000000n_3V0?[`iP1o0?[`iP030<f5?`3jl>H0n_3V00d0n_3V0P00000j0?[`iP03
0000003jl>H0n_3V04P0n_3V00<0cHDo0?[`iP3jl>H0[03jl>H10?ooo`00:`3jl>H00`000000n_3V
0?[`iP1o0?[`iP030<f5?`3jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0>P3jl>H00`000000n_3V
0?[`iP190?[`iP030<f5?`3jl>H0n_3V0:/0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0OP3j
l>H00`3=QCl0n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H0B@3j
l>H00`3=QCl0n_3V0?[`iP2[0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V07h0n_3V00<0cHDo
0?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0l0?[`iP030000003jl>H0n_3V04X0n_3V00<0cHDo
0?[`iP3jl>H0ZP3jl>H10?ooo`000P000?lY0?[`iP030000003jl>H0n_3V07h0n_3V00<0cHDo0?[`
iP3jl>H02@3jl>H2000003l0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2W0?[`
iP80003o0@3jl>H10?ooo`000P3jl>H30000obH0n_3V00<000000?[`iP3jl>H0OP3jl>H00`3=QCl0
n_3V0?[`iP080?[`iP030000003jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0
n_3V0?[`iP2T0?[`iP<0003o0`3jl>H10?ooo`001@3jl>H40000ob80n_3V00<000000?[`iP3jl>H0
O@3jl>H00`3=QCl0n_3V0?[`iP080?[`iP030000003jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0
BP3jl>H00`3=QCl0n_3V0?[`iP2P0?[`iP@0003o1P3jl>H10?ooo`002@3jl>H30000oal0n_3V00<0
00000?[`iP3jl>H0O@3jl>H00`3=QCl0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0440n_3V00<0
00000?[`iP3jl>H0B`3jl>H00`3=QCl0n_3V0?[`iP2L0?[`iP<0003o2P3jl>H10?ooo`00303jl>H3
0000oa`0n_3V00<000000?[`iP3jl>H0O03jl>H00`3=QCl0n_3V0?[`iP060?[`iP800000A03jl>H0
0`000000n_3V0?[`iP1;0?[`iP030<f5?`3jl>H0n_3V09T0n_3V0`000?l=0?[`iP40oooo000?0?[`
iP@0003o603jl>H00`000000n_3V0?[`iP1l0?[`iP030<f5?`3jl>H0n_3V00D0n_3V00<000000?[`
iP3jl>H0A03jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V09@0n_3V10000?l@0?[`
iP40oooo000C0?[`iP<0003o5@3jl>H00`000000n_3V0?[`iP1l0?[`iP030<f5?`3jl>H0n_3V00@0
n_3V00<000000?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V0940
n_3V0`000?lD0?[`iP40oooo000F0?[`iP<0003o4P3jl>H00`000000n_3V0?[`iP1l0?[`iP030<f5
?`3jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5
?`3jl>H0n_3V08h0n_3V0`000?lG0?[`iP40oooo000I0?[`iP<0003o3`3jl>H00`000000n_3V0?[`
iP1k0?[`iP030<f5?`3jl>H0n_3V0080n_3V0P0000190?[`iP030000003jl>H0n_3V04`0n_3V00<0
cHDo0?[`iP3jl>H0R`3jl>H30000oaX0n_3V0@3oool001`0n_3V0`000?l<0?[`iP030000003jl>H0
n_3V07/0n_3V00D0cHDo0?[`iP3jl>H0n_3V0000001;0?[`iP030000003jl>H0n_3V04d0n_3V00<0
cHDo0?[`iP3jl>H0Q`3jl>H30000oad0n_3V0@3oool001l0n_3V10000?l80?[`iP030000003jl>H0
n_3V07/0n_3V00@0cHDo0?[`iP3jl>H00000C03jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3j
l>H0n_3V08@0n_3V0`000?lP0?[`iP40oooo000S0?[`iP<0003o1@3jl>H00`000000n_3V0?[`iP1k
0?[`iP030<f5?`3jl>H0000004d0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP21
0?[`iP<0003o8`3jl>H10?ooo`009P3jl>H30000o`040?[`iP0000000000000007X0n_3V1000001>
0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0OP3jl>H30000obH0n_3V0@3oool0
02T0n_3V1@00001h0?[`iPD00000CP3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V
07X0n_3V0`000?lY0?[`iP40oooo000Y0?[`iX800000CP3jl>H00`000000n_3V0?[`iP1>0?[`iP03
0<f5?`3jl>H0n_3V07P0n_3V0P000?l/0?[`iP40oooo000Y0?[`iPD000000P000?mf0?[`iPD00000
CP3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V07H0n_3V0P000?l^0?[`iP40oooo
000Z0?[`iP<000000`3jl>H30000og40n_3V0P000000103jl>H0000000000000001?0?[`iP030000
003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0L`3jl>H30000oc00n_3V0@3oool002/0n_3V00<0
00000?[`iP3jl>H01@3jl>H20000ofh0n_3V00D000000?[`iP3jl>H0n_3V0<f5?`1A0?[`iP030000
003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0L03jl>H20000oc<0n_3V0@3oool002/0n_3V00<0
00000?[`iP3jl>H01`3jl>H20000of/0n_3V00<000000?[`iP3jl>H00P3jl>H00`3=QCl0n_3V0?[`
iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0KP3jl>H20000ocD0n_3V0@3o
ool002/0n_3V00<000000?[`iP3jl>H02@3jl>H30000ofL0n_3V00<000000?[`iP3jl>H00`3jl>H0
0`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0J`3jl>H3
0000ocL0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0303jl>H20000of@0n_3V00<000000?[`
iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`
iP3jl>H0J@3jl>H20000ocX0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H03P3jl>H20000of00
n_3V0P0000070?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0
n_3V0?[`iP1W0?[`iP80003o?03jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP0@0?[`iP<0003o
G03jl>H00`000000n_3V0?[`iP060?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0
C`3jl>H00`3=QCl0n_3V0?[`iP1T0?[`iP<0003o?P3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`
iP0C0?[`iP80003oF@3jl>H00`000000n_3V0?[`iP070?[`iP030<f5?`3jl>H0n_3V0500n_3V00<0
00000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1Q0?[`iP80003o@@3jl>H10?ooo`00:`3jl>H0
0`000000n_3V0?[`iP0E0?[`iP80003oEP3jl>H00`000000n_3V0?[`iP080?[`iP030<f5?`3jl>H0
n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1O0?[`iP80003o@`3jl>H1
0?ooo`00:`3jl>H00`000000n_3V0?[`iP0G0?[`iP80003oDP3jl>H2000000/0n_3V00<0cHDo0?[`
iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05d0n_3V0P000?m50?[`
iP40oooo000[0?[`iP030000003jl>H0n_3V01T0n_3V0P000?m?0?[`iP030000003jl>H0n_3V00/0
n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05/0
n_3V0P000?m70?[`iP40oooo000[0?[`iP030000003jl>H0n_3V01/0n_3V0`000?m;0?[`iP030000
003jl>H0n_3V00`0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5
?`3jl>H0n_3V05T0n_3V0P000?m90?[`iP40oooo000[0?[`iP030000003jl>H0n_3V01h0n_3V0P00
0?m80?[`iP030000003jl>H0n_3V00d0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`
iP1@0?[`iP030<f5?`3jl>H0n_3V05L0n_3V0P000?m;0?[`iP40oooo000[0?[`iP030000003jl>H0
n_3V0200n_3V0P000?m40?[`iP800000403jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP<00000D@3jl>H0
0`3=QCl0n_3V0?[`iP1E0?[`iP80003oC@3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP0R0?[`
iP80003o@@3jl>H00`000000n_3V0?[`iP0@0?[`iP030<f5?`3jl>H0n_3V04h0n_3V1@00001@0?[`
iP030<f5?`3jl>H0n_3V05<0n_3V0P000?m?0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V02@0
n_3V0P000?ln0?[`iP030000003jl>H0n_3V0140n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H500000500
n_3V00<0cHDo0?[`iP3jl>H0D@3jl>H20000oe40n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0
9P3jl>H20000oc/0n_3V00<000000?[`iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iPD00000
D03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP80003oD`3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`
iP0X0?[`iP80003o=`3jl>H2000001D0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H300000540n_3V00<0
cHDo0?[`iP3jl>H0C@3jl>H20000oeD0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0:P3jl>H2
0000oc@0n_3V00<000000?[`iP3jl>H05@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0
n_3V0500n_3V00<0cHDo0?[`iP3jl>H0B`3jl>H20000oeL0n_3V0@3oool002/0n_3V00<000000?[`
iP3jl>H0;03jl>H00`000?l0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V01H0n_3V00<0cHDo0?[`
iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04T0n_3V0P000?mI0?[`
iP40oooo000[0?[`iP030000003jl>H0n_3V02d0n_3V0P000?l_0?[`iP030000003jl>H0n_3V01L0
n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04L0
n_3V0P000?mK0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V02l0n_3V0P000?l[0?[`iP800000
6P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H0
A@3jl>H20000oed0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0<@3jl>H20000obP0n_3V00<0
00000?[`iP3jl>H06P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0
cHDo0?[`iP3jl>H0@`3jl>H20000oel0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0<`3jl>H0
0`000?l0n_3V0?[`iP0T0?[`iP030000003jl>H0n_3V01/0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H0
0`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V0440n_3V0P000?mQ0?[`iP40oooo000[0?[`
iP030000003jl>H0n_3V03@0n_3V0P000?lS0?[`iP030000003jl>H0n_3V01`0n_3V00<0cHDo0?[`
iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V03l0n_3V0P000?mS0?[`
iP40oooo000[0?[`iP030000003jl>H0n_3V03H0n_3V0P000?lO0?[`iP8000007`3jl>H00`3=QCl0
n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H20000ofD0
n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0>03jl>H20000oa`0n_3V00<000000?[`iP3jl>H0
803jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0
?03jl>H20000ofL0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0>P3jl>H00`000?l0n_3V0?[`
iP0H0?[`iP030000003jl>H0n_3V0240n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`
iP1?0?[`iP030<f5?`3jl>H0n_3V03/0n_3V00<0003o0?[`iP3jl>H0I`3jl>H10?ooo`00:`3jl>H0
0`000000n_3V0?[`iP0k0?[`iP80003o5`3jl>H00`000000n_3V0?[`iP0R0?[`iP030<f5?`3jl>H0
n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP80003oJP3jl>H1
0?ooo`00:`3jl>H00`000000n_3V0?[`iP0m0?[`iP80003o503jl>H00`000000n_3V0?[`iP0S0?[`
iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0h0?[`
iP030000o`3jl>H0n_3V06X0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0?`3jl>H00`000?l0
n_3V0?[`iP0?0?[`iP8000009P3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0
n_3V00<0cHDo0?[`iP3jl>H0=P3jl>H20000ofd0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0
@03jl>H20000o`h0n_3V00<000000?[`iP3jl>H09P3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000
003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0=@3jl>H20000ofl0n_3V0@3oool002/0n_3V00<0
00000?[`iP3jl>H0@P3jl>H20000o`/0n_3V00<000000?[`iP3jl>H0:03jl>H00`3=QCl0n_3V0?[`
iP1>0?[`iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0=03jl>H00`000?l0n_3V0?[`
iP1_0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V04@0n_3V00<0003o0?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP0Y0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H0
0`3=QCl0n_3V0?[`iP0b0?[`iP80003oLP3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP150?[`
iP80003o1@3jl>H2000002`0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>0?[`
iP030<f5?`3jl>H0n_3V0340n_3V00<0003o0?[`iP3jl>H0LP3jl>H10?ooo`00:`3jl>H00`000000
n_3V0?[`iP170?[`iP80003o0P3jl>H00`000000n_3V0?[`iP0/0?[`iP030<f5?`3jl>H0n_3V04h0
n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP80003oM@3jl>H10?ooo`00
:`3jl>H00`000000n_3V0?[`iP190?[`iP030000o`000000n_3V02l0n_3V00<0cHDo0?[`iP3jl>H0
C@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V02h0n_3V0P000?mg0?[`iP40oooo
000[0?[`iP030000003jl>H0n_3V04T0n_3V00<000000000o`000?l0;`3jl>H00`3=QCl0n_3V0?[`
iP1=0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`000?l0n_3V0?[`
iP1g0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V04L0n_3V0P0000030?[`iP80003o;@3jl>H0
0`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H2
0000ogX0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP050?[`
iP030000o`3jl>H0n_3V02X0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1<0?[`
iP030<f5?`3jl>H0n_3V02/0n_3V00<0003o0?[`iP3jl>H0NP3jl>H10?ooo`00:`3jl>H00`000000
n_3V0?[`iP150?[`iP030000003jl>H0n_3V00L0n_3V0P000?l[0?[`iP030<f5?`3jl>H0n_3V04`0
n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0Y0?[`iP80003oO@3jl>H10?ooo`00
:`3jl>H00`000000n_3V0?[`iP140?[`iP030000003jl>H0n_3V00X0n_3V0P000?lY0?[`iP030<f5
?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP80003o
O`3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP120?[`iP8000003`3jl>H00`000?l0n_3V0?[`
iP0V0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`
iP0V0?[`iP030000o`3jl>H0n_3V07l0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0@@3jl>H0
0`000000n_3V0?[`iP0@0?[`iP80003o9P3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0
n_3V04/0n_3V00<0cHDo0?[`iP3jl>H09@3jl>H20000oh80n_3V0@3oool002/0n_3V00<000000?[`
iP3jl>H0@03jl>H00`000000n_3V0?[`iP0C0?[`iP80003o9@3jl>H00`3=QCl0n_3V0?[`iP1;0?[`
iP030000003jl>H0n_3V04/0n_3V00<0cHDo0?[`iP3jl>H0903jl>H00`000?l0n_3V0?[`iP220?[`
iP40oooo000[0?[`iP030000003jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H05P3jl>H00`000?l0
n_3V0?[`iP0R0?[`iP030<f5?`3jl>H0n_3V04/0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0
n_3V0?[`iP0S0?[`iP80003oQ@3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP0m0?[`iP800000
6P3jl>H20000ob<0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5
?`3jl>H0n_3V0240n_3V0P000?n70?[`iP40oooo000[0?[`iP030000003jl>H0n_3V03`0n_3V00<0
00000?[`iP3jl>H0703jl>H20000ob40n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`
iP1:0?[`iP030<f5?`3jl>H0n_3V0200n_3V00<0003o0?[`iP3jl>H0Q`3jl>H10?ooo`00:`3jl>H0
0`000000n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V01l0n_3V0P000?lO0?[`iP030<f5?`3jl>H0
n_3V04X0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0N0?[`iP80003oRP3jl>H1
0?ooo`00:`3jl>H00`000000n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V0280n_3V00<0003o0?[`
iP3jl>H0703jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`
iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP2:0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V03P0
n_3V0P00000V0?[`iP80003o7@3jl>H00`3=QCl0n_3V0?[`iP190?[`iP030000003jl>H0n_3V04T0
n_3V00<0cHDo0?[`iP3jl>H0703jl>H20000ohd0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0
=`3jl>H00`000000n_3V0?[`iP0X0?[`iP80003o703jl>H00`3=QCl0n_3V0?[`iP180?[`iP030000
003jl>H0n_3V04P0n_3V00<0cHDo0?[`iP3jl>H06`3jl>H20000ohl0n_3V0@3oool002/0n_3V00<0
00000?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP0[0?[`iP030000o`3jl>H0n_3V01T0n_3V00<0
cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP170?[`iP030<f5?`3jl>H0n_3V01/0n_3V00<0
003o0?[`iP3jl>H0S`3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP0e0?[`iP030000003jl>H0
n_3V02d0n_3V0P000?lJ0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H0A`3jl>H0
0`3=QCl0n_3V0?[`iP0I0?[`iP80003oTP3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP0c0?[`
iP800000<P3jl>H00`000?l0n_3V0?[`iP0G0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<000000?[`
iP3jl>H0AP3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000o`3jl>H0n_3V0980n_3V0@3oool002/0
n_3V00<000000?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP0c0?[`iP80003o603jl>H00`3=QCl0
n_3V0?[`iP160?[`iP030000003jl>H0n_3V04H0n_3V00<0cHDo0?[`iP3jl>H05`3jl>H20000oiD0
n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0f0?[`iP030000
o`3jl>H0n_3V01D0n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP150?[`iP030<f5
?`3jl>H0n_3V01L0n_3V00<0003o0?[`iP3jl>H0U@3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`
iP0`0?[`iP030000003jl>H0n_3V03P0n_3V0P000?lF0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<0
00000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP80003oV03jl>H10?ooo`00:`3jl>H0
0`000000n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V03/0n_3V00<0003o0?[`iP3jl>H04`3jl>H0
0`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H05@3jl>H0
0`000?l0n_3V0?[`iP2H0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V02d0n_3V0P00000o0?[`
iP80003o503jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`
iP3jl>H04`3jl>H20000oi/0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0;03jl>H00`000000
n_3V0?[`iP110?[`iP030000o`3jl>H0n_3V0180n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H00`000000
n_3V0?[`iP130?[`iP030<f5?`3jl>H0n_3V01<0n_3V00<0003o0?[`iP3jl>H0V`3jl>H10?ooo`00
:`3jl>H00`000000n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V04<0n_3V0P000?lB0?[`iP030<f5
?`3jl>H0n_3V04<0n_3V00<000000?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP80003o
WP3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V04H0n_3V00<0
003o0?[`iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V0480n_3V00<0
cHDo0?[`iP3jl>H04@3jl>H00`000?l0n_3V0?[`iP2N0?[`iP40oooo000[0?[`iP030000003jl>H0
n_3V02P0n_3V0P00001:0?[`iP80003o4@3jl>H00`3=QCl0n_3V0?[`iP110?[`iP030000003jl>H0
n_3V0440n_3V00<0cHDo0?[`iP3jl>H0403jl>H20000oj40n_3V0@3oool002/0n_3V00<000000?[`
iP3jl>H09`3jl>H00`000000n_3V0?[`iP1<0?[`iP030000o`3jl>H0n_3V00l0n_3V00<0cHDo0?[`
iP3jl>H0@03jl>H00`000000n_3V0?[`iP100?[`iP030<f5?`3jl>H0n_3V0100n_3V00<0003o0?[`
iP3jl>H0X@3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V04h0
n_3V0P000?l?0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=QCl0
n_3V0?[`iP0?0?[`iP80003oY03jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP0U0?[`iP030000
003jl>H0n_3V0540n_3V00<0003o0?[`iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP030000
003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H03P3jl>H00`000?l0n_3V0?[`iP2T0?[`iP40oooo
000[0?[`iP030000003jl>H0n_3V02<0n_3V0P00001E0?[`iP80003o3P3jl>H00`3=QCl0n_3V0?[`
iP0n0?[`iP030000003jl>H0n_3V03h0n_3V00<0cHDo0?[`iP3jl>H03@3jl>H20000ojL0n_3V0@3o
ool002/0n_3V00<000000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP1G0?[`iP80003o303jl>H0
0`3=QCl0n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03d0n_3V00<0cHDo0?[`iP3jl>H0303jl>H2
0000ojT0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP1J0?[`
iP030000o`3jl>H0n_3V00X0n_3V00<0cHDo0?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP0m0?[`
iP030<f5?`3jl>H0n_3V00X0n_3V0P000?n[0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V0200
n_3V00<000000?[`iP3jl>H0G03jl>H20000o`/0n_3V0P3=QClm0?[`iP030000003jl>H0n_3V03/0
n_3V0P3=QCl<0?[`iP030000o`3jl>H0n_3V0:/0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0
7P3jl>H200000640n_3V0P000?l:0?[`iP030<f5?`3jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H0
>P3jl>H00`3=QCl0n_3V0?[`iP0:0?[`iP80003o[P3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`
iP0M0?[`iP030000003jl>H0n_3V06<0n_3V00<0003o0?[`iP3jl>H0203jl>H00`3=QCl0n_3V0?[`
iP0j0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H0203jl>H20000ok00n_3V0@3o
ool002/0n_3V00<000000?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP1U0?[`iP80003o2@3jl>H0
0`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V03T0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H2
0000ok80n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP1X0?[`
iP80003o203jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V03P0n_3V00<0cHDo0?[`
iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP2b0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V01T0
n_3V0P00001]0?[`iP030000o`3jl>H0n_3V00H0n_3V00<0cHDo0?[`iP3jl>H0=`3jl>H00`000000
n_3V0?[`iP0g0?[`iP030<f5?`3jl>H0n_3V00H0n_3V0P000?ne0?[`iP40oooo000[0?[`iP030000
003jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H0KP3jl>H20000o`L0n_3V0P3=QClg0?[`iP030000
003jl>H0n_3V03D0n_3V0P3=QCl70?[`iP80003o]`3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`
iP0G0?[`iP030000003jl>H0n_3V0740n_3V0P000?l60?[`iP030<f5?`3jl>H0n_3V03D0n_3V00<0
00000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP050?[`iP80003o^@3jl>H10?ooo`00:`3jl>H0
0`000000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V07@0n_3V00<0003o0?[`iP3jl>H0103jl>H0
0`3=QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0n_3V03@0n_3V00<0cHDo0?[`iP3jl>H0103jl>H0
0`000?l0n_3V0?[`iP2i0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V01@0n_3V0P00001h0?[`
iP80003o1@3jl>H20<f5?c@0n_3V00<000000?[`iP3jl>H0<P3jl>H20<f5?`D0n_3V0P000?nl0?[`
iP40oooo000[0?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0NP3jl>H20000o`D0
n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0a0?[`iP030<f5?`3jl>H0n_3V00<0
n_3V0P000?nn0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0
O@3jl>H00`000?l0n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V0300n_3V00<000000?[`iP3jl>H0
<03jl>H00`3=QCl0n_3V0?[`iP020?[`iP80003o`03jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`
iP0A0?[`iP030000003jl>H0n_3V07l0n_3V0P000?l40?[`iP030<f5?`3jl>H0n_3V02l0n_3V00<0
00000?[`iP3jl>H0;`3jl>H0103=QCl0n_3V0?[`iP3jl>H20000ol80n_3V0@3oool002/0n_3V00<0
00000?[`iP3jl>H03`3jl>H2000008@0n_3V0P000?l30?[`iP80cHDo;`3jl>H00`000000n_3V0?[`
iP0]0?[`iP80cHDo0`3jl>H00`000?l0n_3V0?[`iP320?[`iP40oooo000[0?[`iP030000003jl>H0
n_3V00h0n_3V00<000000?[`iP3jl>H0QP3jl>H20000o`<0n_3V00<0cHDo0?[`iP3jl>H0;03jl>H0
0`000000n_3V0?[`iP0/0?[`iP040<f5?`3jl>H0n_3V0?[`iP80003oa@3jl>H10?ooo`00:`3jl>H0
0`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V08T0n_3V0P000?l20?[`iP80cHDo;03jl>H0
0`000000n_3V0?[`iP0Z0?[`iP80cHDo0P3jl>H20000olL0n_3V0@3oool002/0n_3V00<000000?[`
iP3jl>H0303jl>H00`000000n_3V0?[`iP2<0?[`iP80003o0P3jl>H20<f5?bX0n_3V00<000000?[`
iP3jl>H0:03jl>H20<f5?`80n_3V0P000?o90?[`iP40oooo000[0?[`iP030000003jl>H0n_3V00/0
n_3V00<000000?[`iP3jl>H0S`3jl>H20000o`80n_3V00<0cHDo0?[`iP3jl>H09`3jl>H00`000000
n_3V0?[`iP0W0?[`iP030<f5?`3jl>H0n_3V0080003ob`3jl>H10?ooo`00:`3jl>H00`000000n_3V
0?[`iP090?[`iP800000U03jl>H20000o`030?[`iP3=QCl0cHDo02L0n_3V00<000000?[`iP3jl>H0
9@3jl>H20<f5?`030?[`iP000?l0003o0<d0n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H0203j
l>H00`000000n_3V0?[`iP2F0?[`iP<0003o0P3=QClU0?[`iP030000003jl>H0n_3V02<0n_3V0P3=
QCl00`3jl>H0003o0000o`3?0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V00L0n_3V00<00000
0?[`iP3jl>H0VP3jl>H30000o`030<f5?`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H08@3jl>H2
0<f5?`030?[`iP000?l0003o0=40n_3V0@3oool002/0n_3V00<000000?[`iP3jl>H01P3jl>H00`00
0000n_3V0?[`iP2N0?[`iP80003o00<0cHDo0?[`iP3jl>H07`3jl>H00`000000n_3V0?[`iP0O0?[`
iP80cHDo0`000?oC0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V00@0n_3V0P00002S0?[`iP<0
003o7`3jl>H00`000000n_3V0?[`iP0M0?[`iP80cHDo0P000?oF0?[`iP40oooo000[0?[`iP030000
003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0YP3jl>H30000o`030<f5?`3jl>H0n_3V01T0n_3V
00<000000?[`iP3jl>H06@3jl>H30<f5?`<0003of03jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`
iP020?[`iP030000003jl>H0n_3V0:X0n_3V0`000?lI0?[`iP030000003jl>H0n_3V01L0n_3V00<0
cHDo0000o`000?l00P000?oK0?[`iP40oooo000[0?[`iP050000003jl>H0n_3V0?[`iP000000/03j
l>H40000oaD0n_3V00<000000?[`iP3jl>H04`3jl>H00`3=QCl0003o0000o`020000oml0n_3V0@3o
ool002X0n_3V1@00002e0?[`iP@0003o4@3jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`000?l0
003o0080003oh`3jl>H10?ooo`00:@3jl>H500000;X0n_3V10000?l=0?[`iP030000003jl>H0n_3V
00/0n_3V1@000?oW0?[`iP40oooo000Y0<f5?`D00000_P3=QCl=0000o`03000000000?l0003o00/0
003oj`3=QCl10?[`iP40oooo000Y0?[`iPD00000o`3jl>K60?[`iP40oooo000Z0?[`iP<00000o`3j
l>K70?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00;H0n_3V0P00
00000`1VHUh0c<Bk0?[`iP0[0?[`iP060=C<``1VHUh0000000000029Q7h0i=_BI@3jl>H01P3Dc<<0
IV9N000000000000RHAn0>CKdY`0n_3V0@3oool00;P0n_3V00<0IV9N0000003Le</0:`3jl>H01P1<
BDD0`k^c0?[`iP3/h]T0000008V4OVD0n_3V00H0C4U50<>k/`3jl>H0k>;I00000029Q7jL0?[`iP40
oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP040:nXX@1<BDD0000008V4OPL0
n_3V00H0g=C;07UeL0000000000008V4OP3<a;/20?[`iP040:nXX@1<BDD0000008V4OP80n_3V0P00
00020?[`iP80000000D0n_3V0<c4^`000000NGE`0?[`iP0200000080n_3V0P0000000`1VHUh0n_3V
0?[`iP070?[`iP8000000`3jl>H0103<a;/0C4U506IRGP3Tfm82000000030?[`iP000000000000<0
n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000000P3jl>H00`29
Q7h0IV9N0<c4^`02000000L0n_3V00D0g=C;07UeL0000000C4U50:BMUP020?[`iP040<c4^`1<BDD0
IV9N0>CKdP80000000<0n_3V000000000000103jl>H00`2TWIH000000:BMUP030?[`iP040:nXX@1<
BDD0000008V4OPL0n_3V00@0[jRQ04a9A@1<BDD0[jRQ0P3jl>H2000000H0n_3V0P0000001@3jl>H0
`k^c00000033^k<0n_3V0080000000D0n_3V0<c4^`1<BDD0C4U50:nXX@02000000030?[`iP000000
000000<0n_3V0P0000001@3jl>H0c<Bk04a9A@1<BDD0[jRQ00800000103jl>H2000000030>cRf@3j
l>H0k>;I008000000P3jl>H00`29Q7h0IV9N0<c4^`02000000030?[`iP00000000000080n_3V0P00
00020?[`iP040:nXX@1<BDD0000008V4OP80n_3V00L0k>;I09NAR`000000000007UeL03Tfm80n_3V
00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80000000L0n_3V0:nXX@00
0000`k^c0>CKdP000000RHAn00D0n_3V00D0i=_B0000002GTH/0n_3V0;VbZP02000000080?[`iP2_
Z:4000000<>k/`3Tfm80000008V4OP3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0<c4^`0000000P0000000`3Tfm80n_3V0?[`iP060?[`iP8000000`3jl>H0101V
HUh000000>CKdP2i/ZX2000000030?[`iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V
000000000000n_3V0P0000020?[`iP80000000D0n_3V0:BMUP000000`k^c0:BMUP02000000H0n_3V
00`0i=_B0000002GTH/0n_3V0=C<``000000RHAn0?[`iP1VHUh000000>CKdP2i/ZX2000000030?[`
iP000000000000@0n_3V0`000000203/h]T0n_3V0:nXX@000000`k^c0>CKdP000000RHAn1@3jl>H0
1`2i/ZX000000<>k/`33^k<000000;VbZP3jl>H00P0000060?[`iP80000000D0n_3V09NAR`000000
Ui6;0?[`iP02000000050?[`iP1<BDD000000>CKdP33^k<00P0000000`3jl>H00000000000030?[`
iP80000000D0n_3V04a9A@000000i=_B0<>k/`02000000@0n_3V00`0RHAn0000003Dc<<0n_3V0=C<
``000000RHAn0?[`iP2TWIH000000<>k/`2TWIH2000000030?[`iP00000000000080n_3V0P000000
3`3jl>H0[jRQ00000033^k<0i=_B00000029Q7h0n_3V07UeL0000000i=_B0>cRf@000000IV9N0?[`
iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP1<BDD0
000000T0n_3V00<0Ui6;0000003Le</00P3jl>H2000000030?[`iP1<BDD0000000D0n_3V0P000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000060?[`iP2GTH/0000008V4OP000000[jRQ
203jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H200000080n_3V
0P000000103jl>H000000000003jl>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP80
00001P3jl>H00`2GTH/000000>CKdP050?[`iP8000000P3jl>H2000000030?[`iP000000000000<0
n_3V00P0^K:Z00000029Q7h000000;VbZP3jl>H0C4U5000000T0n_3V00L0IV9N0000003jl>H0n_3V
0000001VHUh0n_3V008000001P3jl>H2000000050?[`iP1<BDD0000004a9A@3jl>H00P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000000`3jl>H2000000030?[`iP0000000000
0080n_3V0P0000040?[`iP030:nXX@000000000000<0000000@0[jRQ0?[`iP1<BDD000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H0C4U5000000070?[`iP050=C<``2TWIH0
000004a9A@3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P000000
0`3jl>H0000000000004000000D0n_3V00<0C4U50000003jl>H00P3jl>H2000000030?[`iP000000
000000@0000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
1P3jl>H0C4U50000003/h]T0000006IRGPP0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`
iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000H0n_3V0P0000060?[`iP8000000P3jl>H200000003
0?[`iP000000000000<0n_3V0P1<BDD0103/h]T0C4U504a9A@3jl>H6000000D0n_3V0P0000020?[`
iP80000000<0n_3V0000000000001P3jl>H2000000050>CKdP000000Ui6;0000003Tfm800P000000
1@3jl>H0c<Bk0000002GTH/0i=_B0080000000<0n_3V0000000000000`3jl>H2000000050?[`iP3<
a;/0000009NAR`3Tfm800P0000040?[`iP080=C<``000000RHAn0?[`iP2GTH/000000=C<``3jl>H2
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000000010000000
0`3jl>H0c<Bk04a9A@020000000304a9A@3<a;/0n_3V00800000Q03jl>H10?ooo`00P`3jl>H20000
00<0n_3V0P0000020?[`iP80000000<0n_3V04a9A@0000000P3jl>H00`000000IV9N0?[`iP040?[`
iP8000000P3jl>H3000000030?[`iP1<BDD000000080n_3V00<0000006IRGP3jl>H00P0000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000070=cDb`000000RHAn0?[`iP29Q7h000000>CK
dP070?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP8000000P3j
l>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000030?[`iP1<BDD000000080n_3V
0P0000060?[`iP8000001P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP090<c4
^`000000Y9fF0?[`iP2TWIH000000<c4^`1<BDD000000080n_3V00<0000006IRGP3jl>H0103jl>H0
1`1VHUh000000?[`iP3jl>H0000006IRGP3jl>H00P0000060?[`iP80000000D0c<Bk0000003Le</0
00000<c4^`0200000080n_3V00<0g=C;0:nXX@1iMG000P0000000`3jl>H00000000000030?[`iP80
00000P3jl>H00`3Le</0[jRQ07UeL002000000D0n_3V00D0000004a9A@3jl>H0C4U5000000020?[`
iP0404a9A@000000n_3V0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP1<BDD0
00000080n_3V00L0000006IRGP3jl>H0C4U50000001iMG00c<Bk00<0n_3V0P0000240?[`iP40oooo
00230?[`iP8000000`3jl>H20000000;0:BMUP3Tfm80000006IRGP3jl>H0^K:Z00000033^k<0c<Bk
0000002i/ZX01@3jl>H00`1<BDD000000?[`iP050?[`iP070;VbZP000000`k^c0<c4^`000000^K:Z
0?[`iP02000000050;VbZP3Tfm80000004a9A@3jl>H00P0000020?[`iP80000000L0[jRQ00000033
^k<0n_3V0<>k/`000000[jRQ00L0n_3V0P0000030?[`iP8000000P3jl>H2000000040?[`iP000000
00000=C<``80n_3V0P0000001@2i/ZX0i=_B0000001<BDD0n_3V0080000000`0n_3V000000000000
^K:Z0>CKdP000000C4U50?[`iP2TWIH000000<>k/`2TWIH2000000H0n_3V00<0C4U50000003jl>H0
1@3jl>H200000080n_3V0P0000004P3jl>H000000000003Dc<<0n_3V06IRGP000000k>;I0?[`iP3/
h]T0000006IRGP2i/ZX000000<>k/`3<a;/000000;VbZPD0n_3V00L0^K:Z00000033^k<0`k^c0000
002i/ZX0n_3V008000001P3jl>H2000000050:BMUP1VHUh0n_3V06IRGP2TWIH00P000000203jl>H0
NGE`0=C<``3jl>H0i=_B0000001<BDD0n_3V0P0000000`3Dc<<0n_3V0?[`iP02000000070?[`iP1i
MG00e<c30?[`iP3Tfm80000004a9A@050?[`iP0507UeL0000000c<Bk0000001VHUh00P3jl>H0102T
WIH000000<>k/`2TWIH20000000F0?[`iP00000000000;VbZP3Tfm80000004a9A@3jl>H0^K:Z0000
0033^k<0c<Bk0000002i/ZX0n_3V06IRGP000000n_3V0>CKdP000000NGE`0?[`iP800000Q03jl>H1
0?ooo`00P`3jl>H2000000<0n_3V0P000000103Le</0RHAn04a9A@3<a;/20?[`iP040:nXX@000000
00000:nXX@H0n_3V00<0Ui6;0000003Tfm801P3jl>H0102_Z:4000000000002_Z:420?[`iP800000
00@0c<Bk07UeL01<BDD0c<Bk100000002P3jl>H000000000001VHUh000000>cRf@3jl>H0k>;I0000
001VHUh70?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H0000000000029Q7h0NGE`0?[`
iP80000000D0c<Bk07UeL01<BDD0c<Bk0?[`iP02000000070?[`iP00000000000<c4^`1iMG00C4U5
0<c4^`020?[`iP0308V4OP1VHUh0c<Bk008000001P3jl>H00`2GTH/000000>CKdP050?[`iP800000
0P3jl>H2000000040?[`iP000000000008V4OP80000000P0RHAn0?[`iP3jl>H0n_3V08V4OP000000
g=C;0:nXX@80000000<0[jRQ0?[`iP3jl>H01@3jl>H01@2_Z:40C4U50000002_Z:40n_3V00@00000
1@3jl>H20000000506IRGP2TWIH0n_3V09NAR`1VHUh00P0000000`3jl>H0i=_B08V4OP0200000003
06IRGP3Dc<<0n_3V0080000000<0RHAn07UeL03jl>H00P0000000`3jl>H0i=_B08V4OP0200000003
06IRGP3Dc<<0n_3V00@0n_3V00D0Y9fF00000029Q7h000000:BMUP030?[`iP0308V4OP1VHUh0c<Bk
0080000000L0n_3V000000000000c<Bk07UeL01<BDD0c<Bk0080n_3V00@0[jRQ000000000000[jRQ
0P3jl>H01`3Tfm80NGE`000000000000RHAn0>CKdP3jl>H00P0000240?[`iP40oooo00230?[`iP80
00000`3jl>H200000100n_3V00L0i=_B0000002GTH/0n_3V0=C<``000000NGE`00l0n_3V0P000002
0?[`iP8000003P3jl>H2000002`0n_3V00L0i=_B0000002GTH/0n_3V0=C<``000000RHAn02D0n_3V
0P0000060?[`iP<0000000<0c<Bk0?[`iP33^k<00`00000K0?[`iP050<c4^`000000000000000033
^k<0Y03jl>H10?ooo`00P@3jl>H6000000030?[`iP00000000000140n_3V00H0g=C;07UeL0000000
000009NAR`3/h]T?0?[`iP040=cDb`29Q7h0n_3V0?[`iP800000303jl>H6000001@0n_3V0P00000E
0?[`iP050=cDb`1iMG0000000000002TWIH09P3jl>H0103<a;/0IV9N00000029Q7h40?[`iP<00000
00<0k>;I0?[`iP3Le</00`00000=0?[`iP800000303jl>H01@3/h]T00000000000000000i=_B01h0
n_3V0P0000240?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.13043 .38333 L
s
.13043 .05 m
.13043 .38333 L
s
.33422 .19953 m
.13043 .19953 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.13043 .38333 Mdot
.33422 .19953 Mdot
.13043 .19953 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00440n_3V00<000000?[`iP3jl>H0Z@3jl>H:0<f5
?`030?[`iP00000000000080n_3V2P3=QCo]0?[`iP40oooo00110?[`iP030000003jl>H0n_3V0:<0
n_3V1P3=QCl:0?[`iP030000003jl>H0000000`0n_3V1`3=QCoV0?[`iP40oooo00110?[`iP030000
003jl>H0n_3V0:40n_3V0P3=QCl?0?[`iP040000003jl>H0n_3V000001<0n_3V0P3=QCoT0?[`iP40
oooo00110?[`iP030000003jl>H0n_3V09d0n_3V103=QCl@0?[`iP050000003jl>H0n_3V0?[`iP00
00005@3jl>H30<f5?n40n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0V@3jl>H40<f5?a80n_3V
0P0000040?[`iP030000003jl>H0n_3V01H0n_3V103=QCoM0?[`iP40oooo00110?[`iP030000003j
l>H0n_3V09L0n_3V0P3=QClE0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H06P3j
l>H20<f5?m/0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0U@3jl>H20<f5?aH0n_3V00<00000
0?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0L0?[`iP80cHDof@3jl>H10?ooo`00@@3jl>H00`00
0000n_3V0?[`iP2C0?[`iP80cHDo5`3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V
01h0n_3V0P3=QCoG0?[`iP40oooo00110?[`iP030000003jl>H0n_3V0940n_3V0P3=QClH0?[`iP03
0000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0803jl>H20<f5?mD0n_3V0@3oool00440n_3V
00<000000?[`iP3jl>H0S`3jl>H20<f5?aT0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V
0?[`iP0R0?[`iP80cHDod`3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP2=0?[`iP80cHDo6P3j
l>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V02@0n_3V0P3=QCoA0?[`iP40oooo0011
0?[`iP030000003jl>H0n_3V08/0n_3V0P3=QClK0?[`iP030000003jl>H0n_3V00X0n_3V00<00000
0?[`iP3jl>H09P3jl>H20<f5?ll0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0RP3jl>H00`3=
QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0:03jl>H00`3=
QCl0n_3V0?[`iP3<0?[`iP40oooo00110?[`iP030000003jl>H0n_3V08P0n_3V0P3=QClK0?[`iP80
00003P3jl>H00`000000n_3V0?[`iP0Y0?[`iP80cHDoc03jl>H10?ooo`00@@3jl>H00`000000n_3V
0?[`iP260?[`iP80cHDo703jl>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V02/0n_3V
0P3=QCo:0?[`iP40oooo00110?[`iP030000003jl>H0n_3V08D0n_3V00<0cHDo0?[`iP3jl>H06`3j
l>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V02d0n_3V00<0cHDo0?[`iP3jl>H0a`3j
l>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP230?[`iP80cHDo7@3jl>H00`000000n_3V0?[`iP0@
0?[`iP030000003jl>H0n_3V02h0n_3V0P3=QCo70?[`iP40oooo00110?[`iP030000003jl>H0n_3V
0880n_3V00<0cHDo0?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V
0300n_3V00<0cHDo0?[`iP3jl>H0a03jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP210?[`iP03
0<f5?`3jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0a0?[`iP03
0<f5?`3jl>H0n_3V0<<0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0P03jl>H00`3=QCl0n_3V
0?[`iP0L0?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0<P3jl>H00`3=QCl0n_3V
0?[`iP320?[`iP40oooo00110?[`iP030000003jl>H0n_3V07h0n_3V0P3=QClN0?[`iP030000003j
l>H0n_3V01@0n_3V00<000000?[`iP3jl>H0<`3jl>H20<f5?l80n_3V0@3oool00440n_3V00<00000
0?[`iP3jl>H0O@3jl>H00`3=QCl0n_3V0?[`iP0M0?[`iP030000003jl>H0n_3V01D0n_3V00<00000
0?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP300?[`iP40oooo00110?[`iP030000003jl>H0n_3V
07`0n_3V00<0cHDo0?[`iP3jl>H0703jl>H2000001P0n_3V00<000000?[`iP3jl>H0=@3jl>H00`3=
QCl0n_3V0?[`iP2o0?[`iP40oooo00110?[`iP030000003jl>H0n_3V07/0n_3V00<0cHDo0?[`iP3j
l>H0703jl>H00`000000n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V03H0n_3V0P3=QCno0?[`iP40
oooo00110?[`iP030000003jl>H0n_3V07X0n_3V00<0cHDo0?[`iP3jl>H0703jl>H00`000000n_3V
0?[`iP0I0?[`iP030000003jl>H0n_3V03P0n_3V00<0cHDo0?[`iP3jl>H0_03jl>H10?ooo`00@@3j
l>H00`000000n_3V0?[`iP1i0?[`iP030<f5?`3jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H06P3j
l>H00`000000n_3V0?[`iP0i0?[`iP030<f5?`3jl>H0n_3V0;/0n_3V0@3oool00440n_3V00<00000
0?[`iP3jl>H0N03jl>H00`3=QCl0n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V01/0n_3V00<00000
0?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`iP2j0?[`iP40oooo00110?[`iP030000003jl>H0n_3V
07L0n_3V00<0cHDo0?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V
03X0n_3V00<0cHDo0?[`iP3jl>H0^P3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP1f0?[`iP03
0<f5?`3jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP0k0?[`iP03
0<f5?`3jl>H0n_3V0;T0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0M@3jl>H00`3=QCl0n_3V
0?[`iP0L0?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0?03jl>H20<f5?kT0n_3V
0@3oool00440n_3V00<000000?[`iP3jl>H0M03jl>H00`3=QCl0n_3V0?[`iP0L0?[`iP030000003j
l>H0n_3V01l0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3=QCl0n_3V0?[`iP2g0?[`iP40oooo0011
0?[`iP030000003jl>H0n_3V07@0n_3V00<0cHDo0?[`iP3jl>H06P3jl>H200000280n_3V00<00000
0?[`iP3jl>H0?P3jl>H00`3=QCl0n_3V0?[`iP2f0?[`iP40oooo00110?[`iP030000003jl>H0n_3V
07<0n_3V00<0cHDo0?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V
03l0n_3V00<0cHDo0?[`iP3jl>H0]@3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP1b0?[`iP03
0<f5?`3jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP0o0?[`iP03
0<f5?`3jl>H0n_3V0;D0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0LP3jl>H00`3=QCl0n_3V
0?[`iP0I0?[`iP030000003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0@03jl>H00`3=QCl0n_3V
0?[`iP2d0?[`iP40oooo00110?[`iP030000003jl>H0n_3V0740n_3V00<0cHDo0?[`iP3jl>H06@3j
l>H00`000000n_3V0?[`iP0U0?[`iP030000003jl>H0n_3V0440n_3V00<0cHDo0?[`iP3jl>H0/`3j
l>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP1`0?[`iP030<f5?`3jl>H0n_3V01T0n_3V00<00000
0?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V0;80n_3V0@3oool0
0440n_3V00<000000?[`iP3jl>H0K`3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V
02L0n_3V00<000000?[`iP3jl>H0@`3jl>H00`3=QCl0n_3V0?[`iP2a0?[`iP40oooo00110?[`iP03
0000003jl>H0n_3V06h0n_3V00<0cHDo0?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0X0?[`iP03
0000003jl>H0n_3V04<0n_3V00<0cHDo0?[`iP3jl>H0/@3jl>H10?ooo`00@@3jl>H00`000000n_3V
0?[`iP1^0?[`iP030<f5?`3jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H0:@3jl>H00`000000n_3V
0?[`iP140?[`iP030<f5?`3jl>H0n_3V0;00n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0K@3j
l>H00`3=QCl0n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H0A03j
l>H00`3=QCl0n_3V0?[`iP2`0?[`iP40oooo00110?[`iP030000003jl>H0n_3V06d0n_3V00<0cHDo
0?[`iP3jl>H05P3jl>H2000002d0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP2_
0?[`iP40oooo00110?[`iP030000003jl>H0n_3V06`0n_3V00<0cHDo0?[`iP3jl>H05P3jl>H00`00
0000n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H0[`3jl>H10?oo
o`00@@3jl>H00`000000n_3V0?[`iP1/0?[`iP030<f5?`3jl>H0n_3V01D0n_3V00<000000?[`iP3j
l>H0;P3jl>H00`000000n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool00440n_3V
00<000000?[`iP3jl>H0J`3jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V02l0n_3V
00<000000?[`iP3jl>H0AP3jl>H00`3=QCl0n_3V0?[`iP2^0?[`iP40oooo00110?[`iP030000003j
l>H0n_3V06/0n_3V00<0cHDo0?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP0`0?[`iP030000003j
l>H0n_3V04L0n_3V00<0cHDo0?[`iP3jl>H0[@3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP1Z
0?[`iP030<f5?`3jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP18
0?[`iP030<f5?`3jl>H0n_3V0:`0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0J@3jl>H00`3=
QCl0n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V0380n_3V00<000000?[`iP3jl>H0B03jl>H00`3=
QCl0n_3V0?[`iP2/0?[`iP40oooo00110?[`iP030000003jl>H0n_3V06T0n_3V00<0cHDo0?[`iP3j
l>H04`3jl>H00`000000n_3V0?[`iP0c0?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3j
l>H0Z`3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP1X0?[`iP030<f5?`3jl>H0n_3V01<0n_3V
00<000000?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V0:/0n_3V
0@3oool00440n_3V00<000000?[`iP3jl>H0J03jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP800000=`3j
l>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:X0n_3V0@3oool00080003o?`3jl>H0
0`000000n_3V0?[`iP1X0?[`iP030<f5?`3jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0=`3jl>H0
0`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:L0n_3V0P000?l10?[`iP40oooo00020?[`
iP<0003o?03jl>H00`000000n_3V0?[`iP1X0?[`iP030<f5?`3jl>H0n_3V00l0n_3V00<000000?[`
iP3jl>H0>03jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:@0n_3V0`000?l30?[`
iP40oooo00050?[`iP@0003o>03jl>H00`000000n_3V0?[`iP1W0?[`iP030<f5?`3jl>H0n_3V00l0
n_3V00<000000?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:00
n_3V10000?l60?[`iP40oooo00090?[`iP<0003o=@3jl>H00`000000n_3V0?[`iP1W0?[`iP030<f5
?`3jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP1;0?[`iP030<f5
?`3jl>H0n_3V09`0n_3V0`000?l:0?[`iP40oooo000<0?[`iP<0003o<P3jl>H00`000000n_3V0?[`
iP1V0?[`iP030<f5?`3jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0>`3jl>H00`000000n_3V0?[`
iP1;0?[`iP030<f5?`3jl>H0n_3V09T0n_3V0`000?l=0?[`iP40oooo000?0?[`iP@0003o;P3jl>H0
0`000000n_3V0?[`iP1V0?[`iP030<f5?`3jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H0?03jl>H0
0`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V09@0n_3V10000?l@0?[`iP40oooo000C0?[`
iP<0003o:`3jl>H00`000000n_3V0?[`iP1V0?[`iP030<f5?`3jl>H0n_3V00`0n_3V00<000000?[`
iP3jl>H0?@3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V0940n_3V0`000?lD0?[`
iP40oooo000F0?[`iP<0003o:03jl>H00`000000n_3V0?[`iP1V0?[`iP030<f5?`3jl>H0n_3V00/0
n_3V00<000000?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V08h0
n_3V0`000?lG0?[`iP40oooo000I0?[`iP<0003o9@3jl>H00`000000n_3V0?[`iP1U0?[`iP030<f5
?`3jl>H0n_3V00X0n_3V0P0000110?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0
R`3jl>H30000oaX0n_3V0@3oool001`0n_3V0`000?lR0?[`iP030000003jl>H0n_3V06D0n_3V00<0
cHDo0?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP110?[`iP030000003jl>H0n_3V04d0n_3V00<0
cHDo0?[`iP3jl>H0Q`3jl>H30000oad0n_3V0@3oool001l0n_3V10000?lN0?[`iP030000003jl>H0
n_3V06D0n_3V00<0cHDo0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP120?[`iP030000003jl>H0
n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0Q03jl>H30000ob00n_3V0@3oool002<0n_3V0`000?lK0?[`
iP030000003jl>H0n_3V06D0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP130?[`
iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0P@3jl>H30000ob<0n_3V0@3oool002H0
n_3V0`000?lH0?[`iP030000003jl>H0n_3V06@0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H00`000000
n_3V0?[`iP140?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0OP3jl>H30000obH0
n_3V0@3oool002T0n_3V0`000?lE0?[`iP030000003jl>H0n_3V06@0n_3V00<0cHDo0?[`iP3jl>H0
1P3jl>H00`000000n_3V0?[`iP150?[`iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0
NP3jl>H30000obT0n_3V0@3oool002`0n_3V0P000?lC0?[`iP030000003jl>H0n_3V06@0n_3V00<0
cHDo0?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP160?[`iP030000003jl>H0n_3V04h0n_3V00<0
cHDo0?[`iP3jl>H0N03jl>H20000ob`0n_3V0@3oool002h0n_3V0P000?lA0?[`iP030000003jl>H0
n_3V06@0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP170?[`iP030000003jl>H0
n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0MP3jl>H20000obh0n_3V0@3oool00300n_3V0`000?l>0?[`
iP030000003jl>H0n_3V06<0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP180?[`
iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0L`3jl>H30000oc00n_3V0@3oool003<0
n_3V0P000?l<0?[`iP030000003jl>H0n_3V06<0n_3V00<0cHDo0?[`iP3jl>H00P3jl>H2000004/0
n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1`0?[`iP80003o<`3jl>H10?ooo`00
=@3jl>H20000o`X0n_3V00<000000?[`iP3jl>H0H`3jl>H01@3=QCl0n_3V0?[`iP3jl>H0000004d0
n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1^0?[`iP80003o=@3jl>H10?ooo`00
=`3jl>H30000o`L0n_3V00<000000?[`iP3jl>H0H`3jl>H0103=QCl0n_3V0?[`iP00001>0?[`iP03
0000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0J`3jl>H30000ocL0n_3V0@3oool003X0n_3V
0P000?l50?[`iP030000003jl>H0n_3V06<0n_3V00<0cHDo0?[`iP000000C`3jl>H00`000000n_3V
0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06T0n_3V0P000?lj0?[`iP40oooo000l0?[`iP80003o0P3j
l>H300000680n_3V1000001@0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0I`3j
l>H20000oc`0n_3V0@3oool003h0n_3V00<0003o0000000000000`00001P0?[`iPD00000D03jl>H0
0`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06@0n_3V0`000?ln0?[`iP40oooo000o0?[`
iVX00000D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V0640n_3V0P000?m10?[`
iP40oooo000o0?[`iPD0000000<0003o0?[`iP3jl>H0G@3jl>H500000500n_3V00<000000?[`iP3j
l>H0D03jl>H00`3=QCl0n_3V0?[`iP1O0?[`iP80003o@`3jl>H10?ooo`00@03jl>H300000080n_3V
0P000?mM0?[`iP@00000D@3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05d0n_3V
0P000?m50?[`iP40oooo00110?[`iP030000003jl>H0n_3V00<0n_3V0P000?mI0?[`iP8000000P3j
l>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H0F`3j
l>H20000odL0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H01@3jl>H30000oeD0n_3V00<00000
0?[`iP3jl>H00P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo
0?[`iP3jl>H0F@3jl>H20000odT0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0203jl>H20000
oe80n_3V00<000000?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V
0500n_3V00<0cHDo0?[`iP3jl>H0E`3jl>H20000od/0n_3V0@3oool00440n_3V00<000000?[`iP3j
l>H02P3jl>H20000odl0n_3V00<000000?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP<0
0000D@3jl>H00`3=QCl0n_3V0?[`iP1E0?[`iP80003oC@3jl>H10?ooo`00@@3jl>H00`000000n_3V
0?[`iP0<0?[`iP80003oC03jl>H00`000000n_3V0?[`iP050?[`iP030<f5?`3jl>H0n_3V04h0n_3V
1@00001@0?[`iP030<f5?`3jl>H0n_3V05<0n_3V0P000?m?0?[`iP40oooo00110?[`iP030000003j
l>H0n_3V00h0n_3V0P000?m90?[`iP030000003jl>H0n_3V00H0n_3V00<0cHDo0?[`iP3jl>H0CP3j
l>H500000500n_3V00<0cHDo0?[`iP3jl>H0D@3jl>H20000oe40n_3V0@3oool00440n_3V00<00000
0?[`iP3jl>H0403jl>H20000odH0n_3V00<000000?[`iP3jl>H01`3jl>H00`3=QCl0n_3V0?[`iP1>
0?[`iPD00000D03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP80003oD`3jl>H10?ooo`00@@3jl>H00`00
0000n_3V0?[`iP0B0?[`iP80003o@`3jl>H00`000000n_3V0?[`iP080?[`iP030<f5?`3jl>H0n_3V
04l0n_3V0`00001A0?[`iP030<f5?`3jl>H0n_3V04d0n_3V0P000?mE0?[`iP40oooo00110?[`iP03
0000003jl>H0n_3V01@0n_3V0P000?m00?[`iP030000003jl>H0n_3V00T0n_3V00<0cHDo0?[`iP3j
l>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04/0n_3V0P000?mG0?[`iP40
oooo00110?[`iP030000003jl>H0n_3V01H0n_3V00<0003o0?[`iP3jl>H0?03jl>H00`000000n_3V
0?[`iP0:0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V
0?[`iP190?[`iP80003oF@3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0G0?[`iP80003o>P3j
l>H2000000d0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3j
l>H0n_3V04L0n_3V0P000?mK0?[`iP40oooo00110?[`iP030000003jl>H0n_3V01T0n_3V0P000?lg
0?[`iP030000003jl>H0n_3V00d0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@
0?[`iP030<f5?`3jl>H0n_3V04D0n_3V0P000?mM0?[`iP40oooo00110?[`iP030000003jl>H0n_3V
01/0n_3V0P000?ld0?[`iP030000003jl>H0n_3V00h0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`00
0000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04<0n_3V0P000?mO0?[`iP40oooo00110?[`iP03
0000003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0?0?[`iP03
0<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP110?[`iP80
003oH@3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0N0?[`iP80003o;`3jl>H00`000000n_3V
0?[`iP0@0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V
0?[`iP0o0?[`iP80003oH`3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0P0?[`iP80003o;03j
l>H00`000000n_3V0?[`iP0A0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0C`3j
l>H00`3=QCl0n_3V0?[`iP0n0?[`iP80003oI@3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0R
0?[`iP80003o:@3jl>H00`000000n_3V0?[`iP0C0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<00000
0?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP80003oI`3jl>H10?ooo`00@@3jl>H00`00
0000n_3V0?[`iP0T0?[`iP030000o`3jl>H0n_3V02D0n_3V00<000000?[`iP3jl>H0503jl>H00`3=
QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H00`00
0?l0n_3V0?[`iP1W0?[`iP40oooo00110?[`iP030000003jl>H0n_3V02D0n_3V0P000?lT0?[`iP03
0000003jl>H0n_3V01D0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP03
0<f5?`3jl>H0n_3V03T0n_3V0P000?mZ0?[`iP40oooo00110?[`iP030000003jl>H0n_3V02L0n_3V
0P000?lP0?[`iP800000603jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V
00<0cHDo0?[`iP3jl>H0>03jl>H00`000?l0n_3V0?[`iP1Z0?[`iP40oooo00110?[`iP030000003j
l>H0n_3V02T0n_3V00<0003o0?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP0H0?[`iP030<f5?`3j
l>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0f0?[`iP80003oK@3j
l>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0Z0?[`iP80003o6`3jl>H00`000000n_3V0?[`iP0I
0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0e
0?[`iP80003oK`3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0/0?[`iP80003o603jl>H00`00
0000n_3V0?[`iP0K0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=
QCl0n_3V0?[`iP0d0?[`iP030000o`3jl>H0n_3V06l0n_3V0@3oool00440n_3V00<000000?[`iP3j
l>H0;P3jl>H00`000?l0n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V01`0n_3V00<0cHDo0?[`iP3j
l>H0CP3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V0380n_3V0P000?mb0?[`iP40
oooo00110?[`iP030000003jl>H0n_3V02l0n_3V0P000?lC0?[`iP030000003jl>H0n_3V01d0n_3V
00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V0340n_3V
00<0003o0?[`iP3jl>H0LP3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0a0?[`iP80003o403j
l>H00`000000n_3V0?[`iP0N0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0C@3j
l>H00`3=QCl0n_3V0?[`iP0`0?[`iP80003oM@3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0c
0?[`iP030000o`3jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0803jl>H00`3=QCl0n_3V0?[`iP1=
0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0;P3jl>H20000ogL0n_3V0@3oool0
0440n_3V00<000000?[`iP3jl>H0=03jl>H20000o`/0n_3V00<000000?[`iP3jl>H08@3jl>H00`3=
QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`00
0?l0n_3V0?[`iP1g0?[`iP40oooo00110?[`iP030000003jl>H0n_3V03H0n_3V0P000?l70?[`iP80
0000903jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3j
l>H0:`3jl>H20000ogX0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0>03jl>H00`000?l0n_3V
0?[`iP030?[`iP030000003jl>H0n_3V02@0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V
0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02/0n_3V00<0003o0?[`iP3jl>H0NP3jl>H10?ooo`00@@3j
l>H00`000000n_3V0?[`iP0i0?[`iP80003o0P3jl>H00`000000n_3V0?[`iP0V0?[`iP030<f5?`3j
l>H0n_3V04`0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0Y0?[`iP80003oO@3j
l>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0k0?[`iP030000o`000000n_3V02P0n_3V00<0cHDo
0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02L0n_3V0P000?mo
0?[`iP40oooo00110?[`iP030000003jl>H0n_3V03/0n_3V00<000000?[`iP000?l0:03jl>H00`3=
QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H09P3jl>H00`00
0?l0n_3V0?[`iP1o0?[`iP40oooo00110?[`iP030000003jl>H0n_3V03X0n_3V00@000000?[`iP3j
l>H0n_3V0P000?lV0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0B`3jl>H00`3=
QCl0n_3V0?[`iP0U0?[`iP80003oPP3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0i0?[`iP03
0000003jl>H0n_3V00@0n_3V0P000?lU0?[`iP030<f5?`3jl>H0n_3V04/0n_3V00<000000?[`iP3j
l>H0B`3jl>H00`3=QCl0n_3V0?[`iP0T0?[`iP030000o`3jl>H0n_3V0880n_3V0@3oool00440n_3V
00<000000?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP070?[`iP030000o`3jl>H0n_3V0280n_3V
00<0cHDo0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V02<0n_3V
0P000?n50?[`iP40oooo00110?[`iP030000003jl>H0n_3V03L0n_3V00<000000?[`iP3jl>H02@3j
l>H20000ob<0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3j
l>H0n_3V0240n_3V0P000?n70?[`iP40oooo00110?[`iP030000003jl>H0n_3V03D0n_3V0P00000>
0?[`iP80003o8@3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V04X0n_3V00<0cHDo
0?[`iP3jl>H0803jl>H00`000?l0n_3V0?[`iP270?[`iP40oooo00110?[`iP030000003jl>H0n_3V
03@0n_3V00<000000?[`iP3jl>H0403jl>H20000oal0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`00
0000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V01h0n_3V0P000?n:0?[`iP40oooo00110?[`iP03
0000003jl>H0n_3V03<0n_3V00<000000?[`iP3jl>H04`3jl>H00`000?l0n_3V0?[`iP0L0?[`iP03
0<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP0N0?[`iP03
0000o`3jl>H0n_3V08X0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0<P3jl>H00`000000n_3V
0?[`iP0E0?[`iP80003o7@3jl>H00`3=QCl0n_3V0?[`iP190?[`iP030000003jl>H0n_3V04T0n_3V
00<0cHDo0?[`iP3jl>H0703jl>H20000ohd0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0<@3j
l>H00`000000n_3V0?[`iP0H0?[`iP80003o703jl>H00`3=QCl0n_3V0?[`iP180?[`iP030000003j
l>H0n_3V04P0n_3V00<0cHDo0?[`iP3jl>H06`3jl>H20000ohl0n_3V0@3oool00440n_3V00<00000
0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0K0?[`iP030000o`3jl>H0n_3V01T0n_3V00<0cHDo
0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP170?[`iP030<f5?`3jl>H0n_3V01/0n_3V00<0003o
0?[`iP3jl>H0S`3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V
01d0n_3V0P000?lJ0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H0A`3jl>H00`3=
QCl0n_3V0?[`iP0I0?[`iP80003oTP3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0^0?[`iP03
0000003jl>H0n_3V0200n_3V00<0003o0?[`iP3jl>H05`3jl>H00`3=QCl0n_3V0?[`iP170?[`iP03
0000003jl>H0n_3V04H0n_3V00<0cHDo0?[`iP3jl>H06@3jl>H00`000?l0n_3V0?[`iP2B0?[`iP40
oooo00110?[`iP030000003jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H08P3jl>H20000oaP0n_3V
00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V01L0n_3V
0P000?nE0?[`iP40oooo00110?[`iP030000003jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H09@3j
l>H00`000?l0n_3V0?[`iP0E0?[`iP030<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H0A@3j
l>H00`3=QCl0n_3V0?[`iP0G0?[`iP030000o`3jl>H0n_3V09D0n_3V0@3oool00440n_3V00<00000
0?[`iP3jl>H0:P3jl>H2000002T0n_3V0P000?lF0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<00000
0?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP80003oV03jl>H10?ooo`00@@3jl>H00`00
0000n_3V0?[`iP0Y0?[`iP030000003jl>H0n_3V02/0n_3V00<0003o0?[`iP3jl>H04`3jl>H00`3=
QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H05@3jl>H00`00
0?l0n_3V0?[`iP2H0?[`iP40oooo00110?[`iP030000003jl>H0n_3V02P0n_3V00<000000?[`iP3j
l>H0;@3jl>H20000oa@0n_3V00<0cHDo0?[`iP3jl>H0A03jl>H00`000000n_3V0?[`iP140?[`iP03
0<f5?`3jl>H0n_3V01<0n_3V0P000?nK0?[`iP40oooo00110?[`iP030000003jl>H0n_3V02L0n_3V
00<000000?[`iP3jl>H0<03jl>H00`000?l0n_3V0?[`iP0B0?[`iP030<f5?`3jl>H0n_3V04<0n_3V
00<000000?[`iP3jl>H0@`3jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP030000o`3jl>H0n_3V09/0n_3V
0@3oool00440n_3V00<000000?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP0b0?[`iP80003o4P3j
l>H00`3=QCl0n_3V0?[`iP130?[`iP030000003jl>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H04P3j
l>H20000oih0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H09@3jl>H00`000000n_3V0?[`iP0e
0?[`iP030000o`3jl>H0n_3V0100n_3V00<0cHDo0?[`iP3jl>H0@P3jl>H00`000000n_3V0?[`iP12
0?[`iP030<f5?`3jl>H0n_3V0140n_3V00<0003o0?[`iP3jl>H0WP3jl>H10?ooo`00@@3jl>H00`00
0000n_3V0?[`iP0T0?[`iP030000003jl>H0n_3V03L0n_3V0P000?lA0?[`iP030<f5?`3jl>H0n_3V
0440n_3V00<000000?[`iP3jl>H0@@3jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP80003oX@3jl>H10?oo
o`00@@3jl>H00`000000n_3V0?[`iP0S0?[`iP030000003jl>H0n_3V03X0n_3V00<0003o0?[`iP3j
l>H03`3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V0400n_3V00<0cHDo0?[`iP3j
l>H0403jl>H00`000?l0n_3V0?[`iP2Q0?[`iP40oooo00110?[`iP030000003jl>H0n_3V0280n_3V
00<000000?[`iP3jl>H0?03jl>H20000o`l0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V
0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V00l0n_3V0P000?nT0?[`iP40oooo00110?[`iP030000003j
l>H0n_3V0200n_3V0P0000110?[`iP030000o`3jl>H0n_3V00d0n_3V00<0cHDo0?[`iP3jl>H0?`3j
l>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V00h0n_3V00<0003o0?[`iP3jl>H0Y03j
l>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V0480n_3V0P000?l>
0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0?P3jl>H00`3=QCl0n_3V0?[`iP0=
0?[`iP80003oY`3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V
04D0n_3V0P000?l<0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3=
QCl0n_3V0?[`iP0<0?[`iP80003oZ@3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0M0?[`iP03
0000003jl>H0n_3V04P0n_3V00<0003o0?[`iP3jl>H02P3jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP03
0000003jl>H0n_3V03d0n_3V00<0cHDo0?[`iP3jl>H02P3jl>H20000oj/0n_3V0@3oool00440n_3V
00<000000?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP1:0?[`iP80003o2`3jl>H20<f5?cd0n_3V
00<000000?[`iP3jl>H0>`3jl>H20<f5?``0n_3V00<0003o0?[`iP3jl>H0Z`3jl>H10?ooo`00@@3j
l>H00`000000n_3V0?[`iP0K0?[`iP030000003jl>H0n_3V04d0n_3V0P000?l:0?[`iP030<f5?`3j
l>H0n_3V03/0n_3V00<000000?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`iP0:0?[`iP80003o[P3j
l>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V0500n_3V00<0003o
0?[`iP3jl>H0203jl>H00`3=QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo
0?[`iP3jl>H0203jl>H20000ok00n_3V0@3oool00440n_3V00<000000?[`iP3jl>H06@3jl>H00`00
0000n_3V0?[`iP1B0?[`iP80003o2@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V
03T0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H20000ok80n_3V0@3oool00440n_3V00<000000?[`iP3j
l>H0603jl>H00`000000n_3V0?[`iP1E0?[`iP80003o203jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP03
0000003jl>H0n_3V03P0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP2b0?[`iP40
oooo00110?[`iP030000003jl>H0n_3V01H0n_3V0P00001J0?[`iP030000o`3jl>H0n_3V00H0n_3V
00<0cHDo0?[`iP3jl>H0=`3jl>H00`000000n_3V0?[`iP0g0?[`iP030<f5?`3jl>H0n_3V00H0n_3V
0P000?ne0?[`iP40oooo00110?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0F`3j
l>H20000o`L0n_3V0P3=QClg0?[`iP030000003jl>H0n_3V03D0n_3V0P3=QCl70?[`iP80003o]`3j
l>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V05h0n_3V0P000?l6
0?[`iP030<f5?`3jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP05
0?[`iP80003o^@3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V
0640n_3V00<0003o0?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0n_3V
03@0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000?l0n_3V0?[`iP2i0?[`iP40oooo00110?[`iP03
0000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0H`3jl>H20000o`D0n_3V0P3=QCld0?[`iP03
0000003jl>H0n_3V0380n_3V0P3=QCl50?[`iP80003o_03jl>H10?ooo`00@@3jl>H00`000000n_3V
0?[`iP0A0?[`iP030000003jl>H0n_3V06H0n_3V0P000?l50?[`iP030<f5?`3jl>H0n_3V0340n_3V
00<000000?[`iP3jl>H0<@3jl>H00`3=QCl0n_3V0?[`iP030?[`iP80003o_P3jl>H10?ooo`00@@3j
l>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V06T0n_3V00<0003o0?[`iP3jl>H00`3j
l>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V0300n_3V00<0cHDo0?[`iP3jl>H00P3j
l>H20000ol00n_3V0@3oool00440n_3V00<000000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP1[
0?[`iP80003o103jl>H00`3=QCl0n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V02l0n_3V00@0cHDo
0?[`iP3jl>H0n_3V0P000?o20?[`iP40oooo00110?[`iP030000003jl>H0n_3V00h0n_3V00<00000
0?[`iP3jl>H0KP3jl>H20000o`<0n_3V0P3=QCl_0?[`iP030000003jl>H0n_3V02d0n_3V0P3=QCl3
0?[`iP030000o`3jl>H0n_3V0<80n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0303jl>H20000
07<0n_3V0P000?l30?[`iP030<f5?`3jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0;03jl>H0103=
QCl0n_3V0?[`iP3jl>H20000olD0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H02`3jl>H00`00
0000n_3V0?[`iP1e0?[`iP80003o0P3jl>H20<f5?b`0n_3V00<000000?[`iP3jl>H0:P3jl>H20<f5
?`80n_3V0P000?o70?[`iP40oooo00110?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3j
l>H0N03jl>H20000o`80n_3V0P3=QClZ0?[`iP030000003jl>H0n_3V02P0n_3V0P3=QCl20?[`iP80
003ob@3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V07/0n_3V
0P000?l20?[`iP030<f5?`3jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V
0?[`iP020000ol/0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`
iP1n0?[`iP80003o00<0n_3V0<f5?`3=QCl09`3jl>H00`000000n_3V0?[`iP0U0?[`iP80cHDo00<0
n_3V0000o`000?l0c@3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0
n_3V0840n_3V0`000?l20<f5?bD0n_3V00<000000?[`iP3jl>H08`3jl>H20<f5?`030?[`iP000?l0
003o0<l0n_3V0@3oool00440n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP250?[`
iP<0003o00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0Q0?[`iP80cHDo00<0n_3V0000
o`000?l0d@3jl>H10?ooo`00@@3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V08T0
n_3V0P000?l00`3=QCl0n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V01l0n_3V0P3=QCl30000om<0
n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP2<0?[`iP<0003o
7`3jl>H00`000000n_3V0?[`iP0M0?[`iP80cHDo0P000?oF0?[`iP40oooo00110?[`iP030000003j
l>H0n_3V0080n_3V0P00002B0?[`iP<0003o00<0cHDo0?[`iP3jl>H06@3jl>H00`000000n_3V0?[`
iP0I0?[`iP<0cHDo0`000?oH0?[`iP40oooo00110?[`iP050000003jl>H0n_3V0?[`iP000000U`3j
l>H30000oaT0n_3V00<000000?[`iP3jl>H05`3jl>H00`3=QCl0003o0000o`020000om/0n_3V0@3o
ool00440n_3V00@000000?[`iP3jl>H00000V`3jl>H40000oaD0n_3V00<000000?[`iP3jl>H04`3j
l>H00`3=QCl0003o0000o`020000oml0n_3V0@3oool00400n_3V1000002P0?[`iP@0003o4@3jl>H0
0`000000n_3V0?[`iP0?0?[`iP030<f5?`000?l0003o0080003oh`3jl>H10?ooo`00?`3jl>H50000
0:@0n_3V10000?l=0?[`iP030000003jl>H0n_3V00/0n_3V1@000?oW0?[`iP40oooo000o0<f5?`D0
0000Z03=QCl=0000o`03000000000?l0003o00/0003oj`3=QCl10?[`iP40oooo000o0?[`iPD00000
o`3jl>J`0?[`iP40oooo00100?[`iP<00000o`3jl>Ja0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00;H0n_3V0P0000000`1VHUh0c<Bk0?[`iP0[0?[`iP060=C<``1V
HUh0000000000029Q7h0i=_BI@3jl>H01P3Dc<<0IV9N000000000000RHAn0>CKdY`0n_3V0@3oool0
0;P0n_3V00<0IV9N0000003Le</0:`3jl>H01P1<BDD0`k^c0?[`iP3/h]T0000008V4OVD0n_3V00H0
C4U50<>k/`3jl>H0k>;I00000029Q7jL0?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V
0P0000020?[`iP040:nXX@1<BDD0000008V4OPL0n_3V00H0g=C;07UeL0000000000008V4OP3<a;/2
0?[`iP040:nXX@1<BDD0000008V4OP80n_3V0P0000020?[`iP80000000D0n_3V0<c4^`000000NGE`
0?[`iP0200000080n_3V0P0000000`1VHUh0n_3V0?[`iP070?[`iP8000000`3jl>H0103<a;/0C4U5
06IRGP3Tfm82000000030?[`iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V00000000
0000n_3V0P0000020?[`iP8000000P3jl>H00`29Q7h0IV9N0<c4^`02000000L0n_3V00D0g=C;07Ue
L0000000C4U50:BMUP020?[`iP040<c4^`1<BDD0IV9N0>CKdP80000000<0n_3V000000000000103j
l>H00`2TWIH000000:BMUP030?[`iP040:nXX@1<BDD0000008V4OPL0n_3V00@0[jRQ04a9A@1<BDD0
[jRQ0P3jl>H2000000H0n_3V0P0000001@3jl>H0`k^c00000033^k<0n_3V0080000000D0n_3V0<c4
^`1<BDD0C4U50:nXX@02000000030?[`iP000000000000<0n_3V0P0000001@3jl>H0c<Bk04a9A@1<
BDD0[jRQ00800000103jl>H2000000030>cRf@3jl>H0k>;I008000000P3jl>H00`29Q7h0IV9N0<c4
^`02000000030?[`iP00000000000080n_3V0P0000020?[`iP040:nXX@1<BDD0000008V4OP80n_3V
00L0k>;I09NAR`000000000007UeL03Tfm80n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0
n_3V0P0000020?[`iP80000000L0n_3V0:nXX@000000`k^c0>CKdP000000RHAn00D0n_3V00D0i=_B
0000002GTH/0n_3V0;VbZP02000000080?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0<c4^`0000000P0000000`3T
fm80n_3V0?[`iP060?[`iP8000000`3jl>H0101VHUh000000>CKdP2i/ZX2000000030?[`iP000000
000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000D0
n_3V0:BMUP000000`k^c0:BMUP02000000H0n_3V00`0i=_B0000002GTH/0n_3V0=C<``000000RHAn
0?[`iP1VHUh000000>CKdP2i/ZX2000000030?[`iP000000000000@0n_3V0`000000203/h]T0n_3V
0:nXX@000000`k^c0>CKdP000000RHAn1@3jl>H01`2i/ZX000000<>k/`33^k<000000;VbZP3jl>H0
0P0000060?[`iP80000000D0n_3V09NAR`000000Ui6;0?[`iP02000000050?[`iP1<BDD000000>CK
dP33^k<00P0000000`3jl>H00000000000030?[`iP80000000D0n_3V04a9A@000000i=_B0<>k/`02
000000@0n_3V00`0RHAn0000003Dc<<0n_3V0=C<``000000RHAn0?[`iP2TWIH000000<>k/`2TWIH2
000000030?[`iP00000000000080n_3V0P0000003`3jl>H0[jRQ00000033^k<0i=_B00000029Q7h0
n_3V07UeL0000000i=_B0>cRf@000000IV9N0?[`iP02000008@0n_3V0@3oool008<0n_3V0P000003
0?[`iP8000000P3jl>H2000000030?[`iP1<BDD0000000T0n_3V00<0Ui6;0000003Le</00P3jl>H2
000000030?[`iP1<BDD0000000D0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2
000000060?[`iP2GTH/0000008V4OP000000[jRQ203jl>H2000000<0n_3V0P0000020?[`iP800000
00<0n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080
n_3V0P0000000`3jl>H0C4U5000000020?[`iP8000001P3jl>H00`2GTH/000000>CKdP050?[`iP80
00000P3jl>H2000000030?[`iP000000000000<0n_3V00P0^K:Z00000029Q7h000000;VbZP3jl>H0
C4U5000000T0n_3V00L0IV9N0000003jl>H0n_3V0000001VHUh0n_3V008000001P3jl>H200000005
0?[`iP1<BDD0000004a9A@3jl>H00P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
000000000`3jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP030:nXX@0000000000
00<0000000@0[jRQ0?[`iP1<BDD000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H0C4U5000000070?[`iP050=C<``2TWIH0000004a9A@3jl>H00P0000240?[`iP40oooo0023
0?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0000000000004000000D0n_3V00<0C4U5
0000003jl>H00P3jl>H2000000030?[`iP000000000000@0000000<0n_3V0000000000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000001P3jl>H0C4U50000003/h]T0000006IRGPP0n_3V
0P0000030?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V0P0000020?[`iP800000
00@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000H0
n_3V0P0000060?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V0P1<BDD0103/h]T0
C4U504a9A@3jl>H6000000D0n_3V0P0000020?[`iP80000000<0n_3V0000000000001P3jl>H20000
00050>CKdP000000Ui6;0000003Tfm800P0000001@3jl>H0c<Bk0000002GTH/0i=_B0080000000<0
n_3V0000000000000`3jl>H2000000050?[`iP3<a;/0000009NAR`3Tfm800P0000040?[`iP080=C<
``000000RHAn0?[`iP2GTH/000000=C<``3jl>H200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V000000000000100000000`3jl>H0c<Bk04a9A@020000000304a9A@3<a;/0
n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V04a9
A@0000000P3jl>H00`000000IV9N0?[`iP040?[`iP8000000P3jl>H3000000030?[`iP1<BDD00000
0080n_3V00<0000006IRGP3jl>H00P0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00070=cDb`000000RHAn0?[`iP29Q7h000000>CKdP070?[`iP8000000`3jl>H200000080n_3V0P00
00000`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP800000
0P3jl>H2000000030?[`iP1<BDD000000080n_3V0P0000060?[`iP8000001P3jl>H200000080n_3V
0P0000000`3jl>H00000000000020?[`iP090<c4^`000000Y9fF0?[`iP2TWIH000000<c4^`1<BDD0
00000080n_3V00<0000006IRGP3jl>H0103jl>H01`1VHUh000000?[`iP3jl>H0000006IRGP3jl>H0
0P0000060?[`iP80000000D0c<Bk0000003Le</000000<c4^`0200000080n_3V00<0g=C;0:nXX@1i
MG000P0000000`3jl>H00000000000030?[`iP8000000P3jl>H00`3Le</0[jRQ07UeL002000000D0
n_3V00D0000004a9A@3jl>H0C4U5000000020?[`iP0404a9A@000000n_3V0?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP1<BDD000000080n_3V00L0000006IRGP3jl>H0C4U50000
001iMG00c<Bk00<0n_3V0P0000240?[`iP40oooo00230?[`iP8000000`3jl>H20000000;0:BMUP3T
fm80000006IRGP3jl>H0^K:Z00000033^k<0c<Bk0000002i/ZX01@3jl>H00`1<BDD000000?[`iP05
0?[`iP070;VbZP000000`k^c0<c4^`000000^K:Z0?[`iP02000000050;VbZP3Tfm80000004a9A@3j
l>H00P0000020?[`iP80000000L0[jRQ00000033^k<0n_3V0<>k/`000000[jRQ00L0n_3V0P000003
0?[`iP8000000P3jl>H2000000040?[`iP00000000000=C<``80n_3V0P0000001@2i/ZX0i=_B0000
001<BDD0n_3V0080000000`0n_3V000000000000^K:Z0>CKdP000000C4U50?[`iP2TWIH000000<>k
/`2TWIH2000000H0n_3V00<0C4U50000003jl>H01@3jl>H200000080n_3V0P0000004P3jl>H00000
0000003Dc<<0n_3V06IRGP000000k>;I0?[`iP3/h]T0000006IRGP2i/ZX000000<>k/`3<a;/00000
0;VbZPD0n_3V00L0^K:Z00000033^k<0`k^c0000002i/ZX0n_3V008000001P3jl>H2000000050:BM
UP1VHUh0n_3V06IRGP2TWIH00P000000203jl>H0NGE`0=C<``3jl>H0i=_B0000001<BDD0n_3V0P00
00000`3Dc<<0n_3V0?[`iP02000000070?[`iP1iMG00e<c30?[`iP3Tfm80000004a9A@050?[`iP05
07UeL0000000c<Bk0000001VHUh00P3jl>H0102TWIH000000<>k/`2TWIH20000000F0?[`iP000000
00000;VbZP3Tfm80000004a9A@3jl>H0^K:Z00000033^k<0c<Bk0000002i/ZX0n_3V06IRGP000000
n_3V0>CKdP000000NGE`0?[`iP800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P000000103L
e</0RHAn04a9A@3<a;/20?[`iP040:nXX@00000000000:nXX@H0n_3V00<0Ui6;0000003Tfm801P3j
l>H0102_Z:4000000000002_Z:420?[`iP80000000@0c<Bk07UeL01<BDD0c<Bk100000002P3jl>H0
00000000001VHUh000000>cRf@3jl>H0k>;I0000001VHUh70?[`iP8000000`3jl>H200000080n_3V
0P0000001P3jl>H0000000000029Q7h0NGE`0?[`iP80000000D0c<Bk07UeL01<BDD0c<Bk0?[`iP02
000000070?[`iP00000000000<c4^`1iMG00C4U50<c4^`020?[`iP0308V4OP1VHUh0c<Bk00800000
1P3jl>H00`2GTH/000000>CKdP050?[`iP8000000P3jl>H2000000040?[`iP000000000008V4OP80
000000P0RHAn0?[`iP3jl>H0n_3V08V4OP000000g=C;0:nXX@80000000<0[jRQ0?[`iP3jl>H01@3j
l>H01@2_Z:40C4U50000002_Z:40n_3V00@000001@3jl>H20000000506IRGP2TWIH0n_3V09NAR`1V
HUh00P0000000`3jl>H0i=_B08V4OP020000000306IRGP3Dc<<0n_3V0080000000<0RHAn07UeL03j
l>H00P0000000`3jl>H0i=_B08V4OP020000000306IRGP3Dc<<0n_3V00@0n_3V00D0Y9fF00000029
Q7h000000:BMUP030?[`iP0308V4OP1VHUh0c<Bk0080000000L0n_3V000000000000c<Bk07UeL01<
BDD0c<Bk0080n_3V00@0[jRQ000000000000[jRQ0P3jl>H01`3Tfm80NGE`000000000000RHAn0>CK
dP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000100n_3V00L0i=_B0000002G
TH/0n_3V0=C<``000000NGE`00l0n_3V0P0000020?[`iP8000003P3jl>H2000002`0n_3V00L0i=_B
0000002GTH/0n_3V0=C<``000000RHAn02D0n_3V0P0000060?[`iP<0000000<0c<Bk0?[`iP33^k<0
0`00000K0?[`iP050<c4^`000000000000000033^k<0Y03jl>H10?ooo`00P@3jl>H6000000030?[`
iP00000000000140n_3V00H0g=C;07UeL0000000000009NAR`3/h]T?0?[`iP040=cDb`29Q7h0n_3V
0?[`iP800000303jl>H6000001@0n_3V0P00000E0?[`iP050=cDb`1iMG0000000000002TWIH09P3j
l>H0103<a;/0IV9N00000029Q7h40?[`iP<0000000<0k>;I0?[`iP3Le</00`00000=0?[`iP800000
303jl>H01@3/h]T00000000000000000i=_B01h0n_3V0P0000240?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.17391 .38333 L
s
.17391 .05 m
.17391 .38333 L
s
.33337 .22033 m
.17391 .22033 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.17391 .38333 Mdot
.33337 .22033 Mdot
.17391 .22033 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool005L0n_3V00<000000?[`iP3jl>H0T`3jl>H:0<f5
?`030?[`iP00000000000080n_3V2P3=QCo]0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V08d0
n_3V1P3=QCl:0?[`iP030000003jl>H0000000`0n_3V1`3=QCoV0?[`iP40oooo001G0?[`iP030000
003jl>H0n_3V08/0n_3V0P3=QCl?0?[`iP040000003jl>H0n_3V000001<0n_3V0P3=QCoT0?[`iP40
oooo001G0?[`iP030000003jl>H0n_3V08L0n_3V103=QCl@0?[`iP050000003jl>H0n_3V0?[`iP00
00005@3jl>H30<f5?n40n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0P`3jl>H40<f5?a<0n_3V
00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0F0?[`iP@0cHDog@3jl>H10?ooo`00E`3j
l>H00`000000n_3V0?[`iP210?[`iP80cHDo5P3jl>H00`000000n_3V0?[`iP030?[`iP030000003j
l>H0n_3V01X0n_3V0P3=QCoK0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V07l0n_3V0P3=QClG
0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0703jl>H20<f5?mT0n_3V0@3oool0
05L0n_3V00<000000?[`iP3jl>H0O@3jl>H20<f5?aP0n_3V00<000000?[`iP3jl>H01@3jl>H00`00
0000n_3V0?[`iP0N0?[`iP80cHDoe`3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP1k0?[`iP80
cHDo6@3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V0200n_3V0P3=QCoE0?[`iP40
oooo001G0?[`iP030000003jl>H0n_3V07T0n_3V0P3=QClJ0?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H08P3jl>H20<f5?m<0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0M`3j
l>H20<f5?a/0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0T0?[`iP80cHDod@3j
l>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP1e0?[`iP80cHDo703jl>H00`000000n_3V0?[`iP09
0?[`iP030000003jl>H0n_3V02H0n_3V0P3=QCo?0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V
07@0n_3V00<0cHDo0?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V
02P0n_3V00<0cHDo0?[`iP3jl>H0c03jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP1b0?[`iP80
cHDo7@3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V02T0n_3V0P3=QCo<0?[`iP40
oooo001G0?[`iP030000003jl>H0n_3V0700n_3V0P3=QClN0?[`iP030000003jl>H0n_3V00`0n_3V
00<000000?[`iP3jl>H0:`3jl>H20<f5?lX0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0K`3j
l>H00`3=QCl0n_3V0?[`iP0M0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H0;@3j
l>H00`3=QCl0n_3V0?[`iP370?[`iP40oooo001G0?[`iP030000003jl>H0n_3V06d0n_3V0P3=QClO
0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0;P3jl>H20<f5?lL0n_3V0@3oool0
05L0n_3V00<000000?[`iP3jl>H0K03jl>H00`3=QCl0n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V
00l0n_3V00<000000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP340?[`iP40oooo001G0?[`iP03
0000003jl>H0n_3V06/0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP0@0?[`iP03
0000003jl>H0n_3V0340n_3V00<0cHDo0?[`iP3jl>H0``3jl>H10?ooo`00E`3jl>H00`000000n_3V
0?[`iP1Z0?[`iP030<f5?`3jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V
0?[`iP0b0?[`iP030<f5?`3jl>H0n_3V0<80n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0J03j
l>H20<f5?b40n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0c0?[`iP80cHDo`P3j
l>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP1W0?[`iP030<f5?`3jl>H0n_3V0200n_3V00<00000
0?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0d0?[`iP030<f5?`3jl>H0n_3V0<00n_3V0@3oool0
05L0n_3V00<000000?[`iP3jl>H0IP3jl>H00`3=QCl0n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V
01<0n_3V00<000000?[`iP3jl>H0=@3jl>H00`3=QCl0n_3V0?[`iP2o0?[`iP40oooo001G0?[`iP03
0000003jl>H0n_3V06D0n_3V00<0cHDo0?[`iP3jl>H0803jl>H00`000000n_3V0?[`iP0D0?[`iP03
0000003jl>H0n_3V03H0n_3V0P3=QCno0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V06@0n_3V
00<0cHDo0?[`iP3jl>H0803jl>H00`000000n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V03P0n_3V
00<0cHDo0?[`iP3jl>H0_03jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP1S0?[`iP030<f5?`3j
l>H0n_3V0200n_3V00<000000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP0i0?[`iP030<f5?`3j
l>H0n_3V0;/0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0HP3jl>H00`3=QCl0n_3V0?[`iP0P
0?[`iP030000003jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`iP2j
0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V0640n_3V00<0cHDo0?[`iP3jl>H0803jl>H00`00
0000n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H0^P3jl>H10?oo
o`00E`3jl>H00`000000n_3V0?[`iP1P0?[`iP030<f5?`3jl>H0n_3V0200n_3V00<000000?[`iP3j
l>H06@3jl>H00`000000n_3V0?[`iP0k0?[`iP030<f5?`3jl>H0n_3V0;T0n_3V0@3oool005L0n_3V
00<000000?[`iP3jl>H0G`3jl>H00`3=QCl0n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V01X0n_3V
00<000000?[`iP3jl>H0?03jl>H20<f5?kT0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0GP3j
l>H00`3=QCl0n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0?@3j
l>H00`3=QCl0n_3V0?[`iP2g0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V05h0n_3V00<0cHDo
0?[`iP3jl>H07`3jl>H00`000000n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V03h0n_3V00<0cHDo
0?[`iP3jl>H0]P3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP1M0?[`iP030<f5?`3jl>H0n_3V
01l0n_3V00<000000?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V
0;D0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0G03jl>H00`3=QCl0n_3V0?[`iP0O0?[`iP03
0000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=QCl0n_3V0?[`iP2e0?[`iP40
oooo001G0?[`iP030000003jl>H0n_3V05`0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H00`000000n_3V
0?[`iP0O0?[`iP030000003jl>H0n_3V0400n_3V00<0cHDo0?[`iP3jl>H0]03jl>H10?ooo`00E`3j
l>H00`000000n_3V0?[`iP1K0?[`iP030<f5?`3jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0803j
l>H00`000000n_3V0?[`iP110?[`iP030<f5?`3jl>H0n_3V0;<0n_3V0@3oool005L0n_3V00<00000
0?[`iP3jl>H0FP3jl>H00`3=QCl0n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V0240n_3V00<00000
0?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP2b0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V
05T0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V
04<0n_3V00<0cHDo0?[`iP3jl>H0/@3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP1H0?[`iP03
0<f5?`3jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP130?[`iP03
0<f5?`3jl>H0n_3V0;40n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0F03jl>H00`3=QCl0n_3V
0?[`iP0M0?[`iP030000003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0A03jl>H00`3=QCl0n_3V
0?[`iP2`0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V05L0n_3V00<0cHDo0?[`iP3jl>H07@3j
l>H00`000000n_3V0?[`iP0U0?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H0/03j
l>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP1G0?[`iP030<f5?`3jl>H0n_3V01`0n_3V00<00000
0?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V0:l0n_3V0@3oool0
05L0n_3V00<000000?[`iP3jl>H0EP3jl>H00`3=QCl0n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V
02L0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP2_0?[`iP40oooo001G0?[`iP03
0000003jl>H0n_3V05H0n_3V00<0cHDo0?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP0X0?[`iP03
0000003jl>H0n_3V04H0n_3V00<0cHDo0?[`iP3jl>H0[P3jl>H10?ooo`00E`3jl>H00`000000n_3V
0?[`iP1E0?[`iP030<f5?`3jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0:@3jl>H00`000000n_3V
0?[`iP160?[`iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0E@3j
l>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H0A`3j
l>H00`3=QCl0n_3V0?[`iP2]0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V05@0n_3V00<0cHDo
0?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V04P0n_3V00<0cHDo
0?[`iP3jl>H0[03jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP1C0?[`iP030<f5?`3jl>H0n_3V
01X0n_3V00<000000?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP180?[`iP030<f5?`3jl>H0n_3V
0:`0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0D`3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP03
0000003jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP2[0?[`iP40
oooo001G0?[`iP030000003jl>H0n_3V0580n_3V00<0cHDo0?[`iP3jl>H06@3jl>H00`000000n_3V
0?[`iP0^0?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3jl>H0Z`3jl>H10?ooo`00E`3j
l>H00`000000n_3V0?[`iP1B0?[`iP030<f5?`3jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H0;`3j
l>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:X0n_3V0@3oool00080003oE@3jl>H0
0`000000n_3V0?[`iP1B0?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H0<03jl>H0
0`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:L0n_3V0P000?l10?[`iP40oooo00020?[`
iP<0003oDP3jl>H00`000000n_3V0?[`iP1B0?[`iP030<f5?`3jl>H0n_3V01H0n_3V00<000000?[`
iP3jl>H0<@3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:@0n_3V0`000?l30?[`
iP40oooo00050?[`iP@0003oCP3jl>H00`000000n_3V0?[`iP1A0?[`iP030<f5?`3jl>H0n_3V01H0
n_3V00<000000?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:00
n_3V10000?l60?[`iP40oooo00090?[`iP<0003oB`3jl>H00`000000n_3V0?[`iP1A0?[`iP030<f5
?`3jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0<`3jl>H00`000000n_3V0?[`iP1;0?[`iP030<f5
?`3jl>H0n_3V09`0n_3V0`000?l:0?[`iP40oooo000<0?[`iP<0003oB03jl>H00`000000n_3V0?[`
iP1@0?[`iP030<f5?`3jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0=03jl>H00`000000n_3V0?[`
iP1;0?[`iP030<f5?`3jl>H0n_3V09T0n_3V0`000?l=0?[`iP40oooo000?0?[`iP@0003oA03jl>H0
0`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0=@3jl>H0
0`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V09@0n_3V10000?l@0?[`iP40oooo000C0?[`
iP<0003o@@3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V01<0n_3V00<000000?[`
iP3jl>H0=P3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V0940n_3V0`000?lD0?[`
iP40oooo000F0?[`iP<0003o?P3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V0180
n_3V00<000000?[`iP3jl>H0=`3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V08h0
n_3V0`000?lG0?[`iP40oooo000I0?[`iP<0003o>`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5
?`3jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5
?`3jl>H0n_3V08/0n_3V0`000?lJ0?[`iP40oooo000L0?[`iP<0003o>03jl>H00`000000n_3V0?[`
iP1?0?[`iP030<f5?`3jl>H0n_3V0140n_3V00<000000?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`
iP1=0?[`iP030<f5?`3jl>H0n_3V08L0n_3V0`000?lM0?[`iP40oooo000O0?[`iP@0003o=03jl>H0
0`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0>P3jl>H0
0`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V08@0n_3V0`000?lP0?[`iP40oooo000S0?[`
iP<0003o<@3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V0100n_3V00<000000?[`
iP3jl>H0>P3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V0840n_3V0`000?lS0?[`
iP40oooo000V0?[`iP<0003o;P3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V0100
n_3V00<000000?[`iP3jl>H0>`3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V07h0
n_3V0`000?lV0?[`iP40oooo000Y0?[`iP<0003o:`3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5
?`3jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0?03jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5
?`3jl>H0n_3V07X0n_3V0`000?lY0?[`iP40oooo000/0?[`iP80003o:@3jl>H00`000000n_3V0?[`
iP1>0?[`iP030<f5?`3jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`
iP1>0?[`iP030<f5?`3jl>H0n_3V07P0n_3V0P000?l/0?[`iP40oooo000^0?[`iP80003o9`3jl>H0
0`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H0?P3jl>H0
0`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V07H0n_3V0P000?l^0?[`iP40oooo000`0?[`
iP<0003o903jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V00d0n_3V00<000000?[`
iP3jl>H0?`3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V07<0n_3V0`000?l`0?[`
iP40oooo000c0?[`iP80003o8P3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V00`0
n_3V00<000000?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V0700
n_3V0P000?lc0?[`iP40oooo000e0?[`iP80003o803jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5
?`3jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5
?`3jl>H0n_3V06h0n_3V0P000?le0?[`iP40oooo000g0?[`iP<0003o7@3jl>H00`000000n_3V0?[`
iP1=0?[`iP030<f5?`3jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0@P3jl>H00`000000n_3V0?[`
iP1?0?[`iP030<f5?`3jl>H0n_3V06/0n_3V0`000?lg0?[`iP40oooo000j0?[`iP80003o6`3jl>H0
0`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0@`3jl>H0
0`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06T0n_3V0P000?lj0?[`iP40oooo000l0?[`
iP80003o6@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V00P0n_3V00<000000?[`
iP3jl>H0A03jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06L0n_3V0P000?ll0?[`
iP40oooo000n0?[`iP<0003o5P3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V00P0
n_3V00<000000?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06@0
n_3V0`000?ln0?[`iP40oooo00110?[`iP80003o503jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5
?`3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5
?`3jl>H0n_3V0640n_3V0P000?m10?[`iP40oooo00130?[`iP80003o4P3jl>H00`000000n_3V0?[`
iP1<0?[`iP030<f5?`3jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`
iP1@0?[`iP030<f5?`3jl>H0n_3V05l0n_3V0P000?m30?[`iP40oooo00150?[`iP80003o403jl>H0
0`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0B03jl>H0
0`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05d0n_3V0P000?m50?[`iP40oooo00170?[`
iP80003o3P3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V00@0n_3V00<000000?[`
iP3jl>H0B@3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05/0n_3V0P000?m70?[`
iP40oooo00190?[`iP<0003o2`3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V00<0
n_3V00<000000?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05T0
n_3V0P000?m90?[`iP40oooo001<0?[`iP80003o2@3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5
?`3jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5
?`3jl>H0n_3V05L0n_3V0P000?m;0?[`iP40oooo001>0?[`iP80003o1`3jl>H00`000000n_3V0?[`
iP1<0?[`iP050<f5?`3jl>H0n_3V0?[`iP000000C@3jl>H300000540n_3V00<0cHDo0?[`iP3jl>H0
E@3jl>H20000odd0n_3V0@3oool00500n_3V0P000?l50?[`iP030000003jl>H0n_3V04`0n_3V00@0
cHDo0?[`iP3jl>H00000C@3jl>H500000500n_3V00<0cHDo0?[`iP3jl>H0D`3jl>H20000odl0n_3V
0@3oool00580n_3V0P000?l20?[`iP<00000C03jl>H4000004h0n_3V1@00001@0?[`iP030<f5?`3j
l>H0n_3V0540n_3V0P000?mA0?[`iP40oooo001D0?[`iP030000o`000000000000<00000BP3jl>H5
000004h0n_3V1@00001@0?[`iP030<f5?`3jl>H0n_3V04l0n_3V0P000?mC0?[`iP40oooo001E0?[`
iU@00000C`3jl>H300000540n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H20000oeD0n_3V0@3oool005D0
n_3V1@00001:0?[`iPD00000D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04/0
n_3V0P000?mG0?[`iP40oooo001F0?[`iP<0000000<0n_3V0000o`3jl>H0B03jl>H400000540n_3V
00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP190?[`iP80003oF@3jl>H10?ooo`00E`3j
l>H010000000n_3V0?[`iP3jl>H20000odH0n_3V00@000000?[`iP3jl>H0cHDoDP3jl>H00`000000
n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04L0n_3V0P000?mK0?[`iP40oooo001G0?[`iP030000
003jl>H0n_3V00<0n_3V0P000?m30?[`iP050000003jl>H0n_3V0?[`iP3=QCl0DP3jl>H00`000000
n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04D0n_3V0P000?mM0?[`iP40oooo001G0?[`iP030000
003jl>H0n_3V00D0n_3V0P000?m00?[`iP030000003jl>H0n_3V0080n_3V00<0cHDo0?[`iP3jl>H0
D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04<0n_3V0P000?mO0?[`iP40oooo
001G0?[`iP030000003jl>H0n_3V00L0n_3V00<0003o0?[`iP3jl>H0?03jl>H00`000000n_3V0?[`
iP030?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`
iP110?[`iP80003oH@3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP080?[`iP80003o>`3jl>H0
0`000000n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H0
0`3=QCl0n_3V0?[`iP0o0?[`iP80003oH`3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP0:0?[`
iP80003o>03jl>H00`000000n_3V0?[`iP050?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`
iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP80003oI@3jl>H10?ooo`00E`3jl>H00`000000
n_3V0?[`iP0<0?[`iP80003o=@3jl>H00`000000n_3V0?[`iP070?[`iP030<f5?`3jl>H0n_3V04l0
n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP80003oI`3jl>H10?ooo`00
E`3jl>H00`000000n_3V0?[`iP0>0?[`iP030000o`3jl>H0n_3V0340n_3V00<000000?[`iP3jl>H0
203jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0
>`3jl>H00`000?l0n_3V0?[`iP1W0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V00l0n_3V0P00
0?l`0?[`iP030000003jl>H0n_3V00T0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`
iP1?0?[`iP030<f5?`3jl>H0n_3V03T0n_3V0P000?mZ0?[`iP40oooo001G0?[`iP030000003jl>H0
n_3V0140n_3V0P000?l]0?[`iP030000003jl>H0n_3V00X0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H0
0`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V03P0n_3V00<0003o0?[`iP3jl>H0JP3jl>H1
0?ooo`00E`3jl>H00`000000n_3V0?[`iP0C0?[`iP030000o`3jl>H0n_3V02T0n_3V00<000000?[`
iP3jl>H02`3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`
iP3jl>H0=P3jl>H20000ofd0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0503jl>H20000obP0
n_3V00<000000?[`iP3jl>H0303jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04h0
n_3V00<0cHDo0?[`iP3jl>H0=@3jl>H20000ofl0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0
5P3jl>H20000obD0n_3V00<000000?[`iP3jl>H03P3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000
003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0=03jl>H00`000?l0n_3V0?[`iP1_0?[`iP40oooo
001G0?[`iP030000003jl>H0n_3V01P0n_3V00<0003o0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`
iP0?0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`
iP0b0?[`iP80003oLP3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP0I0?[`iP80003o803jl>H0
0`000000n_3V0?[`iP0@0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H0
0`3=QCl0n_3V0?[`iP0a0?[`iP030000o`3jl>H0n_3V0780n_3V0@3oool005L0n_3V00<000000?[`
iP3jl>H06`3jl>H20000oad0n_3V00<000000?[`iP3jl>H04@3jl>H00`3=QCl0n_3V0?[`iP1>0?[`
iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0<03jl>H20000ogD0n_3V0@3oool005L0
n_3V00<000000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V0180
n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V02h0
n_3V0P000?mg0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V01h0n_3V0P000?lI0?[`iP030000
003jl>H0n_3V01<0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5
?`3jl>H0n_3V02d0n_3V00<0003o0?[`iP3jl>H0M`3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`
iP0P0?[`iP80003o5P3jl>H00`000000n_3V0?[`iP0D0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<0
00000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP80003oNP3jl>H10?ooo`00E`3jl>H0
0`000000n_3V0?[`iP0R0?[`iP030000o`3jl>H0n_3V0180n_3V00<000000?[`iP3jl>H05@3jl>H0
0`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H0
0`000?l0n_3V0?[`iP1j0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V02<0n_3V0P000?lA0?[`
iP030000003jl>H0n_3V01L0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP1<0?[`
iP030<f5?`3jl>H0n_3V02T0n_3V0P000?mm0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V02D0
n_3V0P000?l>0?[`iP030000003jl>H0n_3V01P0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000
n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02L0n_3V0P000?mo0?[`iP40oooo001G0?[`iP030000
003jl>H0n_3V02L0n_3V00<0003o0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0I0?[`iP030<f5
?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0V0?[`iP030000
o`3jl>H0n_3V07l0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0:03jl>H20000o`T0n_3V00<0
00000?[`iP3jl>H06P3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04/0n_3V00<0
cHDo0?[`iP3jl>H09@3jl>H20000oh80n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0:P3jl>H2
0000o`H0n_3V00<000000?[`iP3jl>H0703jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0
n_3V04/0n_3V00<0cHDo0?[`iP3jl>H0903jl>H00`000?l0n_3V0?[`iP220?[`iP40oooo001G0?[`
iP030000003jl>H0n_3V02`0n_3V00<0003o0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0M0?[`
iP030<f5?`3jl>H0n_3V04/0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0S0?[`
iP80003oQ@3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP0]0?[`iP80003o00<0n_3V0000003j
l>H0803jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3j
l>H08@3jl>H20000ohL0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0;`3jl>H00`000000003o
0?[`iP0P0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V
0?[`iP0P0?[`iP030000o`3jl>H0n_3V08L0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0;P3j
l>H00`000000n_3V0?[`iP020000oal0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`
iP1:0?[`iP030<f5?`3jl>H0n_3V01h0n_3V0P000?n:0?[`iP40oooo001G0?[`iP030000003jl>H0
n_3V02d0n_3V00<000000?[`iP3jl>H00`3jl>H00`000?l0n_3V0?[`iP0L0?[`iP030<f5?`3jl>H0
n_3V04X0n_3V00<000000?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP0N0?[`iP030000o`3jl>H0
n_3V08X0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP050?[`
iP80003o7@3jl>H00`3=QCl0n_3V0?[`iP190?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`
iP3jl>H0703jl>H20000ohd0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0:`3jl>H00`000000
n_3V0?[`iP080?[`iP80003o703jl>H00`3=QCl0n_3V0?[`iP180?[`iP030000003jl>H0n_3V04P0
n_3V00<0cHDo0?[`iP3jl>H06`3jl>H20000ohl0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0
:P3jl>H00`000000n_3V0?[`iP0;0?[`iP030000o`3jl>H0n_3V01T0n_3V00<0cHDo0?[`iP3jl>H0
B03jl>H00`000000n_3V0?[`iP170?[`iP030<f5?`3jl>H0n_3V01/0n_3V00<0003o0?[`iP3jl>H0
S`3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP0Y0?[`iP030000003jl>H0n_3V00d0n_3V0P00
0?lJ0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H0A`3jl>H00`3=QCl0n_3V0?[`
iP0I0?[`iP80003oTP3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP0X0?[`iP030000003jl>H0
n_3V0100n_3V00<0003o0?[`iP3jl>H05`3jl>H00`3=QCl0n_3V0?[`iP170?[`iP030000003jl>H0
n_3V04H0n_3V00<0cHDo0?[`iP3jl>H06@3jl>H00`000?l0n_3V0?[`iP2B0?[`iP40oooo001G0?[`
iP030000003jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H04P3jl>H20000oaP0n_3V00<0cHDo0?[`
iP3jl>H0AP3jl>H00`000000n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V01L0n_3V0P000?nE0?[`
iP40oooo001G0?[`iP030000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H05@3jl>H00`000?l0
n_3V0?[`iP0E0?[`iP030<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0
n_3V0?[`iP0G0?[`iP030000o`3jl>H0n_3V09D0n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0
9@3jl>H00`000000n_3V0?[`iP0G0?[`iP80003o5P3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000
003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H05@3jl>H20000oiP0n_3V0@3oool005L0n_3V00<0
00000?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP0J0?[`iP030000o`3jl>H0n_3V01<0n_3V00<0
cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0n_3V01D0n_3V00<0
003o0?[`iP3jl>H0V03jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP0S0?[`iP030000003jl>H0
n_3V01`0n_3V0P000?lD0?[`iP030<f5?`3jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H0A03jl>H0
0`3=QCl0n_3V0?[`iP0C0?[`iP80003oV`3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP0R0?[`
iP030000003jl>H0n_3V01l0n_3V00<0003o0?[`iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`iP130?[`
iP030000003jl>H0n_3V04<0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H00`000?l0n_3V0?[`iP2K0?[`
iP40oooo001G0?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H08@3jl>H20000oa80
n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V0180
n_3V0P000?nN0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0
903jl>H00`000?l0n_3V0?[`iP0@0?[`iP030<f5?`3jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0
@P3jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000o`3jl>H0n_3V09h0n_3V0@3oool005L0n_3V00<0
00000?[`iP3jl>H07`3jl>H00`000000n_3V0?[`iP0V0?[`iP80003o4@3jl>H00`3=QCl0n_3V0?[`
iP110?[`iP030000003jl>H0n_3V0440n_3V00<0cHDo0?[`iP3jl>H0403jl>H20000oj40n_3V0@3o
ool005L0n_3V00<000000?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP0Y0?[`iP030000o`3jl>H0
n_3V00l0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP100?[`iP030<f5?`3jl>H0
n_3V0100n_3V00<0003o0?[`iP3jl>H0X@3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP0M0?[`
iP030000003jl>H0n_3V02/0n_3V0P000?l?0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`
iP3jl>H0?`3jl>H00`3=QCl0n_3V0?[`iP0?0?[`iP80003oY03jl>H10?ooo`00E`3jl>H00`000000
n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V02h0n_3V00<0003o0?[`iP3jl>H03@3jl>H00`3=QCl0
n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H03P3jl>H00`000?l0
n_3V0?[`iP2T0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0
<03jl>H20000o`h0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0n0?[`iP030<f5
?`3jl>H0n_3V00d0n_3V0P000?nW0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V01X0n_3V00<0
00000?[`iP3jl>H0<`3jl>H20000o``0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`
iP0m0?[`iP030<f5?`3jl>H0n_3V00`0n_3V0P000?nY0?[`iP40oooo001G0?[`iP030000003jl>H0
n_3V01T0n_3V00<000000?[`iP3jl>H0=P3jl>H00`000?l0n_3V0?[`iP0:0?[`iP030<f5?`3jl>H0
n_3V03d0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3=QCl0n_3V0?[`iP0:0?[`iP80003oZ`3jl>H1
0?ooo`00E`3jl>H00`000000n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V03P0n_3V0P000?l;0?[`
iP80cHDo?@3jl>H00`000000n_3V0?[`iP0k0?[`iP80cHDo303jl>H00`000?l0n_3V0?[`iP2[0?[`
iP40oooo001G0?[`iP030000003jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H0>`3jl>H20000o`X0
n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H00`000000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V00X0
n_3V0P000?n^0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H0
?P3jl>H00`000?l0n_3V0?[`iP080?[`iP030<f5?`3jl>H0n_3V03X0n_3V00<000000?[`iP3jl>H0
>P3jl>H00`3=QCl0n_3V0?[`iP080?[`iP80003o/03jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`
iP0E0?[`iP030000003jl>H0n_3V0400n_3V0P000?l90?[`iP030<f5?`3jl>H0n_3V03T0n_3V00<0
00000?[`iP3jl>H0>@3jl>H00`3=QCl0n_3V0?[`iP070?[`iP80003o/P3jl>H10?ooo`00E`3jl>H0
0`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V04<0n_3V0P000?l80?[`iP030<f5?`3jl>H0
n_3V03P0n_3V00<000000?[`iP3jl>H0>03jl>H00`3=QCl0n_3V0?[`iP070?[`iP030000o`3jl>H0
n_3V0;80n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP160?[`
iP030000o`3jl>H0n_3V00H0n_3V00<0cHDo0?[`iP3jl>H0=`3jl>H00`000000n_3V0?[`iP0g0?[`
iP030<f5?`3jl>H0n_3V00H0n_3V0P000?ne0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V0180
n_3V00<000000?[`iP3jl>H0B03jl>H20000o`L0n_3V0P3=QClg0?[`iP030000003jl>H0n_3V03D0
n_3V0P3=QCl70?[`iP80003o]`3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP0A0?[`iP030000
003jl>H0n_3V04/0n_3V0P000?l60?[`iP030<f5?`3jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0
=03jl>H00`3=QCl0n_3V0?[`iP050?[`iP80003o^@3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`
iP0A0?[`iP030000003jl>H0n_3V04d0n_3V00<0003o0?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`
iP0d0?[`iP030000003jl>H0n_3V03@0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000?l0n_3V0?[`
iP2i0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0C`3jl>H2
0000o`D0n_3V0P3=QCld0?[`iP030000003jl>H0n_3V0380n_3V0P3=QCl50?[`iP80003o_03jl>H1
0?ooo`00E`3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V0580n_3V0P000?l50?[`
iP030<f5?`3jl>H0n_3V0340n_3V00<000000?[`iP3jl>H0<@3jl>H00`3=QCl0n_3V0?[`iP030?[`
iP80003o_P3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V05D0
n_3V00<0003o0?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V0300
n_3V00<0cHDo0?[`iP3jl>H00P3jl>H20000ol00n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0
3@3jl>H00`000000n_3V0?[`iP1G0?[`iP80003o103jl>H00`3=QCl0n_3V0?[`iP0_0?[`iP030000
003jl>H0n_3V02l0n_3V00@0cHDo0?[`iP3jl>H0n_3V0P000?o20?[`iP40oooo001G0?[`iP030000
003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0FP3jl>H20000o`<0n_3V0P3=QCl_0?[`iP030000
003jl>H0n_3V02d0n_3V0P3=QCl30?[`iP030000o`3jl>H0n_3V0<80n_3V0@3oool005L0n_3V00<0
00000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP1M0?[`iP80003o0`3jl>H00`3=QCl0n_3V0?[`
iP0/0?[`iP030000003jl>H0n_3V02`0n_3V00@0cHDo0?[`iP3jl>H0n_3V0P000?o50?[`iP40oooo
001G0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0H03jl>H20000o`80n_3V0P3=
QCl/0?[`iP030000003jl>H0n_3V02X0n_3V0P3=QCl20?[`iP80003oa`3jl>H10?ooo`00E`3jl>H0
0`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V06<0n_3V0P000?l20?[`iP80cHDo:P3jl>H0
0`000000n_3V0?[`iP0X0?[`iP80cHDo0P3jl>H20000olT0n_3V0@3oool005L0n_3V00<000000?[`
iP3jl>H0203jl>H00`000000n_3V0?[`iP1V0?[`iP80003o0P3jl>H00`3=QCl0n_3V0?[`iP0W0?[`
iP030000003jl>H0n_3V02L0n_3V00<0cHDo0?[`iP3jl>H00P000?o;0?[`iP40oooo001G0?[`iP03
0000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0J@3jl>H20000o`030?[`iP3=QCl0cHDo02L0
n_3V00<000000?[`iP3jl>H09@3jl>H20<f5?`030?[`iP000?l0003o0<d0n_3V0@3oool005L0n_3V
00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP1/0?[`iP<0003o0P3=QClU0?[`iP030000
003jl>H0n_3V02<0n_3V0P3=QCl00`3jl>H0003o0000o`3?0?[`iP40oooo001G0?[`iP030000003j
l>H0n_3V00D0n_3V00<000000?[`iP3jl>H0L03jl>H30000o`030<f5?`3jl>H0n_3V0240n_3V00<0
00000?[`iP3jl>H08@3jl>H20<f5?`030?[`iP000?l0003o0=40n_3V0@3oool005L0n_3V00<00000
0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP1d0?[`iP80003o00<0cHDo0?[`iP3jl>H07`3jl>H0
0`000000n_3V0?[`iP0O0?[`iP80cHDo0`000?oC0?[`iP40oooo001G0?[`iP030000003jl>H0n_3V
00<0n_3V00<000000?[`iP3jl>H0M`3jl>H30000oal0n_3V00<000000?[`iP3jl>H07@3jl>H20<f5
?`80003oeP3jl>H10?ooo`00E`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V07/0
n_3V0`000?l00`3=QCl0n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V01T0n_3V0`3=QCl30000omP0
n_3V0@3oool005L0n_3V00D000000?[`iP3jl>H0n_3V000000210?[`iP<0003o6@3jl>H00`000000
n_3V0?[`iP0G0?[`iP030<f5?`000?l0003o0080003of`3jl>H10?ooo`00E`3jl>H010000000n_3V
0?[`iP0000250?[`iP@0003o5@3jl>H00`000000n_3V0?[`iP0C0?[`iP030<f5?`000?l0003o0080
003og`3jl>H10?ooo`00EP3jl>H4000008X0n_3V10000?lA0?[`iP030000003jl>H0n_3V00l0n_3V
00<0cHDo0000o`000?l00P000?oS0?[`iP40oooo001E0?[`iPD00000SP3jl>H40000o`d0n_3V00<0
00000?[`iP3jl>H02`3jl>H50000onL0n_3V0@3oool005D0cHDo1@00002B0<f5?`d0003o00<00000
0000o`000?l02`000?o[0<f5?`40n_3V0@3oool005D0n_3V1@00003o0?[`iYX0n_3V0@3oool005H0
n_3V0`00003o0?[`iY/0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00]P3jl>H20000000306IRGP3<a;/0n_3V02/0n_3V00H0e<c306IRGP000000000008V4OP3Tfm9U
0?[`iP060=C<``1VHUh0000000000029Q7h0i=_BW03jl>H10?ooo`00^03jl>H00`1VHUh000000=cD
b`0[0?[`iP0604a9A@33^k<0n_3V0>cRf@000000RHAnI@3jl>H01P1<BDD0`k^c0?[`iP3/h]T00000
08V4OY`0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V00@0[jRQ04a9
A@000000RHAn1`3jl>H01P3Le</0NGE`000000000000RHAn0<c4^`80n_3V00@0[jRQ04a9A@000000
RHAn0P3jl>H200000080n_3V0P0000001@3jl>H0c<Bk0000001iMG00n_3V008000000P3jl>H20000
000306IRGP3jl>H0n_3V00L0n_3V0P0000030?[`iP040<c4^`1<BDD0IV9N0>CKdP80000000<0n_3V
0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00
00020?[`iP0308V4OP1VHUh0c<Bk008000001`3jl>H01@3Le</0NGE`0000001<BDD0Y9fF0080n_3V
00@0c<Bk04a9A@1VHUh0i=_B0P0000000`3jl>H00000000000040?[`iP030:BMUP000000Y9fF00<0
n_3V00@0[jRQ04a9A@000000RHAn1`3jl>H0102_Z:40C4U504a9A@2_Z:420?[`iP8000001P3jl>H2
000000050?[`iP33^k<000000<>k/`3jl>H00P0000001@3jl>H0c<Bk04a9A@1<BDD0[jRQ00800000
00<0n_3V0000000000000`3jl>H2000000050?[`iP3<a;/0C4U504a9A@2_Z:400P0000040?[`iP80
000000<0k>;I0?[`iP3/h]T00P0000020?[`iP0308V4OP1VHUh0c<Bk0080000000<0n_3V00000000
00000P3jl>H200000080n_3V00@0[jRQ04a9A@000000RHAn0P3jl>H01`3/h]T0Ui6;000000000000
NGE`0>CKdP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P000000
1`3jl>H0[jRQ00000033^k<0i=_B00000029Q7h01@3jl>H01@3Tfm80000009NAR`3jl>H0^K:Z0080
000000P0n_3V0:nXX@000000`k^c0>CKdP000000RHAn0?[`iP8000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H0c<Bk00000002000000030>CKdP3jl>H0n_3V00H0n_3V0P00
00030?[`iP0406IRGP000000i=_B0;VbZP80000000<0n_3V0000000000000`3jl>H200000080n_3V
0P000000103jl>H000000000003jl>H200000080n_3V0P0000001@3jl>H0Y9fF00000033^k<0Y9fF
008000001P3jl>H0303Tfm80000009NAR`3jl>H0e<c300000029Q7h0n_3V06IRGP000000i=_B0;Vb
ZP80000000<0n_3V000000000000103jl>H3000000080>cRf@3jl>H0[jRQ00000033^k<0i=_B0000
0029Q7h50?[`iP070;VbZP000000`k^c0<>k/`000000^K:Z0?[`iP02000000H0n_3V0P0000001@3j
l>H0Ui6;0000002GTH/0n_3V0080000000D0n_3V04a9A@000000i=_B0<>k/`02000000030?[`iP00
0000000000<0n_3V0P0000001@3jl>H0C4U50000003Tfm80`k^c00800000103jl>H03029Q7h00000
0=C<``3jl>H0e<c300000029Q7h0n_3V0:BMUP000000`k^c0:BMUP80000000<0n_3V000000000000
0P3jl>H20000000?0?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP3jl>H0NGE`0000003Tfm80k>;I
0000001VHUh0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP800000
00<0n_3V04a9A@0000002@3jl>H00`2GTH/000000=cDb`020?[`iP80000000<0n_3V04a9A@000000
1@3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000H0n_3V09NAR`000000
RHAn0000002_Z:480?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`
iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000030?[`iP1<BDD0
00000080n_3V0P0000060?[`iP0309NAR`000000i=_B00D0n_3V0P0000020?[`iP80000000<0n_3V
0000000000000`3jl>H0202i/ZX0000008V4OP000000^K:Z0?[`iP1<BDD000002@3jl>H01`1VHUh0
00000?[`iP3jl>H0000006IRGP3jl>H00P0000060?[`iP80000000D0n_3V04a9A@000000C4U50?[`
iP02000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000030?[`iP80000000<0
n_3V0000000000000P3jl>H2000000@0n_3V00<0[jRQ0000000000000`000000102_Z:40n_3V04a9
A@0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP1<BDD0000000L0n_3V
00D0e<c30:BMUP000000C4U50?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP800000
0P3jl>H2000000030?[`iP000000000000@000001@3jl>H00`1<BDD000000?[`iP020?[`iP800000
00<0n_3V000000000000100000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000060?[`iP1<BDD000000>cRf@000000IV9N203jl>H2000000<0n_3V0P0000020?[`
iP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2
00000080n_3V0P0000000`3jl>H00000000000020?[`iP8000001P3jl>H2000000H0n_3V0P000002
0?[`iP80000000<0n_3V0000000000000`3jl>H204a9A@040>cRf@1<BDD0C4U50?[`iPH000001@3j
l>H200000080n_3V0P0000000`3jl>H00000000000060?[`iP80000000D0i=_B0000002GTH/00000
0>CKdP02000000050?[`iP3<a;/0000009NAR`3Tfm800P0000000`3jl>H00000000000030?[`iP80
000000D0n_3V0<c4^`000000Ui6;0>CKdP02000000@0n_3V00P0e<c300000029Q7h0n_3V09NAR`00
0000e<c30?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
00000004000000030?[`iP3<a;/0C4U50080000000<0C4U50<c4^`3jl>H00P0000240?[`iP40oooo
00230?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP030000001V
HUh0n_3V00@0n_3V0P0000020?[`iP<0000000<0n_3V04a9A@0000000P3jl>H00`000000IV9N0?[`
iP0200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000L0g=C;00000029Q7h0n_3V
08V4OP000000i=_B00L0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP000000000000<0
n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V04a9
A@0000000P3jl>H2000000H0n_3V0P0000060?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V00T0c<Bk0000002TWIH0n_3V0:BMUP000000c<Bk04a9A@0000000P3jl>H00`000000IV9N
0?[`iP040?[`iP0706IRGP000000n_3V0?[`iP000000IV9N0?[`iP02000000H0n_3V0P0000001@3<
a;/000000=cDb`000000c<Bk008000000P3jl>H00`3Le</0[jRQ07UeL002000000030?[`iP000000
000000<0n_3V0P0000020?[`iP030=cDb`2_Z:40NGE`008000001@3jl>H01@000000C4U50?[`iP1<
BDD000000080n_3V00@0C4U50000003jl>H0n_3V0P0000000`3jl>H00000000000020?[`iP800000
00<0n_3V04a9A@0000000P3jl>H01`000000IV9N0?[`iP1<BDD0000007UeL03<a;/00`3jl>H20000
08@0n_3V0@3oool008<0n_3V0P0000030?[`iP80000000/0Y9fF0>CKdP000000IV9N0?[`iP2i/ZX0
00000<>k/`3<a;/000000;VbZP050?[`iP0304a9A@000000n_3V00D0n_3V00L0^K:Z00000033^k<0
c<Bk0000002i/ZX0n_3V0080000000D0^K:Z0>CKdP000000C4U50?[`iP0200000080n_3V0P000000
1`2_Z:4000000<>k/`3jl>H0`k^c0000002_Z:401`3jl>H2000000<0n_3V0P0000020?[`iP800000
00@0n_3V000000000000e<c30P3jl>H2000000050;VbZP3Tfm80000004a9A@3jl>H00P000000303j
l>H000000000002i/ZX0i=_B0000001<BDD0n_3V0:BMUP000000`k^c0:BMUP8000001P3jl>H00`1<
BDD000000?[`iP050?[`iP8000000P3jl>H20000000B0?[`iP00000000000=C<``3jl>H0IV9N0000
003/h]T0n_3V0>cRf@000000IV9N0;VbZP000000`k^c0<c4^`000000^K:Z1@3jl>H01`2i/ZX00000
0<>k/`33^k<000000;VbZP3jl>H00P0000060?[`iP80000000D0Y9fF06IRGP3jl>H0IV9N0:BMUP02
000000080?[`iP1iMG00e<c30?[`iP3Tfm80000004a9A@3jl>H2000000030=C<``3jl>H0n_3V0080
000000L0n_3V07UeL03Dc<<0n_3V0>CKdP000000C4U500D0n_3V00D0NGE`0000003<a;/0000006IR
GP020?[`iP040:BMUP000000`k^c0:BMUP80000001H0n_3V000000000000^K:Z0>CKdP000000C4U5
0?[`iP2i/ZX000000<>k/`3<a;/000000;VbZP3jl>H0IV9N0000003jl>H0i=_B0000001iMG00n_3V
0P0000240?[`iP40oooo00230?[`iP8000000`3jl>H2000000040=cDb`29Q7h0C4U50<c4^`80n_3V
00@0[jRQ000000000000[jRQ1P3jl>H00`2GTH/000000>CKdP060?[`iP040:nXX@00000000000:nX
X@80n_3V0P000000103<a;/0NGE`04a9A@3<a;/40000000:0?[`iP000000000006IRGP000000k>;I
0?[`iP3/h]T0000006IRGPL0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP0000000000
08V4OP1iMG00n_3V0P0000001@3<a;/0NGE`04a9A@3<a;/0n_3V0080000000L0n_3V000000000000
c<Bk07UeL01<BDD0c<Bk0080n_3V00<0RHAn06IRGP3<a;/00P0000060?[`iP0309NAR`000000i=_B
00D0n_3V0P0000020?[`iP80000000@0n_3V000000000000RHAn0P0000002029Q7h0n_3V0?[`iP3j
l>H0RHAn0000003Le</0[jRQ0P0000000`2_Z:40n_3V0?[`iP050?[`iP050:nXX@1<BDD000000:nX
X@3jl>H0100000050?[`iP80000000D0IV9N0:BMUP3jl>H0Ui6;06IRGP02000000030?[`iP3Tfm80
RHAn0080000000<0IV9N0=C<``3jl>H00P0000000`29Q7h0NGE`0?[`iP02000000030?[`iP3Tfm80
RHAn0080000000<0IV9N0=C<``3jl>H0103jl>H01@2TWIH0000008V4OP000000Y9fF00<0n_3V00<0
RHAn06IRGP3<a;/00P0000001`3jl>H000000000003<a;/0NGE`04a9A@3<a;/00P3jl>H0102_Z:40
00000000002_Z:420?[`iP070>CKdP1iMG00000000000029Q7h0i=_B0?[`iP02000008@0n_3V0@3o
ool008<0n_3V0P0000030?[`iP800000403jl>H01`3Tfm80000009NAR`3jl>H0e<c30000001iMG00
3`3jl>H200000080n_3V0P00000>0?[`iP800000;03jl>H01`3Tfm80000009NAR`3jl>H0e<c30000
0029Q7h09@3jl>H2000000H0n_3V0`0000000`3<a;/0n_3V0<>k/`03000001/0n_3V00D0c<Bk0000
0000000000000<>k/`2T0?[`iP40oooo00210?[`iPH0000000<0n_3V0000000000004@3jl>H01P3L
e</0NGE`000000000000Ui6;0>cRf@l0n_3V00@0g=C;08V4OP3jl>H0n_3V0P00000<0?[`iPH00000
503jl>H2000001D0n_3V00D0g=C;07UeL000000000000:BMUP0V0?[`iP040<c4^`1VHUh0000008V4
OP@0n_3V0`0000000`3/h]T0n_3V0=cDb`03000000d0n_3V0P00000<0?[`iP050>cRf@0000000000
0000003Tfm807P3jl>H2000008@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.21739 .38333 L
s
.21739 .05 m
.21739 .38333 L
s
.33558 .24393 m
.21739 .24393 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.21739 .38333 Mdot
.33558 .24393 Mdot
.21739 .24393 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool006`0n_3V00<000000?[`iP3jl>H0OP3jl>H:0<f5
?`030?[`iP00000000000080n_3V2P3=QCo]0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V07P0
n_3V1P3=QCl:0?[`iP030000003jl>H0000000`0n_3V1`3=QCoV0?[`iP40oooo001/0?[`iP030000
003jl>H0n_3V07H0n_3V0P3=QCl?0?[`iP040000003jl>H0n_3V000001<0n_3V0P3=QCoT0?[`iP40
oooo001/0?[`iP030000003jl>H0n_3V0780n_3V103=QClA0?[`iP040000003jl>H0n_3V000001D0
n_3V0`3=QCoQ0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V06h0n_3V103=QClD0?[`iP050000
003jl>H0n_3V0?[`iP000000603jl>H40<f5?md0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0
K03jl>H20<f5?aL0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0J0?[`iP80cHDo
f`3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP1Z0?[`iP80cHDo603jl>H00`000000n_3V0?[`
iP030?[`iP030000003jl>H0n_3V01`0n_3V0P3=QCoI0?[`iP40oooo001/0?[`iP030000003jl>H0
n_3V06P0n_3V0P3=QClI0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H07P3jl>H2
0<f5?mL0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0IP3jl>H20<f5?aX0n_3V00<000000?[`
iP3jl>H01@3jl>H00`000000n_3V0?[`iP0P0?[`iP80cHDoe@3jl>H10?ooo`00K03jl>H00`000000
n_3V0?[`iP1T0?[`iP80cHDo703jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V0280
n_3V0P3=QCoC0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V0680n_3V0P3=QClM0?[`iP030000
003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0903jl>H20<f5?m40n_3V0@3oool006`0n_3V00<0
00000?[`iP3jl>H0H03jl>H20<f5?ah0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP0V0?[`iP80cHDoc`3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP1O0?[`iP030<f5?`3jl>H0
n_3V01d0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0X0?[`iP030<f5?`3jl>H0
n_3V0<`0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0G@3jl>H20<f5?al0n_3V00<000000?[`
iP3jl>H02@3jl>H00`000000n_3V0?[`iP0Y0?[`iP80cHDoc03jl>H10?ooo`00K03jl>H00`000000
n_3V0?[`iP1K0?[`iP80cHDo803jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V02/0
n_3V0P3=QCo:0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V05X0n_3V00<0cHDo0?[`iP3jl>H0
7`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V02d0n_3V00<0cHDo0?[`iP3jl>H0
a`3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP1H0?[`iP80cHDo8P3jl>H00`000000n_3V0?[`
iP0;0?[`iP030000003jl>H0n_3V02h0n_3V0P3=QCo70?[`iP40oooo001/0?[`iP030000003jl>H0
n_3V05L0n_3V00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0
n_3V0300n_3V00<0cHDo0?[`iP3jl>H0a03jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP1F0?[`
iP030<f5?`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0a0?[`
iP030<f5?`3jl>H0n_3V0<<0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0E@3jl>H00`3=QCl0
n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0<P3jl>H00`3=QCl0
n_3V0?[`iP320?[`iP40oooo001/0?[`iP030000003jl>H0n_3V05<0n_3V0P3=QClS0?[`iP030000
003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0<`3jl>H20<f5?l80n_3V0@3oool006`0n_3V00<0
00000?[`iP3jl>H0DP3jl>H00`3=QCl0n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V0100n_3V00<0
00000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP300?[`iP40oooo001/0?[`iP030000003jl>H0
n_3V0540n_3V00<0cHDo0?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0
n_3V03D0n_3V00<0cHDo0?[`iP3jl>H0_`3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP1@0?[`
iP030<f5?`3jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0f0?[`
iP80cHDo_`3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V02<0
n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0h0?[`iP030<f5?`3jl>H0n_3V0;`0
n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0S0?[`iP030000
003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0>@3jl>H00`3=QCl0n_3V0?[`iP2k0?[`iP40oooo
001/0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H08`3jl>H00`000000n_3V0?[`
iP0D0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H0^P3jl>H10?ooo`00K03jl>H0
0`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H05@3jl>H0
0`000000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V0;X0n_3V0@3oool006`0n_3V00<000000?[`
iP3jl>H0B`3jl>H00`3=QCl0n_3V0?[`iP0S0?[`iP030000003jl>H0n_3V01H0n_3V00<000000?[`
iP3jl>H0>`3jl>H00`3=QCl0n_3V0?[`iP2i0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V04X0
n_3V00<0cHDo0?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V03`0
n_3V0P3=QCni0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3jl>H0
903jl>H00`000000n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V03d0n_3V00<0cHDo0?[`iP3jl>H0
]`3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V02<0n_3V00<0
00000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP0n0?[`iP030<f5?`3jl>H0n_3V0;H0n_3V0@3o
ool006`0n_3V00<000000?[`iP3jl>H0B03jl>H00`3=QCl0n_3V0?[`iP0S0?[`iP030000003jl>H0
n_3V01T0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=QCl0n_3V0?[`iP2e0?[`iP40oooo001/0?[`
iP030000003jl>H0n_3V04L0n_3V00<0cHDo0?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP0J0?[`
iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H0]@3jl>H10?ooo`00K03jl>H00`000000
n_3V0?[`iP170?[`iP030<f5?`3jl>H0n_3V0280n_3V00<000000?[`iP3jl>H06`3jl>H00`000000
n_3V0?[`iP100?[`iP030<f5?`3jl>H0n_3V0;@0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0
AP3jl>H00`3=QCl0n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H0
@@3jl>H00`3=QCl0n_3V0?[`iP2c0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V04D0n_3V00<0
cHDo0?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V0480n_3V00<0
cHDo0?[`iP3jl>H0/P3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0
n_3V02<0n_3V00<000000?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP130?[`iP030<f5?`3jl>H0
n_3V0;40n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0@`3jl>H00`3=QCl0n_3V0?[`iP0S0?[`
iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0@`3jl>H00`3=QCl0n_3V0?[`iP2a0?[`
iP40oooo001/0?[`iP030000003jl>H0n_3V04<0n_3V00<0cHDo0?[`iP3jl>H08P3jl>H00`000000
n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H0/03jl>H10?ooo`00
K03jl>H00`000000n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V0280n_3V00<000000?[`iP3jl>H0
803jl>H00`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0n_3V0;00n_3V0@3oool006`0n_3V00<0
00000?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V0240n_3V00<0
00000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP2_0?[`iP40oooo001/0?[`iP030000003jl>H0
n_3V0440n_3V00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0R0?[`iP030000003jl>H0
n_3V04D0n_3V00<0cHDo0?[`iP3jl>H0[`3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP110?[`
iP030<f5?`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP160?[`
iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0@03jl>H00`3=QCl0
n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H0AP3jl>H00`3=QCl0
n_3V0?[`iP2^0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V0400n_3V00<0cHDo0?[`iP3jl>H0
803jl>H00`000000n_3V0?[`iP0T0?[`iP030000003jl>H0n_3V04L0n_3V00<0cHDo0?[`iP3jl>H0
[@3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V0200n_3V00<0
00000?[`iP3jl>H09@3jl>H00`000000n_3V0?[`iP180?[`iP030<f5?`3jl>H0n_3V0:`0n_3V0@3o
ool006`0n_3V00<000000?[`iP3jl>H0?P3jl>H00`3=QCl0n_3V0?[`iP0P0?[`iP030000003jl>H0
n_3V02H0n_3V00<000000?[`iP3jl>H0B03jl>H00`3=QCl0n_3V0?[`iP2/0?[`iP40oooo001/0?[`
iP030000003jl>H0n_3V03h0n_3V00<0cHDo0?[`iP3jl>H07`3jl>H00`000000n_3V0?[`iP0W0?[`
iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3jl>H0Z`3jl>H10?ooo`00K03jl>H00`000000
n_3V0?[`iP0m0?[`iP030<f5?`3jl>H0n_3V0200n_3V00<000000?[`iP3jl>H09`3jl>H00`000000
n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V0:/0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0
?@3jl>H00`3=QCl0n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H0
BP3jl>H00`3=QCl0n_3V0?[`iP2Z0?[`iP40oooo00020000ofX0n_3V00<000000?[`iP3jl>H0?@3j
l>H00`3=QCl0n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V02T0n_3V00<000000?[`iP3jl>H0BP3j
l>H00`3=QCl0n_3V0?[`iP2W0?[`iP80003o0@3jl>H10?ooo`000P3jl>H30000ofL0n_3V00<00000
0?[`iP3jl>H0?@3jl>H00`3=QCl0n_3V0?[`iP0M0?[`iP030000003jl>H0n_3V02X0n_3V00<00000
0?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2T0?[`iP<0003o0`3jl>H10?ooo`001@3jl>H40000
of<0n_3V00<000000?[`iP3jl>H0?03jl>H00`3=QCl0n_3V0?[`iP0M0?[`iP030000003jl>H0n_3V
02/0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2P0?[`iP@0003o1P3jl>H10?oo
o`002@3jl>H30000of00n_3V00<000000?[`iP3jl>H0?03jl>H00`3=QCl0n_3V0?[`iP0L0?[`iP03
0000003jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0B`3jl>H00`3=QCl0n_3V0?[`iP2L0?[`iP<0
003o2P3jl>H10?ooo`00303jl>H30000oed0n_3V00<000000?[`iP3jl>H0>`3jl>H00`3=QCl0n_3V
0?[`iP0L0?[`iP030000003jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H0B`3jl>H00`3=QCl0n_3V
0?[`iP2I0?[`iP<0003o3@3jl>H10?ooo`003`3jl>H40000oeT0n_3V00<000000?[`iP3jl>H0>`3j
l>H00`3=QCl0n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H0C03j
l>H00`3=QCl0n_3V0?[`iP2D0?[`iP@0003o403jl>H10?ooo`004`3jl>H30000oeH0n_3V00<00000
0?[`iP3jl>H0>`3jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP030000003jl>H0n_3V02h0n_3V00<00000
0?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP2A0?[`iP<0003o503jl>H10?ooo`005P3jl>H30000
oe<0n_3V00<000000?[`iP3jl>H0>`3jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V
02l0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP2>0?[`iP<0003o5`3jl>H10?oo
o`006@3jl>H30000oe00n_3V00<000000?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP03
0000003jl>H0n_3V0300n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP2;0?[`iP<0
003o6P3jl>H10?ooo`00703jl>H30000odd0n_3V00<000000?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V
0?[`iP0I0?[`iP030000003jl>H0n_3V0340n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V
0?[`iP270?[`iP<0003o7@3jl>H10?ooo`007`3jl>H40000odT0n_3V00<000000?[`iP3jl>H0>P3j
l>H00`3=QCl0n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V0380n_3V00<000000?[`iP3jl>H0C@3j
l>H00`3=QCl0n_3V0?[`iP240?[`iP<0003o803jl>H10?ooo`008`3jl>H30000odH0n_3V00<00000
0?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V03<0n_3V00<00000
0?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP210?[`iP<0003o8`3jl>H10?ooo`009P3jl>H30000
od<0n_3V00<000000?[`iP3jl>H0>@3jl>H00`3=QCl0n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V
03<0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP1n0?[`iP<0003o9P3jl>H10?oo
o`00:@3jl>H30000od00n_3V00<000000?[`iP3jl>H0>@3jl>H00`3=QCl0n_3V0?[`iP0G0?[`iP03
0000003jl>H0n_3V03@0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP1j0?[`iP<0
003o:@3jl>H10?ooo`00;03jl>H20000och0n_3V00<000000?[`iP3jl>H0>@3jl>H00`3=QCl0n_3V
0?[`iP0F0?[`iP030000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V
0?[`iP1h0?[`iP80003o;03jl>H10?ooo`00;P3jl>H20000oc`0n_3V00<000000?[`iP3jl>H0>@3j
l>H00`3=QCl0n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V03H0n_3V00<000000?[`iP3jl>H0CP3j
l>H00`3=QCl0n_3V0?[`iP1f0?[`iP80003o;P3jl>H10?ooo`00<03jl>H30000ocT0n_3V00<00000
0?[`iP3jl>H0>03jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V03L0n_3V00<00000
0?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP1c0?[`iP<0003o<03jl>H10?ooo`00<`3jl>H20000
ocL0n_3V00<000000?[`iP3jl>H0>03jl>H00`3=QCl0n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V
03P0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1`0?[`iP80003o<`3jl>H10?oo
o`00=@3jl>H20000ocD0n_3V00<000000?[`iP3jl>H0>03jl>H00`3=QCl0n_3V0?[`iP0D0?[`iP03
0000003jl>H0n_3V03P0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1^0?[`iP80
003o=@3jl>H10?ooo`00=`3jl>H30000oc80n_3V00<000000?[`iP3jl>H0>03jl>H00`3=QCl0n_3V
0?[`iP0C0?[`iP030000003jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V
0?[`iP1[0?[`iP<0003o=`3jl>H10?ooo`00>P3jl>H20000oc00n_3V00<000000?[`iP3jl>H0>03j
l>H00`3=QCl0n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V03X0n_3V00<000000?[`iP3jl>H0C`3j
l>H00`3=QCl0n_3V0?[`iP1Y0?[`iP80003o>P3jl>H10?ooo`00?03jl>H20000obh0n_3V00<00000
0?[`iP3jl>H0>03jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V03/0n_3V00<00000
0?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1W0?[`iP80003o?03jl>H10?ooo`00?P3jl>H30000
ob/0n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V
03`0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1T0?[`iP<0003o?P3jl>H10?oo
o`00@@3jl>H20000obT0n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP03
0000003jl>H0n_3V03d0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1Q0?[`iP80
003o@@3jl>H10?ooo`00@`3jl>H20000obL0n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V
0?[`iP0?0?[`iP030000003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V
0?[`iP1O0?[`iP80003o@`3jl>H10?ooo`00A@3jl>H20000obD0n_3V00<000000?[`iP3jl>H0=`3j
l>H00`3=QCl0n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0D03j
l>H00`3=QCl0n_3V0?[`iP1M0?[`iP80003oA@3jl>H10?ooo`00A`3jl>H20000ob<0n_3V00<00000
0?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V03l0n_3V00<00000
0?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1K0?[`iP80003oA`3jl>H10?ooo`00B@3jl>H30000
ob00n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V
0400n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1I0?[`iP80003oB@3jl>H10?oo
o`00C03jl>H20000oah0n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP03
0000003jl>H0n_3V0440n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1G0?[`iP80
003oB`3jl>H10?ooo`00CP3jl>H20000oa`0n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V
0?[`iP0;0?[`iP030000003jl>H0n_3V0440n_3V0`00001A0?[`iP030<f5?`3jl>H0n_3V05D0n_3V
0P000?m=0?[`iP40oooo001@0?[`iP80003o6P3jl>H00`000000n_3V0?[`iP0g0?[`iP030<f5?`3j
l>H0n_3V00X0n_3V00<000000?[`iP3jl>H0@@3jl>H500000500n_3V00<0cHDo0?[`iP3jl>H0D`3j
l>H20000odl0n_3V0@3oool00580n_3V0P000?lH0?[`iP030000003jl>H0n_3V03L0n_3V00<0cHDo
0?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP120?[`iPD00000D03jl>H00`3=QCl0n_3V0?[`iP1A
0?[`iP80003oD@3jl>H10?ooo`00E03jl>H20000oaH0n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=
QCl0n_3V0?[`iP090?[`iP030000003jl>H0n_3V0480n_3V1@00001@0?[`iP030<f5?`3jl>H0n_3V
04l0n_3V0P000?mC0?[`iP40oooo001F0?[`iP80003o503jl>H00`000000n_3V0?[`iP0g0?[`iP03
0<f5?`3jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0A03jl>H300000540n_3V00<0cHDo0?[`iP3j
l>H0C@3jl>H20000oeD0n_3V0@3oool005P0n_3V0P000?lB0?[`iP030000003jl>H0n_3V03L0n_3V
00<0cHDo0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP160?[`iP030000003jl>H0n_3V0500n_3V
00<0cHDo0?[`iP3jl>H0B`3jl>H20000oeL0n_3V0@3oool005X0n_3V00<0003o0?[`iP3jl>H03`3j
l>H00`000000n_3V0?[`iP0g0?[`iP030<f5?`3jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0A`3j
l>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04T0n_3V0P000?mI0?[`iP40oooo001K
0?[`iP80003o3`3jl>H00`000000n_3V0?[`iP0g0?[`iP030<f5?`3jl>H0n_3V00D0n_3V00<00000
0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04L0n_3V0P000?mK
0?[`iP40oooo001M0?[`iP80003o3@3jl>H00`000000n_3V0?[`iP0g0?[`iP030<f5?`3jl>H0n_3V
00@0n_3V00<000000?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V
04D0n_3V0P000?mM0?[`iP40oooo001O0?[`iP80003o2`3jl>H00`000000n_3V0?[`iP0g0?[`iP03
0<f5?`3jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`iP1@0?[`iP03
0<f5?`3jl>H0n_3V04<0n_3V0P000?mO0?[`iP40oooo001Q0?[`iP030000o`3jl>H0n_3V00P0n_3V
00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V0?[`iP030?[`iP030000003jl>H0n_3V04X0n_3V
00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP110?[`iP80003oH@3jl>H10?ooo`00HP3j
l>H20000o`P0n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V0?[`iP020?[`iP030000003j
l>H0n_3V04/0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP80003oH`3j
l>H10?ooo`00I03jl>H20000o`H0n_3V00<000000?[`iP3jl>H0=`3jl>H01@3=QCl0n_3V0?[`iP3j
l>H0000004h0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP80003oI@3j
l>H10?ooo`00IP3jl>H20000o`@0n_3V00<000000?[`iP3jl>H0>03jl>H00`3=QCl0n_3V0000001?
0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0?03jl>H20000ofL0n_3V0@3oool0
06P0n_3V00<0003o0?[`iP3jl>H00`00000h0?[`iP<00000D03jl>H00`000000n_3V0?[`iP1?0?[`
iP030<f5?`3jl>H0n_3V03/0n_3V00<0003o0?[`iP3jl>H0I`3jl>H10?ooo`00J@3jl>H00`000?l0
000000000003000003H0n_3V1@00001?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3j
l>H0>@3jl>H20000ofX0n_3V0@3oool006X0n_3V@000001?0?[`iP030000003jl>H0n_3V04l0n_3V
00<0cHDo0?[`iP3jl>H0>03jl>H00`000?l0n_3V0?[`iP1Z0?[`iP40oooo001Z0?[`iPD00000=P3j
l>H5000004l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0f0?[`iP80003oK@3j
l>H10?ooo`00J`3jl>H300000080003o=@3jl>H400000500n_3V00<000000?[`iP3jl>H0CP3jl>H0
0`3=QCl0n_3V0?[`iP0e0?[`iP80003oK`3jl>H10?ooo`00K03jl>H010000000n_3V0?[`iP3jl>H2
0000oc80n_3V00D000000?[`iP3jl>H0n_3V0<f5?`1@0?[`iP030000003jl>H0n_3V04h0n_3V00<0
cHDo0?[`iP3jl>H0=03jl>H00`000?l0n_3V0?[`iP1_0?[`iP40oooo001/0?[`iP030000003jl>H0
n_3V00<0n_3V00<0003o0?[`iP3jl>H0;P3jl>H00`000000n_3V0?[`iP020?[`iP030<f5?`3jl>H0
n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0b0?[`iP80003oLP3jl>H1
0?ooo`00K03jl>H00`000000n_3V0?[`iP040?[`iP80003o;@3jl>H00`000000n_3V0?[`iP030?[`
iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0a0?[`
iP030000o`3jl>H0n_3V0780n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H01P3jl>H20000ob/0
n_3V00<000000?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04d0
n_3V00<0cHDo0?[`iP3jl>H0<03jl>H20000ogD0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0
203jl>H00`000?l0n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V00D0n_3V00<0cHDo0?[`iP3jl>H0
C@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V02h0n_3V0P000?mg0?[`iP40oooo
001/0?[`iP030000003jl>H0n_3V00T0n_3V0P000?lV0?[`iP030000003jl>H0n_3V00H0n_3V00<0
cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V02d0n_3V00<0
003o0?[`iP3jl>H0M`3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP0;0?[`iP80003o8`3jl>H0
0`000000n_3V0?[`iP070?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0C@3jl>H0
0`3=QCl0n_3V0?[`iP0[0?[`iP80003oNP3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP0=0?[`
iP030000o`3jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0203jl>H00`3=QCl0n_3V0?[`iP1=0?[`
iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`000?l0n_3V0?[`iP1j0?[`
iP40oooo001/0?[`iP030000003jl>H0n_3V00h0n_3V0P000?lN0?[`iP030000003jl>H0n_3V00X0
n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02T0
n_3V0P000?mm0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V0100n_3V0P000?lK0?[`iP030000
003jl>H0n_3V00/0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5
?`3jl>H0n_3V02L0n_3V0P000?mo0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V0180n_3V00<0
003o0?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP0;0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<0
00000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0V0?[`iP030000o`3jl>H0n_3V07l0n_3V0@3o
ool006`0n_3V00<000000?[`iP3jl>H04`3jl>H20000oaL0n_3V00<000000?[`iP3jl>H0303jl>H0
0`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04/0n_3V00<0cHDo0?[`iP3jl>H09@3jl>H2
0000oh80n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H05@3jl>H20000oa@0n_3V00<000000?[`
iP3jl>H03P3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V04/0n_3V00<0cHDo0?[`
iP3jl>H0903jl>H00`000?l0n_3V0?[`iP220?[`iP40oooo001/0?[`iP030000003jl>H0n_3V01L0
n_3V00<0003o0?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V04/0
n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0S0?[`iP80003oQ@3jl>H10?ooo`00
K03jl>H00`000000n_3V0?[`iP0H0?[`iP80003o3`3jl>H00`000000n_3V0?[`iP0A0?[`iP030<f5
?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0Q0?[`iP80003o
Q`3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP0J0?[`iP80003o303jl>H00`000000n_3V0?[`
iP0B0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`
iP0P0?[`iP030000o`3jl>H0n_3V08L0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0703jl>H2
0000o`T0n_3V00<000000?[`iP3jl>H04`3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0
n_3V04X0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H20000ohX0n_3V0@3oool006`0n_3V00<000000?[`
iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP060?[`iP030000003jl>H0n_3V01<0n_3V00<0cHDo0?[`
iP3jl>H0BP3jl>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V01h0n_3V00<0003o0?[`
iP3jl>H0RP3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP0O0?[`iP80003o1@3jl>H00`000000
n_3V0?[`iP0E0?[`iP030<f5?`3jl>H0n_3V04T0n_3V00<000000?[`iP3jl>H0B@3jl>H00`3=QCl0
n_3V0?[`iP0L0?[`iP80003oS@3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP0Q0?[`iP80003o
0P3jl>H00`000000n_3V0?[`iP0G0?[`iP030<f5?`3jl>H0n_3V04P0n_3V00<000000?[`iP3jl>H0
B03jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP80003oS`3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`
iP0S0?[`iP030000o`000000n_3V01T0n_3V00<0cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`
iP170?[`iP030<f5?`3jl>H0n_3V01/0n_3V00<0003o0?[`iP3jl>H0S`3jl>H10?ooo`00K03jl>H0
0`000000n_3V0?[`iP0S0?[`iP03000000000?l0003o01X0n_3V00<0cHDo0?[`iP3jl>H0A`3jl>H0
0`000000n_3V0?[`iP170?[`iP030<f5?`3jl>H0n_3V01T0n_3V0P000?nB0?[`iP40oooo001/0?[`
iP030000003jl>H0n_3V0280n_3V00D000000?[`iP3jl>H0n_3V0000o`0I0?[`iP030<f5?`3jl>H0
n_3V04L0n_3V00<000000?[`iP3jl>H0AP3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000o`3jl>H0
n_3V0980n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP020?[`
iP80003o603jl>H00`3=QCl0n_3V0?[`iP160?[`iP030000003jl>H0n_3V04H0n_3V00<0cHDo0?[`
iP3jl>H05`3jl>H20000oiD0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H08@3jl>H00`000000
n_3V0?[`iP050?[`iP030000o`3jl>H0n_3V01D0n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000
n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<0003o0?[`iP3jl>H0U@3jl>H10?ooo`00
K03jl>H00`000000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V00L0n_3V0P000?lF0?[`iP030<f5
?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP80003o
V03jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V00X0n_3V00<0
003o0?[`iP3jl>H04`3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V04@0n_3V00<0
cHDo0?[`iP3jl>H05@3jl>H00`000?l0n_3V0?[`iP2H0?[`iP40oooo001/0?[`iP030000003jl>H0
n_3V01h0n_3V00<000000?[`iP3jl>H0303jl>H20000oa@0n_3V00<0cHDo0?[`iP3jl>H0A03jl>H0
0`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0n_3V01<0n_3V0P000?nK0?[`iP40oooo001/0?[`
iP030000003jl>H0n_3V01d0n_3V00<000000?[`iP3jl>H03`3jl>H00`000?l0n_3V0?[`iP0B0?[`
iP030<f5?`3jl>H0n_3V04<0n_3V00<000000?[`iP3jl>H0@`3jl>H00`3=QCl0n_3V0?[`iP0C0?[`
iP030000o`3jl>H0n_3V09/0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0703jl>H00`000000
n_3V0?[`iP0A0?[`iP80003o4P3jl>H00`3=QCl0n_3V0?[`iP130?[`iP030000003jl>H0n_3V0480
n_3V00<0cHDo0?[`iP3jl>H04P3jl>H20000oih0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0
703jl>H00`000000n_3V0?[`iP0C0?[`iP030000o`3jl>H0n_3V0100n_3V00<0cHDo0?[`iP3jl>H0
@P3jl>H00`000000n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V0140n_3V00<0003o0?[`iP3jl>H0
WP3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP0K0?[`iP030000003jl>H0n_3V01D0n_3V0P00
0?lA0?[`iP030<f5?`3jl>H0n_3V0440n_3V00<000000?[`iP3jl>H0@@3jl>H00`3=QCl0n_3V0?[`
iP0@0?[`iP80003oX@3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP0J0?[`iP030000003jl>H0
n_3V01P0n_3V00<0003o0?[`iP3jl>H03`3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0
n_3V0400n_3V00<0cHDo0?[`iP3jl>H0403jl>H00`000?l0n_3V0?[`iP2Q0?[`iP40oooo001/0?[`
iP030000003jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06P3jl>H20000o`l0n_3V00<0cHDo0?[`
iP3jl>H0@03jl>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V00l0n_3V0P000?nT0?[`
iP40oooo001/0?[`iP030000003jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H07@3jl>H00`000?l0
n_3V0?[`iP0=0?[`iP030<f5?`3jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=QCl0
n_3V0?[`iP0>0?[`iP030000o`3jl>H0n_3V0:@0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0
5`3jl>H00`000000n_3V0?[`iP0O0?[`iP80003o3P3jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP030000
003jl>H0n_3V03h0n_3V00<0cHDo0?[`iP3jl>H03@3jl>H20000ojL0n_3V0@3oool006`0n_3V00<0
00000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP0R0?[`iP80003o303jl>H00`3=QCl0n_3V0?[`
iP0n0?[`iP030000003jl>H0n_3V03d0n_3V00<0cHDo0?[`iP3jl>H0303jl>H20000ojT0n_3V0@3o
ool006`0n_3V00<000000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP0T0?[`iP030000o`3jl>H0
n_3V00X0n_3V00<0cHDo0?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP0m0?[`iP030<f5?`3jl>H0
n_3V00X0n_3V0P000?n[0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`
iP3jl>H09P3jl>H20000o`/0n_3V0P3=QClm0?[`iP030000003jl>H0n_3V03/0n_3V0P3=QCl<0?[`
iP030000o`3jl>H0n_3V0:/0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0503jl>H00`000000
n_3V0?[`iP0Y0?[`iP80003o2P3jl>H00`3=QCl0n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V03X0
n_3V00<0cHDo0?[`iP3jl>H02P3jl>H20000ojh0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0
4`3jl>H00`000000n_3V0?[`iP0/0?[`iP030000o`3jl>H0n_3V00P0n_3V00<0cHDo0?[`iP3jl>H0
>P3jl>H00`000000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V00P0n_3V0P000?n`0?[`iP40oooo
001/0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0;P3jl>H20000o`T0n_3V00<0
cHDo0?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP0i0?[`iP030<f5?`3jl>H0n_3V00L0n_3V0P00
0?nb0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H0<@3jl>H2
0000o`P0n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP0h0?[`iP030<f5?`3jl>H0
n_3V00L0n_3V00<0003o0?[`iP3jl>H0/P3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP0A0?[`
iP030000003jl>H0n_3V03<0n_3V00<0003o0?[`iP3jl>H01P3jl>H00`3=QCl0n_3V0?[`iP0g0?[`
iP030000003jl>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H01P3jl>H20000okD0n_3V0@3oool006`0
n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0e0?[`iP80003o1`3jl>H20<f5?cL0
n_3V00<000000?[`iP3jl>H0=@3jl>H20<f5?`L0n_3V0P000?ng0?[`iP40oooo001/0?[`iP030000
003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0>03jl>H20000o`H0n_3V00<0cHDo0?[`iP3jl>H0
=@3jl>H00`000000n_3V0?[`iP0d0?[`iP030<f5?`3jl>H0n_3V00D0n_3V0P000?ni0?[`iP40oooo
001/0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0>`3jl>H00`000?l0n_3V0?[`
iP040?[`iP030<f5?`3jl>H0n_3V03@0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`
iP040?[`iP030000o`3jl>H0n_3V0;T0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H03@3jl>H0
0`000000n_3V0?[`iP0m0?[`iP80003o1@3jl>H20<f5?c@0n_3V00<000000?[`iP3jl>H0<P3jl>H2
0<f5?`D0n_3V0P000?nl0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`
iP3jl>H0@03jl>H20000o`D0n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0a0?[`
iP030<f5?`3jl>H0n_3V00<0n_3V0P000?nn0?[`iP40oooo001/0?[`iP030000003jl>H0n_3V00/0
n_3V00<000000?[`iP3jl>H0@`3jl>H00`000?l0n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V0300
n_3V00<000000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP020?[`iP80003o`03jl>H10?ooo`00
K03jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V04@0n_3V0P000?l40?[`iP030<f5
?`3jl>H0n_3V02l0n_3V00<000000?[`iP3jl>H0;`3jl>H0103=QCl0n_3V0?[`iP3jl>H20000ol80
n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP170?[`iP80003o
0`3jl>H20<f5?bl0n_3V00<000000?[`iP3jl>H0;@3jl>H20<f5?`<0n_3V00<0003o0?[`iP3jl>H0
`P3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V04X0n_3V0P00
0?l30?[`iP030<f5?`3jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0;03jl>H0103=QCl0n_3V0?[`
iP3jl>H20000olD0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`
iP1=0?[`iP80003o0P3jl>H20<f5?b`0n_3V00<000000?[`iP3jl>H0:P3jl>H20<f5?`80n_3V0P00
0?o70?[`iP40oooo001/0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0D03jl>H2
0000o`80n_3V0P3=QClZ0?[`iP030000003jl>H0n_3V02P0n_3V0P3=QCl20?[`iP80003ob@3jl>H1
0?ooo`00K03jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V05<0n_3V0P000?l20?[`
iP030<f5?`3jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V0?[`iP020000
ol/0n_3V0@3oool006`0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP1F0?[`iP80
003o00<0n_3V0<f5?`3=QCl09`3jl>H00`000000n_3V0?[`iP0U0?[`iP80cHDo00<0n_3V0000o`00
0?l0c@3jl>H10?ooo`00K03jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V05P0n_3V
0`000?l20<f5?bD0n_3V00<000000?[`iP3jl>H08`3jl>H20<f5?`030?[`iP000?l0003o0<l0n_3V
0@3oool006`0n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP1L0?[`iP<0003o00<0
cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0Q0?[`iP80cHDo00<0n_3V0000o`000?l0d@3j
l>H10?ooo`00K03jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0600n_3V0P000?l0
0`3=QCl0n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V01l0n_3V0P3=QCl30000om<0n_3V0@3oool0
06`0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP1S0?[`iP<0003o7`3jl>H00`00
0000n_3V0?[`iP0M0?[`iP80cHDo0P000?oF0?[`iP40oooo001/0?[`iP050000003jl>H0n_3V0?[`
iP000000J@3jl>H30000o`030<f5?`3jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06@3jl>H30<f5
?`<0003of03jl>H10?ooo`00K03jl>H010000000n_3V0?[`iP00001]0?[`iP<0003o6@3jl>H00`00
0000n_3V0?[`iP0G0?[`iP030<f5?`000?l0003o0080003of`3jl>H10?ooo`00K03jl>H010000000
n_3V0?[`iP00001`0?[`iP@0003o5@3jl>H00`000000n_3V0?[`iP0C0?[`iP030<f5?`000?l0003o
0080003og`3jl>H10?ooo`00J`3jl>H4000007D0n_3V10000?lA0?[`iP030000003jl>H0n_3V00l0
n_3V00<0cHDo0000o`000?l00P000?oS0?[`iP40oooo001Z0?[`iPD00000N@3jl>H40000o`d0n_3V
00<000000?[`iP3jl>H02`3jl>H50000onL0n_3V0@3oool006X0cHDo1@00001m0<f5?`d0003o00<0
00000000o`000?l02`000?o[0<f5?`40n_3V0@3oool006X0n_3V1@00003o0?[`iXD0n_3V0@3oool0
06/0n_3V0`00003o0?[`iXH0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00]P3jl>H20000000306IRGP3<a;/0n_3V02/0n_3V00H0e<c306IRGP000000000008V4OP3T
fm9U0?[`iP060=C<``1VHUh0000000000029Q7h0i=_BW03jl>H10?ooo`00^03jl>H00`1VHUh00000
0=cDb`0[0?[`iP0604a9A@33^k<0n_3V0>cRf@000000RHAnI@3jl>H01P1<BDD0`k^c0?[`iP3/h]T0
000008V4OY`0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V00@0[jRQ
04a9A@000000RHAn1`3jl>H01P3Le</0NGE`000000000000RHAn0<c4^`80n_3V00@0[jRQ04a9A@00
0000RHAn0P3jl>H200000080n_3V0P0000001@3jl>H0c<Bk0000001iMG00n_3V008000000P3jl>H2
0000000306IRGP3jl>H0n_3V00L0n_3V0P0000030?[`iP040<c4^`1<BDD0IV9N0>CKdP80000000<0
n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V
0P0000020?[`iP0308V4OP1VHUh0c<Bk008000001`3jl>H01@3Le</0NGE`0000001<BDD0Y9fF0080
n_3V00@0c<Bk04a9A@1VHUh0i=_B0P0000000`3jl>H00000000000040?[`iP030:BMUP000000Y9fF
00<0n_3V00@0[jRQ04a9A@000000RHAn1`3jl>H0102_Z:40C4U504a9A@2_Z:420?[`iP8000001P3j
l>H2000000050?[`iP33^k<000000<>k/`3jl>H00P0000001@3jl>H0c<Bk04a9A@1<BDD0[jRQ0080
000000<0n_3V0000000000000`3jl>H2000000050?[`iP3<a;/0C4U504a9A@2_Z:400P0000040?[`
iP80000000<0k>;I0?[`iP3/h]T00P0000020?[`iP0308V4OP1VHUh0c<Bk0080000000<0n_3V0000
000000000P3jl>H200000080n_3V00@0[jRQ04a9A@000000RHAn0P3jl>H01`3/h]T0Ui6;00000000
0000NGE`0>CKdP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P00
00001`3jl>H0[jRQ00000033^k<0i=_B00000029Q7h01@3jl>H01@3Tfm80000009NAR`3jl>H0^K:Z
0080000000P0n_3V0:nXX@000000`k^c0>CKdP000000RHAn0?[`iP8000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H0c<Bk00000002000000030>CKdP3jl>H0n_3V00H0n_3V
0P0000030?[`iP0406IRGP000000i=_B0;VbZP80000000<0n_3V0000000000000`3jl>H200000080
n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P0000001@3jl>H0Y9fF00000033^k<0
Y9fF008000001P3jl>H0303Tfm80000009NAR`3jl>H0e<c300000029Q7h0n_3V06IRGP000000i=_B
0;VbZP80000000<0n_3V000000000000103jl>H3000000080>cRf@3jl>H0[jRQ00000033^k<0i=_B
00000029Q7h50?[`iP070;VbZP000000`k^c0<>k/`000000^K:Z0?[`iP02000000H0n_3V0P000000
1@3jl>H0Ui6;0000002GTH/0n_3V0080000000D0n_3V04a9A@000000i=_B0<>k/`02000000030?[`
iP000000000000<0n_3V0P0000001@3jl>H0C4U50000003Tfm80`k^c00800000103jl>H03029Q7h0
00000=C<``3jl>H0e<c300000029Q7h0n_3V0:BMUP000000`k^c0:BMUP80000000<0n_3V00000000
00000P3jl>H20000000?0?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP3jl>H0NGE`0000003Tfm80
k>;I0000001VHUh0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80
000000<0n_3V04a9A@0000002@3jl>H00`2GTH/000000=cDb`020?[`iP80000000<0n_3V04a9A@00
00001@3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000H0n_3V09NAR`00
0000RHAn0000002_Z:480?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0000000000003
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000030?[`iP1<
BDD000000080n_3V0P0000060?[`iP0309NAR`000000i=_B00D0n_3V0P0000020?[`iP80000000<0
n_3V0000000000000`3jl>H0202i/ZX0000008V4OP000000^K:Z0?[`iP1<BDD000002@3jl>H01`1V
HUh000000?[`iP3jl>H0000006IRGP3jl>H00P0000060?[`iP80000000D0n_3V04a9A@000000C4U5
0?[`iP02000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000030?[`iP800000
00<0n_3V0000000000000P3jl>H2000000@0n_3V00<0[jRQ0000000000000`000000102_Z:40n_3V
04a9A@0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP1<BDD0000000L0
n_3V00D0e<c30:BMUP000000C4U50?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP80
00000P3jl>H2000000030?[`iP000000000000@000001@3jl>H00`1<BDD000000?[`iP020?[`iP80
000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
00000P3jl>H2000000060?[`iP1<BDD000000>cRf@000000IV9N203jl>H2000000<0n_3V0P000002
0?[`iP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003j
l>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP8000001P3jl>H2000000H0n_3V0P00
00020?[`iP80000000<0n_3V0000000000000`3jl>H204a9A@040>cRf@1<BDD0C4U50?[`iPH00000
1@3jl>H200000080n_3V0P0000000`3jl>H00000000000060?[`iP80000000D0i=_B0000002GTH/0
00000>CKdP02000000050?[`iP3<a;/0000009NAR`3Tfm800P0000000`3jl>H00000000000030?[`
iP80000000D0n_3V0<c4^`000000Ui6;0>CKdP02000000@0n_3V00P0e<c300000029Q7h0n_3V09NA
R`000000e<c30?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
000000000004000000030?[`iP3<a;/0C4U50080000000<0C4U50<c4^`3jl>H00P0000240?[`iP40
oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP030000
001VHUh0n_3V00@0n_3V0P0000020?[`iP<0000000<0n_3V04a9A@0000000P3jl>H00`000000IV9N
0?[`iP0200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000L0g=C;00000029Q7h0
n_3V08V4OP000000i=_B00L0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP0000000000
00<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V
04a9A@0000000P3jl>H2000000H0n_3V0P0000060?[`iP8000000P3jl>H2000000030?[`iP000000
00000080n_3V00T0c<Bk0000002TWIH0n_3V0:BMUP000000c<Bk04a9A@0000000P3jl>H00`000000
IV9N0?[`iP040?[`iP0706IRGP000000n_3V0?[`iP000000IV9N0?[`iP02000000H0n_3V0P000000
1@3<a;/000000=cDb`000000c<Bk008000000P3jl>H00`3Le</0[jRQ07UeL002000000030?[`iP00
0000000000<0n_3V0P0000020?[`iP030=cDb`2_Z:40NGE`008000001@3jl>H01@000000C4U50?[`
iP1<BDD000000080n_3V00@0C4U50000003jl>H0n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V04a9A@0000000P3jl>H01`000000IV9N0?[`iP1<BDD0000007UeL03<a;/00`3jl>H2
000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP80000000/0Y9fF0>CKdP000000IV9N0?[`iP2i
/ZX000000<>k/`3<a;/000000;VbZP050?[`iP0304a9A@000000n_3V00D0n_3V00L0^K:Z00000033
^k<0c<Bk0000002i/ZX0n_3V0080000000D0^K:Z0>CKdP000000C4U50?[`iP0200000080n_3V0P00
00001`2_Z:4000000<>k/`3jl>H0`k^c0000002_Z:401`3jl>H2000000<0n_3V0P0000020?[`iP80
000000@0n_3V000000000000e<c30P3jl>H2000000050;VbZP3Tfm80000004a9A@3jl>H00P000000
303jl>H000000000002i/ZX0i=_B0000001<BDD0n_3V0:BMUP000000`k^c0:BMUP8000001P3jl>H0
0`1<BDD000000?[`iP050?[`iP8000000P3jl>H20000000B0?[`iP00000000000=C<``3jl>H0IV9N
0000003/h]T0n_3V0>cRf@000000IV9N0;VbZP000000`k^c0<c4^`000000^K:Z1@3jl>H01`2i/ZX0
00000<>k/`33^k<000000;VbZP3jl>H00P0000060?[`iP80000000D0Y9fF06IRGP3jl>H0IV9N0:BM
UP02000000080?[`iP1iMG00e<c30?[`iP3Tfm80000004a9A@3jl>H2000000030=C<``3jl>H0n_3V
0080000000L0n_3V07UeL03Dc<<0n_3V0>CKdP000000C4U500D0n_3V00D0NGE`0000003<a;/00000
06IRGP020?[`iP040:BMUP000000`k^c0:BMUP80000001H0n_3V000000000000^K:Z0>CKdP000000
C4U50?[`iP2i/ZX000000<>k/`3<a;/000000;VbZP3jl>H0IV9N0000003jl>H0i=_B0000001iMG00
n_3V0P0000240?[`iP40oooo00230?[`iP8000000`3jl>H2000000040=cDb`29Q7h0C4U50<c4^`80
n_3V00@0[jRQ000000000000[jRQ1P3jl>H00`2GTH/000000>CKdP060?[`iP040:nXX@0000000000
0:nXX@80n_3V0P000000103<a;/0NGE`04a9A@3<a;/40000000:0?[`iP000000000006IRGP000000
k>;I0?[`iP3/h]T0000006IRGPL0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP000000
000008V4OP1iMG00n_3V0P0000001@3<a;/0NGE`04a9A@3<a;/0n_3V0080000000L0n_3V00000000
0000c<Bk07UeL01<BDD0c<Bk0080n_3V00<0RHAn06IRGP3<a;/00P0000060?[`iP0309NAR`000000
i=_B00D0n_3V0P0000020?[`iP80000000@0n_3V000000000000RHAn0P0000002029Q7h0n_3V0?[`
iP3jl>H0RHAn0000003Le</0[jRQ0P0000000`2_Z:40n_3V0?[`iP050?[`iP050:nXX@1<BDD00000
0:nXX@3jl>H0100000050?[`iP80000000D0IV9N0:BMUP3jl>H0Ui6;06IRGP02000000030?[`iP3T
fm80RHAn0080000000<0IV9N0=C<``3jl>H00P0000000`29Q7h0NGE`0?[`iP02000000030?[`iP3T
fm80RHAn0080000000<0IV9N0=C<``3jl>H0103jl>H01@2TWIH0000008V4OP000000Y9fF00<0n_3V
00<0RHAn06IRGP3<a;/00P0000001`3jl>H000000000003<a;/0NGE`04a9A@3<a;/00P3jl>H0102_
Z:4000000000002_Z:420?[`iP070>CKdP1iMG00000000000029Q7h0i=_B0?[`iP02000008@0n_3V
0@3oool008<0n_3V0P0000030?[`iP800000403jl>H01`3Tfm80000009NAR`3jl>H0e<c30000001i
MG003`3jl>H200000080n_3V0P00000>0?[`iP800000;03jl>H01`3Tfm80000009NAR`3jl>H0e<c3
00000029Q7h09@3jl>H2000000H0n_3V0`0000000`3<a;/0n_3V0<>k/`03000001/0n_3V00D0c<Bk
00000000000000000<>k/`2T0?[`iP40oooo00210?[`iPH0000000<0n_3V0000000000004@3jl>H0
1P3Le</0NGE`000000000000Ui6;0>cRf@l0n_3V00@0g=C;08V4OP3jl>H0n_3V0P00000<0?[`iPH0
0000503jl>H2000001D0n_3V00D0g=C;07UeL000000000000:BMUP0V0?[`iP040<c4^`1VHUh00000
08V4OP@0n_3V0`0000000`3/h]T0n_3V0=cDb`03000000d0n_3V0P00000<0?[`iP050>cRf@000000
00000000003Tfm807P3jl>H2000008@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.26087 .38333 L
s
.26087 .05 m
.26087 .38333 L
s
.34212 .27007 m
.26087 .27007 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.26087 .38333 Mdot
.34212 .27007 Mdot
.26087 .27007 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00880n_3V00<000000?[`iP3jl>H0J03jl>H:0<f5
?`030?[`iP00000000000080n_3V2P3=QCo]0?[`iP40oooo00220?[`iP030000003jl>H0n_3V0680
n_3V1P3=QCl;0?[`iP800000303jl>H70<f5?nH0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0
H03jl>H20<f5?a00n_3V00<000000?[`iP0000004`3jl>H20<f5?n@0n_3V0@3oool00880n_3V00<0
00000?[`iP3jl>H0G03jl>H40<f5?a40n_3V00@000000?[`iP3jl>H000005@3jl>H30<f5?n40n_3V
0@3oool00880n_3V00<000000?[`iP3jl>H0F03jl>H40<f5?a@0n_3V00D000000?[`iP3jl>H0n_3V
0000000H0?[`iP@0cHDog@3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP1F0?[`iP80cHDo603j
l>H01@000000n_3V0?[`iP3jl>H0000001`0n_3V0P3=QCoK0?[`iP40oooo00220?[`iP030000003j
l>H0n_3V05@0n_3V0P3=QClI0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0703j
l>H20<f5?mT0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0DP3jl>H20<f5?aX0n_3V00<00000
0?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0N0?[`iP80cHDoe`3jl>H10?ooo`00PP3jl>H00`00
0000n_3V0?[`iP1@0?[`iP80cHDo703jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V
0200n_3V0P3=QCoE0?[`iP40oooo00220?[`iP030000003jl>H0n_3V04h0n_3V0P3=QClM0?[`iP03
0000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H08P3jl>H20<f5?m<0n_3V0@3oool00880n_3V
00<000000?[`iP3jl>H0C03jl>H20<f5?ah0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V
0?[`iP0T0?[`iP80cHDod@3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP1:0?[`iP80cHDo7`3j
l>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V02H0n_3V0P3=QCo?0?[`iP40oooo0022
0?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3jl>H07`3jl>H00`000000n_3V0?[`iP06
0?[`iP030000003jl>H0n_3V02P0n_3V00<0cHDo0?[`iP3jl>H0c03jl>H10?ooo`00PP3jl>H00`00
0000n_3V0?[`iP170?[`iP80cHDo8@3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V
02T0n_3V0P3=QCo<0?[`iP40oooo00220?[`iP030000003jl>H0n_3V04D0n_3V0P3=QClR0?[`iP03
0000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0:`3jl>H20<f5?lX0n_3V0@3oool00880n_3V
00<000000?[`iP3jl>H0A03jl>H00`3=QCl0n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V00P0n_3V
00<000000?[`iP3jl>H0;@3jl>H00`3=QCl0n_3V0?[`iP370?[`iP40oooo00220?[`iP030000003j
l>H0n_3V0480n_3V0P3=QClT0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0;P3j
l>H20<f5?lL0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0@@3jl>H00`3=QCl0n_3V0?[`iP0S
0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP34
0?[`iP40oooo00220?[`iP030000003jl>H0n_3V0400n_3V00<0cHDo0?[`iP3jl>H08`3jl>H00`00
0000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V0340n_3V00<0cHDo0?[`iP3jl>H0``3jl>H10?oo
o`00PP3jl>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V02@0n_3V00<000000?[`iP3j
l>H02`3jl>H00`000000n_3V0?[`iP0b0?[`iP030<f5?`3jl>H0n_3V0<80n_3V0@3oool00880n_3V
00<000000?[`iP3jl>H0?@3jl>H20<f5?bH0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V
0?[`iP0c0?[`iP80cHDo`P3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP0l0?[`iP030<f5?`3j
l>H0n_3V02D0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0d0?[`iP030<f5?`3j
l>H0n_3V0<00n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0>`3jl>H00`3=QCl0n_3V0?[`iP0V
0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H0=@3jl>H00`3=QCl0n_3V0?[`iP2o
0?[`iP40oooo00220?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H09P3jl>H00`00
0000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V03H0n_3V0P3=QCno0?[`iP40oooo00220?[`iP03
0000003jl>H0n_3V03T0n_3V00<0cHDo0?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP0?0?[`iP03
0000003jl>H0n_3V03P0n_3V00<0cHDo0?[`iP3jl>H0_03jl>H10?ooo`00PP3jl>H00`000000n_3V
0?[`iP0h0?[`iP030<f5?`3jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V
0?[`iP0i0?[`iP030<f5?`3jl>H0n_3V0;/0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0=`3j
l>H00`3=QCl0n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0>P3j
l>H00`3=QCl0n_3V0?[`iP2j0?[`iP40oooo00220?[`iP030000003jl>H0n_3V03H0n_3V00<0cHDo
0?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo
0?[`iP3jl>H0^P3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP0e0?[`iP030<f5?`3jl>H0n_3V
02L0n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0k0?[`iP030<f5?`3jl>H0n_3V
0;T0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP03
0000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0?03jl>H20<f5?kT0n_3V0@3oool00880n_3V
00<000000?[`iP3jl>H0<`3jl>H00`3=QCl0n_3V0?[`iP0X0?[`iP030000003jl>H0n_3V01<0n_3V
00<000000?[`iP3jl>H0?@3jl>H00`3=QCl0n_3V0?[`iP2g0?[`iP40oooo00220?[`iP030000003j
l>H0n_3V03<0n_3V00<0cHDo0?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003j
l>H0n_3V03h0n_3V00<0cHDo0?[`iP3jl>H0]P3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP0b
0?[`iP030<f5?`3jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0o
0?[`iP030<f5?`3jl>H0n_3V0;D0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0<@3jl>H00`3=
QCl0n_3V0?[`iP0X0?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=
QCl0n_3V0?[`iP2e0?[`iP40oooo00220?[`iP030000003jl>H0n_3V0340n_3V00<0cHDo0?[`iP3j
l>H09`3jl>H00`000000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V0400n_3V00<0cHDo0?[`iP3j
l>H0]03jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP0`0?[`iP030<f5?`3jl>H0n_3V02L0n_3V
00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP110?[`iP030<f5?`3jl>H0n_3V0;<0n_3V
0@3oool00880n_3V00<000000?[`iP3jl>H0;`3jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP030000003j
l>H0n_3V01P0n_3V00<000000?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP2b0?[`iP40oooo0022
0?[`iP030000003jl>H0n_3V02h0n_3V00<0cHDo0?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP0H
0?[`iP030000003jl>H0n_3V04<0n_3V00<0cHDo0?[`iP3jl>H0/@3jl>H10?ooo`00PP3jl>H00`00
0000n_3V0?[`iP0]0?[`iP030<f5?`3jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H06@3jl>H00`00
0000n_3V0?[`iP130?[`iP030<f5?`3jl>H0n_3V0;40n_3V0@3oool00880n_3V00<000000?[`iP3j
l>H0;@3jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V01X0n_3V00<000000?[`iP3j
l>H0A03jl>H00`3=QCl0n_3V0?[`iP2`0?[`iP40oooo00220?[`iP030000003jl>H0n_3V02`0n_3V
00<0cHDo0?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V04@0n_3V
00<0cHDo0?[`iP3jl>H0/03jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP0/0?[`iP030<f5?`3j
l>H0n_3V02L0n_3V00<000000?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP150?[`iP030<f5?`3j
l>H0n_3V0:l0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0:`3jl>H00`3=QCl0n_3V0?[`iP0W
0?[`iP030000003jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP2_
0?[`iP40oooo00220?[`iP030000003jl>H0n_3V02/0n_3V00<0cHDo0?[`iP3jl>H09P3jl>H00`00
0000n_3V0?[`iP0M0?[`iP030000003jl>H0n_3V04H0n_3V00<0cHDo0?[`iP3jl>H0[P3jl>H10?oo
o`00PP3jl>H00`000000n_3V0?[`iP0Z0?[`iP030<f5?`3jl>H0n_3V02L0n_3V00<000000?[`iP3j
l>H07@3jl>H00`000000n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool00880n_3V
00<000000?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V01h0n_3V
00<000000?[`iP3jl>H0A`3jl>H00`3=QCl0n_3V0?[`iP2]0?[`iP40oooo00220?[`iP030000003j
l>H0n_3V02T0n_3V00<0cHDo0?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP0O0?[`iP030000003j
l>H0n_3V04P0n_3V00<0cHDo0?[`iP3jl>H0[03jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP0X
0?[`iP030<f5?`3jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H07`3jl>H00`000000n_3V0?[`iP18
0?[`iP030<f5?`3jl>H0n_3V0:`0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0:03jl>H00`3=
QCl0n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0B@3jl>H00`3=
QCl0n_3V0?[`iP2[0?[`iP40oooo00220?[`iP030000003jl>H0n_3V02L0n_3V00<0cHDo0?[`iP3j
l>H09P3jl>H00`000000n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3j
l>H0Z`3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP0W0?[`iP030<f5?`3jl>H0n_3V02D0n_3V
00<000000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:X0n_3V
0@3oool00080003oP03jl>H00`000000n_3V0?[`iP0W0?[`iP030<f5?`3jl>H0n_3V02D0n_3V00<0
00000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:L0n_3V0P00
0?l10?[`iP40oooo00020?[`iP<0003oO@3jl>H00`000000n_3V0?[`iP0W0?[`iP030<f5?`3jl>H0
n_3V02@0n_3V00<000000?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0
n_3V0:@0n_3V0`000?l30?[`iP40oooo00050?[`iP@0003oN@3jl>H00`000000n_3V0?[`iP0V0?[`
iP030<f5?`3jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP1:0?[`
iP030<f5?`3jl>H0n_3V0:00n_3V10000?l60?[`iP40oooo00090?[`iP<0003oMP3jl>H00`000000
n_3V0?[`iP0V0?[`iP030<f5?`3jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0903jl>H00`000000
n_3V0?[`iP1;0?[`iP030<f5?`3jl>H0n_3V09`0n_3V0`000?l:0?[`iP40oooo000<0?[`iP<0003o
L`3jl>H00`000000n_3V0?[`iP0U0?[`iP030<f5?`3jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0
9@3jl>H00`000000n_3V0?[`iP1;0?[`iP030<f5?`3jl>H0n_3V09T0n_3V0`000?l=0?[`iP40oooo
000?0?[`iP@0003oK`3jl>H00`000000n_3V0?[`iP0U0?[`iP030<f5?`3jl>H0n_3V02<0n_3V00<0
00000?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V09@0n_3V1000
0?l@0?[`iP40oooo000C0?[`iP<0003oK03jl>H00`000000n_3V0?[`iP0U0?[`iP030<f5?`3jl>H0
n_3V0280n_3V00<000000?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0
n_3V0940n_3V0`000?lD0?[`iP40oooo000F0?[`iP<0003oJ@3jl>H00`000000n_3V0?[`iP0U0?[`
iP030<f5?`3jl>H0n_3V0280n_3V00<000000?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP1<0?[`
iP030<f5?`3jl>H0n_3V08h0n_3V0`000?lG0?[`iP40oooo000I0?[`iP<0003oIP3jl>H00`000000
n_3V0?[`iP0T0?[`iP030<f5?`3jl>H0n_3V0280n_3V00<000000?[`iP3jl>H0:03jl>H00`000000
n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V08/0n_3V0`000?lJ0?[`iP40oooo000L0?[`iP<0003o
H`3jl>H00`000000n_3V0?[`iP0T0?[`iP030<f5?`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0
:@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V08L0n_3V0`000?lM0?[`iP40oooo
000O0?[`iP@0003oG`3jl>H00`000000n_3V0?[`iP0T0?[`iP030<f5?`3jl>H0n_3V0240n_3V00<0
00000?[`iP3jl>H0:@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V08@0n_3V0`00
0?lP0?[`iP40oooo000S0?[`iP<0003oG03jl>H00`000000n_3V0?[`iP0T0?[`iP030<f5?`3jl>H0
n_3V0200n_3V00<000000?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0
n_3V0840n_3V0`000?lS0?[`iP40oooo000V0?[`iP<0003oF@3jl>H00`000000n_3V0?[`iP0S0?[`
iP030<f5?`3jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP1=0?[`
iP030<f5?`3jl>H0n_3V07h0n_3V0`000?lV0?[`iP40oooo000Y0?[`iP<0003oEP3jl>H00`000000
n_3V0?[`iP0S0?[`iP030<f5?`3jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0;03jl>H00`000000
n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V07X0n_3V0`000?lY0?[`iP40oooo000/0?[`iP80003o
E03jl>H00`000000n_3V0?[`iP0S0?[`iP030<f5?`3jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0
;03jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V07P0n_3V0P000?l/0?[`iP40oooo
000^0?[`iP80003oDP3jl>H00`000000n_3V0?[`iP0S0?[`iP030<f5?`3jl>H0n_3V01h0n_3V00<0
00000?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V07H0n_3V0P00
0?l^0?[`iP40oooo000`0?[`iP<0003oC`3jl>H00`000000n_3V0?[`iP0R0?[`iP030<f5?`3jl>H0
n_3V01h0n_3V00<000000?[`iP3jl>H0;P3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0
n_3V07<0n_3V0`000?l`0?[`iP40oooo000c0?[`iP80003oC@3jl>H00`000000n_3V0?[`iP0R0?[`
iP030<f5?`3jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0;P3jl>H00`000000n_3V0?[`iP1?0?[`
iP030<f5?`3jl>H0n_3V0700n_3V0P000?lc0?[`iP40oooo000e0?[`iP80003oB`3jl>H00`000000
n_3V0?[`iP0R0?[`iP030<f5?`3jl>H0n_3V01d0n_3V00<000000?[`iP3jl>H0;`3jl>H00`000000
n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06h0n_3V0P000?le0?[`iP40oooo000g0?[`iP<0003o
B03jl>H00`000000n_3V0?[`iP0R0?[`iP030<f5?`3jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H0
<03jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06/0n_3V0`000?lg0?[`iP40oooo
000j0?[`iP80003oAP3jl>H00`000000n_3V0?[`iP0R0?[`iP030<f5?`3jl>H0n_3V01/0n_3V00<0
00000?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06T0n_3V0P00
0?lj0?[`iP40oooo000l0?[`iP80003oA03jl>H00`000000n_3V0?[`iP0R0?[`iP030<f5?`3jl>H0
n_3V01/0n_3V00<000000?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0
n_3V06L0n_3V0P000?ll0?[`iP40oooo000n0?[`iP<0003o@@3jl>H00`000000n_3V0?[`iP0Q0?[`
iP030<f5?`3jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP1?0?[`
iP030<f5?`3jl>H0n_3V06@0n_3V0`000?ln0?[`iP40oooo00110?[`iP80003o?`3jl>H00`000000
n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H0<`3jl>H00`000000
n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V0640n_3V0P000?m10?[`iP40oooo00130?[`iP80003o
?@3jl>H00`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H0
<`3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05l0n_3V0P000?m30?[`iP40oooo
00150?[`iP80003o>`3jl>H00`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V01T0n_3V00<0
00000?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05d0n_3V0P00
0?m50?[`iP40oooo00170?[`iP80003o>@3jl>H00`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0
n_3V01P0n_3V00<000000?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0
n_3V05/0n_3V0P000?m70?[`iP40oooo00190?[`iP<0003o=P3jl>H00`000000n_3V0?[`iP0Q0?[`
iP030<f5?`3jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP1@0?[`
iP030<f5?`3jl>H0n_3V05T0n_3V0P000?m90?[`iP40oooo001<0?[`iP80003o=03jl>H00`000000
n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H0=P3jl>H00`000000
n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05L0n_3V0P000?m;0?[`iP40oooo001>0?[`iP80003o
<P3jl>H00`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H0
=P3jl>H300000540n_3V00<0cHDo0?[`iP3jl>H0E@3jl>H20000odd0n_3V0@3oool00500n_3V0P00
0?l`0?[`iP030000003jl>H0n_3V0240n_3V00<0cHDo0?[`iP3jl>H05@3jl>H00`000000n_3V0?[`
iP0f0?[`iPD00000D03jl>H00`3=QCl0n_3V0?[`iP1C0?[`iP80003oC`3jl>H10?ooo`00DP3jl>H2
0000obh0n_3V00<000000?[`iP3jl>H08@3jl>H00`3=QCl0n_3V0?[`iP0D0?[`iP030000003jl>H0
n_3V03L0n_3V1@00001@0?[`iP030<f5?`3jl>H0n_3V0540n_3V0P000?mA0?[`iP40oooo001D0?[`
iP80003o;03jl>H00`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V01@0n_3V00<000000?[`
iP3jl>H0=`3jl>H500000500n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H20000oe<0n_3V0@3oool005H0
n_3V0P000?lZ0?[`iP030000003jl>H0n_3V0240n_3V00<0cHDo0?[`iP3jl>H04`3jl>H00`000000
n_3V0?[`iP0i0?[`iP<00000D@3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP80003oE@3jl>H10?ooo`00
F03jl>H20000obP0n_3V00<000000?[`iP3jl>H08@3jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP030000
003jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP80003o
E`3jl>H10?ooo`00FP3jl>H00`000?l0n_3V0?[`iP0U0?[`iP030000003jl>H0n_3V0240n_3V00<0
cHDo0?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V0500n_3V00<0
cHDo0?[`iP3jl>H0B@3jl>H20000oeT0n_3V0@3oool005/0n_3V0P000?lU0?[`iP030000003jl>H0
n_3V0240n_3V00<0cHDo0?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0l0?[`iP030000003jl>H0
n_3V0500n_3V00<0cHDo0?[`iP3jl>H0A`3jl>H20000oe/0n_3V0@3oool005d0n_3V0P000?lS0?[`
iP030000003jl>H0n_3V0240n_3V00<0cHDo0?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0m0?[`
iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H20000oed0n_3V0@3oool005l0
n_3V0P000?lQ0?[`iP030000003jl>H0n_3V0240n_3V00<0cHDo0?[`iP3jl>H03`3jl>H00`000000
n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H20000oel0
n_3V0@3oool00640n_3V00<0003o0?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP0Q0?[`iP030<f5
?`3jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5
?`3jl>H0n_3V0440n_3V0P000?mQ0?[`iP40oooo001R0?[`iP80003o7P3jl>H00`000000n_3V0?[`
iP0Q0?[`iP030<f5?`3jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0?`3jl>H00`000000n_3V0?[`
iP1@0?[`iP030<f5?`3jl>H0n_3V03l0n_3V0P000?mS0?[`iP40oooo001T0?[`iP80003o703jl>H0
0`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H0@03jl>H0
0`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V03h0n_3V0P000?mU0?[`iP40oooo001V0?[`
iP80003o6P3jl>H00`000000n_3V0?[`iP0R0?[`iP030<f5?`3jl>H0n_3V00`0n_3V00<000000?[`
iP3jl>H0@03jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V03`0n_3V0P000?mW0?[`
iP40oooo001X0?[`iP030000o`3jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H08P3jl>H00`3=QCl0
n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V0440n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0
n_3V0?[`iP0k0?[`iP030000o`3jl>H0n_3V06L0n_3V0@3oool006T0n_3V0P000?lG0?[`iP030000
003jl>H0n_3V0280n_3V00<0cHDo0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP120?[`iP030000
003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0>@3jl>H20000ofX0n_3V0@3oool006/0n_3V0P00
0?lE0?[`iP030000003jl>H0n_3V0280n_3V00<0cHDo0?[`iP3jl>H02@3jl>H00`000000n_3V0?[`
iP130?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000?l0n_3V0?[`
iP1Z0?[`iP40oooo001]0?[`iP030000o`3jl>H0n_3V0180n_3V00<000000?[`iP3jl>H08P3jl>H0
0`3=QCl0n_3V0?[`iP090?[`iP030000003jl>H0n_3V04<0n_3V00<000000?[`iP3jl>H0C`3jl>H0
0`3=QCl0n_3V0?[`iP0f0?[`iP80003oK@3jl>H10?ooo`00KP3jl>H20000oa80n_3V00<000000?[`
iP3jl>H08P3jl>H00`3=QCl0n_3V0?[`iP080?[`iP030000003jl>H0n_3V04@0n_3V00<000000?[`
iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0e0?[`iP80003oK`3jl>H10?ooo`00L03jl>H20000oa00
n_3V00<000000?[`iP3jl>H08`3jl>H00`3=QCl0n_3V0?[`iP060?[`iP030000003jl>H0n_3V04D0
n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000o`3jl>H0n_3V06l0
n_3V0@3oool00780n_3V00<0003o0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0S0?[`iP030<f5
?`3jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5
?`3jl>H0n_3V0380n_3V0P000?mb0?[`iP40oooo001c0?[`iP80003o3@3jl>H00`000000n_3V0?[`
iP0S0?[`iP030<f5?`3jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`
iP1>0?[`iP030<f5?`3jl>H0n_3V0340n_3V00<0003o0?[`iP3jl>H0LP3jl>H10?ooo`00M@3jl>H2
0000o`/0n_3V00<000000?[`iP3jl>H08`3jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000003jl>H0
n_3V04L0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP80003oM@3jl>H1
0?ooo`00M`3jl>H00`000?l0n_3V0?[`iP080?[`iP030000003jl>H0n_3V02@0n_3V00<0cHDo0?[`
iP3jl>H00P3jl>H00`000000n_3V0?[`iP180?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`
iP3jl>H0;P3jl>H20000ogL0n_3V0@3oool007P0n_3V0P000?l80?[`iP030000003jl>H0n_3V02@0
n_3V00<0cHDo0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP180?[`iP030000003jl>H0n_3V04d0
n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`000?l0n_3V0?[`iP1g0?[`iP40oooo001j0?[`iP80003o
1P3jl>H00`000000n_3V0?[`iP0T0?[`iP050<f5?`3jl>H0n_3V0?[`iP000000B`3jl>H00`000000
n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V02/0n_3V0P000?mj0?[`iP40oooo001l0?[`iP030000
o`3jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0903jl>H0103=QCl0n_3V0?[`iP00001<0?[`iP03
0000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`000?l0n_3V0?[`iP1j0?[`iP40
oooo001m0?[`iP80003o0P3jl>H3000002D0n_3V1000001<0?[`iP030000003jl>H0n_3V04`0n_3V
00<0cHDo0?[`iP3jl>H0:@3jl>H20000ogd0n_3V0@3oool007l0n_3V00<0003o0000000000000`00
000S0?[`iPD00000C03jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02L0n_3V0P00
0?mo0?[`iP40oooo00200?[`iRd00000C03jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0
n_3V02H0n_3V00<0003o0?[`iP3jl>H0O`3jl>H10?ooo`00P03jl>H5000002<0n_3V1@00001<0?[`
iP030000003jl>H0n_3V04/0n_3V00<0cHDo0?[`iP3jl>H09@3jl>H20000oh80n_3V0@3oool00840
n_3V0`0000020000ob<0n_3V0`00001=0?[`iP030000003jl>H0n_3V04/0n_3V00<0cHDo0?[`iP3j
l>H0903jl>H00`000?l0n_3V0?[`iP220?[`iP40oooo00220?[`iP050000003jl>H0n_3V0?[`iP00
0?l08@3jl>H010000000n_3V0?[`iP3=QCm=0?[`iP030000003jl>H0n_3V04X0n_3V00<0cHDo0?[`
iP3jl>H08`3jl>H20000ohD0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H00P3jl>H20000oah0
n_3V00<000000?[`iP3jl>H00P3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V04X0
n_3V00<0cHDo0?[`iP3jl>H08@3jl>H20000ohL0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0
103jl>H20000oa`0n_3V00<000000?[`iP3jl>H00P3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000
003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H0803jl>H00`000?l0n_3V0?[`iP270?[`iP40oooo
00220?[`iP030000003jl>H0n_3V00H0n_3V0P000?lI0?[`iP030000003jl>H0n_3V00<0n_3V00<0
cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V01h0n_3V0P00
0?n:0?[`iP40oooo00220?[`iP030000003jl>H0n_3V00P0n_3V00<0003o0?[`iP3jl>H05@3jl>H0
0`000000n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0B@3jl>H0
0`3=QCl0n_3V0?[`iP0N0?[`iP030000o`3jl>H0n_3V08X0n_3V0@3oool00880n_3V00<000000?[`
iP3jl>H02@3jl>H20000oa@0n_3V00<000000?[`iP3jl>H01P3jl>H00`3=QCl0n_3V0?[`iP190?[`
iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3jl>H0703jl>H20000ohd0n_3V0@3oool00880
n_3V00<000000?[`iP3jl>H02`3jl>H20000oa80n_3V00<000000?[`iP3jl>H01`3jl>H00`3=QCl0
n_3V0?[`iP180?[`iP030000003jl>H0n_3V04P0n_3V00<0cHDo0?[`iP3jl>H06`3jl>H20000ohl0
n_3V0@3oool00880n_3V00<000000?[`iP3jl>H03@3jl>H00`000?l0n_3V0?[`iP0>0?[`iP030000
003jl>H0n_3V00P0n_3V00<0cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP170?[`iP030<f5
?`3jl>H0n_3V01/0n_3V00<0003o0?[`iP3jl>H0S`3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`
iP0>0?[`iP80003o3@3jl>H00`000000n_3V0?[`iP0:0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<0
00000?[`iP3jl>H0A`3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP80003oTP3jl>H10?ooo`00PP3jl>H0
0`000000n_3V0?[`iP0@0?[`iP030000o`3jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H0
0`3=QCl0n_3V0?[`iP170?[`iP030000003jl>H0n_3V04H0n_3V00<0cHDo0?[`iP3jl>H06@3jl>H0
0`000?l0n_3V0?[`iP2B0?[`iP40oooo00220?[`iP030000003jl>H0n_3V0140n_3V0P000?l90?[`
iP030000003jl>H0n_3V00`0n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP160?[`
iP030<f5?`3jl>H0n_3V01L0n_3V0P000?nE0?[`iP40oooo00220?[`iP030000003jl>H0n_3V01<0
n_3V00<0003o0?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0=0?[`iP030<f5?`3jl>H0n_3V04H0
n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP0G0?[`iP030000o`3jl>H0n_3V09D0
n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0503jl>H20000o`@0n_3V00<000000?[`iP3jl>H0
3`3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H0
5@3jl>H20000oiP0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H05P3jl>H01@000?l0n_3V0?[`
iP3jl>H000000140n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP140?[`iP030<f5
?`3jl>H0n_3V01D0n_3V00<0003o0?[`iP3jl>H0V03jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`
iP0G0?[`iP80003o00<000000?[`iP3jl>H04@3jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003j
l>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H20000oi/0n_3V0@3oool00880n_3V00<00000
0?[`iP3jl>H0603jl>H00`000000003o0?[`iP0C0?[`iP030<f5?`3jl>H0n_3V04<0n_3V00<00000
0?[`iP3jl>H0@`3jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP030000o`3jl>H0n_3V09/0n_3V0@3oool0
0880n_3V00<000000?[`iP3jl>H0603jl>H010000000n_3V0000o`000?lB0?[`iP030<f5?`3jl>H0
n_3V04<0n_3V00<000000?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP80003oWP3jl>H1
0?ooo`00PP3jl>H00`000000n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V0080n_3V00<0003o0?[`
iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V0480n_3V00<0cHDo0?[`
iP3jl>H04@3jl>H00`000?l0n_3V0?[`iP2N0?[`iP40oooo00220?[`iP030000003jl>H0n_3V01H0
n_3V00<000000?[`iP3jl>H0103jl>H20000oa40n_3V00<0cHDo0?[`iP3jl>H0@@3jl>H00`000000
n_3V0?[`iP110?[`iP030<f5?`3jl>H0n_3V0100n_3V0P000?nQ0?[`iP40oooo00220?[`iP030000
003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP0?0?[`iP030<f5
?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0@03jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP030000
o`3jl>H0n_3V0:40n_3V0@3oool00880n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`
iP080?[`iP80003o3`3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V03l0n_3V00<0
cHDo0?[`iP3jl>H03`3jl>H20000oj@0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0503jl>H0
0`000000n_3V0?[`iP0;0?[`iP030000o`3jl>H0n_3V00d0n_3V00<0cHDo0?[`iP3jl>H0?`3jl>H0
0`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V00h0n_3V00<0003o0?[`iP3jl>H0Y03jl>H1
0?ooo`00PP3jl>H00`000000n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V00d0n_3V0P000?l>0?[`
iP030<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0?P3jl>H00`3=QCl0n_3V0?[`iP0=0?[`
iP80003oY`3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V00l0
n_3V0P000?l<0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3=QCl0
n_3V0?[`iP0<0?[`iP80003oZ@3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP0B0?[`iP030000
003jl>H0n_3V0180n_3V00<0003o0?[`iP3jl>H02P3jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP030000
003jl>H0n_3V03d0n_3V00<0cHDo0?[`iP3jl>H02P3jl>H20000oj/0n_3V0@3oool00880n_3V00<0
00000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0D0?[`iP80003o2`3jl>H20<f5?cd0n_3V00<0
00000?[`iP3jl>H0>`3jl>H20<f5?``0n_3V00<0003o0?[`iP3jl>H0Z`3jl>H10?ooo`00PP3jl>H0
0`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V01L0n_3V0P000?l:0?[`iP030<f5?`3jl>H0
n_3V03/0n_3V00<000000?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`iP0:0?[`iP80003o[P3jl>H1
0?ooo`00PP3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V01T0n_3V00<0003o0?[`
iP3jl>H0203jl>H00`3=QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`
iP3jl>H0203jl>H20000ok00n_3V0@3oool00880n_3V00<000000?[`iP3jl>H03`3jl>H00`000000
n_3V0?[`iP0K0?[`iP80003o2@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V03T0
n_3V00<0cHDo0?[`iP3jl>H01`3jl>H20000ok80n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0
3P3jl>H00`000000n_3V0?[`iP0N0?[`iP80003o203jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP030000
003jl>H0n_3V03P0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP2b0?[`iP40oooo
00220?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H08@3jl>H00`000?l0n_3V0?[`
iP060?[`iP030<f5?`3jl>H0n_3V03L0n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V0?[`
iP060?[`iP80003o]@3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0
n_3V0280n_3V0P000?l70?[`iP80cHDo=`3jl>H00`000000n_3V0?[`iP0e0?[`iP80cHDo1`3jl>H2
0000okL0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0U0?[`
iP80003o1P3jl>H00`3=QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V03@0n_3V00<0cHDo0?[`
iP3jl>H01@3jl>H20000okT0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP0X0?[`iP030000o`3jl>H0n_3V00@0n_3V00<0cHDo0?[`iP3jl>H0=03jl>H00`000000
n_3V0?[`iP0d0?[`iP030<f5?`3jl>H0n_3V00@0n_3V00<0003o0?[`iP3jl>H0^@3jl>H10?ooo`00
PP3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V02T0n_3V0P000?l50?[`iP80cHDo
=03jl>H00`000000n_3V0?[`iP0b0?[`iP80cHDo1@3jl>H20000ok`0n_3V0@3oool00880n_3V00<0
00000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0/0?[`iP80003o1@3jl>H00`3=QCl0n_3V0?[`
iP0a0?[`iP030000003jl>H0n_3V0340n_3V00<0cHDo0?[`iP3jl>H00`3jl>H20000okh0n_3V0@3o
ool00880n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0_0?[`iP030000o`3jl>H0
n_3V00<0n_3V00<0cHDo0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0`0?[`iP030<f5?`3jl>H0
n_3V0080n_3V0P000?o00?[`iP40oooo00220?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`
iP3jl>H0<@3jl>H20000o`@0n_3V00<0cHDo0?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0_0?[`
iP040<f5?`3jl>H0n_3V0?[`iP80003o`P3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP080?[`
iP030000003jl>H0n_3V03<0n_3V0P000?l30?[`iP80cHDo;`3jl>H00`000000n_3V0?[`iP0]0?[`
iP80cHDo0`3jl>H00`000?l0n_3V0?[`iP320?[`iP40oooo00220?[`iP030000003jl>H0n_3V00L0
n_3V00<000000?[`iP3jl>H0=P3jl>H20000o`<0n_3V00<0cHDo0?[`iP3jl>H0;03jl>H00`000000
n_3V0?[`iP0/0?[`iP040<f5?`3jl>H0n_3V0?[`iP80003oa@3jl>H10?ooo`00PP3jl>H00`000000
n_3V0?[`iP060?[`iP030000003jl>H0n_3V03T0n_3V0P000?l20?[`iP80cHDo;03jl>H00`000000
n_3V0?[`iP0Z0?[`iP80cHDo0P3jl>H20000olL0n_3V0@3oool00880n_3V00<000000?[`iP3jl>H0
1P3jl>H00`000000n_3V0?[`iP0k0?[`iP80003o0P3jl>H20<f5?bX0n_3V00<000000?[`iP3jl>H0
:03jl>H20<f5?`80n_3V0P000?o90?[`iP40oooo00220?[`iP030000003jl>H0n_3V00D0n_3V00<0
00000?[`iP3jl>H0?P3jl>H20000o`80n_3V00<0cHDo0?[`iP3jl>H09`3jl>H00`000000n_3V0?[`
iP0W0?[`iP030<f5?`3jl>H0n_3V0080003ob`3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP04
0?[`iP030000003jl>H0n_3V0440n_3V0P000?l00`3jl>H0cHDo0<f5?`0W0?[`iP030000003jl>H0
n_3V02D0n_3V0P3=QCl00`3jl>H0003o0000o`3=0?[`iP40oooo00220?[`iP030000003jl>H0n_3V
00<0n_3V00<000000?[`iP3jl>H0A03jl>H30000o`80cHDo9@3jl>H00`000000n_3V0?[`iP0S0?[`
iP80cHDo00<0n_3V0000o`000?l0c`3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP030?[`iP03
0000003jl>H0n_3V04L0n_3V0`000?l00`3=QCl0n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V0240
n_3V0P3=QCl00`3jl>H0003o0000o`3A0?[`iP40oooo00220?[`iP030000003jl>H0n_3V0080n_3V
00<000000?[`iP3jl>H0B`3jl>H20000o`030<f5?`3jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0
7`3jl>H20<f5?`<0003od`3jl>H10?ooo`00PP3jl>H01@000000n_3V0?[`iP3jl>H000000500n_3V
0`000?lO0?[`iP030000003jl>H0n_3V01d0n_3V0P3=QCl20000omH0n_3V0@3oool00880n_3V00D0
00000?[`iP3jl>H0n_3V0000001C0?[`iP<0003o00<0cHDo0?[`iP3jl>H06@3jl>H00`000000n_3V
0?[`iP0I0?[`iP<0cHDo0`000?oH0?[`iP40oooo00220?[`iP040000003jl>H0n_3V000005L0n_3V
0`000?lI0?[`iP030000003jl>H0n_3V01L0n_3V00<0cHDo0000o`000?l00P000?oK0?[`iP40oooo
00220?[`iP030000003jl>H0000005/0n_3V10000?lE0?[`iP030000003jl>H0n_3V01<0n_3V00<0
cHDo0000o`000?l00P000?oO0?[`iP40oooo00210?[`iP<00000H03jl>H40000oa40n_3V00<00000
0?[`iP3jl>H03`3jl>H00`3=QCl0003o0000o`020000on<0n_3V0@3oool00800n_3V1@00001S0?[`
iP@0003o3@3jl>H00`000000n_3V0?[`iP0;0?[`iPD0003oi`3jl>H10?ooo`00P03=QCl5000006L0
cHDo3@000?l00`000000003o0000o`0;0000on/0cHDo0@3jl>H10?ooo`00P03jl>H500000?l0n_3V
K`3jl>H10?ooo`00P@3jl>H300000?l0n_3VL03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo002f0?[`iP80000000<0IV9N0<c4^`3jl>H0:`3jl>H01P3Dc<<0IV9N0000
00000000RHAn0>CKdVD0n_3V00H0e<c306IRGP000000000008V4OP3Tfm:L0?[`iP40oooo002h0?[`
iP0306IRGP000000g=C;02/0n_3V00H0C4U50<>k/`3jl>H0k>;I00000029Q7iU0?[`iP0604a9A@33
^k<0n_3V0>cRf@000000RHAnW03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP800000
0P3jl>H0102_Z:40C4U500000029Q7h70?[`iP060=cDb`1iMG00000000000029Q7h0c<Bk0P3jl>H0
102_Z:40C4U500000029Q7h20?[`iP8000000P3jl>H2000000050?[`iP3<a;/0000007UeL03jl>H0
0P0000020?[`iP80000000<0IV9N0?[`iP3jl>H01`3jl>H2000000<0n_3V00@0c<Bk04a9A@1VHUh0
i=_B0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`
iP8000000P3jl>H200000080n_3V00<0RHAn06IRGP3<a;/00P0000070?[`iP050=cDb`1iMG000000
04a9A@2TWIH00P3jl>H0103<a;/0C4U506IRGP3Tfm82000000030?[`iP000000000000@0n_3V00<0
Y9fF0000002TWIH00`3jl>H0102_Z:40C4U500000029Q7h70?[`iP040:nXX@1<BDD0C4U50:nXX@80
n_3V0P0000060?[`iP80000000D0n_3V0<>k/`000000`k^c0?[`iP02000000050?[`iP3<a;/0C4U5
04a9A@2_Z:400P0000000`3jl>H00000000000030?[`iP80000000D0n_3V0<c4^`1<BDD0C4U50:nX
X@02000000@0n_3V0P0000000`3/h]T0n_3V0>cRf@0200000080n_3V00<0RHAn06IRGP3<a;/00P00
00000`3jl>H00000000000020?[`iP8000000P3jl>H0102_Z:40C4U500000029Q7h20?[`iP070>cR
f@2GTH/000000000001iMG00i=_B0?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP80
00000P3jl>H2000000070?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP050?[`iP050>CKdP000000
Ui6;0?[`iP2i/ZX00P000000203jl>H0[jRQ00000033^k<0i=_B00000029Q7h0n_3V0P0000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP3<a;/000000080000000<0i=_B0?[`
iP3jl>H01P3jl>H2000000<0n_3V00@0IV9N0000003Tfm80^K:Z0P0000000`3jl>H0000000000003
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000050?[`iP2T
WIH000000<>k/`2TWIH00P0000060?[`iP0<0>CKdP000000Ui6;0?[`iP3Dc<<0000008V4OP3jl>H0
IV9N0000003Tfm80^K:Z0P0000000`3jl>H00000000000040?[`iP<0000000P0k>;I0?[`iP2_Z:40
00000<>k/`3Tfm80000008V4OPD0n_3V00L0^K:Z00000033^k<0`k^c0000002i/ZX0n_3V00800000
1P3jl>H2000000050?[`iP2GTH/0000009NAR`3jl>H00P0000001@3jl>H0C4U50000003Tfm80`k^c
0080000000<0n_3V0000000000000`3jl>H2000000050?[`iP1<BDD000000>CKdP33^k<00P000004
0?[`iP0<08V4OP000000e<c30?[`iP3Dc<<0000008V4OP3jl>H0Y9fF00000033^k<0Y9fF0P000000
0`3jl>H00000000000020?[`iP80000000l0n_3V0:nXX@000000`k^c0>CKdP000000RHAn0?[`iP1i
MG0000000>CKdP3/h]T0000006IRGP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H2
00000080n_3V0P0000000`3jl>H0C4U5000000090?[`iP0309NAR`000000g=C;0080n_3V0P000000
0`3jl>H0C4U5000000050?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
1P3jl>H0Ui6;00000029Q7h000000:nXX@P0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`
iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80
000000<0n_3V04a9A@0000000P3jl>H2000000H0n_3V00<0Ui6;0000003Tfm801@3jl>H200000080
n_3V0P0000000`3jl>H00000000000030?[`iP080;VbZP000000RHAn0000002i/ZX0n_3V04a9A@00
00090?[`iP0706IRGP000000n_3V0?[`iP000000IV9N0?[`iP02000000H0n_3V0P0000001@3jl>H0
C4U50000001<BDD0n_3V0080000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
00<0n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H00`2_Z:400000000000030000
00040:nXX@3jl>H0C4U500000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
04a9A@0000001`3jl>H01@3Dc<<0Y9fF0000001<BDD0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2
000000<0n_3V0P0000020?[`iP80000000<0n_3V000000000000100000050?[`iP0304a9A@000000
n_3V0080n_3V0P0000000`3jl>H0000000000004000000030?[`iP00000000000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000H0n_3V04a9A@000000k>;I0000001VHUh80?[`iP800000
0`3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`
iP00000000000?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000060?[`iP80
00001P3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP80C4U500@0k>;I04a9A@1<
BDD0n_3V1P0000050?[`iP8000000P3jl>H2000000030?[`iP000000000000H0n_3V0P0000001@3T
fm80000009NAR`000000i=_B0080000000D0n_3V0<c4^`000000Ui6;0>CKdP02000000030?[`iP00
0000000000<0n_3V0P0000001@3jl>H0c<Bk0000002GTH/0i=_B00800000103jl>H0203Dc<<00000
08V4OP3jl>H0Ui6;0000003Dc<<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP000000000000@0000000<0n_3V0<c4^`1<BDD00P0000000`1<BDD0c<Bk0?[`iP02
000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP1<BDD00000
0080n_3V00<0000006IRGP3jl>H0103jl>H200000080n_3V0`0000000`3jl>H0C4U5000000020?[`
iP030000001VHUh0n_3V008000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000001`3L
e</0000008V4OP3jl>H0RHAn0000003Tfm801`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0
n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V
0P0000000`3jl>H0C4U5000000020?[`iP8000001P3jl>H2000000H0n_3V0P0000020?[`iP800000
00<0n_3V0000000000000P3jl>H02@3<a;/000000:BMUP3jl>H0Y9fF0000003<a;/0C4U500000002
0?[`iP030000001VHUh0n_3V00@0n_3V00L0IV9N0000003jl>H0n_3V0000001VHUh0n_3V00800000
1P3jl>H2000000050<c4^`000000g=C;0000003<a;/00P0000020?[`iP030=cDb`2_Z:40NGE`0080
000000<0n_3V0000000000000`3jl>H200000080n_3V00<0g=C;0:nXX@1iMG000P0000050?[`iP05
0000001<BDD0n_3V04a9A@0000000P3jl>H0101<BDD000000?[`iP3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP070000001VHUh0n_3V04a9A@000000NGE`
0<c4^`030?[`iP800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000002`2TWIH0i=_B0000
001VHUh0n_3V0;VbZP000000`k^c0<c4^`000000^K:Z00D0n_3V00<0C4U50000003jl>H01@3jl>H0
1`2i/ZX000000<>k/`3<a;/000000;VbZP3jl>H00P0000001@2i/ZX0i=_B0000001<BDD0n_3V0080
00000P3jl>H2000000070:nXX@000000`k^c0?[`iP33^k<000000:nXX@070?[`iP8000000`3jl>H2
00000080n_3V0P000000103jl>H000000000003Dc<<20?[`iP80000000D0^K:Z0>CKdP000000C4U5
0?[`iP020000000<0?[`iP00000000000;VbZP3Tfm80000004a9A@3jl>H0Y9fF00000033^k<0Y9fF
0P0000060?[`iP0304a9A@000000n_3V00D0n_3V0P0000020?[`iP8000000180n_3V000000000000
e<c30?[`iP1VHUh000000>cRf@3jl>H0k>;I0000001VHUh0^K:Z00000033^k<0c<Bk0000002i/ZX5
0?[`iP070;VbZP000000`k^c0<>k/`000000^K:Z0?[`iP02000000H0n_3V0P0000001@2TWIH0IV9N
0?[`iP1VHUh0Y9fF0080000000P0n_3V07UeL03Dc<<0n_3V0>CKdP000000C4U50?[`iP80000000<0
e<c30?[`iP3jl>H00P0000001`3jl>H0NGE`0=C<``3jl>H0i=_B0000001<BDD01@3jl>H01@1iMG00
00000<c4^`000000IV9N0080n_3V00@0Y9fF00000033^k<0Y9fF0P0000005P3jl>H000000000002i
/ZX0i=_B0000001<BDD0n_3V0;VbZP000000`k^c0<c4^`000000^K:Z0?[`iP1VHUh000000?[`iP3T
fm80000007UeL03jl>H2000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP80000000@0g=C;08V4
OP1<BDD0c<Bk0P3jl>H0102_Z:4000000000002_Z:460?[`iP0309NAR`000000i=_B00H0n_3V00@0
[jRQ000000000000[jRQ0P3jl>H2000000040<c4^`1iMG00C4U50<c4^`@0000000X0n_3V00000000
0000IV9N0000003/h]T0n_3V0>cRf@000000IV9N1`3jl>H2000000<0n_3V0P0000020?[`iP800000
00H0n_3V000000000000RHAn07UeL03jl>H2000000050<c4^`1iMG00C4U50<c4^`3jl>H00P000000
1`3jl>H000000000003<a;/0NGE`04a9A@3<a;/00P3jl>H00`29Q7h0IV9N0<c4^`02000000H0n_3V
00<0Ui6;0000003Tfm801@3jl>H200000080n_3V0P000000103jl>H0000000000029Q7h200000008
08V4OP3jl>H0n_3V0?[`iP29Q7h000000=cDb`2_Z:42000000030:nXX@3jl>H0n_3V00D0n_3V00D0
[jRQ04a9A@000000[jRQ0?[`iP04000000D0n_3V0P0000001@1VHUh0Y9fF0?[`iP2GTH/0IV9N0080
000000<0n_3V0>CKdP29Q7h00P0000000`1VHUh0e<c30?[`iP020000000308V4OP1iMG00n_3V0080
000000<0n_3V0>CKdP29Q7h00P0000000`1VHUh0e<c30?[`iP040?[`iP050:BMUP000000RHAn0000
002TWIH00`3jl>H00`29Q7h0IV9N0<c4^`02000000070?[`iP00000000000<c4^`1iMG00C4U50<c4
^`020?[`iP040:nXX@00000000000:nXX@80n_3V00L0i=_B07UeL0000000000008V4OP3Tfm80n_3V
00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P00000@0?[`iP070>CKdP000000Ui6;0?[`
iP3Dc<<0000007UeL00?0?[`iP8000000P3jl>H2000000h0n_3V0P00000/0?[`iP070>CKdP000000
Ui6;0?[`iP3Dc<<0000008V4OP0U0?[`iP8000001P3jl>H3000000030<c4^`3jl>H0`k^c00<00000
6`3jl>H01@3<a;/00000000000000000`k^c0:@0n_3V0@3oool00840n_3V1P0000000`3jl>H00000
0000000A0?[`iP060=cDb`1iMG0000000000002GTH/0k>;I3`3jl>H0103Le</0RHAn0?[`iP3jl>H2
000000`0n_3V1P00000D0?[`iP8000005@3jl>H01@3Le</0NGE`000000000000Y9fF02H0n_3V00@0
c<Bk06IRGP000000RHAn103jl>H3000000030>cRf@3jl>H0g=C;00<000003@3jl>H2000000`0n_3V
00D0k>;I00000000000000000>CKdP0N0?[`iP800000Q03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.30435 .38333 L
s
.30435 .05 m
.30435 .38333 L
s
.35448 .29792 m
.30435 .29792 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.30435 .38333 Mdot
.35448 .29792 Mdot
.30435 .29792 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool009P0n_3V00<000000?[`iP3jl>H0DP3jl>H:0<f5
?`030?[`iP00000000000080n_3V2P3=QCo]0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V04`0
n_3V1P3=QCl;0?[`iP800000303jl>H70<f5?nH0n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H0
BP3jl>H20<f5?a00n_3V00<000000?[`iP0000004`3jl>H20<f5?n@0n_3V0@3oool009P0n_3V00<0
00000?[`iP3jl>H0AP3jl>H40<f5?a80n_3V00<000000?[`iP0000005@3jl>H30<f5?n40n_3V0@3o
ool009P0n_3V00<000000?[`iP3jl>H0@P3jl>H40<f5?aD0n_3V00@000000?[`iP3jl>H00000603j
l>H40<f5?md0n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H0@03jl>H20<f5?aP0n_3V00D00000
0?[`iP3jl>H0n_3V0000000L0?[`iP80cHDof`3jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP0n
0?[`iP80cHDo6P3jl>H01@000000n_3V0?[`iP3jl>H0000001h0n_3V0P3=QCoI0?[`iP40oooo002H
0?[`iP030000003jl>H0n_3V03`0n_3V0P3=QClK0?[`iP030000003jl>H0n_3V0080n_3V00<00000
0?[`iP3jl>H07P3jl>H20<f5?mL0n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H0>P3jl>H20<f5
?ad0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0P0?[`iP80cHDoe@3jl>H10?oo
o`00V03jl>H00`000000n_3V0?[`iP0h0?[`iP80cHDo7P3jl>H00`000000n_3V0?[`iP030?[`iP03
0000003jl>H0n_3V0280n_3V0P3=QCoC0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V03H0n_3V
0P3=QClP0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0903jl>H20<f5?m40n_3V
0@3oool009P0n_3V00<000000?[`iP3jl>H0=03jl>H20<f5?b40n_3V00<000000?[`iP3jl>H0103j
l>H00`000000n_3V0?[`iP0V0?[`iP80cHDoc`3jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP0c
0?[`iP030<f5?`3jl>H0n_3V0200n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0X
0?[`iP030<f5?`3jl>H0n_3V0<`0n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H0<@3jl>H20<f5
?b<0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0Y0?[`iP80cHDoc03jl>H10?oo
o`00V03jl>H00`000000n_3V0?[`iP0_0?[`iP80cHDo903jl>H00`000000n_3V0?[`iP060?[`iP03
0000003jl>H0n_3V02/0n_3V0P3=QCo:0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V02h0n_3V
00<0cHDo0?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V02d0n_3V
00<0cHDo0?[`iP3jl>H0a`3jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP0/0?[`iP80cHDo9P3j
l>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V02h0n_3V0P3=QCo70?[`iP40oooo002H
0?[`iP030000003jl>H0n_3V02/0n_3V00<0cHDo0?[`iP3jl>H09@3jl>H00`000000n_3V0?[`iP08
0?[`iP030000003jl>H0n_3V0300n_3V00<0cHDo0?[`iP3jl>H0a03jl>H10?ooo`00V03jl>H00`00
0000n_3V0?[`iP0Z0?[`iP030<f5?`3jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0203jl>H00`00
0000n_3V0?[`iP0a0?[`iP030<f5?`3jl>H0n_3V0<<0n_3V0@3oool009P0n_3V00<000000?[`iP3j
l>H0:@3jl>H00`3=QCl0n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3j
l>H0<P3jl>H00`3=QCl0n_3V0?[`iP320?[`iP40oooo002H0?[`iP030000003jl>H0n_3V02L0n_3V
0P3=QClY0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0<`3jl>H20<f5?l80n_3V
0@3oool009P0n_3V00<000000?[`iP3jl>H09P3jl>H00`3=QCl0n_3V0?[`iP0X0?[`iP030000003j
l>H0n_3V00X0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP300?[`iP40oooo002H
0?[`iP030000003jl>H0n_3V02D0n_3V00<0cHDo0?[`iP3jl>H0:@3jl>H00`000000n_3V0?[`iP0:
0?[`iP030000003jl>H0n_3V03D0n_3V00<0cHDo0?[`iP3jl>H0_`3jl>H10?ooo`00V03jl>H00`00
0000n_3V0?[`iP0T0?[`iP030<f5?`3jl>H0n_3V02T0n_3V00<000000?[`iP3jl>H02`3jl>H00`00
0000n_3V0?[`iP0f0?[`iP80cHDo_`3jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP0S0?[`iP03
0<f5?`3jl>H0n_3V02T0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0h0?[`iP03
0<f5?`3jl>H0n_3V0;`0n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H08P3jl>H00`3=QCl0n_3V
0?[`iP0Z0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0>@3jl>H00`3=QCl0n_3V
0?[`iP2k0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V0240n_3V00<0cHDo0?[`iP3jl>H0:P3j
l>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H0^P3j
l>H10?ooo`00V03jl>H00`000000n_3V0?[`iP0P0?[`iP030<f5?`3jl>H0n_3V02/0n_3V00<00000
0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V0;X0n_3V0@3oool0
09P0n_3V00<000000?[`iP3jl>H07`3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V
00h0n_3V00<000000?[`iP3jl>H0>`3jl>H00`3=QCl0n_3V0?[`iP2i0?[`iP40oooo002H0?[`iP03
0000003jl>H0n_3V01h0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP0?0?[`iP03
0000003jl>H0n_3V03`0n_3V0P3=QCni0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V01d0n_3V
00<0cHDo0?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V03d0n_3V
00<0cHDo0?[`iP3jl>H0]`3jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP0M0?[`iP030<f5?`3j
l>H0n_3V02/0n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0n0?[`iP030<f5?`3j
l>H0n_3V0;H0n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H0703jl>H00`3=QCl0n_3V0?[`iP0/
0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=QCl0n_3V0?[`iP2e
0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V01/0n_3V00<0cHDo0?[`iP3jl>H0;03jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H0]@3jl>H10?oo
o`00V03jl>H00`000000n_3V0?[`iP0K0?[`iP030<f5?`3jl>H0n_3V02`0n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP100?[`iP030<f5?`3jl>H0n_3V0;@0n_3V0@3oool009P0n_3V
00<000000?[`iP3jl>H06P3jl>H00`3=QCl0n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V0180n_3V
00<000000?[`iP3jl>H0@@3jl>H00`3=QCl0n_3V0?[`iP2c0?[`iP40oooo002H0?[`iP030000003j
l>H0n_3V01T0n_3V00<0cHDo0?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0C0?[`iP030000003j
l>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H0/P3jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP0H
0?[`iP030<f5?`3jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP13
0?[`iP030<f5?`3jl>H0n_3V0;40n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H05`3jl>H00`3=
QCl0n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0@`3jl>H00`3=
QCl0n_3V0?[`iP2a0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V01L0n_3V00<0cHDo0?[`iP3j
l>H0;@3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3j
l>H0/03jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP0F0?[`iP030<f5?`3jl>H0n_3V02d0n_3V
00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0n_3V0;00n_3V
0@3oool009P0n_3V00<000000?[`iP3jl>H05P3jl>H00`3=QCl0n_3V0?[`iP0/0?[`iP030000003j
l>H0n_3V01H0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP2_0?[`iP40oooo002H
0?[`iP030000003jl>H0n_3V01D0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP0F
0?[`iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H0[`3jl>H10?ooo`00V03jl>H00`00
0000n_3V0?[`iP0E0?[`iP030<f5?`3jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H05`3jl>H00`00
0000n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool009P0n_3V00<000000?[`iP3j
l>H0503jl>H00`3=QCl0n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V01L0n_3V00<000000?[`iP3j
l>H0AP3jl>H00`3=QCl0n_3V0?[`iP2^0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V01@0n_3V
00<0cHDo0?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V04L0n_3V
00<0cHDo0?[`iP3jl>H0[@3jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP0C0?[`iP030<f5?`3j
l>H0n_3V02d0n_3V00<000000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP180?[`iP030<f5?`3j
l>H0n_3V0:`0n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`iP0]
0?[`iP030000003jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H0B03jl>H00`3=QCl0n_3V0?[`iP2/
0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V0180n_3V00<0cHDo0?[`iP3jl>H0;03jl>H00`00
0000n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3jl>H0Z`3jl>H10?oo
o`00V03jl>H00`000000n_3V0?[`iP0A0?[`iP030<f5?`3jl>H0n_3V02d0n_3V00<000000?[`iP3j
l>H06P3jl>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V0:/0n_3V0@3oool009P0n_3V
00<000000?[`iP3jl>H04@3jl>H00`3=QCl0n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V01/0n_3V
00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2Z0?[`iP40oooo00020000oiH0n_3V00<0
00000?[`iP3jl>H04@3jl>H00`3=QCl0n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V01/0n_3V00<0
00000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2W0?[`iP80003o0@3jl>H10?ooo`000P3jl>H3
0000oi<0n_3V00<000000?[`iP3jl>H04@3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP030000003jl>H0
n_3V01`0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2T0?[`iP<0003o0`3jl>H1
0?ooo`001@3jl>H40000ohl0n_3V00<000000?[`iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP0[0?[`
iP030000003jl>H0n_3V01d0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2P0?[`
iP@0003o1P3jl>H10?ooo`002@3jl>H30000oh`0n_3V00<000000?[`iP3jl>H0403jl>H00`3=QCl0
n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V01d0n_3V00<000000?[`iP3jl>H0B`3jl>H00`3=QCl0
n_3V0?[`iP2L0?[`iP<0003o2P3jl>H10?ooo`00303jl>H30000ohT0n_3V00<000000?[`iP3jl>H0
3`3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0
B`3jl>H00`3=QCl0n_3V0?[`iP2I0?[`iP<0003o3@3jl>H10?ooo`003`3jl>H40000ohD0n_3V00<0
00000?[`iP3jl>H03`3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V01h0n_3V00<0
00000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP2D0?[`iP@0003o403jl>H10?ooo`004`3jl>H3
0000oh80n_3V00<000000?[`iP3jl>H03`3jl>H00`3=QCl0n_3V0?[`iP0Z0?[`iP030000003jl>H0
n_3V01l0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP2A0?[`iP<0003o503jl>H1
0?ooo`005P3jl>H30000ogl0n_3V00<000000?[`iP3jl>H03`3jl>H00`3=QCl0n_3V0?[`iP0Z0?[`
iP030000003jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP2>0?[`
iP<0003o5`3jl>H10?ooo`006@3jl>H30000og`0n_3V00<000000?[`iP3jl>H03P3jl>H00`3=QCl0
n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0
n_3V0?[`iP2;0?[`iP<0003o6P3jl>H10?ooo`00703jl>H30000ogT0n_3V00<000000?[`iP3jl>H0
3P3jl>H00`3=QCl0n_3V0?[`iP0Y0?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0
C@3jl>H00`3=QCl0n_3V0?[`iP270?[`iP<0003o7@3jl>H10?ooo`007`3jl>H40000ogD0n_3V00<0
00000?[`iP3jl>H03P3jl>H00`3=QCl0n_3V0?[`iP0Y0?[`iP030000003jl>H0n_3V0240n_3V00<0
00000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP240?[`iP<0003o803jl>H10?ooo`008`3jl>H3
0000og80n_3V00<000000?[`iP3jl>H03P3jl>H00`3=QCl0n_3V0?[`iP0X0?[`iP030000003jl>H0
n_3V0280n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP210?[`iP<0003o8`3jl>H1
0?ooo`009P3jl>H30000ofl0n_3V00<000000?[`iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP0Y0?[`
iP030000003jl>H0n_3V0280n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP1n0?[`
iP<0003o9P3jl>H10?ooo`00:@3jl>H30000of`0n_3V00<000000?[`iP3jl>H03@3jl>H00`3=QCl0
n_3V0?[`iP0X0?[`iP030000003jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0
n_3V0?[`iP1j0?[`iP<0003o:@3jl>H10?ooo`00;03jl>H20000ofX0n_3V00<000000?[`iP3jl>H0
3@3jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0
CP3jl>H00`3=QCl0n_3V0?[`iP1h0?[`iP80003o;03jl>H10?ooo`00;P3jl>H20000ofP0n_3V00<0
00000?[`iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V02@0n_3V00<0
00000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP1f0?[`iP80003o;P3jl>H10?ooo`00<03jl>H3
0000ofD0n_3V00<000000?[`iP3jl>H0303jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP030000003jl>H0
n_3V02D0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP1c0?[`iP<0003o<03jl>H1
0?ooo`00<`3jl>H20000of<0n_3V00<000000?[`iP3jl>H0303jl>H00`3=QCl0n_3V0?[`iP0W0?[`
iP030000003jl>H0n_3V02D0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1`0?[`
iP80003o<`3jl>H10?ooo`00=@3jl>H20000of40n_3V00<000000?[`iP3jl>H0303jl>H00`3=QCl0
n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0
n_3V0?[`iP1^0?[`iP80003o=@3jl>H10?ooo`00=`3jl>H30000oeh0n_3V00<000000?[`iP3jl>H0
303jl>H00`3=QCl0n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0
C`3jl>H00`3=QCl0n_3V0?[`iP1[0?[`iP<0003o=`3jl>H10?ooo`00>P3jl>H20000oe`0n_3V00<0
00000?[`iP3jl>H0303jl>H00`3=QCl0n_3V0?[`iP0U0?[`iP030000003jl>H0n_3V02L0n_3V00<0
00000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1Y0?[`iP80003o>P3jl>H10?ooo`00?03jl>H2
0000oeX0n_3V00<000000?[`iP3jl>H0303jl>H00`3=QCl0n_3V0?[`iP0T0?[`iP030000003jl>H0
n_3V02P0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1W0?[`iP80003o?03jl>H1
0?ooo`00?P3jl>H30000oeL0n_3V00<000000?[`iP3jl>H02`3jl>H00`3=QCl0n_3V0?[`iP0U0?[`
iP030000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1T0?[`
iP<0003o?P3jl>H10?ooo`00@@3jl>H20000oeD0n_3V00<000000?[`iP3jl>H02`3jl>H00`3=QCl0
n_3V0?[`iP0T0?[`iP030000003jl>H0n_3V02T0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0
n_3V0?[`iP1Q0?[`iP80003o@@3jl>H10?ooo`00@`3jl>H20000oe<0n_3V00<000000?[`iP3jl>H0
2`3jl>H00`3=QCl0n_3V0?[`iP0T0?[`iP030000003jl>H0n_3V02T0n_3V00<000000?[`iP3jl>H0
D03jl>H00`3=QCl0n_3V0?[`iP1O0?[`iP80003o@`3jl>H10?ooo`00A@3jl>H20000oe40n_3V00<0
00000?[`iP3jl>H02`3jl>H00`3=QCl0n_3V0?[`iP0S0?[`iP030000003jl>H0n_3V02X0n_3V00<0
00000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1M0?[`iP80003oA@3jl>H10?ooo`00A`3jl>H2
0000odl0n_3V00<000000?[`iP3jl>H02`3jl>H00`3=QCl0n_3V0?[`iP0R0?[`iP030000003jl>H0
n_3V02/0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1K0?[`iP80003oA`3jl>H1
0?ooo`00B@3jl>H30000od`0n_3V00<000000?[`iP3jl>H02`3jl>H00`3=QCl0n_3V0?[`iP0R0?[`
iP030000003jl>H0n_3V02/0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1I0?[`
iP80003oB@3jl>H10?ooo`00C03jl>H20000odX0n_3V00<000000?[`iP3jl>H02`3jl>H00`3=QCl0
n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0
n_3V0?[`iP1G0?[`iP80003oB`3jl>H10?ooo`00CP3jl>H20000odP0n_3V00<000000?[`iP3jl>H0
2`3jl>H00`3=QCl0n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V02/0n_3V0`00001A0?[`iP030<f5
?`3jl>H0n_3V05D0n_3V0P000?m=0?[`iP40oooo001@0?[`iP80003oAP3jl>H00`000000n_3V0?[`
iP0;0?[`iP030<f5?`3jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0:`3jl>H500000500n_3V00<0
cHDo0?[`iP3jl>H0D`3jl>H20000odl0n_3V0@3oool00580n_3V0P000?m40?[`iP030000003jl>H0
n_3V00/0n_3V00<0cHDo0?[`iP3jl>H07`3jl>H00`000000n_3V0?[`iP0/0?[`iPD00000D03jl>H0
0`3=QCl0n_3V0?[`iP1A0?[`iP80003oD@3jl>H10?ooo`00E03jl>H20000od80n_3V00<000000?[`
iP3jl>H02`3jl>H00`3=QCl0n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V02`0n_3V1@00001@0?[`
iP030<f5?`3jl>H0n_3V04l0n_3V0P000?mC0?[`iP40oooo001F0?[`iP80003o@03jl>H00`000000
n_3V0?[`iP0;0?[`iP030<f5?`3jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0;P3jl>H300000540
n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H20000oeD0n_3V0@3oool005P0n_3V0P000?ln0?[`iP030000
003jl>H0n_3V00/0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP0_0?[`iP030000
003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H0B`3jl>H20000oeL0n_3V0@3oool005X0n_3V00<0
003o0?[`iP3jl>H0>`3jl>H00`000000n_3V0?[`iP0;0?[`iP030<f5?`3jl>H0n_3V01d0n_3V00<0
00000?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04T0n_3V0P00
0?mI0?[`iP40oooo001K0?[`iP80003o>`3jl>H00`000000n_3V0?[`iP0;0?[`iP030<f5?`3jl>H0
n_3V01d0n_3V00<000000?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0
n_3V04L0n_3V0P000?mK0?[`iP40oooo001M0?[`iP80003o>@3jl>H00`000000n_3V0?[`iP0;0?[`
iP030<f5?`3jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP1@0?[`
iP030<f5?`3jl>H0n_3V04D0n_3V0P000?mM0?[`iP40oooo001O0?[`iP80003o=`3jl>H00`000000
n_3V0?[`iP0;0?[`iP030<f5?`3jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0<P3jl>H00`000000
n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04<0n_3V0P000?mO0?[`iP40oooo001Q0?[`iP030000
o`3jl>H0n_3V03@0n_3V00<000000?[`iP3jl>H02`3jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP030000
003jl>H0n_3V0380n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP110?[`iP80003o
H@3jl>H10?ooo`00HP3jl>H20000oc@0n_3V00<000000?[`iP3jl>H02`3jl>H00`3=QCl0n_3V0?[`
iP0J0?[`iP030000003jl>H0n_3V03<0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`
iP0o0?[`iP80003oH`3jl>H10?ooo`00I03jl>H20000oc80n_3V00<000000?[`iP3jl>H02`3jl>H0
0`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V03<0n_3V00<000000?[`iP3jl>H0C`3jl>H0
0`3=QCl0n_3V0?[`iP0n0?[`iP80003oI@3jl>H10?ooo`00IP3jl>H20000oc00n_3V00<000000?[`
iP3jl>H0303jl>H00`3=QCl0n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V03@0n_3V00<000000?[`
iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP80003oI`3jl>H10?ooo`00J03jl>H00`000?l0
n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V00`0n_3V00<0cHDo0?[`iP3jl>H05`3jl>H00`000000
n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H00`000?l0
n_3V0?[`iP1W0?[`iP40oooo001Y0?[`iP80003o;@3jl>H00`000000n_3V0?[`iP0<0?[`iP030<f5
?`3jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5
?`3jl>H0n_3V03T0n_3V0P000?mZ0?[`iP40oooo001[0?[`iP80003o:`3jl>H00`000000n_3V0?[`
iP0<0?[`iP030<f5?`3jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`
iP1?0?[`iP030<f5?`3jl>H0n_3V03P0n_3V00<0003o0?[`iP3jl>H0JP3jl>H10?ooo`00K@3jl>H0
0`000?l0n_3V0?[`iP0X0?[`iP030000003jl>H0n_3V00`0n_3V00<0cHDo0?[`iP3jl>H05P3jl>H0
0`000000n_3V0?[`iP0f0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0=P3jl>H2
0000ofd0n_3V0@3oool006h0n_3V0P000?lX0?[`iP030000003jl>H0n_3V00`0n_3V00<0cHDo0?[`
iP3jl>H05@3jl>H00`000000n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`
iP3jl>H0=@3jl>H20000ofl0n_3V0@3oool00700n_3V0P000?lV0?[`iP030000003jl>H0n_3V00d0
n_3V00<0cHDo0?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V04h0
n_3V00<0cHDo0?[`iP3jl>H0=03jl>H00`000?l0n_3V0?[`iP1_0?[`iP40oooo001b0?[`iP030000
o`3jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP030000
003jl>H0n_3V03P0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0b0?[`iP80003o
LP3jl>H10?ooo`00L`3jl>H20000ob<0n_3V00<000000?[`iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`
iP0B0?[`iP030000003jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`
iP0a0?[`iP030000o`3jl>H0n_3V0780n_3V0@3oool007D0n_3V0P000?lQ0?[`iP030000003jl>H0
n_3V00d0n_3V00<0cHDo0?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0i0?[`iP030000003jl>H0
n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0<03jl>H20000ogD0n_3V0@3oool007L0n_3V00<0003o0?[`
iP3jl>H07P3jl>H00`000000n_3V0?[`iP0>0?[`iP030<f5?`3jl>H0n_3V0100n_3V00<000000?[`
iP3jl>H0>P3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V02h0n_3V0P000?mg0?[`
iP40oooo001h0?[`iP80003o7P3jl>H00`000000n_3V0?[`iP0>0?[`iP030<f5?`3jl>H0n_3V0100
n_3V00<000000?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V02d0
n_3V00<0003o0?[`iP3jl>H0M`3jl>H10?ooo`00NP3jl>H20000oa`0n_3V00<000000?[`iP3jl>H0
3P3jl>H00`3=QCl0n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H0
C@3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP80003oNP3jl>H10?ooo`00O03jl>H00`000?l0n_3V0?[`
iP0I0?[`iP030000003jl>H0n_3V00h0n_3V00<0cHDo0?[`iP3jl>H03P3jl>H00`000000n_3V0?[`
iP0l0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`000?l0n_3V0?[`
iP1j0?[`iP40oooo001m0?[`iP80003o6@3jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0
n_3V00d0n_3V00<000000?[`iP3jl>H0?03jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0
n_3V02T0n_3V0P000?mm0?[`iP40oooo001o0?[`iP80003o5`3jl>H00`000000n_3V0?[`iP0?0?[`
iP030<f5?`3jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP1<0?[`
iP030<f5?`3jl>H0n_3V02L0n_3V0P000?mo0?[`iP40oooo00210?[`iP030000o`3jl>H0n_3V01@0
n_3V00<000000?[`iP3jl>H03`3jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V03d0
n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0V0?[`iP030000o`3jl>H0n_3V07l0
n_3V0@3oool00880n_3V0P000?lD0?[`iP030000003jl>H0n_3V00l0n_3V00<0cHDo0?[`iP3jl>H0
2`3jl>H00`000000n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V04/0n_3V00<0cHDo0?[`iP3jl>H0
9@3jl>H20000oh80n_3V0@3oool008@0n_3V0P000?lB0?[`iP030000003jl>H0n_3V0100n_3V00<0
cHDo0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V04/0n_3V00<0
cHDo0?[`iP3jl>H0903jl>H00`000?l0n_3V0?[`iP220?[`iP40oooo00260?[`iP030000o`3jl>H0
n_3V00l0n_3V00<000000?[`iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP090?[`iP030000003jl>H0
n_3V03l0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0S0?[`iP80003oQ@3jl>H1
0?ooo`00Q`3jl>H20000o`l0n_3V00<000000?[`iP3jl>H04@3jl>H00`3=QCl0n_3V0?[`iP070?[`
iP030000003jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0Q0?[`
iP80003oQ`3jl>H10?ooo`00R@3jl>H20000o`d0n_3V00<000000?[`iP3jl>H04@3jl>H00`3=QCl0
n_3V0?[`iP070?[`iP030000003jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0
n_3V0?[`iP0P0?[`iP030000o`3jl>H0n_3V08L0n_3V0@3oool008/0n_3V0P000?l;0?[`iP030000
003jl>H0n_3V0140n_3V00<0cHDo0?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP110?[`iP030000
003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H20000ohX0n_3V0@3oool008d0n_3V00<0
003o0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0A0?[`iP030<f5?`3jl>H0n_3V00H0n_3V00<0
00000?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V01h0n_3V00<0
003o0?[`iP3jl>H0RP3jl>H10?ooo`00SP3jl>H20000o`P0n_3V00<000000?[`iP3jl>H04P3jl>H0
0`3=QCl0n_3V0?[`iP040?[`iP030000003jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0B@3jl>H0
0`3=QCl0n_3V0?[`iP0L0?[`iP80003oS@3jl>H10?ooo`00T03jl>H20000o`H0n_3V00<000000?[`
iP3jl>H04`3jl>H00`3=QCl0n_3V0?[`iP020?[`iP030000003jl>H0n_3V04<0n_3V00<000000?[`
iP3jl>H0B03jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP80003oS`3jl>H10?ooo`00TP3jl>H00`000?l0
n_3V0?[`iP030?[`iP030000003jl>H0n_3V01<0n_3V00<0cHDo0?[`iP3jl>H00P3jl>H00`000000
n_3V0?[`iP130?[`iP030000003jl>H0n_3V04L0n_3V00<0cHDo0?[`iP3jl>H06`3jl>H00`000?l0
n_3V0?[`iP2?0?[`iP40oooo002C0?[`iP80003o0`3jl>H00`000000n_3V0?[`iP0D0?[`iP040<f5
?`3jl>H0n_3V000004H0n_3V00<000000?[`iP3jl>H0A`3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP80
003oTP3jl>H10?ooo`00U@3jl>H00`000?l0n_3V00000002000001D0n_3V00@0cHDo000000000000
0000AP3jl>H00`000000n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V01T0n_3V00<0003o0?[`iP3j
l>H0TP3jl>H10?ooo`00UP3jl>H5000001@0n_3V1@0000150?[`iP030000003jl>H0n_3V04H0n_3V
00<0cHDo0?[`iP3jl>H05`3jl>H20000oiD0n_3V0@3oool009H0n_3V7P0000150?[`iP030000003j
l>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H05`3jl>H00`000?l0n_3V0?[`iP2E0?[`iP40oooo002F
0?[`iPD00000503jl>H5000004D0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP0E
0?[`iP80003oV03jl>H10?ooo`00U`3jl>H3000000030?[`iP000?l0n_3V0180n_3V100000160?[`
iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H05@3jl>H00`000?l0n_3V0?[`iP2H0?[`
iP40oooo002H0?[`iP040000003jl>H0n_3V0?[`iP80003o4@3jl>H010000000n_3V0?[`iP3=QCm6
0?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H20000oi/0n_3V0@3oool0
09P0n_3V00<000000?[`iP3jl>H00`3jl>H00`000?l0n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V
0080n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP130?[`iP030<f5?`3jl>H0n_3V
01<0n_3V00<0003o0?[`iP3jl>H0V`3jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP040?[`iP80
003o3@3jl>H00`000000n_3V0?[`iP020?[`iP030<f5?`3jl>H0n_3V04<0n_3V00<000000?[`iP3j
l>H0@P3jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP80003oWP3jl>H10?ooo`00V03jl>H00`000000n_3V
0?[`iP060?[`iP030000o`3jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0103jl>H00`3=QCl0n_3V
0?[`iP120?[`iP030000003jl>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H04@3jl>H00`000?l0n_3V
0?[`iP2N0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V00L0n_3V0P000?l80?[`iP030000003j
l>H0n_3V00H0n_3V00<0cHDo0?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP110?[`iP030<f5?`3j
l>H0n_3V0100n_3V0P000?nQ0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V00T0n_3V00<0003o
0?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP070?[`iP030<f5?`3jl>H0n_3V0400n_3V00<00000
0?[`iP3jl>H0@03jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP030000o`3jl>H0n_3V0:40n_3V0@3oool0
09P0n_3V00<000000?[`iP3jl>H02P3jl>H20000o`@0n_3V00<000000?[`iP3jl>H0203jl>H00`3=
QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H03`3jl>H20000
oj@0n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H0303jl>H01@000?l0n_3V0?[`iP3jl>H00000
00/0n_3V00<0cHDo0?[`iP3jl>H0?`3jl>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V
00h0n_3V00<0003o0?[`iP3jl>H0Y03jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP0=0?[`iP80
003o00<000000?[`iP3jl>H02`3jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03h0
n_3V00<0cHDo0?[`iP3jl>H03@3jl>H20000ojL0n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H0
3`3jl>H00`000000003o0?[`iP0;0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0
?@3jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP80003oZ@3jl>H10?ooo`00V03jl>H00`000000n_3V0?[`
iP0>0?[`iP040000003jl>H0n_3V0000o``0n_3V00<0cHDo0?[`iP3jl>H0?@3jl>H00`000000n_3V
0?[`iP0m0?[`iP030<f5?`3jl>H0n_3V00X0n_3V0P000?n[0?[`iP40oooo002H0?[`iP030000003j
l>H0n_3V00d0n_3V00<000000?[`iP3jl>H00P3jl>H20000o`/0n_3V0P3=QClm0?[`iP030000003j
l>H0n_3V03/0n_3V0P3=QCl<0?[`iP030000o`3jl>H0n_3V0:/0n_3V0@3oool009P0n_3V00<00000
0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP040?[`iP80003o2P3jl>H00`3=QCl0n_3V0?[`iP0k
0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H02P3jl>H20000ojh0n_3V0@3oool0
09P0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP070?[`iP030000o`3jl>H0n_3V
00P0n_3V00<0cHDo0?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V
00P0n_3V0P000?n`0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3j
l>H0203jl>H20000o`T0n_3V00<0cHDo0?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP0i0?[`iP03
0<f5?`3jl>H0n_3V00L0n_3V0P000?nb0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V00/0n_3V
00<000000?[`iP3jl>H02`3jl>H20000o`P0n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000000n_3V
0?[`iP0h0?[`iP030<f5?`3jl>H0n_3V00L0n_3V00<0003o0?[`iP3jl>H0/P3jl>H10?ooo`00V03j
l>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00h0n_3V00<0003o0?[`iP3jl>H01P3j
l>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H01P3j
l>H20000okD0n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0?
0?[`iP80003o1`3jl>H20<f5?cL0n_3V00<000000?[`iP3jl>H0=@3jl>H20<f5?`L0n_3V0P000?ng
0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H04P3jl>H20000
o`H0n_3V00<0cHDo0?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP0d0?[`iP030<f5?`3jl>H0n_3V
00D0n_3V0P000?ni0?[`iP40oooo002H0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3j
l>H0503jl>H00`000?l0n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V03@0n_3V00<000000?[`iP3j
l>H0=03jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000o`3jl>H0n_3V0;T0n_3V0@3oool009P0n_3V
00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0F0?[`iP80003o1@3jl>H20<f5?c@0n_3V
00<000000?[`iP3jl>H0<P3jl>H20<f5?`D0n_3V0P000?nl0?[`iP40oooo002H0?[`iP030000003j
l>H0n_3V00P0n_3V00<000000?[`iP3jl>H0603jl>H20000o`D0n_3V00<0cHDo0?[`iP3jl>H0<@3j
l>H00`000000n_3V0?[`iP0a0?[`iP030<f5?`3jl>H0n_3V00<0n_3V0P000?nn0?[`iP40oooo002H
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H06`3jl>H00`000?l0n_3V0?[`iP03
0?[`iP030<f5?`3jl>H0n_3V0300n_3V00<000000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP02
0?[`iP80003o`03jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V
01d0n_3V0P000?l40?[`iP030<f5?`3jl>H0n_3V02l0n_3V00<000000?[`iP3jl>H0;`3jl>H0103=
QCl0n_3V0?[`iP3jl>H20000ol80n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H01P3jl>H00`00
0000n_3V0?[`iP0O0?[`iP80003o0`3jl>H20<f5?bl0n_3V00<000000?[`iP3jl>H0;@3jl>H20<f5
?`<0n_3V00<0003o0?[`iP3jl>H0`P3jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP050?[`iP03
0000003jl>H0n_3V0280n_3V0P000?l30?[`iP030<f5?`3jl>H0n_3V02`0n_3V00<000000?[`iP3j
l>H0;03jl>H0103=QCl0n_3V0?[`iP3jl>H20000olD0n_3V0@3oool009P0n_3V00<000000?[`iP3j
l>H01@3jl>H00`000000n_3V0?[`iP0T0?[`iP80003o0P3jl>H20<f5?b`0n_3V00<000000?[`iP3j
l>H0:P3jl>H20<f5?`80n_3V0P000?o70?[`iP40oooo002H0?[`iP030000003jl>H0n_3V00@0n_3V
00<000000?[`iP3jl>H09`3jl>H20000o`80n_3V0P3=QClZ0?[`iP030000003jl>H0n_3V02P0n_3V
0P3=QCl20?[`iP80003ob@3jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP030?[`iP030000003j
l>H0n_3V02X0n_3V0P000?l20?[`iP030<f5?`3jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H09`3j
l>H00`3=QCl0n_3V0?[`iP020000ol/0n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H00`3jl>H0
0`000000n_3V0?[`iP0/0?[`iP80003o00<0n_3V0<f5?`3=QCl09`3jl>H00`000000n_3V0?[`iP0U
0?[`iP80cHDo00<0n_3V0000o`000?l0c@3jl>H10?ooo`00V03jl>H00`000000n_3V0?[`iP020?[`
iP030000003jl>H0n_3V02l0n_3V0`000?l20<f5?bD0n_3V00<000000?[`iP3jl>H08`3jl>H20<f5
?`030?[`iP000?l0003o0<l0n_3V0@3oool009P0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000
n_3V0?[`iP0b0?[`iP<0003o00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0Q0?[`iP80
cHDo00<0n_3V0000o`000?l0d@3jl>H10?ooo`00V03jl>H01@000000n_3V0?[`iP3jl>H0000003P0
n_3V0P000?l00`3=QCl0n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V01l0n_3V0P3=QCl30000om<0
n_3V0@3oool009P0n_3V00D000000?[`iP3jl>H0n_3V0000000j0?[`iP<0003o7`3jl>H00`000000
n_3V0?[`iP0M0?[`iP80cHDo0P000?oF0?[`iP40oooo002H0?[`iP040000003jl>H0n_3V000003h0
n_3V0`000?l00`3=QCl0n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V01T0n_3V0`3=QCl30000omP0
n_3V0@3oool009P0n_3V00<000000?[`iP000000@P3jl>H30000oaT0n_3V00<000000?[`iP3jl>H0
5`3jl>H00`3=QCl0003o0000o`020000om/0n_3V0@3oool009P0n_3V00<000000?[`iP000000A@3j
l>H40000oaD0n_3V00<000000?[`iP3jl>H04`3jl>H00`3=QCl0003o0000o`020000oml0n_3V0@3o
ool009L0n_3V0`00001:0?[`iP@0003o4@3jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`000?l0
003o0080003oh`3jl>H10?ooo`00UP3jl>H5000004d0n_3V10000?l=0?[`iP030000003jl>H0n_3V
00/0n_3V1@000?oW0?[`iP40oooo002F0<f5?`D00000D@3=QCl=0000o`03000000000?l0003o00/0
003oj`3=QCl10?[`iP40oooo002F0?[`iPD00000o`3jl>II0?[`iP40oooo002G0?[`iP<00000o`3j
l>IJ0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00;H0n_3V0P00
00000`1VHUh0c<Bk0?[`iP0[0?[`iP060=C<``1VHUh0000000000029Q7h0i=_BI@3jl>H01P3Dc<<0
IV9N000000000000RHAn0>CKdY`0n_3V0@3oool00;P0n_3V00<0IV9N0000003Le</0:`3jl>H01P1<
BDD0`k^c0?[`iP3/h]T0000008V4OVD0n_3V00H0C4U50<>k/`3jl>H0k>;I00000029Q7jL0?[`iP40
oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP040:nXX@1<BDD0000008V4OPL0
n_3V00H0g=C;07UeL0000000000008V4OP3<a;/20?[`iP040:nXX@1<BDD0000008V4OP80n_3V0P00
00020?[`iP80000000D0n_3V0<c4^`000000NGE`0?[`iP0200000080n_3V0P0000000`1VHUh0n_3V
0?[`iP070?[`iP8000000`3jl>H0103<a;/0C4U506IRGP3Tfm82000000030?[`iP000000000000<0
n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000000P3jl>H00`29
Q7h0IV9N0<c4^`02000000L0n_3V00D0g=C;07UeL0000000C4U50:BMUP020?[`iP040<c4^`1<BDD0
IV9N0>CKdP80000000<0n_3V000000000000103jl>H00`2TWIH000000:BMUP030?[`iP040:nXX@1<
BDD0000008V4OPL0n_3V00@0[jRQ04a9A@1<BDD0[jRQ0P3jl>H2000000H0n_3V0P0000001@3jl>H0
`k^c00000033^k<0n_3V0080000000D0n_3V0<c4^`1<BDD0C4U50:nXX@02000000030?[`iP000000
000000<0n_3V0P0000001@3jl>H0c<Bk04a9A@1<BDD0[jRQ00800000103jl>H2000000030>cRf@3j
l>H0k>;I008000000P3jl>H00`29Q7h0IV9N0<c4^`02000000030?[`iP00000000000080n_3V0P00
00020?[`iP040:nXX@1<BDD0000008V4OP80n_3V00L0k>;I09NAR`000000000007UeL03Tfm80n_3V
00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80000000L0n_3V0:nXX@00
0000`k^c0>CKdP000000RHAn00D0n_3V00D0i=_B0000002GTH/0n_3V0;VbZP02000000080?[`iP2_
Z:4000000<>k/`3Tfm80000008V4OP3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0<c4^`0000000P0000000`3Tfm80n_3V0?[`iP060?[`iP8000000`3jl>H0101V
HUh000000>CKdP2i/ZX2000000030?[`iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V
000000000000n_3V0P0000020?[`iP80000000D0n_3V0:BMUP000000`k^c0:BMUP02000000H0n_3V
00`0i=_B0000002GTH/0n_3V0=C<``000000RHAn0?[`iP1VHUh000000>CKdP2i/ZX2000000030?[`
iP000000000000@0n_3V0`000000203/h]T0n_3V0:nXX@000000`k^c0>CKdP000000RHAn1@3jl>H0
1`2i/ZX000000<>k/`33^k<000000;VbZP3jl>H00P0000060?[`iP80000000D0n_3V09NAR`000000
Ui6;0?[`iP02000000050?[`iP1<BDD000000>CKdP33^k<00P0000000`3jl>H00000000000030?[`
iP80000000D0n_3V04a9A@000000i=_B0<>k/`02000000@0n_3V00`0RHAn0000003Dc<<0n_3V0=C<
``000000RHAn0?[`iP2TWIH000000<>k/`2TWIH2000000030?[`iP00000000000080n_3V0P000000
3`3jl>H0[jRQ00000033^k<0i=_B00000029Q7h0n_3V07UeL0000000i=_B0>cRf@000000IV9N0?[`
iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP1<BDD0
000000T0n_3V00<0Ui6;0000003Le</00P3jl>H2000000030?[`iP1<BDD0000000D0n_3V0P000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000060?[`iP2GTH/0000008V4OP000000[jRQ
203jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H200000080n_3V
0P000000103jl>H000000000003jl>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP80
00001P3jl>H00`2GTH/000000>CKdP050?[`iP8000000P3jl>H2000000030?[`iP000000000000<0
n_3V00P0^K:Z00000029Q7h000000;VbZP3jl>H0C4U5000000T0n_3V00L0IV9N0000003jl>H0n_3V
0000001VHUh0n_3V008000001P3jl>H2000000050?[`iP1<BDD0000004a9A@3jl>H00P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000000`3jl>H2000000030?[`iP0000000000
0080n_3V0P0000040?[`iP030:nXX@000000000000<0000000@0[jRQ0?[`iP1<BDD000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H0C4U5000000070?[`iP050=C<``2TWIH0
000004a9A@3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P000000
0`3jl>H0000000000004000000D0n_3V00<0C4U50000003jl>H00P3jl>H2000000030?[`iP000000
000000@0000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
1P3jl>H0C4U50000003/h]T0000006IRGPP0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`
iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000H0n_3V0P0000060?[`iP8000000P3jl>H200000003
0?[`iP000000000000<0n_3V0P1<BDD0103/h]T0C4U504a9A@3jl>H6000000D0n_3V0P0000020?[`
iP80000000<0n_3V0000000000001P3jl>H2000000050>CKdP000000Ui6;0000003Tfm800P000000
1@3jl>H0c<Bk0000002GTH/0i=_B0080000000<0n_3V0000000000000`3jl>H2000000050?[`iP3<
a;/0000009NAR`3Tfm800P0000040?[`iP080=C<``000000RHAn0?[`iP2GTH/000000=C<``3jl>H2
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000000010000000
0`3jl>H0c<Bk04a9A@020000000304a9A@3<a;/0n_3V00800000Q03jl>H10?ooo`00P`3jl>H20000
00<0n_3V0P0000020?[`iP80000000<0n_3V04a9A@0000000P3jl>H00`000000IV9N0?[`iP040?[`
iP8000000P3jl>H3000000030?[`iP1<BDD000000080n_3V00<0000006IRGP3jl>H00P0000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000070=cDb`000000RHAn0?[`iP29Q7h000000>CK
dP070?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP8000000P3j
l>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000030?[`iP1<BDD000000080n_3V
0P0000060?[`iP8000001P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP090<c4
^`000000Y9fF0?[`iP2TWIH000000<c4^`1<BDD000000080n_3V00<0000006IRGP3jl>H0103jl>H0
1`1VHUh000000?[`iP3jl>H0000006IRGP3jl>H00P0000060?[`iP80000000D0c<Bk0000003Le</0
00000<c4^`0200000080n_3V00<0g=C;0:nXX@1iMG000P0000000`3jl>H00000000000030?[`iP80
00000P3jl>H00`3Le</0[jRQ07UeL002000000D0n_3V00D0000004a9A@3jl>H0C4U5000000020?[`
iP0404a9A@000000n_3V0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP1<BDD0
00000080n_3V00L0000006IRGP3jl>H0C4U50000001iMG00c<Bk00<0n_3V0P0000240?[`iP40oooo
00230?[`iP8000000`3jl>H20000000;0:BMUP3Tfm80000006IRGP3jl>H0^K:Z00000033^k<0c<Bk
0000002i/ZX01@3jl>H00`1<BDD000000?[`iP050?[`iP070;VbZP000000`k^c0<c4^`000000^K:Z
0?[`iP02000000050;VbZP3Tfm80000004a9A@3jl>H00P0000020?[`iP80000000L0[jRQ00000033
^k<0n_3V0<>k/`000000[jRQ00L0n_3V0P0000030?[`iP8000000P3jl>H2000000040?[`iP000000
00000=C<``80n_3V0P0000001@2i/ZX0i=_B0000001<BDD0n_3V0080000000`0n_3V000000000000
^K:Z0>CKdP000000C4U50?[`iP2TWIH000000<>k/`2TWIH2000000H0n_3V00<0C4U50000003jl>H0
1@3jl>H200000080n_3V0P0000004P3jl>H000000000003Dc<<0n_3V06IRGP000000k>;I0?[`iP3/
h]T0000006IRGP2i/ZX000000<>k/`3<a;/000000;VbZPD0n_3V00L0^K:Z00000033^k<0`k^c0000
002i/ZX0n_3V008000001P3jl>H2000000050:BMUP1VHUh0n_3V06IRGP2TWIH00P000000203jl>H0
NGE`0=C<``3jl>H0i=_B0000001<BDD0n_3V0P0000000`3Dc<<0n_3V0?[`iP02000000070?[`iP1i
MG00e<c30?[`iP3Tfm80000004a9A@050?[`iP0507UeL0000000c<Bk0000001VHUh00P3jl>H0102T
WIH000000<>k/`2TWIH20000000F0?[`iP00000000000;VbZP3Tfm80000004a9A@3jl>H0^K:Z0000
0033^k<0c<Bk0000002i/ZX0n_3V06IRGP000000n_3V0>CKdP000000NGE`0?[`iP800000Q03jl>H1
0?ooo`00P`3jl>H2000000<0n_3V0P000000103Le</0RHAn04a9A@3<a;/20?[`iP040:nXX@000000
00000:nXX@H0n_3V00<0Ui6;0000003Tfm801P3jl>H0102_Z:4000000000002_Z:420?[`iP800000
00@0c<Bk07UeL01<BDD0c<Bk100000002P3jl>H000000000001VHUh000000>cRf@3jl>H0k>;I0000
001VHUh70?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H0000000000029Q7h0NGE`0?[`
iP80000000D0c<Bk07UeL01<BDD0c<Bk0?[`iP02000000070?[`iP00000000000<c4^`1iMG00C4U5
0<c4^`020?[`iP0308V4OP1VHUh0c<Bk008000001P3jl>H00`2GTH/000000>CKdP050?[`iP800000
0P3jl>H2000000040?[`iP000000000008V4OP80000000P0RHAn0?[`iP3jl>H0n_3V08V4OP000000
g=C;0:nXX@80000000<0[jRQ0?[`iP3jl>H01@3jl>H01@2_Z:40C4U50000002_Z:40n_3V00@00000
1@3jl>H20000000506IRGP2TWIH0n_3V09NAR`1VHUh00P0000000`3jl>H0i=_B08V4OP0200000003
06IRGP3Dc<<0n_3V0080000000<0RHAn07UeL03jl>H00P0000000`3jl>H0i=_B08V4OP0200000003
06IRGP3Dc<<0n_3V00@0n_3V00D0Y9fF00000029Q7h000000:BMUP030?[`iP0308V4OP1VHUh0c<Bk
0080000000L0n_3V000000000000c<Bk07UeL01<BDD0c<Bk0080n_3V00@0[jRQ000000000000[jRQ
0P3jl>H01`3Tfm80NGE`000000000000RHAn0>CKdP3jl>H00P0000240?[`iP40oooo00230?[`iP80
00000`3jl>H200000100n_3V00L0i=_B0000002GTH/0n_3V0=C<``000000NGE`00l0n_3V0P000002
0?[`iP8000003P3jl>H2000002`0n_3V00L0i=_B0000002GTH/0n_3V0=C<``000000RHAn02D0n_3V
0P0000060?[`iP<0000000<0c<Bk0?[`iP33^k<00`00000K0?[`iP050<c4^`000000000000000033
^k<0Y03jl>H10?ooo`00P@3jl>H6000000030?[`iP00000000000140n_3V00H0g=C;07UeL0000000
000009NAR`3/h]T?0?[`iP040=cDb`29Q7h0n_3V0?[`iP800000303jl>H6000001@0n_3V0P00000E
0?[`iP050=cDb`1iMG0000000000002TWIH09P3jl>H0103<a;/0IV9N00000029Q7h40?[`iP<00000
00<0k>;I0?[`iP3Le</00`00000=0?[`iP800000303jl>H01@3/h]T00000000000000000i=_B01h0
n_3V0P0000240?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.34783 .38333 L
s
.34783 .05 m
.34783 .38333 L
s
.37407 .32584 m
.34783 .32584 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.34783 .38333 Mdot
.37407 .32584 Mdot
.34783 .32584 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00:d0n_3V00<000000?[`iP3jl>H0?@3jl>H:0<f5
?`80n_3V00<000000?[`iP3jl>H02P3=QCo]0?[`iP40oooo002]0?[`iP030000003jl>H0n_3V03L0
n_3V1P3=QCl;0?[`iP800000303jl>H70<f5?nH0n_3V0@3oool00:d0n_3V00<000000?[`iP3jl>H0
=@3jl>H20<f5?a40n_3V0P00000C0?[`iP80cHDoi03jl>H10?ooo`00[@3jl>H00`000000n_3V0?[`
iP0a0?[`iP@0cHDo4P3jl>H00`000000n_3V0000000E0?[`iP<0cHDoh@3jl>H10?ooo`00[@3jl>H0
0`000000n_3V0?[`iP0]0?[`iP@0cHDo5P3jl>H00`000000n_3V0000000H0?[`iP@0cHDog@3jl>H1
0?ooo`00[@3jl>H00`000000n_3V0?[`iP0[0?[`iP80cHDo6@3jl>H010000000n_3V0?[`iP00000L
0?[`iP80cHDof`3jl>H10?ooo`00[@3jl>H00`000000n_3V0?[`iP0Y0?[`iP80cHDo6`3jl>H01000
0000n_3V0?[`iP00000N0?[`iP80cHDof@3jl>H10?ooo`00[@3jl>H00`000000n_3V0?[`iP0W0?[`
iP80cHDo703jl>H01@000000n_3V0?[`iP3jl>H000000200n_3V0P3=QCoG0?[`iP40oooo002]0?[`
iP030000003jl>H0n_3V02D0n_3V0P3=QClN0?[`iP050000003jl>H0n_3V0?[`iP0000008P3jl>H2
0<f5?mD0n_3V0@3oool00:d0n_3V00<000000?[`iP3jl>H08`3jl>H20<f5?al0n_3V00<000000?[`
iP3jl>H00P3jl>H00`000000n_3V0?[`iP0R0?[`iP80cHDod`3jl>H10?ooo`00[@3jl>H00`000000
n_3V0?[`iP0Q0?[`iP80cHDo8@3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V02@0
n_3V0P3=QCoA0?[`iP40oooo002]0?[`iP030000003jl>H0n_3V01l0n_3V0P3=QClS0?[`iP030000
003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H09P3jl>H20<f5?ll0n_3V0@3oool00:d0n_3V00<0
00000?[`iP3jl>H07P3jl>H00`3=QCl0n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V00<0n_3V00<0
00000?[`iP3jl>H0:03jl>H00`3=QCl0n_3V0?[`iP3<0?[`iP40oooo002]0?[`iP030000003jl>H0
n_3V01`0n_3V0P3=QClU0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0:@3jl>H2
0<f5?l`0n_3V0@3oool00:d0n_3V00<000000?[`iP3jl>H06P3jl>H20<f5?bH0n_3V00<000000?[`
iP3jl>H0103jl>H00`000000n_3V0?[`iP0[0?[`iP80cHDobP3jl>H10?ooo`00[@3jl>H00`000000
n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0103jl>H00`000000
n_3V0?[`iP0]0?[`iP030<f5?`3jl>H0n_3V0<L0n_3V0@3oool00:d0n_3V00<000000?[`iP3jl>H0
5`3jl>H20<f5?bP0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0^0?[`iP80cHDo
a`3jl>H10?ooo`00[@3jl>H00`000000n_3V0?[`iP0F0?[`iP030<f5?`3jl>H0n_3V02P0n_3V00<0
00000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0`0?[`iP030<f5?`3jl>H0n_3V0<@0n_3V0@3o
ool00:d0n_3V00<000000?[`iP3jl>H05@3jl>H00`3=QCl0n_3V0?[`iP0X0?[`iP030000003jl>H0
n_3V00H0n_3V00<000000?[`iP3jl>H0<@3jl>H00`3=QCl0n_3V0?[`iP330?[`iP40oooo002]0?[`
iP030000003jl>H0n_3V01@0n_3V00<0cHDo0?[`iP3jl>H0:@3jl>H00`000000n_3V0?[`iP060?[`
iP030000003jl>H0n_3V0380n_3V00<0cHDo0?[`iP3jl>H0`P3jl>H10?ooo`00[@3jl>H00`000000
n_3V0?[`iP0B0?[`iP80cHDo:`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V03<0
n_3V0P3=QCo20?[`iP40oooo002]0?[`iP030000003jl>H0n_3V0140n_3V00<0cHDo0?[`iP3jl>H0
:`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V03@0n_3V00<0cHDo0?[`iP3jl>H0
`03jl>H10?ooo`00[@3jl>H00`000000n_3V0?[`iP0@0?[`iP030<f5?`3jl>H0n_3V02/0n_3V00<0
00000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0e0?[`iP030<f5?`3jl>H0n_3V0;l0n_3V0@3o
ool00:d0n_3V00<000000?[`iP3jl>H03`3jl>H00`3=QCl0n_3V0?[`iP0/0?[`iP030000003jl>H0
n_3V00P0n_3V00<000000?[`iP3jl>H0=P3jl>H20<f5?kl0n_3V0@3oool00:d0n_3V00<000000?[`
iP3jl>H03P3jl>H00`3=QCl0n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`
iP3jl>H0>03jl>H00`3=QCl0n_3V0?[`iP2l0?[`iP40oooo002]0?[`iP030000003jl>H0n_3V00d0
n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V03T0
n_3V00<0cHDo0?[`iP3jl>H0^`3jl>H10?ooo`00[@3jl>H00`000000n_3V0?[`iP0<0?[`iP030<f5
?`3jl>H0n_3V02h0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0j0?[`iP030<f5
?`3jl>H0n_3V0;X0n_3V0@3oool00:d0n_3V00<000000?[`iP3jl>H02`3jl>H00`3=QCl0n_3V0?[`
iP0^0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`
iP2j0?[`iP40oooo002]0?[`iP030000003jl>H0n_3V00X0n_3V00<0cHDo0?[`iP3jl>H0;`3jl>H0
0`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V03/0n_3V00<0cHDo0?[`iP3jl>H0^@3jl>H1
0?ooo`00[@3jl>H00`000000n_3V0?[`iP090?[`iP030<f5?`3jl>H0n_3V02l0n_3V00<000000?[`
iP3jl>H02`3jl>H00`000000n_3V0?[`iP0l0?[`iP80cHDo^@3jl>H10?ooo`00[@3jl>H00`000000
n_3V0?[`iP080?[`iP030<f5?`3jl>H0n_3V0300n_3V00<000000?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP0m0?[`iP030<f5?`3jl>H0n_3V0;L0n_3V0@3oool00:d0n_3V00<000000?[`iP3jl>H0
203jl>H00`3=QCl0n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0
?P3jl>H00`3=QCl0n_3V0?[`iP2f0?[`iP40oooo002]0?[`iP030000003jl>H0n_3V00L0n_3V00<0
cHDo0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V03l0n_3V00<0
cHDo0?[`iP3jl>H0]@3jl>H10?ooo`00[@3jl>H00`000000n_3V0?[`iP060?[`iP030<f5?`3jl>H0
n_3V0300n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0
n_3V0;D0n_3V0@3oool00:d0n_3V00<000000?[`iP3jl>H01P3jl>H00`3=QCl0n_3V0?[`iP0`0?[`
iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H0@03jl>H00`3=QCl0n_3V0?[`iP2d0?[`
iP40oooo002]0?[`iP030000003jl>H0n_3V00D0n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000
n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V0440n_3V00<0cHDo0?[`iP3jl>H0/`3jl>H10?ooo`00
[@3jl>H00`000000n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V0340n_3V00<000000?[`iP3jl>H0
3P3jl>H00`000000n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V0;80n_3V0@3oool00:d0n_3V00<0
00000?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP0b0?[`iP030000003jl>H0n_3V00h0n_3V00<0
00000?[`iP3jl>H0@`3jl>H00`3=QCl0n_3V0?[`iP2a0?[`iP40oooo002]0?[`iP030000003jl>H0
n_3V0080n_3V00<0cHDo0?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0
n_3V04<0n_3V00<0cHDo0?[`iP3jl>H0/@3jl>H10?ooo`00[@3jl>H00`000000n_3V0?[`iP020?[`
iP030<f5?`3jl>H0n_3V0380n_3V00<000000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP140?[`
iP030<f5?`3jl>H0n_3V0;00n_3V0@3oool00:d0n_3V00D000000?[`iP3jl>H0n_3V0<f5?`0d0?[`
iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0A03jl>H00`3=QCl0n_3V0?[`iP2`0?[`
iP40oooo002]0?[`iP050000003jl>H0n_3V0?[`iP3=QCl0=03jl>H00`000000n_3V0?[`iP0@0?[`
iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H0[`3jl>H10?ooo`00[@3jl>H010000000
n_3V0?[`iP3=QCld0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=
QCl0n_3V0?[`iP2_0?[`iP40oooo002]0?[`iP040000003jl>H0n_3V0<f5?c@0n_3V00<000000?[`
iP3jl>H04@3jl>H00`000000n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool00:d0
n_3V00<000000?[`iP3=QCl0=03jl>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V04H0
n_3V00<0cHDo0?[`iP3jl>H0[P3jl>H10?ooo`00[@3jl>H00`000000n_3V0<f5?`0d0?[`iP030000
003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0A`3jl>H00`3=QCl0n_3V0?[`iP2]0?[`iP40oooo
002]0?[`iP030000003=QCl0n_3V03<0n_3V00<000000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`
iP180?[`iP030<f5?`3jl>H0n_3V0:`0n_3V0@3oool00:d0n_3V00<000000?[`iP3jl>H0<`3jl>H0
0`000000n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V04P0n_3V00<0cHDo0?[`iP3jl>H0[03jl>H1
0?ooo`00[@3jl>H00`000000n_3V0?[`iP0c0?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`
iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP2[0?[`iP40oooo002/0?[`iP030<f5?`000000n_3V03<0
n_3V00<000000?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V0:/0
n_3V0@3oool00:`0n_3V00<0cHDo0000003jl>H0<`3jl>H00`000000n_3V0?[`iP0D0?[`iP030000
003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H0ZP3jl>H10?ooo`000P000?nZ0?[`iP030<f5?`00
0000n_3V0380n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3j
l>H0n_3V0:L0n_3V0P000?l10?[`iP40oooo00020?[`iP<0003oY`3jl>H00`3=QCl000000?[`iP0b
0?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2T
0?[`iP<0003o0`3jl>H10?ooo`001@3jl>H40000oj80n_3V00<0cHDo0?[`iP000000<P3jl>H00`00
0000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H0X03jl>H40000
o`H0n_3V0@3oool000T0n_3V0`000?nO0?[`iP030<f5?`3jl>H000000380n_3V00<000000?[`iP3j
l>H05P3jl>H00`000000n_3V0?[`iP1;0?[`iP030<f5?`3jl>H0n_3V09`0n_3V0`000?l:0?[`iP40
oooo000<0?[`iP<0003oV`3jl>H0103=QCl0n_3V0?[`iP00000a0?[`iP030000003jl>H0n_3V01L0
n_3V00<000000?[`iP3jl>H0B`3jl>H00`3=QCl0n_3V0?[`iP2I0?[`iP<0003o3@3jl>H10?ooo`00
3`3jl>H40000oiL0n_3V00@0cHDo0?[`iP3jl>H00000<@3jl>H00`000000n_3V0?[`iP0G0?[`iP03
0000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0U03jl>H40000oa00n_3V0@3oool001<0n_3V
0`000?nD0?[`iP040<f5?`3jl>H0n_3V00000300n_3V00<000000?[`iP3jl>H0603jl>H00`000000
n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V0940n_3V0`000?lD0?[`iP40oooo000F0?[`iP<0003o
T@3jl>H0103=QCl0n_3V0?[`iP00000`0?[`iP030000003jl>H0n_3V01P0n_3V00<000000?[`iP3j
l>H0C03jl>H00`3=QCl0n_3V0?[`iP2>0?[`iP<0003o5`3jl>H10?ooo`006@3jl>H30000ohd0n_3V
00D0cHDo0?[`iP3jl>H0n_3V0000000`0?[`iP030000003jl>H0n_3V01P0n_3V00<000000?[`iP3j
l>H0C03jl>H00`3=QCl0n_3V0?[`iP2;0?[`iP<0003o6P3jl>H10?ooo`00703jl>H30000ohX0n_3V
00D0cHDo0?[`iP3jl>H0n_3V0000000_0?[`iP030000003jl>H0n_3V01T0n_3V00<000000?[`iP3j
l>H0C@3jl>H00`3=QCl0n_3V0?[`iP270?[`iP<0003o7@3jl>H10?ooo`007`3jl>H40000ohH0n_3V
00D0cHDo0?[`iP3jl>H0n_3V0000000_0?[`iP030000003jl>H0n_3V01T0n_3V00<000000?[`iP3j
l>H0C@3jl>H00`3=QCl0n_3V0?[`iP240?[`iP<0003o803jl>H10?ooo`008`3jl>H30000oh<0n_3V
00D0cHDo0?[`iP3jl>H0n_3V0000000^0?[`iP030000003jl>H0n_3V01X0n_3V00<000000?[`iP3j
l>H0C@3jl>H00`3=QCl0n_3V0?[`iP210?[`iP<0003o8`3jl>H10?ooo`009P3jl>H30000ogl0n_3V
00<0cHDo0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V01X0n_3V
00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP1n0?[`iP<0003o9P3jl>H10?ooo`00:@3j
l>H30000og`0n_3V00<0cHDo0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0[0?[`iP030000003j
l>H0n_3V01/0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP1j0?[`iP<0003o:@3j
l>H10?ooo`00;03jl>H20000ogX0n_3V00<0cHDo0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0[
0?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP1h
0?[`iP80003o;03jl>H10?ooo`00;P3jl>H20000ogP0n_3V00<0cHDo0?[`iP3jl>H00P3jl>H00`00
0000n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=
QCl0n_3V0?[`iP1f0?[`iP80003o;P3jl>H10?ooo`00<03jl>H30000og@0n_3V00<0cHDo0?[`iP3j
l>H00`3jl>H00`000000n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V01`0n_3V00<000000?[`iP3j
l>H0CP3jl>H00`3=QCl0n_3V0?[`iP1c0?[`iP<0003o<03jl>H10?ooo`00<`3jl>H20000og80n_3V
00<0cHDo0?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0Y0?[`iP030000003jl>H0n_3V01d0n_3V
00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1`0?[`iP80003o<`3jl>H10?ooo`00=@3j
l>H20000og00n_3V00<0cHDo0?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0Y0?[`iP030000003j
l>H0n_3V01d0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1^0?[`iP80003o=@3j
l>H10?ooo`00=`3jl>H30000ofd0n_3V00<0cHDo0?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0X
0?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1[
0?[`iP<0003o=`3jl>H10?ooo`00>P3jl>H20000of/0n_3V00<0cHDo0?[`iP3jl>H00`3jl>H00`00
0000n_3V0?[`iP0X0?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=
QCl0n_3V0?[`iP1Y0?[`iP80003o>P3jl>H10?ooo`00?03jl>H20000ofT0n_3V00<0cHDo0?[`iP3j
l>H00`3jl>H00`000000n_3V0?[`iP0X0?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3j
l>H0C`3jl>H00`3=QCl0n_3V0?[`iP1W0?[`iP80003o?03jl>H10?ooo`00?P3jl>H30000ofD0n_3V
00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V01l0n_3V
00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1T0?[`iP<0003o?P3jl>H10?ooo`00@@3j
l>H20000of<0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0W0?[`iP030000003j
l>H0n_3V01l0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1Q0?[`iP80003o@@3j
l>H10?ooo`00@`3jl>H20000of40n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0V
0?[`iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1O
0?[`iP80003o@`3jl>H10?ooo`00A@3jl>H20000oel0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`00
0000n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0D03jl>H00`3=
QCl0n_3V0?[`iP1M0?[`iP80003oA@3jl>H10?ooo`00A`3jl>H20000oed0n_3V00<0cHDo0?[`iP3j
l>H0103jl>H00`000000n_3V0?[`iP0U0?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3j
l>H0D03jl>H00`3=QCl0n_3V0?[`iP1K0?[`iP80003oA`3jl>H10?ooo`00B@3jl>H30000oeX0n_3V
00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0U0?[`iP030000003jl>H0n_3V0240n_3V
00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1I0?[`iP80003oB@3jl>H10?ooo`00C03j
l>H20000oeP0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0T0?[`iP030000003j
l>H0n_3V0280n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1G0?[`iP80003oB`3j
l>H10?ooo`00CP3jl>H20000oeH0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0T
0?[`iP030000003jl>H0n_3V0240n_3V0`00001A0?[`iP030<f5?`3jl>H0n_3V05D0n_3V0P000?m=
0?[`iP40oooo001@0?[`iP80003oE03jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000003jl>H0n_3V
02<0n_3V00<000000?[`iP3jl>H08@3jl>H500000500n_3V00<0cHDo0?[`iP3jl>H0D`3jl>H20000
odl0n_3V0@3oool00580n_3V0P000?mB0?[`iP030<f5?`3jl>H0n_3V00@0n_3V00<000000?[`iP3j
l>H08`3jl>H00`000000n_3V0?[`iP0Q0?[`iPD00000D03jl>H00`3=QCl0n_3V0?[`iP1A0?[`iP80
003oD@3jl>H10?ooo`00E03jl>H20000oe00n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V
0?[`iP0S0?[`iP030000003jl>H0n_3V0240n_3V1@00001@0?[`iP030<f5?`3jl>H0n_3V04l0n_3V
0P000?mC0?[`iP40oooo001F0?[`iP80003oCP3jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000003j
l>H0n_3V0280n_3V00<000000?[`iP3jl>H08`3jl>H300000540n_3V00<0cHDo0?[`iP3jl>H0C@3j
l>H20000oeD0n_3V0@3oool005P0n_3V0P000?m<0?[`iP030<f5?`3jl>H0n_3V00@0n_3V00<00000
0?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP0T0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo
0?[`iP3jl>H0B`3jl>H20000oeL0n_3V0@3oool005X0n_3V00<0003o0?[`iP3jl>H0B@3jl>H00`3=
QCl0n_3V0?[`iP040?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H09@3jl>H00`00
0000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04T0n_3V0P000?mI0?[`iP40oooo001K0?[`iP80
003oB@3jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3j
l>H09@3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04L0n_3V0P000?mK0?[`iP40
oooo001M0?[`iP80003oA`3jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000003jl>H0n_3V0200n_3V
00<000000?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04D0n_3V
0P000?mM0?[`iP40oooo001O0?[`iP80003oA@3jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000003j
l>H0n_3V0200n_3V00<000000?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3j
l>H0n_3V04<0n_3V0P000?mO0?[`iP40oooo001Q0?[`iP030000o`3jl>H0n_3V0480n_3V00<0cHDo
0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V02L0n_3V00<00000
0?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP110?[`iP80003oH@3jl>H10?ooo`00HP3jl>H20000
od80n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V
02L0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP80003oH`3jl>H10?oo
o`00I03jl>H20000od00n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0N0?[`iP03
0000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP80
003oI@3jl>H10?ooo`00IP3jl>H20000ocl0n_3V00<0cHDo0?[`iP3jl>H00`3jl>H00`000000n_3V
0?[`iP0N0?[`iP030000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V
0?[`iP0l0?[`iP80003oI`3jl>H10?ooo`00J03jl>H00`000?l0n_3V0?[`iP0l0?[`iP030<f5?`3j
l>H0n_3V00<0n_3V00<000000?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP0X0?[`iP030000003j
l>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H00`000?l0n_3V0?[`iP1W0?[`iP40oooo001Y
0?[`iP80003o?03jl>H00`3=QCl0n_3V0?[`iP030?[`iP030000003jl>H0n_3V01d0n_3V00<00000
0?[`iP3jl>H0:@3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V03T0n_3V0P000?mZ
0?[`iP40oooo001[0?[`iP80003o>P3jl>H00`3=QCl0n_3V0?[`iP030?[`iP030000003jl>H0n_3V
01d0n_3V00<000000?[`iP3jl>H0:@3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V
03P0n_3V00<0003o0?[`iP3jl>H0JP3jl>H10?ooo`00K@3jl>H00`000?l0n_3V0?[`iP0g0?[`iP03
0<f5?`3jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP0Z0?[`iP03
0000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0=P3jl>H20000ofd0n_3V0@3oool006h0n_3V
0P000?lg0?[`iP030<f5?`3jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0703jl>H00`000000n_3V
0?[`iP0Z0?[`iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0=@3jl>H20000ofl0n_3V
0@3oool00700n_3V0P000?lf0?[`iP030<f5?`3jl>H0n_3V0080n_3V00<000000?[`iP3jl>H06`3j
l>H00`000000n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0=03j
l>H00`000?l0n_3V0?[`iP1_0?[`iP40oooo001b0?[`iP030000o`3jl>H0n_3V03<0n_3V00<0cHDo
0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0K0?[`iP030000003jl>H0n_3V02/0n_3V00<00000
0?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0b0?[`iP80003oLP3jl>H10?ooo`00L`3jl>H20000
oc<0n_3V00<0cHDo0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V
02`0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0a0?[`iP030000o`3jl>H0n_3V
0780n_3V0@3oool007D0n_3V0P000?la0?[`iP030<f5?`3jl>H0n_3V0080n_3V00<000000?[`iP3j
l>H06P3jl>H00`000000n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3j
l>H0<03jl>H20000ogD0n_3V0@3oool007L0n_3V00<0003o0?[`iP3jl>H0;`3jl>H01@3=QCl0n_3V
0?[`iP3jl>H0000001/0n_3V00<000000?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP1=0?[`iP03
0<f5?`3jl>H0n_3V02h0n_3V0P000?mg0?[`iP40oooo001h0?[`iP80003o;`3jl>H01@3=QCl0n_3V
0?[`iP3jl>H0000001/0n_3V00<000000?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP1=0?[`iP03
0<f5?`3jl>H0n_3V02d0n_3V00<0003o0?[`iP3jl>H0M`3jl>H10?ooo`00NP3jl>H20000obd0n_3V
00D0cHDo0?[`iP3jl>H0n_3V0000000J0?[`iP030000003jl>H0n_3V02h0n_3V00<000000?[`iP3j
l>H0C@3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP80003oNP3jl>H10?ooo`00O03jl>H00`000?l0n_3V
0?[`iP0Z0?[`iP050<f5?`3jl>H0n_3V0?[`iP0000006P3jl>H00`000000n_3V0?[`iP0^0?[`iP03
0000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`000?l0n_3V0?[`iP1j0?[`iP40
oooo001m0?[`iP80003o:`3jl>H0103=QCl0n_3V0?[`iP00000J0?[`iP030000003jl>H0n_3V02h0
n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0Y0?[`iP80003oO@3jl>H10?ooo`00
O`3jl>H20000obT0n_3V00@0cHDo0?[`iP3jl>H000006@3jl>H00`000000n_3V0?[`iP0_0?[`iP03
0000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H09`3jl>H20000ogl0n_3V0@3oool00840n_3V
00<0003o0?[`iP3jl>H09P3jl>H0103=QCl0n_3V0?[`iP00000I0?[`iP030000003jl>H0n_3V02l0
n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0V0?[`iP030000o`3jl>H0n_3V07l0
n_3V0@3oool00880n_3V0P000?lV0?[`iP040<f5?`3jl>H0n_3V000001P0n_3V00<000000?[`iP3j
l>H0<03jl>H00`000000n_3V0?[`iP1;0?[`iP030<f5?`3jl>H0n_3V02D0n_3V0P000?n20?[`iP40
oooo00240?[`iP80003o9@3jl>H00`3=QCl0n_3V0000000H0?[`iP030000003jl>H0n_3V0300n_3V
00<000000?[`iP3jl>H0B`3jl>H00`3=QCl0n_3V0?[`iP0T0?[`iP030000o`3jl>H0n_3V0880n_3V
0@3oool008H0n_3V00<0003o0?[`iP3jl>H08P3jl>H00`3=QCl0n_3V0000000G0?[`iP030000003j
l>H0n_3V0340n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0S0?[`iP80003oQ@3j
l>H10?ooo`00Q`3jl>H20000ob<0n_3V00<0cHDo0000003jl>H05P3jl>H00`000000n_3V0?[`iP0a
0?[`iP030000003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H08@3jl>H20000ohL0n_3V0@3oool0
08T0n_3V0P000?lQ0?[`iP030<f5?`000000n_3V01D0n_3V00<000000?[`iP3jl>H0<P3jl>H00`00
0000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0200n_3V00<0003o0?[`iP3jl>H0Q`3jl>H10?oo
o`00R`3jl>H20000oal0n_3V00<0cHDo0000003jl>H05@3jl>H00`000000n_3V0?[`iP0b0?[`iP03
0000003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H20000ohX0n_3V0@3oool008d0n_3V
00<0003o0?[`iP3jl>H0703jl>H00`3=QCl000000?[`iP0D0?[`iP030000003jl>H0n_3V03<0n_3V
00<000000?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP0N0?[`iP030000o`3jl>H0n_3V08X0n_3V
0@3oool008h0n_3V0P000?lM0?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0<`3j
l>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V01`0n_3V0P000?n=0?[`iP40oooo002@
0?[`iP80003o6`3jl>H00`000000cHDo0?[`iP0C0?[`iP030000003jl>H0n_3V03<0n_3V00<00000
0?[`iP3jl>H0B03jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP80003oS`3jl>H10?ooo`00TP3jl>H00`00
0?l0n_3V0?[`iP0H0?[`iP030000003=QCl0n_3V0180n_3V00<000000?[`iP3jl>H0=03jl>H00`00
0000n_3V0?[`iP170?[`iP030<f5?`3jl>H0n_3V01/0n_3V00<0003o0?[`iP3jl>H0S`3jl>H10?oo
o`00T`3jl>H20000oaP0n_3V00<000000?[`iP3=QCl04P3jl>H00`000000n_3V0?[`iP0d0?[`iP03
0000003jl>H0n_3V04L0n_3V00<0cHDo0?[`iP3jl>H06@3jl>H20000oi80n_3V0@3oool009D0n_3V
00<0003o0?[`iP3jl>H05@3jl>H00`000000n_3V0<f5?`0A0?[`iP030000003jl>H0n_3V03D0n_3V
00<000000?[`iP3jl>H0AP3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000o`3jl>H0n_3V0980n_3V
0@3oool009H0n_3V0P000?lE0?[`iP040000003jl>H0n_3V0<f5?a00n_3V00<000000?[`iP3jl>H0
=@3jl>H00`000000n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V01L0n_3V0P000?nE0?[`iP40oooo
002H0?[`iP030000o`3jl>H0n_3V0180n_3V00@000000?[`iP3jl>H0cHDo3`3jl>H00`000000n_3V
0?[`iP0f0?[`iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H05`3jl>H00`000?l0n_3V
0?[`iP2E0?[`iP40oooo002I0?[`iP80003o4P3jl>H01@000000n_3V0?[`iP3jl>H0cHDo00h0n_3V
00<000000?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V01D0n_3V
0P000?nH0?[`iP40oooo002K0?[`iP030000o`3jl>H0n_3V00l0n_3V00D000000?[`iP3jl>H0n_3V
0<f5?`0=0?[`iP030000003jl>H0n_3V03L0n_3V00<000000?[`iP3jl>H0A03jl>H00`3=QCl0n_3V
0?[`iP0E0?[`iP030000o`3jl>H0n_3V09P0n_3V0@3oool009`0n_3V0P000?l?0?[`iP030000003j
l>H0n_3V0080n_3V00<0cHDo0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0g0?[`iP030000003j
l>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H20000oi/0n_3V0@3oool009h0n_3V00<0003o
0?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V00P0n_3V00<00000
0?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP130?[`iP030<f5?`3jl>H0n_3V01<0n_3V00<0003o
0?[`iP3jl>H0V`3jl>H10?ooo`00W`3jl>H20000o``0n_3V00<000000?[`iP3jl>H00`3jl>H00`3=
QCl0n_3V0?[`iP080?[`iP030000003jl>H0n_3V03P0n_3V00<000000?[`iP3jl>H0@P3jl>H00`3=
QCl0n_3V0?[`iP0B0?[`iP80003oWP3jl>H10?ooo`00X@3jl>H00`000?l0n_3V0?[`iP090?[`iP03
0000003jl>H0n_3V00@0n_3V00<0cHDo0?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP0i0?[`iP03
0000003jl>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H04@3jl>H00`000?l0n_3V0?[`iP2N0?[`iP40
oooo002R0?[`iP80003o2@3jl>H00`000000n_3V0?[`iP050?[`iP030<f5?`3jl>H0n_3V00D0n_3V
00<000000?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP110?[`iP030<f5?`3jl>H0n_3V0100n_3V
0P000?nQ0?[`iP40oooo002T0?[`iP030000o`3jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H01P3j
l>H00`3=QCl0n_3V0?[`iP040?[`iP030000003jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H0@03j
l>H00`3=QCl0n_3V0?[`iP0@0?[`iP030000o`3jl>H0n_3V0:40n_3V0@3oool00:D0n_3V0P000?l6
0?[`iP030000003jl>H0n_3V00H0n_3V00<0cHDo0?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0j
0?[`iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H03`3jl>H20000oj@0n_3V0@3oool0
0:L0n_3V00<0003o0?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP070?[`iP030<f5?`3jl>H0n_3V
0080n_3V00<000000?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V
00h0n_3V00<0003o0?[`iP3jl>H0Y03jl>H10?ooo`00Z03jl>H20000o`<0n_3V00<000000?[`iP3j
l>H0203jl>H0103=QCl0n_3V0?[`iP00000m0?[`iP030000003jl>H0n_3V03h0n_3V00<0cHDo0?[`
iP3jl>H03@3jl>H20000ojL0n_3V0@3oool00:X0n_3V0P000?l3000000T0n_3V00@0cHDo00000000
00000000?@3jl>H00`000000n_3V0?[`iP0m0?[`iP030<f5?`3jl>H0n_3V00`0n_3V0P000?nY0?[`
iP40oooo002[0?[`iPD00000203jl>H5000003`0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3=QCl0
n_3V0?[`iP0:0?[`iP80003oZ`3jl>H10?ooo`00Z`3jl>HB000003`0n_3V00<000000?[`iP3jl>H0
>`3jl>H20<f5?``0n_3V00<0003o0?[`iP3jl>H0Z`3jl>H10?ooo`00Z`3jl>H5000000030000o`3j
l>H0n_3V00D0n_3V1@00000l0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H02P3j
l>H20000ojh0n_3V0@3oool00:`0n_3V0`0000020?[`iP030000o`3jl>H0n_3V00D0n_3V0`000000
0`3=QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H0203jl>H2
0000ok00n_3V0@3oool00:d0n_3V00<000000?[`iP3jl>H00P3jl>H20000o`@0n_3V00<000000?[`
iP3jl>H00P3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V03T0n_3V00<0cHDo0?[`
iP3jl>H01`3jl>H20000ok80n_3V0@3oool00:d0n_3V00<000000?[`iP3jl>H0103jl>H20000o`80
n_3V00<000000?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V03P0
n_3V00<0cHDo0?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP2b0?[`iP40oooo002]0?[`iP030000
003jl>H0n_3V00H0n_3V00<0003o0?[`iP0000001P3jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000
003jl>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H01P3jl>H20000okD0n_3V0@3oool00:d0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`000000003o0?[`iP060?[`iP80cHDo=`3jl>H00`000000n_3V0?[`
iP0e0?[`iP80cHDo1`3jl>H20000okL0n_3V0@3oool00:d0n_3V00<000000?[`iP3jl>H01`3jl>H0
10000000n_3V0000o`000?l60?[`iP030<f5?`3jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0=03j
l>H00`3=QCl0n_3V0?[`iP050?[`iP80003o^@3jl>H10?ooo`00[@3jl>H00`000000n_3V0?[`iP06
0?[`iP030000003jl>H0n_3V0080n_3V00<0003o0?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP0d
0?[`iP030000003jl>H0n_3V03@0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000?l0n_3V0?[`iP2i
0?[`iP40oooo002]0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H00`3jl>H20000
o`D0n_3V0P3=QCld0?[`iP030000003jl>H0n_3V0380n_3V0P3=QCl50?[`iP80003o_03jl>H10?oo
o`00[@3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V00H0n_3V0P000?l50?[`iP03
0<f5?`3jl>H0n_3V0340n_3V00<000000?[`iP3jl>H0<@3jl>H00`3=QCl0n_3V0?[`iP030?[`iP80
003o_P3jl>H10?ooo`00[@3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V00P0n_3V
00<0003o0?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V0300n_3V
00<0cHDo0?[`iP3jl>H00P3jl>H20000ol00n_3V0@3oool00:d0n_3V00<000000?[`iP3jl>H0103j
l>H00`000000n_3V0?[`iP0:0?[`iP80003o103jl>H00`3=QCl0n_3V0?[`iP0_0?[`iP030000003j
l>H0n_3V02l0n_3V00@0cHDo0?[`iP3jl>H0n_3V0P000?o20?[`iP40oooo002]0?[`iP030000003j
l>H0n_3V00@0n_3V00<000000?[`iP3jl>H0303jl>H20000o`<0n_3V0P3=QCl_0?[`iP030000003j
l>H0n_3V02d0n_3V0P3=QCl30?[`iP030000o`3jl>H0n_3V0<80n_3V0@3oool00:d0n_3V00<00000
0?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0?0?[`iP80003o0`3jl>H00`3=QCl0n_3V0?[`iP0/
0?[`iP030000003jl>H0n_3V02`0n_3V00@0cHDo0?[`iP3jl>H0n_3V0P000?o50?[`iP40oooo002]
0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H04@3jl>H20000o`80n_3V0P3=QCl/
0?[`iP030000003jl>H0n_3V02X0n_3V0P3=QCl20?[`iP80003oa`3jl>H10?ooo`00[@3jl>H00`00
0000n_3V0?[`iP020?[`iP030000003jl>H0n_3V01@0n_3V0P000?l20?[`iP80cHDo:P3jl>H00`00
0000n_3V0?[`iP0X0?[`iP80cHDo0P3jl>H20000olT0n_3V0@3oool00:d0n_3V00<000000?[`iP3j
l>H00P3jl>H00`000000n_3V0?[`iP0F0?[`iP80003o0P3jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP03
0000003jl>H0n_3V02L0n_3V00<0cHDo0?[`iP3jl>H00P000?o;0?[`iP40oooo002]0?[`iP030000
003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0603jl>H20000o`030?[`iP3=QCl0cHDo02L0n_3V
00<000000?[`iP3jl>H09@3jl>H20<f5?`030?[`iP000?l0003o0<d0n_3V0@3oool00:d0n_3V00D0
00000?[`iP3jl>H0n_3V0000000M0?[`iP<0003o0P3=QClU0?[`iP030000003jl>H0n_3V02<0n_3V
0P3=QCl00`3jl>H0003o0000o`3?0?[`iP40oooo002]0?[`iP050000003jl>H0n_3V0?[`iP000000
803jl>H30000o`030<f5?`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H08@3jl>H20<f5?`030?[`
iP000?l0003o0=40n_3V0@3oool00:d0n_3V00@000000?[`iP3jl>H00000903jl>H20000o`030<f5
?`3jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H07`3jl>H20<f5?`<0003od`3jl>H10?ooo`00[@3j
l>H010000000n_3V0?[`iP00000V0?[`iP<0003o7`3jl>H00`000000n_3V0?[`iP0M0?[`iP80cHDo
0P000?oF0?[`iP40oooo002]0?[`iP030000003jl>H0000002X0n_3V0`000?l00`3=QCl0n_3V0?[`
iP0I0?[`iP030000003jl>H0n_3V01T0n_3V0`3=QCl30000omP0n_3V0@3oool00:d0n_3V00<00000
0?[`iP000000;@3jl>H30000oaT0n_3V00<000000?[`iP3jl>H05`3jl>H00`3=QCl0003o0000o`02
0000om/0n_3V0@3oool00:d0n_3V0P00000a0?[`iP@0003o5@3jl>H00`000000n_3V0?[`iP0C0?[`
iP030<f5?`000?l0003o0080003og`3jl>H10?ooo`00[03jl>H3000003D0n_3V10000?lA0?[`iP03
0000003jl>H0n_3V00l0n_3V00<0cHDo0000o`000?l00P000?oS0?[`iP40oooo002[0?[`iPD00000
>03jl>H40000o`d0n_3V00<000000?[`iP3jl>H02`3jl>H50000onL0n_3V0@3oool00:/0cHDo1@00
000l0<f5?`d0003o00<000000000o`000?l02`000?o[0<f5?`40n_3V0@3oool00:/0n_3V1@00003o
0?[`iT@0n_3V0@3oool00:`0n_3V0`00003o0?[`iTD0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00]P3jl>H20000000306IRGP3<a;/0n_3V02/0n_3V00H0e<c306IR
GP000000000008V4OP3Tfm9U0?[`iP060=C<``1VHUh0000000000029Q7h0i=_BW03jl>H10?ooo`00
^03jl>H00`1VHUh000000=cDb`0[0?[`iP0604a9A@33^k<0n_3V0>cRf@000000RHAnI@3jl>H01P1<
BDD0`k^c0?[`iP3/h]T0000008V4OY`0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2
00000080n_3V00@0[jRQ04a9A@000000RHAn1`3jl>H01P3Le</0NGE`000000000000RHAn0<c4^`80
n_3V00@0[jRQ04a9A@000000RHAn0P3jl>H200000080n_3V0P0000001@3jl>H0c<Bk0000001iMG00
n_3V008000000P3jl>H20000000306IRGP3jl>H0n_3V00L0n_3V0P0000030?[`iP040<c4^`1<BDD0
IV9N0>CKdP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000
003jl>H200000080n_3V0P0000020?[`iP0308V4OP1VHUh0c<Bk008000001`3jl>H01@3Le</0NGE`
0000001<BDD0Y9fF0080n_3V00@0c<Bk04a9A@1VHUh0i=_B0P0000000`3jl>H00000000000040?[`
iP030:BMUP000000Y9fF00<0n_3V00@0[jRQ04a9A@000000RHAn1`3jl>H0102_Z:40C4U504a9A@2_
Z:420?[`iP8000001P3jl>H2000000050?[`iP33^k<000000<>k/`3jl>H00P0000001@3jl>H0c<Bk
04a9A@1<BDD0[jRQ0080000000<0n_3V0000000000000`3jl>H2000000050?[`iP3<a;/0C4U504a9
A@2_Z:400P0000040?[`iP80000000<0k>;I0?[`iP3/h]T00P0000020?[`iP0308V4OP1VHUh0c<Bk
0080000000<0n_3V0000000000000P3jl>H200000080n_3V00@0[jRQ04a9A@000000RHAn0P3jl>H0
1`3/h]T0Ui6;000000000000NGE`0>CKdP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3j
l>H200000080n_3V0P0000001`3jl>H0[jRQ00000033^k<0i=_B00000029Q7h01@3jl>H01@3Tfm80
000009NAR`3jl>H0^K:Z0080000000P0n_3V0:nXX@000000`k^c0>CKdP000000RHAn0?[`iP800000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0c<Bk00000002000000030>CK
dP3jl>H0n_3V00H0n_3V0P0000030?[`iP0406IRGP000000i=_B0;VbZP80000000<0n_3V00000000
00000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P0000001@3j
l>H0Y9fF00000033^k<0Y9fF008000001P3jl>H0303Tfm80000009NAR`3jl>H0e<c300000029Q7h0
n_3V06IRGP000000i=_B0;VbZP80000000<0n_3V000000000000103jl>H3000000080>cRf@3jl>H0
[jRQ00000033^k<0i=_B00000029Q7h50?[`iP070;VbZP000000`k^c0<>k/`000000^K:Z0?[`iP02
000000H0n_3V0P0000001@3jl>H0Ui6;0000002GTH/0n_3V0080000000D0n_3V04a9A@000000i=_B
0<>k/`02000000030?[`iP000000000000<0n_3V0P0000001@3jl>H0C4U50000003Tfm80`k^c0080
0000103jl>H03029Q7h000000=C<``3jl>H0e<c300000029Q7h0n_3V0:BMUP000000`k^c0:BMUP80
000000<0n_3V0000000000000P3jl>H20000000?0?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP3j
l>H0NGE`0000003Tfm80k>;I0000001VHUh0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0
n_3V0P0000020?[`iP80000000<0n_3V04a9A@0000002@3jl>H00`2GTH/000000=cDb`020?[`iP80
000000<0n_3V04a9A@0000001@3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000H0n_3V09NAR`000000RHAn0000002_Z:480?[`iP8000000`3jl>H200000080n_3V0P000000
0`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3j
l>H2000000030?[`iP1<BDD000000080n_3V0P0000060?[`iP0309NAR`000000i=_B00D0n_3V0P00
00020?[`iP80000000<0n_3V0000000000000`3jl>H0202i/ZX0000008V4OP000000^K:Z0?[`iP1<
BDD000002@3jl>H01`1VHUh000000?[`iP3jl>H0000006IRGP3jl>H00P0000060?[`iP80000000D0
n_3V04a9A@000000C4U50?[`iP02000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000030?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V00<0[jRQ000000000000
0`000000102_Z:40n_3V04a9A@0000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP1<BDD0000000L0n_3V00D0e<c30:BMUP000000C4U50?[`iP02000008@0n_3V0@3oool008<0
n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP000000000000@000001@3jl>H00`1<BDD0
00000?[`iP020?[`iP80000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000060?[`iP1<BDD000000>cRf@000000IV9N203jl>H2
000000<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000
103jl>H000000000003jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP8000001P3j
l>H2000000H0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H204a9A@040>cRf@1<
BDD0C4U50?[`iPH000001@3jl>H200000080n_3V0P0000000`3jl>H00000000000060?[`iP800000
00D0i=_B0000002GTH/000000>CKdP02000000050?[`iP3<a;/0000009NAR`3Tfm800P0000000`3j
l>H00000000000030?[`iP80000000D0n_3V0<c4^`000000Ui6;0>CKdP02000000@0n_3V00P0e<c3
00000029Q7h0n_3V09NAR`000000e<c30?[`iP8000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H0000000000004000000030?[`iP3<a;/0C4U50080000000<0C4U50<c4^`3j
l>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0C4U5
000000020?[`iP030000001VHUh0n_3V00@0n_3V0P0000020?[`iP<0000000<0n_3V04a9A@000000
0P3jl>H00`000000IV9N0?[`iP0200000080n_3V0P0000000`3jl>H00000000000020?[`iP800000
00L0g=C;00000029Q7h0n_3V08V4OP000000i=_B00L0n_3V0P0000030?[`iP8000000P3jl>H20000
00030?[`iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P000002
0?[`iP80000000<0n_3V04a9A@0000000P3jl>H2000000H0n_3V0P0000060?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V00T0c<Bk0000002TWIH0n_3V0:BMUP000000c<Bk04a9A@00
00000P3jl>H00`000000IV9N0?[`iP040?[`iP0706IRGP000000n_3V0?[`iP000000IV9N0?[`iP02
000000H0n_3V0P0000001@3<a;/000000=cDb`000000c<Bk008000000P3jl>H00`3Le</0[jRQ07Ue
L002000000030?[`iP000000000000<0n_3V0P0000020?[`iP030=cDb`2_Z:40NGE`008000001@3j
l>H01@000000C4U50?[`iP1<BDD000000080n_3V00@0C4U50000003jl>H0n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V04a9A@0000000P3jl>H01`000000IV9N0?[`iP1<BDD00000
07UeL03<a;/00`3jl>H2000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP80000000/0Y9fF0>CK
dP000000IV9N0?[`iP2i/ZX000000<>k/`3<a;/000000;VbZP050?[`iP0304a9A@000000n_3V00D0
n_3V00L0^K:Z00000033^k<0c<Bk0000002i/ZX0n_3V0080000000D0^K:Z0>CKdP000000C4U50?[`
iP0200000080n_3V0P0000001`2_Z:4000000<>k/`3jl>H0`k^c0000002_Z:401`3jl>H2000000<0
n_3V0P0000020?[`iP80000000@0n_3V000000000000e<c30P3jl>H2000000050;VbZP3Tfm800000
04a9A@3jl>H00P000000303jl>H000000000002i/ZX0i=_B0000001<BDD0n_3V0:BMUP000000`k^c
0:BMUP8000001P3jl>H00`1<BDD000000?[`iP050?[`iP8000000P3jl>H20000000B0?[`iP000000
00000=C<``3jl>H0IV9N0000003/h]T0n_3V0>cRf@000000IV9N0;VbZP000000`k^c0<c4^`000000
^K:Z1@3jl>H01`2i/ZX000000<>k/`33^k<000000;VbZP3jl>H00P0000060?[`iP80000000D0Y9fF
06IRGP3jl>H0IV9N0:BMUP02000000080?[`iP1iMG00e<c30?[`iP3Tfm80000004a9A@3jl>H20000
00030=C<``3jl>H0n_3V0080000000L0n_3V07UeL03Dc<<0n_3V0>CKdP000000C4U500D0n_3V00D0
NGE`0000003<a;/0000006IRGP020?[`iP040:BMUP000000`k^c0:BMUP80000001H0n_3V00000000
0000^K:Z0>CKdP000000C4U50?[`iP2i/ZX000000<>k/`3<a;/000000;VbZP3jl>H0IV9N0000003j
l>H0i=_B0000001iMG00n_3V0P0000240?[`iP40oooo00230?[`iP8000000`3jl>H2000000040=cD
b`29Q7h0C4U50<c4^`80n_3V00@0[jRQ000000000000[jRQ1P3jl>H00`2GTH/000000>CKdP060?[`
iP040:nXX@00000000000:nXX@80n_3V0P000000103<a;/0NGE`04a9A@3<a;/40000000:0?[`iP00
0000000006IRGP000000k>;I0?[`iP3/h]T0000006IRGPL0n_3V0P0000030?[`iP8000000P3jl>H2
000000060?[`iP000000000008V4OP1iMG00n_3V0P0000001@3<a;/0NGE`04a9A@3<a;/0n_3V0080
000000L0n_3V000000000000c<Bk07UeL01<BDD0c<Bk0080n_3V00<0RHAn06IRGP3<a;/00P000006
0?[`iP0309NAR`000000i=_B00D0n_3V0P0000020?[`iP80000000@0n_3V000000000000RHAn0P00
00002029Q7h0n_3V0?[`iP3jl>H0RHAn0000003Le</0[jRQ0P0000000`2_Z:40n_3V0?[`iP050?[`
iP050:nXX@1<BDD000000:nXX@3jl>H0100000050?[`iP80000000D0IV9N0:BMUP3jl>H0Ui6;06IR
GP02000000030?[`iP3Tfm80RHAn0080000000<0IV9N0=C<``3jl>H00P0000000`29Q7h0NGE`0?[`
iP02000000030?[`iP3Tfm80RHAn0080000000<0IV9N0=C<``3jl>H0103jl>H01@2TWIH0000008V4
OP000000Y9fF00<0n_3V00<0RHAn06IRGP3<a;/00P0000001`3jl>H000000000003<a;/0NGE`04a9
A@3<a;/00P3jl>H0102_Z:4000000000002_Z:420?[`iP070>CKdP1iMG00000000000029Q7h0i=_B
0?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP800000403jl>H01`3Tfm80000009NA
R`3jl>H0e<c30000001iMG003`3jl>H200000080n_3V0P00000>0?[`iP800000;03jl>H01`3Tfm80
000009NAR`3jl>H0e<c300000029Q7h09@3jl>H2000000H0n_3V0`0000000`3<a;/0n_3V0<>k/`03
000001/0n_3V00D0c<Bk00000000000000000<>k/`2T0?[`iP40oooo00210?[`iPH0000000<0n_3V
0000000000004@3jl>H01P3Le</0NGE`000000000000Ui6;0>cRf@l0n_3V00@0g=C;08V4OP3jl>H0
n_3V0P00000<0?[`iPH00000503jl>H2000001D0n_3V00D0g=C;07UeL000000000000:BMUP0V0?[`
iP040<c4^`1VHUh0000008V4OP@0n_3V0`0000000`3/h]T0n_3V0=cDb`03000000d0n_3V0P00000<
0?[`iP050>cRf@00000000000000003Tfm807P3jl>H2000008@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.3913 .38333 L
s
.3913 .05 m
.3913 .38333 L
s
.40175 .3513 m
.3913 .3513 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.3913 .38333 Mdot
.40175 .3513 Mdot
.3913 .3513 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00<<0n_3V00<000000?[`iP3jl>H09`3jl>H:0<f5
?`80n_3V00<000000?[`iP3jl>H02P3=QCo]0?[`iP40oooo00330?[`iP030000003jl>H0n_3V0240
n_3V1P3=QCl;0?[`iP800000303jl>H70<f5?nH0n_3V0@3oool00<<0n_3V00<000000?[`iP3jl>H0
7`3jl>H20<f5?a40n_3V0P00000C0?[`iP80cHDoi03jl>H10?ooo`00``3jl>H00`000000n_3V0?[`
iP0K0?[`iP@0cHDo4`3jl>H2000001D0n_3V0`3=QCoQ0?[`iP40oooo00330?[`iP030000003jl>H0
n_3V01L0n_3V103=QClF0?[`iP030000003jl>H0000001P0n_3V103=QCoM0?[`iP40oooo00330?[`
iP030000003jl>H0n_3V01D0n_3V0P3=QClJ0?[`iP030000003jl>H0000001`0n_3V0P3=QCoK0?[`
iP40oooo00330?[`iP030000003jl>H0n_3V01<0n_3V0P3=QClL0?[`iP030000003jl>H0000001h0
n_3V0P3=QCoI0?[`iP40oooo00330?[`iP030000003jl>H0n_3V0140n_3V0P3=QClM0?[`iP040000
003jl>H0n_3V00000200n_3V0P3=QCoG0?[`iP40oooo00330?[`iP030000003jl>H0n_3V00l0n_3V
0P3=QClO0?[`iP040000003jl>H0n_3V00000280n_3V0P3=QCoE0?[`iP40oooo00330?[`iP030000
003jl>H0n_3V00d0n_3V0P3=QClQ0?[`iP040000003jl>H0n_3V000002@0n_3V0P3=QCoC0?[`iP40
oooo00330?[`iP030000003jl>H0n_3V00/0n_3V0P3=QClR0?[`iP050000003jl>H0n_3V0?[`iP00
00009P3jl>H20<f5?m40n_3V0@3oool00<<0n_3V00<000000?[`iP3jl>H02@3jl>H20<f5?b@0n_3V
00D000000?[`iP3jl>H0n_3V0000000X0?[`iP80cHDoc`3jl>H10?ooo`00``3jl>H00`000000n_3V
0?[`iP080?[`iP030<f5?`3jl>H0n_3V02@0n_3V00D000000?[`iP3jl>H0n_3V0000000Z0?[`iP03
0<f5?`3jl>H0n_3V0<`0n_3V0@3oool00<<0n_3V00<000000?[`iP3jl>H01P3jl>H20<f5?bH0n_3V
00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0Y0?[`iP80cHDoc03jl>H10?ooo`00``3j
l>H00`000000n_3V0?[`iP040?[`iP80cHDo:03jl>H00`000000n_3V0?[`iP020?[`iP030000003j
l>H0n_3V02/0n_3V0P3=QCo:0?[`iP40oooo00330?[`iP030000003jl>H0n_3V00<0n_3V00<0cHDo
0?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V02d0n_3V00<0cHDo
0?[`iP3jl>H0a`3jl>H10?ooo`00``3jl>H010000000n_3V0?[`iP3jl>H20<f5?bX0n_3V00<00000
0?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0^0?[`iP80cHDoa`3jl>H10?ooo`00``3jl>H01000
0000n_3V0?[`iP3=QCl/0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0<03jl>H0
0`3=QCl0n_3V0?[`iP340?[`iP40oooo00330?[`iP030000003jl>H0cHDo02d0n_3V00<000000?[`
iP3jl>H00`3jl>H00`000000n_3V0?[`iP0a0?[`iP030<f5?`3jl>H0n_3V0<<0n_3V0@3oool00<<0
n_3V00<000000<f5?`3jl>H0;03jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V0380
n_3V00<0cHDo0?[`iP3jl>H0`P3jl>H10?ooo`00`P3jl>H00`3=QCl000000?[`iP0]0?[`iP030000
003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0<`3jl>H20<f5?l80n_3V0@3oool00<40n_3V00<0
cHDo0?[`iP000000;P3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V03@0n_3V00<0
cHDo0?[`iP3jl>H0`03jl>H10?ooo`00`03jl>H0103=QCl0n_3V0?[`iP00000^0?[`iP030000003j
l>H0n_3V00@0n_3V00<000000?[`iP3jl>H0=@3jl>H00`3=QCl0n_3V0?[`iP2o0?[`iP40oooo002o
0?[`iP050<f5?`3jl>H0n_3V0?[`iP000000;@3jl>H00`000000n_3V0?[`iP050?[`iP030000003j
l>H0n_3V03H0n_3V0P3=QCno0?[`iP40oooo002n0?[`iP030<f5?`3jl>H0n_3V0080n_3V00<00000
0?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V03P0n_3V00<0cHDo
0?[`iP3jl>H0_03jl>H10?ooo`00_@3jl>H00`3=QCl0n_3V0?[`iP030?[`iP030000003jl>H0n_3V
02/0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0i0?[`iP030<f5?`3jl>H0n_3V
0;/0n_3V0@3oool00;`0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0Z0?[`iP03
0000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`iP2j0?[`iP40
oooo002k0?[`iP030<f5?`3jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0:P3jl>H00`000000n_3V
0?[`iP060?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H0^P3jl>H10?ooo`00^P3j
l>H00`3=QCl0n_3V0?[`iP060?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H01P3j
l>H00`000000n_3V0?[`iP0k0?[`iP030<f5?`3jl>H0n_3V0;T0n_3V0@3oool00;T0n_3V00<0cHDo
0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0Y0?[`iP030000003jl>H0n_3V00L0n_3V00<00000
0?[`iP3jl>H0?03jl>H20<f5?kT0n_3V0@3oool00;P0n_3V00<0cHDo0?[`iP3jl>H0203jl>H00`00
0000n_3V0?[`iP0Y0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3=
QCl0n_3V0?[`iP2g0?[`iP40oooo002h0?[`iP030<f5?`3jl>H0n_3V00P0n_3V00<000000?[`iP3j
l>H0:@3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V03h0n_3V00<0cHDo0?[`iP3j
l>H0]P3jl>H10?ooo`00]`3jl>H00`3=QCl0n_3V0?[`iP090?[`iP030000003jl>H0n_3V02P0n_3V
00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V0;D0n_3V
0@3oool00;H0n_3V00<0cHDo0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0X0?[`iP030000003j
l>H0n_3V00P0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=QCl0n_3V0?[`iP2e0?[`iP40oooo002f
0?[`iP030<f5?`3jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP08
0?[`iP030000003jl>H0n_3V0400n_3V00<0cHDo0?[`iP3jl>H0]03jl>H10?ooo`00]@3jl>H00`3=
QCl0n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP110?[`iP030<f5?`3jl>H0n_3V0;<0n_3V0@3oool00;@0n_3V00<0cHDo0?[`iP3j
l>H0303jl>H00`000000n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3j
l>H0@P3jl>H00`3=QCl0n_3V0?[`iP2b0?[`iP40oooo002c0?[`iP030<f5?`3jl>H0n_3V00d0n_3V
00<000000?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V04<0n_3V
00<0cHDo0?[`iP3jl>H0/@3jl>H10?ooo`00/P3jl>H00`3=QCl0n_3V0?[`iP0>0?[`iP030000003j
l>H0n_3V02H0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP130?[`iP030<f5?`3j
l>H0n_3V0;40n_3V0@3oool00;80n_3V00<0cHDo0?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0V
0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0A03jl>H00`3=QCl0n_3V0?[`iP2`
0?[`iP40oooo002a0?[`iP030<f5?`3jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H09P3jl>H00`00
0000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H0/03jl>H10?oo
o`00/@3jl>H00`3=QCl0n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V02D0n_3V00<000000?[`iP3j
l>H02`3jl>H00`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V0:l0n_3V0@3oool00;00n_3V
00<0cHDo0?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0U0?[`iP030000003jl>H0n_3V00/0n_3V
00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP2_0?[`iP40oooo002`0?[`iP030<f5?`3j
l>H0n_3V0100n_3V00<000000?[`iP3jl>H09@3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003j
l>H0n_3V04H0n_3V00<0cHDo0?[`iP3jl>H0[P3jl>H10?ooo`00[`3jl>H00`3=QCl0n_3V0?[`iP0A
0?[`iP030000003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP16
0?[`iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool00:l0n_3V00<0cHDo0?[`iP3jl>H04@3jl>H00`00
0000n_3V0?[`iP0T0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0A`3jl>H00`3=
QCl0n_3V0?[`iP2]0?[`iP40oooo002^0?[`iP030<f5?`3jl>H0n_3V0180n_3V00<000000?[`iP3j
l>H0903jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V04P0n_3V00<0cHDo0?[`iP3j
l>H0[03jl>H10?ooo`00[@3jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V02<0n_3V
00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP180?[`iP030<f5?`3jl>H0n_3V0:`0n_3V
0@3oool00:d0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP0S0?[`iP030000003j
l>H0n_3V00d0n_3V00<000000?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP2[0?[`iP40oooo002/
0?[`iP030<f5?`3jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP0=
0?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3jl>H0Z`3jl>H10?ooo`00[03jl>H00`3=
QCl0n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V0280n_3V00<000000?[`iP3jl>H03P3jl>H00`00
0000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:X0n_3V0@3oool00080003oZP3jl>H00`3=QCl0
n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V0280n_3V00<000000?[`iP3jl>H03P3jl>H00`000000
n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:L0n_3V0P000?l10?[`iP40oooo00020?[`iP<0003o
Y`3jl>H00`3=QCl0n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V0280n_3V00<000000?[`iP3jl>H0
3P3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:@0n_3V0`000?l30?[`iP40oooo
00050?[`iP@0003oXP3jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V0240n_3V00<0
00000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0:00n_3V1000
0?l60?[`iP40oooo00090?[`iP<0003oW`3jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP030000003jl>H0
n_3V0240n_3V00<000000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP1;0?[`iP030<f5?`3jl>H0
n_3V09`0n_3V0`000?l:0?[`iP40oooo000<0?[`iP<0003oV`3jl>H00`3=QCl0n_3V0?[`iP0F0?[`
iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP1;0?[`
iP030<f5?`3jl>H0n_3V09T0n_3V0`000?l=0?[`iP40oooo000?0?[`iP@0003oU`3jl>H00`3=QCl0
n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0403jl>H00`000000
n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V09@0n_3V10000?l@0?[`iP40oooo000C0?[`iP<0003o
U03jl>H00`3=QCl0n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0
403jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V0940n_3V0`000?lD0?[`iP40oooo
000F0?[`iP<0003oT@3jl>H00`3=QCl0n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V0200n_3V00<0
00000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V08h0n_3V0`00
0?lG0?[`iP40oooo000I0?[`iP<0003oS@3jl>H00`3=QCl0n_3V0?[`iP0G0?[`iP030000003jl>H0
n_3V01l0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0
n_3V08/0n_3V0`000?lJ0?[`iP40oooo000L0?[`iP<0003oRP3jl>H00`3=QCl0n_3V0?[`iP0G0?[`
iP030000003jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP1=0?[`
iP030<f5?`3jl>H0n_3V08L0n_3V0`000?lM0?[`iP40oooo000O0?[`iP@0003oQP3jl>H00`3=QCl0
n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000
n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V08@0n_3V0`000?lP0?[`iP40oooo000S0?[`iP<0003o
P`3jl>H00`3=QCl0n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0
4@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V0840n_3V0`000?lS0?[`iP40oooo
000V0?[`iP<0003oO`3jl>H00`3=QCl0n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V01h0n_3V00<0
00000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V07h0n_3V0`00
0?lV0?[`iP40oooo000Y0?[`iP<0003oO03jl>H00`3=QCl0n_3V0?[`iP0H0?[`iP030000003jl>H0
n_3V01h0n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0
n_3V07X0n_3V0`000?lY0?[`iP40oooo000/0?[`iP80003oNP3jl>H00`3=QCl0n_3V0?[`iP0H0?[`
iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP1>0?[`
iP030<f5?`3jl>H0n_3V07P0n_3V0P000?l/0?[`iP40oooo000^0?[`iP80003oN03jl>H00`3=QCl0
n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V01d0n_3V00<000000?[`iP3jl>H04`3jl>H00`000000
n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V07H0n_3V0P000?l^0?[`iP40oooo000`0?[`iP<0003o
M03jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V01d0n_3V00<000000?[`iP3jl>H0
4`3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V07<0n_3V0`000?l`0?[`iP40oooo
000c0?[`iP80003oLP3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V01d0n_3V00<0
00000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V0700n_3V0P00
0?lc0?[`iP40oooo000e0?[`iP80003oL03jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000003jl>H0
n_3V01`0n_3V00<000000?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0
n_3V06h0n_3V0P000?le0?[`iP40oooo000g0?[`iP<0003oK@3jl>H00`3=QCl0n_3V0?[`iP0I0?[`
iP030000003jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP1?0?[`
iP030<f5?`3jl>H0n_3V06/0n_3V0`000?lg0?[`iP40oooo000j0?[`iP80003oJ`3jl>H00`3=QCl0
n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H0503jl>H00`000000
n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06T0n_3V0P000?lj0?[`iP40oooo000l0?[`iP80003o
J@3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0
5@3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06L0n_3V0P000?ll0?[`iP40oooo
000n0?[`iP<0003oI@3jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V01/0n_3V00<0
00000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06@0n_3V0`00
0?ln0?[`iP40oooo00110?[`iP80003oH`3jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0
n_3V01/0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0
n_3V0640n_3V0P000?m10?[`iP40oooo00130?[`iP80003oH@3jl>H00`3=QCl0n_3V0?[`iP0J0?[`
iP030000003jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP1@0?[`
iP030<f5?`3jl>H0n_3V05l0n_3V0P000?m30?[`iP40oooo00150?[`iP80003oG`3jl>H00`3=QCl0
n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H05P3jl>H00`000000
n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05d0n_3V0P000?m50?[`iP40oooo00170?[`iP80003o
G@3jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H0
5P3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05/0n_3V0P000?m70?[`iP40oooo
00190?[`iP<0003oFP3jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V01T0n_3V00<0
00000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05T0n_3V0P00
0?m90?[`iP40oooo001<0?[`iP80003oF03jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0
n_3V01T0n_3V00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0
n_3V05L0n_3V0P000?m;0?[`iP40oooo001>0?[`iP80003oEP3jl>H00`3=QCl0n_3V0?[`iP0J0?[`
iP030000003jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H05P3jl>H300000540n_3V00<0cHDo0?[`
iP3jl>H0E@3jl>H20000odd0n_3V0@3oool00500n_3V0P000?mD0?[`iP030<f5?`3jl>H0n_3V01X0
n_3V00<000000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP0F0?[`iPD00000D03jl>H00`3=QCl0
n_3V0?[`iP1C0?[`iP80003oC`3jl>H10?ooo`00DP3jl>H20000oe80n_3V00<0cHDo0?[`iP3jl>H0
6P3jl>H00`000000n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V01H0n_3V1@00001@0?[`iP030<f5
?`3jl>H0n_3V0540n_3V0P000?mA0?[`iP40oooo001D0?[`iP80003oD03jl>H00`3=QCl0n_3V0?[`
iP0J0?[`iP030000003jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H05P3jl>H500000500n_3V00<0
cHDo0?[`iP3jl>H0C`3jl>H20000oe<0n_3V0@3oool005H0n_3V0P000?m>0?[`iP030<f5?`3jl>H0
n_3V01X0n_3V00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP0H0?[`iP<00000D@3jl>H0
0`3=QCl0n_3V0?[`iP1=0?[`iP80003oE@3jl>H10?ooo`00F03jl>H20000od`0n_3V00<0cHDo0?[`
iP3jl>H06P3jl>H00`000000n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V01T0n_3V00<000000?[`
iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP80003oE`3jl>H10?ooo`00FP3jl>H00`000?l0
n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H05`3jl>H00`000000
n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H20000oeT0
n_3V0@3oool005/0n_3V0P000?m90?[`iP030<f5?`3jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H0
5P3jl>H00`000000n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H0
A`3jl>H20000oe/0n_3V0@3oool005d0n_3V0P000?m70?[`iP030<f5?`3jl>H0n_3V01X0n_3V00<0
00000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V0500n_3V00<0
cHDo0?[`iP3jl>H0A@3jl>H20000oed0n_3V0@3oool005l0n_3V0P000?m50?[`iP030<f5?`3jl>H0
n_3V01X0n_3V00<000000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP0J0?[`iP030000003jl>H0
n_3V0500n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H20000oel0n_3V0@3oool00640n_3V00<0003o0?[`
iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`
iP3jl>H06`3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V0440n_3V0P000?mQ0?[`
iP40oooo001R0?[`iP80003o@P3jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V01D0
n_3V00<000000?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V03l0
n_3V0P000?mS0?[`iP40oooo001T0?[`iP80003o@03jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000
003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5
?`3jl>H0n_3V03h0n_3V0P000?mU0?[`iP40oooo001V0?[`iP80003o?`3jl>H00`3=QCl0n_3V0?[`
iP0I0?[`iP030000003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0703jl>H00`000000n_3V0?[`
iP1?0?[`iP030<f5?`3jl>H0n_3V03`0n_3V0P000?mW0?[`iP40oooo001X0?[`iP030000o`3jl>H0
n_3V03`0n_3V00<0cHDo0?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0
n_3V01`0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0k0?[`iP030000o`3jl>H0
n_3V06L0n_3V0@3oool006T0n_3V0P000?ll0?[`iP030<f5?`3jl>H0n_3V01T0n_3V00<000000?[`
iP3jl>H0503jl>H00`000000n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`
iP3jl>H0>@3jl>H20000ofX0n_3V0@3oool006/0n_3V0P000?lj0?[`iP030<f5?`3jl>H0n_3V01T0
n_3V00<000000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP0M0?[`iP030000003jl>H0n_3V04l0
n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000?l0n_3V0?[`iP1Z0?[`iP40oooo001]0?[`iP030000
o`3jl>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0C0?[`iP030000
003jl>H0n_3V01d0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0f0?[`iP80003o
K@3jl>H10?ooo`00KP3jl>H20000ocL0n_3V00<0cHDo0?[`iP3jl>H06@3jl>H00`000000n_3V0?[`
iP0C0?[`iP030000003jl>H0n_3V01d0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`
iP0e0?[`iP80003oK`3jl>H10?ooo`00L03jl>H20000ocH0n_3V00<0cHDo0?[`iP3jl>H0603jl>H0
0`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0CP3jl>H0
0`3=QCl0n_3V0?[`iP0d0?[`iP030000o`3jl>H0n_3V06l0n_3V0@3oool00780n_3V00<0003o0?[`
iP3jl>H0<`3jl>H00`3=QCl0n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`
iP3jl>H07P3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V0380n_3V0P000?mb0?[`
iP40oooo001c0?[`iP80003o<`3jl>H00`3=QCl0n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V0180
n_3V00<000000?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V0340
n_3V00<0003o0?[`iP3jl>H0LP3jl>H10?ooo`00M@3jl>H20000oc40n_3V00<0cHDo0?[`iP3jl>H0
603jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0
C@3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP80003oM@3jl>H10?ooo`00M`3jl>H00`000?l0n_3V0?[`
iP0_0?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`
iP0O0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0;P3jl>H20000ogL0n_3V0@3o
ool007P0n_3V0P000?l_0?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H04@3jl>H0
0`000000n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H0
0`000?l0n_3V0?[`iP1g0?[`iP40oooo001j0?[`iP80003o;@3jl>H00`3=QCl0n_3V0?[`iP0G0?[`
iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H07`3jl>H00`000000n_3V0?[`iP1=0?[`
iP030<f5?`3jl>H0n_3V02/0n_3V0P000?mj0?[`iP40oooo001l0?[`iP030000o`3jl>H0n_3V02X0
n_3V00<0cHDo0?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V0200
n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP030000o`3jl>H0n_3V07X0
n_3V0@3oool007d0n_3V0P000?l[0?[`iP030<f5?`3jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H0
403jl>H00`000000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0
:@3jl>H20000ogd0n_3V0@3oool007l0n_3V0P000?lY0?[`iP030<f5?`3jl>H0n_3V01H0n_3V00<0
00000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V04`0n_3V00<0
cHDo0?[`iP3jl>H09`3jl>H20000ogl0n_3V0@3oool00840n_3V00<0003o0?[`iP3jl>H09P3jl>H0
0`3=QCl0n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H08@3jl>H0
0`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02H0n_3V00<0003o0?[`iP3jl>H0O`3jl>H1
0?ooo`00PP3jl>H20000obH0n_3V00<0cHDo0?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP0?0?[`
iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0B`3jl>H00`3=QCl0n_3V0?[`iP0U0?[`
iP80003oPP3jl>H10?ooo`00Q03jl>H20000obD0n_3V00<0cHDo0?[`iP3jl>H05@3jl>H00`000000
n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0B`3jl>H00`3=QCl0
n_3V0?[`iP0T0?[`iP030000o`3jl>H0n_3V0880n_3V0@3oool008H0n_3V00<0003o0?[`iP3jl>H0
8P3jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0
8P3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V02<0n_3V0P000?n50?[`iP40oooo
00270?[`iP80003o8`3jl>H00`3=QCl0n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V00h0n_3V00<0
00000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0240n_3V0P00
0?n70?[`iP40oooo00290?[`iP80003o8@3jl>H00`3=QCl0n_3V0?[`iP0D0?[`iP030000003jl>H0
n_3V00h0n_3V00<000000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0
n_3V0200n_3V00<0003o0?[`iP3jl>H0Q`3jl>H10?ooo`00R`3jl>H20000oal0n_3V00<0cHDo0?[`
iP3jl>H0503jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V02<0n_3V00<000000?[`
iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0N0?[`iP80003oRP3jl>H10?ooo`00S@3jl>H00`000?l0
n_3V0?[`iP0L0?[`iP030<f5?`3jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000
n_3V0?[`iP0S0?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H00`000?l0
n_3V0?[`iP2:0?[`iP40oooo002>0?[`iP80003o7@3jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP030000
003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP190?[`iP030<f5
?`3jl>H0n_3V01`0n_3V0P000?n=0?[`iP40oooo002@0?[`iP80003o703jl>H00`3=QCl0n_3V0?[`
iP0B0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0903jl>H00`000000n_3V0?[`
iP180?[`iP030<f5?`3jl>H0n_3V01/0n_3V0P000?n?0?[`iP40oooo002B0?[`iP030000o`3jl>H0
n_3V01T0n_3V00<0cHDo0?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0
n_3V02@0n_3V00<000000?[`iP3jl>H0A`3jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP030000o`3jl>H0
n_3V08l0n_3V0@3oool009<0n_3V0P000?lJ0?[`iP030<f5?`3jl>H0n_3V0140n_3V00<000000?[`
iP3jl>H0303jl>H00`000000n_3V0?[`iP0T0?[`iP030000003jl>H0n_3V04L0n_3V00<0cHDo0?[`
iP3jl>H06@3jl>H20000oi80n_3V0@3oool009D0n_3V00<0003o0?[`iP3jl>H05`3jl>H00`3=QCl0
n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H09@3jl>H00`000000
n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V01T0n_3V00<0003o0?[`iP3jl>H0TP3jl>H10?ooo`00
UP3jl>H20000oaP0n_3V00<0cHDo0?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0;0?[`iP030000
003jl>H0n_3V02D0n_3V00<000000?[`iP3jl>H0AP3jl>H00`3=QCl0n_3V0?[`iP0G0?[`iP80003o
U@3jl>H10?ooo`00V03jl>H00`000?l0n_3V0?[`iP0E0?[`iP030<f5?`3jl>H0n_3V0100n_3V00<0
00000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0U0?[`iP030000003jl>H0n_3V04D0n_3V00<0
cHDo0?[`iP3jl>H05`3jl>H00`000?l0n_3V0?[`iP2E0?[`iP40oooo002I0?[`iP80003o5P3jl>H0
0`3=QCl0n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H09P3jl>H0
0`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V01D0n_3V0P000?nH0?[`iP40oooo002K0?[`
iP030000o`3jl>H0n_3V01<0n_3V00<0cHDo0?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP0:0?[`
iP030000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0A03jl>H00`3=QCl0n_3V0?[`iP0E0?[`
iP030000o`3jl>H0n_3V09P0n_3V0@3oool009`0n_3V0P000?lD0?[`iP030<f5?`3jl>H0n_3V00h0
n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V04@0
n_3V00<0cHDo0?[`iP3jl>H04`3jl>H20000oi/0n_3V0@3oool009h0n_3V00<0003o0?[`iP3jl>H0
4P3jl>H00`3=QCl0n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0
9`3jl>H00`000000n_3V0?[`iP130?[`iP030<f5?`3jl>H0n_3V01<0n_3V00<0003o0?[`iP3jl>H0
V`3jl>H10?ooo`00W`3jl>H20000oa80n_3V00<0cHDo0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`
iP090?[`iP030000003jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`
iP0B0?[`iP80003oWP3jl>H10?ooo`00X@3jl>H00`000?l0n_3V0?[`iP0@0?[`iP030<f5?`3jl>H0
n_3V00`0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0W0?[`iP030000003jl>H0
n_3V0480n_3V00<0cHDo0?[`iP3jl>H04@3jl>H00`000?l0n_3V0?[`iP2N0?[`iP40oooo002R0?[`
iP80003o4@3jl>H00`3=QCl0n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`
iP3jl>H0:03jl>H00`000000n_3V0?[`iP110?[`iP030<f5?`3jl>H0n_3V0100n_3V0P000?nQ0?[`
iP40oooo002T0?[`iP030000o`3jl>H0n_3V00l0n_3V00<0cHDo0?[`iP3jl>H02P3jl>H00`000000
n_3V0?[`iP080?[`iP030000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H0@03jl>H00`3=QCl0
n_3V0?[`iP0@0?[`iP030000o`3jl>H0n_3V0:40n_3V0@3oool00:D0n_3V0P000?l?0?[`iP030<f5
?`3jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0X0?[`iP030000
003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H03`3jl>H20000oj@0n_3V0@3oool00:L0n_3V00<0
003o0?[`iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP090?[`iP030000003jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H0:@3jl>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V00h0n_3V00<0
003o0?[`iP3jl>H0Y03jl>H10?ooo`00Z03jl>H20000o`h0n_3V00<0cHDo0?[`iP3jl>H0203jl>H0
0`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V02T0n_3V00<000000?[`iP3jl>H0?P3jl>H0
0`3=QCl0n_3V0?[`iP0=0?[`iP80003oY`3jl>H10?ooo`00ZP3jl>H20000o``0n_3V00<0cHDo0?[`
iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V02T0n_3V00<000000?[`
iP3jl>H0?@3jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP80003oZ@3jl>H10?ooo`00[03jl>H00`000?l0
n_3V0?[`iP0:0?[`iP030<f5?`3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000
n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V03d0n_3V00<0cHDo0?[`iP3jl>H02P3jl>H20000oj/0
n_3V0@3oool00:d0n_3V0P000?l;0?[`iP80cHDo1`3jl>H00`000000n_3V0?[`iP060?[`iP030000
003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H0>`3jl>H20<f5?``0n_3V00<0003o0?[`iP3jl>H0
Z`3jl>H10?ooo`00[`3jl>H20000o`X0n_3V00<0cHDo0?[`iP3jl>H01@3jl>H00`000000n_3V0?[`
iP060?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`
iP0:0?[`iP80003o[P3jl>H10?ooo`00/@3jl>H00`000?l0n_3V0?[`iP080?[`iP030<f5?`3jl>H0
n_3V00@0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0[0?[`iP030000003jl>H0
n_3V03X0n_3V00<0cHDo0?[`iP3jl>H0203jl>H20000ok00n_3V0@3oool00;80n_3V0P000?l90?[`
iP030<f5?`3jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0[0?[`
iP030000003jl>H0n_3V03T0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H20000ok80n_3V0@3oool00;@0
n_3V0P000?l80?[`iP030<f5?`3jl>H0n_3V0080n_3V00<000000?[`iP3jl>H01@3jl>H00`000000
n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V03P0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H00`000?l0
n_3V0?[`iP2b0?[`iP40oooo002f0?[`iP030000o`3jl>H0n_3V00H0n_3V00D0cHDo0?[`iP3jl>H0
n_3V000000060?[`iP030000003jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0
n_3V0?[`iP060?[`iP80003o]@3jl>H10?ooo`00]`3jl>H20000o`L0n_3V0P3=QCl00`3jl>H00000
0?[`iP050?[`iP030000003jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0=@3jl>H20<f5?`L0n_3V
0P000?ng0?[`iP40oooo002i0?[`iP80003o1P3jl>H00`3=QCl0n_3V000000060?[`iP030000003j
l>H0n_3V02`0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP050?[`iP80003o^@3j
l>H10?ooo`00^`3jl>H00`000?l0n_3V0?[`iP040?[`iP030<f5?`000000n_3V00D0n_3V00<00000
0?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0d0?[`iP030<f5?`3jl>H0n_3V00@0n_3V00<0003o
0?[`iP3jl>H0^@3jl>H10?ooo`00_03jl>H20000o`D0n_3V00<000000<f5?`3jl>H00`3jl>H00`00
0000n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V0380n_3V0P3=QCl50?[`iP80003o_03jl>H10?oo
o`00_P3jl>H20000o`<0n_3V00<000000?[`iP3=QCl00`3jl>H00`000000n_3V0?[`iP0]0?[`iP03
0000003jl>H0n_3V0340n_3V00<0cHDo0?[`iP3jl>H00`3jl>H20000okh0n_3V0@3oool00<00n_3V
00<0003o0?[`iP0000000P0000000`3jl>H0cHDo00000002000002l0n_3V00<000000?[`iP3jl>H0
<03jl>H00`3=QCl0n_3V0?[`iP020?[`iP80003o`03jl>H10?ooo`00`@3jl>H:000002h0n_3V00<0
00000?[`iP3jl>H0;`3jl>H0103=QCl0n_3V0?[`iP3jl>H20000ol80n_3V0@3oool00<40n_3V2P00
000^0?[`iP030000003jl>H0n_3V02d0n_3V0P3=QCl30?[`iP030000o`3jl>H0n_3V0<80n_3V0@3o
ool00<40n_3V2P00000^0?[`iP030000003jl>H0n_3V02`0n_3V00@0cHDo0?[`iP3jl>H0n_3V0P00
0?o50?[`iP40oooo00320?[`iP<000000P3jl>H3000000030?[`iP3=QCl0cHDo02`0n_3V00<00000
0?[`iP3jl>H0:P3jl>H20<f5?`80n_3V0P000?o70?[`iP40oooo00330?[`iP060000003jl>H0n_3V
0?[`iP000000n_3V0P000?l20?[`iP80cHDo:P3jl>H00`000000n_3V0?[`iP0X0?[`iP80cHDo0P3j
l>H20000olT0n_3V0@3oool00<<0n_3V00D000000?[`iP3jl>H0n_3V000000030?[`iP80003o0P3j
l>H00`3=QCl0n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V02L0n_3V00<0cHDo0?[`iP3jl>H00P00
0?o;0?[`iP40oooo00330?[`iP040000003jl>H0n_3V000000H0n_3V0P000?l00`3jl>H0cHDo0<f5
?`0W0?[`iP030000003jl>H0n_3V02D0n_3V0P3=QCl00`3jl>H0003o0000o`3=0?[`iP40oooo0033
0?[`iP040000003jl>H0n_3V000000P0n_3V0`000?l20<f5?bD0n_3V00<000000?[`iP3jl>H08`3j
l>H20<f5?`030?[`iP000?l0003o0<l0n_3V0@3oool00<<0n_3V00@000000?[`iP3jl>H000002`3j
l>H30000o`030<f5?`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H08@3jl>H20<f5?`030?[`iP00
0?l0003o0=40n_3V0@3oool00<<0n_3V00<000000?[`iP0000003`3jl>H20000o`030<f5?`3jl>H0
n_3V01l0n_3V00<000000?[`iP3jl>H07`3jl>H20<f5?`<0003od`3jl>H10?ooo`00``3jl>H00`00
0000n_3V0000000A0?[`iP<0003o7`3jl>H00`000000n_3V0?[`iP0M0?[`iP80cHDo0P000?oF0?[`
iP40oooo00330?[`iP030000003jl>H0000001@0n_3V0`000?l00`3=QCl0n_3V0?[`iP0I0?[`iP03
0000003jl>H0n_3V01T0n_3V0`3=QCl30000omP0n_3V0@3oool00<<0n_3V0P00000H0?[`iP<0003o
6@3jl>H00`000000n_3V0?[`iP0G0?[`iP030<f5?`000?l0003o0080003of`3jl>H10?ooo`00``3j
l>H2000001/0n_3V10000?lE0?[`iP030000003jl>H0n_3V01<0n_3V00<0cHDo0000o`000?l00P00
0?oO0?[`iP40oooo00320?[`iP<000007`3jl>H40000oa40n_3V00<000000?[`iP3jl>H03`3jl>H0
0`3=QCl0003o0000o`020000on<0n_3V0@3oool00<40n_3V1@00000R0?[`iP@0003o3@3jl>H00`00
0000n_3V0?[`iP0;0?[`iPD0003oi`3jl>H10?ooo`00`@3=QCl5000002H0cHDo3@000?l00`000000
003o0000o`0;0000on/0cHDo0@3jl>H10?ooo`00`@3jl>H500000?l0n_3V;P3jl>H10?ooo`00`P3j
l>H300000?l0n_3V;`3jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
002f0?[`iP80000000<0IV9N0<c4^`3jl>H0:`3jl>H01P3Dc<<0IV9N000000000000RHAn0>CKdVD0
n_3V00H0e<c306IRGP000000000008V4OP3Tfm:L0?[`iP40oooo002h0?[`iP0306IRGP000000g=C;
02/0n_3V00H0C4U50<>k/`3jl>H0k>;I00000029Q7iU0?[`iP0604a9A@33^k<0n_3V0>cRf@000000
RHAnW03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H0102_Z:40C4U5
00000029Q7h70?[`iP060=cDb`1iMG00000000000029Q7h0c<Bk0P3jl>H0102_Z:40C4U500000029
Q7h20?[`iP8000000P3jl>H2000000050?[`iP3<a;/0000007UeL03jl>H00P0000020?[`iP800000
00<0IV9N0?[`iP3jl>H01`3jl>H2000000<0n_3V00@0c<Bk04a9A@1VHUh0i=_B0P0000000`3jl>H0
0000000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H20000
0080n_3V00<0RHAn06IRGP3<a;/00P0000070?[`iP050=cDb`1iMG00000004a9A@2TWIH00P3jl>H0
103<a;/0C4U506IRGP3Tfm82000000030?[`iP000000000000@0n_3V00<0Y9fF0000002TWIH00`3j
l>H0102_Z:40C4U500000029Q7h70?[`iP040:nXX@1<BDD0C4U50:nXX@80n_3V0P0000060?[`iP80
000000D0n_3V0<>k/`000000`k^c0?[`iP02000000050?[`iP3<a;/0C4U504a9A@2_Z:400P000000
0`3jl>H00000000000030?[`iP80000000D0n_3V0<c4^`1<BDD0C4U50:nXX@02000000@0n_3V0P00
00000`3/h]T0n_3V0>cRf@0200000080n_3V00<0RHAn06IRGP3<a;/00P0000000`3jl>H000000000
00020?[`iP8000000P3jl>H0102_Z:40C4U500000029Q7h20?[`iP070>cRf@2GTH/000000000001i
MG00i=_B0?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H200000007
0?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP050?[`iP050>CKdP000000Ui6;0?[`iP2i/ZX00P00
0000203jl>H0[jRQ00000033^k<0i=_B00000029Q7h0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP3<a;/000000080000000<0i=_B0?[`iP3jl>H01P3jl>H20000
00<0n_3V00@0IV9N0000003Tfm80^K:Z0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP8000000P3jl>H2000000050?[`iP2TWIH000000<>k/`2TWIH0
0P0000060?[`iP0<0>CKdP000000Ui6;0?[`iP3Dc<<0000008V4OP3jl>H0IV9N0000003Tfm80^K:Z
0P0000000`3jl>H00000000000040?[`iP<0000000P0k>;I0?[`iP2_Z:4000000<>k/`3Tfm800000
08V4OPD0n_3V00L0^K:Z00000033^k<0`k^c0000002i/ZX0n_3V008000001P3jl>H2000000050?[`
iP2GTH/0000009NAR`3jl>H00P0000001@3jl>H0C4U50000003Tfm80`k^c0080000000<0n_3V0000
000000000`3jl>H2000000050?[`iP1<BDD000000>CKdP33^k<00P0000040?[`iP0<08V4OP000000
e<c30?[`iP3Dc<<0000008V4OP3jl>H0Y9fF00000033^k<0Y9fF0P0000000`3jl>H0000000000002
0?[`iP80000000l0n_3V0:nXX@000000`k^c0>CKdP000000RHAn0?[`iP1iMG0000000>CKdP3/h]T0
000006IRGP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P000000
0`3jl>H0C4U5000000090?[`iP0309NAR`000000g=C;0080n_3V0P0000000`3jl>H0C4U500000005
0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000001P3jl>H0Ui6;00000029
Q7h000000:nXX@P0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V
0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V04a9A@00
00000P3jl>H2000000H0n_3V00<0Ui6;0000003Tfm801@3jl>H200000080n_3V0P0000000`3jl>H0
0000000000030?[`iP080;VbZP000000RHAn0000002i/ZX0n_3V04a9A@0000090?[`iP0706IRGP00
0000n_3V0?[`iP000000IV9N0?[`iP02000000H0n_3V0P0000001@3jl>H0C4U50000001<BDD0n_3V
0080000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000<0n_3V0P0000000`3j
l>H00000000000020?[`iP800000103jl>H00`2_Z:40000000000003000000040:nXX@3jl>H0C4U5
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V04a9A@0000001`3jl>H0
1@3Dc<<0Y9fF0000001<BDD0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P000002
0?[`iP80000000<0n_3V000000000000100000050?[`iP0304a9A@000000n_3V0080n_3V0P000000
0`3jl>H0000000000004000000030?[`iP00000000000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000H0n_3V04a9A@000000k>;I0000001VHUh80?[`iP8000000`3jl>H200000080n_3V
0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000060?[`iP8000001P3jl>H200000080
n_3V0P0000000`3jl>H00000000000030?[`iP80C4U500@0k>;I04a9A@1<BDD0n_3V1P0000050?[`
iP8000000P3jl>H2000000030?[`iP000000000000H0n_3V0P0000001@3Tfm80000009NAR`000000
i=_B0080000000D0n_3V0<c4^`000000Ui6;0>CKdP02000000030?[`iP000000000000<0n_3V0P00
00001@3jl>H0c<Bk0000002GTH/0i=_B00800000103jl>H0203Dc<<0000008V4OP3jl>H0Ui6;0000
003Dc<<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
000000@0000000<0n_3V0<c4^`1<BDD00P0000000`1<BDD0c<Bk0?[`iP02000008@0n_3V0@3oool0
08<0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP1<BDD000000080n_3V00<0000006IR
GP3jl>H0103jl>H200000080n_3V0`0000000`3jl>H0C4U5000000020?[`iP030000001VHUh0n_3V
008000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000001`3Le</0000008V4OP3jl>H0
RHAn0000003Tfm801`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3j
l>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P0000000`3jl>H0C4U5
000000020?[`iP8000001P3jl>H2000000H0n_3V0P0000020?[`iP80000000<0n_3V000000000000
0P3jl>H02@3<a;/000000:BMUP3jl>H0Y9fF0000003<a;/0C4U5000000020?[`iP030000001VHUh0
n_3V00@0n_3V00L0IV9N0000003jl>H0n_3V0000001VHUh0n_3V008000001P3jl>H2000000050<c4
^`000000g=C;0000003<a;/00P0000020?[`iP030=cDb`2_Z:40NGE`0080000000<0n_3V00000000
00000`3jl>H200000080n_3V00<0g=C;0:nXX@1iMG000P0000050?[`iP050000001<BDD0n_3V04a9
A@0000000P3jl>H0101<BDD000000?[`iP3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H0C4U5000000020?[`iP070000001VHUh0n_3V04a9A@000000NGE`0<c4^`030?[`iP800000
Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000002`2TWIH0i=_B0000001VHUh0n_3V0;VbZP00
0000`k^c0<c4^`000000^K:Z00D0n_3V00<0C4U50000003jl>H01@3jl>H01`2i/ZX000000<>k/`3<
a;/000000;VbZP3jl>H00P0000001@2i/ZX0i=_B0000001<BDD0n_3V008000000P3jl>H200000007
0:nXX@000000`k^c0?[`iP33^k<000000:nXX@070?[`iP8000000`3jl>H200000080n_3V0P000000
103jl>H000000000003Dc<<20?[`iP80000000D0^K:Z0>CKdP000000C4U50?[`iP020000000<0?[`
iP00000000000;VbZP3Tfm80000004a9A@3jl>H0Y9fF00000033^k<0Y9fF0P0000060?[`iP0304a9
A@000000n_3V00D0n_3V0P0000020?[`iP8000000180n_3V000000000000e<c30?[`iP1VHUh00000
0>cRf@3jl>H0k>;I0000001VHUh0^K:Z00000033^k<0c<Bk0000002i/ZX50?[`iP070;VbZP000000
`k^c0<>k/`000000^K:Z0?[`iP02000000H0n_3V0P0000001@2TWIH0IV9N0?[`iP1VHUh0Y9fF0080
000000P0n_3V07UeL03Dc<<0n_3V0>CKdP000000C4U50?[`iP80000000<0e<c30?[`iP3jl>H00P00
00001`3jl>H0NGE`0=C<``3jl>H0i=_B0000001<BDD01@3jl>H01@1iMG0000000<c4^`000000IV9N
0080n_3V00@0Y9fF00000033^k<0Y9fF0P0000005P3jl>H000000000002i/ZX0i=_B0000001<BDD0
n_3V0;VbZP000000`k^c0<c4^`000000^K:Z0?[`iP1VHUh000000?[`iP3Tfm80000007UeL03jl>H2
000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP80000000@0g=C;08V4OP1<BDD0c<Bk0P3jl>H0
102_Z:4000000000002_Z:460?[`iP0309NAR`000000i=_B00H0n_3V00@0[jRQ000000000000[jRQ
0P3jl>H2000000040<c4^`1iMG00C4U50<c4^`@0000000X0n_3V000000000000IV9N0000003/h]T0
n_3V0>cRf@000000IV9N1`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000
RHAn07UeL03jl>H2000000050<c4^`1iMG00C4U50<c4^`3jl>H00P0000001`3jl>H000000000003<
a;/0NGE`04a9A@3<a;/00P3jl>H00`29Q7h0IV9N0<c4^`02000000H0n_3V00<0Ui6;0000003Tfm80
1@3jl>H200000080n_3V0P000000103jl>H0000000000029Q7h20000000808V4OP3jl>H0n_3V0?[`
iP29Q7h000000=cDb`2_Z:42000000030:nXX@3jl>H0n_3V00D0n_3V00D0[jRQ04a9A@000000[jRQ
0?[`iP04000000D0n_3V0P0000001@1VHUh0Y9fF0?[`iP2GTH/0IV9N0080000000<0n_3V0>CKdP29
Q7h00P0000000`1VHUh0e<c30?[`iP020000000308V4OP1iMG00n_3V0080000000<0n_3V0>CKdP29
Q7h00P0000000`1VHUh0e<c30?[`iP040?[`iP050:BMUP000000RHAn0000002TWIH00`3jl>H00`29
Q7h0IV9N0<c4^`02000000070?[`iP00000000000<c4^`1iMG00C4U50<c4^`020?[`iP040:nXX@00
000000000:nXX@80n_3V00L0i=_B07UeL0000000000008V4OP3Tfm80n_3V00800000Q03jl>H10?oo
o`00P`3jl>H2000000<0n_3V0P00000@0?[`iP070>CKdP000000Ui6;0?[`iP3Dc<<0000007UeL00?
0?[`iP8000000P3jl>H2000000h0n_3V0P00000/0?[`iP070>CKdP000000Ui6;0?[`iP3Dc<<00000
08V4OP0U0?[`iP8000001P3jl>H3000000030<c4^`3jl>H0`k^c00<000006`3jl>H01@3<a;/00000
000000000000`k^c0:@0n_3V0@3oool00840n_3V1P0000000`3jl>H000000000000A0?[`iP060=cD
b`1iMG0000000000002GTH/0k>;I3`3jl>H0103Le</0RHAn0?[`iP3jl>H2000000`0n_3V1P00000D
0?[`iP8000005@3jl>H01@3Le</0NGE`000000000000Y9fF02H0n_3V00@0c<Bk06IRGP000000RHAn
103jl>H3000000030>cRf@3jl>H0g=C;00<000003@3jl>H2000000`0n_3V00D0k>;I000000000000
00000>CKdP0N0?[`iP800000Q03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.43478 .38333 L
s
.43478 .05 m
.43478 .38333 L
s
.43719 .37104 m
.43478 .37104 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.43478 .38333 Mdot
.43719 .37104 Mdot
.43478 .37104 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00=T0n_3V00<000000?[`iP3jl>H04@3jl>H:0<f5
?`80n_3V00<000000?[`iP3jl>H02P3=QCo]0?[`iP40oooo003I0?[`iP030000003jl>H0n_3V00/0
n_3V1P3=QCl<0?[`iP030000003jl>H0n_3V00X0n_3V1`3=QCoV0?[`iP40oooo003I0?[`iP030000
003jl>H0n_3V00T0n_3V0P3=QClA0?[`iP8000004`3jl>H20<f5?n@0n_3V0@3oool00=T0n_3V00<0
00000?[`iP3jl>H01@3jl>H40<f5?a<0n_3V0P00000E0?[`iP<0cHDoh@3jl>H10?ooo`00f@3jl>H0
10000000n_3V0?[`iP3jl>H40<f5?aL0n_3V0P00000H0?[`iP@0cHDog@3jl>H10?ooo`00f@3jl>H0
10000000n_3V0<f5?`3=QClK0?[`iP800000703jl>H20<f5?m/0n_3V0@3oool00=T0n_3V00<00000
0<f5?`3jl>H0703jl>H2000001h0n_3V0P3=QCoI0?[`iP40oooo003G0?[`iP80cHDo00<000000?[`
iP3jl>H06`3jl>H00`000000n_3V0000000P0?[`iP80cHDoe`3jl>H10?ooo`00e@3jl>H20<f5?`80
n_3V00<000000?[`iP3jl>H06`3jl>H00`000000n_3V0000000R0?[`iP80cHDoe@3jl>H10?ooo`00
d`3jl>H20<f5?`@0n_3V00<000000?[`iP3jl>H06`3jl>H00`000000n_3V0000000T0?[`iP80cHDo
d`3jl>H10?ooo`00d@3jl>H20<f5?`H0n_3V00<000000?[`iP3jl>H06`3jl>H00`000000n_3V0000
000V0?[`iP80cHDod@3jl>H10?ooo`00c`3jl>H20<f5?`P0n_3V00<000000?[`iP3jl>H06`3jl>H0
0`000000n_3V0000000X0?[`iP80cHDoc`3jl>H10?ooo`00cP3jl>H00`3=QCl0n_3V0?[`iP080?[`
iP030000003jl>H0n_3V01X0n_3V00@000000?[`iP3jl>H00000:P3jl>H00`3=QCl0n_3V0?[`iP3<
0?[`iP40oooo003<0?[`iP80cHDo2`3jl>H00`000000n_3V0?[`iP0J0?[`iP040000003jl>H0n_3V
000002/0n_3V0P3=QCo<0?[`iP40oooo003:0?[`iP80cHDo3@3jl>H00`000000n_3V0?[`iP0J0?[`
iP040000003jl>H0n_3V000002d0n_3V0P3=QCo:0?[`iP40oooo00390?[`iP030<f5?`3jl>H0n_3V
00d0n_3V00<000000?[`iP3jl>H06P3jl>H010000000n_3V0?[`iP00000_0?[`iP030<f5?`3jl>H0
n_3V0<L0n_3V0@3oool00<L0n_3V0P3=QCl@0?[`iP030000003jl>H0n_3V01X0n_3V00@000000?[`
iP3jl>H00000<03jl>H20<f5?lL0n_3V0@3oool00<H0n_3V00<0cHDo0?[`iP3jl>H0403jl>H00`00
0000n_3V0?[`iP0J0?[`iP040000003jl>H0n_3V00000380n_3V00<0cHDo0?[`iP3jl>H0a03jl>H1
0?ooo`00a@3jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V01T0n_3V00D000000?[`
iP3jl>H0n_3V0000000c0?[`iP030<f5?`3jl>H0n_3V0<<0n_3V0@3oool00<@0n_3V00<0cHDo0?[`
iP3jl>H04P3jl>H00`000000n_3V0?[`iP0I0?[`iP050000003jl>H0n_3V0?[`iP000000=03jl>H0
0`3=QCl0n_3V0?[`iP320?[`iP40oooo00320?[`iP80cHDo5@3jl>H00`000000n_3V0?[`iP0I0?[`
iP050000003jl>H0n_3V0?[`iP000000=@3jl>H20<f5?l80n_3V0@3oool00<40n_3V00<0cHDo0?[`
iP3jl>H05@3jl>H00`000000n_3V0?[`iP0I0?[`iP050000003jl>H0n_3V0?[`iP000000=P3jl>H0
0`3=QCl0n_3V0?[`iP300?[`iP40oooo00300?[`iP030<f5?`3jl>H0n_3V01H0n_3V00<000000?[`
iP3jl>H06@3jl>H01@000000n_3V0?[`iP3jl>H0000003L0n_3V00<0cHDo0?[`iP3jl>H0_`3jl>H1
0?ooo`00_`3jl>H00`3=QCl0n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V01P0n_3V00<000000?[`
iP3jl>H00P3jl>H00`000000n_3V0?[`iP0f0?[`iP80cHDo_`3jl>H10?ooo`00_P3jl>H00`3=QCl0
n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000
n_3V0?[`iP0h0?[`iP030<f5?`3jl>H0n_3V0;`0n_3V0@3oool00;d0n_3V00<0cHDo0?[`iP3jl>H0
6@3jl>H00`000000n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0
>@3jl>H00`3=QCl0n_3V0?[`iP2k0?[`iP40oooo002l0?[`iP030<f5?`3jl>H0n_3V01X0n_3V00<0
00000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V03X0n_3V00<0
cHDo0?[`iP3jl>H0^P3jl>H10?ooo`00^`3jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP030000003jl>H0
n_3V01P0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0
n_3V0;X0n_3V0@3oool00;X0n_3V00<0cHDo0?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP0G0?[`
iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0>`3jl>H00`3=QCl0n_3V0?[`iP2i0?[`
iP40oooo002i0?[`iP030<f5?`3jl>H0n_3V01d0n_3V00<000000?[`iP3jl>H05`3jl>H00`000000
n_3V0?[`iP030?[`iP030000003jl>H0n_3V03`0n_3V0P3=QCni0?[`iP40oooo002h0?[`iP030<f5
?`3jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP030?[`iP030000
003jl>H0n_3V03d0n_3V00<0cHDo0?[`iP3jl>H0]`3jl>H10?ooo`00^03jl>H00`3=QCl0n_3V0?[`
iP0N0?[`iP030000003jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`
iP0n0?[`iP030<f5?`3jl>H0n_3V0;H0n_3V0@3oool00;L0n_3V00<0cHDo0?[`iP3jl>H07`3jl>H0
0`000000n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0?`3jl>H0
0`3=QCl0n_3V0?[`iP2e0?[`iP40oooo002f0?[`iP030<f5?`3jl>H0n_3V0200n_3V00<000000?[`
iP3jl>H05P3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`
iP3jl>H0]@3jl>H10?ooo`00]P3jl>H00`3=QCl0n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V01H0
n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP100?[`iP030<f5?`3jl>H0n_3V0;@0
n_3V0@3oool00;D0n_3V00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0F0?[`iP030000
003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0@@3jl>H00`3=QCl0n_3V0?[`iP2c0?[`iP40oooo
002d0?[`iP030<f5?`3jl>H0n_3V0280n_3V00<000000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`
iP040?[`iP030000003jl>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H0/P3jl>H10?ooo`00/`3jl>H0
0`3=QCl0n_3V0?[`iP0S0?[`iP030000003jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H0103jl>H0
0`000000n_3V0?[`iP130?[`iP030<f5?`3jl>H0n_3V0;40n_3V0@3oool00;80n_3V00<0cHDo0?[`
iP3jl>H0903jl>H00`000000n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`
iP3jl>H0@`3jl>H00`3=QCl0n_3V0?[`iP2a0?[`iP40oooo002b0?[`iP030<f5?`3jl>H0n_3V02@0
n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V04@0
n_3V00<0cHDo0?[`iP3jl>H0/03jl>H10?ooo`00/@3jl>H00`3=QCl0n_3V0?[`iP0U0?[`iP030000
003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP140?[`iP030<f5
?`3jl>H0n_3V0;00n_3V0@3oool00;40n_3V00<0cHDo0?[`iP3jl>H09@3jl>H00`000000n_3V0?[`
iP0E0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`
iP2_0?[`iP40oooo002`0?[`iP030<f5?`3jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H05@3jl>H0
0`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H0[`3jl>H1
0?ooo`00/03jl>H00`3=QCl0n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`
iP3jl>H01@3jl>H00`000000n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool00:l0
n_3V00<0cHDo0?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V00H0
n_3V00<000000?[`iP3jl>H0AP3jl>H00`3=QCl0n_3V0?[`iP2^0?[`iP40oooo002_0?[`iP030<f5
?`3jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP060?[`iP030000
003jl>H0n_3V04L0n_3V00<0cHDo0?[`iP3jl>H0[@3jl>H10?ooo`00[P3jl>H00`3=QCl0n_3V0?[`
iP0X0?[`iP030000003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`
iP180?[`iP030<f5?`3jl>H0n_3V0:`0n_3V0@3oool00:d0n_3V00<0cHDo0?[`iP3jl>H0:@3jl>H0
0`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0B03jl>H0
0`3=QCl0n_3V0?[`iP2/0?[`iP40oooo002]0?[`iP030<f5?`3jl>H0n_3V02T0n_3V00<000000?[`
iP3jl>H0503jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`
iP3jl>H0Z`3jl>H10?ooo`00[03jl>H00`3=QCl0n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V01<0
n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V0:/0
n_3V0@3oool00:`0n_3V00<0cHDo0?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`iP0C0?[`iP030000
003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2Z0?[`iP40oooo
00020000ojX0n_3V00<0cHDo0?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`iP0C0?[`iP030000003j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2W0?[`iP80003o0@3j
l>H10?ooo`000P3jl>H30000ojL0n_3V00<0cHDo0?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`iP0C
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP2T
0?[`iP<0003o0`3jl>H10?ooo`001@3jl>H40000oj80n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`00
0000n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=
QCl0n_3V0?[`iP2P0?[`iP@0003o1P3jl>H10?ooo`002@3jl>H30000oil0n_3V00<0cHDo0?[`iP3j
l>H0:`3jl>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3j
l>H0B`3jl>H00`3=QCl0n_3V0?[`iP2L0?[`iP<0003o2P3jl>H10?ooo`00303jl>H30000oi/0n_3V
00<0cHDo0?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V00P0n_3V
00<000000?[`iP3jl>H0B`3jl>H00`3=QCl0n_3V0?[`iP2I0?[`iP<0003o3@3jl>H10?ooo`003`3j
l>H40000oiL0n_3V00<0cHDo0?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0B0?[`iP030000003j
l>H0n_3V00P0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP2D0?[`iP@0003o403j
l>H10?ooo`004`3jl>H30000oi@0n_3V00<0cHDo0?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0B
0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP2A
0?[`iP<0003o503jl>H10?ooo`005P3jl>H30000oi40n_3V00<0cHDo0?[`iP3jl>H0;03jl>H00`00
0000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=
QCl0n_3V0?[`iP2>0?[`iP<0003o5`3jl>H10?ooo`006@3jl>H30000ohd0n_3V00<0cHDo0?[`iP3j
l>H0;@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3j
l>H0C03jl>H00`3=QCl0n_3V0?[`iP2;0?[`iP<0003o6P3jl>H10?ooo`00703jl>H30000ohX0n_3V
00<0cHDo0?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00T0n_3V
00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP270?[`iP<0003o7@3jl>H10?ooo`007`3j
l>H40000ohH0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003j
l>H0n_3V00T0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP240?[`iP<0003o803j
l>H10?ooo`008`3jl>H30000oh<0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP0A
0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP21
0?[`iP<0003o8`3jl>H10?ooo`009P3jl>H30000ogl0n_3V00<0cHDo0?[`iP3jl>H0;P3jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=
QCl0n_3V0?[`iP1n0?[`iP<0003o9P3jl>H10?ooo`00:@3jl>H30000og`0n_3V00<0cHDo0?[`iP3j
l>H0;P3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3j
l>H0CP3jl>H00`3=QCl0n_3V0?[`iP1j0?[`iP<0003o:@3jl>H10?ooo`00;03jl>H20000ogX0n_3V
00<0cHDo0?[`iP3jl>H0;P3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V00X0n_3V
00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP1h0?[`iP80003o;03jl>H10?ooo`00;P3j
l>H20000ogP0n_3V00<0cHDo0?[`iP3jl>H0;P3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003j
l>H0n_3V00X0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP1f0?[`iP80003o;P3j
l>H10?ooo`00<03jl>H30000og@0n_3V00<0cHDo0?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0@
0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP1c
0?[`iP<0003o<03jl>H10?ooo`00<`3jl>H20000og80n_3V00<0cHDo0?[`iP3jl>H0;`3jl>H00`00
0000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=
QCl0n_3V0?[`iP1`0?[`iP80003o<`3jl>H10?ooo`00=@3jl>H20000og00n_3V00<0cHDo0?[`iP3j
l>H0;`3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3j
l>H0C`3jl>H00`3=QCl0n_3V0?[`iP1^0?[`iP80003o=@3jl>H10?ooo`00=`3jl>H30000ofd0n_3V
00<0cHDo0?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00/0n_3V
00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1[0?[`iP<0003o=`3jl>H10?ooo`00>P3j
l>H20000of/0n_3V00<0cHDo0?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003j
l>H0n_3V00/0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1Y0?[`iP80003o>P3j
l>H10?ooo`00?03jl>H20000ofT0n_3V00<0cHDo0?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0?
0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP1W
0?[`iP80003o?03jl>H10?ooo`00?P3jl>H30000ofD0n_3V00<0cHDo0?[`iP3jl>H0<03jl>H00`00
0000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=
QCl0n_3V0?[`iP1T0?[`iP<0003o?P3jl>H10?ooo`00@@3jl>H20000of<0n_3V00<0cHDo0?[`iP3j
l>H0<03jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3j
l>H0D03jl>H00`3=QCl0n_3V0?[`iP1Q0?[`iP80003o@@3jl>H10?ooo`00@`3jl>H20000of40n_3V
00<0cHDo0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00`0n_3V
00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1O0?[`iP80003o@`3jl>H10?ooo`00A@3j
l>H20000oel0n_3V00<0cHDo0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0>0?[`iP030000003j
l>H0n_3V00`0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1M0?[`iP80003oA@3j
l>H10?ooo`00A`3jl>H20000oed0n_3V00<0cHDo0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0>
0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP1K
0?[`iP80003oA`3jl>H10?ooo`00B@3jl>H30000oeX0n_3V00<0cHDo0?[`iP3jl>H0<03jl>H00`00
0000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=
QCl0n_3V0?[`iP1I0?[`iP80003oB@3jl>H10?ooo`00C03jl>H20000oeP0n_3V00<0cHDo0?[`iP3j
l>H0<03jl>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3j
l>H0D03jl>H00`3=QCl0n_3V0?[`iP1G0?[`iP80003oB`3jl>H10?ooo`00CP3jl>H20000oeH0n_3V
00<0cHDo0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V00`0n_3V
0`00001A0?[`iP030<f5?`3jl>H0n_3V05D0n_3V0P000?m=0?[`iP40oooo001@0?[`iP80003oE03j
l>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H02`3j
l>H500000500n_3V00<0cHDo0?[`iP3jl>H0D`3jl>H20000odl0n_3V0@3oool00580n_3V0P000?mB
0?[`iP030<f5?`3jl>H0n_3V0300n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0;
0?[`iPD00000D03jl>H00`3=QCl0n_3V0?[`iP1A0?[`iP80003oD@3jl>H10?ooo`00E03jl>H20000
oe00n_3V00<0cHDo0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V
00/0n_3V1@00001@0?[`iP030<f5?`3jl>H0n_3V04l0n_3V0P000?mC0?[`iP40oooo001F0?[`iP80
003oCP3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3j
l>H0303jl>H300000540n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H20000oeD0n_3V0@3oool005P0n_3V
0P000?m<0?[`iP030<f5?`3jl>H0n_3V0300n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V
0?[`iP0>0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H0B`3jl>H20000oeL0n_3V
0@3oool005X0n_3V00<0003o0?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003j
l>H0n_3V00`0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3j
l>H0n_3V04T0n_3V0P000?mI0?[`iP40oooo001K0?[`iP80003oB@3jl>H00`3=QCl0n_3V0?[`iP0`
0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP1@
0?[`iP030<f5?`3jl>H0n_3V04L0n_3V0P000?mK0?[`iP40oooo001M0?[`iP80003oA`3jl>H00`3=
QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H03P3jl>H00`00
0000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04D0n_3V0P000?mM0?[`iP40oooo001O0?[`iP80
003oA@3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3j
l>H03P3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04<0n_3V0P000?mO0?[`iP40
oooo001Q0?[`iP030000o`3jl>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H0<03jl>H00`000000n_3V
0?[`iP0;0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V
0?[`iP110?[`iP80003oH@3jl>H10?ooo`00HP3jl>H20000od80n_3V00<0cHDo0?[`iP3jl>H0<03j
l>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0D03j
l>H00`3=QCl0n_3V0?[`iP0o0?[`iP80003oH`3jl>H10?ooo`00I03jl>H20000od00n_3V00<0cHDo
0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00l0n_3V00<00000
0?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP80003oI@3jl>H10?ooo`00IP3jl>H20000
ocl0n_3V00<0cHDo0?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V
00l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP80003oI`3jl>H10?oo
o`00J03jl>H00`000?l0n_3V0?[`iP0l0?[`iP030<f5?`3jl>H0n_3V02l0n_3V00<000000?[`iP3j
l>H02`3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3j
l>H0>`3jl>H00`000?l0n_3V0?[`iP1W0?[`iP40oooo001Y0?[`iP80003o?03jl>H00`3=QCl0n_3V
0?[`iP0_0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V
0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V03T0n_3V0P000?mZ0?[`iP40oooo001[0?[`iP80003o>P3j
l>H00`3=QCl0n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0403j
l>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V03P0n_3V00<0003o0?[`iP3jl>H0JP3j
l>H10?ooo`00K@3jl>H00`000?l0n_3V0?[`iP0g0?[`iP030<f5?`3jl>H0n_3V02l0n_3V00<00000
0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo
0?[`iP3jl>H0=P3jl>H20000ofd0n_3V0@3oool006h0n_3V0P000?lg0?[`iP030<f5?`3jl>H0n_3V
02l0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V
04h0n_3V00<0cHDo0?[`iP3jl>H0=@3jl>H20000ofl0n_3V0@3oool00700n_3V0P000?lf0?[`iP03
0<f5?`3jl>H0n_3V02h0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0@0?[`iP03
0000003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0=03jl>H00`000?l0n_3V0?[`iP1_0?[`iP40
oooo001b0?[`iP030000o`3jl>H0n_3V03<0n_3V00<0cHDo0?[`iP3jl>H0;P3jl>H00`000000n_3V
0?[`iP0:0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V
0?[`iP0b0?[`iP80003oLP3jl>H10?ooo`00L`3jl>H20000oc<0n_3V00<0cHDo0?[`iP3jl>H0;P3j
l>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H0CP3j
l>H00`3=QCl0n_3V0?[`iP0a0?[`iP030000o`3jl>H0n_3V0780n_3V0@3oool007D0n_3V0P000?la
0?[`iP030<f5?`3jl>H0n_3V02h0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0A
0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0<03jl>H20000ogD0n_3V0@3oool0
07L0n_3V00<0003o0?[`iP3jl>H0;`3jl>H00`3=QCl0n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V
00T0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V
02h0n_3V0P000?mg0?[`iP40oooo001h0?[`iP80003o;`3jl>H00`3=QCl0n_3V0?[`iP0]0?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP1=0?[`iP03
0<f5?`3jl>H0n_3V02d0n_3V00<0003o0?[`iP3jl>H0M`3jl>H10?ooo`00NP3jl>H20000obd0n_3V
00<0cHDo0?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V0140n_3V
00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP80003oNP3jl>H10?ooo`00O03j
l>H00`000?l0n_3V0?[`iP0Z0?[`iP030<f5?`3jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H0203j
l>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0:`3j
l>H00`000?l0n_3V0?[`iP1j0?[`iP40oooo001m0?[`iP80003o:`3jl>H00`3=QCl0n_3V0?[`iP0/
0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP1<
0?[`iP030<f5?`3jl>H0n_3V02T0n_3V0P000?mm0?[`iP40oooo001o0?[`iP80003o:@3jl>H00`3=
QCl0n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H04P3jl>H00`00
0000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02L0n_3V0P000?mo0?[`iP40oooo00210?[`iP03
0000o`3jl>H0n_3V02H0n_3V00<0cHDo0?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP080?[`iP03
0000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0V0?[`iP03
0000o`3jl>H0n_3V07l0n_3V0@3oool00880n_3V0P000?lV0?[`iP030<f5?`3jl>H0n_3V02`0n_3V
00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V04/0n_3V
00<0cHDo0?[`iP3jl>H09@3jl>H20000oh80n_3V0@3oool008@0n_3V0P000?lU0?[`iP030<f5?`3j
l>H0n_3V02/0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0C0?[`iP030000003j
l>H0n_3V04/0n_3V00<0cHDo0?[`iP3jl>H0903jl>H00`000?l0n_3V0?[`iP220?[`iP40oooo0026
0?[`iP030000o`3jl>H0n_3V0280n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0S
0?[`iP80003oQ@3jl>H10?ooo`00Q`3jl>H20000ob<0n_3V00<0cHDo0?[`iP3jl>H0:P3jl>H00`00
0000n_3V0?[`iP070?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=
QCl0n_3V0?[`iP0Q0?[`iP80003oQ`3jl>H10?ooo`00R@3jl>H20000ob40n_3V00<0cHDo0?[`iP3j
l>H0:P3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3j
l>H0BP3jl>H00`3=QCl0n_3V0?[`iP0P0?[`iP030000o`3jl>H0n_3V08L0n_3V0@3oool008/0n_3V
0P000?lO0?[`iP030<f5?`3jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V
0?[`iP0C0?[`iP030000003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H20000ohX0n_3V
0@3oool008d0n_3V00<0003o0?[`iP3jl>H0703jl>H00`3=QCl0n_3V0?[`iP0Z0?[`iP030000003j
l>H0n_3V00H0n_3V00<000000?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP190?[`iP030<f5?`3j
l>H0n_3V01h0n_3V00<0003o0?[`iP3jl>H0RP3jl>H10?ooo`00SP3jl>H20000oad0n_3V00<0cHDo
0?[`iP3jl>H0:@3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V01@0n_3V00<00000
0?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP0L0?[`iP80003oS@3jl>H10?ooo`00T03jl>H20000
oa`0n_3V00<0cHDo0?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V
01@0n_3V00<000000?[`iP3jl>H0B03jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP80003oS`3jl>H10?oo
o`00TP3jl>H00`000?l0n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V02P0n_3V00<000000?[`iP3j
l>H01P3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V04L0n_3V00<0cHDo0?[`iP3j
l>H06`3jl>H00`000?l0n_3V0?[`iP2?0?[`iP40oooo002C0?[`iP80003o6P3jl>H00`3=QCl0n_3V
0?[`iP0W0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0503jl>H00`000000n_3V
0?[`iP170?[`iP030<f5?`3jl>H0n_3V01T0n_3V0P000?nB0?[`iP40oooo002E0?[`iP030000o`3j
l>H0n_3V01L0n_3V00<0cHDo0?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP050?[`iP030000003j
l>H0n_3V01D0n_3V00<000000?[`iP3jl>H0AP3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000o`3j
l>H0n_3V0980n_3V0@3oool009H0n_3V0P000?lH0?[`iP030<f5?`3jl>H0n_3V02H0n_3V00<00000
0?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V04H0n_3V00<0cHDo
0?[`iP3jl>H05`3jl>H20000oiD0n_3V0@3oool009P0n_3V00<0003o0?[`iP3jl>H05@3jl>H00`3=
QCl0n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H05@3jl>H00`00
0000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<0003o0?[`iP3jl>H0U@3jl>H10?oo
o`00V@3jl>H20000oaH0n_3V00<0cHDo0?[`iP3jl>H09@3jl>H00`000000n_3V0?[`iP050?[`iP03
0000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP80
003oV03jl>H10?ooo`00V`3jl>H00`000?l0n_3V0?[`iP0C0?[`iP030<f5?`3jl>H0n_3V02D0n_3V
00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V04@0n_3V
00<0cHDo0?[`iP3jl>H05@3jl>H00`000?l0n_3V0?[`iP2H0?[`iP40oooo002L0?[`iP80003o503j
l>H00`3=QCl0n_3V0?[`iP0T0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H05@3j
l>H00`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0n_3V01<0n_3V0P000?nK0?[`iP40oooo002N
0?[`iP030000o`3jl>H0n_3V0180n_3V00<0cHDo0?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP04
0?[`iP030000003jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H0@`3jl>H00`3=QCl0n_3V0?[`iP0C
0?[`iP030000o`3jl>H0n_3V09/0n_3V0@3oool009l0n_3V0P000?lB0?[`iP030<f5?`3jl>H0n_3V
02<0n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V
0480n_3V00<0cHDo0?[`iP3jl>H04P3jl>H20000oih0n_3V0@3oool00:40n_3V00<0003o0?[`iP3j
l>H0403jl>H00`3=QCl0n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3j
l>H05P3jl>H00`000000n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V0140n_3V00<0003o0?[`iP3j
l>H0WP3jl>H10?ooo`00XP3jl>H20000oa40n_3V00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V
0?[`iP040?[`iP030000003jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H0@@3jl>H00`3=QCl0n_3V
0?[`iP0@0?[`iP80003oX@3jl>H10?ooo`00Y03jl>H00`000?l0n_3V0?[`iP0?0?[`iP030<f5?`3j
l>H0n_3V0200n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0F0?[`iP030000003j
l>H0n_3V0400n_3V00<0cHDo0?[`iP3jl>H0403jl>H00`000?l0n_3V0?[`iP2Q0?[`iP40oooo002U
0?[`iP80003o3`3jl>H00`3=QCl0n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V00<0n_3V00<00000
0?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V00l0n_3V0P000?nT
0?[`iP40oooo002W0?[`iP030000o`3jl>H0n_3V00d0n_3V00<0cHDo0?[`iP3jl>H07`3jl>H00`00
0000n_3V0?[`iP030?[`iP030000003jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=
QCl0n_3V0?[`iP0>0?[`iP030000o`3jl>H0n_3V0:@0n_3V0@3oool00:P0n_3V0P000?l>0?[`iP03
0<f5?`3jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0G0?[`iP03
0000003jl>H0n_3V03h0n_3V00<0cHDo0?[`iP3jl>H03@3jl>H20000ojL0n_3V0@3oool00:X0n_3V
0P000?l<0?[`iP030<f5?`3jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V
0?[`iP0G0?[`iP030000003jl>H0n_3V03d0n_3V00<0cHDo0?[`iP3jl>H0303jl>H20000ojT0n_3V
0@3oool00:`0n_3V00<0003o0?[`iP3jl>H02P3jl>H00`3=QCl0n_3V0?[`iP0M0?[`iP030000003j
l>H0n_3V00<0n_3V00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP0m0?[`iP030<f5?`3j
l>H0n_3V00X0n_3V0P000?n[0?[`iP40oooo002]0?[`iP80003o2`3jl>H20<f5?ad0n_3V00<00000
0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V03/0n_3V0P3=QCl<
0?[`iP030000o`3jl>H0n_3V0:/0n_3V0@3oool00:l0n_3V0P000?l:0?[`iP030<f5?`3jl>H0n_3V
01/0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V
03X0n_3V00<0cHDo0?[`iP3jl>H02P3jl>H20000ojh0n_3V0@3oool00;40n_3V00<0003o0?[`iP3j
l>H0203jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3j
l>H0603jl>H00`000000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V00P0n_3V0P000?n`0?[`iP40
oooo002b0?[`iP80003o2@3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V0080n_3V
00<000000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP0i0?[`iP030<f5?`3jl>H0n_3V00L0n_3V
0P000?nb0?[`iP40oooo002d0?[`iP80003o203jl>H00`3=QCl0n_3V0?[`iP0H0?[`iP030000003j
l>H0n_3V0080n_3V00<000000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP0h0?[`iP030<f5?`3j
l>H0n_3V00L0n_3V00<0003o0?[`iP3jl>H0/P3jl>H10?ooo`00]P3jl>H00`000?l0n_3V0?[`iP06
0?[`iP030<f5?`3jl>H0n_3V01L0n_3V00D000000?[`iP3jl>H0n_3V0000000K0?[`iP030000003j
l>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H01P3jl>H20000okD0n_3V0@3oool00;L0n_3V0P000?l7
0?[`iP80cHDo5`3jl>H01@000000n_3V0?[`iP3jl>H0000001/0n_3V00<000000?[`iP3jl>H0=@3j
l>H20<f5?`L0n_3V0P000?ng0?[`iP40oooo002i0?[`iP80003o1P3jl>H00`3=QCl0n_3V0?[`iP0E
0?[`iP050000003jl>H0n_3V0?[`iP0000006`3jl>H00`000000n_3V0?[`iP0d0?[`iP030<f5?`3j
l>H0n_3V00D0n_3V0P000?ni0?[`iP40oooo002k0?[`iP030000o`3jl>H0n_3V00@0n_3V00<0cHDo
0?[`iP3jl>H0503jl>H01@000000n_3V0?[`iP3jl>H0000001/0n_3V00<000000?[`iP3jl>H0=03j
l>H00`3=QCl0n_3V0?[`iP040?[`iP030000o`3jl>H0n_3V0;T0n_3V0@3oool00;`0n_3V0P000?l5
0?[`iP80cHDo503jl>H01@000000n_3V0?[`iP3jl>H0000001/0n_3V00<000000?[`iP3jl>H0<P3j
l>H20<f5?`D0n_3V0P000?nl0?[`iP40oooo002n0?[`iP80003o1@3jl>H00`3=QCl0n_3V0?[`iP0A
0?[`iP040000003jl>H0n_3V000001`0n_3V00<000000?[`iP3jl>H0<@3jl>H00`3=QCl0n_3V0?[`
iP030?[`iP80003o_P3jl>H10?ooo`00`03jl>H00`000?l0n_3V0?[`iP030?[`iP030<f5?`3jl>H0
n_3V0100n_3V00@000000?[`iP3jl>H00000703jl>H00`000000n_3V0?[`iP0`0?[`iP030<f5?`3j
l>H0n_3V0080n_3V0P000?o00?[`iP40oooo00310?[`iP80003o103jl>H00`3=QCl0n_3V0?[`iP0?
0?[`iP040000003jl>H0n_3V000001`0n_3V00<000000?[`iP3jl>H0;`3jl>H0103=QCl0n_3V0?[`
iP3jl>H20000ol80n_3V0@3oool00<<0n_3V0P000?l30?[`iP80cHDo3`3jl>H010000000n_3V0?[`
iP00000L0?[`iP030000003jl>H0n_3V02d0n_3V0P3=QCl30?[`iP030000o`3jl>H0n_3V0<80n_3V
0@3oool00<D0n_3V0P000?l30?[`iP030<f5?`3jl>H0n_3V00`0n_3V00@000000?[`iP3jl>H00000
703jl>H00`000000n_3V0?[`iP0/0?[`iP040<f5?`3jl>H0n_3V0?[`iP80003oa@3jl>H10?ooo`00
a`3jl>H20000o`80n_3V0P3=QCl<0?[`iP040000003jl>H0n_3V000001`0n_3V00<000000?[`iP3j
l>H0:P3jl>H20<f5?`80n_3V0P000?o70?[`iP40oooo00390?[`iP80003o0P3jl>H20<f5?`X0n_3V
00<000000?[`iP0000007@3jl>H00`000000n_3V0?[`iP0X0?[`iP80cHDo0P3jl>H20000olT0n_3V
0@3oool00</0n_3V0P000?l20?[`iP030<f5?`3jl>H0n_3V00L0n_3V00<000000?[`iP0000007@3j
l>H00`000000n_3V0?[`iP0W0?[`iP030<f5?`3jl>H0n_3V0080003ob`3jl>H10?ooo`00c@3jl>H2
0000o`030?[`iP3=QCl0cHDo00L0n_3V00<000000?[`iP0000007@3jl>H00`000000n_3V0?[`iP0U
0?[`iP80cHDo00<0n_3V0000o`000?l0c@3jl>H10?ooo`00c`3jl>H30000o`80cHDo1@3jl>H00`00
0000n_3V0000000M0?[`iP030000003jl>H0n_3V02<0n_3V0P3=QCl00`3jl>H0003o0000o`3?0?[`
iP40oooo003B0?[`iP<0003o00<0cHDo0?[`iP3jl>H01000000M0?[`iP030000003jl>H0n_3V0240
n_3V0P3=QCl00`3jl>H0003o0000o`3A0?[`iP40oooo003E0?[`iP80003o1P00000L0?[`iP030000
003jl>H0n_3V01l0n_3V0P3=QCl30000om<0n_3V0@3oool00=L0n_3V1P00000L0?[`iP030000003j
l>H0n_3V01d0n_3V0P3=QCl20000omH0n_3V0@3oool00=L0n_3V1P0000000`3=QCl0n_3V0?[`iP0I
0?[`iP030000003jl>H0n_3V01T0n_3V0`3=QCl30000omP0n_3V0@3oool00=P0n_3V10000000103j
l>H0003o0000o`000?lI0?[`iP030000003jl>H0n_3V01L0n_3V00<0cHDo0000o`000?l00P000?oK
0?[`iP40oooo003I0?[`iP8000001@3jl>H40000oaD0n_3V00<000000?[`iP3jl>H04`3jl>H00`3=
QCl0003o0000o`020000oml0n_3V0@3oool00=P0n_3V0`0000090?[`iP@0003o4@3jl>H00`000000
n_3V0?[`iP0?0?[`iP030<f5?`000?l0003o0080003oh`3jl>H10?ooo`00e`3jl>H5000000`0n_3V
10000?l=0?[`iP030000003jl>H0n_3V00/0n_3V1@000?oW0?[`iP40oooo003G0<f5?`D00000403=
QCl=0000o`03000000000?l0003o00/0003oj`3=QCl10?[`iP40oooo003G0?[`iPD00000o`3jl>HH
0?[`iP40oooo003H0?[`iP<00000o`3jl>HI0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00;H0n_3V0P0000000`1VHUh0c<Bk0?[`iP0[0?[`iP060=C<``1VHUh00000
00000029Q7h0i=_BI@3jl>H01P3Dc<<0IV9N000000000000RHAn0>CKdY`0n_3V0@3oool00;P0n_3V
00<0IV9N0000003Le</0:`3jl>H01P1<BDD0`k^c0?[`iP3/h]T0000008V4OVD0n_3V00H0C4U50<>k
/`3jl>H0k>;I00000029Q7jL0?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P000002
0?[`iP040:nXX@1<BDD0000008V4OPL0n_3V00H0g=C;07UeL0000000000008V4OP3<a;/20?[`iP04
0:nXX@1<BDD0000008V4OP80n_3V0P0000020?[`iP80000000D0n_3V0<c4^`000000NGE`0?[`iP02
00000080n_3V0P0000000`1VHUh0n_3V0?[`iP070?[`iP8000000`3jl>H0103<a;/0C4U506IRGP3T
fm82000000030?[`iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V
0P0000020?[`iP8000000P3jl>H00`29Q7h0IV9N0<c4^`02000000L0n_3V00D0g=C;07UeL0000000
C4U50:BMUP020?[`iP040<c4^`1<BDD0IV9N0>CKdP80000000<0n_3V000000000000103jl>H00`2T
WIH000000:BMUP030?[`iP040:nXX@1<BDD0000008V4OPL0n_3V00@0[jRQ04a9A@1<BDD0[jRQ0P3j
l>H2000000H0n_3V0P0000001@3jl>H0`k^c00000033^k<0n_3V0080000000D0n_3V0<c4^`1<BDD0
C4U50:nXX@02000000030?[`iP000000000000<0n_3V0P0000001@3jl>H0c<Bk04a9A@1<BDD0[jRQ
00800000103jl>H2000000030>cRf@3jl>H0k>;I008000000P3jl>H00`29Q7h0IV9N0<c4^`020000
00030?[`iP00000000000080n_3V0P0000020?[`iP040:nXX@1<BDD0000008V4OP80n_3V00L0k>;I
09NAR`000000000007UeL03Tfm80n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P00
00020?[`iP80000000L0n_3V0:nXX@000000`k^c0>CKdP000000RHAn00D0n_3V00D0i=_B0000002G
TH/0n_3V0;VbZP02000000080?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP3jl>H200000080n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0<c4^`0000000P0000000`3Tfm80n_3V
0?[`iP060?[`iP8000000`3jl>H0101VHUh000000>CKdP2i/ZX2000000030?[`iP000000000000<0
n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000D0n_3V0:BM
UP000000`k^c0:BMUP02000000H0n_3V00`0i=_B0000002GTH/0n_3V0=C<``000000RHAn0?[`iP1V
HUh000000>CKdP2i/ZX2000000030?[`iP000000000000@0n_3V0`000000203/h]T0n_3V0:nXX@00
0000`k^c0>CKdP000000RHAn1@3jl>H01`2i/ZX000000<>k/`33^k<000000;VbZP3jl>H00P000006
0?[`iP80000000D0n_3V09NAR`000000Ui6;0?[`iP02000000050?[`iP1<BDD000000>CKdP33^k<0
0P0000000`3jl>H00000000000030?[`iP80000000D0n_3V04a9A@000000i=_B0<>k/`02000000@0
n_3V00`0RHAn0000003Dc<<0n_3V0=C<``000000RHAn0?[`iP2TWIH000000<>k/`2TWIH200000003
0?[`iP00000000000080n_3V0P0000003`3jl>H0[jRQ00000033^k<0i=_B00000029Q7h0n_3V07Ue
L0000000i=_B0>cRf@000000IV9N0?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP80
00000P3jl>H2000000030?[`iP1<BDD0000000T0n_3V00<0Ui6;0000003Le</00P3jl>H200000003
0?[`iP1<BDD0000000D0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H200000006
0?[`iP2GTH/0000008V4OP000000[jRQ203jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V
0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00
00000`3jl>H0C4U5000000020?[`iP8000001P3jl>H00`2GTH/000000>CKdP050?[`iP8000000P3j
l>H2000000030?[`iP000000000000<0n_3V00P0^K:Z00000029Q7h000000;VbZP3jl>H0C4U50000
00T0n_3V00L0IV9N0000003jl>H0n_3V0000001VHUh0n_3V008000001P3jl>H2000000050?[`iP1<
BDD0000004a9A@3jl>H00P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
0`3jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP030:nXX@000000000000<00000
00@0[jRQ0?[`iP1<BDD000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
C4U5000000070?[`iP050=C<``2TWIH0000004a9A@3jl>H00P0000240?[`iP40oooo00230?[`iP80
00000`3jl>H200000080n_3V0P0000000`3jl>H0000000000004000000D0n_3V00<0C4U50000003j
l>H00P3jl>H2000000030?[`iP000000000000@0000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000001P3jl>H0C4U50000003/h]T0000006IRGPP0n_3V0P000003
0?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V
000000000000n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000H0n_3V0P00
00060?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V0P1<BDD0103/h]T0C4U504a9
A@3jl>H6000000D0n_3V0P0000020?[`iP80000000<0n_3V0000000000001P3jl>H2000000050>CK
dP000000Ui6;0000003Tfm800P0000001@3jl>H0c<Bk0000002GTH/0i=_B0080000000<0n_3V0000
000000000`3jl>H2000000050?[`iP3<a;/0000009NAR`3Tfm800P0000040?[`iP080=C<``000000
RHAn0?[`iP2GTH/000000=C<``3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V000000000000100000000`3jl>H0c<Bk04a9A@020000000304a9A@3<a;/0n_3V0080
0000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V04a9A@000000
0P3jl>H00`000000IV9N0?[`iP040?[`iP8000000P3jl>H3000000030?[`iP1<BDD000000080n_3V
00<0000006IRGP3jl>H00P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000070=cD
b`000000RHAn0?[`iP29Q7h000000>CKdP070?[`iP8000000`3jl>H200000080n_3V0P0000000`3j
l>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2
000000030?[`iP1<BDD000000080n_3V0P0000060?[`iP8000001P3jl>H200000080n_3V0P000000
0`3jl>H00000000000020?[`iP090<c4^`000000Y9fF0?[`iP2TWIH000000<c4^`1<BDD000000080
n_3V00<0000006IRGP3jl>H0103jl>H01`1VHUh000000?[`iP3jl>H0000006IRGP3jl>H00P000006
0?[`iP80000000D0c<Bk0000003Le</000000<c4^`0200000080n_3V00<0g=C;0:nXX@1iMG000P00
00000`3jl>H00000000000030?[`iP8000000P3jl>H00`3Le</0[jRQ07UeL002000000D0n_3V00D0
000004a9A@3jl>H0C4U5000000020?[`iP0404a9A@000000n_3V0?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP1<BDD000000080n_3V00L0000006IRGP3jl>H0C4U50000001iMG00
c<Bk00<0n_3V0P0000240?[`iP40oooo00230?[`iP8000000`3jl>H20000000;0:BMUP3Tfm800000
06IRGP3jl>H0^K:Z00000033^k<0c<Bk0000002i/ZX01@3jl>H00`1<BDD000000?[`iP050?[`iP07
0;VbZP000000`k^c0<c4^`000000^K:Z0?[`iP02000000050;VbZP3Tfm80000004a9A@3jl>H00P00
00020?[`iP80000000L0[jRQ00000033^k<0n_3V0<>k/`000000[jRQ00L0n_3V0P0000030?[`iP80
00000P3jl>H2000000040?[`iP00000000000=C<``80n_3V0P0000001@2i/ZX0i=_B0000001<BDD0
n_3V0080000000`0n_3V000000000000^K:Z0>CKdP000000C4U50?[`iP2TWIH000000<>k/`2TWIH2
000000H0n_3V00<0C4U50000003jl>H01@3jl>H200000080n_3V0P0000004P3jl>H000000000003D
c<<0n_3V06IRGP000000k>;I0?[`iP3/h]T0000006IRGP2i/ZX000000<>k/`3<a;/000000;VbZPD0
n_3V00L0^K:Z00000033^k<0`k^c0000002i/ZX0n_3V008000001P3jl>H2000000050:BMUP1VHUh0
n_3V06IRGP2TWIH00P000000203jl>H0NGE`0=C<``3jl>H0i=_B0000001<BDD0n_3V0P0000000`3D
c<<0n_3V0?[`iP02000000070?[`iP1iMG00e<c30?[`iP3Tfm80000004a9A@050?[`iP0507UeL000
0000c<Bk0000001VHUh00P3jl>H0102TWIH000000<>k/`2TWIH20000000F0?[`iP00000000000;Vb
ZP3Tfm80000004a9A@3jl>H0^K:Z00000033^k<0c<Bk0000002i/ZX0n_3V06IRGP000000n_3V0>CK
dP000000NGE`0?[`iP800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P000000103Le</0RHAn
04a9A@3<a;/20?[`iP040:nXX@00000000000:nXX@H0n_3V00<0Ui6;0000003Tfm801P3jl>H0102_
Z:4000000000002_Z:420?[`iP80000000@0c<Bk07UeL01<BDD0c<Bk100000002P3jl>H000000000
001VHUh000000>cRf@3jl>H0k>;I0000001VHUh70?[`iP8000000`3jl>H200000080n_3V0P000000
1P3jl>H0000000000029Q7h0NGE`0?[`iP80000000D0c<Bk07UeL01<BDD0c<Bk0?[`iP0200000007
0?[`iP00000000000<c4^`1iMG00C4U50<c4^`020?[`iP0308V4OP1VHUh0c<Bk008000001P3jl>H0
0`2GTH/000000>CKdP050?[`iP8000000P3jl>H2000000040?[`iP000000000008V4OP80000000P0
RHAn0?[`iP3jl>H0n_3V08V4OP000000g=C;0:nXX@80000000<0[jRQ0?[`iP3jl>H01@3jl>H01@2_
Z:40C4U50000002_Z:40n_3V00@000001@3jl>H20000000506IRGP2TWIH0n_3V09NAR`1VHUh00P00
00000`3jl>H0i=_B08V4OP020000000306IRGP3Dc<<0n_3V0080000000<0RHAn07UeL03jl>H00P00
00000`3jl>H0i=_B08V4OP020000000306IRGP3Dc<<0n_3V00@0n_3V00D0Y9fF00000029Q7h00000
0:BMUP030?[`iP0308V4OP1VHUh0c<Bk0080000000L0n_3V000000000000c<Bk07UeL01<BDD0c<Bk
0080n_3V00@0[jRQ000000000000[jRQ0P3jl>H01`3Tfm80NGE`000000000000RHAn0>CKdP3jl>H0
0P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000100n_3V00L0i=_B0000002GTH/0n_3V
0=C<``000000NGE`00l0n_3V0P0000020?[`iP8000003P3jl>H2000002`0n_3V00L0i=_B0000002G
TH/0n_3V0=C<``000000RHAn02D0n_3V0P0000060?[`iP<0000000<0c<Bk0?[`iP33^k<00`00000K
0?[`iP050<c4^`000000000000000033^k<0Y03jl>H10?ooo`00P@3jl>H6000000030?[`iP000000
00000140n_3V00H0g=C;07UeL0000000000009NAR`3/h]T?0?[`iP040=cDb`29Q7h0n_3V0?[`iP80
0000303jl>H6000001@0n_3V0P00000E0?[`iP050=cDb`1iMG0000000000002TWIH09P3jl>H0103<
a;/0IV9N00000029Q7h40?[`iP<0000000<0k>;I0?[`iP3Le</00`00000=0?[`iP800000303jl>H0
1@3/h]T00000000000000000i=_B01h0n_3V0P0000240?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.47826 .38333 L
s
.47826 .05 m
.47826 .38333 L
s
.47835 .38192 m
.47826 .38192 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.47826 .38333 Mdot
.47835 .38192 Mdot
.47826 .38192 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V00<0cHDo0000003=QCl01`3=QCl20?[`
iP030000003jl>H0n_3V00X0cHDok@3jl>H10?ooo`00i`3jl>H60<f5?`030?[`iP000000n_3V00T0
n_3V00<000000?[`iP3jl>H02P3jl>H70<f5?nH0n_3V0@3oool00>D0n_3V0P3=QCl70?[`iP030000
003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H04@3jl>H20<f5?n@0n_3V0@3oool00>40n_3V103=
QCl90?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H04`3jl>H30<f5?n40n_3V0@3o
ool00=d0n_3V103=QCl=0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H05P3jl>H4
0<f5?md0n_3V0@3oool00=/0n_3V0P3=QClA0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`
iP3jl>H06P3jl>H20<f5?m/0n_3V0@3oool00=T0n_3V0P3=QClC0?[`iP030000003jl>H0n_3V00P0
n_3V00<000000?[`iP3jl>H0703jl>H20<f5?mT0n_3V0@3oool00=L0n_3V0P3=QClE0?[`iP030000
003jl>H0n_3V00L0n_3V0P00000P0?[`iP80cHDoe`3jl>H10?ooo`00e@3jl>H20<f5?aL0n_3V00<0
00000?[`iP3jl>H01`3jl>H200000280n_3V0P3=QCoE0?[`iP40oooo003C0?[`iP80cHDo6@3jl>H0
0`000000n_3V0?[`iP070?[`iP800000903jl>H20<f5?m<0n_3V0@3oool00=40n_3V0P3=QClK0?[`
iP030000003jl>H0n_3V00L0n_3V0P00000V0?[`iP80cHDod@3jl>H10?ooo`00c`3jl>H20<f5?ad0
n_3V00<000000?[`iP3jl>H01`3jl>H2000002P0n_3V0P3=QCo?0?[`iP40oooo003>0?[`iP030<f5
?`3jl>H0n_3V01d0n_3V00<000000?[`iP3jl>H01`3jl>H2000002X0n_3V00<0cHDo0?[`iP3jl>H0
c03jl>H10?ooo`00c03jl>H20<f5?b00n_3V00<000000?[`iP3jl>H01`3jl>H2000002/0n_3V0P3=
QCo<0?[`iP40oooo003:0?[`iP80cHDo8P3jl>H00`000000n_3V0?[`iP070?[`iP800000;@3jl>H2
0<f5?lX0n_3V0@3oool00<T0n_3V00<0cHDo0?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP070?[`
iP800000;`3jl>H00`3=QCl0n_3V0?[`iP370?[`iP40oooo00370?[`iP80cHDo9@3jl>H00`000000
n_3V0?[`iP070?[`iP800000<03jl>H20<f5?lL0n_3V0@3oool00<H0n_3V00<0cHDo0?[`iP3jl>H0
9@3jl>H00`000000n_3V0?[`iP070?[`iP800000<P3jl>H00`3=QCl0n_3V0?[`iP340?[`iP40oooo
00350?[`iP030<f5?`3jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H01`3jl>H2000003<0n_3V00<0
cHDo0?[`iP3jl>H0``3jl>H10?ooo`00a03jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP030000003jl>H0
n_3V00L0n_3V0P00000d0?[`iP030<f5?`3jl>H0n_3V0<80n_3V0@3oool00<80n_3V0P3=QClZ0?[`
iP030000003jl>H0n_3V00L0n_3V0P00000e0?[`iP80cHDo`P3jl>H10?ooo`00`@3jl>H00`3=QCl0
n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V00L0n_3V0P00000f0?[`iP030<f5?`3jl>H0n_3V0<00
n_3V0@3oool00<00n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP060?[`iP030000
003jl>H0000003L0n_3V00<0cHDo0?[`iP3jl>H0_`3jl>H10?ooo`00_`3jl>H00`3=QCl0n_3V0?[`
iP0/0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP000000>03jl>H20<f5?kl0n_3V0@3o
ool00;h0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0
000003X0n_3V00<0cHDo0?[`iP3jl>H0_03jl>H10?ooo`00_@3jl>H00`3=QCl0n_3V0?[`iP0^0?[`
iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP000000>`3jl>H00`3=QCl0n_3V0?[`iP2k0?[`
iP40oooo002l0?[`iP030<f5?`3jl>H0n_3V02l0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000
n_3V0000000l0?[`iP030<f5?`3jl>H0n_3V0;X0n_3V0@3oool00;/0n_3V00<0cHDo0?[`iP3jl>H0
<03jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0000003`0n_3V00<0cHDo0?[`iP3jl>H0
^P3jl>H10?ooo`00^P3jl>H00`3=QCl0n_3V0?[`iP0a0?[`iP030000003jl>H0n_3V00H0n_3V00<0
00000?[`iP000000?@3jl>H00`3=QCl0n_3V0?[`iP2i0?[`iP40oooo002i0?[`iP030<f5?`3jl>H0
n_3V0380n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0000000n0?[`iP80cHDo^@3jl>H1
0?ooo`00^03jl>H00`3=QCl0n_3V0?[`iP0c0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`
iP000000?`3jl>H00`3=QCl0n_3V0?[`iP2g0?[`iP40oooo002h0?[`iP030<f5?`3jl>H0n_3V03<0
n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V000000100?[`iP030<f5?`3jl>H0n_3V0;H0
n_3V0@3oool00;L0n_3V00<0cHDo0?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP060?[`iP030000
003jl>H000000440n_3V00<0cHDo0?[`iP3jl>H0]@3jl>H10?ooo`00]P3jl>H00`3=QCl0n_3V0?[`
iP0e0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP000000@@3jl>H00`3=QCl0n_3V0?[`
iP2e0?[`iP40oooo002f0?[`iP030<f5?`3jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H01P3jl>H0
0`000000n_3V000000120?[`iP030<f5?`3jl>H0n_3V0;@0n_3V0@3oool00;D0n_3V00<0cHDo0?[`
iP3jl>H0=P3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0000004<0n_3V00<0cHDo0?[`
iP3jl>H0/`3jl>H10?ooo`00]03jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V00H0
n_3V00<000000?[`iP000000A03jl>H00`3=QCl0n_3V0?[`iP2b0?[`iP40oooo002c0?[`iP030<f5
?`3jl>H0n_3V03P0n_3V00<000000?[`iP3jl>H01@3jl>H010000000n_3V0?[`iP0000150?[`iP03
0<f5?`3jl>H0n_3V0;40n_3V0@3oool00;80n_3V00<0cHDo0?[`iP3jl>H0>@3jl>H00`000000n_3V
0?[`iP050?[`iP040000003jl>H0n_3V000004D0n_3V00<0cHDo0?[`iP3jl>H0/@3jl>H10?ooo`00
/P3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V00D0n_3V00@000000?[`iP3jl>H0
0000AP3jl>H00`3=QCl0n_3V0?[`iP2`0?[`iP40oooo002a0?[`iP030<f5?`3jl>H0n_3V03X0n_3V
00<000000?[`iP3jl>H01@3jl>H010000000n_3V0?[`iP0000160?[`iP030<f5?`3jl>H0n_3V0;00
n_3V0@3oool00;40n_3V00<0cHDo0?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP050?[`iP040000
003jl>H0n_3V000004L0n_3V00<0cHDo0?[`iP3jl>H0[`3jl>H10?ooo`00/03jl>H00`3=QCl0n_3V
0?[`iP0k0?[`iP030000003jl>H0n_3V00D0n_3V00@000000?[`iP3jl>H00000A`3jl>H00`3=QCl0
n_3V0?[`iP2_0?[`iP40oooo002`0?[`iP030<f5?`3jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H0
1@3jl>H010000000n_3V0?[`iP0000180?[`iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool00:l0n_3V
00<0cHDo0?[`iP3jl>H0?03jl>H00`000000n_3V0?[`iP050?[`iP040000003jl>H0n_3V000004P0
n_3V00<0cHDo0?[`iP3jl>H0[P3jl>H10?ooo`00[`3jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP030000
003jl>H0n_3V00D0n_3V00@000000?[`iP3jl>H00000B@3jl>H00`3=QCl0n_3V0?[`iP2]0?[`iP40
oooo002^0?[`iP030<f5?`3jl>H0n_3V03d0n_3V00<000000?[`iP3jl>H01@3jl>H010000000n_3V
0?[`iP00001:0?[`iP030<f5?`3jl>H0n_3V0:`0n_3V0@3oool00:d0n_3V00<0cHDo0?[`iP3jl>H0
?P3jl>H00`000000n_3V0?[`iP050?[`iP040000003jl>H0n_3V000004X0n_3V00<0cHDo0?[`iP3j
l>H0[03jl>H10?ooo`00[@3jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V00D0n_3V
00@000000?[`iP3jl>H00000B`3jl>H00`3=QCl0n_3V0?[`iP2[0?[`iP40oooo002/0?[`iP030<f5
?`3jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H01@3jl>H010000000n_3V0?[`iP00001;0?[`iP03
0<f5?`3jl>H0n_3V0:/0n_3V0@3oool00:`0n_3V00<0cHDo0?[`iP3jl>H0?`3jl>H00`000000n_3V
0?[`iP050?[`iP040000003jl>H0n_3V000004`0n_3V00<0cHDo0?[`iP3jl>H0ZP3jl>H10?ooo`00
0P000?nZ0?[`iP030<f5?`3jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H01@3jl>H010000000n_3V
0?[`iP00001<0?[`iP030<f5?`3jl>H0n_3V0:L0n_3V0P000?l10?[`iP40oooo00020?[`iP<0003o
Y`3jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001<0?[`iP030<f5?`3jl>H0n_3V0:@0n_3V0`000?l30?[`iP40oooo00050?[`iP@0003o
XP3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001<0?[`iP030<f5?`3jl>H0n_3V0:00n_3V10000?l60?[`iP40oooo00090?[`iP<0003o
W`3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001=0?[`iP030<f5?`3jl>H0n_3V09`0n_3V0`000?l:0?[`iP40oooo000<0?[`iP<0003o
V`3jl>H00`3=QCl0n_3V0?[`iP110?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001=0?[`iP030<f5?`3jl>H0n_3V09T0n_3V0`000?l=0?[`iP40oooo000?0?[`iP@0003o
U`3jl>H00`3=QCl0n_3V0?[`iP110?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001>0?[`iP030<f5?`3jl>H0n_3V09@0n_3V10000?l@0?[`iP40oooo000C0?[`iP<0003o
U03jl>H00`3=QCl0n_3V0?[`iP110?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001>0?[`iP030<f5?`3jl>H0n_3V0940n_3V0`000?lD0?[`iP40oooo000F0?[`iP<0003o
T@3jl>H00`3=QCl0n_3V0?[`iP110?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001>0?[`iP030<f5?`3jl>H0n_3V08h0n_3V0`000?lG0?[`iP40oooo000I0?[`iP<0003o
S@3jl>H00`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001>0?[`iP030<f5?`3jl>H0n_3V08/0n_3V0`000?lJ0?[`iP40oooo000L0?[`iP<0003o
RP3jl>H00`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001?0?[`iP030<f5?`3jl>H0n_3V08L0n_3V0`000?lM0?[`iP40oooo000O0?[`iP@0003o
QP3jl>H00`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001?0?[`iP030<f5?`3jl>H0n_3V08@0n_3V0`000?lP0?[`iP40oooo000S0?[`iP<0003o
P`3jl>H00`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001?0?[`iP030<f5?`3jl>H0n_3V0840n_3V0`000?lS0?[`iP40oooo000V0?[`iP<0003o
O`3jl>H00`3=QCl0n_3V0?[`iP130?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001?0?[`iP030<f5?`3jl>H0n_3V07h0n_3V0`000?lV0?[`iP40oooo000Y0?[`iP<0003o
O03jl>H00`3=QCl0n_3V0?[`iP130?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001@0?[`iP030<f5?`3jl>H0n_3V07X0n_3V0`000?lY0?[`iP40oooo000/0?[`iP80003o
NP3jl>H00`3=QCl0n_3V0?[`iP130?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001@0?[`iP030<f5?`3jl>H0n_3V07P0n_3V0P000?l/0?[`iP40oooo000^0?[`iP80003o
N03jl>H00`3=QCl0n_3V0?[`iP130?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0
n_3V0000001@0?[`iP030<f5?`3jl>H0n_3V07H0n_3V0P000?l^0?[`iP40oooo000`0?[`iP<0003o
M03jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0
0P3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V07<0n_3V0`000?l`0?[`iP40oooo
000c0?[`iP80003oLP3jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V00<0n_3V00<0
00000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V0700n_3V0P00
0?lc0?[`iP40oooo000e0?[`iP80003oL03jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0
n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0
n_3V06h0n_3V0P000?le0?[`iP40oooo000g0?[`iP<0003oK@3jl>H00`3=QCl0n_3V0?[`iP140?[`
iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP1?0?[`
iP030<f5?`3jl>H0n_3V06/0n_3V0`000?lg0?[`iP40oooo000j0?[`iP80003oJ`3jl>H00`3=QCl0
n_3V0?[`iP140?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000
n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06T0n_3V0P000?lj0?[`iP40oooo000l0?[`iP80003o
J@3jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0
0P3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06L0n_3V0P000?ll0?[`iP40oooo
000n0?[`iP<0003oI@3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V00<0n_3V00<0
00000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V06@0n_3V0`00
0?ln0?[`iP40oooo00110?[`iP80003oH`3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0
n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0
n_3V0640n_3V0P000?m10?[`iP40oooo00130?[`iP80003oH@3jl>H00`3=QCl0n_3V0?[`iP150?[`
iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP1@0?[`
iP030<f5?`3jl>H0n_3V05l0n_3V0P000?m30?[`iP40oooo00150?[`iP80003oG`3jl>H00`3=QCl0
n_3V0?[`iP150?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000
n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05d0n_3V0P000?m50?[`iP40oooo00170?[`iP80003o
G@3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0
0P3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05/0n_3V0P000?m70?[`iP40oooo
00190?[`iP<0003oFP3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V00<0n_3V00<0
00000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V05T0n_3V0P00
0?m90?[`iP40oooo001<0?[`iP80003oF03jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0
n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0
n_3V05L0n_3V0P000?m;0?[`iP40oooo001>0?[`iP80003oEP3jl>H00`3=QCl0n_3V0?[`iP150?[`
iP030000003jl>H0n_3V00<0n_3V00@000000?[`iP3jl>H0n_3V0`00001A0?[`iP030<f5?`3jl>H0
n_3V05D0n_3V0P000?m=0?[`iP40oooo001@0?[`iP80003oE03jl>H00`3=QCl0n_3V0?[`iP150?[`
iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H01@00001@0?[`iP030<f5?`3jl>H0n_3V
05<0n_3V0P000?m?0?[`iP40oooo001B0?[`iP80003oDP3jl>H00`3=QCl0n_3V0?[`iP150?[`iP03
0000003jl>H0n_3V0080n_3V00@000000?[`iP3jl>H0n_3V1@00001@0?[`iP030<f5?`3jl>H0n_3V
0540n_3V0P000?mA0?[`iP40oooo001D0?[`iP80003oD03jl>H00`3=QCl0n_3V0?[`iP150?[`iP03
0000003jl>H0n_3V0080n_3V00@000000?[`iP3jl>H0n_3V1@00001@0?[`iP030<f5?`3jl>H0n_3V
04l0n_3V0P000?mC0?[`iP40oooo001F0?[`iP80003oCP3jl>H00`3=QCl0n_3V0?[`iP150?[`iP03
0000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00P3jl>H300000540n_3V00<0cHDo0?[`iP3j
l>H0C@3jl>H20000oeD0n_3V0@3oool005P0n_3V0P000?m<0?[`iP030<f5?`3jl>H0n_3V04D0n_3V
00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0500n_3V
00<0cHDo0?[`iP3jl>H0B`3jl>H20000oeL0n_3V0@3oool005X0n_3V00<0003o0?[`iP3jl>H0B@3j
l>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3j
l>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04T0n_3V0P000?mI0?[`iP40oooo001K
0?[`iP80003oB@3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V0080n_3V00<00000
0?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V04L0n_3V0P000?mK
0?[`iP40oooo001M0?[`iP80003oA`3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V
0080n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V
04D0n_3V0P000?mM0?[`iP40oooo001O0?[`iP80003oA@3jl>H00`3=QCl0n_3V0?[`iP150?[`iP03
0000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP1@0?[`iP03
0<f5?`3jl>H0n_3V04<0n_3V0P000?mO0?[`iP40oooo001Q0?[`iP030000o`3jl>H0n_3V0480n_3V
00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00<0n_3V
00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP110?[`iP80003oH@3jl>H10?ooo`00HP3j
l>H20000od80n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP020?[`iP030000003j
l>H0n_3V00<0n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP80003oH`3j
l>H10?ooo`00I03jl>H20000od00n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP02
0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0n
0?[`iP80003oI@3jl>H10?ooo`00IP3jl>H20000ocl0n_3V00<0cHDo0?[`iP3jl>H0A03jl>H00`00
0000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=
QCl0n_3V0?[`iP0l0?[`iP80003oI`3jl>H10?ooo`00J03jl>H00`000?l0n_3V0?[`iP0l0?[`iP03
0<f5?`3jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP030?[`iP03
0000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H00`000?l0n_3V0?[`iP1W0?[`iP40
oooo001Y0?[`iP80003o?03jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V0080n_3V
00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V03T0n_3V
0P000?mZ0?[`iP40oooo001[0?[`iP80003o>P3jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003j
l>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3j
l>H0n_3V03P0n_3V00<0003o0?[`iP3jl>H0JP3jl>H10?ooo`00K@3jl>H00`000?l0n_3V0?[`iP0g
0?[`iP030<f5?`3jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP03
0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0=P3jl>H20000ofd0n_3V0@3oool0
06h0n_3V0P000?lg0?[`iP030<f5?`3jl>H0n_3V04@0n_3V00D000000?[`iP3jl>H0n_3V00000006
0?[`iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0=@3jl>H20000ofl0n_3V0@3oool0
0700n_3V0P000?lf0?[`iP030<f5?`3jl>H0n_3V04<0n_3V00D000000?[`iP3jl>H0n_3V00000006
0?[`iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H0=03jl>H00`000?l0n_3V0?[`iP1_
0?[`iP40oooo001b0?[`iP030000o`3jl>H0n_3V03<0n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H01@00
0000n_3V0?[`iP3jl>H0000000H0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0b
0?[`iP80003oLP3jl>H10?ooo`00L`3jl>H20000oc<0n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H01@00
0000n_3V0?[`iP3jl>H0000000H0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0a
0?[`iP030000o`3jl>H0n_3V0780n_3V0@3oool007D0n_3V0P000?la0?[`iP030<f5?`3jl>H0n_3V
04<0n_3V00D000000?[`iP3jl>H0n_3V000000060?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo
0?[`iP3jl>H0<03jl>H20000ogD0n_3V0@3oool007L0n_3V00<0003o0?[`iP3jl>H0;`3jl>H00`3=
QCl0n_3V0?[`iP120?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000n_3V0?[`iP1=
0?[`iP030<f5?`3jl>H0n_3V02h0n_3V0P000?mg0?[`iP40oooo001h0?[`iP80003o;`3jl>H00`3=
QCl0n_3V0?[`iP120?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000n_3V0?[`iP1=
0?[`iP030<f5?`3jl>H0n_3V02d0n_3V00<0003o0?[`iP3jl>H0M`3jl>H10?ooo`00NP3jl>H20000
obd0n_3V00<0cHDo0?[`iP3jl>H0@P3jl>H01@000000n_3V0?[`iP3jl>H0000000H0n_3V00<00000
0?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP80003oNP3jl>H10?ooo`00O03jl>H00`00
0?l0n_3V0?[`iP0Z0?[`iP030<f5?`3jl>H0n_3V0480n_3V00D000000?[`iP3jl>H0n_3V00000006
0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`000?l0n_3V0?[`iP1j
0?[`iP40oooo001m0?[`iP80003o:`3jl>H00`3=QCl0n_3V0?[`iP110?[`iP050000003jl>H0n_3V
0?[`iP0000001P3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02T0n_3V0P000?mm
0?[`iP40oooo001o0?[`iP80003o:@3jl>H00`3=QCl0n_3V0?[`iP110?[`iP050000003jl>H0n_3V
0?[`iP0000001P3jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02L0n_3V0P000?mo
0?[`iP40oooo00210?[`iP030000o`3jl>H0n_3V02H0n_3V00<0cHDo0?[`iP3jl>H0@@3jl>H01@00
0000n_3V0?[`iP3jl>H0000000H0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0V
0?[`iP030000o`3jl>H0n_3V07l0n_3V0@3oool00880n_3V0P000?lV0?[`iP030<f5?`3jl>H0n_3V
0440n_3V00D000000?[`iP3jl>H0n_3V000000060?[`iP030000003jl>H0n_3V04/0n_3V00<0cHDo
0?[`iP3jl>H09@3jl>H20000oh80n_3V0@3oool008@0n_3V0P000?lU0?[`iP030<f5?`3jl>H0n_3V
0400n_3V00D000000?[`iP3jl>H0n_3V000000060?[`iP030000003jl>H0n_3V04/0n_3V00<0cHDo
0?[`iP3jl>H0903jl>H00`000?l0n_3V0?[`iP220?[`iP40oooo00260?[`iP030000o`3jl>H0n_3V
0280n_3V00<0cHDo0?[`iP3jl>H0@03jl>H01@000000n_3V0?[`iP3jl>H0000000H0n_3V00<00000
0?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0S0?[`iP80003oQ@3jl>H10?ooo`00Q`3jl>H20000
ob<0n_3V00<0cHDo0?[`iP3jl>H0?`3jl>H010000000n_3V0?[`iP0000070?[`iP030000003jl>H0
n_3V04X0n_3V00<0cHDo0?[`iP3jl>H08@3jl>H20000ohL0n_3V0@3oool008T0n_3V0P000?lQ0?[`
iP030<f5?`3jl>H0n_3V03l0n_3V00@000000?[`iP3jl>H000001`3jl>H00`000000n_3V0?[`iP1:
0?[`iP030<f5?`3jl>H0n_3V0200n_3V00<0003o0?[`iP3jl>H0Q`3jl>H10?ooo`00R`3jl>H20000
oal0n_3V00<0cHDo0?[`iP3jl>H0?`3jl>H010000000n_3V0?[`iP0000070?[`iP030000003jl>H0
n_3V04X0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H20000ohX0n_3V0@3oool008d0n_3V00<0003o0?[`
iP3jl>H0703jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP040000003jl>H0n_3V000000L0n_3V00<00000
0?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP0N0?[`iP030000o`3jl>H0n_3V08X0n_3V0@3oool0
08h0n_3V0P000?lM0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00@000000?[`iP3jl>H000001`3jl>H0
0`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V01`0n_3V0P000?n=0?[`iP40oooo002@0?[`
iP80003o703jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP040000003jl>H0n_3V000000L0n_3V00<00000
0?[`iP3jl>H0B03jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP80003oS`3jl>H10?ooo`00TP3jl>H00`00
0?l0n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V03d0n_3V00@000000?[`iP3jl>H000001`3jl>H0
0`000000n_3V0?[`iP170?[`iP030<f5?`3jl>H0n_3V01/0n_3V00<0003o0?[`iP3jl>H0S`3jl>H1
0?ooo`00T`3jl>H20000oaX0n_3V00<0cHDo0?[`iP3jl>H0?03jl>H010000000n_3V0?[`iP000007
0?[`iP030000003jl>H0n_3V04L0n_3V00<0cHDo0?[`iP3jl>H06@3jl>H20000oi80n_3V0@3oool0
09D0n_3V00<0003o0?[`iP3jl>H05`3jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP040000003jl>H0n_3V
000000L0n_3V00<000000?[`iP3jl>H0AP3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000o`3jl>H0
n_3V0980n_3V0@3oool009H0n_3V0P000?lH0?[`iP030<f5?`3jl>H0n_3V03/0n_3V00@000000?[`
iP3jl>H000001`3jl>H00`000000n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V01L0n_3V0P000?nE
0?[`iP40oooo002H0?[`iP030000o`3jl>H0n_3V01D0n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H01000
0000n_3V0?[`iP0000070?[`iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H05`3jl>H0
0`000?l0n_3V0?[`iP2E0?[`iP40oooo002I0?[`iP80003o5P3jl>H00`3=QCl0n_3V0?[`iP0j0?[`
iP040000003jl>H0n_3V000000L0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP0E
0?[`iP80003oV03jl>H10?ooo`00V`3jl>H00`000?l0n_3V0?[`iP0C0?[`iP030<f5?`3jl>H0n_3V
03X0n_3V00@000000?[`iP3jl>H000001`3jl>H00`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0
n_3V01D0n_3V00<0003o0?[`iP3jl>H0V03jl>H10?ooo`00W03jl>H20000oa@0n_3V00<0cHDo0?[`
iP3jl>H0>@3jl>H010000000n_3V0?[`iP0000070?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo
0?[`iP3jl>H04`3jl>H20000oi/0n_3V0@3oool009h0n_3V00<0003o0?[`iP3jl>H04P3jl>H00`3=
QCl0n_3V0?[`iP0h0?[`iP040000003jl>H0n_3V000000L0n_3V00<000000?[`iP3jl>H0@`3jl>H0
0`3=QCl0n_3V0?[`iP0C0?[`iP030000o`3jl>H0n_3V09/0n_3V0@3oool009l0n_3V0P000?lB0?[`
iP030<f5?`3jl>H0n_3V03P0n_3V00<000000?[`iP000000203jl>H00`000000n_3V0?[`iP120?[`
iP030<f5?`3jl>H0n_3V0180n_3V0P000?nN0?[`iP40oooo002Q0?[`iP030000o`3jl>H0n_3V0100
n_3V00<0cHDo0?[`iP3jl>H0=`3jl>H00`000000n_3V000000080?[`iP030000003jl>H0n_3V0480
n_3V00<0cHDo0?[`iP3jl>H04@3jl>H00`000?l0n_3V0?[`iP2N0?[`iP40oooo002R0?[`iP80003o
4@3jl>H00`3=QCl0n_3V0?[`iP0f0?[`iP030000003jl>H0000000P0n_3V00<000000?[`iP3jl>H0
@@3jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP80003oX@3jl>H10?ooo`00Y03jl>H00`000?l0n_3V0?[`
iP0?0?[`iP030<f5?`3jl>H0n_3V03D0n_3V00<000000?[`iP000000203jl>H00`000000n_3V0?[`
iP100?[`iP030<f5?`3jl>H0n_3V0100n_3V00<0003o0?[`iP3jl>H0X@3jl>H10?ooo`00Y@3jl>H2
0000o`l0n_3V00<0cHDo0?[`iP3jl>H0=@3jl>H00`000000n_3V000000080?[`iP030000003jl>H0
n_3V03l0n_3V00<0cHDo0?[`iP3jl>H03`3jl>H20000oj@0n_3V0@3oool00:L0n_3V00<0003o0?[`
iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0000000P0n_3V00<000000?[`
iP3jl>H0?`3jl>H00`3=QCl0n_3V0?[`iP0>0?[`iP030000o`3jl>H0n_3V0:@0n_3V0@3oool00:P0
n_3V0P000?l>0?[`iP030<f5?`3jl>H0n_3V03<0n_3V00<000000?[`iP000000203jl>H00`000000
n_3V0?[`iP0n0?[`iP030<f5?`3jl>H0n_3V00d0n_3V0P000?nW0?[`iP40oooo002Z0?[`iP80003o
303jl>H00`3=QCl0n_3V0?[`iP0c0?[`iP030000003jl>H0000000P0n_3V00<000000?[`iP3jl>H0
?@3jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP80003oZ@3jl>H10?ooo`00[03jl>H00`000?l0n_3V0?[`
iP0:0?[`iP030<f5?`3jl>H0n_3V0380n_3V00<000000?[`iP000000203jl>H00`000000n_3V0?[`
iP0m0?[`iP030<f5?`3jl>H0n_3V00X0n_3V0P000?n[0?[`iP40oooo002]0?[`iP80003o2`3jl>H2
0<f5?c80n_3V00<000000?[`iP000000203jl>H00`000000n_3V0?[`iP0k0?[`iP80cHDo303jl>H0
0`000?l0n_3V0?[`iP2[0?[`iP40oooo002_0?[`iP80003o2P3jl>H00`3=QCl0n_3V0?[`iP0`0?[`
iP030000003jl>H0000000P0n_3V00<000000?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`iP0:0?[`
iP80003o[P3jl>H10?ooo`00/@3jl>H00`000?l0n_3V0?[`iP080?[`iP030<f5?`3jl>H0n_3V02l0
n_3V00<000000?[`iP000000203jl>H00`000000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V00P0
n_3V0P000?n`0?[`iP40oooo002b0?[`iP80003o2@3jl>H00`3=QCl0n_3V0?[`iP0^0?[`iP030000
003jl>H0000000P0n_3V00<000000?[`iP3jl>H0>@3jl>H00`3=QCl0n_3V0?[`iP070?[`iP80003o
/P3jl>H10?ooo`00]03jl>H20000o`P0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`000000n_3V0000
00080?[`iP030000003jl>H0n_3V03P0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`
iP2b0?[`iP40oooo002f0?[`iP030000o`3jl>H0n_3V00H0n_3V00<0cHDo0?[`iP3jl>H0;03jl>H0
0`000000n_3V000000080?[`iP030000003jl>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H01P3jl>H2
0000okD0n_3V0@3oool00;L0n_3V0P000?l70?[`iP80cHDo;03jl>H2000000T0n_3V00<000000?[`
iP3jl>H0=@3jl>H20<f5?`L0n_3V0P000?ng0?[`iP40oooo002i0?[`iP80003o1P3jl>H00`3=QCl0
n_3V0?[`iP0Z0?[`iP8000002@3jl>H00`000000n_3V0?[`iP0d0?[`iP030<f5?`3jl>H0n_3V00D0
n_3V0P000?ni0?[`iP40oooo002k0?[`iP030000o`3jl>H0n_3V00@0n_3V00<0cHDo0?[`iP3jl>H0
:@3jl>H2000000T0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000
o`3jl>H0n_3V0;T0n_3V0@3oool00;`0n_3V0P000?l50?[`iP80cHDo:@3jl>H2000000T0n_3V00<0
00000?[`iP3jl>H0<P3jl>H20<f5?`D0n_3V0P000?nl0?[`iP40oooo002n0?[`iP80003o1@3jl>H0
0`3=QCl0n_3V0?[`iP0V0?[`iP8000002@3jl>H00`000000n_3V0?[`iP0a0?[`iP030<f5?`3jl>H0
n_3V00<0n_3V0P000?nn0?[`iP40oooo00300?[`iP030000o`3jl>H0n_3V00<0n_3V00<0cHDo0?[`
iP3jl>H09@3jl>H2000000T0n_3V00<000000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP020?[`
iP80003o`03jl>H10?ooo`00`@3jl>H20000o`@0n_3V00<0cHDo0?[`iP3jl>H0903jl>H2000000T0
n_3V00<000000?[`iP3jl>H0;`3jl>H0103=QCl0n_3V0?[`iP3jl>H20000ol80n_3V0@3oool00<<0
n_3V0P000?l30?[`iP80cHDo903jl>H2000000T0n_3V00<000000?[`iP3jl>H0;@3jl>H20<f5?`<0
n_3V00<0003o0?[`iP3jl>H0`P3jl>H10?ooo`00a@3jl>H20000o`<0n_3V00<0cHDo0?[`iP3jl>H0
8@3jl>H2000000T0n_3V00<000000?[`iP3jl>H0;03jl>H0103=QCl0n_3V0?[`iP3jl>H20000olD0
n_3V0@3oool00<L0n_3V0P000?l20?[`iP80cHDo8@3jl>H2000000T0n_3V00<000000?[`iP3jl>H0
:P3jl>H20<f5?`80n_3V0P000?o70?[`iP40oooo00390?[`iP80003o0P3jl>H20<f5?al0n_3V0P00
00090?[`iP030000003jl>H0n_3V02P0n_3V0P3=QCl20?[`iP80003ob@3jl>H10?ooo`00b`3jl>H2
0000o`80n_3V00<0cHDo0?[`iP3jl>H0703jl>H2000000T0n_3V00<000000?[`iP3jl>H09`3jl>H0
0`3=QCl0n_3V0?[`iP020000ol/0n_3V0@3oool00<d0n_3V0P000?l00`3jl>H0cHDo0<f5?`0L0?[`
iP8000002@3jl>H00`000000n_3V0?[`iP0U0?[`iP80cHDo00<0n_3V0000o`000?l0c@3jl>H10?oo
o`00c`3jl>H30000o`80cHDo6P3jl>H2000000T0n_3V00<000000?[`iP3jl>H08`3jl>H20<f5?`03
0?[`iP000?l0003o0<l0n_3V0@3oool00=80n_3V0`000?l00`3=QCl0n_3V0?[`iP0F0?[`iP800000
2@3jl>H00`000000n_3V0?[`iP0Q0?[`iP80cHDo00<0n_3V0000o`000?l0d@3jl>H10?ooo`00e@3j
l>H20000o`030<f5?`3jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`
iP0O0?[`iP80cHDo0`000?oC0?[`iP40oooo003G0?[`iP<0003o503jl>H00`000000n_3V0?[`iP08
0?[`iP030000003jl>H0n_3V01d0n_3V0P3=QCl20000omH0n_3V0@3oool00=X0n_3V0`000?l00`3=
QCl0n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H06@3jl>H30<f5
?`<0003of03jl>H10?ooo`00g@3jl>H30000o`h0n_3V00<000000?[`iP3jl>H0203jl>H00`000000
n_3V0?[`iP0G0?[`iP030<f5?`000?l0003o0080003of`3jl>H10?ooo`00h03jl>H40000o`X0n_3V
00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0C0?[`iP030<f5?`000?l0003o0080003o
g`3jl>H10?ooo`00i03jl>H40000o`D0n_3V0`0000090?[`iP030000003jl>H0n_3V00l0n_3V00<0
cHDo0000o`000?l00P000?oS0?[`iP40oooo003X0?[`iP@0003o1@0000080?[`iP030000003jl>H0
n_3V00/0n_3V1@000?oW0?[`iP40oooo003/0<f5?`D0000020000?l00`000000003o0000o`0;0000
on/0cHDo0@3jl>H10?ooo`00k03jl>H500000?l0n_3V0`3jl>H10?ooo`00k@3jl>H300000?l0n_3V
103jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo002f0?[`iP800000
00<0IV9N0<c4^`3jl>H0:`3jl>H01P3Dc<<0IV9N000000000000RHAn0>CKdVD0n_3V00H0e<c306IR
GP000000000008V4OP3Tfm:L0?[`iP40oooo002h0?[`iP0306IRGP000000g=C;02/0n_3V00H0C4U5
0<>k/`3jl>H0k>;I00000029Q7iU0?[`iP0604a9A@33^k<0n_3V0>cRf@000000RHAnW03jl>H10?oo
o`00P`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H0102_Z:40C4U500000029Q7h70?[`
iP060=cDb`1iMG00000000000029Q7h0c<Bk0P3jl>H0102_Z:40C4U500000029Q7h20?[`iP800000
0P3jl>H2000000050?[`iP3<a;/0000007UeL03jl>H00P0000020?[`iP80000000<0IV9N0?[`iP3j
l>H01`3jl>H2000000<0n_3V00@0c<Bk04a9A@1VHUh0i=_B0P0000000`3jl>H00000000000030?[`
iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H200000080n_3V00<0RHAn
06IRGP3<a;/00P0000070?[`iP050=cDb`1iMG00000004a9A@2TWIH00P3jl>H0103<a;/0C4U506IR
GP3Tfm82000000030?[`iP000000000000@0n_3V00<0Y9fF0000002TWIH00`3jl>H0102_Z:40C4U5
00000029Q7h70?[`iP040:nXX@1<BDD0C4U50:nXX@80n_3V0P0000060?[`iP80000000D0n_3V0<>k
/`000000`k^c0?[`iP02000000050?[`iP3<a;/0C4U504a9A@2_Z:400P0000000`3jl>H000000000
00030?[`iP80000000D0n_3V0<c4^`1<BDD0C4U50:nXX@02000000@0n_3V0P0000000`3/h]T0n_3V
0>cRf@0200000080n_3V00<0RHAn06IRGP3<a;/00P0000000`3jl>H00000000000020?[`iP800000
0P3jl>H0102_Z:40C4U500000029Q7h20?[`iP070>cRf@2GTH/000000000001iMG00i=_B0?[`iP02
000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2000000070?[`iP2_Z:400000
0<>k/`3Tfm80000008V4OP050?[`iP050>CKdP000000Ui6;0?[`iP2i/ZX00P000000203jl>H0[jRQ
00000033^k<0i=_B00000029Q7h0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP3<a;/000000080000000<0i=_B0?[`iP3jl>H01P3jl>H2000000<0n_3V00@0IV9N
0000003Tfm80^K:Z0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP00
000000000?[`iP8000000P3jl>H2000000050?[`iP2TWIH000000<>k/`2TWIH00P0000060?[`iP0<
0>CKdP000000Ui6;0?[`iP3Dc<<0000008V4OP3jl>H0IV9N0000003Tfm80^K:Z0P0000000`3jl>H0
0000000000040?[`iP<0000000P0k>;I0?[`iP2_Z:4000000<>k/`3Tfm80000008V4OPD0n_3V00L0
^K:Z00000033^k<0`k^c0000002i/ZX0n_3V008000001P3jl>H2000000050?[`iP2GTH/0000009NA
R`3jl>H00P0000001@3jl>H0C4U50000003Tfm80`k^c0080000000<0n_3V0000000000000`3jl>H2
000000050?[`iP1<BDD000000>CKdP33^k<00P0000040?[`iP0<08V4OP000000e<c30?[`iP3Dc<<0
000008V4OP3jl>H0Y9fF00000033^k<0Y9fF0P0000000`3jl>H00000000000020?[`iP80000000l0
n_3V0:nXX@000000`k^c0>CKdP000000RHAn0?[`iP1iMG0000000>CKdP3/h]T0000006IRGP3jl>H0
0P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0C4U50000
00090?[`iP0309NAR`000000g=C;0080n_3V0P0000000`3jl>H0C4U5000000050?[`iP8000000P3j
l>H2000000030?[`iP00000000000080n_3V0P0000001P3jl>H0Ui6;00000029Q7h000000:nXX@P0
n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V0P0000020?[`iP80
000000@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V04a9A@0000000P3jl>H20000
00H0n_3V00<0Ui6;0000003Tfm801@3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`
iP080;VbZP000000RHAn0000002i/ZX0n_3V04a9A@0000090?[`iP0706IRGP000000n_3V0?[`iP00
0000IV9N0?[`iP02000000H0n_3V0P0000001@3jl>H0C4U50000001<BDD0n_3V0080000000<0n_3V
0000000000000P3jl>H2000000030?[`iP000000000000<0n_3V0P0000000`3jl>H0000000000002
0?[`iP800000103jl>H00`2_Z:40000000000003000000040:nXX@3jl>H0C4U500000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V04a9A@0000001`3jl>H01@3Dc<<0Y9fF0000
001<BDD0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0
n_3V000000000000100000050?[`iP0304a9A@000000n_3V0080n_3V0P0000000`3jl>H000000000
0004000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000H0
n_3V04a9A@000000k>;I0000001VHUh80?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0
0000000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000060?[`iP8000001P3jl>H200000080n_3V0P0000000`3j
l>H00000000000030?[`iP80C4U500@0k>;I04a9A@1<BDD0n_3V1P0000050?[`iP8000000P3jl>H2
000000030?[`iP000000000000H0n_3V0P0000001@3Tfm80000009NAR`000000i=_B0080000000D0
n_3V0<c4^`000000Ui6;0>CKdP02000000030?[`iP000000000000<0n_3V0P0000001@3jl>H0c<Bk
0000002GTH/0i=_B00800000103jl>H0203Dc<<0000008V4OP3jl>H0Ui6;0000003Dc<<0n_3V0P00
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0000000<0
n_3V0<c4^`1<BDD00P0000000`1<BDD0c<Bk0?[`iP02000008@0n_3V0@3oool008<0n_3V0P000003
0?[`iP8000000P3jl>H2000000030?[`iP1<BDD000000080n_3V00<0000006IRGP3jl>H0103jl>H2
00000080n_3V0`0000000`3jl>H0C4U5000000020?[`iP030000001VHUh0n_3V008000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000001`3Le</0000008V4OP3jl>H0RHAn0000003Tfm80
1`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H200000080n_3V
0P000000103jl>H000000000003jl>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP80
00001P3jl>H2000000H0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H02@3<a;/0
00000:BMUP3jl>H0Y9fF0000003<a;/0C4U5000000020?[`iP030000001VHUh0n_3V00@0n_3V00L0
IV9N0000003jl>H0n_3V0000001VHUh0n_3V008000001P3jl>H2000000050<c4^`000000g=C;0000
003<a;/00P0000020?[`iP030=cDb`2_Z:40NGE`0080000000<0n_3V0000000000000`3jl>H20000
0080n_3V00<0g=C;0:nXX@1iMG000P0000050?[`iP050000001<BDD0n_3V04a9A@0000000P3jl>H0
101<BDD000000?[`iP3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0C4U50000
00020?[`iP070000001VHUh0n_3V04a9A@000000NGE`0<c4^`030?[`iP800000Q03jl>H10?ooo`00
P`3jl>H2000000<0n_3V0P0000002`2TWIH0i=_B0000001VHUh0n_3V0;VbZP000000`k^c0<c4^`00
0000^K:Z00D0n_3V00<0C4U50000003jl>H01@3jl>H01`2i/ZX000000<>k/`3<a;/000000;VbZP3j
l>H00P0000001@2i/ZX0i=_B0000001<BDD0n_3V008000000P3jl>H2000000070:nXX@000000`k^c
0?[`iP33^k<000000:nXX@070?[`iP8000000`3jl>H200000080n_3V0P000000103jl>H000000000
003Dc<<20?[`iP80000000D0^K:Z0>CKdP000000C4U50?[`iP020000000<0?[`iP00000000000;Vb
ZP3Tfm80000004a9A@3jl>H0Y9fF00000033^k<0Y9fF0P0000060?[`iP0304a9A@000000n_3V00D0
n_3V0P0000020?[`iP8000000180n_3V000000000000e<c30?[`iP1VHUh000000>cRf@3jl>H0k>;I
0000001VHUh0^K:Z00000033^k<0c<Bk0000002i/ZX50?[`iP070;VbZP000000`k^c0<>k/`000000
^K:Z0?[`iP02000000H0n_3V0P0000001@2TWIH0IV9N0?[`iP1VHUh0Y9fF0080000000P0n_3V07Ue
L03Dc<<0n_3V0>CKdP000000C4U50?[`iP80000000<0e<c30?[`iP3jl>H00P0000001`3jl>H0NGE`
0=C<``3jl>H0i=_B0000001<BDD01@3jl>H01@1iMG0000000<c4^`000000IV9N0080n_3V00@0Y9fF
00000033^k<0Y9fF0P0000005P3jl>H000000000002i/ZX0i=_B0000001<BDD0n_3V0;VbZP000000
`k^c0<c4^`000000^K:Z0?[`iP1VHUh000000?[`iP3Tfm80000007UeL03jl>H2000008@0n_3V0@3o
ool008<0n_3V0P0000030?[`iP80000000@0g=C;08V4OP1<BDD0c<Bk0P3jl>H0102_Z:4000000000
002_Z:460?[`iP0309NAR`000000i=_B00H0n_3V00@0[jRQ000000000000[jRQ0P3jl>H200000004
0<c4^`1iMG00C4U50<c4^`@0000000X0n_3V000000000000IV9N0000003/h]T0n_3V0>cRf@000000
IV9N1`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000RHAn07UeL03jl>H2
000000050<c4^`1iMG00C4U50<c4^`3jl>H00P0000001`3jl>H000000000003<a;/0NGE`04a9A@3<
a;/00P3jl>H00`29Q7h0IV9N0<c4^`02000000H0n_3V00<0Ui6;0000003Tfm801@3jl>H200000080
n_3V0P000000103jl>H0000000000029Q7h20000000808V4OP3jl>H0n_3V0?[`iP29Q7h000000=cD
b`2_Z:42000000030:nXX@3jl>H0n_3V00D0n_3V00D0[jRQ04a9A@000000[jRQ0?[`iP04000000D0
n_3V0P0000001@1VHUh0Y9fF0?[`iP2GTH/0IV9N0080000000<0n_3V0>CKdP29Q7h00P0000000`1V
HUh0e<c30?[`iP020000000308V4OP1iMG00n_3V0080000000<0n_3V0>CKdP29Q7h00P0000000`1V
HUh0e<c30?[`iP040?[`iP050:BMUP000000RHAn0000002TWIH00`3jl>H00`29Q7h0IV9N0<c4^`02
000000070?[`iP00000000000<c4^`1iMG00C4U50<c4^`020?[`iP040:nXX@00000000000:nXX@80
n_3V00L0i=_B07UeL0000000000008V4OP3Tfm80n_3V00800000Q03jl>H10?ooo`00P`3jl>H20000
00<0n_3V0P00000@0?[`iP070>CKdP000000Ui6;0?[`iP3Dc<<0000007UeL00?0?[`iP8000000P3j
l>H2000000h0n_3V0P00000/0?[`iP070>CKdP000000Ui6;0?[`iP3Dc<<0000008V4OP0U0?[`iP80
00001P3jl>H3000000030<c4^`3jl>H0`k^c00<000006`3jl>H01@3<a;/00000000000000000`k^c
0:@0n_3V0@3oool00840n_3V1P0000000`3jl>H000000000000A0?[`iP060=cDb`1iMG0000000000
002GTH/0k>;I3`3jl>H0103Le</0RHAn0?[`iP3jl>H2000000`0n_3V1P00000D0?[`iP8000005@3j
l>H01@3Le</0NGE`000000000000Y9fF02H0n_3V00@0c<Bk06IRGP000000RHAn103jl>H300000003
0>cRf@3jl>H0g=C;00<000003@3jl>H2000000`0n_3V00D0k>;I00000000000000000>CKdP0N0?[`
iP800000Q03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.52174 .38333 L
s
.52174 .05 m
.52174 .38333 L
s
.52165 .38192 m
.52174 .38192 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.52174 .38333 Mdot
.52165 .38192 Mdot
.52174 .38192 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V2P3=QCl20?[`iP030000003jl>H0n_3V
00P0cHDo00<000000<f5?`3jl>H0k03jl>H10?ooo`00i`3jl>H60<f5?``0n_3V00<000000?[`iP3j
l>H0203jl>H00`000000n_3V0<f5?`060<f5?nH0n_3V0@3oool00>D0n_3V0P3=QClB0?[`iP030000
003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H01P3jl>H20<f5?n@0n_3V0@3oool00>40n_3V103=
QClD0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H30<f5?n40n_3V0@3o
ool00=d0n_3V103=QClH0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H02`3jl>H4
0<f5?md0n_3V0@3oool00=/0n_3V0P3=QClL0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`
iP3jl>H03`3jl>H20<f5?m/0n_3V0@3oool00=T0n_3V0P3=QClN0?[`iP030000003jl>H0n_3V00P0
n_3V00<000000?[`iP3jl>H04@3jl>H20<f5?mT0n_3V0@3oool00=L0n_3V0P3=QClP0?[`iP800000
2@3jl>H00`000000n_3V0?[`iP0C0?[`iP80cHDoe`3jl>H10?ooo`00e@3jl>H20<f5?b80n_3V0P00
00090?[`iP030000003jl>H0n_3V01D0n_3V0P3=QCoE0?[`iP40oooo003C0?[`iP80cHDo903jl>H2
000000T0n_3V00<000000?[`iP3jl>H05`3jl>H20<f5?m<0n_3V0@3oool00=40n_3V0P3=QClV0?[`
iP8000002@3jl>H00`000000n_3V0?[`iP0I0?[`iP80cHDod@3jl>H10?ooo`00c`3jl>H20<f5?bP0
n_3V0P0000090?[`iP030000003jl>H0n_3V01/0n_3V0P3=QCo?0?[`iP40oooo003>0?[`iP030<f5
?`3jl>H0n_3V02P0n_3V0P0000090?[`iP030000003jl>H0n_3V01d0n_3V00<0cHDo0?[`iP3jl>H0
c03jl>H10?ooo`00c03jl>H20<f5?b/0n_3V0P0000090?[`iP030000003jl>H0n_3V01h0n_3V0P3=
QCo<0?[`iP40oooo003:0?[`iP80cHDo;@3jl>H2000000T0n_3V00<000000?[`iP3jl>H0803jl>H2
0<f5?lX0n_3V0@3oool00<T0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H2000000T0n_3V00<000000?[`
iP3jl>H08P3jl>H00`3=QCl0n_3V0?[`iP370?[`iP40oooo00370?[`iP80cHDo<03jl>H2000000T0
n_3V00<000000?[`iP3jl>H08`3jl>H20<f5?lL0n_3V0@3oool00<H0n_3V00<0cHDo0?[`iP3jl>H0
<03jl>H2000000T0n_3V00<000000?[`iP3jl>H09@3jl>H00`3=QCl0n_3V0?[`iP340?[`iP40oooo
00350?[`iP030<f5?`3jl>H0n_3V0340n_3V0P0000090?[`iP030000003jl>H0n_3V02H0n_3V00<0
cHDo0?[`iP3jl>H0``3jl>H10?ooo`00a03jl>H00`3=QCl0n_3V0?[`iP0b0?[`iP8000002@3jl>H0
0`000000n_3V0?[`iP0W0?[`iP030<f5?`3jl>H0n_3V0<80n_3V0@3oool00<80n_3V0P3=QCle0?[`
iP8000002@3jl>H00`000000n_3V0?[`iP0X0?[`iP80cHDo`P3jl>H10?ooo`00`@3jl>H00`3=QCl0
n_3V0?[`iP0e0?[`iP8000002@3jl>H00`000000n_3V0?[`iP0Y0?[`iP030<f5?`3jl>H0n_3V0<00
n_3V0@3oool00<00n_3V00<0cHDo0?[`iP3jl>H0=P3jl>H00`000000n_3V000000080?[`iP030000
003jl>H0n_3V02X0n_3V00<0cHDo0?[`iP3jl>H0_`3jl>H10?ooo`00_`3jl>H00`3=QCl0n_3V0?[`
iP0g0?[`iP030000003jl>H0000000P0n_3V00<000000?[`iP3jl>H0:`3jl>H20<f5?kl0n_3V0@3o
ool00;h0n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000000n_3V000000080?[`iP030000003jl>H0
n_3V02d0n_3V00<0cHDo0?[`iP3jl>H0_03jl>H10?ooo`00_@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`
iP030000003jl>H0000000P0n_3V00<000000?[`iP3jl>H0;P3jl>H00`3=QCl0n_3V0?[`iP2k0?[`
iP40oooo002l0?[`iP030<f5?`3jl>H0n_3V03X0n_3V00<000000?[`iP000000203jl>H00`000000
n_3V0?[`iP0_0?[`iP030<f5?`3jl>H0n_3V0;X0n_3V0@3oool00;/0n_3V00<0cHDo0?[`iP3jl>H0
>`3jl>H00`000000n_3V000000080?[`iP030000003jl>H0n_3V02l0n_3V00<0cHDo0?[`iP3jl>H0
^P3jl>H10?ooo`00^P3jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP030000003jl>H0000000P0n_3V00<0
00000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP2i0?[`iP40oooo002i0?[`iP030<f5?`3jl>H0
n_3V03d0n_3V00<000000?[`iP000000203jl>H00`000000n_3V0?[`iP0a0?[`iP80cHDo^@3jl>H1
0?ooo`00^03jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP030000003jl>H0000000P0n_3V00<000000?[`
iP3jl>H0<P3jl>H00`3=QCl0n_3V0?[`iP2g0?[`iP40oooo002h0?[`iP030<f5?`3jl>H0n_3V03h0
n_3V00<000000?[`iP000000203jl>H00`000000n_3V0?[`iP0c0?[`iP030<f5?`3jl>H0n_3V0;H0
n_3V0@3oool00;L0n_3V00<0cHDo0?[`iP3jl>H0?`3jl>H00`000000n_3V000000080?[`iP030000
003jl>H0n_3V03@0n_3V00<0cHDo0?[`iP3jl>H0]@3jl>H10?ooo`00]P3jl>H00`3=QCl0n_3V0?[`
iP100?[`iP030000003jl>H0000000P0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`
iP2e0?[`iP40oooo002f0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP000000203jl>H0
0`000000n_3V0?[`iP0e0?[`iP030<f5?`3jl>H0n_3V0;@0n_3V0@3oool00;D0n_3V00<0cHDo0?[`
iP3jl>H0@@3jl>H00`000000n_3V000000080?[`iP030000003jl>H0n_3V03H0n_3V00<0cHDo0?[`
iP3jl>H0/`3jl>H10?ooo`00]03jl>H00`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0000000P0
n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V0?[`iP2b0?[`iP40oooo002c0?[`iP030<f5
?`3jl>H0n_3V04<0n_3V00@000000?[`iP3jl>H000001`3jl>H00`000000n_3V0?[`iP0h0?[`iP03
0<f5?`3jl>H0n_3V0;40n_3V0@3oool00;80n_3V00<0cHDo0?[`iP3jl>H0A03jl>H010000000n_3V
0?[`iP0000070?[`iP030000003jl>H0n_3V03P0n_3V00<0cHDo0?[`iP3jl>H0/@3jl>H10?ooo`00
/P3jl>H00`3=QCl0n_3V0?[`iP140?[`iP040000003jl>H0n_3V000000L0n_3V00<000000?[`iP3j
l>H0>@3jl>H00`3=QCl0n_3V0?[`iP2`0?[`iP40oooo002a0?[`iP030<f5?`3jl>H0n_3V04D0n_3V
00@000000?[`iP3jl>H000001`3jl>H00`000000n_3V0?[`iP0i0?[`iP030<f5?`3jl>H0n_3V0;00
n_3V0@3oool00;40n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H010000000n_3V0?[`iP0000070?[`iP03
0000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H0[`3jl>H10?ooo`00/03jl>H00`3=QCl0n_3V
0?[`iP160?[`iP040000003jl>H0n_3V000000L0n_3V00<000000?[`iP3jl>H0>P3jl>H00`3=QCl0
n_3V0?[`iP2_0?[`iP40oooo002`0?[`iP030<f5?`3jl>H0n_3V04H0n_3V00@000000?[`iP3jl>H0
00001`3jl>H00`000000n_3V0?[`iP0k0?[`iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool00:l0n_3V
00<0cHDo0?[`iP3jl>H0A`3jl>H010000000n_3V0?[`iP0000070?[`iP030000003jl>H0n_3V03/0
n_3V00<0cHDo0?[`iP3jl>H0[P3jl>H10?ooo`00[`3jl>H00`3=QCl0n_3V0?[`iP170?[`iP040000
003jl>H0n_3V000000L0n_3V00<000000?[`iP3jl>H0?03jl>H00`3=QCl0n_3V0?[`iP2]0?[`iP40
oooo002^0?[`iP030<f5?`3jl>H0n_3V04P0n_3V00@000000?[`iP3jl>H000001`3jl>H00`000000
n_3V0?[`iP0m0?[`iP030<f5?`3jl>H0n_3V0:`0n_3V0@3oool00:d0n_3V00<0cHDo0?[`iP3jl>H0
B@3jl>H010000000n_3V0?[`iP0000070?[`iP030000003jl>H0n_3V03d0n_3V00<0cHDo0?[`iP3j
l>H0[03jl>H10?ooo`00[@3jl>H00`3=QCl0n_3V0?[`iP190?[`iP040000003jl>H0n_3V000000L0
n_3V00<000000?[`iP3jl>H0?P3jl>H00`3=QCl0n_3V0?[`iP2[0?[`iP40oooo002/0?[`iP030<f5
?`3jl>H0n_3V04X0n_3V00@000000?[`iP3jl>H000001`3jl>H00`000000n_3V0?[`iP0n0?[`iP03
0<f5?`3jl>H0n_3V0:/0n_3V0@3oool00:`0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H010000000n_3V
0?[`iP0000070?[`iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H0ZP3jl>H10?ooo`00
0P000?nZ0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00@000000?[`iP3jl>H000001`3jl>H00`000000
n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V0:L0n_3V0P000?l10?[`iP40oooo00020?[`iP<0003o
Y`3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V0:@0n_3V0`000?l30?[`iP40oooo00050?[`iP@0003o
XP3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V0:00n_3V10000?l60?[`iP40oooo00090?[`iP<0003o
W`3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP100?[`iP030<f5?`3jl>H0n_3V09`0n_3V0`000?l:0?[`iP40oooo000<0?[`iP<0003o
V`3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP100?[`iP030<f5?`3jl>H0n_3V09T0n_3V0`000?l=0?[`iP40oooo000?0?[`iP@0003o
U`3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP110?[`iP030<f5?`3jl>H0n_3V09@0n_3V10000?l@0?[`iP40oooo000C0?[`iP<0003o
U03jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP110?[`iP030<f5?`3jl>H0n_3V0940n_3V0`000?lD0?[`iP40oooo000F0?[`iP<0003o
T@3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP110?[`iP030<f5?`3jl>H0n_3V08h0n_3V0`000?lG0?[`iP40oooo000I0?[`iP<0003o
S@3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP110?[`iP030<f5?`3jl>H0n_3V08/0n_3V0`000?lJ0?[`iP40oooo000L0?[`iP<0003o
RP3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V08L0n_3V0`000?lM0?[`iP40oooo000O0?[`iP@0003o
QP3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V08@0n_3V0`000?lP0?[`iP40oooo000S0?[`iP<0003o
P`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V0840n_3V0`000?lS0?[`iP40oooo000V0?[`iP<0003o
O`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V07h0n_3V0`000?lV0?[`iP40oooo000Y0?[`iP<0003o
O03jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP130?[`iP030<f5?`3jl>H0n_3V07X0n_3V0`000?lY0?[`iP40oooo000/0?[`iP80003o
NP3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP130?[`iP030<f5?`3jl>H0n_3V07P0n_3V0P000?l/0?[`iP40oooo000^0?[`iP80003o
N03jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP050000003jl>H0n_3V0?[`iP0000001P3jl>H00`000000
n_3V0?[`iP130?[`iP030<f5?`3jl>H0n_3V07H0n_3V0P000?l^0?[`iP40oooo000`0?[`iP<0003o
M03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0
0`3jl>H00`000000n_3V0?[`iP130?[`iP030<f5?`3jl>H0n_3V07<0n_3V0`000?l`0?[`iP40oooo
000c0?[`iP80003oLP3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V0080n_3V00<0
00000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0n_3V0700n_3V0P00
0?lc0?[`iP40oooo000e0?[`iP80003oL03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0
n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0
n_3V06h0n_3V0P000?le0?[`iP40oooo000g0?[`iP<0003oK@3jl>H00`3=QCl0n_3V0?[`iP1?0?[`
iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP140?[`
iP030<f5?`3jl>H0n_3V06/0n_3V0`000?lg0?[`iP40oooo000j0?[`iP80003oJ`3jl>H00`3=QCl0
n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H00`000000
n_3V0?[`iP140?[`iP030<f5?`3jl>H0n_3V06T0n_3V0P000?lj0?[`iP40oooo000l0?[`iP80003o
J@3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0
0`3jl>H00`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0n_3V06L0n_3V0P000?ll0?[`iP40oooo
000n0?[`iP<0003oI@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0080n_3V00<0
00000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP140?[`iP030<f5?`3jl>H0n_3V06@0n_3V0`00
0?ln0?[`iP40oooo00110?[`iP80003oH`3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0
n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0
n_3V0640n_3V0P000?m10?[`iP40oooo00130?[`iP80003oH@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`
iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP150?[`
iP030<f5?`3jl>H0n_3V05l0n_3V0P000?m30?[`iP40oooo00150?[`iP80003oG`3jl>H00`3=QCl0
n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H00`000000
n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V05d0n_3V0P000?m50?[`iP40oooo00170?[`iP80003o
G@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0
0`3jl>H00`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V05/0n_3V0P000?m70?[`iP40oooo
00190?[`iP<0003oFP3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0080n_3V00<0
00000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V05T0n_3V0P00
0?m90?[`iP40oooo001<0?[`iP80003oF03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0
n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0
n_3V05L0n_3V0P000?m;0?[`iP40oooo001>0?[`iP80003oEP3jl>H00`3=QCl0n_3V0?[`iP1?0?[`
iP<000000`3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`
iP3jl>H0E@3jl>H20000odd0n_3V0@3oool00500n_3V0P000?mD0?[`iP030<f5?`3jl>H0n_3V04h0
n_3V1@0000020?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0
n_3V0?[`iP1C0?[`iP80003oC`3jl>H10?ooo`00DP3jl>H20000oe80n_3V00<0cHDo0?[`iP3jl>H0
CP3jl>H500000080n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP150?[`iP030<f5
?`3jl>H0n_3V0540n_3V0P000?mA0?[`iP40oooo001D0?[`iP80003oD03jl>H00`3=QCl0n_3V0?[`
iP1>0?[`iPD000000`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V04D0n_3V00<0
cHDo0?[`iP3jl>H0C`3jl>H20000oe<0n_3V0@3oool005H0n_3V0P000?m>0?[`iP030<f5?`3jl>H0
n_3V04l0n_3V0`0000040?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0A@3jl>H0
0`3=QCl0n_3V0?[`iP1=0?[`iP80003oE@3jl>H10?ooo`00F03jl>H20000od`0n_3V00<0cHDo0?[`
iP3jl>H0D03jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`
iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP80003oE`3jl>H10?ooo`00FP3jl>H00`000?l0
n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H00`3jl>H00`000000
n_3V0?[`iP020?[`iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H20000oeT0
n_3V0@3oool005/0n_3V0P000?m90?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0
0`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H0
A`3jl>H20000oe/0n_3V0@3oool005d0n_3V0P000?m70?[`iP030<f5?`3jl>H0n_3V0500n_3V00<0
00000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V04D0n_3V00<0
cHDo0?[`iP3jl>H0A@3jl>H20000oed0n_3V0@3oool005l0n_3V0P000?m50?[`iP030<f5?`3jl>H0
n_3V0500n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0
n_3V04D0n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H20000oel0n_3V0@3oool00640n_3V00<0003o0?[`
iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`
iP3jl>H00P3jl>H00`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V0440n_3V0P000?mQ0?[`
iP40oooo001R0?[`iP80003o@P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V00<0
n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V03l0
n_3V0P000?mS0?[`iP40oooo001T0?[`iP80003o@03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000
003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP140?[`iP030<f5
?`3jl>H0n_3V03h0n_3V0P000?mU0?[`iP40oooo001V0?[`iP80003o?`3jl>H00`3=QCl0n_3V0?[`
iP1?0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`
iP140?[`iP030<f5?`3jl>H0n_3V03`0n_3V0P000?mW0?[`iP40oooo001X0?[`iP030000o`3jl>H0
n_3V03`0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0
n_3V0080n_3V00<000000?[`iP3jl>H0A03jl>H00`3=QCl0n_3V0?[`iP0k0?[`iP030000o`3jl>H0
n_3V06L0n_3V0@3oool006T0n_3V0P000?ll0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`
iP3jl>H00`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`
iP3jl>H0>@3jl>H20000ofX0n_3V0@3oool006/0n_3V0P000?lj0?[`iP030<f5?`3jl>H0n_3V04l0
n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V04@0
n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000?l0n_3V0?[`iP1Z0?[`iP40oooo001]0?[`iP030000
o`3jl>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP030?[`iP030000
003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0A03jl>H00`3=QCl0n_3V0?[`iP0f0?[`iP80003o
K@3jl>H10?ooo`00KP3jl>H20000ocL0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`
iP040?[`iP050000003jl>H0n_3V0?[`iP000000A@3jl>H00`3=QCl0n_3V0?[`iP0e0?[`iP80003o
K`3jl>H10?ooo`00L03jl>H20000ocH0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`
iP040?[`iP050000003jl>H0n_3V0?[`iP000000A@3jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000
o`3jl>H0n_3V06l0n_3V0@3oool00780n_3V00<0003o0?[`iP3jl>H0<`3jl>H00`3=QCl0n_3V0?[`
iP1>0?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0n_3V000000150?[`iP030<f5
?`3jl>H0n_3V0380n_3V0P000?mb0?[`iP40oooo001c0?[`iP80003o<`3jl>H00`3=QCl0n_3V0?[`
iP1>0?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0n_3V000000150?[`iP030<f5
?`3jl>H0n_3V0340n_3V00<0003o0?[`iP3jl>H0LP3jl>H10?ooo`00M@3jl>H20000oc40n_3V00<0
cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP040?[`iP050000003jl>H0n_3V0?[`iP000000
A03jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP80003oM@3jl>H10?ooo`00M`3jl>H00`000?l0n_3V0?[`
iP0_0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0103jl>H01@000000n_3V0?[`
iP3jl>H0000004@0n_3V00<0cHDo0?[`iP3jl>H0;P3jl>H20000ogL0n_3V0@3oool007P0n_3V0P00
0?l_0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0103jl>H01@000000n_3V0?[`
iP3jl>H0000004@0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`000?l0n_3V0?[`iP1g0?[`iP40oooo
001j0?[`iP80003o;@3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V00@0n_3V00D0
00000?[`iP3jl>H0n_3V000000140?[`iP030<f5?`3jl>H0n_3V02/0n_3V0P000?mj0?[`iP40oooo
001l0?[`iP030000o`3jl>H0n_3V02X0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`
iP040?[`iP050000003jl>H0n_3V0?[`iP000000@`3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP030000
o`3jl>H0n_3V07X0n_3V0@3oool007d0n_3V0P000?l[0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<0
00000?[`iP3jl>H0103jl>H01@000000n_3V0?[`iP3jl>H0000004<0n_3V00<0cHDo0?[`iP3jl>H0
:@3jl>H20000ogd0n_3V0@3oool007l0n_3V0P000?lY0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<0
00000?[`iP3jl>H0103jl>H01@000000n_3V0?[`iP3jl>H0000004<0n_3V00<0cHDo0?[`iP3jl>H0
9`3jl>H20000ogl0n_3V0@3oool00840n_3V00<0003o0?[`iP3jl>H09P3jl>H00`3=QCl0n_3V0?[`
iP1<0?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`iP3jl>H0n_3V000000130?[`iP030<f5
?`3jl>H0n_3V02H0n_3V00<0003o0?[`iP3jl>H0O`3jl>H10?ooo`00PP3jl>H20000obH0n_3V00<0
cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP040?[`iP050000003jl>H0n_3V0?[`iP000000
@P3jl>H00`3=QCl0n_3V0?[`iP0U0?[`iP80003oPP3jl>H10?ooo`00Q03jl>H20000obD0n_3V00<0
cHDo0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP040?[`iP050000003jl>H0n_3V0?[`iP000000
@P3jl>H00`3=QCl0n_3V0?[`iP0T0?[`iP030000o`3jl>H0n_3V0880n_3V0@3oool008H0n_3V00<0
003o0?[`iP3jl>H08P3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V00@0n_3V00D0
00000?[`iP3jl>H0n_3V000000110?[`iP030<f5?`3jl>H0n_3V02<0n_3V0P000?n50?[`iP40oooo
00270?[`iP80003o8`3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V00D0n_3V00@0
00000?[`iP3jl>H00000@@3jl>H00`3=QCl0n_3V0?[`iP0Q0?[`iP80003oQ`3jl>H10?ooo`00R@3j
l>H20000ob40n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP050?[`iP040000003j
l>H0n_3V00000440n_3V00<0cHDo0?[`iP3jl>H0803jl>H00`000?l0n_3V0?[`iP270?[`iP40oooo
002;0?[`iP80003o7`3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V00D0n_3V00@0
00000?[`iP3jl>H00000@@3jl>H00`3=QCl0n_3V0?[`iP0N0?[`iP80003oRP3jl>H10?ooo`00S@3j
l>H00`000?l0n_3V0?[`iP0L0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H01@3j
l>H010000000n_3V0?[`iP0000100?[`iP030<f5?`3jl>H0n_3V01h0n_3V00<0003o0?[`iP3jl>H0
RP3jl>H10?ooo`00SP3jl>H20000oad0n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`
iP050?[`iP040000003jl>H0n_3V00000400n_3V00<0cHDo0?[`iP3jl>H0703jl>H20000ohd0n_3V
0@3oool00900n_3V0P000?lL0?[`iP030<f5?`3jl>H0n_3V04P0n_3V00<000000?[`iP3jl>H01@3j
l>H010000000n_3V0?[`iP00000o0?[`iP030<f5?`3jl>H0n_3V01/0n_3V0P000?n?0?[`iP40oooo
002B0?[`iP030000o`3jl>H0n_3V01T0n_3V00<0cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`
iP050?[`iP040000003jl>H0n_3V000003h0n_3V00<0cHDo0?[`iP3jl>H06`3jl>H00`000?l0n_3V
0?[`iP2?0?[`iP40oooo002C0?[`iP80003o6P3jl>H00`3=QCl0n_3V0?[`iP170?[`iP030000003j
l>H0n_3V00D0n_3V00@000000?[`iP3jl>H00000?P3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP80003o
TP3jl>H10?ooo`00U@3jl>H00`000?l0n_3V0?[`iP0G0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<0
00000?[`iP3jl>H01@3jl>H010000000n_3V0?[`iP00000m0?[`iP030<f5?`3jl>H0n_3V01T0n_3V
00<0003o0?[`iP3jl>H0TP3jl>H10?ooo`00UP3jl>H20000oaP0n_3V00<0cHDo0?[`iP3jl>H0AP3j
l>H00`000000n_3V0?[`iP050?[`iP040000003jl>H0n_3V000003d0n_3V00<0cHDo0?[`iP3jl>H0
5`3jl>H20000oiD0n_3V0@3oool009P0n_3V00<0003o0?[`iP3jl>H05@3jl>H00`3=QCl0n_3V0?[`
iP160?[`iP030000003jl>H0n_3V00D0n_3V00@000000?[`iP3jl>H00000?03jl>H00`3=QCl0n_3V
0?[`iP0G0?[`iP030000o`3jl>H0n_3V09D0n_3V0@3oool009T0n_3V0P000?lF0?[`iP030<f5?`3j
l>H0n_3V04D0n_3V00<000000?[`iP3jl>H01@3jl>H010000000n_3V0?[`iP00000l0?[`iP030<f5
?`3jl>H0n_3V01D0n_3V0P000?nH0?[`iP40oooo002K0?[`iP030000o`3jl>H0n_3V01<0n_3V00<0
cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP050?[`iP040000003jl>H0n_3V000003/0n_3V
00<0cHDo0?[`iP3jl>H05@3jl>H00`000?l0n_3V0?[`iP2H0?[`iP40oooo002L0?[`iP80003o503j
l>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V00D0n_3V00@000000?[`iP3jl>H00000
>`3jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP80003oV`3jl>H10?ooo`00WP3jl>H00`000?l0n_3V0?[`
iP0B0?[`iP030<f5?`3jl>H0n_3V04<0n_3V00<000000?[`iP3jl>H01@3jl>H010000000n_3V0?[`
iP00000j0?[`iP030<f5?`3jl>H0n_3V01<0n_3V00<0003o0?[`iP3jl>H0V`3jl>H10?ooo`00W`3j
l>H20000oa80n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP060?[`iP030000003j
l>H0000003T0n_3V00<0cHDo0?[`iP3jl>H04P3jl>H20000oih0n_3V0@3oool00:40n_3V00<0003o
0?[`iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V00H0n_3V00<00000
0?[`iP000000>@3jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000o`3jl>H0n_3V09h0n_3V0@3oool0
0:80n_3V0P000?lA0?[`iP030<f5?`3jl>H0n_3V0440n_3V00<000000?[`iP3jl>H01P3jl>H00`00
0000n_3V0000000h0?[`iP030<f5?`3jl>H0n_3V0100n_3V0P000?nQ0?[`iP40oooo002T0?[`iP03
0000o`3jl>H0n_3V00l0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP060?[`iP03
0000003jl>H0000003L0n_3V00<0cHDo0?[`iP3jl>H0403jl>H00`000?l0n_3V0?[`iP2Q0?[`iP40
oooo002U0?[`iP80003o3`3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V00H0n_3V
00<000000?[`iP000000=P3jl>H00`3=QCl0n_3V0?[`iP0?0?[`iP80003oY03jl>H10?ooo`00Y`3j
l>H00`000?l0n_3V0?[`iP0=0?[`iP030<f5?`3jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H01P3j
l>H00`000000n_3V0000000f0?[`iP030<f5?`3jl>H0n_3V00h0n_3V00<0003o0?[`iP3jl>H0Y03j
l>H10?ooo`00Z03jl>H20000o`h0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP06
0?[`iP030000003jl>H0000003D0n_3V00<0cHDo0?[`iP3jl>H03@3jl>H20000ojL0n_3V0@3oool0
0:X0n_3V0P000?l<0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H01P3jl>H00`00
0000n_3V0000000d0?[`iP030<f5?`3jl>H0n_3V00`0n_3V0P000?nY0?[`iP40oooo002/0?[`iP03
0000o`3jl>H0n_3V00X0n_3V00<0cHDo0?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP060?[`iP03
0000003jl>H0000003@0n_3V00<0cHDo0?[`iP3jl>H02P3jl>H20000oj/0n_3V0@3oool00:d0n_3V
0P000?l;0?[`iP80cHDo?@3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H000000380n_3V
0P3=QCl<0?[`iP030000o`3jl>H0n_3V0:/0n_3V0@3oool00:l0n_3V0P000?l:0?[`iP030<f5?`3j
l>H0n_3V03/0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0000000a0?[`iP030<f5?`3j
l>H0n_3V00X0n_3V0P000?n^0?[`iP40oooo002a0?[`iP030000o`3jl>H0n_3V00P0n_3V00<0cHDo
0?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H000000340n_3V00<0cHDo
0?[`iP3jl>H0203jl>H20000ok00n_3V0@3oool00;80n_3V0P000?l90?[`iP030<f5?`3jl>H0n_3V
03T0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0000000`0?[`iP030<f5?`3jl>H0n_3V
00L0n_3V0P000?nb0?[`iP40oooo002d0?[`iP80003o203jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP03
0000003jl>H0n_3V00H0n_3V00<000000?[`iP000000;`3jl>H00`3=QCl0n_3V0?[`iP070?[`iP03
0000o`3jl>H0n_3V0;80n_3V0@3oool00;H0n_3V00<0003o0?[`iP3jl>H01P3jl>H00`3=QCl0n_3V
0?[`iP0g0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP000000;P3jl>H00`3=QCl0n_3V
0?[`iP060?[`iP80003o]@3jl>H10?ooo`00]`3jl>H20000o`L0n_3V0P3=QClg0?[`iP030000003j
l>H0n_3V00L0n_3V0P00000/0?[`iP80cHDo1`3jl>H20000okL0n_3V0@3oool00;T0n_3V0P000?l6
0?[`iP030<f5?`3jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H01`3jl>H2000002/0n_3V00<0cHDo
0?[`iP3jl>H01@3jl>H20000okT0n_3V0@3oool00;/0n_3V00<0003o0?[`iP3jl>H0103jl>H00`3=
QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0n_3V00L0n_3V0P00000[0?[`iP030<f5?`3jl>H0n_3V
00@0n_3V00<0003o0?[`iP3jl>H0^@3jl>H10?ooo`00_03jl>H20000o`D0n_3V0P3=QCld0?[`iP03
0000003jl>H0n_3V00L0n_3V0P00000Y0?[`iP80cHDo1@3jl>H20000ok`0n_3V0@3oool00;h0n_3V
0P000?l50?[`iP030<f5?`3jl>H0n_3V0340n_3V00<000000?[`iP3jl>H01`3jl>H2000002P0n_3V
00<0cHDo0?[`iP3jl>H00`3jl>H20000okh0n_3V0@3oool00<00n_3V00<0003o0?[`iP3jl>H00`3j
l>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V00L0n_3V0P00000W0?[`iP030<f5?`3j
l>H0n_3V0080n_3V0P000?o00?[`iP40oooo00310?[`iP80003o103jl>H00`3=QCl0n_3V0?[`iP0_
0?[`iP030000003jl>H0n_3V00L0n_3V0P00000V0?[`iP040<f5?`3jl>H0n_3V0?[`iP80003o`P3j
l>H10?ooo`00``3jl>H20000o`<0n_3V0P3=QCl_0?[`iP030000003jl>H0n_3V00L0n_3V0P00000T
0?[`iP80cHDo0`3jl>H00`000?l0n_3V0?[`iP320?[`iP40oooo00350?[`iP80003o0`3jl>H00`3=
QCl0n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V00L0n_3V0P00000S0?[`iP040<f5?`3jl>H0n_3V
0?[`iP80003oa@3jl>H10?ooo`00a`3jl>H20000o`80n_3V0P3=QCl/0?[`iP030000003jl>H0n_3V
00L0n_3V0P00000Q0?[`iP80cHDo0P3jl>H20000olL0n_3V0@3oool00<T0n_3V0P000?l20?[`iP80
cHDo:P3jl>H00`000000n_3V0?[`iP070?[`iP8000007`3jl>H20<f5?`80n_3V0P000?o90?[`iP40
oooo003;0?[`iP80003o0P3jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V00L0n_3V
0P00000N0?[`iP030<f5?`3jl>H0n_3V0080003ob`3jl>H10?ooo`00c@3jl>H20000o`030?[`iP3=
QCl0cHDo02L0n_3V00<000000?[`iP3jl>H01`3jl>H2000001`0n_3V0P3=QCl00`3jl>H0003o0000
o`3=0?[`iP40oooo003?0?[`iP<0003o0P3=QClU0?[`iP030000003jl>H0n_3V00L0n_3V0P00000J
0?[`iP80cHDo00<0n_3V0000o`000?l0c`3jl>H10?ooo`00dP3jl>H30000o`030<f5?`3jl>H0n_3V
0240n_3V00<000000?[`iP3jl>H01`3jl>H2000001P0n_3V0P3=QCl00`3jl>H0003o0000o`3A0?[`
iP40oooo003E0?[`iP80003o00<0cHDo0?[`iP3jl>H07`3jl>H00`000000n_3V0?[`iP080?[`iP03
0000003jl>H0n_3V01@0n_3V0P3=QCl30000om<0n_3V0@3oool00=L0n_3V0`000?lO0?[`iP030000
003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H04P3jl>H20<f5?`80003oeP3jl>H10?ooo`00fP3j
l>H30000o`030<f5?`3jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`
iP0>0?[`iP<0cHDo0`000?oH0?[`iP40oooo003M0?[`iP<0003o6@3jl>H00`000000n_3V0?[`iP08
0?[`iP030000003jl>H0n_3V00`0n_3V00<0cHDo0000o`000?l00P000?oK0?[`iP40oooo003P0?[`
iP@0003o5@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<0cHDo0000
o`000?l00P000?oO0?[`iP40oooo003T0?[`iP@0003o4@3jl>H00`000000n_3V0?[`iP070?[`iP<0
00001@3jl>H00`3=QCl0003o0000o`020000on<0n_3V0@3oool00>P0n_3V10000?l=0?[`iP030000
003jl>H0n_3V00H0n_3V1@0000050000onL0n_3V0@3oool00>`0cHDo3@000?l00`000000003o0000
o`060000o`D00000j`3=QCl10?[`iP40oooo003o0?[`iP<0n_3V1@00003/0?[`iP40oooo003o0?[`
iP@0n_3V0`00003]0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0;H0n_3V0P0000000`1VHUh0c<Bk0?[`iP0[0?[`iP060=C<``1VHUh0000000000029Q7h0i=_BI@3j
l>H01P3Dc<<0IV9N000000000000RHAn0>CKdY`0n_3V0@3oool00;P0n_3V00<0IV9N0000003Le</0
:`3jl>H01P1<BDD0`k^c0?[`iP3/h]T0000008V4OVD0n_3V00H0C4U50<>k/`3jl>H0k>;I00000029
Q7jL0?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP040:nXX@1<BDD0
000008V4OPL0n_3V00H0g=C;07UeL0000000000008V4OP3<a;/20?[`iP040:nXX@1<BDD0000008V4
OP80n_3V0P0000020?[`iP80000000D0n_3V0<c4^`000000NGE`0?[`iP0200000080n_3V0P000000
0`1VHUh0n_3V0?[`iP070?[`iP8000000`3jl>H0103<a;/0C4U506IRGP3Tfm82000000030?[`iP00
0000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP800000
0P3jl>H00`29Q7h0IV9N0<c4^`02000000L0n_3V00D0g=C;07UeL0000000C4U50:BMUP020?[`iP04
0<c4^`1<BDD0IV9N0>CKdP80000000<0n_3V000000000000103jl>H00`2TWIH000000:BMUP030?[`
iP040:nXX@1<BDD0000008V4OPL0n_3V00@0[jRQ04a9A@1<BDD0[jRQ0P3jl>H2000000H0n_3V0P00
00001@3jl>H0`k^c00000033^k<0n_3V0080000000D0n_3V0<c4^`1<BDD0C4U50:nXX@0200000003
0?[`iP000000000000<0n_3V0P0000001@3jl>H0c<Bk04a9A@1<BDD0[jRQ00800000103jl>H20000
00030>cRf@3jl>H0k>;I008000000P3jl>H00`29Q7h0IV9N0<c4^`02000000030?[`iP0000000000
0080n_3V0P0000020?[`iP040:nXX@1<BDD0000008V4OP80n_3V00L0k>;I09NAR`000000000007Ue
L03Tfm80n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80000000L0
n_3V0:nXX@000000`k^c0>CKdP000000RHAn00D0n_3V00D0i=_B0000002GTH/0n_3V0;VbZP020000
00080?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP3jl>H200000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0<c4^`0000000P0000000`3Tfm80n_3V0?[`iP060?[`iP800000
0`3jl>H0101VHUh000000>CKdP2i/ZX2000000030?[`iP000000000000<0n_3V0P0000020?[`iP80
000000@0n_3V000000000000n_3V0P0000020?[`iP80000000D0n_3V0:BMUP000000`k^c0:BMUP02
000000H0n_3V00`0i=_B0000002GTH/0n_3V0=C<``000000RHAn0?[`iP1VHUh000000>CKdP2i/ZX2
000000030?[`iP000000000000@0n_3V0`000000203/h]T0n_3V0:nXX@000000`k^c0>CKdP000000
RHAn1@3jl>H01`2i/ZX000000<>k/`33^k<000000;VbZP3jl>H00P0000060?[`iP80000000D0n_3V
09NAR`000000Ui6;0?[`iP02000000050?[`iP1<BDD000000>CKdP33^k<00P0000000`3jl>H00000
000000030?[`iP80000000D0n_3V04a9A@000000i=_B0<>k/`02000000@0n_3V00`0RHAn0000003D
c<<0n_3V0=C<``000000RHAn0?[`iP2TWIH000000<>k/`2TWIH2000000030?[`iP00000000000080
n_3V0P0000003`3jl>H0[jRQ00000033^k<0i=_B00000029Q7h0n_3V07UeL0000000i=_B0>cRf@00
0000IV9N0?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H200000003
0?[`iP1<BDD0000000T0n_3V00<0Ui6;0000003Le</00P3jl>H2000000030?[`iP1<BDD0000000D0
n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000060?[`iP2GTH/0000008V4
OP000000[jRQ203jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H2
00000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P0000000`3jl>H0C4U50000
00020?[`iP8000001P3jl>H00`2GTH/000000>CKdP050?[`iP8000000P3jl>H2000000030?[`iP00
0000000000<0n_3V00P0^K:Z00000029Q7h000000;VbZP3jl>H0C4U5000000T0n_3V00L0IV9N0000
003jl>H0n_3V0000001VHUh0n_3V008000001P3jl>H2000000050?[`iP1<BDD0000004a9A@3jl>H0
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000`3jl>H2000000030?[`
iP00000000000080n_3V0P0000040?[`iP030:nXX@000000000000<0000000@0[jRQ0?[`iP1<BDD0
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0C4U5000000070?[`iP05
0=C<``2TWIH0000004a9A@3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080
n_3V0P0000000`3jl>H0000000000004000000D0n_3V00<0C4U50000003jl>H00P3jl>H200000003
0?[`iP000000000000@0000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000001P3jl>H0C4U50000003/h]T0000006IRGPP0n_3V0P0000030?[`iP8000000P3jl>H2
000000030?[`iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P00
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000H0n_3V0P0000060?[`iP8000000P3j
l>H2000000030?[`iP000000000000<0n_3V0P1<BDD0103/h]T0C4U504a9A@3jl>H6000000D0n_3V
0P0000020?[`iP80000000<0n_3V0000000000001P3jl>H2000000050>CKdP000000Ui6;0000003T
fm800P0000001@3jl>H0c<Bk0000002GTH/0i=_B0080000000<0n_3V0000000000000`3jl>H20000
00050?[`iP3<a;/0000009NAR`3Tfm800P0000040?[`iP080=C<``000000RHAn0?[`iP2GTH/00000
0=C<``3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
0000100000000`3jl>H0c<Bk04a9A@020000000304a9A@3<a;/0n_3V00800000Q03jl>H10?ooo`00
P`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V04a9A@0000000P3jl>H00`000000IV9N
0?[`iP040?[`iP8000000P3jl>H3000000030?[`iP1<BDD000000080n_3V00<0000006IRGP3jl>H0
0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000070=cDb`000000RHAn0?[`iP29
Q7h000000>CKdP070?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`
iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000030?[`iP1<BDD0
00000080n_3V0P0000060?[`iP8000001P3jl>H200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP090<c4^`000000Y9fF0?[`iP2TWIH000000<c4^`1<BDD000000080n_3V00<0000006IRGP3j
l>H0103jl>H01`1VHUh000000?[`iP3jl>H0000006IRGP3jl>H00P0000060?[`iP80000000D0c<Bk
0000003Le</000000<c4^`0200000080n_3V00<0g=C;0:nXX@1iMG000P0000000`3jl>H000000000
00030?[`iP8000000P3jl>H00`3Le</0[jRQ07UeL002000000D0n_3V00D0000004a9A@3jl>H0C4U5
000000020?[`iP0404a9A@000000n_3V0?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP1<BDD000000080n_3V00L0000006IRGP3jl>H0C4U50000001iMG00c<Bk00<0n_3V0P000024
0?[`iP40oooo00230?[`iP8000000`3jl>H20000000;0:BMUP3Tfm80000006IRGP3jl>H0^K:Z0000
0033^k<0c<Bk0000002i/ZX01@3jl>H00`1<BDD000000?[`iP050?[`iP070;VbZP000000`k^c0<c4
^`000000^K:Z0?[`iP02000000050;VbZP3Tfm80000004a9A@3jl>H00P0000020?[`iP80000000L0
[jRQ00000033^k<0n_3V0<>k/`000000[jRQ00L0n_3V0P0000030?[`iP8000000P3jl>H200000004
0?[`iP00000000000=C<``80n_3V0P0000001@2i/ZX0i=_B0000001<BDD0n_3V0080000000`0n_3V
000000000000^K:Z0>CKdP000000C4U50?[`iP2TWIH000000<>k/`2TWIH2000000H0n_3V00<0C4U5
0000003jl>H01@3jl>H200000080n_3V0P0000004P3jl>H000000000003Dc<<0n_3V06IRGP000000
k>;I0?[`iP3/h]T0000006IRGP2i/ZX000000<>k/`3<a;/000000;VbZPD0n_3V00L0^K:Z00000033
^k<0`k^c0000002i/ZX0n_3V008000001P3jl>H2000000050:BMUP1VHUh0n_3V06IRGP2TWIH00P00
0000203jl>H0NGE`0=C<``3jl>H0i=_B0000001<BDD0n_3V0P0000000`3Dc<<0n_3V0?[`iP020000
00070?[`iP1iMG00e<c30?[`iP3Tfm80000004a9A@050?[`iP0507UeL0000000c<Bk0000001VHUh0
0P3jl>H0102TWIH000000<>k/`2TWIH20000000F0?[`iP00000000000;VbZP3Tfm80000004a9A@3j
l>H0^K:Z00000033^k<0c<Bk0000002i/ZX0n_3V06IRGP000000n_3V0>CKdP000000NGE`0?[`iP80
0000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P000000103Le</0RHAn04a9A@3<a;/20?[`iP04
0:nXX@00000000000:nXX@H0n_3V00<0Ui6;0000003Tfm801P3jl>H0102_Z:4000000000002_Z:42
0?[`iP80000000@0c<Bk07UeL01<BDD0c<Bk100000002P3jl>H000000000001VHUh000000>cRf@3j
l>H0k>;I0000001VHUh70?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H0000000000029
Q7h0NGE`0?[`iP80000000D0c<Bk07UeL01<BDD0c<Bk0?[`iP02000000070?[`iP00000000000<c4
^`1iMG00C4U50<c4^`020?[`iP0308V4OP1VHUh0c<Bk008000001P3jl>H00`2GTH/000000>CKdP05
0?[`iP8000000P3jl>H2000000040?[`iP000000000008V4OP80000000P0RHAn0?[`iP3jl>H0n_3V
08V4OP000000g=C;0:nXX@80000000<0[jRQ0?[`iP3jl>H01@3jl>H01@2_Z:40C4U50000002_Z:40
n_3V00@000001@3jl>H20000000506IRGP2TWIH0n_3V09NAR`1VHUh00P0000000`3jl>H0i=_B08V4
OP020000000306IRGP3Dc<<0n_3V0080000000<0RHAn07UeL03jl>H00P0000000`3jl>H0i=_B08V4
OP020000000306IRGP3Dc<<0n_3V00@0n_3V00D0Y9fF00000029Q7h000000:BMUP030?[`iP0308V4
OP1VHUh0c<Bk0080000000L0n_3V000000000000c<Bk07UeL01<BDD0c<Bk0080n_3V00@0[jRQ0000
00000000[jRQ0P3jl>H01`3Tfm80NGE`000000000000RHAn0>CKdP3jl>H00P0000240?[`iP40oooo
00230?[`iP8000000`3jl>H200000100n_3V00L0i=_B0000002GTH/0n_3V0=C<``000000NGE`00l0
n_3V0P0000020?[`iP8000003P3jl>H2000002`0n_3V00L0i=_B0000002GTH/0n_3V0=C<``000000
RHAn02D0n_3V0P0000060?[`iP<0000000<0c<Bk0?[`iP33^k<00`00000K0?[`iP050<c4^`000000
000000000033^k<0Y03jl>H10?ooo`00P@3jl>H6000000030?[`iP00000000000140n_3V00H0g=C;
07UeL0000000000009NAR`3/h]T?0?[`iP040=cDb`29Q7h0n_3V0?[`iP800000303jl>H6000001@0
n_3V0P00000E0?[`iP050=cDb`1iMG0000000000002TWIH09P3jl>H0103<a;/0IV9N00000029Q7h4
0?[`iP<0000000<0k>;I0?[`iP3Le</00`00000=0?[`iP800000303jl>H01@3/h]T0000000000000
0000i=_B01h0n_3V0P0000240?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.56522 .38333 L
s
.56522 .05 m
.56522 .38333 L
s
.56281 .37104 m
.56522 .37104 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.56522 .38333 Mdot
.56281 .37104 Mdot
.56522 .37104 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V2P3=QCl20?[`iP030000003jl>H0n_3V
00X0cHDo4`3jl>H00`000000n_3V0?[`iP3G0?[`iP40oooo003W0?[`iPH0cHDo303jl>H00`000000
n_3V0?[`iP0:0?[`iPL0cHDo303jl>H00`000000n_3V0?[`iP3G0?[`iP40oooo003U0?[`iP80cHDo
4P3jl>H200000180n_3V0P3=QCl:0?[`iP030000003jl>H0n_3V0=L0n_3V0@3oool00>40n_3V103=
QClD0?[`iP800000503jl>H30<f5?`L0n_3V00<000000?[`iP3jl>H0e`3jl>H10?ooo`00g@3jl>H4
0<f5?aP0n_3V0P00000G0?[`iP@0cHDo0`3jl>H00`000000n_3V0?[`iP3G0?[`iP40oooo003K0?[`
iP80cHDo703jl>H2000001/0n_3V0P3=QCl00`3jl>H000000?[`iP3H0?[`iP40oooo003I0?[`iP80
cHDo7P3jl>H2000001d0n_3V00<0cHDo0000003jl>H0f03jl>H10?ooo`00e`3jl>H20<f5?b00n_3V
00<000000?[`iP0000007@3jl>H00`000000cHDo0<f5?`3G0?[`iP40oooo003E0?[`iP80cHDo8P3j
l>H00`000000n_3V0000000M0?[`iP030000003jl>H0n_3V0080cHDoe@3jl>H10?ooo`00d`3jl>H2
0<f5?b@0n_3V00<000000?[`iP0000007@3jl>H00`000000n_3V0?[`iP020?[`iP80cHDod`3jl>H1
0?ooo`00d@3jl>H20<f5?bH0n_3V00<000000?[`iP0000007@3jl>H00`000000n_3V0?[`iP040?[`
iP80cHDod@3jl>H10?ooo`00c`3jl>H20<f5?bP0n_3V00<000000?[`iP0000007@3jl>H00`000000
n_3V0?[`iP060?[`iP80cHDoc`3jl>H10?ooo`00cP3jl>H00`3=QCl0n_3V0?[`iP0X0?[`iP040000
003jl>H0n_3V000001`0n_3V00<000000?[`iP3jl>H0203jl>H00`3=QCl0n_3V0?[`iP3<0?[`iP40
oooo003<0?[`iP80cHDo:`3jl>H010000000n_3V0?[`iP00000L0?[`iP030000003jl>H0n_3V00T0
n_3V0P3=QCo<0?[`iP40oooo003:0?[`iP80cHDo;@3jl>H010000000n_3V0?[`iP00000L0?[`iP03
0000003jl>H0n_3V00/0n_3V0P3=QCo:0?[`iP40oooo00390?[`iP030<f5?`3jl>H0n_3V02d0n_3V
00@000000?[`iP3jl>H00000703jl>H00`000000n_3V0?[`iP0=0?[`iP030<f5?`3jl>H0n_3V0<L0
n_3V0@3oool00<L0n_3V0P3=QCl`0?[`iP040000003jl>H0n_3V000001`0n_3V00<000000?[`iP3j
l>H03P3jl>H20<f5?lL0n_3V0@3oool00<H0n_3V00<0cHDo0?[`iP3jl>H0<03jl>H010000000n_3V
0?[`iP00000L0?[`iP030000003jl>H0n_3V0100n_3V00<0cHDo0?[`iP3jl>H0a03jl>H10?ooo`00
a@3jl>H00`3=QCl0n_3V0?[`iP0a0?[`iP050000003jl>H0n_3V0?[`iP0000006`3jl>H00`000000
n_3V0?[`iP0A0?[`iP030<f5?`3jl>H0n_3V0<<0n_3V0@3oool00<@0n_3V00<0cHDo0?[`iP3jl>H0
<P3jl>H01@000000n_3V0?[`iP3jl>H0000001/0n_3V00<000000?[`iP3jl>H04P3jl>H00`3=QCl0
n_3V0?[`iP320?[`iP40oooo00320?[`iP80cHDo=@3jl>H01@000000n_3V0?[`iP3jl>H0000001/0
n_3V00<000000?[`iP3jl>H04`3jl>H20<f5?l80n_3V0@3oool00<40n_3V00<0cHDo0?[`iP3jl>H0
=@3jl>H01@000000n_3V0?[`iP3jl>H0000001/0n_3V00<000000?[`iP3jl>H0503jl>H00`3=QCl0
n_3V0?[`iP300?[`iP40oooo00300?[`iP030<f5?`3jl>H0n_3V03H0n_3V00D000000?[`iP3jl>H0
n_3V0000000K0?[`iP030000003jl>H0n_3V01D0n_3V00<0cHDo0?[`iP3jl>H0_`3jl>H10?ooo`00
_`3jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0
603jl>H00`000000n_3V0?[`iP0F0?[`iP80cHDo_`3jl>H10?ooo`00_P3jl>H00`3=QCl0n_3V0?[`
iP0h0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0603jl>H00`000000n_3V0?[`
iP0H0?[`iP030<f5?`3jl>H0n_3V0;`0n_3V0@3oool00;d0n_3V00<0cHDo0?[`iP3jl>H0>@3jl>H0
0`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H06@3jl>H0
0`3=QCl0n_3V0?[`iP2k0?[`iP40oooo002l0?[`iP030<f5?`3jl>H0n_3V03X0n_3V00<000000?[`
iP3jl>H00P3jl>H00`000000n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V01X0n_3V00<0cHDo0?[`
iP3jl>H0^P3jl>H10?ooo`00^`3jl>H00`3=QCl0n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V0080
n_3V00<000000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP0J0?[`iP030<f5?`3jl>H0n_3V0;X0
n_3V0@3oool00;X0n_3V00<0cHDo0?[`iP3jl>H0?03jl>H00`000000n_3V0?[`iP030?[`iP030000
003jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H06`3jl>H00`3=QCl0n_3V0?[`iP2i0?[`iP40oooo
002i0?[`iP030<f5?`3jl>H0n_3V03d0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`
iP0G0?[`iP030000003jl>H0n_3V01`0n_3V0P3=QCni0?[`iP40oooo002h0?[`iP030<f5?`3jl>H0
n_3V03h0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0G0?[`iP030000003jl>H0
n_3V01d0n_3V00<0cHDo0?[`iP3jl>H0]`3jl>H10?ooo`00^03jl>H00`3=QCl0n_3V0?[`iP0n0?[`
iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP0N0?[`
iP030<f5?`3jl>H0n_3V0;H0n_3V0@3oool00;L0n_3V00<0cHDo0?[`iP3jl>H0?`3jl>H00`000000
n_3V0?[`iP030?[`iP030000003jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H07`3jl>H00`3=QCl0
n_3V0?[`iP2e0?[`iP40oooo002f0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0
103jl>H00`000000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V01l0n_3V00<0cHDo0?[`iP3jl>H0
]@3jl>H10?ooo`00]P3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V00@0n_3V00<0
00000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP0P0?[`iP030<f5?`3jl>H0n_3V0;@0n_3V0@3o
ool00;D0n_3V00<0cHDo0?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0
n_3V01H0n_3V00<000000?[`iP3jl>H08@3jl>H00`3=QCl0n_3V0?[`iP2c0?[`iP40oooo002d0?[`
iP030<f5?`3jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0F0?[`
iP030000003jl>H0n_3V0280n_3V00<0cHDo0?[`iP3jl>H0/P3jl>H10?ooo`00/`3jl>H00`3=QCl0
n_3V0?[`iP130?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H05P3jl>H00`000000
n_3V0?[`iP0S0?[`iP030<f5?`3jl>H0n_3V0;40n_3V0@3oool00;80n_3V00<0cHDo0?[`iP3jl>H0
A03jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0
8`3jl>H00`3=QCl0n_3V0?[`iP2a0?[`iP40oooo002b0?[`iP030<f5?`3jl>H0n_3V04@0n_3V00<0
00000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V02@0n_3V00<0
cHDo0?[`iP3jl>H0/03jl>H10?ooo`00/@3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0
n_3V00D0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0T0?[`iP030<f5?`3jl>H0
n_3V0;00n_3V0@3oool00;40n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP050?[`
iP030000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H09@3jl>H00`3=QCl0n_3V0?[`iP2_0?[`
iP40oooo002`0?[`iP030<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000
n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V02D0n_3V00<0cHDo0?[`iP3jl>H0[`3jl>H10?ooo`00
/03jl>H00`3=QCl0n_3V0?[`iP160?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0
5@3jl>H00`000000n_3V0?[`iP0V0?[`iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool00:l0n_3V00<0
cHDo0?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V01@0n_3V00<0
00000?[`iP3jl>H09P3jl>H00`3=QCl0n_3V0?[`iP2^0?[`iP40oooo002_0?[`iP030<f5?`3jl>H0
n_3V04L0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0
n_3V02L0n_3V00<0cHDo0?[`iP3jl>H0[@3jl>H10?ooo`00[P3jl>H00`3=QCl0n_3V0?[`iP180?[`
iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP0X0?[`
iP030<f5?`3jl>H0n_3V0:`0n_3V0@3oool00:d0n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H00`000000
n_3V0?[`iP060?[`iP030000003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0:03jl>H00`3=QCl0
n_3V0?[`iP2/0?[`iP40oooo002]0?[`iP030<f5?`3jl>H0n_3V04T0n_3V00<000000?[`iP3jl>H0
1P3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V02T0n_3V00<0cHDo0?[`iP3jl>H0
Z`3jl>H10?ooo`00[03jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP0Y0?[`iP030<f5?`3jl>H0n_3V0:/0n_3V0@3o
ool00:`0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0
n_3V01<0n_3V00<000000?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V0?[`iP2Z0?[`iP40oooo00020000
ojX0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V
01<0n_3V00<000000?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V0?[`iP2W0?[`iP80003o0@3jl>H10?oo
o`000P3jl>H30000ojL0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP070?[`iP03
0000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V0?[`iP2T0?[`iP<0
003o0`3jl>H10?ooo`001@3jl>H40000oj80n_3V00<0cHDo0?[`iP3jl>H0B`3jl>H00`000000n_3V
0?[`iP070?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V
0?[`iP2P0?[`iP@0003o1P3jl>H10?ooo`002@3jl>H30000oil0n_3V00<0cHDo0?[`iP3jl>H0B`3j
l>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0:`3j
l>H00`3=QCl0n_3V0?[`iP2L0?[`iP<0003o2P3jl>H10?ooo`00303jl>H30000oi/0n_3V00<0cHDo
0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V0180n_3V00<00000
0?[`iP3jl>H0:`3jl>H00`3=QCl0n_3V0?[`iP2I0?[`iP<0003o3@3jl>H10?ooo`003`3jl>H40000
oiL0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
0180n_3V00<000000?[`iP3jl>H0;03jl>H00`3=QCl0n_3V0?[`iP2D0?[`iP@0003o403jl>H10?oo
o`004`3jl>H30000oi@0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP080?[`iP03
0000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0;03jl>H00`3=QCl0n_3V0?[`iP2A0?[`iP<0
003o503jl>H10?ooo`005P3jl>H30000oi40n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V
0?[`iP080?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0;03jl>H00`3=QCl0n_3V
0?[`iP2>0?[`iP<0003o5`3jl>H10?ooo`006@3jl>H30000ohd0n_3V00<0cHDo0?[`iP3jl>H0C@3j
l>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H0;03j
l>H00`3=QCl0n_3V0?[`iP2;0?[`iP<0003o6P3jl>H10?ooo`00703jl>H30000ohX0n_3V00<0cHDo
0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V0140n_3V00<00000
0?[`iP3jl>H0;@3jl>H00`3=QCl0n_3V0?[`iP270?[`iP<0003o7@3jl>H10?ooo`007`3jl>H40000
ohH0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V
0140n_3V00<000000?[`iP3jl>H0;@3jl>H00`3=QCl0n_3V0?[`iP240?[`iP<0003o803jl>H10?oo
o`008`3jl>H30000oh<0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP090?[`iP03
0000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H0;@3jl>H00`3=QCl0n_3V0?[`iP210?[`iP<0
003o8`3jl>H10?ooo`009P3jl>H30000ogl0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V
0?[`iP090?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H0;@3jl>H00`3=QCl0n_3V
0?[`iP1n0?[`iP<0003o9P3jl>H10?ooo`00:@3jl>H30000og`0n_3V00<0cHDo0?[`iP3jl>H0CP3j
l>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0;P3j
l>H00`3=QCl0n_3V0?[`iP1j0?[`iP<0003o:@3jl>H10?ooo`00;03jl>H20000ogX0n_3V00<0cHDo
0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V0100n_3V00<00000
0?[`iP3jl>H0;P3jl>H00`3=QCl0n_3V0?[`iP1h0?[`iP80003o;03jl>H10?ooo`00;P3jl>H20000
ogP0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V
0100n_3V00<000000?[`iP3jl>H0;P3jl>H00`3=QCl0n_3V0?[`iP1f0?[`iP80003o;P3jl>H10?oo
o`00<03jl>H30000og@0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP0:0?[`iP03
0000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0;P3jl>H00`3=QCl0n_3V0?[`iP1c0?[`iP<0
003o<03jl>H10?ooo`00<`3jl>H20000og80n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V
0?[`iP0:0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0;`3jl>H00`3=QCl0n_3V
0?[`iP1`0?[`iP80003o<`3jl>H10?ooo`00=@3jl>H20000og00n_3V00<0cHDo0?[`iP3jl>H0C`3j
l>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0;`3j
l>H00`3=QCl0n_3V0?[`iP1^0?[`iP80003o=@3jl>H10?ooo`00=`3jl>H30000ofd0n_3V00<0cHDo
0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00l0n_3V00<00000
0?[`iP3jl>H0;`3jl>H00`3=QCl0n_3V0?[`iP1[0?[`iP<0003o=`3jl>H10?ooo`00>P3jl>H20000
of/0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V
00l0n_3V00<000000?[`iP3jl>H0;`3jl>H00`3=QCl0n_3V0?[`iP1Y0?[`iP80003o>P3jl>H10?oo
o`00?03jl>H20000ofT0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP0;0?[`iP03
0000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0;`3jl>H00`3=QCl0n_3V0?[`iP1W0?[`iP80
003o?03jl>H10?ooo`00?P3jl>H30000ofD0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V
0?[`iP0;0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0;`3jl>H00`3=QCl0n_3V
0?[`iP1T0?[`iP<0003o?P3jl>H10?ooo`00@@3jl>H20000of<0n_3V00<0cHDo0?[`iP3jl>H0D03j
l>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0<03j
l>H00`3=QCl0n_3V0?[`iP1Q0?[`iP80003o@@3jl>H10?ooo`00@`3jl>H20000of40n_3V00<0cHDo
0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00h0n_3V00<00000
0?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP1O0?[`iP80003o@`3jl>H10?ooo`00A@3jl>H20000
oel0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V
00h0n_3V00<000000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP1M0?[`iP80003oA@3jl>H10?oo
o`00A`3jl>H20000oed0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0<0?[`iP03
0000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP1K0?[`iP80
003oA`3jl>H10?ooo`00B@3jl>H30000oeX0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V
0?[`iP0<0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V
0?[`iP1I0?[`iP80003oB@3jl>H10?ooo`00C03jl>H20000oeP0n_3V00<0cHDo0?[`iP3jl>H0D03j
l>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0<03j
l>H00`3=QCl0n_3V0?[`iP1G0?[`iP80003oB`3jl>H10?ooo`00CP3jl>H20000oeH0n_3V00<0cHDo
0?[`iP3jl>H0C`3jl>H3000000h0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0`
0?[`iP030<f5?`3jl>H0n_3V05D0n_3V0P000?m=0?[`iP40oooo001@0?[`iP80003oE03jl>H00`3=
QCl0n_3V0?[`iP1>0?[`iPD000003@3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V
0300n_3V00<0cHDo0?[`iP3jl>H0D`3jl>H20000odl0n_3V0@3oool00580n_3V0P000?mB0?[`iP03
0<f5?`3jl>H0n_3V04h0n_3V1@00000=0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3j
l>H0<03jl>H00`3=QCl0n_3V0?[`iP1A0?[`iP80003oD@3jl>H10?ooo`00E03jl>H20000oe00n_3V
00<0cHDo0?[`iP3jl>H0CP3jl>H5000000d0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V
0?[`iP0`0?[`iP030<f5?`3jl>H0n_3V04l0n_3V0P000?mC0?[`iP40oooo001F0?[`iP80003oCP3j
l>H00`3=QCl0n_3V0?[`iP1?0?[`iP<000003P3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003j
l>H0n_3V0300n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H20000oeD0n_3V0@3oool005P0n_3V0P000?m<
0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0<
0?[`iP030000003jl>H0n_3V0300n_3V00<0cHDo0?[`iP3jl>H0B`3jl>H20000oeL0n_3V0@3oool0
05X0n_3V00<0003o0?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V
00h0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0`0?[`iP030<f5?`3jl>H0n_3V
04T0n_3V0P000?mI0?[`iP40oooo001K0?[`iP80003oB@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP03
0000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0`0?[`iP03
0<f5?`3jl>H0n_3V04L0n_3V0P000?mK0?[`iP40oooo001M0?[`iP80003oA`3jl>H00`3=QCl0n_3V
0?[`iP1@0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V
0?[`iP0`0?[`iP030<f5?`3jl>H0n_3V04D0n_3V0P000?mM0?[`iP40oooo001O0?[`iP80003oA@3j
l>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0303j
l>H00`000000n_3V0?[`iP0`0?[`iP030<f5?`3jl>H0n_3V04<0n_3V0P000?mO0?[`iP40oooo001Q
0?[`iP030000o`3jl>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0?
0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP11
0?[`iP80003oH@3jl>H10?ooo`00HP3jl>H20000od80n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`00
0000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0<03jl>H00`3=
QCl0n_3V0?[`iP0o0?[`iP80003oH`3jl>H10?ooo`00I03jl>H20000od00n_3V00<0cHDo0?[`iP3j
l>H0D03jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3j
l>H0;`3jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP80003oI@3jl>H10?ooo`00IP3jl>H20000ocl0n_3V
00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00/0n_3V
00<000000?[`iP3jl>H0;`3jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP80003oI`3jl>H10?ooo`00J03j
l>H00`000?l0n_3V0?[`iP0l0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H03`3j
l>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V02l0n_3V00<0cHDo0?[`iP3jl>H0>`3j
l>H00`000?l0n_3V0?[`iP1W0?[`iP40oooo001Y0?[`iP80003o?03jl>H00`3=QCl0n_3V0?[`iP1?
0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0_
0?[`iP030<f5?`3jl>H0n_3V03T0n_3V0P000?mZ0?[`iP40oooo001[0?[`iP80003o>P3jl>H00`3=
QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H02P3jl>H00`00
0000n_3V0?[`iP0_0?[`iP030<f5?`3jl>H0n_3V03P0n_3V00<0003o0?[`iP3jl>H0JP3jl>H10?oo
o`00K@3jl>H00`000?l0n_3V0?[`iP0g0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3j
l>H0403jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V02l0n_3V00<0cHDo0?[`iP3j
l>H0=P3jl>H20000ofd0n_3V0@3oool006h0n_3V0P000?lg0?[`iP030<f5?`3jl>H0n_3V04l0n_3V
00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V02h0n_3V
00<0cHDo0?[`iP3jl>H0=@3jl>H20000ofl0n_3V0@3oool00700n_3V0P000?lf0?[`iP030<f5?`3j
l>H0n_3V04h0n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0:0?[`iP030000003j
l>H0n_3V02h0n_3V00<0cHDo0?[`iP3jl>H0=03jl>H00`000?l0n_3V0?[`iP1_0?[`iP40oooo001b
0?[`iP030000o`3jl>H0n_3V03<0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP0@
0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0;P3jl>H00`3=QCl0n_3V0?[`iP0b
0?[`iP80003oLP3jl>H10?ooo`00L`3jl>H20000oc<0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0;P3jl>H00`3=
QCl0n_3V0?[`iP0a0?[`iP030000o`3jl>H0n_3V0780n_3V0@3oool007D0n_3V0P000?la0?[`iP03
0<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP090?[`iP03
0000003jl>H0n_3V02d0n_3V00<0cHDo0?[`iP3jl>H0<03jl>H20000ogD0n_3V0@3oool007L0n_3V
00<0003o0?[`iP3jl>H0;`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V0140n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0]0?[`iP030<f5?`3jl>H0n_3V02h0n_3V
0P000?mg0?[`iP40oooo001h0?[`iP80003o;`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003j
l>H0n_3V0140n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0]0?[`iP030<f5?`3j
l>H0n_3V02d0n_3V00<0003o0?[`iP3jl>H0M`3jl>H10?ooo`00NP3jl>H20000obd0n_3V00<0cHDo
0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00T0n_3V00<00000
0?[`iP3jl>H0;@3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP80003oNP3jl>H10?ooo`00O03jl>H00`00
0?l0n_3V0?[`iP0Z0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H04P3jl>H00`00
0000n_3V0?[`iP080?[`iP030000003jl>H0n_3V02`0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`00
0?l0n_3V0?[`iP1j0?[`iP40oooo001m0?[`iP80003o:`3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP03
0000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0/0?[`iP03
0<f5?`3jl>H0n_3V02T0n_3V0P000?mm0?[`iP40oooo001o0?[`iP80003o:@3jl>H00`3=QCl0n_3V
0?[`iP1<0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V
0?[`iP0/0?[`iP030<f5?`3jl>H0n_3V02L0n_3V0P000?mo0?[`iP40oooo00210?[`iP030000o`3j
l>H0n_3V02H0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP0B0?[`iP030000003j
l>H0n_3V00P0n_3V00<000000?[`iP3jl>H0;03jl>H00`3=QCl0n_3V0?[`iP0V0?[`iP030000o`3j
l>H0n_3V07l0n_3V0@3oool00880n_3V0P000?lV0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<00000
0?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V02/0n_3V00<0cHDo
0?[`iP3jl>H09@3jl>H20000oh80n_3V0@3oool008@0n_3V0P000?lU0?[`iP030<f5?`3jl>H0n_3V
04/0n_3V00<000000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V
02/0n_3V00<0cHDo0?[`iP3jl>H0903jl>H00`000?l0n_3V0?[`iP220?[`iP40oooo00260?[`iP03
0000o`3jl>H0n_3V0280n_3V00<0cHDo0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP0C0?[`iP03
0000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V0?[`iP0S0?[`iP80
003oQ@3jl>H10?ooo`00Q`3jl>H20000ob<0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V
0?[`iP0C0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V
0?[`iP0Q0?[`iP80003oQ`3jl>H10?ooo`00R@3jl>H20000ob40n_3V00<0cHDo0?[`iP3jl>H0BP3j
l>H00`000000n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0:P3j
l>H00`3=QCl0n_3V0?[`iP0P0?[`iP030000o`3jl>H0n_3V08L0n_3V0@3oool008/0n_3V0P000?lO
0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V02X0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H20000ohX0n_3V0@3oool0
08d0n_3V00<0003o0?[`iP3jl>H0703jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V
01@0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP0Y0?[`iP030<f5?`3jl>H0n_3V
01h0n_3V00<0003o0?[`iP3jl>H0RP3jl>H10?ooo`00SP3jl>H20000oad0n_3V00<0cHDo0?[`iP3j
l>H0B@3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3j
l>H0:@3jl>H00`3=QCl0n_3V0?[`iP0L0?[`iP80003oS@3jl>H10?ooo`00T03jl>H20000oa`0n_3V
00<0cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V00H0n_3V
00<000000?[`iP3jl>H0:03jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP80003oS`3jl>H10?ooo`00TP3j
l>H00`000?l0n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V04P0n_3V00<000000?[`iP3jl>H0503j
l>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V02L0n_3V00<0cHDo0?[`iP3jl>H06`3j
l>H00`000?l0n_3V0?[`iP2?0?[`iP40oooo002C0?[`iP80003o6P3jl>H00`3=QCl0n_3V0?[`iP17
0?[`iP030000003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP0W
0?[`iP030<f5?`3jl>H0n_3V01T0n_3V0P000?nB0?[`iP40oooo002E0?[`iP030000o`3jl>H0n_3V
01L0n_3V00<0cHDo0?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V
00D0n_3V00<000000?[`iP3jl>H09P3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000o`3jl>H0n_3V
0980n_3V0@3oool009H0n_3V0P000?lH0?[`iP030<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3j
l>H05@3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V02H0n_3V00<0cHDo0?[`iP3j
l>H05`3jl>H20000oiD0n_3V0@3oool009P0n_3V00<0003o0?[`iP3jl>H05@3jl>H00`3=QCl0n_3V
0?[`iP160?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V
0?[`iP0U0?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<0003o0?[`iP3jl>H0U@3jl>H10?ooo`00V@3j
l>H20000oaH0n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003j
l>H0n_3V00D0n_3V00<000000?[`iP3jl>H09@3jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP80003oV03j
l>H10?ooo`00V`3jl>H00`000?l0n_3V0?[`iP0C0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<00000
0?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V02@0n_3V00<0cHDo
0?[`iP3jl>H05@3jl>H00`000?l0n_3V0?[`iP2H0?[`iP40oooo002L0?[`iP80003o503jl>H00`3=
QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H01@3jl>H00`00
0000n_3V0?[`iP0T0?[`iP030<f5?`3jl>H0n_3V01<0n_3V0P000?nK0?[`iP40oooo002N0?[`iP03
0000o`3jl>H0n_3V0180n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP0F0?[`iP03
0000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H08`3jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP03
0000o`3jl>H0n_3V09/0n_3V0@3oool009l0n_3V0P000?lB0?[`iP030<f5?`3jl>H0n_3V04<0n_3V
00<000000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V0280n_3V
00<0cHDo0?[`iP3jl>H04P3jl>H20000oih0n_3V0@3oool00:40n_3V00<0003o0?[`iP3jl>H0403j
l>H00`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H0103j
l>H00`000000n_3V0?[`iP0R0?[`iP030<f5?`3jl>H0n_3V0140n_3V00<0003o0?[`iP3jl>H0WP3j
l>H10?ooo`00XP3jl>H20000oa40n_3V00<0cHDo0?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP0F
0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H08@3jl>H00`3=QCl0n_3V0?[`iP0@
0?[`iP80003oX@3jl>H10?ooo`00Y03jl>H00`000?l0n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V
0400n_3V00<000000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V
0200n_3V00<0cHDo0?[`iP3jl>H0403jl>H00`000?l0n_3V0?[`iP2Q0?[`iP40oooo002U0?[`iP80
003o3`3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V01L0n_3V00<000000?[`iP3j
l>H00`3jl>H00`000000n_3V0?[`iP0O0?[`iP030<f5?`3jl>H0n_3V00l0n_3V0P000?nT0?[`iP40
oooo002W0?[`iP030000o`3jl>H0n_3V00d0n_3V00<0cHDo0?[`iP3jl>H0?`3jl>H00`000000n_3V
0?[`iP0G0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H07`3jl>H00`3=QCl0n_3V
0?[`iP0>0?[`iP030000o`3jl>H0n_3V0:@0n_3V0@3oool00:P0n_3V0P000?l>0?[`iP030<f5?`3j
l>H0n_3V03h0n_3V00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP030?[`iP030000003j
l>H0n_3V01h0n_3V00<0cHDo0?[`iP3jl>H03@3jl>H20000ojL0n_3V0@3oool00:X0n_3V0P000?l<
0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP03
0?[`iP030000003jl>H0n_3V01d0n_3V00<0cHDo0?[`iP3jl>H0303jl>H20000ojT0n_3V0@3oool0
0:`0n_3V00<0003o0?[`iP3jl>H02P3jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V
01L0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0M0?[`iP030<f5?`3jl>H0n_3V
00X0n_3V0P000?n[0?[`iP40oooo002]0?[`iP80003o2`3jl>H20<f5?cd0n_3V00<000000?[`iP3j
l>H0603jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V01/0n_3V0P3=QCl<0?[`iP03
0000o`3jl>H0n_3V0:/0n_3V0@3oool00:l0n_3V0P000?l:0?[`iP030<f5?`3jl>H0n_3V03/0n_3V
00<000000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V01X0n_3V
00<0cHDo0?[`iP3jl>H02P3jl>H20000ojh0n_3V0@3oool00;40n_3V00<0003o0?[`iP3jl>H0203j
l>H00`3=QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H00P3j
l>H00`000000n_3V0?[`iP0J0?[`iP030<f5?`3jl>H0n_3V00P0n_3V0P000?n`0?[`iP40oooo002b
0?[`iP80003o2@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V01P0n_3V00<00000
0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V00L0n_3V0P000?nb
0?[`iP40oooo002d0?[`iP80003o203jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V
01P0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0H0?[`iP030<f5?`3jl>H0n_3V
00L0n_3V00<0003o0?[`iP3jl>H0/P3jl>H10?ooo`00]P3jl>H00`000?l0n_3V0?[`iP060?[`iP03
0<f5?`3jl>H0n_3V03L0n_3V00<000000?[`iP3jl>H06@3jl>H01@000000n_3V0?[`iP3jl>H00000
01T0n_3V00<0cHDo0?[`iP3jl>H01P3jl>H20000okD0n_3V0@3oool00;L0n_3V0P000?l70?[`iP80
cHDo=`3jl>H00`000000n_3V0?[`iP0I0?[`iP050000003jl>H0n_3V0?[`iP0000005`3jl>H20<f5
?`L0n_3V0P000?ng0?[`iP40oooo002i0?[`iP80003o1P3jl>H00`3=QCl0n_3V0?[`iP0e0?[`iP03
0000003jl>H0n_3V01T0n_3V00D000000?[`iP3jl>H0n_3V0000000F0?[`iP030<f5?`3jl>H0n_3V
00D0n_3V0P000?ni0?[`iP40oooo002k0?[`iP030000o`3jl>H0n_3V00@0n_3V00<0cHDo0?[`iP3j
l>H0=03jl>H00`000000n_3V0?[`iP0I0?[`iP050000003jl>H0n_3V0?[`iP0000005P3jl>H00`3=
QCl0n_3V0?[`iP040?[`iP030000o`3jl>H0n_3V0;T0n_3V0@3oool00;`0n_3V0P000?l50?[`iP80
cHDo=03jl>H00`000000n_3V0?[`iP0I0?[`iP050000003jl>H0n_3V0?[`iP000000503jl>H20<f5
?`D0n_3V0P000?nl0?[`iP40oooo002n0?[`iP80003o1@3jl>H00`3=QCl0n_3V0?[`iP0a0?[`iP03
0000003jl>H0n_3V01X0n_3V00@000000?[`iP3jl>H000004`3jl>H00`3=QCl0n_3V0?[`iP030?[`
iP80003o_P3jl>H10?ooo`00`03jl>H00`000?l0n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V0300
n_3V00<000000?[`iP3jl>H06P3jl>H010000000n_3V0?[`iP00000B0?[`iP030<f5?`3jl>H0n_3V
0080n_3V0P000?o00?[`iP40oooo00310?[`iP80003o103jl>H00`3=QCl0n_3V0?[`iP0_0?[`iP03
0000003jl>H0n_3V01X0n_3V00@000000?[`iP3jl>H000004@3jl>H0103=QCl0n_3V0?[`iP3jl>H2
0000ol80n_3V0@3oool00<<0n_3V0P000?l30?[`iP80cHDo;`3jl>H00`000000n_3V0?[`iP0J0?[`
iP040000003jl>H0n_3V000000l0n_3V0P3=QCl30?[`iP030000o`3jl>H0n_3V0<80n_3V0@3oool0
0<D0n_3V0P000?l30?[`iP030<f5?`3jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H06P3jl>H01000
0000n_3V0?[`iP00000>0?[`iP040<f5?`3jl>H0n_3V0?[`iP80003oa@3jl>H10?ooo`00a`3jl>H2
0000o`80n_3V0P3=QCl/0?[`iP030000003jl>H0n_3V01X0n_3V00@000000?[`iP3jl>H00000303j
l>H20<f5?`80n_3V0P000?o70?[`iP40oooo00390?[`iP80003o0P3jl>H20<f5?bX0n_3V00<00000
0?[`iP3jl>H06`3jl>H00`000000n_3V0000000:0?[`iP80cHDo0P3jl>H20000olT0n_3V0@3oool0
0</0n_3V0P000?l20?[`iP030<f5?`3jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H06`3jl>H00`00
0000n_3V000000090?[`iP030<f5?`3jl>H0n_3V0080003ob`3jl>H10?ooo`00c@3jl>H20000o`03
0?[`iP3=QCl0cHDo02L0n_3V00<000000?[`iP3jl>H06`3jl>H00`000000n_3V000000070?[`iP80
cHDo00<0n_3V0000o`000?l0c@3jl>H10?ooo`00c`3jl>H30000o`80cHDo9@3jl>H00`000000n_3V
0?[`iP0K0?[`iP030000003jl>H0000000D0n_3V0P3=QCl00`3jl>H0003o0000o`3?0?[`iP40oooo
003B0?[`iP<0003o00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0K0?[`iP@000000P3j
l>H20<f5?`030?[`iP000?l0003o0=40n_3V0@3oool00=D0n_3V0P000?l00`3=QCl0n_3V0?[`iP0O
0?[`iP030000003jl>H0n_3V01X0n_3V1P000000103=QCl0003o0000o`000?oC0?[`iP40oooo003G
0?[`iP<0003o7`3jl>H00`000000n_3V0?[`iP0J0?[`iPH0000000<0003o0?[`iP3jl>H0e03jl>H1
0?ooo`00fP3jl>H30000o`030<f5?`3jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06@3jl>H00`3=
QCl000000000000400000=L0n_3V0@3oool00=d0n_3V0`000?lI0?[`iP030000003jl>H0n_3V01L0
n_3V00@0cHDo0000o`000?l0003o1000003H0?[`iP40oooo003P0?[`iP@0003o5@3jl>H00`000000
n_3V0?[`iP0C0?[`iP030<f5?`000?l0003o0080003o103jl>H200000=T0n_3V0@3oool00>@0n_3V
10000?lA0?[`iP030000003jl>H0n_3V00l0n_3V00<0cHDo0000o`000?l00P000?l80?[`iP<00000
f03jl>H10?ooo`00j03jl>H40000o`d0n_3V00<000000?[`iP3jl>H02`3jl>H50000o`/0n_3V1@00
003G0?[`iP40oooo003/0<f5?`d0003o00<000000000o`000?l02`000?l@0<f5?`D00000eP3=QCl1
0?[`iP40oooo003o0?[`iQP0n_3V1@00003G0?[`iP40oooo003o0?[`iQT0n_3V0`00003H0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00;H0n_3V0P0000000`1VHUh0
c<Bk0?[`iP0[0?[`iP060=C<``1VHUh0000000000029Q7h0i=_BI@3jl>H01P3Dc<<0IV9N00000000
0000RHAn0>CKdY`0n_3V0@3oool00;P0n_3V00<0IV9N0000003Le</0:`3jl>H01P1<BDD0`k^c0?[`
iP3/h]T0000008V4OVD0n_3V00H0C4U50<>k/`3jl>H0k>;I00000029Q7jL0?[`iP40oooo00230?[`
iP8000000`3jl>H200000080n_3V0P0000020?[`iP040:nXX@1<BDD0000008V4OPL0n_3V00H0g=C;
07UeL0000000000008V4OP3<a;/20?[`iP040:nXX@1<BDD0000008V4OP80n_3V0P0000020?[`iP80
000000D0n_3V0<c4^`000000NGE`0?[`iP0200000080n_3V0P0000000`1VHUh0n_3V0?[`iP070?[`
iP8000000`3jl>H0103<a;/0C4U506IRGP3Tfm82000000030?[`iP000000000000<0n_3V0P000002
0?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000000P3jl>H00`29Q7h0IV9N0<c4
^`02000000L0n_3V00D0g=C;07UeL0000000C4U50:BMUP020?[`iP040<c4^`1<BDD0IV9N0>CKdP80
000000<0n_3V000000000000103jl>H00`2TWIH000000:BMUP030?[`iP040:nXX@1<BDD0000008V4
OPL0n_3V00@0[jRQ04a9A@1<BDD0[jRQ0P3jl>H2000000H0n_3V0P0000001@3jl>H0`k^c00000033
^k<0n_3V0080000000D0n_3V0<c4^`1<BDD0C4U50:nXX@02000000030?[`iP000000000000<0n_3V
0P0000001@3jl>H0c<Bk04a9A@1<BDD0[jRQ00800000103jl>H2000000030>cRf@3jl>H0k>;I0080
00000P3jl>H00`29Q7h0IV9N0<c4^`02000000030?[`iP00000000000080n_3V0P0000020?[`iP04
0:nXX@1<BDD0000008V4OP80n_3V00L0k>;I09NAR`000000000007UeL03Tfm80n_3V00800000Q03j
l>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80000000L0n_3V0:nXX@000000`k^c0>CK
dP000000RHAn00D0n_3V00D0i=_B0000002GTH/0n_3V0;VbZP02000000080?[`iP2_Z:4000000<>k
/`3Tfm80000008V4OP3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0<c4^`0000000P0000000`3Tfm80n_3V0?[`iP060?[`iP8000000`3jl>H0101VHUh000000>CK
dP2i/ZX2000000030?[`iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000
n_3V0P0000020?[`iP80000000D0n_3V0:BMUP000000`k^c0:BMUP02000000H0n_3V00`0i=_B0000
002GTH/0n_3V0=C<``000000RHAn0?[`iP1VHUh000000>CKdP2i/ZX2000000030?[`iP0000000000
00@0n_3V0`000000203/h]T0n_3V0:nXX@000000`k^c0>CKdP000000RHAn1@3jl>H01`2i/ZX00000
0<>k/`33^k<000000;VbZP3jl>H00P0000060?[`iP80000000D0n_3V09NAR`000000Ui6;0?[`iP02
000000050?[`iP1<BDD000000>CKdP33^k<00P0000000`3jl>H00000000000030?[`iP80000000D0
n_3V04a9A@000000i=_B0<>k/`02000000@0n_3V00`0RHAn0000003Dc<<0n_3V0=C<``000000RHAn
0?[`iP2TWIH000000<>k/`2TWIH2000000030?[`iP00000000000080n_3V0P0000003`3jl>H0[jRQ
00000033^k<0i=_B00000029Q7h0n_3V07UeL0000000i=_B0>cRf@000000IV9N0?[`iP02000008@0
n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP1<BDD0000000T0n_3V
00<0Ui6;0000003Le</00P3jl>H2000000030?[`iP1<BDD0000000D0n_3V0P0000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000060?[`iP2GTH/0000008V4OP000000[jRQ203jl>H20000
00<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000103j
l>H000000000003jl>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP8000001P3jl>H0
0`2GTH/000000>CKdP050?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V00P0^K:Z
00000029Q7h000000;VbZP3jl>H0C4U5000000T0n_3V00L0IV9N0000003jl>H0n_3V0000001VHUh0
n_3V008000001P3jl>H2000000050?[`iP1<BDD0000004a9A@3jl>H00P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000`3jl>H2000000030?[`iP00000000000080n_3V0P00
00040?[`iP030:nXX@000000000000<0000000@0[jRQ0?[`iP1<BDD000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H0C4U5000000070?[`iP050=C<``2TWIH0000004a9A@3j
l>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H00000
00000004000000D0n_3V00<0C4U50000003jl>H00P3jl>H2000000030?[`iP000000000000@00000
00<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000001P3jl>H0C4U5
0000003/h]T0000006IRGPP0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP0000000000
00<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000H0n_3V0P0000060?[`iP8000000P3jl>H2000000030?[`iP000000
000000<0n_3V0P1<BDD0103/h]T0C4U504a9A@3jl>H6000000D0n_3V0P0000020?[`iP80000000<0
n_3V0000000000001P3jl>H2000000050>CKdP000000Ui6;0000003Tfm800P0000001@3jl>H0c<Bk
0000002GTH/0i=_B0080000000<0n_3V0000000000000`3jl>H2000000050?[`iP3<a;/0000009NA
R`3Tfm800P0000040?[`iP080=C<``000000RHAn0?[`iP2GTH/000000=C<``3jl>H200000080n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000100000000`3jl>H0c<Bk
04a9A@020000000304a9A@3<a;/0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P00
00020?[`iP80000000<0n_3V04a9A@0000000P3jl>H00`000000IV9N0?[`iP040?[`iP8000000P3j
l>H3000000030?[`iP1<BDD000000080n_3V00<0000006IRGP3jl>H00P0000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000070=cDb`000000RHAn0?[`iP29Q7h000000>CKdP070?[`iP80
00000`3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H200000004
0?[`iP00000000000?[`iP8000000P3jl>H2000000030?[`iP1<BDD000000080n_3V0P0000060?[`
iP8000001P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP090<c4^`000000Y9fF
0?[`iP2TWIH000000<c4^`1<BDD000000080n_3V00<0000006IRGP3jl>H0103jl>H01`1VHUh00000
0?[`iP3jl>H0000006IRGP3jl>H00P0000060?[`iP80000000D0c<Bk0000003Le</000000<c4^`02
00000080n_3V00<0g=C;0:nXX@1iMG000P0000000`3jl>H00000000000030?[`iP8000000P3jl>H0
0`3Le</0[jRQ07UeL002000000D0n_3V00D0000004a9A@3jl>H0C4U5000000020?[`iP0404a9A@00
0000n_3V0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP1<BDD000000080n_3V
00L0000006IRGP3jl>H0C4U50000001iMG00c<Bk00<0n_3V0P0000240?[`iP40oooo00230?[`iP80
00000`3jl>H20000000;0:BMUP3Tfm80000006IRGP3jl>H0^K:Z00000033^k<0c<Bk0000002i/ZX0
1@3jl>H00`1<BDD000000?[`iP050?[`iP070;VbZP000000`k^c0<c4^`000000^K:Z0?[`iP020000
00050;VbZP3Tfm80000004a9A@3jl>H00P0000020?[`iP80000000L0[jRQ00000033^k<0n_3V0<>k
/`000000[jRQ00L0n_3V0P0000030?[`iP8000000P3jl>H2000000040?[`iP00000000000=C<``80
n_3V0P0000001@2i/ZX0i=_B0000001<BDD0n_3V0080000000`0n_3V000000000000^K:Z0>CKdP00
0000C4U50?[`iP2TWIH000000<>k/`2TWIH2000000H0n_3V00<0C4U50000003jl>H01@3jl>H20000
0080n_3V0P0000004P3jl>H000000000003Dc<<0n_3V06IRGP000000k>;I0?[`iP3/h]T0000006IR
GP2i/ZX000000<>k/`3<a;/000000;VbZPD0n_3V00L0^K:Z00000033^k<0`k^c0000002i/ZX0n_3V
008000001P3jl>H2000000050:BMUP1VHUh0n_3V06IRGP2TWIH00P000000203jl>H0NGE`0=C<``3j
l>H0i=_B0000001<BDD0n_3V0P0000000`3Dc<<0n_3V0?[`iP02000000070?[`iP1iMG00e<c30?[`
iP3Tfm80000004a9A@050?[`iP0507UeL0000000c<Bk0000001VHUh00P3jl>H0102TWIH000000<>k
/`2TWIH20000000F0?[`iP00000000000;VbZP3Tfm80000004a9A@3jl>H0^K:Z00000033^k<0c<Bk
0000002i/ZX0n_3V06IRGP000000n_3V0>CKdP000000NGE`0?[`iP800000Q03jl>H10?ooo`00P`3j
l>H2000000<0n_3V0P000000103Le</0RHAn04a9A@3<a;/20?[`iP040:nXX@00000000000:nXX@H0
n_3V00<0Ui6;0000003Tfm801P3jl>H0102_Z:4000000000002_Z:420?[`iP80000000@0c<Bk07Ue
L01<BDD0c<Bk100000002P3jl>H000000000001VHUh000000>cRf@3jl>H0k>;I0000001VHUh70?[`
iP8000000`3jl>H200000080n_3V0P0000001P3jl>H0000000000029Q7h0NGE`0?[`iP80000000D0
c<Bk07UeL01<BDD0c<Bk0?[`iP02000000070?[`iP00000000000<c4^`1iMG00C4U50<c4^`020?[`
iP0308V4OP1VHUh0c<Bk008000001P3jl>H00`2GTH/000000>CKdP050?[`iP8000000P3jl>H20000
00040?[`iP000000000008V4OP80000000P0RHAn0?[`iP3jl>H0n_3V08V4OP000000g=C;0:nXX@80
000000<0[jRQ0?[`iP3jl>H01@3jl>H01@2_Z:40C4U50000002_Z:40n_3V00@000001@3jl>H20000
000506IRGP2TWIH0n_3V09NAR`1VHUh00P0000000`3jl>H0i=_B08V4OP020000000306IRGP3Dc<<0
n_3V0080000000<0RHAn07UeL03jl>H00P0000000`3jl>H0i=_B08V4OP020000000306IRGP3Dc<<0
n_3V00@0n_3V00D0Y9fF00000029Q7h000000:BMUP030?[`iP0308V4OP1VHUh0c<Bk0080000000L0
n_3V000000000000c<Bk07UeL01<BDD0c<Bk0080n_3V00@0[jRQ000000000000[jRQ0P3jl>H01`3T
fm80NGE`000000000000RHAn0>CKdP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H2
00000100n_3V00L0i=_B0000002GTH/0n_3V0=C<``000000NGE`00l0n_3V0P0000020?[`iP800000
3P3jl>H2000002`0n_3V00L0i=_B0000002GTH/0n_3V0=C<``000000RHAn02D0n_3V0P0000060?[`
iP<0000000<0c<Bk0?[`iP33^k<00`00000K0?[`iP050<c4^`000000000000000033^k<0Y03jl>H1
0?ooo`00P@3jl>H6000000030?[`iP00000000000140n_3V00H0g=C;07UeL0000000000009NAR`3/
h]T?0?[`iP040=cDb`29Q7h0n_3V0?[`iP800000303jl>H6000001@0n_3V0P00000E0?[`iP050=cD
b`1iMG0000000000002TWIH09P3jl>H0103<a;/0IV9N00000029Q7h40?[`iP<0000000<0k>;I0?[`
iP3Le</00`00000=0?[`iP800000303jl>H01@3/h]T00000000000000000i=_B01h0n_3V0P000024
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.6087 .38333 L
s
.6087 .05 m
.6087 .38333 L
s
.59825 .3513 m
.6087 .3513 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.6087 .38333 Mdot
.59825 .3513 Mdot
.6087 .3513 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V2P3=QCl20?[`iP030000003jl>H0n_3V
00X0cHDo:@3jl>H00`000000n_3V0?[`iP310?[`iP40oooo003W0?[`iPH0cHDo303jl>H2000000/0
n_3V1`3=QClR0?[`iP030000003jl>H0n_3V0<40n_3V0@3oool00>D0n_3V0P3=QClB0?[`iP800000
4P3jl>H20<f5?b00n_3V00<000000?[`iP3jl>H0`@3jl>H10?ooo`00h@3jl>H40<f5?a@0n_3V0P00
000D0?[`iP<0cHDo7@3jl>H00`000000n_3V0?[`iP310?[`iP40oooo003M0?[`iP@0cHDo603jl>H0
0`000000n_3V0000000F0?[`iP@0cHDo6@3jl>H00`000000n_3V0?[`iP310?[`iP40oooo003K0?[`
iP80cHDo703jl>H00`000000n_3V0000000J0?[`iP80cHDo5`3jl>H00`000000n_3V0?[`iP310?[`
iP40oooo003I0?[`iP80cHDo7P3jl>H00`000000n_3V0000000L0?[`iP80cHDo5@3jl>H00`000000
n_3V0?[`iP310?[`iP40oooo003G0?[`iP80cHDo803jl>H010000000n_3V0?[`iP00000M0?[`iP80
cHDo4`3jl>H00`000000n_3V0?[`iP310?[`iP40oooo003E0?[`iP80cHDo8P3jl>H010000000n_3V
0?[`iP00000O0?[`iP80cHDo4@3jl>H00`000000n_3V0?[`iP310?[`iP40oooo003C0?[`iP80cHDo
903jl>H010000000n_3V0?[`iP00000Q0?[`iP80cHDo3`3jl>H00`000000n_3V0?[`iP310?[`iP40
oooo003A0?[`iP80cHDo9P3jl>H01@000000n_3V0?[`iP3jl>H000000280n_3V0P3=QCl=0?[`iP03
0000003jl>H0n_3V0<40n_3V0@3oool00<l0n_3V0P3=QClX0?[`iP050000003jl>H0n_3V0?[`iP00
0000903jl>H20<f5?`/0n_3V00<000000?[`iP3jl>H0`@3jl>H10?ooo`00cP3jl>H00`3=QCl0n_3V
0?[`iP0X0?[`iP050000003jl>H0n_3V0?[`iP0000009P3jl>H00`3=QCl0n_3V0?[`iP080?[`iP03
0000003jl>H0n_3V0<40n_3V0@3oool00<`0n_3V0P3=QCl[0?[`iP030000003jl>H0n_3V0080n_3V
00<000000?[`iP3jl>H0903jl>H20<f5?`P0n_3V00<000000?[`iP3jl>H0`@3jl>H10?ooo`00bP3j
l>H20<f5?bd0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0V0?[`iP80cHDo1P3j
l>H00`000000n_3V0?[`iP310?[`iP40oooo00390?[`iP030<f5?`3jl>H0n_3V02d0n_3V00<00000
0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0X0?[`iP030<f5?`3jl>H0n_3V00<0n_3V00<00000
0?[`iP3jl>H0`@3jl>H10?ooo`00a`3jl>H20<f5?c00n_3V00<000000?[`iP3jl>H00`3jl>H00`00
0000n_3V0?[`iP0X0?[`iP80cHDo0`3jl>H00`000000n_3V0?[`iP310?[`iP40oooo00360?[`iP03
0<f5?`3jl>H0n_3V0300n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0Z0?[`iP04
0<f5?`3jl>H0n_3V00000<<0n_3V0@3oool00<D0n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000
n_3V0?[`iP030?[`iP030000003jl>H0n_3V02/0n_3V00<0cHDo0?[`iP000000``3jl>H10?ooo`00
a03jl>H00`3=QCl0n_3V0?[`iP0b0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0
:`3jl>H00`3=QCl000000?[`iP320?[`iP40oooo00320?[`iP80cHDo=@3jl>H00`000000n_3V0?[`
iP040?[`iP030000003jl>H0n_3V02`0n_3V00<000000<f5?`3jl>H0`@3jl>H10?ooo`00`@3jl>H0
0`3=QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0;03jl>H0
0`000000cHDo0?[`iP310?[`iP40oooo00300?[`iP030<f5?`3jl>H0n_3V03H0n_3V00<000000?[`
iP3jl>H0103jl>H00`000000n_3V0?[`iP0/0?[`iP030000003jl>H0cHDo0<40n_3V0@3oool00;l0
n_3V00<0cHDo0?[`iP3jl>H0=`3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V02/0
n_3V00<000000?[`iP3jl>H00P3=QCno0?[`iP40oooo002n0?[`iP030<f5?`3jl>H0n_3V03P0n_3V
00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V0080n_3V
00<0cHDo0?[`iP3jl>H0_03jl>H10?ooo`00_@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003j
l>H0n_3V00D0n_3V00<000000?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP030?[`iP030<f5?`3j
l>H0n_3V0;/0n_3V0@3oool00;`0n_3V00<0cHDo0?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP06
0?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP2j
0?[`iP40oooo002k0?[`iP030<f5?`3jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H01P3jl>H00`00
0000n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V00@0n_3V00<0cHDo0?[`iP3jl>H0^P3jl>H10?oo
o`00^P3jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3j
l>H0:P3jl>H00`000000n_3V0?[`iP050?[`iP030<f5?`3jl>H0n_3V0;T0n_3V0@3oool00;T0n_3V
00<0cHDo0?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V02T0n_3V
00<000000?[`iP3jl>H01P3jl>H20<f5?kT0n_3V0@3oool00;P0n_3V00<0cHDo0?[`iP3jl>H0?P3j
l>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V02T0n_3V00<000000?[`iP3jl>H01`3j
l>H00`3=QCl0n_3V0?[`iP2g0?[`iP40oooo002h0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0Y0?[`iP030000003jl>H0n_3V00P0n_3V00<0cHDo
0?[`iP3jl>H0]P3jl>H10?ooo`00]`3jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP090?[`iP030<f5?`3jl>H0n_3V
0;D0n_3V0@3oool00;H0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP080?[`iP03
0000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H02@3jl>H00`3=QCl0n_3V0?[`iP2e0?[`iP40
oooo002f0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V
0?[`iP0X0?[`iP030000003jl>H0n_3V00X0n_3V00<0cHDo0?[`iP3jl>H0]03jl>H10?ooo`00]@3j
l>H00`3=QCl0n_3V0?[`iP110?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H09`3j
l>H00`000000n_3V0?[`iP0;0?[`iP030<f5?`3jl>H0n_3V0;<0n_3V0@3oool00;@0n_3V00<0cHDo
0?[`iP3jl>H0@P3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V02L0n_3V00<00000
0?[`iP3jl>H0303jl>H00`3=QCl0n_3V0?[`iP2b0?[`iP40oooo002c0?[`iP030<f5?`3jl>H0n_3V
04<0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V
00d0n_3V00<0cHDo0?[`iP3jl>H0/@3jl>H10?ooo`00/P3jl>H00`3=QCl0n_3V0?[`iP140?[`iP03
0000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP0=0?[`iP03
0<f5?`3jl>H0n_3V0;40n_3V0@3oool00;80n_3V00<0cHDo0?[`iP3jl>H0A03jl>H00`000000n_3V
0?[`iP0:0?[`iP030000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H03P3jl>H00`3=QCl0n_3V
0?[`iP2`0?[`iP40oooo002a0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H02P3j
l>H00`000000n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V00h0n_3V00<0cHDo0?[`iP3jl>H0/03j
l>H10?ooo`00/@3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V00/0n_3V00<00000
0?[`iP3jl>H09@3jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V0:l0n_3V0@3oool0
0;00n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V
02D0n_3V00<000000?[`iP3jl>H03`3jl>H00`3=QCl0n_3V0?[`iP2_0?[`iP40oooo002`0?[`iP03
0<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0U0?[`iP03
0000003jl>H0n_3V0100n_3V00<0cHDo0?[`iP3jl>H0[P3jl>H10?ooo`00[`3jl>H00`3=QCl0n_3V
0?[`iP170?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0903jl>H00`000000n_3V
0?[`iP0@0?[`iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool00:l0n_3V00<0cHDo0?[`iP3jl>H0A`3j
l>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H04@3j
l>H00`3=QCl0n_3V0?[`iP2]0?[`iP40oooo002^0?[`iP030<f5?`3jl>H0n_3V04P0n_3V00<00000
0?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0T0?[`iP030000003jl>H0n_3V0180n_3V00<0cHDo
0?[`iP3jl>H0[03jl>H10?ooo`00[@3jl>H00`3=QCl0n_3V0?[`iP190?[`iP030000003jl>H0n_3V
00d0n_3V00<000000?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP0B0?[`iP030<f5?`3jl>H0n_3V
0:`0n_3V0@3oool00:d0n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`iP0=0?[`iP03
0000003jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H04`3jl>H00`3=QCl0n_3V0?[`iP2[0?[`iP40
oooo002/0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V
0?[`iP0S0?[`iP030000003jl>H0n_3V01<0n_3V00<0cHDo0?[`iP3jl>H0Z`3jl>H10?ooo`00[03j
l>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H08P3j
l>H00`000000n_3V0?[`iP0D0?[`iP030<f5?`3jl>H0n_3V0:X0n_3V0@3oool00080003oZP3jl>H0
0`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H08P3jl>H0
0`000000n_3V0?[`iP0D0?[`iP030<f5?`3jl>H0n_3V0:L0n_3V0P000?l10?[`iP40oooo00020?[`
iP<0003oY`3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`
iP3jl>H08P3jl>H00`000000n_3V0?[`iP0D0?[`iP030<f5?`3jl>H0n_3V0:@0n_3V0`000?l30?[`
iP40oooo00050?[`iP@0003oXP3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V00l0
n_3V00<000000?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0D0?[`iP030<f5?`3jl>H0n_3V0:00
n_3V10000?l60?[`iP40oooo00090?[`iP<0003oW`3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000
003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0E0?[`iP030<f5
?`3jl>H0n_3V09`0n_3V0`000?l:0?[`iP40oooo000<0?[`iP<0003oV`3jl>H00`3=QCl0n_3V0?[`
iP1<0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H08@3jl>H00`000000n_3V0?[`
iP0E0?[`iP030<f5?`3jl>H0n_3V09T0n_3V0`000?l=0?[`iP40oooo000?0?[`iP@0003oU`3jl>H0
0`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0803jl>H0
0`000000n_3V0?[`iP0F0?[`iP030<f5?`3jl>H0n_3V09@0n_3V10000?l@0?[`iP40oooo000C0?[`
iP<0003oU03jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`
iP3jl>H0803jl>H00`000000n_3V0?[`iP0F0?[`iP030<f5?`3jl>H0n_3V0940n_3V0`000?lD0?[`
iP40oooo000F0?[`iP<0003oT@3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V0100
n_3V00<000000?[`iP3jl>H0803jl>H00`000000n_3V0?[`iP0F0?[`iP030<f5?`3jl>H0n_3V08h0
n_3V0`000?lG0?[`iP40oooo000I0?[`iP<0003oS@3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000
003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H07`3jl>H00`000000n_3V0?[`iP0F0?[`iP030<f5
?`3jl>H0n_3V08/0n_3V0`000?lJ0?[`iP40oooo000L0?[`iP<0003oRP3jl>H00`3=QCl0n_3V0?[`
iP1=0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H07`3jl>H00`000000n_3V0?[`
iP0G0?[`iP030<f5?`3jl>H0n_3V08L0n_3V0`000?lM0?[`iP40oooo000O0?[`iP@0003oQP3jl>H0
0`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H07`3jl>H0
0`000000n_3V0?[`iP0G0?[`iP030<f5?`3jl>H0n_3V08@0n_3V0`000?lP0?[`iP40oooo000S0?[`
iP<0003oP`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`
iP3jl>H07`3jl>H00`000000n_3V0?[`iP0G0?[`iP030<f5?`3jl>H0n_3V0840n_3V0`000?lS0?[`
iP40oooo000V0?[`iP<0003oO`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V0180
n_3V00<000000?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP0G0?[`iP030<f5?`3jl>H0n_3V07h0
n_3V0`000?lV0?[`iP40oooo000Y0?[`iP<0003oO03jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000
003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP0H0?[`iP030<f5
?`3jl>H0n_3V07X0n_3V0`000?lY0?[`iP40oooo000/0?[`iP80003oNP3jl>H00`3=QCl0n_3V0?[`
iP1>0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H07P3jl>H00`000000n_3V0?[`
iP0H0?[`iP030<f5?`3jl>H0n_3V07P0n_3V0P000?l/0?[`iP40oooo000^0?[`iP80003oN03jl>H0
0`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H07@3jl>H0
0`000000n_3V0?[`iP0H0?[`iP030<f5?`3jl>H0n_3V07H0n_3V0P000?l^0?[`iP40oooo000`0?[`
iP<0003oM03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`
iP3jl>H07@3jl>H00`000000n_3V0?[`iP0H0?[`iP030<f5?`3jl>H0n_3V07<0n_3V0`000?l`0?[`
iP40oooo000c0?[`iP80003oLP3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V01<0
n_3V00<000000?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V0700
n_3V0P000?lc0?[`iP40oooo000e0?[`iP80003oL03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000
003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP0I0?[`iP030<f5
?`3jl>H0n_3V06h0n_3V0P000?le0?[`iP40oooo000g0?[`iP<0003oK@3jl>H00`3=QCl0n_3V0?[`
iP1?0?[`iP030000003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0703jl>H00`000000n_3V0?[`
iP0I0?[`iP030<f5?`3jl>H0n_3V06/0n_3V0`000?lg0?[`iP40oooo000j0?[`iP80003oJ`3jl>H0
0`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0703jl>H0
0`000000n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V06T0n_3V0P000?lj0?[`iP40oooo000l0?[`
iP80003oJ@3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`
iP3jl>H06`3jl>H00`000000n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V06L0n_3V0P000?ll0?[`
iP40oooo000n0?[`iP<0003oI@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V01D0
n_3V00<000000?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V06@0
n_3V0`000?ln0?[`iP40oooo00110?[`iP80003oH`3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000
003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP0J0?[`iP030<f5
?`3jl>H0n_3V0640n_3V0P000?m10?[`iP40oooo00130?[`iP80003oH@3jl>H00`3=QCl0n_3V0?[`
iP1@0?[`iP030000003jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H06P3jl>H00`000000n_3V0?[`
iP0J0?[`iP030<f5?`3jl>H0n_3V05l0n_3V0P000?m30?[`iP40oooo00150?[`iP80003oG`3jl>H0
0`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H06P3jl>H0
0`000000n_3V0?[`iP0J0?[`iP030<f5?`3jl>H0n_3V05d0n_3V0P000?m50?[`iP40oooo00170?[`
iP80003oG@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V01H0n_3V00<000000?[`
iP3jl>H06P3jl>H00`000000n_3V0?[`iP0J0?[`iP030<f5?`3jl>H0n_3V05/0n_3V0P000?m70?[`
iP40oooo00190?[`iP<0003oFP3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V01L0
n_3V00<000000?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0J0?[`iP030<f5?`3jl>H0n_3V05T0
n_3V0P000?m90?[`iP40oooo001<0?[`iP80003oF03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000
003jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0J0?[`iP030<f5
?`3jl>H0n_3V05L0n_3V0P000?m;0?[`iP40oooo001>0?[`iP80003oEP3jl>H00`3=QCl0n_3V0?[`
iP1?0?[`iP<00000603jl>H00`000000n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V01X0n_3V00<0
cHDo0?[`iP3jl>H0E@3jl>H20000odd0n_3V0@3oool00500n_3V0P000?mD0?[`iP030<f5?`3jl>H0
n_3V04h0n_3V1@00000H0?[`iP030000003jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H06P3jl>H0
0`3=QCl0n_3V0?[`iP1C0?[`iP80003oC`3jl>H10?ooo`00DP3jl>H20000oe80n_3V00<0cHDo0?[`
iP3jl>H0CP3jl>H5000001P0n_3V00<000000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP0J0?[`
iP030<f5?`3jl>H0n_3V0540n_3V0P000?mA0?[`iP40oooo001D0?[`iP80003oD03jl>H00`3=QCl0
n_3V0?[`iP1>0?[`iPD00000603jl>H00`000000n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V01X0
n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H20000oe<0n_3V0@3oool005H0n_3V0P000?m>0?[`iP030<f5
?`3jl>H0n_3V04l0n_3V0`00000J0?[`iP030000003jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H0
6P3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP80003oE@3jl>H10?ooo`00F03jl>H20000od`0n_3V00<0
cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V01L0n_3V00<0
00000?[`iP3jl>H06P3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP80003oE`3jl>H10?ooo`00FP3jl>H0
0`000?l0n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H06@3jl>H0
0`000000n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V01X0n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H2
0000oeT0n_3V0@3oool005/0n_3V0P000?m90?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`
iP3jl>H06P3jl>H00`000000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V01X0n_3V00<0cHDo0?[`
iP3jl>H0A`3jl>H20000oe/0n_3V0@3oool005d0n_3V0P000?m70?[`iP030<f5?`3jl>H0n_3V0500
n_3V00<000000?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V01X0
n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H20000oed0n_3V0@3oool005l0n_3V0P000?m50?[`iP030<f5
?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP0F0?[`iP030000
003jl>H0n_3V01X0n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H20000oel0n_3V0@3oool00640n_3V00<0
003o0?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V01/0n_3V00<0
00000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0J0?[`iP030<f5?`3jl>H0n_3V0440n_3V0P00
0?mQ0?[`iP40oooo001R0?[`iP80003o@P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0
n_3V01/0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0J0?[`iP030<f5?`3jl>H0
n_3V03l0n_3V0P000?mS0?[`iP40oooo001T0?[`iP80003o@03jl>H00`3=QCl0n_3V0?[`iP1@0?[`
iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0I0?[`
iP030<f5?`3jl>H0n_3V03h0n_3V0P000?mU0?[`iP40oooo001V0?[`iP80003o?`3jl>H00`3=QCl0
n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H0503jl>H00`000000
n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V03`0n_3V0P000?mW0?[`iP40oooo001X0?[`iP030000
o`3jl>H0n_3V03`0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP0L0?[`iP030000
003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H06@3jl>H00`3=QCl0n_3V0?[`iP0k0?[`iP030000
o`3jl>H0n_3V06L0n_3V0@3oool006T0n_3V0P000?ll0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<0
00000?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V01T0n_3V00<0
cHDo0?[`iP3jl>H0>@3jl>H20000ofX0n_3V0@3oool006/0n_3V0P000?lj0?[`iP030<f5?`3jl>H0
n_3V04l0n_3V00<000000?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP0C0?[`iP030000003jl>H0
n_3V01T0n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000?l0n_3V0?[`iP1Z0?[`iP40oooo001]0?[`
iP030000o`3jl>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP0M0?[`
iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H06@3jl>H00`3=QCl0n_3V0?[`iP0f0?[`
iP80003oK@3jl>H10?ooo`00KP3jl>H20000ocL0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000
n_3V0?[`iP0M0?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0603jl>H00`3=QCl0
n_3V0?[`iP0e0?[`iP80003oK`3jl>H10?ooo`00L03jl>H20000ocH0n_3V00<0cHDo0?[`iP3jl>H0
CP3jl>H00`000000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0
603jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000o`3jl>H0n_3V06l0n_3V0@3oool00780n_3V00<0
003o0?[`iP3jl>H0<`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V01h0n_3V00<0
00000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0H0?[`iP030<f5?`3jl>H0n_3V0380n_3V0P00
0?mb0?[`iP40oooo001c0?[`iP80003o<`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0
n_3V01h0n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0H0?[`iP030<f5?`3jl>H0
n_3V0340n_3V00<0003o0?[`iP3jl>H0LP3jl>H10?ooo`00M@3jl>H20000oc40n_3V00<0cHDo0?[`
iP3jl>H0CP3jl>H00`000000n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`
iP3jl>H05`3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP80003oM@3jl>H10?ooo`00M`3jl>H00`000?l0
n_3V0?[`iP0_0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H07`3jl>H00`000000
n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V01L0n_3V00<0cHDo0?[`iP3jl>H0;P3jl>H20000ogL0
n_3V0@3oool007P0n_3V0P000?l_0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0
7`3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V01L0n_3V00<0cHDo0?[`iP3jl>H0
;@3jl>H00`000?l0n_3V0?[`iP1g0?[`iP40oooo001j0?[`iP80003o;@3jl>H00`3=QCl0n_3V0?[`
iP1=0?[`iP030000003jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`
iP0G0?[`iP030<f5?`3jl>H0n_3V02/0n_3V0P000?mj0?[`iP40oooo001l0?[`iP030000o`3jl>H0
n_3V02X0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP0P0?[`iP030000003jl>H0
n_3V0100n_3V00<000000?[`iP3jl>H05P3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP030000o`3jl>H0
n_3V07X0n_3V0@3oool007d0n_3V0P000?l[0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`
iP3jl>H0803jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V01H0n_3V00<0cHDo0?[`
iP3jl>H0:@3jl>H20000ogd0n_3V0@3oool007l0n_3V0P000?lY0?[`iP030<f5?`3jl>H0n_3V04`0
n_3V00<000000?[`iP3jl>H0803jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V01H0
n_3V00<0cHDo0?[`iP3jl>H09`3jl>H20000ogl0n_3V0@3oool00840n_3V00<0003o0?[`iP3jl>H0
9P3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0
3`3jl>H00`000000n_3V0?[`iP0F0?[`iP030<f5?`3jl>H0n_3V02H0n_3V00<0003o0?[`iP3jl>H0
O`3jl>H10?ooo`00PP3jl>H20000obH0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`
iP0Q0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H05@3jl>H00`3=QCl0n_3V0?[`
iP0U0?[`iP80003oPP3jl>H10?ooo`00Q03jl>H20000obD0n_3V00<0cHDo0?[`iP3jl>H0B`3jl>H0
0`000000n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H05@3jl>H0
0`3=QCl0n_3V0?[`iP0T0?[`iP030000o`3jl>H0n_3V0880n_3V0@3oool008H0n_3V00<0003o0?[`
iP3jl>H08P3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V0280n_3V00<000000?[`
iP3jl>H03P3jl>H00`000000n_3V0?[`iP0D0?[`iP030<f5?`3jl>H0n_3V02<0n_3V0P000?n50?[`
iP40oooo00270?[`iP80003o8`3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V0280
n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0D0?[`iP030<f5?`3jl>H0n_3V0240
n_3V0P000?n70?[`iP40oooo00290?[`iP80003o8@3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000
003jl>H0n_3V0280n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0D0?[`iP030<f5
?`3jl>H0n_3V0200n_3V00<0003o0?[`iP3jl>H0Q`3jl>H10?ooo`00R`3jl>H20000oal0n_3V00<0
cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP0S0?[`iP030000003jl>H0n_3V00d0n_3V00<0
00000?[`iP3jl>H0503jl>H00`3=QCl0n_3V0?[`iP0N0?[`iP80003oRP3jl>H10?ooo`00S@3jl>H0
0`000?l0n_3V0?[`iP0L0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H08`3jl>H0
0`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V01<0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H0
0`000?l0n_3V0?[`iP2:0?[`iP40oooo002>0?[`iP80003o7@3jl>H00`3=QCl0n_3V0?[`iP190?[`
iP030000003jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0C0?[`
iP030<f5?`3jl>H0n_3V01`0n_3V0P000?n=0?[`iP40oooo002@0?[`iP80003o703jl>H00`3=QCl0
n_3V0?[`iP180?[`iP030000003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0303jl>H00`000000
n_3V0?[`iP0B0?[`iP030<f5?`3jl>H0n_3V01/0n_3V0P000?n?0?[`iP40oooo002B0?[`iP030000
o`3jl>H0n_3V01T0n_3V00<0cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP0T0?[`iP030000
003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H04@3jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP030000
o`3jl>H0n_3V08l0n_3V0@3oool009<0n_3V0P000?lJ0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<0
00000?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V0140n_3V00<0
cHDo0?[`iP3jl>H06@3jl>H20000oi80n_3V0@3oool009D0n_3V00<0003o0?[`iP3jl>H05`3jl>H0
0`3=QCl0n_3V0?[`iP170?[`iP030000003jl>H0n_3V02D0n_3V00<000000?[`iP3jl>H02`3jl>H0
0`000000n_3V0?[`iP0@0?[`iP030<f5?`3jl>H0n_3V01T0n_3V00<0003o0?[`iP3jl>H0TP3jl>H1
0?ooo`00UP3jl>H20000oaP0n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP0U0?[`
iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP0G0?[`
iP80003oU@3jl>H10?ooo`00V03jl>H00`000?l0n_3V0?[`iP0E0?[`iP030<f5?`3jl>H0n_3V04H0
n_3V00<000000?[`iP3jl>H09@3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00l0
n_3V00<0cHDo0?[`iP3jl>H05`3jl>H00`000?l0n_3V0?[`iP2E0?[`iP40oooo002I0?[`iP80003o
5P3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0
2P3jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V01D0n_3V0P000?nH0?[`iP40oooo
002K0?[`iP030000o`3jl>H0n_3V01<0n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`
iP0V0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H03P3jl>H00`3=QCl0n_3V0?[`
iP0E0?[`iP030000o`3jl>H0n_3V09P0n_3V0@3oool009`0n_3V0P000?lD0?[`iP030<f5?`3jl>H0
n_3V04@0n_3V00<000000?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0
n_3V00h0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H20000oi/0n_3V0@3oool009h0n_3V00<0003o0?[`
iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`iP130?[`iP030000003jl>H0n_3V02L0n_3V00<000000?[`
iP3jl>H02@3jl>H00`000000n_3V0?[`iP0=0?[`iP030<f5?`3jl>H0n_3V01<0n_3V00<0003o0?[`
iP3jl>H0V`3jl>H10?ooo`00W`3jl>H20000oa80n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H00`000000
n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0303jl>H00`3=QCl0
n_3V0?[`iP0B0?[`iP80003oWP3jl>H10?ooo`00X@3jl>H00`000?l0n_3V0?[`iP0@0?[`iP030<f5
?`3jl>H0n_3V0480n_3V00<000000?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP090?[`iP030000
003jl>H0n_3V00`0n_3V00<0cHDo0?[`iP3jl>H04@3jl>H00`000?l0n_3V0?[`iP2N0?[`iP40oooo
002R0?[`iP80003o4@3jl>H00`3=QCl0n_3V0?[`iP110?[`iP030000003jl>H0n_3V02P0n_3V00<0
00000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0;0?[`iP030<f5?`3jl>H0n_3V0100n_3V0P00
0?nQ0?[`iP40oooo002T0?[`iP030000o`3jl>H0n_3V00l0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H0
0`000000n_3V0?[`iP0X0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H02P3jl>H0
0`3=QCl0n_3V0?[`iP0@0?[`iP030000o`3jl>H0n_3V0:40n_3V0@3oool00:D0n_3V0P000?l?0?[`
iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP080?[`
iP030000003jl>H0n_3V00T0n_3V00<0cHDo0?[`iP3jl>H03`3jl>H20000oj@0n_3V0@3oool00:L0
n_3V00<0003o0?[`iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V02T0
n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP090?[`iP030<f5?`3jl>H0n_3V00h0
n_3V00<0003o0?[`iP3jl>H0Y03jl>H10?ooo`00Z03jl>H20000o`h0n_3V00<0cHDo0?[`iP3jl>H0
?P3jl>H00`000000n_3V0?[`iP0Y0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0
203jl>H00`3=QCl0n_3V0?[`iP0=0?[`iP80003oY`3jl>H10?ooo`00ZP3jl>H20000o``0n_3V00<0
cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0Y0?[`iP030000003jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP80003oZ@3jl>H10?ooo`00[03jl>H0
0`000?l0n_3V0?[`iP0:0?[`iP030<f5?`3jl>H0n_3V03d0n_3V00<000000?[`iP3jl>H0:P3jl>H0
0`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V00L0n_3V00<0cHDo0?[`iP3jl>H02P3jl>H2
0000oj/0n_3V0@3oool00:d0n_3V0P000?l;0?[`iP80cHDo?@3jl>H00`000000n_3V0?[`iP0Z0?[`
iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H01@3jl>H20<f5?``0n_3V00<0003o0?[`
iP3jl>H0Z`3jl>H10?ooo`00[`3jl>H20000o`X0n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H00`000000
n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0103jl>H00`3=QCl0
n_3V0?[`iP0:0?[`iP80003o[P3jl>H10?ooo`00/@3jl>H00`000?l0n_3V0?[`iP080?[`iP030<f5
?`3jl>H0n_3V03X0n_3V00<000000?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP050?[`iP030000
003jl>H0n_3V00@0n_3V00<0cHDo0?[`iP3jl>H0203jl>H20000ok00n_3V0@3oool00;80n_3V0P00
0?l90?[`iP030<f5?`3jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`
iP050?[`iP030000003jl>H0n_3V00<0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H20000ok80n_3V0@3o
ool00;@0n_3V0P000?l80?[`iP030<f5?`3jl>H0n_3V03P0n_3V00<000000?[`iP3jl>H0:`3jl>H0
0`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V0080n_3V00<0cHDo0?[`iP3jl>H01`3jl>H0
0`000?l0n_3V0?[`iP2b0?[`iP40oooo002f0?[`iP030000o`3jl>H0n_3V00H0n_3V00<0cHDo0?[`
iP3jl>H0=`3jl>H00`000000n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V00@0n_3V00D000000?[`
iP3jl>H0n_3V0<f5?`080?[`iP80003o]@3jl>H10?ooo`00]`3jl>H20000o`L0n_3V0P3=QClg0?[`
iP030000003jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0103jl>H010000000n_3V0<f5?`3=QCl7
0?[`iP80003o]`3jl>H10?ooo`00^@3jl>H20000o`H0n_3V00<0cHDo0?[`iP3jl>H0=@3jl>H00`00
0000n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V00@0n_3V00<000000<f5?`3jl>H01P3jl>H20000
okT0n_3V0@3oool00;/0n_3V00<0003o0?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP03
0000003jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0103jl>H00`000000cHDo0?[`iP050?[`iP03
0000o`3jl>H0n_3V0;T0n_3V0@3oool00;`0n_3V0P000?l50?[`iP80cHDo=03jl>H00`000000n_3V
0?[`iP0]0?[`iP030000003jl>H0n_3V0080n_3V00<0cHDo0000003jl>H0103jl>H20000ok`0n_3V
0@3oool00;h0n_3V0P000?l50?[`iP030<f5?`3jl>H0n_3V0340n_3V00<000000?[`iP3jl>H0;@3j
l>H01`000000n_3V0?[`iP3jl>H0cHDo0?[`iP0000000`3jl>H20000okh0n_3V0@3oool00<00n_3V
00<0003o0?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V02d0n_3V
0`0000000`3=QCl0n_3V0000000200000080003o`03jl>H10?ooo`00`@3jl>H20000o`@0n_3V00<0
cHDo0?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0/0?[`iPX00000`@3jl>H10?ooo`00``3jl>H2
0000o`<0n_3V0P3=QCl_0?[`iP030000003jl>H0n_3V02`0n_3V2P0000310?[`iP40oooo00350?[`
iP80003o0`3jl>H00`3=QCl0n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V02`0n_3V2P0000310?[`
iP40oooo00370?[`iP80003o0P3jl>H20<f5?b`0n_3V00<000000?[`iP3jl>H0:P3jl>H20<f5?`04
0?[`iP000000000000000080n_3V0`0000320?[`iP40oooo00390?[`iP80003o0P3jl>H20<f5?bX0
n_3V00<000000?[`iP3jl>H0:03jl>H20<f5?`80n_3V0P000?l00`3jl>H000000?[`iP020?[`iP03
0000003jl>H0n_3V0<40n_3V0@3oool00</0n_3V0P000?l20?[`iP030<f5?`3jl>H0n_3V02L0n_3V
00<000000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V0?[`iP020000o`<0n_3V00D000000?[`iP3jl>H0
n_3V000000330?[`iP40oooo003=0?[`iP80003o00<0n_3V0<f5?`3=QCl09`3jl>H00`000000n_3V
0?[`iP0U0?[`iP80cHDo00<0n_3V0000o`000?l01P3jl>H010000000n_3V0?[`iP0000330?[`iP40
oooo003?0?[`iP<0003o0P3=QClU0?[`iP030000003jl>H0n_3V02<0n_3V0P3=QCl00`3jl>H0003o
0000o`080?[`iP040000003jl>H0n_3V00000<<0n_3V0@3oool00=80n_3V0`000?l00`3=QCl0n_3V
0?[`iP0Q0?[`iP030000003jl>H0n_3V0240n_3V0P3=QCl00`3jl>H0003o0000o`0:0?[`iP040000
003jl>H0n_3V00000<<0n_3V0@3oool00=D0n_3V0P000?l00`3=QCl0n_3V0?[`iP0O0?[`iP030000
003jl>H0n_3V01l0n_3V0P3=QCl30000o`d0n_3V00<000000?[`iP000000``3jl>H10?ooo`00e`3j
l>H30000oal0n_3V00<000000?[`iP3jl>H07@3jl>H20<f5?`80003o403jl>H00`000000n_3V0000
00330?[`iP40oooo003J0?[`iP<0003o00<0cHDo0?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0I
0?[`iP<0cHDo0`000?lB0?[`iP030000003jl>H000000<<0n_3V0@3oool00=d0n_3V0`000?lI0?[`
iP030000003jl>H0n_3V01L0n_3V00<0cHDo0000o`000?l00P000?lF0?[`iP800000``3jl>H10?oo
o`00h03jl>H40000oaD0n_3V00<000000?[`iP3jl>H04`3jl>H00`3=QCl0003o0000o`020000oaX0
n_3V0P0000330?[`iP40oooo003T0?[`iP@0003o4@3jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5
?`000?l0003o0080003o7P3jl>H300000<80n_3V0@3oool00>P0n_3V10000?l=0?[`iP030000003j
l>H0n_3V00/0n_3V1@000?lQ0?[`iPD00000`@3jl>H10?ooo`00k03=QCl=0000o`03000000000?l0
003o00/0003o9P3=QCl500000<00cHDo0@3jl>H10?ooo`00o`3jl>H^0?[`iPD00000`@3jl>H10?oo
o`00o`3jl>H_0?[`iP<00000`P3jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo002f0?[`iP80000000<0IV9N0<c4^`3jl>H0:`3jl>H01P3Dc<<0IV9N000000000000RHAn
0>CKdVD0n_3V00H0e<c306IRGP000000000008V4OP3Tfm:L0?[`iP40oooo002h0?[`iP0306IRGP00
0000g=C;02/0n_3V00H0C4U50<>k/`3jl>H0k>;I00000029Q7iU0?[`iP0604a9A@33^k<0n_3V0>cR
f@000000RHAnW03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H0102_
Z:40C4U500000029Q7h70?[`iP060=cDb`1iMG00000000000029Q7h0c<Bk0P3jl>H0102_Z:40C4U5
00000029Q7h20?[`iP8000000P3jl>H2000000050?[`iP3<a;/0000007UeL03jl>H00P0000020?[`
iP80000000<0IV9N0?[`iP3jl>H01`3jl>H2000000<0n_3V00@0c<Bk04a9A@1VHUh0i=_B0P000000
0`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3j
l>H200000080n_3V00<0RHAn06IRGP3<a;/00P0000070?[`iP050=cDb`1iMG00000004a9A@2TWIH0
0P3jl>H0103<a;/0C4U506IRGP3Tfm82000000030?[`iP000000000000@0n_3V00<0Y9fF0000002T
WIH00`3jl>H0102_Z:40C4U500000029Q7h70?[`iP040:nXX@1<BDD0C4U50:nXX@80n_3V0P000006
0?[`iP80000000D0n_3V0<>k/`000000`k^c0?[`iP02000000050?[`iP3<a;/0C4U504a9A@2_Z:40
0P0000000`3jl>H00000000000030?[`iP80000000D0n_3V0<c4^`1<BDD0C4U50:nXX@02000000@0
n_3V0P0000000`3/h]T0n_3V0>cRf@0200000080n_3V00<0RHAn06IRGP3<a;/00P0000000`3jl>H0
0000000000020?[`iP8000000P3jl>H0102_Z:40C4U500000029Q7h20?[`iP070>cRf@2GTH/00000
0000001iMG00i=_B0?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2
000000070?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP050?[`iP050>CKdP000000Ui6;0?[`iP2i
/ZX00P000000203jl>H0[jRQ00000033^k<0i=_B00000029Q7h0n_3V0P0000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP3<a;/000000080000000<0i=_B0?[`iP3jl>H01P3j
l>H2000000<0n_3V00@0IV9N0000003Tfm80^K:Z0P0000000`3jl>H00000000000030?[`iP800000
0P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000050?[`iP2TWIH000000<>k
/`2TWIH00P0000060?[`iP0<0>CKdP000000Ui6;0?[`iP3Dc<<0000008V4OP3jl>H0IV9N0000003T
fm80^K:Z0P0000000`3jl>H00000000000040?[`iP<0000000P0k>;I0?[`iP2_Z:4000000<>k/`3T
fm80000008V4OPD0n_3V00L0^K:Z00000033^k<0`k^c0000002i/ZX0n_3V008000001P3jl>H20000
00050?[`iP2GTH/0000009NAR`3jl>H00P0000001@3jl>H0C4U50000003Tfm80`k^c0080000000<0
n_3V0000000000000`3jl>H2000000050?[`iP1<BDD000000>CKdP33^k<00P0000040?[`iP0<08V4
OP000000e<c30?[`iP3Dc<<0000008V4OP3jl>H0Y9fF00000033^k<0Y9fF0P0000000`3jl>H00000
000000020?[`iP80000000l0n_3V0:nXX@000000`k^c0>CKdP000000RHAn0?[`iP1iMG0000000>CK
dP3/h]T0000006IRGP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V
0P0000000`3jl>H0C4U5000000090?[`iP0309NAR`000000g=C;0080n_3V0P0000000`3jl>H0C4U5
000000050?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000001P3jl>H0Ui6;
00000029Q7h000000:nXX@P0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP0000000000
00<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V
04a9A@0000000P3jl>H2000000H0n_3V00<0Ui6;0000003Tfm801@3jl>H200000080n_3V0P000000
0`3jl>H00000000000030?[`iP080;VbZP000000RHAn0000002i/ZX0n_3V04a9A@0000090?[`iP07
06IRGP000000n_3V0?[`iP000000IV9N0?[`iP02000000H0n_3V0P0000001@3jl>H0C4U50000001<
BDD0n_3V0080000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000<0n_3V0P00
00000`3jl>H00000000000020?[`iP800000103jl>H00`2_Z:40000000000003000000040:nXX@3j
l>H0C4U500000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V04a9A@000000
1`3jl>H01@3Dc<<0Y9fF0000001<BDD0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V
0P0000020?[`iP80000000<0n_3V000000000000100000050?[`iP0304a9A@000000n_3V0080n_3V
0P0000000`3jl>H0000000000004000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000H0n_3V04a9A@000000k>;I0000001VHUh80?[`iP8000000`3jl>H20000
0080n_3V0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP0000000000
0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000060?[`iP8000001P3jl>H2
00000080n_3V0P0000000`3jl>H00000000000030?[`iP80C4U500@0k>;I04a9A@1<BDD0n_3V1P00
00050?[`iP8000000P3jl>H2000000030?[`iP000000000000H0n_3V0P0000001@3Tfm80000009NA
R`000000i=_B0080000000D0n_3V0<c4^`000000Ui6;0>CKdP02000000030?[`iP000000000000<0
n_3V0P0000001@3jl>H0c<Bk0000002GTH/0i=_B00800000103jl>H0203Dc<<0000008V4OP3jl>H0
Ui6;0000003Dc<<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP000000000000@0000000<0n_3V0<c4^`1<BDD00P0000000`1<BDD0c<Bk0?[`iP02000008@0n_3V
0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP1<BDD000000080n_3V00<0
000006IRGP3jl>H0103jl>H200000080n_3V0`0000000`3jl>H0C4U5000000020?[`iP030000001V
HUh0n_3V008000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000001`3Le</0000008V4
OP3jl>H0RHAn0000003Tfm801`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V00000000
00000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P0000000`3j
l>H0C4U5000000020?[`iP8000001P3jl>H2000000H0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P3jl>H02@3<a;/000000:BMUP3jl>H0Y9fF0000003<a;/0C4U5000000020?[`iP030000
001VHUh0n_3V00@0n_3V00L0IV9N0000003jl>H0n_3V0000001VHUh0n_3V008000001P3jl>H20000
00050<c4^`000000g=C;0000003<a;/00P0000020?[`iP030=cDb`2_Z:40NGE`0080000000<0n_3V
0000000000000`3jl>H200000080n_3V00<0g=C;0:nXX@1iMG000P0000050?[`iP050000001<BDD0
n_3V04a9A@0000000P3jl>H0101<BDD000000?[`iP3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H0C4U5000000020?[`iP070000001VHUh0n_3V04a9A@000000NGE`0<c4^`030?[`
iP800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000002`2TWIH0i=_B0000001VHUh0n_3V
0;VbZP000000`k^c0<c4^`000000^K:Z00D0n_3V00<0C4U50000003jl>H01@3jl>H01`2i/ZX00000
0<>k/`3<a;/000000;VbZP3jl>H00P0000001@2i/ZX0i=_B0000001<BDD0n_3V008000000P3jl>H2
000000070:nXX@000000`k^c0?[`iP33^k<000000:nXX@070?[`iP8000000`3jl>H200000080n_3V
0P000000103jl>H000000000003Dc<<20?[`iP80000000D0^K:Z0>CKdP000000C4U50?[`iP020000
000<0?[`iP00000000000;VbZP3Tfm80000004a9A@3jl>H0Y9fF00000033^k<0Y9fF0P0000060?[`
iP0304a9A@000000n_3V00D0n_3V0P0000020?[`iP8000000180n_3V000000000000e<c30?[`iP1V
HUh000000>cRf@3jl>H0k>;I0000001VHUh0^K:Z00000033^k<0c<Bk0000002i/ZX50?[`iP070;Vb
ZP000000`k^c0<>k/`000000^K:Z0?[`iP02000000H0n_3V0P0000001@2TWIH0IV9N0?[`iP1VHUh0
Y9fF0080000000P0n_3V07UeL03Dc<<0n_3V0>CKdP000000C4U50?[`iP80000000<0e<c30?[`iP3j
l>H00P0000001`3jl>H0NGE`0=C<``3jl>H0i=_B0000001<BDD01@3jl>H01@1iMG0000000<c4^`00
0000IV9N0080n_3V00@0Y9fF00000033^k<0Y9fF0P0000005P3jl>H000000000002i/ZX0i=_B0000
001<BDD0n_3V0;VbZP000000`k^c0<c4^`000000^K:Z0?[`iP1VHUh000000?[`iP3Tfm80000007Ue
L03jl>H2000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP80000000@0g=C;08V4OP1<BDD0c<Bk
0P3jl>H0102_Z:4000000000002_Z:460?[`iP0309NAR`000000i=_B00H0n_3V00@0[jRQ00000000
0000[jRQ0P3jl>H2000000040<c4^`1iMG00C4U50<c4^`@0000000X0n_3V000000000000IV9N0000
003/h]T0n_3V0>cRf@000000IV9N1`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V0000
00000000RHAn07UeL03jl>H2000000050<c4^`1iMG00C4U50<c4^`3jl>H00P0000001`3jl>H00000
0000003<a;/0NGE`04a9A@3<a;/00P3jl>H00`29Q7h0IV9N0<c4^`02000000H0n_3V00<0Ui6;0000
003Tfm801@3jl>H200000080n_3V0P000000103jl>H0000000000029Q7h20000000808V4OP3jl>H0
n_3V0?[`iP29Q7h000000=cDb`2_Z:42000000030:nXX@3jl>H0n_3V00D0n_3V00D0[jRQ04a9A@00
0000[jRQ0?[`iP04000000D0n_3V0P0000001@1VHUh0Y9fF0?[`iP2GTH/0IV9N0080000000<0n_3V
0>CKdP29Q7h00P0000000`1VHUh0e<c30?[`iP020000000308V4OP1iMG00n_3V0080000000<0n_3V
0>CKdP29Q7h00P0000000`1VHUh0e<c30?[`iP040?[`iP050:BMUP000000RHAn0000002TWIH00`3j
l>H00`29Q7h0IV9N0<c4^`02000000070?[`iP00000000000<c4^`1iMG00C4U50<c4^`020?[`iP04
0:nXX@00000000000:nXX@80n_3V00L0i=_B07UeL0000000000008V4OP3Tfm80n_3V00800000Q03j
l>H10?ooo`00P`3jl>H2000000<0n_3V0P00000@0?[`iP070>CKdP000000Ui6;0?[`iP3Dc<<00000
07UeL00?0?[`iP8000000P3jl>H2000000h0n_3V0P00000/0?[`iP070>CKdP000000Ui6;0?[`iP3D
c<<0000008V4OP0U0?[`iP8000001P3jl>H3000000030<c4^`3jl>H0`k^c00<000006`3jl>H01@3<
a;/00000000000000000`k^c0:@0n_3V0@3oool00840n_3V1P0000000`3jl>H000000000000A0?[`
iP060=cDb`1iMG0000000000002GTH/0k>;I3`3jl>H0103Le</0RHAn0?[`iP3jl>H2000000`0n_3V
1P00000D0?[`iP8000005@3jl>H01@3Le</0NGE`000000000000Y9fF02H0n_3V00@0c<Bk06IRGP00
0000RHAn103jl>H3000000030>cRf@3jl>H0g=C;00<000003@3jl>H2000000`0n_3V00D0k>;I0000
0000000000000>CKdP0N0?[`iP800000Q03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.65217 .38333 L
s
.65217 .05 m
.65217 .38333 L
s
.62593 .32584 m
.65217 .32584 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.65217 .38333 Mdot
.62593 .32584 Mdot
.65217 .32584 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V2P3=QCl20?[`iP030000003jl>H0n_3V
00X0cHDo?`3jl>H00`000000n_3V0?[`iP2[0?[`iP40oooo003W0?[`iPH0cHDo303jl>H2000000/0
n_3V1`3=QClh0?[`iP030000003jl>H0n_3V0:/0n_3V0@3oool00>D0n_3V0P3=QClB0?[`iP800000
4P3jl>H20<f5?cH0n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00h@3jl>H40<f5?a@0n_3V00<0
00000?[`iP0000004`3jl>H30<f5?c<0n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00g@3jl>H4
0<f5?aP0n_3V00<000000?[`iP0000005P3jl>H40<f5?bl0n_3V00<000000?[`iP3jl>H0Z`3jl>H1
0?ooo`00f`3jl>H20<f5?a`0n_3V00@000000?[`iP3jl>H000006@3jl>H20<f5?bd0n_3V00<00000
0?[`iP3jl>H0Z`3jl>H10?ooo`00f@3jl>H20<f5?ah0n_3V00@000000?[`iP3jl>H000006`3jl>H2
0<f5?b/0n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00e`3jl>H20<f5?b00n_3V00D000000?[`
iP3jl>H0n_3V0000000L0?[`iP80cHDo:@3jl>H00`000000n_3V0?[`iP2[0?[`iP40oooo003E0?[`
iP80cHDo8P3jl>H01@000000n_3V0?[`iP3jl>H0000001h0n_3V0P3=QClW0?[`iP030000003jl>H0
n_3V0:/0n_3V0@3oool00=<0n_3V0P3=QClT0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`
iP3jl>H07@3jl>H20<f5?bD0n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00d@3jl>H20<f5?bH0
n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0O0?[`iP80cHDo8`3jl>H00`000000
n_3V0?[`iP2[0?[`iP40oooo003?0?[`iP80cHDo:03jl>H00`000000n_3V0?[`iP020?[`iP030000
003jl>H0n_3V0240n_3V0P3=QClQ0?[`iP030000003jl>H0n_3V0:/0n_3V0@3oool00<h0n_3V00<0
cHDo0?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0280n_3V00<0
cHDo0?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP2[0?[`iP40oooo003<0?[`iP80cHDo:`3jl>H0
0`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V02<0n_3V0P3=QClN0?[`iP030000003jl>H0
n_3V0:/0n_3V0@3oool00<X0n_3V0P3=QCl]0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`
iP3jl>H0903jl>H20<f5?a`0n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00b@3jl>H00`3=QCl0
n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H09P3jl>H00`3=QCl0
n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V0:/0n_3V0@3oool00<L0n_3V0P3=QCl`0?[`iP030000
003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H09P3jl>H20<f5?aT0n_3V00<000000?[`iP3jl>H0
Z`3jl>H10?ooo`00aP3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V00D0n_3V00<0
00000?[`iP3jl>H0:03jl>H00`3=QCl0n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V0:/0n_3V0@3o
ool00<D0n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0
n_3V02P0n_3V00<0cHDo0?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP2[0?[`iP40oooo00340?[`
iP030<f5?`3jl>H0n_3V0380n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP0Y0?[`
iP030<f5?`3jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00`P3jl>H20<f5?cD0
n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0Y0?[`iP80cHDo503jl>H00`000000
n_3V0?[`iP2[0?[`iP40oooo00310?[`iP030<f5?`3jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`000000n_3V0?[`iP0Z0?[`iP030<f5?`3jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0
Z`3jl>H10?ooo`00`03jl>H00`3=QCl0n_3V0?[`iP0f0?[`iP030000003jl>H0n_3V00P0n_3V00<0
00000?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0:/0n_3V0@3o
ool00;l0n_3V00<0cHDo0?[`iP3jl>H0=`3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0
n_3V02/0n_3V0P3=QClA0?[`iP030000003jl>H0n_3V0:/0n_3V0@3oool00;h0n_3V00<0cHDo0?[`
iP3jl>H0>03jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V02d0n_3V00<0cHDo0?[`
iP3jl>H03P3jl>H00`000000n_3V0?[`iP2[0?[`iP40oooo002m0?[`iP030<f5?`3jl>H0n_3V03T0
n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0]0?[`iP030<f5?`3jl>H0n_3V00d0
n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00_03jl>H00`3=QCl0n_3V0?[`iP0j0?[`iP030000
003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0;P3jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP030000
003jl>H0n_3V0:/0n_3V0@3oool00;/0n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H00`000000n_3V0?[`
iP0:0?[`iP030000003jl>H0n_3V02d0n_3V00<0cHDo0?[`iP3jl>H0303jl>H00`000000n_3V0?[`
iP2[0?[`iP40oooo002j0?[`iP030<f5?`3jl>H0n_3V03`0n_3V00<000000?[`iP3jl>H02P3jl>H0
0`000000n_3V0?[`iP0^0?[`iP030<f5?`3jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0Z`3jl>H1
0?ooo`00^@3jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`
iP3jl>H0;P3jl>H20<f5?`/0n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00^03jl>H00`3=QCl0
n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0;`3jl>H00`3=QCl0
n_3V0?[`iP090?[`iP030000003jl>H0n_3V0:/0n_3V0@3oool00;P0n_3V00<0cHDo0?[`iP3jl>H0
?P3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V02l0n_3V00<0cHDo0?[`iP3jl>H0
203jl>H00`000000n_3V0?[`iP2[0?[`iP40oooo002g0?[`iP030<f5?`3jl>H0n_3V03l0n_3V00<0
00000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0`0?[`iP030<f5?`3jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H0Z`3jl>H10?ooo`00]P3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0
n_3V00d0n_3V00<000000?[`iP3jl>H0;`3jl>H00`3=QCl0n_3V0?[`iP070?[`iP030000003jl>H0
n_3V0:/0n_3V0@3oool00;H0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP0=0?[`
iP030000003jl>H0n_3V0300n_3V00<0cHDo0?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP2[0?[`
iP40oooo002e0?[`iP030<f5?`3jl>H0n_3V0440n_3V00<000000?[`iP3jl>H03@3jl>H00`000000
n_3V0?[`iP0a0?[`iP030<f5?`3jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00
]03jl>H00`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0
<@3jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000003jl>H0n_3V0:/0n_3V0@3oool00;<0n_3V00<0
cHDo0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V0380n_3V00<0
cHDo0?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP2[0?[`iP40oooo002b0?[`iP030<f5?`3jl>H0
n_3V04@0n_3V00<000000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP0a0?[`iP030<f5?`3jl>H0
n_3V00<0n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00/P3jl>H00`3=QCl0n_3V0?[`iP140?[`
iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0<P3jl>H00`3=QCl0n_3V0?[`iP020?[`
iP030000003jl>H0n_3V0:/0n_3V0@3oool00;40n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000
n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V0340n_3V00<0cHDo0?[`iP3jl>H00P3jl>H00`000000
n_3V0?[`iP2[0?[`iP40oooo002a0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0
403jl>H00`000000n_3V0?[`iP0b0?[`iP050<f5?`3jl>H0n_3V0?[`iP000000[@3jl>H10?ooo`00
/03jl>H00`3=QCl0n_3V0?[`iP160?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H0
<@3jl>H01@3=QCl0n_3V0?[`iP3jl>H000000:d0n_3V0@3oool00;00n_3V00<0cHDo0?[`iP3jl>H0
AP3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0380n_3V00@0cHDo0?[`iP3jl>H0
0000[@3jl>H10?ooo`00[`3jl>H00`3=QCl0n_3V0?[`iP170?[`iP030000003jl>H0n_3V0180n_3V
00<000000?[`iP3jl>H0<@3jl>H0103=QCl0n_3V0?[`iP00002]0?[`iP40oooo002_0?[`iP030<f5
?`3jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0b0?[`iP030<f5
?`3jl>H000000:d0n_3V0@3oool00:h0n_3V00<0cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`
iP0C0?[`iP030000003jl>H0n_3V0380n_3V00<0cHDo0000003jl>H0[03jl>H10?ooo`00[@3jl>H0
0`3=QCl0n_3V0?[`iP190?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0<P3jl>H0
0`3=QCl000000?[`iP2/0?[`iP40oooo002]0?[`iP030<f5?`3jl>H0n_3V04T0n_3V00<000000?[`
iP3jl>H04`3jl>H00`000000n_3V0?[`iP0c0?[`iP030000003jl>H0n_3V0:/0n_3V0@3oool00:`0
n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V0380
n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00[03jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000
003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0<P3jl>H00`000000cHDo0?[`iP2[0?[`iP40oooo
00020000ojX0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003j
l>H0n_3V0340n_3V00<000000<f5?`3jl>H0Z03jl>H20000o`40n_3V0@3oool00080n_3V0`000?nW
0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0a
0?[`iP030000003=QCl0n_3V0:D0n_3V0`000?l30?[`iP40oooo00050?[`iP@0003oXP3jl>H00`3=
QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H0<03jl>H00`00
0000cHDo0?[`iP2Q0?[`iP@0003o1P3jl>H10?ooo`002@3jl>H30000oil0n_3V00<0cHDo0?[`iP3j
l>H0B`3jl>H00`000000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V0300n_3V00<000000?[`iP3=
QCl0WP3jl>H30000o`X0n_3V0@3oool000`0n_3V0`000?nK0?[`iP030<f5?`3jl>H0n_3V04`0n_3V
00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP0_0?[`iP030000003jl>H0cHDo09/0n_3V
0`000?l=0?[`iP40oooo000?0?[`iP@0003oU`3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003j
l>H0n_3V01L0n_3V00<000000?[`iP3jl>H0;`3jl>H010000000n_3V0?[`iP3=QCnF0?[`iP@0003o
403jl>H10?ooo`004`3jl>H30000oi@0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`
iP0H0?[`iP030000003jl>H0n_3V02h0n_3V00@000000?[`iP3jl>H0cHDoT`3jl>H30000oa@0n_3V
0@3oool001H0n_3V0`000?nA0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0603j
l>H00`000000n_3V0?[`iP0^0?[`iP040000003jl>H0n_3V0<f5?i00n_3V0`000?lG0?[`iP40oooo
000I0?[`iP<0003oS@3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V01P0n_3V00<0
00000?[`iP3jl>H0;P3jl>H010000000n_3V0?[`iP3=QCn=0?[`iP<0003o6P3jl>H10?ooo`00703j
l>H30000ohX0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP0I0?[`iP030000003j
l>H0n_3V02d0n_3V00D000000?[`iP3jl>H0n_3V0<f5?`290?[`iP<0003o7@3jl>H10?ooo`007`3j
l>H40000ohH0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP0I0?[`iP030000003j
l>H0n_3V02d0n_3V00D000000?[`iP3jl>H0n_3V0<f5?`260?[`iP<0003o803jl>H10?ooo`008`3j
l>H30000oh<0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP0J0?[`iP030000003j
l>H0n_3V02`0n_3V00D000000?[`iP3jl>H0n_3V0<f5?`230?[`iP<0003o8`3jl>H10?ooo`009P3j
l>H30000ogl0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP0J0?[`iP030000003j
l>H0n_3V02`0n_3V00D000000?[`iP3jl>H0n_3V0<f5?`200?[`iP<0003o9P3jl>H10?ooo`00:@3j
l>H30000og`0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP0K0?[`iP030000003j
l>H0n_3V02/0n_3V00<000000?[`iP3jl>H00P3jl>H00`3=QCl0n_3V0?[`iP1j0?[`iP<0003o:@3j
l>H10?ooo`00;03jl>H20000ogX0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP0K
0?[`iP030000003jl>H0n_3V02/0n_3V00<000000?[`iP3jl>H00P3jl>H00`3=QCl0n_3V0?[`iP1h
0?[`iP80003o;03jl>H10?ooo`00;P3jl>H20000ogP0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`00
0000n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H00P3jl>H00`3=
QCl0n_3V0?[`iP1f0?[`iP80003o;P3jl>H10?ooo`00<03jl>H30000og@0n_3V00<0cHDo0?[`iP3j
l>H0C`3jl>H00`000000n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3j
l>H00P3jl>H00`3=QCl0n_3V0?[`iP1c0?[`iP<0003o<03jl>H10?ooo`00<`3jl>H20000og80n_3V
00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP0M0?[`iP030000003jl>H0n_3V02T0n_3V
00<000000?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP1`0?[`iP80003o<`3jl>H10?ooo`00=@3j
l>H20000og00n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP0M0?[`iP030000003j
l>H0n_3V02T0n_3V00<000000?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP1^0?[`iP80003o=@3j
l>H10?ooo`00=`3jl>H30000ofd0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP0N
0?[`iP030000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP1[
0?[`iP<0003o=`3jl>H10?ooo`00>P3jl>H20000of/0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`00
0000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H00`3jl>H00`3=
QCl0n_3V0?[`iP1Y0?[`iP80003o>P3jl>H10?ooo`00?03jl>H20000ofT0n_3V00<0cHDo0?[`iP3j
l>H0C`3jl>H00`000000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V02P0n_3V00<000000?[`iP3j
l>H00`3jl>H00`3=QCl0n_3V0?[`iP1W0?[`iP80003o?03jl>H10?ooo`00?P3jl>H30000ofD0n_3V
00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V02L0n_3V
00<000000?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP1T0?[`iP<0003o?P3jl>H10?ooo`00@@3j
l>H20000of<0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0O0?[`iP030000003j
l>H0n_3V02L0n_3V00<000000?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP1Q0?[`iP80003o@@3j
l>H10?ooo`00@`3jl>H20000of40n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0P
0?[`iP030000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP1O
0?[`iP80003o@`3jl>H10?ooo`00A@3jl>H20000oel0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`00
0000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0103jl>H00`3=
QCl0n_3V0?[`iP1M0?[`iP80003oA@3jl>H10?ooo`00A`3jl>H20000oed0n_3V00<0cHDo0?[`iP3j
l>H0D03jl>H00`000000n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V02D0n_3V00<000000?[`iP3j
l>H0103jl>H00`3=QCl0n_3V0?[`iP1K0?[`iP80003oA`3jl>H10?ooo`00B@3jl>H30000oeX0n_3V
00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V02D0n_3V
00<000000?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP1I0?[`iP80003oB@3jl>H10?ooo`00C03j
l>H20000oeP0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0R0?[`iP030000003j
l>H0n_3V02@0n_3V00<000000?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP1G0?[`iP80003oB`3j
l>H10?ooo`00CP3jl>H20000oeH0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H3000002<0n_3V00<00000
0?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V05D0n_3V0P000?m=
0?[`iP40oooo001@0?[`iP80003oE03jl>H00`3=QCl0n_3V0?[`iP1>0?[`iPD000008`3jl>H00`00
0000n_3V0?[`iP0S0?[`iP030000003jl>H0n_3V00@0n_3V00<0cHDo0?[`iP3jl>H0D`3jl>H20000
odl0n_3V0@3oool00580n_3V0P000?mB0?[`iP030<f5?`3jl>H0n_3V04h0n_3V1@00000S0?[`iP03
0000003jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP1A0?[`iP80
003oD@3jl>H10?ooo`00E03jl>H20000oe00n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H5000002<0n_3V
00<000000?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V04l0n_3V
0P000?mC0?[`iP40oooo001F0?[`iP80003oCP3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP<000009@3j
l>H00`000000n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V00@0n_3V00<0cHDo0?[`iP3jl>H0C@3j
l>H20000oeD0n_3V0@3oool005P0n_3V0P000?m<0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<00000
0?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V00@0n_3V00<0cHDo
0?[`iP3jl>H0B`3jl>H20000oeL0n_3V0@3oool005X0n_3V00<0003o0?[`iP3jl>H0B@3jl>H00`3=
QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V02D0n_3V00<000000?[`iP3jl>H08@3jl>H00`00
0000n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V04T0n_3V0P000?mI0?[`iP40oooo001K0?[`iP80
003oB@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V02D0n_3V00<000000?[`iP3j
l>H08@3jl>H00`000000n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V04L0n_3V0P000?mK0?[`iP40
oooo001M0?[`iP80003oA`3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V02H0n_3V
00<000000?[`iP3jl>H0803jl>H00`000000n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V04D0n_3V
0P000?mM0?[`iP40oooo001O0?[`iP80003oA@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003j
l>H0n_3V02H0n_3V00<000000?[`iP3jl>H0803jl>H00`000000n_3V0?[`iP040?[`iP030<f5?`3j
l>H0n_3V04<0n_3V0P000?mO0?[`iP40oooo001Q0?[`iP030000o`3jl>H0n_3V0480n_3V00<0cHDo
0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V01l0n_3V00<00000
0?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP110?[`iP80003oH@3jl>H10?ooo`00HP3jl>H20000
od80n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V
01l0n_3V00<000000?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP80003oH`3jl>H10?oo
o`00I03jl>H20000od00n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0X0?[`iP03
0000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP80
003oI@3jl>H10?ooo`00IP3jl>H20000ocl0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V
0?[`iP0X0?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H00`3jl>H00`3=QCl0n_3V
0?[`iP0l0?[`iP80003oI`3jl>H10?ooo`00J03jl>H00`000?l0n_3V0?[`iP0l0?[`iP030<f5?`3j
l>H0n_3V04l0n_3V00<000000?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP0N0?[`iP030000003j
l>H0n_3V00<0n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H00`000?l0n_3V0?[`iP1W0?[`iP40oooo001Y
0?[`iP80003o?03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V02T0n_3V00<00000
0?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V03T0n_3V0P000?mZ
0?[`iP40oooo001[0?[`iP80003o>P3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V
02T0n_3V00<000000?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V
03P0n_3V00<0003o0?[`iP3jl>H0JP3jl>H10?ooo`00K@3jl>H00`000?l0n_3V0?[`iP0g0?[`iP03
0<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`iP0L0?[`iP03
0000003jl>H0n_3V00<0n_3V00<0cHDo0?[`iP3jl>H0=P3jl>H20000ofd0n_3V0@3oool006h0n_3V
0P000?lg0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0:P3jl>H00`000000n_3V
0?[`iP0L0?[`iP030000003jl>H0n_3V0080n_3V00<0cHDo0?[`iP3jl>H0=@3jl>H20000ofl0n_3V
0@3oool00700n_3V0P000?lf0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0:`3j
l>H00`000000n_3V0?[`iP0K0?[`iP030000003jl>H0n_3V0080n_3V00<0cHDo0?[`iP3jl>H0=03j
l>H00`000?l0n_3V0?[`iP1_0?[`iP40oooo001b0?[`iP030000o`3jl>H0n_3V03<0n_3V00<0cHDo
0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V01/0n_3V00<00000
0?[`iP3jl>H00P3jl>H00`3=QCl0n_3V0?[`iP0b0?[`iP80003oLP3jl>H10?ooo`00L`3jl>H20000
oc<0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V
01X0n_3V00<000000?[`iP3jl>H00P3jl>H00`3=QCl0n_3V0?[`iP0a0?[`iP030000o`3jl>H0n_3V
0780n_3V0@3oool007D0n_3V0P000?la0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3j
l>H0;03jl>H00`000000n_3V0?[`iP0J0?[`iP050000003jl>H0n_3V0?[`iP3=QCl0<P3jl>H20000
ogD0n_3V0@3oool007L0n_3V00<0003o0?[`iP3jl>H0;`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP03
0000003jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H06@3jl>H01@000000n_3V0?[`iP3jl>H0cHDo
0300n_3V0P000?mg0?[`iP40oooo001h0?[`iP80003o;`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP03
0000003jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H06@3jl>H01@000000n_3V0?[`iP3jl>H0cHDo
02l0n_3V00<0003o0?[`iP3jl>H0M`3jl>H10?ooo`00NP3jl>H20000obd0n_3V00<0cHDo0?[`iP3j
l>H0C@3jl>H00`000000n_3V0?[`iP0^0?[`iP030000003jl>H0n_3V01P0n_3V00D000000?[`iP3j
l>H0n_3V0<f5?`0]0?[`iP80003oNP3jl>H10?ooo`00O03jl>H00`000?l0n_3V0?[`iP0Z0?[`iP03
0<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0;P3jl>H00`000000n_3V0?[`iP0H0?[`iP04
0000003jl>H0n_3V0<f5?bd0n_3V00<0003o0?[`iP3jl>H0NP3jl>H10?ooo`00O@3jl>H20000ob/0
n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP0^0?[`iP030000003jl>H0n_3V01P0
n_3V00@000000?[`iP3jl>H0cHDo:`3jl>H20000ogd0n_3V0@3oool007l0n_3V0P000?lY0?[`iP03
0<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0G0?[`iP04
0000003jl>H0n_3V0<f5?bT0n_3V0P000?mo0?[`iP40oooo00210?[`iP030000o`3jl>H0n_3V02H0
n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V01L0
n_3V00@000000?[`iP3jl>H0cHDo:03jl>H00`000?l0n_3V0?[`iP1o0?[`iP40oooo00220?[`iP80
003o9P3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V0300n_3V00<000000?[`iP3j
l>H05P3jl>H00`000000n_3V0<f5?`0W0?[`iP80003oPP3jl>H10?ooo`00Q03jl>H20000obD0n_3V
00<0cHDo0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V01H0n_3V
00<000000?[`iP3=QCl09P3jl>H00`000?l0n_3V0?[`iP220?[`iP40oooo00260?[`iP030000o`3j
l>H0n_3V0280n_3V00<0cHDo0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP0a0?[`iP030000003j
l>H0n_3V01D0n_3V00<000000<f5?`3jl>H0903jl>H20000ohD0n_3V0@3oool008L0n_3V0P000?lS
0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0E
0?[`iP030000003=QCl0n_3V0280n_3V0P000?n70?[`iP40oooo00290?[`iP80003o8@3jl>H00`3=
QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V0380n_3V00<000000?[`iP3jl>H0503jl>H00`00
0000cHDo0?[`iP0Q0?[`iP030000o`3jl>H0n_3V08L0n_3V0@3oool008/0n_3V0P000?lO0?[`iP03
0<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP0D0?[`iP03
0000003=QCl0n_3V01l0n_3V0P000?n:0?[`iP40oooo002=0?[`iP030000o`3jl>H0n_3V01`0n_3V
00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP0c0?[`iP030000003jl>H0n_3V01<0n_3V
00<000000?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP2:0?[`iP40oooo002>0?[`iP80003o7@3j
l>H00`3=QCl0n_3V0?[`iP190?[`iP030000003jl>H0n_3V03<0n_3V00<000000?[`iP3jl>H04`3j
l>H00`000000n_3V0?[`iP0L0?[`iP80003oS@3jl>H10?ooo`00T03jl>H20000oa`0n_3V00<0cHDo
0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP0c0?[`iP030000003jl>H0n_3V0180n_3V00<0cHDo
0000003jl>H06`3jl>H20000ohl0n_3V0@3oool00980n_3V00<0003o0?[`iP3jl>H06@3jl>H00`3=
QCl0n_3V0?[`iP180?[`iP030000003jl>H0n_3V03@0n_3V00<000000?[`iP3jl>H0403jl>H00`3=
QCl0n_3V0000000K0?[`iP030000o`3jl>H0n_3V08l0n_3V0@3oool009<0n_3V0P000?lJ0?[`iP03
0<f5?`3jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP0@0?[`iP03
0<f5?`3jl>H0000001T0n_3V0P000?nB0?[`iP40oooo002E0?[`iP030000o`3jl>H0n_3V01L0n_3V
00<0cHDo0?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V00h0n_3V
00@0cHDo0?[`iP3jl>H00000603jl>H00`000?l0n_3V0?[`iP2B0?[`iP40oooo002F0?[`iP80003o
603jl>H00`3=QCl0n_3V0?[`iP160?[`iP030000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0
3P3jl>H0103=QCl0n_3V0?[`iP00000F0?[`iP80003oU@3jl>H10?ooo`00V03jl>H00`000?l0n_3V
0?[`iP0E0?[`iP030<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H0=P3jl>H00`000000n_3V
0?[`iP0<0?[`iP050<f5?`3jl>H0n_3V0?[`iP0000005@3jl>H00`000?l0n_3V0?[`iP2E0?[`iP40
oooo002I0?[`iP80003o5P3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V03H0n_3V
00<000000?[`iP3jl>H0303jl>H01@3=QCl0n_3V0?[`iP3jl>H0000001<0n_3V0P000?nH0?[`iP40
oooo002K0?[`iP030000o`3jl>H0n_3V01<0n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V
0?[`iP0g0?[`iP030000003jl>H0n_3V00X0n_3V00<0cHDo0?[`iP3jl>H00P3jl>H00`000000n_3V
0?[`iP0@0?[`iP030000o`3jl>H0n_3V09P0n_3V0@3oool009`0n_3V0P000?lD0?[`iP030<f5?`3j
l>H0n_3V04@0n_3V00<000000?[`iP3jl>H0=`3jl>H00`000000n_3V0?[`iP0:0?[`iP030<f5?`3j
l>H0n_3V0080n_3V00<000000?[`iP3jl>H03P3jl>H20000oi/0n_3V0@3oool009h0n_3V00<0003o
0?[`iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`iP130?[`iP030000003jl>H0n_3V03P0n_3V00<00000
0?[`iP3jl>H0203jl>H00`3=QCl0n_3V0?[`iP030?[`iP030000003jl>H0n_3V00d0n_3V00<0003o
0?[`iP3jl>H0V`3jl>H10?ooo`00W`3jl>H20000oa80n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H00`00
0000n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V00L0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`00
0000n_3V0?[`iP0;0?[`iP80003oWP3jl>H10?ooo`00X@3jl>H00`000?l0n_3V0?[`iP0@0?[`iP03
0<f5?`3jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP060?[`iP03
0<f5?`3jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H02P3jl>H00`000?l0n_3V0?[`iP2N0?[`iP40
oooo002R0?[`iP80003o4@3jl>H00`3=QCl0n_3V0?[`iP110?[`iP030000003jl>H0n_3V03T0n_3V
00<000000?[`iP3jl>H01@3jl>H00`3=QCl0n_3V0?[`iP050?[`iP030000003jl>H0n_3V00P0n_3V
0P000?nQ0?[`iP40oooo002T0?[`iP030000o`3jl>H0n_3V00l0n_3V00<0cHDo0?[`iP3jl>H0@03j
l>H00`000000n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V00@0n_3V00<0cHDo0?[`iP3jl>H01P3j
l>H00`000000n_3V0?[`iP070?[`iP030000o`3jl>H0n_3V0:40n_3V0@3oool00:D0n_3V0P000?l?
0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP02
0?[`iP030<f5?`3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01@3jl>H20000oj@0n_3V0@3oool0
0:L0n_3V00<0003o0?[`iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V
03X0n_3V00<000000?[`iP3jl>H00P3jl>H00`3=QCl0n_3V0?[`iP070?[`iP030000003jl>H0n_3V
00@0n_3V00<0003o0?[`iP3jl>H0Y03jl>H10?ooo`00Z03jl>H20000o`h0n_3V00<0cHDo0?[`iP3j
l>H0?P3jl>H00`000000n_3V0?[`iP0k0?[`iP040000003jl>H0n_3V0<f5?`X0n_3V00<000000?[`
iP3jl>H00P3jl>H20000ojL0n_3V0@3oool00:X0n_3V0P000?l<0?[`iP030<f5?`3jl>H0n_3V03h0
n_3V00<000000?[`iP3jl>H0>`3jl>H3000000X0n_3V0`0000000`3jl>H0003o0000o`2Y0?[`iP40
oooo002/0?[`iP030000o`3jl>H0n_3V00X0n_3V00<0cHDo0?[`iP3jl>H0?@3jl>H00`000000n_3V
0?[`iP0j0?[`iPD00000203jl>H500000:/0n_3V0@3oool00:d0n_3V0P000?l;0?[`iP80cHDo?@3j
l>H00`000000n_3V0?[`iP0j0?[`iQ800000Z`3jl>H10?ooo`00[`3jl>H20000o`X0n_3V00<0cHDo
0?[`iP3jl>H0>`3jl>H00`000000n_3V0?[`iP0j0?[`iPD00000203jl>H500000:/0n_3V0@3oool0
0;40n_3V00<0003o0?[`iP3jl>H0203jl>H00`3=QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V
03X0n_3V00@0cHDo00000000000000001`3jl>H20000o`040?[`iP000000000000000:`0n_3V0@3o
ool00;80n_3V0P000?l90?[`iP030<f5?`3jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H0>@3jl>H0
0`3=QCl0n_3V0?[`iP020?[`iP030000003jl>H0n_3V0080n_3V0P000?l40?[`iP030000003jl>H0
n_3V0:/0n_3V0@3oool00;@0n_3V0P000?l80?[`iP030<f5?`3jl>H0n_3V03P0n_3V00<000000?[`
iP3jl>H0>03jl>H00`3=QCl0n_3V0?[`iP030?[`iP050000003jl>H0n_3V0?[`iP000?l01P3jl>H0
0`000000n_3V0?[`iP2[0?[`iP40oooo002f0?[`iP030000o`3jl>H0n_3V00H0n_3V00<0cHDo0?[`
iP3jl>H0=`3jl>H00`000000n_3V0?[`iP0g0?[`iP030<f5?`3jl>H0n_3V00@0n_3V00@000000?[`
iP000?l0003o1`3jl>H00`000000n_3V0?[`iP2[0?[`iP40oooo002g0?[`iP80003o1`3jl>H20<f5
?cL0n_3V00<000000?[`iP3jl>H0=@3jl>H20<f5?`L0n_3V00<0003o0000003jl>H0203jl>H00`00
0000n_3V0?[`iP2[0?[`iP40oooo002i0?[`iP80003o1P3jl>H00`3=QCl0n_3V0?[`iP0e0?[`iP03
0000003jl>H0n_3V03@0n_3V00<0cHDo0?[`iP3jl>H01@3jl>H20000o`030?[`iP000000n_3V00P0
n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00^`3jl>H00`000?l0n_3V0?[`iP040?[`iP030<f5
?`3jl>H0n_3V03@0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000
o`3jl>H0n_3V0080n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP2[0?[`iP40oooo
002l0?[`iP80003o1@3jl>H20<f5?c@0n_3V00<000000?[`iP3jl>H0<P3jl>H20<f5?`D0n_3V0P00
0?l50?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00_P3jl>H2
0000o`D0n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0a0?[`iP030<f5?`3jl>H0
n_3V00<0n_3V0P000?l80?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0Z`3jl>H1
0?ooo`00`03jl>H00`000?l0n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V0300n_3V00<000000?[`
iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP020?[`iP80003o2P3jl>H00`000000n_3V0?[`iP050?[`
iP030000003jl>H0n_3V0:/0n_3V0@3oool00<40n_3V0P000?l40?[`iP030<f5?`3jl>H0n_3V02l0
n_3V00<000000?[`iP3jl>H0;`3jl>H0103=QCl0n_3V0?[`iP3jl>H20000o`d0n_3V00<000000?[`
iP3jl>H0103jl>H00`000000n_3V0?[`iP2[0?[`iP40oooo00330?[`iP80003o0`3jl>H20<f5?bl0
n_3V00<000000?[`iP3jl>H0;@3jl>H20<f5?`<0n_3V00<0003o0?[`iP3jl>H03@3jl>H00`000000
n_3V0?[`iP040?[`iP030000003jl>H0n_3V0:/0n_3V0@3oool00<D0n_3V0P000?l30?[`iP030<f5
?`3jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0;03jl>H0103=QCl0n_3V0?[`iP3jl>H20000oa40
n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP2[0?[`iP40oooo00370?[`iP80003o
0P3jl>H20<f5?b`0n_3V00<000000?[`iP3jl>H0:P3jl>H20<f5?`80n_3V0P000?lC0?[`iP030000
003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0Z`3jl>H10?ooo`00b@3jl>H20000o`80n_3V0P3=
QClZ0?[`iP030000003jl>H0n_3V02P0n_3V0P3=QCl20?[`iP80003o5P3jl>H00`000000n_3V0?[`
iP020?[`iP030000003jl>H0n_3V0:/0n_3V0@3oool00</0n_3V0P000?l20?[`iP030<f5?`3jl>H0
n_3V02L0n_3V00<000000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V0?[`iP020000oaP0n_3V00<00000
0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP2[0?[`iP40oooo003=0?[`iP80003o00<0n_3V0<f5
?`3=QCl09`3jl>H00`000000n_3V0?[`iP0U0?[`iP80cHDo00<0n_3V0000o`000?l06P3jl>H00`00
0000n_3V0?[`iP020?[`iP030000003jl>H0n_3V0:/0n_3V0@3oool00<l0n_3V0`000?l20<f5?bD0
n_3V00<000000?[`iP3jl>H08`3jl>H20<f5?`030?[`iP000?l0003o01d0n_3V00D000000?[`iP3j
l>H0n_3V0000002]0?[`iP40oooo003B0?[`iP<0003o00<0cHDo0?[`iP3jl>H08@3jl>H00`000000
n_3V0?[`iP0Q0?[`iP80cHDo00<0n_3V0000o`000?l07`3jl>H01@000000n_3V0?[`iP3jl>H00000
0:d0n_3V0@3oool00=D0n_3V0P000?l00`3=QCl0n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V01l0
n_3V0P3=QCl30000ob80n_3V00@000000?[`iP3jl>H00000[@3jl>H10?ooo`00e`3jl>H30000oal0
n_3V00<000000?[`iP3jl>H07@3jl>H20<f5?`80003o9@3jl>H010000000n_3V0?[`iP00002]0?[`
iP40oooo003J0?[`iP<0003o00<0cHDo0?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0I0?[`iP<0
cHDo0`000?lX0?[`iP030000003jl>H000000:d0n_3V0@3oool00=d0n_3V0`000?lI0?[`iP030000
003jl>H0n_3V01L0n_3V00<0cHDo0000o`000?l00P000?l[0?[`iP030000003jl>H000000:d0n_3V
0@3oool00>00n_3V10000?lE0?[`iP030000003jl>H0n_3V01<0n_3V00<0cHDo0000o`000?l00P00
0?l`0?[`iP800000[@3jl>H10?ooo`00i03jl>H40000oa40n_3V00<000000?[`iP3jl>H03`3jl>H0
0`3=QCl0003o0000o`020000oc@0n_3V0`00002/0?[`iP40oooo003X0?[`iP@0003o3@3jl>H00`00
0000n_3V0?[`iP0;0?[`iPD0003o=`3jl>H500000:/0n_3V0@3oool00>`0cHDo3@000?l00`000000
003o0000o`0;0000oc`0cHDo1@00002Z0<f5?`40n_3V0@3oool00?l0n_3VA03jl>H500000:/0n_3V
0@3oool00?l0n_3VA@3jl>H300000:`0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00]P3jl>H20000000306IRGP3<a;/0n_3V02/0n_3V00H0e<c306IRGP0000000000
08V4OP3Tfm9U0?[`iP060=C<``1VHUh0000000000029Q7h0i=_BW03jl>H10?ooo`00^03jl>H00`1V
HUh000000=cDb`0[0?[`iP0604a9A@33^k<0n_3V0>cRf@000000RHAnI@3jl>H01P1<BDD0`k^c0?[`
iP3/h]T0000008V4OY`0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V
00@0[jRQ04a9A@000000RHAn1`3jl>H01P3Le</0NGE`000000000000RHAn0<c4^`80n_3V00@0[jRQ
04a9A@000000RHAn0P3jl>H200000080n_3V0P0000001@3jl>H0c<Bk0000001iMG00n_3V00800000
0P3jl>H20000000306IRGP3jl>H0n_3V00L0n_3V0P0000030?[`iP040<c4^`1<BDD0IV9N0>CKdP80
000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H20000
0080n_3V0P0000020?[`iP0308V4OP1VHUh0c<Bk008000001`3jl>H01@3Le</0NGE`0000001<BDD0
Y9fF0080n_3V00@0c<Bk04a9A@1VHUh0i=_B0P0000000`3jl>H00000000000040?[`iP030:BMUP00
0000Y9fF00<0n_3V00@0[jRQ04a9A@000000RHAn1`3jl>H0102_Z:40C4U504a9A@2_Z:420?[`iP80
00001P3jl>H2000000050?[`iP33^k<000000<>k/`3jl>H00P0000001@3jl>H0c<Bk04a9A@1<BDD0
[jRQ0080000000<0n_3V0000000000000`3jl>H2000000050?[`iP3<a;/0C4U504a9A@2_Z:400P00
00040?[`iP80000000<0k>;I0?[`iP3/h]T00P0000020?[`iP0308V4OP1VHUh0c<Bk0080000000<0
n_3V0000000000000P3jl>H200000080n_3V00@0[jRQ04a9A@000000RHAn0P3jl>H01`3/h]T0Ui6;
000000000000NGE`0>CKdP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080
n_3V0P0000001`3jl>H0[jRQ00000033^k<0i=_B00000029Q7h01@3jl>H01@3Tfm80000009NAR`3j
l>H0^K:Z0080000000P0n_3V0:nXX@000000`k^c0>CKdP000000RHAn0?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H0c<Bk00000002000000030>CKdP3jl>H0n_3V
00H0n_3V0P0000030?[`iP0406IRGP000000i=_B0;VbZP80000000<0n_3V0000000000000`3jl>H2
00000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P0000001@3jl>H0Y9fF0000
0033^k<0Y9fF008000001P3jl>H0303Tfm80000009NAR`3jl>H0e<c300000029Q7h0n_3V06IRGP00
0000i=_B0;VbZP80000000<0n_3V000000000000103jl>H3000000080>cRf@3jl>H0[jRQ00000033
^k<0i=_B00000029Q7h50?[`iP070;VbZP000000`k^c0<>k/`000000^K:Z0?[`iP02000000H0n_3V
0P0000001@3jl>H0Ui6;0000002GTH/0n_3V0080000000D0n_3V04a9A@000000i=_B0<>k/`020000
00030?[`iP000000000000<0n_3V0P0000001@3jl>H0C4U50000003Tfm80`k^c00800000103jl>H0
3029Q7h000000=C<``3jl>H0e<c300000029Q7h0n_3V0:BMUP000000`k^c0:BMUP80000000<0n_3V
0000000000000P3jl>H20000000?0?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP3jl>H0NGE`0000
003Tfm80k>;I0000001VHUh0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P000002
0?[`iP80000000<0n_3V04a9A@0000002@3jl>H00`2GTH/000000=cDb`020?[`iP80000000<0n_3V
04a9A@0000001@3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000H0n_3V
09NAR`000000RHAn0000002_Z:480?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H00000
000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H200000003
0?[`iP1<BDD000000080n_3V0P0000060?[`iP0309NAR`000000i=_B00D0n_3V0P0000020?[`iP80
000000<0n_3V0000000000000`3jl>H0202i/ZX0000008V4OP000000^K:Z0?[`iP1<BDD000002@3j
l>H01`1VHUh000000?[`iP3jl>H0000006IRGP3jl>H00P0000060?[`iP80000000D0n_3V04a9A@00
0000C4U50?[`iP02000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000030?[`
iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V00<0[jRQ0000000000000`000000102_
Z:40n_3V04a9A@0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP1<BDD0
000000L0n_3V00D0e<c30:BMUP000000C4U50?[`iP02000008@0n_3V0@3oool008<0n_3V0P000003
0?[`iP8000000P3jl>H2000000030?[`iP000000000000@000001@3jl>H00`1<BDD000000?[`iP02
0?[`iP80000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000060?[`iP1<BDD000000>cRf@000000IV9N203jl>H2000000<0n_3V
0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H00000
0000003jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP8000001P3jl>H2000000H0
n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H204a9A@040>cRf@1<BDD0C4U50?[`
iPH000001@3jl>H200000080n_3V0P0000000`3jl>H00000000000060?[`iP80000000D0i=_B0000
002GTH/000000>CKdP02000000050?[`iP3<a;/0000009NAR`3Tfm800P0000000`3jl>H000000000
00030?[`iP80000000D0n_3V0<c4^`000000Ui6;0>CKdP02000000@0n_3V00P0e<c300000029Q7h0
n_3V09NAR`000000e<c30?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H0000000000004000000030?[`iP3<a;/0C4U50080000000<0C4U50<c4^`3jl>H00P000024
0?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`
iP030000001VHUh0n_3V00@0n_3V0P0000020?[`iP<0000000<0n_3V04a9A@0000000P3jl>H00`00
0000IV9N0?[`iP0200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000L0g=C;0000
0029Q7h0n_3V08V4OP000000i=_B00L0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP00
0000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP800000
00<0n_3V04a9A@0000000P3jl>H2000000H0n_3V0P0000060?[`iP8000000P3jl>H2000000030?[`
iP00000000000080n_3V00T0c<Bk0000002TWIH0n_3V0:BMUP000000c<Bk04a9A@0000000P3jl>H0
0`000000IV9N0?[`iP040?[`iP0706IRGP000000n_3V0?[`iP000000IV9N0?[`iP02000000H0n_3V
0P0000001@3<a;/000000=cDb`000000c<Bk008000000P3jl>H00`3Le</0[jRQ07UeL00200000003
0?[`iP000000000000<0n_3V0P0000020?[`iP030=cDb`2_Z:40NGE`008000001@3jl>H01@000000
C4U50?[`iP1<BDD000000080n_3V00@0C4U50000003jl>H0n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V04a9A@0000000P3jl>H01`000000IV9N0?[`iP1<BDD0000007UeL03<a;/0
0`3jl>H2000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP80000000/0Y9fF0>CKdP000000IV9N
0?[`iP2i/ZX000000<>k/`3<a;/000000;VbZP050?[`iP0304a9A@000000n_3V00D0n_3V00L0^K:Z
00000033^k<0c<Bk0000002i/ZX0n_3V0080000000D0^K:Z0>CKdP000000C4U50?[`iP0200000080
n_3V0P0000001`2_Z:4000000<>k/`3jl>H0`k^c0000002_Z:401`3jl>H2000000<0n_3V0P000002
0?[`iP80000000@0n_3V000000000000e<c30P3jl>H2000000050;VbZP3Tfm80000004a9A@3jl>H0
0P000000303jl>H000000000002i/ZX0i=_B0000001<BDD0n_3V0:BMUP000000`k^c0:BMUP800000
1P3jl>H00`1<BDD000000?[`iP050?[`iP8000000P3jl>H20000000B0?[`iP00000000000=C<``3j
l>H0IV9N0000003/h]T0n_3V0>cRf@000000IV9N0;VbZP000000`k^c0<c4^`000000^K:Z1@3jl>H0
1`2i/ZX000000<>k/`33^k<000000;VbZP3jl>H00P0000060?[`iP80000000D0Y9fF06IRGP3jl>H0
IV9N0:BMUP02000000080?[`iP1iMG00e<c30?[`iP3Tfm80000004a9A@3jl>H2000000030=C<``3j
l>H0n_3V0080000000L0n_3V07UeL03Dc<<0n_3V0>CKdP000000C4U500D0n_3V00D0NGE`0000003<
a;/0000006IRGP020?[`iP040:BMUP000000`k^c0:BMUP80000001H0n_3V000000000000^K:Z0>CK
dP000000C4U50?[`iP2i/ZX000000<>k/`3<a;/000000;VbZP3jl>H0IV9N0000003jl>H0i=_B0000
001iMG00n_3V0P0000240?[`iP40oooo00230?[`iP8000000`3jl>H2000000040=cDb`29Q7h0C4U5
0<c4^`80n_3V00@0[jRQ000000000000[jRQ1P3jl>H00`2GTH/000000>CKdP060?[`iP040:nXX@00
000000000:nXX@80n_3V0P000000103<a;/0NGE`04a9A@3<a;/40000000:0?[`iP000000000006IR
GP000000k>;I0?[`iP3/h]T0000006IRGPL0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`
iP000000000008V4OP1iMG00n_3V0P0000001@3<a;/0NGE`04a9A@3<a;/0n_3V0080000000L0n_3V
000000000000c<Bk07UeL01<BDD0c<Bk0080n_3V00<0RHAn06IRGP3<a;/00P0000060?[`iP0309NA
R`000000i=_B00D0n_3V0P0000020?[`iP80000000@0n_3V000000000000RHAn0P0000002029Q7h0
n_3V0?[`iP3jl>H0RHAn0000003Le</0[jRQ0P0000000`2_Z:40n_3V0?[`iP050?[`iP050:nXX@1<
BDD000000:nXX@3jl>H0100000050?[`iP80000000D0IV9N0:BMUP3jl>H0Ui6;06IRGP0200000003
0?[`iP3Tfm80RHAn0080000000<0IV9N0=C<``3jl>H00P0000000`29Q7h0NGE`0?[`iP0200000003
0?[`iP3Tfm80RHAn0080000000<0IV9N0=C<``3jl>H0103jl>H01@2TWIH0000008V4OP000000Y9fF
00<0n_3V00<0RHAn06IRGP3<a;/00P0000001`3jl>H000000000003<a;/0NGE`04a9A@3<a;/00P3j
l>H0102_Z:4000000000002_Z:420?[`iP070>CKdP1iMG00000000000029Q7h0i=_B0?[`iP020000
08@0n_3V0@3oool008<0n_3V0P0000030?[`iP800000403jl>H01`3Tfm80000009NAR`3jl>H0e<c3
0000001iMG003`3jl>H200000080n_3V0P00000>0?[`iP800000;03jl>H01`3Tfm80000009NAR`3j
l>H0e<c300000029Q7h09@3jl>H2000000H0n_3V0`0000000`3<a;/0n_3V0<>k/`03000001/0n_3V
00D0c<Bk00000000000000000<>k/`2T0?[`iP40oooo00210?[`iPH0000000<0n_3V000000000000
4@3jl>H01P3Le</0NGE`000000000000Ui6;0>cRf@l0n_3V00@0g=C;08V4OP3jl>H0n_3V0P00000<
0?[`iPH00000503jl>H2000001D0n_3V00D0g=C;07UeL000000000000:BMUP0V0?[`iP040<c4^`1V
HUh0000008V4OP@0n_3V0`0000000`3/h]T0n_3V0=cDb`03000000d0n_3V0P00000<0?[`iP050>cR
f@00000000000000003Tfm807P3jl>H2000008@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.69565 .38333 L
s
.69565 .05 m
.69565 .38333 L
s
.64552 .29792 m
.69565 .29792 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.69565 .38333 Mdot
.64552 .29792 Mdot
.69565 .29792 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V2P3=QCl20?[`iP80000000<0n_3V0<f5
?`3=QCl0203=QCmD0?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00>L0n_3V1P3=QCl<0?[`iP80
00002`3jl>H70<f5?dd0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00i@3jl>H20<f5?a80n_3V
00<000000?[`iP0000004@3jl>H20<f5?d/0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00h@3j
l>H40<f5?a@0n_3V00<000000?[`iP0000004`3jl>H30<f5?dP0n_3V00<000000?[`iP3jl>H0UP3j
l>H10?ooo`00g@3jl>H40<f5?aP0n_3V00@000000?[`iP3jl>H000005@3jl>H40<f5?d@0n_3V00<0
00000?[`iP3jl>H0UP3jl>H10?ooo`00f`3jl>H20<f5?a`0n_3V00D000000?[`iP3jl>H0n_3V0000
000H0?[`iP80cHDo@P3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo003I0?[`iP80cHDo7P3jl>H0
1@000000n_3V0?[`iP3jl>H0000001X0n_3V0P3=QCm00?[`iP030000003jl>H0n_3V09H0n_3V0@3o
ool00=L0n_3V0P3=QClP0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H06@3jl>H2
0<f5?ch0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00e@3jl>H20<f5?b80n_3V00<000000?[`
iP3jl>H00P3jl>H00`000000n_3V0?[`iP0K0?[`iP80cHDo?03jl>H00`000000n_3V0?[`iP2F0?[`
iP40oooo003C0?[`iP80cHDo903jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V01`0
n_3V0P3=QClj0?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00=40n_3V0P3=QClV0?[`iP030000
003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H07P3jl>H20<f5?cP0n_3V00<000000?[`iP3jl>H0
UP3jl>H10?ooo`00c`3jl>H20<f5?bP0n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`
iP0O0?[`iP80cHDo=P3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo003>0?[`iP030<f5?`3jl>H0
n_3V02P0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0P0?[`iP030<f5?`3jl>H0
n_3V03<0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00c03jl>H20<f5?b/0n_3V00<000000?[`
iP3jl>H01@3jl>H00`000000n_3V0?[`iP0Q0?[`iP80cHDo<`3jl>H00`000000n_3V0?[`iP2F0?[`
iP40oooo003:0?[`iP80cHDo;@3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V0280
n_3V0P3=QCla0?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00<T0n_3V00<0cHDo0?[`iP3jl>H0
;@3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V02@0n_3V00<0cHDo0?[`iP3jl>H0
;P3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo00370?[`iP80cHDo<03jl>H00`000000n_3V0?[`
iP070?[`iP030000003jl>H0n_3V02@0n_3V0P3=QCl^0?[`iP030000003jl>H0n_3V09H0n_3V0@3o
ool00<H0n_3V00<0cHDo0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0
n_3V02D0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo00350?[`
iP030<f5?`3jl>H0n_3V0340n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0V0?[`
iP030<f5?`3jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00a03jl>H00`3=QCl0
n_3V0?[`iP0b0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H09P3jl>H00`3=QCl0
n_3V0?[`iP0Y0?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00<80n_3V0P3=QCle0?[`iP030000
003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H09`3jl>H20<f5?bT0n_3V00<000000?[`iP3jl>H0
UP3jl>H10?ooo`00`@3jl>H00`3=QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V00X0n_3V00<0
00000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V09H0n_3V0@3o
ool00<00n_3V00<0cHDo0?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0
n_3V02P0n_3V00<0cHDo0?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo002o0?[`
iP030<f5?`3jl>H0n_3V03L0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0X0?[`
iP80cHDo9P3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo002n0?[`iP030<f5?`3jl>H0n_3V03P0
n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0Y0?[`iP030<f5?`3jl>H0n_3V02<0
n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00_@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000
003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V0?[`iP0R0?[`iP030000
003jl>H0n_3V09H0n_3V0@3oool00;`0n_3V00<0cHDo0?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`
iP0=0?[`iP030000003jl>H0n_3V02X0n_3V00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`
iP2F0?[`iP40oooo002k0?[`iP030<f5?`3jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H03@3jl>H0
0`000000n_3V0?[`iP0Z0?[`iP030<f5?`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0UP3jl>H1
0?ooo`00^P3jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`
iP3jl>H0:P3jl>H00`3=QCl0n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00;T0
n_3V00<0cHDo0?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V02X0
n_3V0P3=QClP0?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00;P0n_3V00<0cHDo0?[`iP3jl>H0
?P3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V02/0n_3V00<0cHDo0?[`iP3jl>H0
7P3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo002h0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<0
00000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0[0?[`iP030<f5?`3jl>H0n_3V01d0n_3V00<0
00000?[`iP3jl>H0UP3jl>H10?ooo`00]`3jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP030000003jl>H0
n_3V0100n_3V00<000000?[`iP3jl>H0;03jl>H00`3=QCl0n_3V0?[`iP0L0?[`iP030000003jl>H0
n_3V09H0n_3V0@3oool00;H0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP0A0?[`
iP030000003jl>H0n_3V02/0n_3V00<0cHDo0?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP2F0?[`
iP40oooo002f0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H04@3jl>H00`000000
n_3V0?[`iP0/0?[`iP030<f5?`3jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00
]@3jl>H00`3=QCl0n_3V0?[`iP110?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0
;03jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00;@0n_3V00<0
cHDo0?[`iP3jl>H0@P3jl>H00`000000n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V02`0n_3V00<0
cHDo0?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo002c0?[`iP030<f5?`3jl>H0
n_3V04<0n_3V00<000000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP0]0?[`iP030<f5?`3jl>H0
n_3V01P0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00/P3jl>H00`3=QCl0n_3V0?[`iP140?[`
iP030000003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0;03jl>H00`3=QCl0n_3V0?[`iP0H0?[`
iP030000003jl>H0n_3V09H0n_3V0@3oool00;80n_3V00<0cHDo0?[`iP3jl>H0A03jl>H00`000000
n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V02d0n_3V00<0cHDo0?[`iP3jl>H05`3jl>H00`000000
n_3V0?[`iP2F0?[`iP40oooo002a0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0
5@3jl>H00`000000n_3V0?[`iP0/0?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H0
UP3jl>H10?ooo`00/@3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V01H0n_3V00<0
00000?[`iP3jl>H0;03jl>H00`3=QCl0n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V09H0n_3V0@3o
ool00;00n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP0F0?[`iP030000003jl>H0
n_3V02`0n_3V00<0cHDo0?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo002`0?[`
iP030<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP0/0?[`
iP030<f5?`3jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00[`3jl>H00`3=QCl0
n_3V0?[`iP170?[`iP030000003jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H0;03jl>H00`3=QCl0
n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00:l0n_3V00<0cHDo0?[`iP3jl>H0
A`3jl>H00`000000n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V02`0n_3V00<0cHDo0?[`iP3jl>H0
503jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo002^0?[`iP030<f5?`3jl>H0n_3V04P0n_3V00<0
00000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP0]0?[`iP030<f5?`3jl>H0n_3V01<0n_3V00<0
00000?[`iP3jl>H0UP3jl>H10?ooo`00[@3jl>H00`3=QCl0n_3V0?[`iP190?[`iP030000003jl>H0
n_3V01T0n_3V00<000000?[`iP3jl>H0;03jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP030000003jl>H0
n_3V09H0n_3V0@3oool00:d0n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`iP0J0?[`
iP030000003jl>H0n_3V02`0n_3V00<0cHDo0?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP2F0?[`
iP40oooo002/0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H06P3jl>H00`000000
n_3V0?[`iP0/0?[`iP030<f5?`3jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00
[03jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0
;03jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00080003oZP3j
l>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0;03j
l>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V09<0n_3V0P000?l10?[`iP40oooo0002
0?[`iP<0003oY`3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V01`0n_3V00<00000
0?[`iP3jl>H0:`3jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0900n_3V0`000?l3
0?[`iP40oooo00050?[`iP@0003oXP3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V
01d0n_3V00<000000?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V
08`0n_3V10000?l60?[`iP40oooo00090?[`iP<0003oW`3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP03
0000003jl>H0n_3V01d0n_3V00<000000?[`iP3jl>H0:`3jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP03
0000003jl>H0n_3V08T0n_3V0`000?l:0?[`iP40oooo000<0?[`iP<0003oV`3jl>H00`3=QCl0n_3V
0?[`iP1<0?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V
0?[`iP0@0?[`iP030000003jl>H0n_3V08H0n_3V0`000?l=0?[`iP40oooo000?0?[`iP@0003oU`3j
l>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0:`3j
l>H00`3=QCl0n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V0880n_3V10000?l@0?[`iP40oooo000C
0?[`iP<0003oU03jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V01l0n_3V00<00000
0?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V07l0n_3V0`000?lD
0?[`iP40oooo000F0?[`iP<0003oT@3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V
01l0n_3V00<000000?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V
07`0n_3V0`000?lG0?[`iP40oooo000I0?[`iP<0003oS@3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP03
0000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0:@3jl>H00`3=QCl0n_3V0?[`iP0?0?[`iP03
0000003jl>H0n_3V07T0n_3V0`000?lJ0?[`iP40oooo000L0?[`iP<0003oRP3jl>H00`3=QCl0n_3V
0?[`iP1=0?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0:@3jl>H00`3=QCl0n_3V
0?[`iP0>0?[`iP030000003jl>H0n_3V07H0n_3V0`000?lM0?[`iP40oooo000O0?[`iP@0003oQP3j
l>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0:@3j
l>H00`3=QCl0n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V07<0n_3V0`000?lP0?[`iP40oooo000S
0?[`iP<0003oP`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V0280n_3V00<00000
0?[`iP3jl>H0:03jl>H00`3=QCl0n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V0700n_3V0`000?lS
0?[`iP40oooo000V0?[`iP<0003oO`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V
0280n_3V00<000000?[`iP3jl>H0:03jl>H00`3=QCl0n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V
06d0n_3V0`000?lV0?[`iP40oooo000Y0?[`iP<0003oO03jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP03
0000003jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H0:03jl>H00`3=QCl0n_3V0?[`iP0=0?[`iP03
0000003jl>H0n_3V06X0n_3V0`000?lY0?[`iP40oooo000/0?[`iP80003oNP3jl>H00`3=QCl0n_3V
0?[`iP1>0?[`iP030000003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V
0?[`iP0=0?[`iP030000003jl>H0n_3V06P0n_3V0P000?l/0?[`iP40oooo000^0?[`iP80003oN03j
l>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H09`3j
l>H00`3=QCl0n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V06H0n_3V0P000?l^0?[`iP40oooo000`
0?[`iP<0003oM03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V02D0n_3V00<00000
0?[`iP3jl>H09P3jl>H00`3=QCl0n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V06<0n_3V0`000?l`
0?[`iP40oooo000c0?[`iP80003oLP3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V
02D0n_3V00<000000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V
0640n_3V0P000?lc0?[`iP40oooo000e0?[`iP80003oL03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP03
0000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H09P3jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP03
0000003jl>H0n_3V05l0n_3V0P000?le0?[`iP40oooo000g0?[`iP<0003oK@3jl>H00`3=QCl0n_3V
0?[`iP1?0?[`iP030000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H09P3jl>H00`3=QCl0n_3V
0?[`iP0<0?[`iP030000003jl>H0n_3V05`0n_3V0`000?lg0?[`iP40oooo000j0?[`iP80003oJ`3j
l>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H09@3j
l>H00`3=QCl0n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V05X0n_3V0P000?lj0?[`iP40oooo000l
0?[`iP80003oJ@3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V02P0n_3V00<00000
0?[`iP3jl>H0903jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V05P0n_3V0P000?ll
0?[`iP40oooo000n0?[`iP<0003oI@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V
02P0n_3V00<000000?[`iP3jl>H0903jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V
05D0n_3V0`000?ln0?[`iP40oooo00110?[`iP80003oH`3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP03
0000003jl>H0n_3V02T0n_3V00<000000?[`iP3jl>H0903jl>H00`3=QCl0n_3V0?[`iP0;0?[`iP03
0000003jl>H0n_3V05<0n_3V0P000?m10?[`iP40oooo00130?[`iP80003oH@3jl>H00`3=QCl0n_3V
0?[`iP1@0?[`iP030000003jl>H0n_3V02T0n_3V00<000000?[`iP3jl>H0903jl>H00`3=QCl0n_3V
0?[`iP0;0?[`iP030000003jl>H0n_3V0540n_3V0P000?m30?[`iP40oooo00150?[`iP80003oG`3j
l>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H08`3j
l>H00`3=QCl0n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V04l0n_3V0P000?m50?[`iP40oooo0017
0?[`iP80003oG@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V02/0n_3V00<00000
0?[`iP3jl>H08P3jl>H00`3=QCl0n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V04d0n_3V0P000?m7
0?[`iP40oooo00190?[`iP<0003oFP3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V
02/0n_3V00<000000?[`iP3jl>H08P3jl>H00`3=QCl0n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V
04/0n_3V0P000?m90?[`iP40oooo001<0?[`iP80003oF03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP03
0000003jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H08@3jl>H00`3=QCl0n_3V0?[`iP0;0?[`iP03
0000003jl>H0n_3V04T0n_3V0P000?m;0?[`iP40oooo001>0?[`iP80003oEP3jl>H00`3=QCl0n_3V
0?[`iP1?0?[`iP<00000;@3jl>H00`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V00/0n_3V
00<000000?[`iP3jl>H0A`3jl>H20000odd0n_3V0@3oool00500n_3V0P000?mD0?[`iP030<f5?`3j
l>H0n_3V04h0n_3V1@00000]0?[`iP030000003jl>H0n_3V0200n_3V00<0cHDo0?[`iP3jl>H02`3j
l>H00`000000n_3V0?[`iP150?[`iP80003oC`3jl>H10?ooo`00DP3jl>H20000oe80n_3V00<0cHDo
0?[`iP3jl>H0CP3jl>H5000002d0n_3V00<000000?[`iP3jl>H0803jl>H00`3=QCl0n_3V0?[`iP0;
0?[`iP030000003jl>H0n_3V04<0n_3V0P000?mA0?[`iP40oooo001D0?[`iP80003oD03jl>H00`3=
QCl0n_3V0?[`iP1>0?[`iPD00000;P3jl>H00`000000n_3V0?[`iP0O0?[`iP030<f5?`3jl>H0n_3V
00/0n_3V00<000000?[`iP3jl>H0@@3jl>H20000oe<0n_3V0@3oool005H0n_3V0P000?m>0?[`iP03
0<f5?`3jl>H0n_3V04l0n_3V0`00000`0?[`iP030000003jl>H0n_3V01h0n_3V00<0cHDo0?[`iP3j
l>H02`3jl>H00`000000n_3V0?[`iP0o0?[`iP80003oE@3jl>H10?ooo`00F03jl>H20000od`0n_3V
00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V01h0n_3V
00<0cHDo0?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0m0?[`iP80003oE`3jl>H10?ooo`00FP3j
l>H00`000?l0n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0<03j
l>H00`000000n_3V0?[`iP0M0?[`iP030<f5?`3jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0>`3j
l>H20000oeT0n_3V0@3oool005/0n_3V0P000?m90?[`iP030<f5?`3jl>H0n_3V0500n_3V00<00000
0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0M0?[`iP030<f5?`3jl>H0n_3V00/0n_3V00<00000
0?[`iP3jl>H0>@3jl>H20000oe/0n_3V0@3oool005d0n_3V0P000?m70?[`iP030<f5?`3jl>H0n_3V
0500n_3V00<000000?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0L0?[`iP030<f5?`3jl>H0n_3V
00/0n_3V00<000000?[`iP3jl>H0=`3jl>H20000oed0n_3V0@3oool005l0n_3V0P000?m50?[`iP03
0<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP0K0?[`iP03
0<f5?`3jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0=@3jl>H20000oel0n_3V0@3oool00640n_3V
00<0003o0?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0380n_3V
00<000000?[`iP3jl>H06`3jl>H00`3=QCl0n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V03<0n_3V
0P000?mQ0?[`iP40oooo001R0?[`iP80003o@P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003j
l>H0n_3V03<0n_3V00<000000?[`iP3jl>H06P3jl>H00`3=QCl0n_3V0?[`iP0;0?[`iP030000003j
l>H0n_3V0340n_3V0P000?mS0?[`iP40oooo001T0?[`iP80003o@03jl>H00`3=QCl0n_3V0?[`iP1@
0?[`iP030000003jl>H0n_3V03<0n_3V00<000000?[`iP3jl>H06@3jl>H00`3=QCl0n_3V0?[`iP0<
0?[`iP030000003jl>H0n_3V02l0n_3V0P000?mU0?[`iP40oooo001V0?[`iP80003o?`3jl>H00`3=
QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V03@0n_3V00<000000?[`iP3jl>H0603jl>H00`3=
QCl0n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V02d0n_3V0P000?mW0?[`iP40oooo001X0?[`iP03
0000o`3jl>H0n_3V03`0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP0e0?[`iP03
0000003jl>H0n_3V01L0n_3V00<0cHDo0?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0/0?[`iP03
0000o`3jl>H0n_3V06L0n_3V0@3oool006T0n_3V0P000?ll0?[`iP030<f5?`3jl>H0n_3V04l0n_3V
00<000000?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP0G0?[`iP030<f5?`3jl>H0n_3V00`0n_3V
00<000000?[`iP3jl>H0:P3jl>H20000ofX0n_3V0@3oool006/0n_3V0P000?lj0?[`iP030<f5?`3j
l>H0n_3V04l0n_3V00<000000?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP0F0?[`iP030<f5?`3j
l>H0n_3V00`0n_3V00<000000?[`iP3jl>H0:@3jl>H00`000?l0n_3V0?[`iP1Z0?[`iP40oooo001]
0?[`iP030000o`3jl>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP0f
0?[`iP030000003jl>H0n_3V01H0n_3V00<0cHDo0?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0W
0?[`iP80003oK@3jl>H10?ooo`00KP3jl>H20000ocL0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`00
0000n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V01@0n_3V00<0cHDo0?[`iP3jl>H03@3jl>H00`00
0000n_3V0?[`iP0U0?[`iP80003oK`3jl>H10?ooo`00L03jl>H20000ocH0n_3V00<0cHDo0?[`iP3j
l>H0CP3jl>H00`000000n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V01@0n_3V00<0cHDo0?[`iP3j
l>H03@3jl>H00`000000n_3V0?[`iP0T0?[`iP030000o`3jl>H0n_3V06l0n_3V0@3oool00780n_3V
00<0003o0?[`iP3jl>H0<`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V03P0n_3V
00<000000?[`iP3jl>H04`3jl>H00`3=QCl0n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V0280n_3V
0P000?mb0?[`iP40oooo001c0?[`iP80003o<`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003j
l>H0n_3V03T0n_3V00<000000?[`iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`iP0=0?[`iP030000003j
l>H0n_3V0240n_3V00<0003o0?[`iP3jl>H0LP3jl>H10?ooo`00M@3jl>H20000oc40n_3V00<0cHDo
0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V0140n_3V00<0cHDo
0?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0O0?[`iP80003oM@3jl>H10?ooo`00M`3jl>H00`00
0?l0n_3V0?[`iP0_0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0>P3jl>H00`00
0000n_3V0?[`iP0@0?[`iP030<f5?`3jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H07@3jl>H20000
ogL0n_3V0@3oool007P0n_3V0P000?l_0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3j
l>H0>P3jl>H00`000000n_3V0?[`iP0@0?[`iP030<f5?`3jl>H0n_3V00h0n_3V00<000000?[`iP3j
l>H0703jl>H00`000?l0n_3V0?[`iP1g0?[`iP40oooo001j0?[`iP80003o;@3jl>H00`3=QCl0n_3V
0?[`iP1=0?[`iP030000003jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H03`3jl>H00`3=QCl0n_3V
0?[`iP0>0?[`iP030000003jl>H0n_3V01X0n_3V0P000?mj0?[`iP40oooo001l0?[`iP030000o`3j
l>H0n_3V02X0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP0l0?[`iP030000003j
l>H0n_3V00d0n_3V00<0cHDo0?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP0I0?[`iP030000o`3j
l>H0n_3V07X0n_3V0@3oool007d0n_3V0P000?l[0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<00000
0?[`iP3jl>H0?03jl>H00`000000n_3V0?[`iP0=0?[`iP030<f5?`3jl>H0n_3V00l0n_3V00<00000
0?[`iP3jl>H05`3jl>H20000ogd0n_3V0@3oool007l0n_3V0P000?lY0?[`iP030<f5?`3jl>H0n_3V
04`0n_3V00<000000?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP0<0?[`iP030<f5?`3jl>H0n_3V
00l0n_3V00<000000?[`iP3jl>H05@3jl>H20000ogl0n_3V0@3oool00840n_3V00<0003o0?[`iP3j
l>H09P3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V03d0n_3V00<000000?[`iP3j
l>H0303jl>H00`3=QCl0n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V01@0n_3V00<0003o0?[`iP3j
l>H0O`3jl>H10?ooo`00PP3jl>H20000obH0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V
0?[`iP0n0?[`iP030000003jl>H0n_3V00X0n_3V00<0cHDo0?[`iP3jl>H0403jl>H00`000000n_3V
0?[`iP0B0?[`iP80003oPP3jl>H10?ooo`00Q03jl>H20000obD0n_3V00<0cHDo0?[`iP3jl>H0B`3j
l>H00`000000n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V00X0n_3V00<0cHDo0?[`iP3jl>H0403j
l>H00`000000n_3V0?[`iP0A0?[`iP030000o`3jl>H0n_3V0880n_3V0@3oool008H0n_3V00<0003o
0?[`iP3jl>H08P3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V03l0n_3V00<00000
0?[`iP3jl>H0203jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00l0n_3V0P000?n5
0?[`iP40oooo00270?[`iP80003o8`3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V
0400n_3V00<000000?[`iP3jl>H01`3jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V
00d0n_3V0P000?n70?[`iP40oooo00290?[`iP80003o8@3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP03
0000003jl>H0n_3V0400n_3V00<000000?[`iP3jl>H01`3jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP03
0000003jl>H0n_3V00`0n_3V00<0003o0?[`iP3jl>H0Q`3jl>H10?ooo`00R`3jl>H20000oal0n_3V
00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP110?[`iP030000003jl>H0n_3V00H0n_3V
00<0cHDo0?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0:0?[`iP80003oRP3jl>H10?ooo`00S@3j
l>H00`000?l0n_3V0?[`iP0L0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0@@3j
l>H00`000000n_3V0?[`iP050?[`iP030<f5?`3jl>H0n_3V0180n_3V00<000000?[`iP3jl>H02@3j
l>H00`000?l0n_3V0?[`iP2:0?[`iP40oooo002>0?[`iP80003o7@3jl>H00`3=QCl0n_3V0?[`iP19
0?[`iP030000003jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP0B
0?[`iP030000003jl>H0n_3V00L0n_3V0P000?n=0?[`iP40oooo002@0?[`iP80003o703jl>H00`3=
QCl0n_3V0?[`iP180?[`iP030000003jl>H0n_3V04<0n_3V00<000000?[`iP3jl>H00P3jl>H00`3=
QCl0n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V00D0n_3V0P000?n?0?[`iP40oooo002B0?[`iP03
0000o`3jl>H0n_3V01T0n_3V00<0cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP130?[`iP05
0000003jl>H0n_3V0?[`iP3=QCl05P3jl>H00`000000n_3V0?[`iP040?[`iP030000o`3jl>H0n_3V
08l0n_3V0@3oool009<0n_3V0P000?lJ0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<000000?[`iP3j
l>H0A03jl>H010000000n_3V0?[`iP3=QClF0?[`iP030000003jl>H0n_3V0080n_3V0P000?nB0?[`
iP40oooo002E0?[`iP030000o`3jl>H0n_3V01L0n_3V00<0cHDo0?[`iP3jl>H0A`3jl>H00`000000
n_3V0?[`iP140?[`iP<000005P3jl>H300000080n_3V00<0003o0?[`iP3jl>H0TP3jl>H10?ooo`00
UP3jl>H20000oaP0n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP130?[`iPD00000
503jl>H5000000030000o`3jl>H0n_3V09<0n_3V0@3oool009P0n_3V00<0003o0?[`iP3jl>H05@3j
l>H00`3=QCl0n_3V0?[`iP160?[`iP030000003jl>H0n_3V04<0n_3V7P00002F0?[`iP40oooo002I
0?[`iP80003o5P3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V04<0n_3V1@00000D
0?[`iPD00000UP3jl>H10?ooo`00V`3jl>H00`000?l0n_3V0?[`iP0C0?[`iP030<f5?`3jl>H0n_3V
04D0n_3V00<000000?[`iP3jl>H0A03jl>H4000001@0n_3V00@0003o0000000000000000U`3jl>H1
0?ooo`00W03jl>H20000oa@0n_3V00<0cHDo0?[`iP3jl>H0A03jl>H00`000000n_3V0?[`iP140?[`
iP040<f5?`3jl>H0n_3V00000180n_3V0P000?l20?[`iP030000003jl>H0n_3V09H0n_3V0@3oool0
09h0n_3V00<0003o0?[`iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`iP130?[`iP030000003jl>H0n_3V
04<0n_3V00<0cHDo0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0>0?[`iP030000o`3jl>H0n_3V
0080n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00W`3jl>H20000oa80n_3V00<0cHDo0?[`iP3j
l>H0@`3jl>H00`000000n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V00<0n_3V00<000000?[`iP3j
l>H0303jl>H20000o`D0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00X@3jl>H00`000?l0n_3V
0?[`iP0@0?[`iP030<f5?`3jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V
0?[`iP040?[`iP030000003jl>H0n_3V00X0n_3V00<0003o0?[`iP3jl>H01@3jl>H00`000000n_3V
0?[`iP2F0?[`iP40oooo002R0?[`iP80003o4@3jl>H00`3=QCl0n_3V0?[`iP110?[`iP030000003j
l>H0n_3V0440n_3V00<0cHDo0?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP070?[`iP80003o203j
l>H00`000000n_3V0?[`iP2F0?[`iP40oooo002T0?[`iP030000o`3jl>H0n_3V00l0n_3V00<0cHDo
0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP100?[`iP030<f5?`3jl>H0n_3V00L0n_3V00<00000
0?[`iP3jl>H01P3jl>H00`000?l0n_3V0?[`iP080?[`iP030000003jl>H0n_3V09H0n_3V0@3oool0
0:D0n_3V0P000?l?0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=
QCl0n_3V0?[`iP090?[`iP030000003jl>H0n_3V00<0n_3V0P000?l;0?[`iP030000003jl>H0n_3V
09H0n_3V0@3oool00:L0n_3V00<0003o0?[`iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP03
0000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP020?[`iP03
0000o`3jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00Z03jl>H20000o`h0n_3V
00<0cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0n0?[`iP030<f5?`3jl>H0n_3V00/0n_3V
00@000000?[`iP000?l0003o3P3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo002Z0?[`iP80003o
303jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03d0n_3V00<0cHDo0?[`iP3jl>H0
303jl>H00`000000003o0?[`iP0?0?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00:`0n_3V00<0
003o0?[`iP3jl>H02P3jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V03d0n_3V00<0
cHDo0?[`iP3jl>H02P3jl>H20000o`030?[`iP000000n_3V00l0n_3V00<000000?[`iP3jl>H0UP3j
l>H10?ooo`00[@3jl>H20000o`/0n_3V0P3=QClm0?[`iP030000003jl>H0n_3V03/0n_3V0P3=QCl<
0?[`iP030000o`3jl>H0n_3V0080n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP2F
0?[`iP40oooo002_0?[`iP80003o2P3jl>H00`3=QCl0n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V
03X0n_3V00<0cHDo0?[`iP3jl>H02P3jl>H20000o`D0n_3V00<000000?[`iP3jl>H03@3jl>H00`00
0000n_3V0?[`iP2F0?[`iP40oooo002a0?[`iP030000o`3jl>H0n_3V00P0n_3V00<0cHDo0?[`iP3j
l>H0>P3jl>H00`000000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V00P0n_3V0P000?l80?[`iP03
0000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00/P3jl>H20000o`T0n_3V
00<0cHDo0?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP0i0?[`iP030<f5?`3jl>H0n_3V00L0n_3V
0P000?l:0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00]03j
l>H20000o`P0n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP0h0?[`iP030<f5?`3j
l>H0n_3V00L0n_3V00<0003o0?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003j
l>H0n_3V09H0n_3V0@3oool00;H0n_3V00<0003o0?[`iP3jl>H01P3jl>H00`3=QCl0n_3V0?[`iP0g
0?[`iP030000003jl>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H01P3jl>H20000o`l0n_3V00<00000
0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo002g0?[`iP80003o1`3jl>H20<f5
?cL0n_3V00<000000?[`iP3jl>H0=@3jl>H20<f5?`L0n_3V0P000?lA0?[`iP030000003jl>H0n_3V
00X0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00^@3jl>H20000o`H0n_3V00<0cHDo0?[`iP3j
l>H0=@3jl>H00`000000n_3V0?[`iP0d0?[`iP030<f5?`3jl>H0n_3V00D0n_3V0P000?lD0?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00^`3jl>H00`000?l0n_3V
0?[`iP040?[`iP030<f5?`3jl>H0n_3V03@0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V
0?[`iP040?[`iP030000o`3jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V
0?[`iP2F0?[`iP40oooo002l0?[`iP80003o1@3jl>H20<f5?c@0n_3V00<000000?[`iP3jl>H0<P3j
l>H20<f5?`D0n_3V0P000?lH0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0UP3j
l>H10?ooo`00_P3jl>H20000o`D0n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0a
0?[`iP030<f5?`3jl>H0n_3V00<0n_3V0P000?lJ0?[`iP030000003jl>H0n_3V00P0n_3V00<00000
0?[`iP3jl>H0UP3jl>H10?ooo`00`03jl>H00`000?l0n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V
0300n_3V00<000000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP020?[`iP80003o7@3jl>H00`00
0000n_3V0?[`iP070?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00<40n_3V0P000?l40?[`iP03
0<f5?`3jl>H0n_3V02l0n_3V00<000000?[`iP3jl>H0;`3jl>H0103=QCl0n_3V0?[`iP3jl>H20000
ob00n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo00330?[`iP80
003o0`3jl>H20<f5?bl0n_3V00<000000?[`iP3jl>H0;@3jl>H20<f5?`<0n_3V00<0003o0?[`iP3j
l>H0803jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00<D0n_3V
0P000?l30?[`iP030<f5?`3jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0;03jl>H0103=QCl0n_3V
0?[`iP3jl>H20000ob@0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP2F0?[`iP40
oooo00370?[`iP80003o0P3jl>H20<f5?b`0n_3V00<000000?[`iP3jl>H0:P3jl>H20<f5?`80n_3V
0P000?lV0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0UP3jl>H10?ooo`00b@3j
l>H20000o`80n_3V0P3=QClZ0?[`iP030000003jl>H0n_3V02P0n_3V0P3=QCl20?[`iP80003o:@3j
l>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00</0n_3V0P000?l2
0?[`iP030<f5?`3jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V0?[`iP02
0000ob`0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo003=0?[`
iP80003o00<0n_3V0<f5?`3=QCl09`3jl>H00`000000n_3V0?[`iP0U0?[`iP80cHDo00<0n_3V0000
o`000?l0;P3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00<l0
n_3V0`000?l20<f5?bD0n_3V00<000000?[`iP3jl>H08`3jl>H20<f5?`030?[`iP000?l0003o0340
n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP2F0?[`iP40oooo003B0?[`iP<0003o
00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0Q0?[`iP80cHDo00<0n_3V0000o`000?l0
<`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V09H0n_3V0@3oool00=D0n_3V0P00
0?l00`3=QCl0n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V01l0n_3V0P3=QCl30000ocH0n_3V00D0
00000?[`iP3jl>H0n_3V0000002H0?[`iP40oooo003G0?[`iP<0003o7`3jl>H00`000000n_3V0?[`
iP0M0?[`iP80cHDo0P000?li0?[`iP050000003jl>H0n_3V0?[`iP000000V03jl>H10?ooo`00fP3j
l>H30000o`030<f5?`3jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06@3jl>H30<f5?`<0003o?03j
l>H010000000n_3V0?[`iP00002H0?[`iP40oooo003M0?[`iP<0003o6@3jl>H00`000000n_3V0?[`
iP0G0?[`iP030<f5?`000?l0003o0080003o@03jl>H00`000000n_3V0000002H0?[`iP40oooo003P
0?[`iP@0003o5@3jl>H00`000000n_3V0?[`iP0C0?[`iP030<f5?`000?l0003o0080003oA03jl>H0
0`000000n_3V0000002H0?[`iP40oooo003T0?[`iP@0003o4@3jl>H00`000000n_3V0?[`iP0?0?[`
iP030<f5?`000?l0003o0080003oB@3jl>H3000009L0n_3V0@3oool00>P0n_3V10000?l=0?[`iP03
0000003jl>H0n_3V00/0n_3V1@000?m<0?[`iPD00000UP3jl>H10?ooo`00k03=QCl=0000o`030000
00000?l0003o00/0003oD@3=QCl5000009D0cHDo0@3jl>H10?ooo`00o`3jl>II0?[`iPD00000UP3j
l>H10?ooo`00o`3jl>IJ0?[`iP<00000U`3jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo002f0?[`iP80000000<0IV9N0<c4^`3jl>H0:`3jl>H01P3Dc<<0IV9N00000000
0000RHAn0>CKdVD0n_3V00H0e<c306IRGP000000000008V4OP3Tfm:L0?[`iP40oooo002h0?[`iP03
06IRGP000000g=C;02/0n_3V00H0C4U50<>k/`3jl>H0k>;I00000029Q7iU0?[`iP0604a9A@33^k<0
n_3V0>cRf@000000RHAnW03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3j
l>H0102_Z:40C4U500000029Q7h70?[`iP060=cDb`1iMG00000000000029Q7h0c<Bk0P3jl>H0102_
Z:40C4U500000029Q7h20?[`iP8000000P3jl>H2000000050?[`iP3<a;/0000007UeL03jl>H00P00
00020?[`iP80000000<0IV9N0?[`iP3jl>H01`3jl>H2000000<0n_3V00@0c<Bk04a9A@1VHUh0i=_B
0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80
00000P3jl>H200000080n_3V00<0RHAn06IRGP3<a;/00P0000070?[`iP050=cDb`1iMG00000004a9
A@2TWIH00P3jl>H0103<a;/0C4U506IRGP3Tfm82000000030?[`iP000000000000@0n_3V00<0Y9fF
0000002TWIH00`3jl>H0102_Z:40C4U500000029Q7h70?[`iP040:nXX@1<BDD0C4U50:nXX@80n_3V
0P0000060?[`iP80000000D0n_3V0<>k/`000000`k^c0?[`iP02000000050?[`iP3<a;/0C4U504a9
A@2_Z:400P0000000`3jl>H00000000000030?[`iP80000000D0n_3V0<c4^`1<BDD0C4U50:nXX@02
000000@0n_3V0P0000000`3/h]T0n_3V0>cRf@0200000080n_3V00<0RHAn06IRGP3<a;/00P000000
0`3jl>H00000000000020?[`iP8000000P3jl>H0102_Z:40C4U500000029Q7h20?[`iP070>cRf@2G
TH/000000000001iMG00i=_B0?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP800000
0P3jl>H2000000070?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP050?[`iP050>CKdP000000Ui6;
0?[`iP2i/ZX00P000000203jl>H0[jRQ00000033^k<0i=_B00000029Q7h0n_3V0P0000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP3<a;/000000080000000<0i=_B0?[`iP3j
l>H01P3jl>H2000000<0n_3V00@0IV9N0000003Tfm80^K:Z0P0000000`3jl>H00000000000030?[`
iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000050?[`iP2TWIH0
00000<>k/`2TWIH00P0000060?[`iP0<0>CKdP000000Ui6;0?[`iP3Dc<<0000008V4OP3jl>H0IV9N
0000003Tfm80^K:Z0P0000000`3jl>H00000000000040?[`iP<0000000P0k>;I0?[`iP2_Z:400000
0<>k/`3Tfm80000008V4OPD0n_3V00L0^K:Z00000033^k<0`k^c0000002i/ZX0n_3V008000001P3j
l>H2000000050?[`iP2GTH/0000009NAR`3jl>H00P0000001@3jl>H0C4U50000003Tfm80`k^c0080
000000<0n_3V0000000000000`3jl>H2000000050?[`iP1<BDD000000>CKdP33^k<00P0000040?[`
iP0<08V4OP000000e<c30?[`iP3Dc<<0000008V4OP3jl>H0Y9fF00000033^k<0Y9fF0P0000000`3j
l>H00000000000020?[`iP80000000l0n_3V0:nXX@000000`k^c0>CKdP000000RHAn0?[`iP1iMG00
00000>CKdP3/h]T0000006IRGP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H20000
0080n_3V0P0000000`3jl>H0C4U5000000090?[`iP0309NAR`000000g=C;0080n_3V0P0000000`3j
l>H0C4U5000000050?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000001P3j
l>H0Ui6;00000029Q7h000000:nXX@P0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP00
0000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP800000
00<0n_3V04a9A@0000000P3jl>H2000000H0n_3V00<0Ui6;0000003Tfm801@3jl>H200000080n_3V
0P0000000`3jl>H00000000000030?[`iP080;VbZP000000RHAn0000002i/ZX0n_3V04a9A@000009
0?[`iP0706IRGP000000n_3V0?[`iP000000IV9N0?[`iP02000000H0n_3V0P0000001@3jl>H0C4U5
0000001<BDD0n_3V0080000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000<0
n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H00`2_Z:4000000000000300000004
0:nXX@3jl>H0C4U500000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V04a9
A@0000001`3jl>H01@3Dc<<0Y9fF0000001<BDD0n_3V00800000Q03jl>H10?ooo`00P`3jl>H20000
00<0n_3V0P0000020?[`iP80000000<0n_3V000000000000100000050?[`iP0304a9A@000000n_3V
0080n_3V0P0000000`3jl>H0000000000004000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000H0n_3V04a9A@000000k>;I0000001VHUh80?[`iP8000000`3j
l>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP00
000000000?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000060?[`iP800000
1P3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP80C4U500@0k>;I04a9A@1<BDD0
n_3V1P0000050?[`iP8000000P3jl>H2000000030?[`iP000000000000H0n_3V0P0000001@3Tfm80
000009NAR`000000i=_B0080000000D0n_3V0<c4^`000000Ui6;0>CKdP02000000030?[`iP000000
000000<0n_3V0P0000001@3jl>H0c<Bk0000002GTH/0i=_B00800000103jl>H0203Dc<<0000008V4
OP3jl>H0Ui6;0000003Dc<<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000@0000000<0n_3V0<c4^`1<BDD00P0000000`1<BDD0c<Bk0?[`iP020000
08@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP1<BDD000000080
n_3V00<0000006IRGP3jl>H0103jl>H200000080n_3V0`0000000`3jl>H0C4U5000000020?[`iP03
0000001VHUh0n_3V008000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000001`3Le</0
000008V4OP3jl>H0RHAn0000003Tfm801`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V
0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00
00000`3jl>H0C4U5000000020?[`iP8000001P3jl>H2000000H0n_3V0P0000020?[`iP80000000<0
n_3V0000000000000P3jl>H02@3<a;/000000:BMUP3jl>H0Y9fF0000003<a;/0C4U5000000020?[`
iP030000001VHUh0n_3V00@0n_3V00L0IV9N0000003jl>H0n_3V0000001VHUh0n_3V008000001P3j
l>H2000000050<c4^`000000g=C;0000003<a;/00P0000020?[`iP030=cDb`2_Z:40NGE`00800000
00<0n_3V0000000000000`3jl>H200000080n_3V00<0g=C;0:nXX@1iMG000P0000050?[`iP050000
001<BDD0n_3V04a9A@0000000P3jl>H0101<BDD000000?[`iP3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H0C4U5000000020?[`iP070000001VHUh0n_3V04a9A@000000NGE`0<c4
^`030?[`iP800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000002`2TWIH0i=_B0000001V
HUh0n_3V0;VbZP000000`k^c0<c4^`000000^K:Z00D0n_3V00<0C4U50000003jl>H01@3jl>H01`2i
/ZX000000<>k/`3<a;/000000;VbZP3jl>H00P0000001@2i/ZX0i=_B0000001<BDD0n_3V00800000
0P3jl>H2000000070:nXX@000000`k^c0?[`iP33^k<000000:nXX@070?[`iP8000000`3jl>H20000
0080n_3V0P000000103jl>H000000000003Dc<<20?[`iP80000000D0^K:Z0>CKdP000000C4U50?[`
iP020000000<0?[`iP00000000000;VbZP3Tfm80000004a9A@3jl>H0Y9fF00000033^k<0Y9fF0P00
00060?[`iP0304a9A@000000n_3V00D0n_3V0P0000020?[`iP8000000180n_3V000000000000e<c3
0?[`iP1VHUh000000>cRf@3jl>H0k>;I0000001VHUh0^K:Z00000033^k<0c<Bk0000002i/ZX50?[`
iP070;VbZP000000`k^c0<>k/`000000^K:Z0?[`iP02000000H0n_3V0P0000001@2TWIH0IV9N0?[`
iP1VHUh0Y9fF0080000000P0n_3V07UeL03Dc<<0n_3V0>CKdP000000C4U50?[`iP80000000<0e<c3
0?[`iP3jl>H00P0000001`3jl>H0NGE`0=C<``3jl>H0i=_B0000001<BDD01@3jl>H01@1iMG000000
0<c4^`000000IV9N0080n_3V00@0Y9fF00000033^k<0Y9fF0P0000005P3jl>H000000000002i/ZX0
i=_B0000001<BDD0n_3V0;VbZP000000`k^c0<c4^`000000^K:Z0?[`iP1VHUh000000?[`iP3Tfm80
000007UeL03jl>H2000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP80000000@0g=C;08V4OP1<
BDD0c<Bk0P3jl>H0102_Z:4000000000002_Z:460?[`iP0309NAR`000000i=_B00H0n_3V00@0[jRQ
000000000000[jRQ0P3jl>H2000000040<c4^`1iMG00C4U50<c4^`@0000000X0n_3V000000000000
IV9N0000003/h]T0n_3V0>cRf@000000IV9N1`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0
n_3V000000000000RHAn07UeL03jl>H2000000050<c4^`1iMG00C4U50<c4^`3jl>H00P0000001`3j
l>H000000000003<a;/0NGE`04a9A@3<a;/00P3jl>H00`29Q7h0IV9N0<c4^`02000000H0n_3V00<0
Ui6;0000003Tfm801@3jl>H200000080n_3V0P000000103jl>H0000000000029Q7h20000000808V4
OP3jl>H0n_3V0?[`iP29Q7h000000=cDb`2_Z:42000000030:nXX@3jl>H0n_3V00D0n_3V00D0[jRQ
04a9A@000000[jRQ0?[`iP04000000D0n_3V0P0000001@1VHUh0Y9fF0?[`iP2GTH/0IV9N00800000
00<0n_3V0>CKdP29Q7h00P0000000`1VHUh0e<c30?[`iP020000000308V4OP1iMG00n_3V00800000
00<0n_3V0>CKdP29Q7h00P0000000`1VHUh0e<c30?[`iP040?[`iP050:BMUP000000RHAn0000002T
WIH00`3jl>H00`29Q7h0IV9N0<c4^`02000000070?[`iP00000000000<c4^`1iMG00C4U50<c4^`02
0?[`iP040:nXX@00000000000:nXX@80n_3V00L0i=_B07UeL0000000000008V4OP3Tfm80n_3V0080
0000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P00000@0?[`iP070>CKdP000000Ui6;0?[`iP3D
c<<0000007UeL00?0?[`iP8000000P3jl>H2000000h0n_3V0P00000/0?[`iP070>CKdP000000Ui6;
0?[`iP3Dc<<0000008V4OP0U0?[`iP8000001P3jl>H3000000030<c4^`3jl>H0`k^c00<000006`3j
l>H01@3<a;/00000000000000000`k^c0:@0n_3V0@3oool00840n_3V1P0000000`3jl>H000000000
000A0?[`iP060=cDb`1iMG0000000000002GTH/0k>;I3`3jl>H0103Le</0RHAn0?[`iP3jl>H20000
00`0n_3V1P00000D0?[`iP8000005@3jl>H01@3Le</0NGE`000000000000Y9fF02H0n_3V00@0c<Bk
06IRGP000000RHAn103jl>H3000000030>cRf@3jl>H0g=C;00<000003@3jl>H2000000`0n_3V00D0
k>;I00000000000000000>CKdP0N0?[`iP800000Q03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.73913 .38333 L
s
.73913 .05 m
.73913 .38333 L
s
.65788 .27007 m
.73913 .27007 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.73913 .38333 Mdot
.65788 .27007 Mdot
.73913 .27007 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V2P3=QCl20?[`iP80000000<0n_3V0<f5
?`3=QCl0203=QCmZ0?[`iP030000003jl>H0n_3V0800n_3V0@3oool00>L0n_3V1P3=QCl<0?[`iP80
00002`3jl>H70<f5?f<0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00i@3jl>H20<f5?a80n_3V
00<000000?[`iP0000004@3jl>H20<f5?f40n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00h@3j
l>H40<f5?a@0n_3V00@000000?[`iP3jl>H000004P3jl>H30<f5?eh0n_3V00<000000?[`iP3jl>H0
P03jl>H10?ooo`00g@3jl>H40<f5?aP0n_3V00D000000?[`iP3jl>H0n_3V0000000D0?[`iP@0cHDo
FP3jl>H00`000000n_3V0?[`iP200?[`iP40oooo003K0?[`iP80cHDo703jl>H01@000000n_3V0?[`
iP3jl>H0000001P0n_3V0P3=QCmH0?[`iP030000003jl>H0n_3V0800n_3V0@3oool00=T0n_3V0P3=
QClN0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H05`3jl>H20<f5?eH0n_3V00<0
00000?[`iP3jl>H0P03jl>H10?ooo`00e`3jl>H20<f5?b00n_3V00<000000?[`iP3jl>H00`3jl>H0
0`000000n_3V0?[`iP0H0?[`iP80cHDoE03jl>H00`000000n_3V0?[`iP200?[`iP40oooo003E0?[`
iP80cHDo8P3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V01X0n_3V0P3=QCmB0?[`
iP030000003jl>H0n_3V0800n_3V0@3oool00=<0n_3V0P3=QClT0?[`iP030000003jl>H0n_3V00@0
n_3V00<000000?[`iP3jl>H06`3jl>H20<f5?e00n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00
d@3jl>H20<f5?bH0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0L0?[`iP80cHDo
CP3jl>H00`000000n_3V0?[`iP200?[`iP40oooo003?0?[`iP80cHDo:03jl>H00`000000n_3V0?[`
iP060?[`iP030000003jl>H0n_3V01d0n_3V0P3=QCm<0?[`iP030000003jl>H0n_3V0800n_3V0@3o
ool00<h0n_3V00<0cHDo0?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0
n_3V01l0n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`iP200?[`iP40oooo003<0?[`
iP80cHDo:`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V01l0n_3V0P3=QCm90?[`
iP030000003jl>H0n_3V0800n_3V0@3oool00<X0n_3V0P3=QCl]0?[`iP030000003jl>H0n_3V00P0
n_3V00<000000?[`iP3jl>H0803jl>H20<f5?dL0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00
b@3jl>H00`3=QCl0n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0
8P3jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V0800n_3V0@3oool00<L0n_3V0P3=
QCl`0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H08P3jl>H20<f5?d@0n_3V00<0
00000?[`iP3jl>H0P03jl>H10?ooo`00aP3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0
n_3V00X0n_3V00<000000?[`iP3jl>H08`3jl>H00`3=QCl0n_3V0?[`iP110?[`iP030000003jl>H0
n_3V0800n_3V0@3oool00<D0n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0;0?[`
iP030000003jl>H0n_3V02<0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP200?[`
iP40oooo00340?[`iP030<f5?`3jl>H0n_3V0380n_3V00<000000?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP0T0?[`iP030<f5?`3jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00
`P3jl>H20<f5?cD0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0T0?[`iP80cHDo
?`3jl>H00`000000n_3V0?[`iP200?[`iP40oooo00310?[`iP030<f5?`3jl>H0n_3V03D0n_3V00<0
00000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0T0?[`iP030<f5?`3jl>H0n_3V03d0n_3V00<0
00000?[`iP3jl>H0P03jl>H10?ooo`00`03jl>H00`3=QCl0n_3V0?[`iP0f0?[`iP030000003jl>H0
n_3V00d0n_3V00<000000?[`iP3jl>H09@3jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP030000003jl>H0
n_3V0800n_3V0@3oool00;l0n_3V00<0cHDo0?[`iP3jl>H0=`3jl>H00`000000n_3V0?[`iP0>0?[`
iP030000003jl>H0n_3V02D0n_3V0P3=QCll0?[`iP030000003jl>H0n_3V0800n_3V0@3oool00;h0
n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V02H0
n_3V00<0cHDo0?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP200?[`iP40oooo002m0?[`iP030<f5
?`3jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0V0?[`iP030<f5
?`3jl>H0n_3V03P0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00_03jl>H00`3=QCl0n_3V0?[`
iP0j0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V0?[`
iP0g0?[`iP030000003jl>H0n_3V0800n_3V0@3oool00;/0n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H0
0`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V02H0n_3V00<0cHDo0?[`iP3jl>H0=`3jl>H0
0`000000n_3V0?[`iP200?[`iP40oooo002j0?[`iP030<f5?`3jl>H0n_3V03`0n_3V00<000000?[`
iP3jl>H04P3jl>H00`000000n_3V0?[`iP0V0?[`iP030<f5?`3jl>H0n_3V03H0n_3V00<000000?[`
iP3jl>H0P03jl>H10?ooo`00^@3jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V01<0
n_3V00<000000?[`iP3jl>H09P3jl>H20<f5?cH0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00
^03jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0
9`3jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0n_3V0800n_3V0@3oool00;P0n_3V00<0
cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V02L0n_3V00<0
cHDo0?[`iP3jl>H0<`3jl>H00`000000n_3V0?[`iP200?[`iP40oooo002g0?[`iP030<f5?`3jl>H0
n_3V03l0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0W0?[`iP030<f5?`3jl>H0
n_3V0380n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00]P3jl>H00`3=QCl0n_3V0?[`iP100?[`
iP030000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V0?[`iP0b0?[`
iP030000003jl>H0n_3V0800n_3V0@3oool00;H0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000
n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V02L0n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000
n_3V0?[`iP200?[`iP40oooo002e0?[`iP030<f5?`3jl>H0n_3V0440n_3V00<000000?[`iP3jl>H0
5`3jl>H00`000000n_3V0?[`iP0W0?[`iP030<f5?`3jl>H0n_3V0300n_3V00<000000?[`iP3jl>H0
P03jl>H10?ooo`00]03jl>H00`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V01P0n_3V00<0
00000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V0800n_3V0@3o
ool00;<0n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP0H0?[`iP030000003jl>H0
n_3V02P0n_3V00<0cHDo0?[`iP3jl>H0;P3jl>H00`000000n_3V0?[`iP200?[`iP40oooo002b0?[`
iP030<f5?`3jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0W0?[`
iP030<f5?`3jl>H0n_3V02h0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00/P3jl>H00`3=QCl0
n_3V0?[`iP140?[`iP030000003jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H09`3jl>H00`3=QCl0
n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V0800n_3V0@3oool00;40n_3V00<0cHDo0?[`iP3jl>H0
A@3jl>H00`000000n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V02L0n_3V00<0cHDo0?[`iP3jl>H0
;@3jl>H00`000000n_3V0?[`iP200?[`iP40oooo002a0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<0
00000?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP0W0?[`iP030<f5?`3jl>H0n_3V02`0n_3V00<0
00000?[`iP3jl>H0P03jl>H10?ooo`00/03jl>H00`3=QCl0n_3V0?[`iP160?[`iP030000003jl>H0
n_3V01`0n_3V00<000000?[`iP3jl>H09P3jl>H00`3=QCl0n_3V0?[`iP0/0?[`iP030000003jl>H0
n_3V0800n_3V0@3oool00;00n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP0M0?[`
iP030000003jl>H0n_3V02H0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP200?[`
iP40oooo002_0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H07@3jl>H00`000000
n_3V0?[`iP0V0?[`iP030<f5?`3jl>H0n_3V02/0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00
[`3jl>H00`3=QCl0n_3V0?[`iP170?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0
9P3jl>H00`3=QCl0n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V0800n_3V0@3oool00:h0n_3V00<0
cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V02H0n_3V00<0
cHDo0?[`iP3jl>H0:@3jl>H00`000000n_3V0?[`iP200?[`iP40oooo002]0?[`iP030<f5?`3jl>H0
n_3V04T0n_3V00<000000?[`iP3jl>H07`3jl>H00`000000n_3V0?[`iP0V0?[`iP030<f5?`3jl>H0
n_3V02T0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00[@3jl>H00`3=QCl0n_3V0?[`iP190?[`
iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H09P3jl>H00`3=QCl0n_3V0?[`iP0X0?[`
iP030000003jl>H0n_3V0800n_3V0@3oool00:`0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000
n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V02D0n_3V00<0cHDo0?[`iP3jl>H0:03jl>H00`000000
n_3V0?[`iP200?[`iP40oooo002/0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0
8P3jl>H00`000000n_3V0?[`iP0U0?[`iP030<f5?`3jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H0
P03jl>H10?ooo`000P000?nZ0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H08P3j
l>H00`000000n_3V0?[`iP0U0?[`iP030<f5?`3jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H0O@3j
l>H20000o`40n_3V0@3oool00080n_3V0`000?nW0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<00000
0?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP0T0?[`iP030<f5?`3jl>H0n_3V02L0n_3V00<00000
0?[`iP3jl>H0NP3jl>H30000o`<0n_3V0@3oool000D0n_3V10000?nR0?[`iP030<f5?`3jl>H0n_3V
04/0n_3V00<000000?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP0S0?[`iP030<f5?`3jl>H0n_3V
02L0n_3V00<000000?[`iP3jl>H0MP3jl>H40000o`H0n_3V0@3oool000T0n_3V0`000?nO0?[`iP03
0<f5?`3jl>H0n_3V04/0n_3V00<000000?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP0T0?[`iP03
0<f5?`3jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0L`3jl>H30000o`X0n_3V0@3oool000`0n_3V
0`000?nK0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H09@3jl>H00`000000n_3V
0?[`iP0S0?[`iP030<f5?`3jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0L03jl>H30000o`d0n_3V
0@3oool000l0n_3V10000?nG0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H09P3j
l>H00`000000n_3V0?[`iP0S0?[`iP030<f5?`3jl>H0n_3V02D0n_3V00<000000?[`iP3jl>H0K03j
l>H40000oa00n_3V0@3oool001<0n_3V0`000?nD0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<00000
0?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP0R0?[`iP030<f5?`3jl>H0n_3V02D0n_3V00<00000
0?[`iP3jl>H0J@3jl>H30000oa@0n_3V0@3oool001H0n_3V0`000?nA0?[`iP030<f5?`3jl>H0n_3V
04`0n_3V00<000000?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP0R0?[`iP030<f5?`3jl>H0n_3V
02D0n_3V00<000000?[`iP3jl>H0IP3jl>H30000oaL0n_3V0@3oool001T0n_3V0`000?n=0?[`iP03
0<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP0Q0?[`iP03
0<f5?`3jl>H0n_3V02D0n_3V00<000000?[`iP3jl>H0H`3jl>H30000oaX0n_3V0@3oool001`0n_3V
0`000?n:0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0:@3jl>H00`000000n_3V
0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0H03jl>H30000oad0n_3V
0@3oool001l0n_3V10000?n60?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0:@3j
l>H00`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0G@3j
l>H30000ob00n_3V0@3oool002<0n_3V0`000?n30?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<00000
0?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`iP0P0?[`iP030<f5?`3jl>H0n_3V02@0n_3V00<00000
0?[`iP3jl>H0FP3jl>H30000ob<0n_3V0@3oool002H0n_3V0`000?mo0?[`iP030<f5?`3jl>H0n_3V
04h0n_3V00<000000?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP0O0?[`iP030<f5?`3jl>H0n_3V
02@0n_3V00<000000?[`iP3jl>H0E`3jl>H30000obH0n_3V0@3oool002T0n_3V0`000?ml0?[`iP03
0<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0O0?[`iP03
0<f5?`3jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H0E03jl>H30000obT0n_3V0@3oool002`0n_3V
0P000?mj0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0;03jl>H00`000000n_3V
0?[`iP0O0?[`iP030<f5?`3jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H0DP3jl>H20000ob`0n_3V
0@3oool002h0n_3V0P000?mh0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0;@3j
l>H00`000000n_3V0?[`iP0N0?[`iP030<f5?`3jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H0D03j
l>H20000obh0n_3V0@3oool00300n_3V0`000?md0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<00000
0?[`iP3jl>H0;P3jl>H00`000000n_3V0?[`iP0M0?[`iP030<f5?`3jl>H0n_3V02<0n_3V00<00000
0?[`iP3jl>H0C@3jl>H30000oc00n_3V0@3oool003<0n_3V0P000?mb0?[`iP030<f5?`3jl>H0n_3V
04l0n_3V00<000000?[`iP3jl>H0;P3jl>H00`000000n_3V0?[`iP0N0?[`iP030<f5?`3jl>H0n_3V
0280n_3V00<000000?[`iP3jl>H0B`3jl>H20000oc<0n_3V0@3oool003D0n_3V0P000?m`0?[`iP03
0<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0M0?[`iP03
0<f5?`3jl>H0n_3V0280n_3V00<000000?[`iP3jl>H0B@3jl>H20000ocD0n_3V0@3oool003L0n_3V
0`000?m]0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0<03jl>H00`000000n_3V
0?[`iP0L0?[`iP030<f5?`3jl>H0n_3V0280n_3V00<000000?[`iP3jl>H0AP3jl>H30000ocL0n_3V
0@3oool003X0n_3V0P000?m[0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0<@3j
l>H00`000000n_3V0?[`iP0K0?[`iP030<f5?`3jl>H0n_3V0280n_3V00<000000?[`iP3jl>H0A03j
l>H20000ocX0n_3V0@3oool003`0n_3V0P000?mY0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<00000
0?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0K0?[`iP030<f5?`3jl>H0n_3V0280n_3V00<00000
0?[`iP3jl>H0@P3jl>H20000oc`0n_3V0@3oool003h0n_3V0`000?mU0?[`iP030<f5?`3jl>H0n_3V
0500n_3V00<000000?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP0J0?[`iP030<f5?`3jl>H0n_3V
0280n_3V00<000000?[`iP3jl>H0?`3jl>H30000och0n_3V0@3oool00440n_3V0P000?mS0?[`iP03
0<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0<`3jl>H00`000000n_3V0?[`iP0J0?[`iP03
0<f5?`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0?@3jl>H20000od40n_3V0@3oool004<0n_3V
0P000?mQ0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0<`3jl>H00`000000n_3V
0?[`iP0J0?[`iP030<f5?`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0>`3jl>H20000od<0n_3V
0@3oool004D0n_3V0P000?mO0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0=03j
l>H00`000000n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0>@3j
l>H20000odD0n_3V0@3oool004L0n_3V0P000?mM0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<00000
0?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP0H0?[`iP030<f5?`3jl>H0n_3V0240n_3V00<00000
0?[`iP3jl>H0=`3jl>H20000odL0n_3V0@3oool004T0n_3V0`000?mJ0?[`iP030<f5?`3jl>H0n_3V
0500n_3V00<000000?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP0G0?[`iP030<f5?`3jl>H0n_3V
0240n_3V00<000000?[`iP3jl>H0=@3jl>H20000odT0n_3V0@3oool004`0n_3V0P000?mH0?[`iP03
0<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP0G0?[`iP03
0<f5?`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0<`3jl>H20000od/0n_3V0@3oool004h0n_3V
0P000?mF0?[`iP030<f5?`3jl>H0n_3V04l0n_3V0`00000h0?[`iP030000003jl>H0n_3V01H0n_3V
00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0a0?[`iP80003oC@3jl>H10?ooo`00D03j
l>H20000oe@0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H5000003P0n_3V00<000000?[`iP3jl>H05@3j
l>H00`3=QCl0n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V02l0n_3V0P000?m?0?[`iP40oooo001B
0?[`iP80003oDP3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iPD00000>03jl>H00`000000n_3V0?[`iP0E
0?[`iP030<f5?`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0;@3jl>H20000oe40n_3V0@3oool0
05@0n_3V0P000?m@0?[`iP030<f5?`3jl>H0n_3V04h0n_3V1@00000i0?[`iP030000003jl>H0n_3V
01@0n_3V00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0[0?[`iP80003oD`3jl>H10?oo
o`00EP3jl>H20000odh0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H3000003/0n_3V00<000000?[`iP3j
l>H04`3jl>H00`3=QCl0n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V02T0n_3V0P000?mE0?[`iP40
oooo001H0?[`iP80003oC03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V03/0n_3V
00<000000?[`iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V02L0n_3V
0P000?mG0?[`iP40oooo001J0?[`iP030000o`3jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3jl>H0D03j
l>H00`000000n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V0180n_3V00<0cHDo0?[`iP3jl>H08@3j
l>H00`000000n_3V0?[`iP0U0?[`iP80003oF@3jl>H10?ooo`00F`3jl>H20000odT0n_3V00<0cHDo
0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0l0?[`iP030000003jl>H0n_3V0140n_3V00<0cHDo
0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0S0?[`iP80003oF`3jl>H10?ooo`00G@3jl>H20000
odL0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V
0100n_3V00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0Q0?[`iP80003oG@3jl>H10?oo
o`00G`3jl>H20000odD0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0n0?[`iP03
0000003jl>H0n_3V00l0n_3V00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0O0?[`iP80
003oG`3jl>H10?ooo`00H@3jl>H00`000?l0n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V0500n_3V
00<000000?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V0240n_3V
00<000000?[`iP3jl>H07@3jl>H20000of40n_3V0@3oool00680n_3V0P000?m20?[`iP030<f5?`3j
l>H0n_3V0500n_3V00<000000?[`iP3jl>H0?`3jl>H00`000000n_3V0?[`iP0>0?[`iP030<f5?`3j
l>H0n_3V0240n_3V00<000000?[`iP3jl>H06`3jl>H20000of<0n_3V0@3oool006@0n_3V0P000?m0
0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP0<
0?[`iP030<f5?`3jl>H0n_3V0280n_3V00<000000?[`iP3jl>H06@3jl>H20000ofD0n_3V0@3oool0
06H0n_3V0P000?lo0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0@03jl>H00`00
0000n_3V0?[`iP0<0?[`iP030<f5?`3jl>H0n_3V0280n_3V00<000000?[`iP3jl>H05`3jl>H20000
ofL0n_3V0@3oool006P0n_3V00<0003o0?[`iP3jl>H0?03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP03
0000003jl>H0n_3V0440n_3V00<000000?[`iP3jl>H02`3jl>H00`3=QCl0n_3V0?[`iP0R0?[`iP03
0000003jl>H0n_3V01H0n_3V00<0003o0?[`iP3jl>H0I`3jl>H10?ooo`00J@3jl>H20000oc`0n_3V
00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP120?[`iP030000003jl>H0n_3V00X0n_3V
00<0cHDo0?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP0D0?[`iP80003oJP3jl>H10?ooo`00J`3j
l>H20000ocX0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP130?[`iP030000003j
l>H0n_3V00T0n_3V00<0cHDo0?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP0C0?[`iP030000o`3j
l>H0n_3V06X0n_3V0@3oool006d0n_3V00<0003o0?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V0?[`iP1?
0?[`iP030000003jl>H0n_3V04<0n_3V00<000000?[`iP3jl>H02@3jl>H00`3=QCl0n_3V0?[`iP0R
0?[`iP030000003jl>H0n_3V0140n_3V0P000?m]0?[`iP40oooo001^0?[`iP80003o=`3jl>H00`3=
QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H01`3jl>H00`3=
QCl0n_3V0?[`iP0S0?[`iP030000003jl>H0n_3V00l0n_3V0P000?m_0?[`iP40oooo001`0?[`iP80
003o=P3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04D0n_3V00<000000?[`iP3j
l>H01P3jl>H00`3=QCl0n_3V0?[`iP0S0?[`iP030000003jl>H0n_3V00h0n_3V00<0003o0?[`iP3j
l>H0K`3jl>H10?ooo`00LP3jl>H00`000?l0n_3V0?[`iP0c0?[`iP030<f5?`3jl>H0n_3V04h0n_3V
00<000000?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP060?[`iP030<f5?`3jl>H0n_3V02<0n_3V
00<000000?[`iP3jl>H0303jl>H20000og80n_3V0@3oool007<0n_3V0P000?lc0?[`iP030<f5?`3j
l>H0n_3V04h0n_3V00<000000?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP050?[`iP030<f5?`3j
l>H0n_3V02<0n_3V00<000000?[`iP3jl>H02`3jl>H00`000?l0n_3V0?[`iP1b0?[`iP40oooo001e
0?[`iP80003o<@3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04L0n_3V00<00000
0?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP0T0?[`iP030000003jl>H0n_3V00T0n_3V0P000?me
0?[`iP40oooo001g0?[`iP030000o`3jl>H0n_3V02l0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`00
0000n_3V0?[`iP180?[`iP030000003jl>H0n_3V0080n_3V00<0cHDo0?[`iP3jl>H0903jl>H00`00
0000n_3V0?[`iP070?[`iP80003oM`3jl>H10?ooo`00N03jl>H20000obl0n_3V00<0cHDo0?[`iP3j
l>H0C@3jl>H00`000000n_3V0?[`iP180?[`iP030000003jl>H0n_3V0080n_3V00<0cHDo0?[`iP3j
l>H0903jl>H00`000000n_3V0?[`iP060?[`iP030000o`3jl>H0n_3V07L0n_3V0@3oool007X0n_3V
0P000?l]0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0B@3jl>H01@000000n_3V
0?[`iP3jl>H0cHDo02H0n_3V00<000000?[`iP3jl>H0103jl>H20000ogX0n_3V0@3oool007`0n_3V
00<0003o0?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V04X0n_3V
00<000000?[`iP3=QCl09`3jl>H00`000000n_3V0?[`iP030?[`iP030000o`3jl>H0n_3V07X0n_3V
0@3oool007d0n_3V0P000?l[0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0BP3j
l>H4000002D0n_3V0`0000020?[`iP80003oO@3jl>H10?ooo`00O`3jl>H20000obT0n_3V00<0cHDo
0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP1:0?[`iPD000008`3jl>H5000000030000o`3jl>H0
n_3V07d0n_3V0@3oool00840n_3V00<0003o0?[`iP3jl>H09P3jl>H00`3=QCl0n_3V0?[`iP1<0?[`
iP030000003jl>H0n_3V04X0n_3V;@0000200?[`iP40oooo00220?[`iP80003o9P3jl>H00`3=QCl0
n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04X0n_3V1@00000S0?[`iPD00000P03jl>H10?ooo`00
Q03jl>H20000obD0n_3V00<0cHDo0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP1;0?[`iP<00000
903jl>H010000?l000000000000000210?[`iP40oooo00260?[`iP030000o`3jl>H0n_3V0280n_3V
00<0cHDo0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP1:0?[`iP050<f5?`3jl>H0n_3V0?[`iP00
00008@3jl>H20000o`80n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00Q`3jl>H20000ob<0n_3V
00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0080n_3V
00<000000?[`iP3jl>H0703jl>H20000o`@0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00R@3j
l>H20000ob40n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3j
l>H0n_3V0080n_3V00<000000?[`iP3jl>H06`3jl>H00`000?l0n_3V0?[`iP040?[`iP030000003j
l>H0n_3V0800n_3V0@3oool008/0n_3V0P000?lO0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<00000
0?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP030?[`iP030000003jl>H0n_3V01P0n_3V0P000?l7
0?[`iP030000003jl>H0n_3V0800n_3V0@3oool008d0n_3V00<0003o0?[`iP3jl>H0703jl>H00`3=
QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3jl>H01@3jl>H00`00
0000n_3V0?[`iP0F0?[`iP030000o`3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0P03jl>H10?oo
o`00SP3jl>H20000oad0n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`iP190?[`iP03
0<f5?`3jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H04`3jl>H20000o`X0n_3V00<000000?[`iP3j
l>H0P03jl>H10?ooo`00T03jl>H20000oa`0n_3V00<0cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V
0?[`iP180?[`iP030<f5?`3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04@3jl>H20000o``0n_3V
00<000000?[`iP3jl>H0P03jl>H10?ooo`00TP3jl>H00`000?l0n_3V0?[`iP0I0?[`iP030<f5?`3j
l>H0n_3V04P0n_3V00<000000?[`iP3jl>H0A`3jl>H00`3=QCl0n_3V0?[`iP090?[`iP030000003j
l>H0n_3V00l0n_3V00<0003o0?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP200?[`iP40oooo002C
0?[`iP80003o6P3jl>H00`3=QCl0n_3V0?[`iP170?[`iP030000003jl>H0n_3V04L0n_3V00<0cHDo
0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0<0?[`iP80003o3`3jl>H00`000000n_3V0?[`iP20
0?[`iP40oooo002E0?[`iP030000o`3jl>H0n_3V01L0n_3V00<0cHDo0?[`iP3jl>H0A`3jl>H00`00
0000n_3V0?[`iP160?[`iP030<f5?`3jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02`3jl>H00`00
0?l0n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V0800n_3V0@3oool009H0n_3V0P000?lH0?[`iP03
0<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H0AP3jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP03
0000003jl>H0n_3V00P0n_3V0P000?lB0?[`iP030000003jl>H0n_3V0800n_3V0@3oool009P0n_3V
00<0003o0?[`iP3jl>H05@3jl>H00`3=QCl0n_3V0?[`iP160?[`iP030000003jl>H0n_3V04D0n_3V
00<0cHDo0?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP060?[`iP030000o`3jl>H0n_3V0180n_3V
00<000000?[`iP3jl>H0P03jl>H10?ooo`00V@3jl>H20000oaH0n_3V00<0cHDo0?[`iP3jl>H0A@3j
l>H00`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H00`3j
l>H20000oaD0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00V`3jl>H00`000?l0n_3V0?[`iP0C
0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0A03jl>H00`3=QCl0n_3V0?[`iP0@
0?[`iP030000003jl>H0n_3V0080n_3V00<0003o0?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP20
0?[`iP40oooo002L0?[`iP80003o503jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V
04@0n_3V00<0cHDo0?[`iP3jl>H04@3jl>H010000000n_3V0000o`000?lH0?[`iP030000003jl>H0
n_3V0800n_3V0@3oool009h0n_3V00<0003o0?[`iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`iP130?[`
iP030000003jl>H0n_3V04<0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP0H0?[`
iP030000003jl>H0n_3V0800n_3V0@3oool009l0n_3V0P000?lB0?[`iP030<f5?`3jl>H0n_3V04<0
n_3V00<000000?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP80003o00<000000?[`iP3j
l>H0603jl>H00`000000n_3V0?[`iP200?[`iP40oooo002Q0?[`iP030000o`3jl>H0n_3V0100n_3V
00<0cHDo0?[`iP3jl>H0@P3jl>H00`000000n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V0140n_3V
00D0003o0?[`iP3jl>H0n_3V0000000I0?[`iP030000003jl>H0n_3V0800n_3V0@3oool00:80n_3V
0P000?lA0?[`iP030<f5?`3jl>H0n_3V0440n_3V00<000000?[`iP3jl>H0@@3jl>H00`3=QCl0n_3V
0?[`iP0@0?[`iP80003o1@3jl>H00`000000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V0800n_3V
0@3oool00:@0n_3V00<0003o0?[`iP3jl>H03`3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003j
l>H0n_3V0400n_3V00<0cHDo0?[`iP3jl>H0403jl>H00`000?l0n_3V0?[`iP060?[`iP030000003j
l>H0n_3V01D0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00Y@3jl>H20000o`l0n_3V00<0cHDo
0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V00l0n_3V0P000?l9
0?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00Y`3jl>H00`00
0?l0n_3V0?[`iP0=0?[`iP030<f5?`3jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=
QCl0n_3V0?[`iP0>0?[`iP030000o`3jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0503jl>H00`00
0000n_3V0?[`iP200?[`iP40oooo002X0?[`iP80003o3P3jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP03
0000003jl>H0n_3V03h0n_3V00<0cHDo0?[`iP3jl>H03@3jl>H20000o`h0n_3V00<000000?[`iP3j
l>H04`3jl>H00`000000n_3V0?[`iP200?[`iP40oooo002Z0?[`iP80003o303jl>H00`3=QCl0n_3V
0?[`iP0n0?[`iP030000003jl>H0n_3V03d0n_3V00<0cHDo0?[`iP3jl>H0303jl>H20000oa00n_3V
00<000000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP200?[`iP40oooo002/0?[`iP030000o`3j
l>H0n_3V00X0n_3V00<0cHDo0?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP0m0?[`iP030<f5?`3j
l>H0n_3V00X0n_3V0P000?lC0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0P03j
l>H10?ooo`00[@3jl>H20000o`/0n_3V0P3=QClm0?[`iP030000003jl>H0n_3V03/0n_3V0P3=QCl<
0?[`iP030000o`3jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP20
0?[`iP40oooo002_0?[`iP80003o2P3jl>H00`3=QCl0n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V
03X0n_3V00<0cHDo0?[`iP3jl>H02P3jl>H20000oaP0n_3V00<000000?[`iP3jl>H0403jl>H00`00
0000n_3V0?[`iP200?[`iP40oooo002a0?[`iP030000o`3jl>H0n_3V00P0n_3V00<0cHDo0?[`iP3j
l>H0>P3jl>H00`000000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V00P0n_3V0P000?lJ0?[`iP03
0000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00/P3jl>H20000o`T0n_3V
00<0cHDo0?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP0i0?[`iP030<f5?`3jl>H0n_3V00L0n_3V
0P000?lM0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00]03j
l>H20000o`P0n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP0h0?[`iP030<f5?`3j
l>H0n_3V00L0n_3V00<0003o0?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003j
l>H0n_3V0800n_3V0@3oool00;H0n_3V00<0003o0?[`iP3jl>H01P3jl>H00`3=QCl0n_3V0?[`iP0g
0?[`iP030000003jl>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H01P3jl>H20000ob80n_3V00<00000
0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP200?[`iP40oooo002g0?[`iP80003o1`3jl>H20<f5
?cL0n_3V00<000000?[`iP3jl>H0=@3jl>H20<f5?`L0n_3V0P000?lT0?[`iP030000003jl>H0n_3V
00d0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00^@3jl>H20000o`H0n_3V00<0cHDo0?[`iP3j
l>H0=@3jl>H00`000000n_3V0?[`iP0d0?[`iP030<f5?`3jl>H0n_3V00D0n_3V0P000?lW0?[`iP03
0000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00^`3jl>H00`000?l0n_3V
0?[`iP040?[`iP030<f5?`3jl>H0n_3V03@0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V
0?[`iP040?[`iP030000o`3jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V
0?[`iP200?[`iP40oooo002l0?[`iP80003o1@3jl>H20<f5?c@0n_3V00<000000?[`iP3jl>H0<P3j
l>H20<f5?`D0n_3V0P000?l[0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0P03j
l>H10?ooo`00_P3jl>H20000o`D0n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0a
0?[`iP030<f5?`3jl>H0n_3V00<0n_3V0P000?l^0?[`iP030000003jl>H0n_3V00X0n_3V00<00000
0?[`iP3jl>H0P03jl>H10?ooo`00`03jl>H00`000?l0n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V
0300n_3V00<000000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP020?[`iP80003o<@3jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V0800n_3V0@3oool00<40n_3V0P000?l40?[`iP03
0<f5?`3jl>H0n_3V02l0n_3V00<000000?[`iP3jl>H0;`3jl>H0103=QCl0n_3V0?[`iP3jl>H20000
oc@0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP200?[`iP40oooo00330?[`iP80
003o0`3jl>H20<f5?bl0n_3V00<000000?[`iP3jl>H0;@3jl>H20<f5?`<0n_3V00<0003o0?[`iP3j
l>H0=03jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V0800n_3V0@3oool00<D0n_3V
0P000?l30?[`iP030<f5?`3jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0;03jl>H0103=QCl0n_3V
0?[`iP3jl>H20000ocP0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP200?[`iP40
oooo00370?[`iP80003o0P3jl>H20<f5?b`0n_3V00<000000?[`iP3jl>H0:P3jl>H20<f5?`80n_3V
0P000?lk0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00b@3j
l>H20000o`80n_3V0P3=QClZ0?[`iP030000003jl>H0n_3V02P0n_3V0P3=QCl20?[`iP80003o?@3j
l>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V0800n_3V0@3oool00</0n_3V0P000?l2
0?[`iP030<f5?`3jl>H0n_3V02L0n_3V00<000000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V0?[`iP02
0000od00n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP200?[`iP40oooo003=0?[`
iP80003o00<0n_3V0<f5?`3=QCl09`3jl>H00`000000n_3V0?[`iP0U0?[`iP80cHDo00<0n_3V0000
o`000?l0@`3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V0800n_3V0@3oool00<l0
n_3V0`000?l20<f5?bD0n_3V00<000000?[`iP3jl>H08`3jl>H20<f5?`030?[`iP000?l0003o04H0
n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP200?[`iP40oooo003B0?[`iP<0003o
00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0Q0?[`iP80cHDo00<0n_3V0000o`000?l0
B03jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0800n_3V0@3oool00=D0n_3V0P00
0?l00`3=QCl0n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V01l0n_3V0P3=QCl30000od/0n_3V00<0
00000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP200?[`iP40oooo003G0?[`iP<0003o7`3jl>H0
0`000000n_3V0?[`iP0M0?[`iP80cHDo0P000?m?0?[`iP050000003jl>H0n_3V0?[`iP000000PP3j
l>H10?ooo`00fP3jl>H30000o`030<f5?`3jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06@3jl>H3
0<f5?`<0003oD@3jl>H01@000000n_3V0?[`iP3jl>H000000880n_3V0@3oool00=d0n_3V0`000?lI
0?[`iP030000003jl>H0n_3V01L0n_3V00<0cHDo0000o`000?l00P000?mE0?[`iP040000003jl>H0
n_3V00000880n_3V0@3oool00>00n_3V10000?lE0?[`iP030000003jl>H0n_3V01<0n_3V00<0cHDo
0000o`000?l00P000?mJ0?[`iP030000003jl>H000000880n_3V0@3oool00>@0n_3V10000?lA0?[`
iP030000003jl>H0n_3V00l0n_3V00<0cHDo0000o`000?l00P000?mO0?[`iP<00000P@3jl>H10?oo
o`00j03jl>H40000o`d0n_3V00<000000?[`iP3jl>H02`3jl>H50000of80n_3V1@0000200?[`iP40
oooo003/0<f5?`d0003o00<000000000o`000?l02`000?mW0<f5?`D00000O`3=QCl10?[`iP40oooo
003o0?[`iVl0n_3V1@0000200?[`iP40oooo003o0?[`iW00n_3V0`0000210?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00;H0n_3V0P0000000`1VHUh0c<Bk0?[`iP0[
0?[`iP060=C<``1VHUh0000000000029Q7h0i=_BI@3jl>H01P3Dc<<0IV9N000000000000RHAn0>CK
dY`0n_3V0@3oool00;P0n_3V00<0IV9N0000003Le</0:`3jl>H01P1<BDD0`k^c0?[`iP3/h]T00000
08V4OVD0n_3V00H0C4U50<>k/`3jl>H0k>;I00000029Q7jL0?[`iP40oooo00230?[`iP8000000`3j
l>H200000080n_3V0P0000020?[`iP040:nXX@1<BDD0000008V4OPL0n_3V00H0g=C;07UeL0000000
000008V4OP3<a;/20?[`iP040:nXX@1<BDD0000008V4OP80n_3V0P0000020?[`iP80000000D0n_3V
0<c4^`000000NGE`0?[`iP0200000080n_3V0P0000000`1VHUh0n_3V0?[`iP070?[`iP8000000`3j
l>H0103<a;/0C4U506IRGP3Tfm82000000030?[`iP000000000000<0n_3V0P0000020?[`iP800000
00@0n_3V000000000000n_3V0P0000020?[`iP8000000P3jl>H00`29Q7h0IV9N0<c4^`02000000L0
n_3V00D0g=C;07UeL0000000C4U50:BMUP020?[`iP040<c4^`1<BDD0IV9N0>CKdP80000000<0n_3V
000000000000103jl>H00`2TWIH000000:BMUP030?[`iP040:nXX@1<BDD0000008V4OPL0n_3V00@0
[jRQ04a9A@1<BDD0[jRQ0P3jl>H2000000H0n_3V0P0000001@3jl>H0`k^c00000033^k<0n_3V0080
000000D0n_3V0<c4^`1<BDD0C4U50:nXX@02000000030?[`iP000000000000<0n_3V0P0000001@3j
l>H0c<Bk04a9A@1<BDD0[jRQ00800000103jl>H2000000030>cRf@3jl>H0k>;I008000000P3jl>H0
0`29Q7h0IV9N0<c4^`02000000030?[`iP00000000000080n_3V0P0000020?[`iP040:nXX@1<BDD0
000008V4OP80n_3V00L0k>;I09NAR`000000000007UeL03Tfm80n_3V00800000Q03jl>H10?ooo`00
P`3jl>H2000000<0n_3V0P0000020?[`iP80000000L0n_3V0:nXX@000000`k^c0>CKdP000000RHAn
00D0n_3V00D0i=_B0000002GTH/0n_3V0;VbZP02000000080?[`iP2_Z:4000000<>k/`3Tfm800000
08V4OP3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0<c4^`00
00000P0000000`3Tfm80n_3V0?[`iP060?[`iP8000000`3jl>H0101VHUh000000>CKdP2i/ZX20000
00030?[`iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P000002
0?[`iP80000000D0n_3V0:BMUP000000`k^c0:BMUP02000000H0n_3V00`0i=_B0000002GTH/0n_3V
0=C<``000000RHAn0?[`iP1VHUh000000>CKdP2i/ZX2000000030?[`iP000000000000@0n_3V0`00
0000203/h]T0n_3V0:nXX@000000`k^c0>CKdP000000RHAn1@3jl>H01`2i/ZX000000<>k/`33^k<0
00000;VbZP3jl>H00P0000060?[`iP80000000D0n_3V09NAR`000000Ui6;0?[`iP02000000050?[`
iP1<BDD000000>CKdP33^k<00P0000000`3jl>H00000000000030?[`iP80000000D0n_3V04a9A@00
0000i=_B0<>k/`02000000@0n_3V00`0RHAn0000003Dc<<0n_3V0=C<``000000RHAn0?[`iP2TWIH0
00000<>k/`2TWIH2000000030?[`iP00000000000080n_3V0P0000003`3jl>H0[jRQ00000033^k<0
i=_B00000029Q7h0n_3V07UeL0000000i=_B0>cRf@000000IV9N0?[`iP02000008@0n_3V0@3oool0
08<0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP1<BDD0000000T0n_3V00<0Ui6;0000
003Le</00P3jl>H2000000030?[`iP1<BDD0000000D0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000060?[`iP2GTH/0000008V4OP000000[jRQ203jl>H2000000<0n_3V0P00
00020?[`iP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000
003jl>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP8000001P3jl>H00`2GTH/00000
0>CKdP050?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V00P0^K:Z00000029Q7h0
00000;VbZP3jl>H0C4U5000000T0n_3V00L0IV9N0000003jl>H0n_3V0000001VHUh0n_3V00800000
1P3jl>H2000000050?[`iP1<BDD0000004a9A@3jl>H00P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V0000000000000`3jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP03
0:nXX@000000000000<0000000@0[jRQ0?[`iP1<BDD000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H0C4U5000000070?[`iP050=C<``2TWIH0000004a9A@3jl>H00P000024
0?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H00000000000040000
00D0n_3V00<0C4U50000003jl>H00P3jl>H2000000030?[`iP000000000000@0000000<0n_3V0000
000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000001P3jl>H0C4U50000003/h]T0
000006IRGPP0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V0P00
00020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000H0n_3V0P0000060?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V
0P1<BDD0103/h]T0C4U504a9A@3jl>H6000000D0n_3V0P0000020?[`iP80000000<0n_3V00000000
00001P3jl>H2000000050>CKdP000000Ui6;0000003Tfm800P0000001@3jl>H0c<Bk0000002GTH/0
i=_B0080000000<0n_3V0000000000000`3jl>H2000000050?[`iP3<a;/0000009NAR`3Tfm800P00
00040?[`iP080=C<``000000RHAn0?[`iP2GTH/000000=C<``3jl>H200000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V000000000000100000000`3jl>H0c<Bk04a9A@020000
000304a9A@3<a;/0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80
000000<0n_3V04a9A@0000000P3jl>H00`000000IV9N0?[`iP040?[`iP8000000P3jl>H300000003
0?[`iP1<BDD000000080n_3V00<0000006IRGP3jl>H00P0000020?[`iP80000000<0n_3V00000000
00000P3jl>H2000000070=cDb`000000RHAn0?[`iP29Q7h000000>CKdP070?[`iP8000000`3jl>H2
00000080n_3V0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP8000000P3jl>H2000000030?[`iP1<BDD000000080n_3V0P0000060?[`iP8000001P3j
l>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP090<c4^`000000Y9fF0?[`iP2TWIH0
00000<c4^`1<BDD000000080n_3V00<0000006IRGP3jl>H0103jl>H01`1VHUh000000?[`iP3jl>H0
000006IRGP3jl>H00P0000060?[`iP80000000D0c<Bk0000003Le</000000<c4^`0200000080n_3V
00<0g=C;0:nXX@1iMG000P0000000`3jl>H00000000000030?[`iP8000000P3jl>H00`3Le</0[jRQ
07UeL002000000D0n_3V00D0000004a9A@3jl>H0C4U5000000020?[`iP0404a9A@000000n_3V0?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP1<BDD000000080n_3V00L0000006IR
GP3jl>H0C4U50000001iMG00c<Bk00<0n_3V0P0000240?[`iP40oooo00230?[`iP8000000`3jl>H2
0000000;0:BMUP3Tfm80000006IRGP3jl>H0^K:Z00000033^k<0c<Bk0000002i/ZX01@3jl>H00`1<
BDD000000?[`iP050?[`iP070;VbZP000000`k^c0<c4^`000000^K:Z0?[`iP02000000050;VbZP3T
fm80000004a9A@3jl>H00P0000020?[`iP80000000L0[jRQ00000033^k<0n_3V0<>k/`000000[jRQ
00L0n_3V0P0000030?[`iP8000000P3jl>H2000000040?[`iP00000000000=C<``80n_3V0P000000
1@2i/ZX0i=_B0000001<BDD0n_3V0080000000`0n_3V000000000000^K:Z0>CKdP000000C4U50?[`
iP2TWIH000000<>k/`2TWIH2000000H0n_3V00<0C4U50000003jl>H01@3jl>H200000080n_3V0P00
00004P3jl>H000000000003Dc<<0n_3V06IRGP000000k>;I0?[`iP3/h]T0000006IRGP2i/ZX00000
0<>k/`3<a;/000000;VbZPD0n_3V00L0^K:Z00000033^k<0`k^c0000002i/ZX0n_3V008000001P3j
l>H2000000050:BMUP1VHUh0n_3V06IRGP2TWIH00P000000203jl>H0NGE`0=C<``3jl>H0i=_B0000
001<BDD0n_3V0P0000000`3Dc<<0n_3V0?[`iP02000000070?[`iP1iMG00e<c30?[`iP3Tfm800000
04a9A@050?[`iP0507UeL0000000c<Bk0000001VHUh00P3jl>H0102TWIH000000<>k/`2TWIH20000
000F0?[`iP00000000000;VbZP3Tfm80000004a9A@3jl>H0^K:Z00000033^k<0c<Bk0000002i/ZX0
n_3V06IRGP000000n_3V0>CKdP000000NGE`0?[`iP800000Q03jl>H10?ooo`00P`3jl>H2000000<0
n_3V0P000000103Le</0RHAn04a9A@3<a;/20?[`iP040:nXX@00000000000:nXX@H0n_3V00<0Ui6;
0000003Tfm801P3jl>H0102_Z:4000000000002_Z:420?[`iP80000000@0c<Bk07UeL01<BDD0c<Bk
100000002P3jl>H000000000001VHUh000000>cRf@3jl>H0k>;I0000001VHUh70?[`iP8000000`3j
l>H200000080n_3V0P0000001P3jl>H0000000000029Q7h0NGE`0?[`iP80000000D0c<Bk07UeL01<
BDD0c<Bk0?[`iP02000000070?[`iP00000000000<c4^`1iMG00C4U50<c4^`020?[`iP0308V4OP1V
HUh0c<Bk008000001P3jl>H00`2GTH/000000>CKdP050?[`iP8000000P3jl>H2000000040?[`iP00
0000000008V4OP80000000P0RHAn0?[`iP3jl>H0n_3V08V4OP000000g=C;0:nXX@80000000<0[jRQ
0?[`iP3jl>H01@3jl>H01@2_Z:40C4U50000002_Z:40n_3V00@000001@3jl>H20000000506IRGP2T
WIH0n_3V09NAR`1VHUh00P0000000`3jl>H0i=_B08V4OP020000000306IRGP3Dc<<0n_3V00800000
00<0RHAn07UeL03jl>H00P0000000`3jl>H0i=_B08V4OP020000000306IRGP3Dc<<0n_3V00@0n_3V
00D0Y9fF00000029Q7h000000:BMUP030?[`iP0308V4OP1VHUh0c<Bk0080000000L0n_3V00000000
0000c<Bk07UeL01<BDD0c<Bk0080n_3V00@0[jRQ000000000000[jRQ0P3jl>H01`3Tfm80NGE`0000
00000000RHAn0>CKdP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000100n_3V
00L0i=_B0000002GTH/0n_3V0=C<``000000NGE`00l0n_3V0P0000020?[`iP8000003P3jl>H20000
02`0n_3V00L0i=_B0000002GTH/0n_3V0=C<``000000RHAn02D0n_3V0P0000060?[`iP<0000000<0
c<Bk0?[`iP33^k<00`00000K0?[`iP050<c4^`000000000000000033^k<0Y03jl>H10?ooo`00P@3j
l>H6000000030?[`iP00000000000140n_3V00H0g=C;07UeL0000000000009NAR`3/h]T?0?[`iP04
0=cDb`29Q7h0n_3V0?[`iP800000303jl>H6000001@0n_3V0P00000E0?[`iP050=cDb`1iMG000000
0000002TWIH09P3jl>H0103<a;/0IV9N00000029Q7h40?[`iP<0000000<0k>;I0?[`iP3Le</00`00
000=0?[`iP800000303jl>H01@3/h]T00000000000000000i=_B01h0n_3V0P0000240?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.78261 .38333 L
s
.78261 .05 m
.78261 .38333 L
s
.66442 .24393 m
.78261 .24393 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.78261 .38333 Mdot
.66442 .24393 Mdot
.78261 .24393 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V2P3=QCl20?[`iP80000000<0n_3V0<f5
?`3=QCl0203=QCn00?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00>L0n_3V1P3=QCl<0?[`iP03
0000003jl>H0000000X0n_3V1`3=QCmi0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00>D0n_3V
0P3=QClB0?[`iP040000003jl>H0n_3V00000100n_3V0P3=QCmg0?[`iP030000003jl>H0n_3V06X0
n_3V0@3oool00>40n_3V103=QClD0?[`iP040000003jl>H0n_3V00000180n_3V0`3=QCmd0?[`iP03
0000003jl>H0n_3V06X0n_3V0@3oool00=d0n_3V103=QClH0?[`iP050000003jl>H0n_3V0?[`iP00
0000503jl>H40<f5?g00n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00f`3jl>H20<f5?a`0n_3V
00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0E0?[`iP80cHDoKP3jl>H00`000000n_3V
0?[`iP1Z0?[`iP40oooo003I0?[`iP80cHDo7P3jl>H00`000000n_3V0?[`iP030?[`iP030000003j
l>H0n_3V01H0n_3V0P3=QCm/0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00=L0n_3V0P3=QClP
0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H05`3jl>H20<f5?fX0n_3V00<00000
0?[`iP3jl>H0JP3jl>H10?ooo`00e@3jl>H20<f5?b80n_3V00<000000?[`iP3jl>H01@3jl>H00`00
0000n_3V0?[`iP0H0?[`iP80cHDoJ03jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo003C0?[`iP80
cHDo903jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V01X0n_3V0P3=QCmV0?[`iP03
0000003jl>H0n_3V06X0n_3V0@3oool00=40n_3V0P3=QClV0?[`iP030000003jl>H0n_3V00H0n_3V
00<000000?[`iP3jl>H06`3jl>H20<f5?f@0n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00c`3j
l>H20<f5?bP0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0L0?[`iP80cHDoHP3j
l>H00`000000n_3V0?[`iP1Z0?[`iP40oooo003>0?[`iP030<f5?`3jl>H0n_3V02P0n_3V00<00000
0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0M0?[`iP030<f5?`3jl>H0n_3V05l0n_3V00<00000
0?[`iP3jl>H0JP3jl>H10?ooo`00c03jl>H20<f5?b/0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP0M0?[`iP80cHDoG`3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo003:0?[`iP80
cHDo;@3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V01h0n_3V0P3=QCmM0?[`iP03
0000003jl>H0n_3V06X0n_3V0@3oool00<T0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`000000n_3V
0?[`iP0;0?[`iP030000003jl>H0n_3V01l0n_3V00<0cHDo0?[`iP3jl>H0FP3jl>H00`000000n_3V
0?[`iP1Z0?[`iP40oooo00370?[`iP80cHDo<03jl>H00`000000n_3V0?[`iP0;0?[`iP030000003j
l>H0n_3V0200n_3V0P3=QCmJ0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00<H0n_3V00<0cHDo
0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V0240n_3V00<0cHDo
0?[`iP3jl>H0E`3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo00350?[`iP030<f5?`3jl>H0n_3V
0340n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V
05H0n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00a03jl>H00`3=QCl0n_3V0?[`iP0b0?[`iP03
0000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H08@3jl>H00`3=QCl0n_3V0?[`iP1E0?[`iP03
0000003jl>H0n_3V06X0n_3V0@3oool00<80n_3V0P3=QCle0?[`iP030000003jl>H0n_3V00l0n_3V
00<000000?[`iP3jl>H08@3jl>H20<f5?eD0n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00`@3j
l>H00`3=QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H08@3j
l>H00`3=QCl0n_3V0?[`iP1C0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00<00n_3V00<0cHDo
0?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0240n_3V00<0cHDo
0?[`iP3jl>H0DP3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002o0?[`iP030<f5?`3jl>H0n_3V
03L0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0R0?[`iP80cHDoDP3jl>H00`00
0000n_3V0?[`iP1Z0?[`iP40oooo002n0?[`iP030<f5?`3jl>H0n_3V03P0n_3V00<000000?[`iP3j
l>H04P3jl>H00`000000n_3V0?[`iP0S0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3j
l>H0JP3jl>H10?ooo`00_@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V01<0n_3V
00<000000?[`iP3jl>H08`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V06X0n_3V
0@3oool00;`0n_3V00<0cHDo0?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003j
l>H0n_3V02<0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002k
0?[`iP030<f5?`3jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0R
0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00^P3jl>H00`3=
QCl0n_3V0?[`iP0l0?[`iP030000003jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H08P3jl>H00`3=
QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00;T0n_3V00<0cHDo0?[`iP3j
l>H0?@3jl>H00`000000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V02<0n_3V0P3=QCm<0?[`iP03
0000003jl>H0n_3V06X0n_3V0@3oool00;P0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V
0?[`iP0G0?[`iP030000003jl>H0n_3V02<0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V
0?[`iP1Z0?[`iP40oooo002h0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0603j
l>H00`000000n_3V0?[`iP0S0?[`iP030<f5?`3jl>H0n_3V04T0n_3V00<000000?[`iP3jl>H0JP3j
l>H10?ooo`00]`3jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V01T0n_3V00<00000
0?[`iP3jl>H08`3jl>H00`3=QCl0n_3V0?[`iP180?[`iP030000003jl>H0n_3V06X0n_3V0@3oool0
0;H0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V
0280n_3V00<0cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002f0?[`iP03
0<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP0R0?[`iP03
0<f5?`3jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00]@3jl>H00`3=QCl0n_3V
0?[`iP110?[`iP030000003jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H08P3jl>H00`3=QCl0n_3V
0?[`iP160?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00;@0n_3V00<0cHDo0?[`iP3jl>H0@P3j
l>H00`000000n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V02<0n_3V00<0cHDo0?[`iP3jl>H0A@3j
l>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002c0?[`iP030<f5?`3jl>H0n_3V04<0n_3V00<00000
0?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP0S0?[`iP030<f5?`3jl>H0n_3V04@0n_3V00<00000
0?[`iP3jl>H0JP3jl>H10?ooo`00/P3jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V
01h0n_3V00<000000?[`iP3jl>H08P3jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V
06X0n_3V0@3oool00;80n_3V00<0cHDo0?[`iP3jl>H0A03jl>H00`000000n_3V0?[`iP0O0?[`iP03
0000003jl>H0n_3V0280n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP1Z0?[`iP40
oooo002a0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0803jl>H00`000000n_3V
0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V04<0n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00/@3j
l>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H08@3j
l>H00`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00;00n_3V00<0cHDo
0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V0200n_3V00<0cHDo
0?[`iP3jl>H0@P3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002`0?[`iP030<f5?`3jl>H0n_3V
04H0n_3V00<000000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP0Q0?[`iP030<f5?`3jl>H0n_3V
0440n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00[`3jl>H00`3=QCl0n_3V0?[`iP170?[`iP03
0000003jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H0803jl>H00`3=QCl0n_3V0?[`iP110?[`iP03
0000003jl>H0n_3V06X0n_3V0@3oool00:l0n_3V00<0cHDo0?[`iP3jl>H0A`3jl>H00`000000n_3V
0?[`iP0T0?[`iP030000003jl>H0n_3V0200n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V
0?[`iP1Z0?[`iP40oooo002^0?[`iP030<f5?`3jl>H0n_3V04P0n_3V00<000000?[`iP3jl>H09@3j
l>H00`000000n_3V0?[`iP0P0?[`iP030<f5?`3jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H0JP3j
l>H10?ooo`00[@3jl>H00`3=QCl0n_3V0?[`iP190?[`iP030000003jl>H0n_3V02H0n_3V00<00000
0?[`iP3jl>H07`3jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool0
0:d0n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V
01l0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002/0?[`iP03
0<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP0O0?[`iP03
0<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00[03jl>H00`3=QCl0n_3V
0?[`iP1:0?[`iP030000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H07`3jl>H00`3=QCl0n_3V
0?[`iP0m0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00080003oZP3jl>H00`3=QCl0n_3V0?[`
iP1:0?[`iP030000003jl>H0n_3V02T0n_3V00<000000?[`iP3jl>H07P3jl>H00`3=QCl0n_3V0?[`
iP0m0?[`iP030000003jl>H0n_3V06L0n_3V0P000?l10?[`iP40oooo00020?[`iP<0003oY`3jl>H0
0`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H07@3jl>H0
0`3=QCl0n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V06@0n_3V0`000?l30?[`iP40oooo00050?[`
iP@0003oXP3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V02/0n_3V00<000000?[`
iP3jl>H0703jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V0600n_3V10000?l60?[`
iP40oooo00090?[`iP<0003oW`3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V02`0
n_3V00<000000?[`iP3jl>H0703jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP030000003jl>H0n_3V05d0
n_3V0`000?l:0?[`iP40oooo000<0?[`iP<0003oV`3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000
003jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H06`3jl>H00`3=QCl0n_3V0?[`iP0l0?[`iP030000
003jl>H0n_3V05X0n_3V0`000?l=0?[`iP40oooo000?0?[`iP@0003oU`3jl>H00`3=QCl0n_3V0?[`
iP1<0?[`iP030000003jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H0703jl>H00`3=QCl0n_3V0?[`
iP0k0?[`iP030000003jl>H0n_3V05H0n_3V10000?l@0?[`iP40oooo000C0?[`iP<0003oU03jl>H0
0`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V02h0n_3V00<000000?[`iP3jl>H06`3jl>H0
0`3=QCl0n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V05<0n_3V0`000?lD0?[`iP40oooo000F0?[`
iP<0003oT@3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V02l0n_3V00<000000?[`
iP3jl>H06P3jl>H00`3=QCl0n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V0500n_3V0`000?lG0?[`
iP40oooo000I0?[`iP<0003oS@3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V0300
n_3V00<000000?[`iP3jl>H06@3jl>H00`3=QCl0n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V04d0
n_3V0`000?lJ0?[`iP40oooo000L0?[`iP<0003oRP3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000
003jl>H0n_3V0340n_3V00<000000?[`iP3jl>H06@3jl>H00`3=QCl0n_3V0?[`iP0j0?[`iP030000
003jl>H0n_3V04X0n_3V0`000?lM0?[`iP40oooo000O0?[`iP@0003oQP3jl>H00`3=QCl0n_3V0?[`
iP1=0?[`iP030000003jl>H0n_3V0380n_3V00<000000?[`iP3jl>H0603jl>H00`3=QCl0n_3V0?[`
iP0j0?[`iP030000003jl>H0n_3V04L0n_3V0`000?lP0?[`iP40oooo000S0?[`iP<0003oP`3jl>H0
0`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V03<0n_3V00<000000?[`iP3jl>H05`3jl>H0
0`3=QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V04@0n_3V0`000?lS0?[`iP40oooo000V0?[`
iP<0003oO`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V03<0n_3V00<000000?[`
iP3jl>H05`3jl>H00`3=QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V0440n_3V0`000?lV0?[`
iP40oooo000Y0?[`iP<0003oO03jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V03@0
n_3V00<000000?[`iP3jl>H05`3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V03h0
n_3V0`000?lY0?[`iP40oooo000/0?[`iP80003oNP3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000
003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H05P3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000
003jl>H0n_3V03`0n_3V0P000?l/0?[`iP40oooo000^0?[`iP80003oN03jl>H00`3=QCl0n_3V0?[`
iP1>0?[`iP030000003jl>H0n_3V03H0n_3V00<000000?[`iP3jl>H05@3jl>H00`3=QCl0n_3V0?[`
iP0i0?[`iP030000003jl>H0n_3V03X0n_3V0P000?l^0?[`iP40oooo000`0?[`iP<0003oM03jl>H0
0`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V03L0n_3V00<000000?[`iP3jl>H0503jl>H0
0`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V03L0n_3V0`000?l`0?[`iP40oooo000c0?[`
iP80003oLP3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V03P0n_3V00<000000?[`
iP3jl>H0503jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V03D0n_3V0P000?lc0?[`
iP40oooo000e0?[`iP80003oL03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V03P0
n_3V00<000000?[`iP3jl>H0503jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V03<0
n_3V0P000?le0?[`iP40oooo000g0?[`iP<0003oK@3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000
003jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H04`3jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP030000
003jl>H0n_3V0300n_3V0`000?lg0?[`iP40oooo000j0?[`iP80003oJ`3jl>H00`3=QCl0n_3V0?[`
iP1?0?[`iP030000003jl>H0n_3V03X0n_3V00<000000?[`iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`
iP0h0?[`iP030000003jl>H0n_3V02h0n_3V0P000?lj0?[`iP40oooo000l0?[`iP80003oJ@3jl>H0
0`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H04@3jl>H0
0`3=QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V02`0n_3V0P000?ll0?[`iP40oooo000n0?[`
iP<0003oI@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V03`0n_3V00<000000?[`
iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V02T0n_3V0`000?ln0?[`
iP40oooo00110?[`iP80003oH`3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V03d0
n_3V00<000000?[`iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V02L0
n_3V0P000?m10?[`iP40oooo00130?[`iP80003oH@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000
003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H03`3jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000
003jl>H0n_3V02D0n_3V0P000?m30?[`iP40oooo00150?[`iP80003oG`3jl>H00`3=QCl0n_3V0?[`
iP1@0?[`iP030000003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H03`3jl>H00`3=QCl0n_3V0?[`
iP0g0?[`iP030000003jl>H0n_3V02<0n_3V0P000?m50?[`iP40oooo00170?[`iP80003oG@3jl>H0
0`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H03P3jl>H0
0`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V0240n_3V0P000?m70?[`iP40oooo00190?[`
iP<0003oFP3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0400n_3V00<000000?[`
iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V01l0n_3V0P000?m90?[`
iP40oooo001<0?[`iP80003oF03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0440
n_3V00<000000?[`iP3jl>H0303jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V01d0
n_3V0P000?m;0?[`iP40oooo001>0?[`iP80003oEP3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP<00000
@`3jl>H00`000000n_3V0?[`iP0;0?[`iP030<f5?`3jl>H0n_3V03L0n_3V00<000000?[`iP3jl>H0
6`3jl>H20000odd0n_3V0@3oool00500n_3V0P000?mD0?[`iP030<f5?`3jl>H0n_3V04h0n_3V1@00
00130?[`iP030000003jl>H0n_3V00X0n_3V00<0cHDo0?[`iP3jl>H0=`3jl>H00`000000n_3V0?[`
iP0I0?[`iP80003oC`3jl>H10?ooo`00DP3jl>H20000oe80n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H5
000004<0n_3V00<000000?[`iP3jl>H02P3jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0
n_3V01L0n_3V0P000?mA0?[`iP40oooo001D0?[`iP80003oD03jl>H00`3=QCl0n_3V0?[`iP1>0?[`
iPD00000A03jl>H00`000000n_3V0?[`iP090?[`iP030<f5?`3jl>H0n_3V03L0n_3V00<000000?[`
iP3jl>H05@3jl>H20000oe<0n_3V0@3oool005H0n_3V0P000?m>0?[`iP030<f5?`3jl>H0n_3V04l0
n_3V0`0000160?[`iP030000003jl>H0n_3V00P0n_3V00<0cHDo0?[`iP3jl>H0=`3jl>H00`000000
n_3V0?[`iP0C0?[`iP80003oE@3jl>H10?ooo`00F03jl>H20000od`0n_3V00<0cHDo0?[`iP3jl>H0
D03jl>H00`000000n_3V0?[`iP160?[`iP030000003jl>H0n_3V00L0n_3V00<0cHDo0?[`iP3jl>H0
=`3jl>H00`000000n_3V0?[`iP0A0?[`iP80003oE`3jl>H10?ooo`00FP3jl>H00`000?l0n_3V0?[`
iP190?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`
iP060?[`iP030<f5?`3jl>H0n_3V03L0n_3V00<000000?[`iP3jl>H03`3jl>H20000oeT0n_3V0@3o
ool005/0n_3V0P000?m90?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0B03jl>H0
0`000000n_3V0?[`iP050?[`iP030<f5?`3jl>H0n_3V03L0n_3V00<000000?[`iP3jl>H03@3jl>H2
0000oe/0n_3V0@3oool005d0n_3V0P000?m70?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`
iP3jl>H0B@3jl>H00`000000n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V03L0n_3V00<000000?[`
iP3jl>H02`3jl>H20000oed0n_3V0@3oool005l0n_3V0P000?m50?[`iP030<f5?`3jl>H0n_3V0500
n_3V00<000000?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V03L0
n_3V00<000000?[`iP3jl>H02@3jl>H20000oel0n_3V0@3oool00640n_3V00<0003o0?[`iP3jl>H0
@P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0
0`3jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V00L0n_3V0P000?mQ0?[`iP40oooo
001R0?[`iP80003o@P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V04/0n_3V00<0
00000?[`iP3jl>H00P3jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V00D0n_3V0P00
0?mS0?[`iP40oooo001T0?[`iP80003o@03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0
n_3V04`0n_3V00@000000?[`iP3jl>H0cHDo>P3jl>H00`000000n_3V0?[`iP030?[`iP80003oI@3j
l>H10?ooo`00IP3jl>H20000ocl0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1=
0?[`iP030000003jl>H0cHDo03X0n_3V00@000000?[`iP3jl>H0n_3V0P000?mW0?[`iP40oooo001X
0?[`iP030000o`3jl>H0n_3V03`0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1>
0?[`iP<00000>03jl>H3000000030?[`iP000?l0n_3V06P0n_3V0@3oool006T0n_3V0P000?ll0?[`
iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C@3jl>H5000003H0n_3V1@00001Z0?[`
iP40oooo001[0?[`iP80003o>P3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04d0
n_3V@000001Z0?[`iP40oooo001]0?[`iP030000o`3jl>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H0
C`3jl>H00`000000n_3V0?[`iP1=0?[`iPD00000=P3jl>H5000006X0n_3V0@3oool006h0n_3V0P00
0?lg0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0CP3jl>H4000003@0n_3V0P00
0?l0103jl>H0000000000000001[0?[`iP40oooo001`0?[`iP80003o=P3jl>H00`3=QCl0n_3V0?[`
iP1>0?[`iP030000003jl>H0n_3V04h0n_3V00D0cHDo0?[`iP3jl>H0n_3V0000000b0?[`iP030000
o`3jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00LP3jl>H00`000?l0n_3V0?[`
iP0c0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`
iP020?[`iP030000003jl>H0n_3V02d0n_3V0P000?l50?[`iP030000003jl>H0n_3V06X0n_3V0@3o
ool007<0n_3V0P000?lc0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H0
0`3=QCl0n_3V0?[`iP030?[`iP030000003jl>H0n_3V02/0n_3V00<0003o0?[`iP3jl>H01@3jl>H0
0`000000n_3V0?[`iP1Z0?[`iP40oooo001e0?[`iP80003o<@3jl>H00`3=QCl0n_3V0?[`iP1>0?[`
iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0Y0?[`
iP80003o203jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo001g0?[`iP030000o`3jl>H0n_3V02l0
n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V00D0
n_3V00<000000?[`iP3jl>H09P3jl>H20000o`X0n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00
N03jl>H20000obl0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5
?`3jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0903jl>H00`000?l0n_3V0?[`iP0:0?[`iP030000
003jl>H0n_3V06X0n_3V0@3oool007X0n_3V0P000?l]0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<0
00000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0240n_3V0P00
0?l=0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool007`0n_3V00<0003o0?[`iP3jl>H0:P3jl>H0
0`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H02@3jl>H0
0`000000n_3V0?[`iP0O0?[`iP030000o`3jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H0JP3jl>H1
0?ooo`00O@3jl>H20000ob/0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP1<0?[`
iP030<f5?`3jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0703jl>H20000oa00n_3V00<000000?[`
iP3jl>H0JP3jl>H10?ooo`00O`3jl>H20000obT0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000
n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H06@3jl>H20000oa80
n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00P@3jl>H00`000?l0n_3V0?[`iP0V0?[`iP030<f5
?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0;0?[`iP030000
003jl>H0n_3V01P0n_3V00<0003o0?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo
00220?[`iP80003o9P3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04/0n_3V00<0
cHDo0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0E0?[`iP80003o5@3jl>H00`000000n_3V0?[`
iP1Z0?[`iP40oooo00240?[`iP80003o9@3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0
n_3V04/0n_3V00<0cHDo0?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0C0?[`iP030000o`3jl>H0
n_3V01D0n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00QP3jl>H00`000?l0n_3V0?[`iP0R0?[`
iP030<f5?`3jl>H0n_3V04/0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0@0?[`
iP030000003jl>H0n_3V0100n_3V0P000?lH0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool008L0
n_3V0P000?lS0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0
n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00d0n_3V0P000?lJ0?[`iP030000003jl>H0n_3V06X0
n_3V0@3oool008T0n_3V0P000?lQ0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0
BP3jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V00/0n_3V00<0003o0?[`iP3jl>H0
6P3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002;0?[`iP80003o7`3jl>H00`3=QCl0n_3V0?[`
iP1:0?[`iP030000003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H00`000000n_3V0?[`
iP080?[`iP80003o7@3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002=0?[`iP030000o`3jl>H0
n_3V01`0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0
n_3V01@0n_3V00<000000?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP0M0?[`iP030000003jl>H0
n_3V06X0n_3V0@3oool008h0n_3V0P000?lM0?[`iP030<f5?`3jl>H0n_3V04T0n_3V00<000000?[`
iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V00@0n_3V0P000?lP0?[`
iP030000003jl>H0n_3V06X0n_3V0@3oool00900n_3V0P000?lL0?[`iP030<f5?`3jl>H0n_3V04P0
n_3V00<000000?[`iP3jl>H0B03jl>H00`3=QCl0n_3V0?[`iP0G0?[`iP040000003jl>H0n_3V0?[`
iP80003o8P3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002B0?[`iP030000o`3jl>H0n_3V01T0
n_3V00<0cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP170?[`iP030<f5?`3jl>H0n_3V01T0
n_3V00<000000?[`iP000?l0903jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002C0?[`iP80003o
6P3jl>H00`3=QCl0n_3V0?[`iP170?[`iP030000003jl>H0n_3V04L0n_3V00<0cHDo0?[`iP3jl>H0
6@3jl>H00`000?l000000?[`iP0T0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool009D0n_3V00<0
003o0?[`iP3jl>H05`3jl>H00`3=QCl0n_3V0?[`iP170?[`iP030000003jl>H0n_3V04H0n_3V00<0
cHDo0?[`iP3jl>H06@3jl>H010000?l0n_3V0?[`iP00000T0?[`iP030000003jl>H0n_3V06X0n_3V
0@3oool009H0n_3V0P000?lH0?[`iP030<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H0AP3j
l>H00`3=QCl0n_3V0?[`iP0G0?[`iP80003o0`3jl>H00`000000n_3V0?[`iP0R0?[`iP030000003j
l>H0n_3V06X0n_3V0@3oool009P0n_3V00<0003o0?[`iP3jl>H05@3jl>H00`3=QCl0n_3V0?[`iP16
0?[`iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H05`3jl>H00`000?l0n_3V0?[`iP04
0?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00V@3jl>H20000
oaH0n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V
01D0n_3V0P000?l80?[`iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0JP3jl>H10?oo
o`00V`3jl>H00`000?l0n_3V0?[`iP0C0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3j
l>H0A03jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP030000o`3jl>H0n_3V00T0n_3V00<000000?[`iP3j
l>H07`3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002L0?[`iP80003o503jl>H00`3=QCl0n_3V
0?[`iP140?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H20000o`d0n_3V
00<000000?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002N0?[`iP030000o`3j
l>H0n_3V0180n_3V00<0cHDo0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP130?[`iP030<f5?`3j
l>H0n_3V01<0n_3V00<0003o0?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0M0?[`iP030000003j
l>H0n_3V06X0n_3V0@3oool009l0n_3V0P000?lB0?[`iP030<f5?`3jl>H0n_3V04<0n_3V00<00000
0?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP80003o4P3jl>H00`000000n_3V0?[`iP0L
0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00:40n_3V00<0003o0?[`iP3jl>H0403jl>H00`3=
QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H04@3jl>H00`00
0?l0n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H0JP3jl>H10?oo
o`00XP3jl>H20000oa40n_3V00<0cHDo0?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP110?[`iP03
0<f5?`3jl>H0n_3V0100n_3V0P000?lF0?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3j
l>H0JP3jl>H10?ooo`00Y03jl>H00`000?l0n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V0400n_3V
00<000000?[`iP3jl>H0@03jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP030000o`3jl>H0n_3V01L0n_3V
00<000000?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002U0?[`iP80003o3`3j
l>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H03`3j
l>H20000oa/0n_3V00<000000?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002W
0?[`iP030000o`3jl>H0n_3V00d0n_3V00<0cHDo0?[`iP3jl>H0?`3jl>H00`000000n_3V0?[`iP0o
0?[`iP030<f5?`3jl>H0n_3V00h0n_3V00<0003o0?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP0H
0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00:P0n_3V0P000?l>0?[`iP030<f5?`3jl>H0n_3V
03h0n_3V00<000000?[`iP3jl>H0?P3jl>H00`3=QCl0n_3V0?[`iP0=0?[`iP80003o803jl>H00`00
0000n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00:X0n_3V0P000?l<0?[`iP03
0<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3=QCl0n_3V0?[`iP0<0?[`iP80
003o8`3jl>H00`000000n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00:`0n_3V
00<0003o0?[`iP3jl>H02P3jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V03d0n_3V
00<0cHDo0?[`iP3jl>H02P3jl>H20000obD0n_3V00<000000?[`iP3jl>H05P3jl>H00`000000n_3V
0?[`iP1Z0?[`iP40oooo002]0?[`iP80003o2`3jl>H20<f5?cd0n_3V00<000000?[`iP3jl>H0>`3j
l>H20<f5?``0n_3V00<0003o0?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003j
l>H0n_3V06X0n_3V0@3oool00:l0n_3V0P000?l:0?[`iP030<f5?`3jl>H0n_3V03/0n_3V00<00000
0?[`iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`iP0:0?[`iP80003o:P3jl>H00`000000n_3V0?[`iP0D
0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00;40n_3V00<0003o0?[`iP3jl>H0203jl>H00`3=
QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H0203jl>H20000
obd0n_3V00<000000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002b0?[`iP80
003o2@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V03T0n_3V00<0cHDo0?[`iP3j
l>H01`3jl>H20000oc00n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP1Z0?[`iP40
oooo002d0?[`iP80003o203jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V03P0n_3V
00<0cHDo0?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP0a0?[`iP030000003jl>H0n_3V0140n_3V
00<000000?[`iP3jl>H0JP3jl>H10?ooo`00]P3jl>H00`000?l0n_3V0?[`iP060?[`iP030<f5?`3j
l>H0n_3V03L0n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V0?[`iP060?[`iP80003o=03j
l>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00;L0n_3V0P000?l7
0?[`iP80cHDo=`3jl>H00`000000n_3V0?[`iP0e0?[`iP80cHDo1`3jl>H20000ocL0n_3V00<00000
0?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002i0?[`iP80003o1P3jl>H00`3=
QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V03@0n_3V00<0cHDo0?[`iP3jl>H01@3jl>H20000
ocX0n_3V00<000000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP1Z0?[`iP40oooo002k0?[`iP03
0000o`3jl>H0n_3V00@0n_3V00<0cHDo0?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP0d0?[`iP03
0<f5?`3jl>H0n_3V00@0n_3V00<0003o0?[`iP3jl>H0>`3jl>H00`000000n_3V0?[`iP0>0?[`iP03
0000003jl>H0n_3V06X0n_3V0@3oool00;`0n_3V0P000?l50?[`iP80cHDo=03jl>H00`000000n_3V
0?[`iP0b0?[`iP80cHDo1@3jl>H20000ocl0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V
0?[`iP1Z0?[`iP40oooo002n0?[`iP80003o1@3jl>H00`3=QCl0n_3V0?[`iP0a0?[`iP030000003j
l>H0n_3V0340n_3V00<0cHDo0?[`iP3jl>H00`3jl>H20000od80n_3V00<000000?[`iP3jl>H0303j
l>H00`000000n_3V0?[`iP1Z0?[`iP40oooo00300?[`iP030000o`3jl>H0n_3V00<0n_3V00<0cHDo
0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0`0?[`iP030<f5?`3jl>H0n_3V0080n_3V0P000?m5
0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00`@3jl>H20000
o`@0n_3V00<0cHDo0?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0_0?[`iP040<f5?`3jl>H0n_3V
0?[`iP80003oA`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V06X0n_3V0@3oool0
0<<0n_3V0P000?l30?[`iP80cHDo;`3jl>H00`000000n_3V0?[`iP0]0?[`iP80cHDo0`3jl>H00`00
0?l0n_3V0?[`iP180?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0JP3jl>H10?oo
o`00a@3jl>H20000o`<0n_3V00<0cHDo0?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0/0?[`iP04
0<f5?`3jl>H0n_3V0?[`iP80003oC03jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V
06X0n_3V0@3oool00<L0n_3V0P000?l20?[`iP80cHDo;03jl>H00`000000n_3V0?[`iP0Z0?[`iP80
cHDo0P3jl>H20000odl0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP1Z0?[`iP40
oooo00390?[`iP80003o0P3jl>H20<f5?bX0n_3V00<000000?[`iP3jl>H0:03jl>H20<f5?`80n_3V
0P000?mB0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00b`3j
l>H20000o`80n_3V00<0cHDo0?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP0W0?[`iP030<f5?`3j
l>H0n_3V0080003oE@3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V06X0n_3V0@3o
ool00<d0n_3V0P000?l00`3jl>H0cHDo0<f5?`0W0?[`iP030000003jl>H0n_3V02D0n_3V0P3=QCl0
0`3jl>H0003o0000o`1H0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0JP3jl>H1
0?ooo`00c`3jl>H30000o`80cHDo9@3jl>H00`000000n_3V0?[`iP0S0?[`iP80cHDo00<0n_3V0000
o`000?l0FP3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00=80
n_3V0`000?l00`3=QCl0n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V0240n_3V0P3=QCl00`3jl>H0
003o0000o`1M0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0JP3jl>H10?ooo`00
e@3jl>H20000o`030<f5?`3jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H07`3jl>H20<f5?`<0003o
H03jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V06X0n_3V0@3oool00=L0n_3V0`00
0?lO0?[`iP030000003jl>H0n_3V01d0n_3V0P3=QCl20000of@0n_3V00<000000?[`iP3jl>H00P3j
l>H00`000000n_3V0?[`iP1Z0?[`iP40oooo003J0?[`iP<0003o00<0cHDo0?[`iP3jl>H06@3jl>H0
0`000000n_3V0?[`iP0I0?[`iP<0cHDo0`000?mW0?[`iP050000003jl>H0n_3V0?[`iP000000K03j
l>H10?ooo`00g@3jl>H30000oaT0n_3V00<000000?[`iP3jl>H05`3jl>H00`3=QCl0003o0000o`02
0000of/0n_3V00@000000?[`iP3jl>H00000K03jl>H10?ooo`00h03jl>H40000oaD0n_3V00<00000
0?[`iP3jl>H04`3jl>H00`3=QCl0003o0000o`020000ofl0n_3V00@000000?[`iP3jl>H00000K03j
l>H10?ooo`00i03jl>H40000oa40n_3V00<000000?[`iP3jl>H03`3jl>H00`3=QCl0003o0000o`02
0000og@0n_3V1000001[0?[`iP40oooo003X0?[`iP@0003o3@3jl>H00`000000n_3V0?[`iP0;0?[`
iPD0003oN03jl>H5000006X0n_3V0@3oool00>`0cHDo3@000?l00`000000003o0000o`0;0000ogd0
cHDo1@00001Y0<f5?`40n_3V0@3oool00?l0n_3VQ@3jl>H5000006X0n_3V0@3oool00?l0n_3VQP3j
l>H3000006/0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00]P3j
l>H20000000306IRGP3<a;/0n_3V02/0n_3V00H0e<c306IRGP000000000008V4OP3Tfm9U0?[`iP06
0=C<``1VHUh0000000000029Q7h0i=_BW03jl>H10?ooo`00^03jl>H00`1VHUh000000=cDb`0[0?[`
iP0604a9A@33^k<0n_3V0>cRf@000000RHAnI@3jl>H01P1<BDD0`k^c0?[`iP3/h]T0000008V4OY`0
n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V00@0[jRQ04a9A@000000
RHAn1`3jl>H01P3Le</0NGE`000000000000RHAn0<c4^`80n_3V00@0[jRQ04a9A@000000RHAn0P3j
l>H200000080n_3V0P0000001@3jl>H0c<Bk0000001iMG00n_3V008000000P3jl>H20000000306IR
GP3jl>H0n_3V00L0n_3V0P0000030?[`iP040<c4^`1<BDD0IV9N0>CKdP80000000<0n_3V00000000
00000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P0000020?[`
iP0308V4OP1VHUh0c<Bk008000001`3jl>H01@3Le</0NGE`0000001<BDD0Y9fF0080n_3V00@0c<Bk
04a9A@1VHUh0i=_B0P0000000`3jl>H00000000000040?[`iP030:BMUP000000Y9fF00<0n_3V00@0
[jRQ04a9A@000000RHAn1`3jl>H0102_Z:40C4U504a9A@2_Z:420?[`iP8000001P3jl>H200000005
0?[`iP33^k<000000<>k/`3jl>H00P0000001@3jl>H0c<Bk04a9A@1<BDD0[jRQ0080000000<0n_3V
0000000000000`3jl>H2000000050?[`iP3<a;/0C4U504a9A@2_Z:400P0000040?[`iP80000000<0
k>;I0?[`iP3/h]T00P0000020?[`iP0308V4OP1VHUh0c<Bk0080000000<0n_3V0000000000000P3j
l>H200000080n_3V00@0[jRQ04a9A@000000RHAn0P3jl>H01`3/h]T0Ui6;000000000000NGE`0>CK
dP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000001`3jl>H0
[jRQ00000033^k<0i=_B00000029Q7h01@3jl>H01@3Tfm80000009NAR`3jl>H0^K:Z0080000000P0
n_3V0:nXX@000000`k^c0>CKdP000000RHAn0?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H0c<Bk00000002000000030>CKdP3jl>H0n_3V00H0n_3V0P0000030?[`
iP0406IRGP000000i=_B0;VbZP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000
103jl>H000000000003jl>H200000080n_3V0P0000001@3jl>H0Y9fF00000033^k<0Y9fF00800000
1P3jl>H0303Tfm80000009NAR`3jl>H0e<c300000029Q7h0n_3V06IRGP000000i=_B0;VbZP800000
00<0n_3V000000000000103jl>H3000000080>cRf@3jl>H0[jRQ00000033^k<0i=_B00000029Q7h5
0?[`iP070;VbZP000000`k^c0<>k/`000000^K:Z0?[`iP02000000H0n_3V0P0000001@3jl>H0Ui6;
0000002GTH/0n_3V0080000000D0n_3V04a9A@000000i=_B0<>k/`02000000030?[`iP0000000000
00<0n_3V0P0000001@3jl>H0C4U50000003Tfm80`k^c00800000103jl>H03029Q7h000000=C<``3j
l>H0e<c300000029Q7h0n_3V0:BMUP000000`k^c0:BMUP80000000<0n_3V0000000000000P3jl>H2
0000000?0?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP3jl>H0NGE`0000003Tfm80k>;I0000001V
HUh0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V
04a9A@0000002@3jl>H00`2GTH/000000=cDb`020?[`iP80000000<0n_3V04a9A@0000001@3jl>H2
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000H0n_3V09NAR`000000RHAn0000
002_Z:480?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP800000
0P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000030?[`iP1<BDD000000080
n_3V0P0000060?[`iP0309NAR`000000i=_B00D0n_3V0P0000020?[`iP80000000<0n_3V00000000
00000`3jl>H0202i/ZX0000008V4OP000000^K:Z0?[`iP1<BDD000002@3jl>H01`1VHUh000000?[`
iP3jl>H0000006IRGP3jl>H00P0000060?[`iP80000000D0n_3V04a9A@000000C4U50?[`iP020000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000030?[`iP80000000<0n_3V0000
000000000P3jl>H2000000@0n_3V00<0[jRQ0000000000000`000000102_Z:40n_3V04a9A@000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP1<BDD0000000L0n_3V00D0e<c3
0:BMUP000000C4U50?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2
000000030?[`iP000000000000@000001@3jl>H00`1<BDD000000?[`iP020?[`iP80000000<0n_3V
000000000000100000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2
000000060?[`iP1<BDD000000>cRf@000000IV9N203jl>H2000000<0n_3V0P0000020?[`iP800000
00<0n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080
n_3V0P0000000`3jl>H00000000000020?[`iP8000001P3jl>H2000000H0n_3V0P0000020?[`iP80
000000<0n_3V0000000000000`3jl>H204a9A@040>cRf@1<BDD0C4U50?[`iPH000001@3jl>H20000
0080n_3V0P0000000`3jl>H00000000000060?[`iP80000000D0i=_B0000002GTH/000000>CKdP02
000000050?[`iP3<a;/0000009NAR`3Tfm800P0000000`3jl>H00000000000030?[`iP80000000D0
n_3V0<c4^`000000Ui6;0>CKdP02000000@0n_3V00P0e<c300000029Q7h0n_3V09NAR`000000e<c3
0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0000000000004
000000030?[`iP3<a;/0C4U50080000000<0C4U50<c4^`3jl>H00P0000240?[`iP40oooo00230?[`
iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP030000001VHUh0n_3V
00@0n_3V0P0000020?[`iP<0000000<0n_3V04a9A@0000000P3jl>H00`000000IV9N0?[`iP020000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000L0g=C;00000029Q7h0n_3V08V4OP00
0000i=_B00L0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V0P00
00020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V04a9A@000000
0P3jl>H2000000H0n_3V0P0000060?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V
00T0c<Bk0000002TWIH0n_3V0:BMUP000000c<Bk04a9A@0000000P3jl>H00`000000IV9N0?[`iP04
0?[`iP0706IRGP000000n_3V0?[`iP000000IV9N0?[`iP02000000H0n_3V0P0000001@3<a;/00000
0=cDb`000000c<Bk008000000P3jl>H00`3Le</0[jRQ07UeL002000000030?[`iP000000000000<0
n_3V0P0000020?[`iP030=cDb`2_Z:40NGE`008000001@3jl>H01@000000C4U50?[`iP1<BDD00000
0080n_3V00@0C4U50000003jl>H0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
04a9A@0000000P3jl>H01`000000IV9N0?[`iP1<BDD0000007UeL03<a;/00`3jl>H2000008@0n_3V
0@3oool008<0n_3V0P0000030?[`iP80000000/0Y9fF0>CKdP000000IV9N0?[`iP2i/ZX000000<>k
/`3<a;/000000;VbZP050?[`iP0304a9A@000000n_3V00D0n_3V00L0^K:Z00000033^k<0c<Bk0000
002i/ZX0n_3V0080000000D0^K:Z0>CKdP000000C4U50?[`iP0200000080n_3V0P0000001`2_Z:40
00000<>k/`3jl>H0`k^c0000002_Z:401`3jl>H2000000<0n_3V0P0000020?[`iP80000000@0n_3V
000000000000e<c30P3jl>H2000000050;VbZP3Tfm80000004a9A@3jl>H00P000000303jl>H00000
0000002i/ZX0i=_B0000001<BDD0n_3V0:BMUP000000`k^c0:BMUP8000001P3jl>H00`1<BDD00000
0?[`iP050?[`iP8000000P3jl>H20000000B0?[`iP00000000000=C<``3jl>H0IV9N0000003/h]T0
n_3V0>cRf@000000IV9N0;VbZP000000`k^c0<c4^`000000^K:Z1@3jl>H01`2i/ZX000000<>k/`33
^k<000000;VbZP3jl>H00P0000060?[`iP80000000D0Y9fF06IRGP3jl>H0IV9N0:BMUP0200000008
0?[`iP1iMG00e<c30?[`iP3Tfm80000004a9A@3jl>H2000000030=C<``3jl>H0n_3V0080000000L0
n_3V07UeL03Dc<<0n_3V0>CKdP000000C4U500D0n_3V00D0NGE`0000003<a;/0000006IRGP020?[`
iP040:BMUP000000`k^c0:BMUP80000001H0n_3V000000000000^K:Z0>CKdP000000C4U50?[`iP2i
/ZX000000<>k/`3<a;/000000;VbZP3jl>H0IV9N0000003jl>H0i=_B0000001iMG00n_3V0P000024
0?[`iP40oooo00230?[`iP8000000`3jl>H2000000040=cDb`29Q7h0C4U50<c4^`80n_3V00@0[jRQ
000000000000[jRQ1P3jl>H00`2GTH/000000>CKdP060?[`iP040:nXX@00000000000:nXX@80n_3V
0P000000103<a;/0NGE`04a9A@3<a;/40000000:0?[`iP000000000006IRGP000000k>;I0?[`iP3/
h]T0000006IRGPL0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP000000000008V4OP1i
MG00n_3V0P0000001@3<a;/0NGE`04a9A@3<a;/0n_3V0080000000L0n_3V000000000000c<Bk07Ue
L01<BDD0c<Bk0080n_3V00<0RHAn06IRGP3<a;/00P0000060?[`iP0309NAR`000000i=_B00D0n_3V
0P0000020?[`iP80000000@0n_3V000000000000RHAn0P0000002029Q7h0n_3V0?[`iP3jl>H0RHAn
0000003Le</0[jRQ0P0000000`2_Z:40n_3V0?[`iP050?[`iP050:nXX@1<BDD000000:nXX@3jl>H0
100000050?[`iP80000000D0IV9N0:BMUP3jl>H0Ui6;06IRGP02000000030?[`iP3Tfm80RHAn0080
000000<0IV9N0=C<``3jl>H00P0000000`29Q7h0NGE`0?[`iP02000000030?[`iP3Tfm80RHAn0080
000000<0IV9N0=C<``3jl>H0103jl>H01@2TWIH0000008V4OP000000Y9fF00<0n_3V00<0RHAn06IR
GP3<a;/00P0000001`3jl>H000000000003<a;/0NGE`04a9A@3<a;/00P3jl>H0102_Z:4000000000
002_Z:420?[`iP070>CKdP1iMG00000000000029Q7h0i=_B0?[`iP02000008@0n_3V0@3oool008<0
n_3V0P0000030?[`iP800000403jl>H01`3Tfm80000009NAR`3jl>H0e<c30000001iMG003`3jl>H2
00000080n_3V0P00000>0?[`iP800000;03jl>H01`3Tfm80000009NAR`3jl>H0e<c300000029Q7h0
9@3jl>H2000000H0n_3V0`0000000`3<a;/0n_3V0<>k/`03000001/0n_3V00D0c<Bk000000000000
00000<>k/`2T0?[`iP40oooo00210?[`iPH0000000<0n_3V0000000000004@3jl>H01P3Le</0NGE`
000000000000Ui6;0>cRf@l0n_3V00@0g=C;08V4OP3jl>H0n_3V0P00000<0?[`iPH00000503jl>H2
000001D0n_3V00D0g=C;07UeL000000000000:BMUP0V0?[`iP040<c4^`1VHUh0000008V4OP@0n_3V
0`0000000`3/h]T0n_3V0=cDb`03000000d0n_3V0P00000<0?[`iP050>cRf@00000000000000003T
fm807P3jl>H2000008@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.82609 .38333 L
s
.82609 .05 m
.82609 .38333 L
s
.66663 .22033 m
.82609 .22033 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.82609 .38333 Mdot
.66663 .22033 Mdot
.82609 .22033 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V2P3=QCl20?[`iP80000000<0n_3V0<f5
?`3=QCl0203=QCnE0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00>L0n_3V1P3=QCl<0?[`iP03
0000003jl>H0000000X0n_3V1`3=QCn>0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00>D0n_3V
0P3=QClB0?[`iP040000003jl>H0n_3V00000100n_3V0P3=QCn<0?[`iP030000003jl>H0n_3V05D0
n_3V0@3oool00>40n_3V103=QClD0?[`iP050000003jl>H0n_3V0?[`iP0000004@3jl>H30<f5?hT0
n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00g@3jl>H40<f5?aP0n_3V00<000000?[`iP3jl>H0
0P3jl>H00`000000n_3V0?[`iP0A0?[`iP@0cHDoQ@3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo
003K0?[`iP80cHDo703jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V01@0n_3V0P3=
QCn30?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00=T0n_3V0P3=QClN0?[`iP030000003jl>H0
n_3V00@0n_3V00<000000?[`iP3jl>H05@3jl>H20<f5?h40n_3V00<000000?[`iP3jl>H0E@3jl>H1
0?ooo`00e`3jl>H20<f5?b00n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0F0?[`
iP80cHDoO`3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo003E0?[`iP80cHDo8P3jl>H00`000000
n_3V0?[`iP060?[`iP030000003jl>H0n_3V01L0n_3V0P3=QCmm0?[`iP030000003jl>H0n_3V05D0
n_3V0@3oool00=<0n_3V0P3=QClT0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0
603jl>H20<f5?g/0n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00d@3jl>H20<f5?bH0n_3V00<0
00000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0I0?[`iP80cHDoN@3jl>H00`000000n_3V0?[`
iP1E0?[`iP40oooo003?0?[`iP80cHDo:03jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0
n_3V01X0n_3V0P3=QCmg0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00<h0n_3V00<0cHDo0?[`
iP3jl>H0:03jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V01/0n_3V00<0cHDo0?[`
iP3jl>H0M03jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo003<0?[`iP80cHDo:`3jl>H00`000000
n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V01/0n_3V0P3=QCmd0?[`iP030000003jl>H0n_3V05D0
n_3V0@3oool00<X0n_3V0P3=QCl]0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0
703jl>H20<f5?g80n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00b@3jl>H00`3=QCl0n_3V0?[`
iP0]0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H07@3jl>H00`3=QCl0n_3V0?[`
iP1_0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00<L0n_3V0P3=QCl`0?[`iP030000003jl>H0
n_3V00h0n_3V00<000000?[`iP3jl>H07@3jl>H20<f5?fl0n_3V00<000000?[`iP3jl>H0E@3jl>H1
0?ooo`00aP3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`
iP3jl>H07P3jl>H00`3=QCl0n_3V0?[`iP1/0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00<D0
n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V01h0
n_3V00<0cHDo0?[`iP3jl>H0J`3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo00340?[`iP030<f5
?`3jl>H0n_3V0380n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0N0?[`iP030<f5
?`3jl>H0n_3V06X0n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00`P3jl>H20<f5?cD0n_3V00<0
00000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0O0?[`iP80cHDoJP3jl>H00`000000n_3V0?[`
iP1E0?[`iP40oooo00310?[`iP030<f5?`3jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H04P3jl>H0
0`000000n_3V0?[`iP0O0?[`iP030<f5?`3jl>H0n_3V06P0n_3V00<000000?[`iP3jl>H0E@3jl>H1
0?ooo`00`03jl>H00`3=QCl0n_3V0?[`iP0f0?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`
iP3jl>H07`3jl>H00`3=QCl0n_3V0?[`iP1W0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00;l0
n_3V00<0cHDo0?[`iP3jl>H0=`3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V01l0
n_3V0P3=QCmW0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00;h0n_3V00<0cHDo0?[`iP3jl>H0
>03jl>H00`000000n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V0200n_3V00<0cHDo0?[`iP3jl>H0
I03jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo002m0?[`iP030<f5?`3jl>H0n_3V03T0n_3V00<0
00000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP0P0?[`iP030<f5?`3jl>H0n_3V06<0n_3V00<0
00000?[`iP3jl>H0E@3jl>H10?ooo`00_03jl>H00`3=QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0
n_3V01L0n_3V00<000000?[`iP3jl>H0803jl>H00`3=QCl0n_3V0?[`iP1R0?[`iP030000003jl>H0
n_3V05D0n_3V0@3oool00;/0n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H00`000000n_3V0?[`iP0H0?[`
iP030000003jl>H0n_3V01l0n_3V00<0cHDo0?[`iP3jl>H0HP3jl>H00`000000n_3V0?[`iP1E0?[`
iP40oooo002j0?[`iP030<f5?`3jl>H0n_3V03`0n_3V00<000000?[`iP3jl>H06@3jl>H00`000000
n_3V0?[`iP0O0?[`iP030<f5?`3jl>H0n_3V0640n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00
^@3jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H0
7`3jl>H20<f5?f40n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00^03jl>H00`3=QCl0n_3V0?[`
iP0n0?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H07`3jl>H00`3=QCl0n_3V0?[`
iP1O0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00;P0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H0
0`000000n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V01l0n_3V00<0cHDo0?[`iP3jl>H0GP3jl>H0
0`000000n_3V0?[`iP1E0?[`iP40oooo002g0?[`iP030<f5?`3jl>H0n_3V03l0n_3V00<000000?[`
iP3jl>H07@3jl>H00`000000n_3V0?[`iP0O0?[`iP030<f5?`3jl>H0n_3V05d0n_3V00<000000?[`
iP3jl>H0E@3jl>H10?ooo`00]P3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V01h0
n_3V00<000000?[`iP3jl>H07P3jl>H00`3=QCl0n_3V0?[`iP1M0?[`iP030000003jl>H0n_3V05D0
n_3V0@3oool00;H0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP0O0?[`iP030000
003jl>H0n_3V01h0n_3V00<0cHDo0?[`iP3jl>H0G03jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo
002e0?[`iP030<f5?`3jl>H0n_3V0440n_3V00<000000?[`iP3jl>H0803jl>H00`000000n_3V0?[`
iP0N0?[`iP030<f5?`3jl>H0n_3V05/0n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00]03jl>H0
0`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H07P3jl>H0
0`3=QCl0n_3V0?[`iP1J0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00;<0n_3V00<0cHDo0?[`
iP3jl>H0@`3jl>H00`000000n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V01h0n_3V00<0cHDo0?[`
iP3jl>H0F@3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo002b0?[`iP030<f5?`3jl>H0n_3V04@0
n_3V00<000000?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP0M0?[`iP030<f5?`3jl>H0n_3V05T0
n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00/P3jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000
003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H07@3jl>H00`3=QCl0n_3V0?[`iP1H0?[`iP030000
003jl>H0n_3V05D0n_3V0@3oool00;40n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`
iP0U0?[`iP030000003jl>H0n_3V01`0n_3V00<0cHDo0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`
iP1E0?[`iP40oooo002a0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H09P3jl>H0
0`000000n_3V0?[`iP0L0?[`iP030<f5?`3jl>H0n_3V05L0n_3V00<000000?[`iP3jl>H0E@3jl>H1
0?ooo`00/03jl>H00`3=QCl0n_3V0?[`iP160?[`iP030000003jl>H0n_3V02L0n_3V00<000000?[`
iP3jl>H06`3jl>H00`3=QCl0n_3V0?[`iP1G0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00;00
n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP0X0?[`iP030000003jl>H0n_3V01/0
n_3V00<0cHDo0?[`iP3jl>H0EP3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo002_0?[`iP030<f5
?`3jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H0:@3jl>H00`000000n_3V0?[`iP0J0?[`iP030<f5
?`3jl>H0n_3V05H0n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00[`3jl>H00`3=QCl0n_3V0?[`
iP170?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H06P3jl>H00`3=QCl0n_3V0?[`
iP1E0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00:h0n_3V00<0cHDo0?[`iP3jl>H0B03jl>H0
0`000000n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V01X0n_3V00<0cHDo0?[`iP3jl>H0E03jl>H0
0`000000n_3V0?[`iP1E0?[`iP40oooo002]0?[`iP030<f5?`3jl>H0n_3V04T0n_3V00<000000?[`
iP3jl>H0;03jl>H00`000000n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V05@0n_3V00<000000?[`
iP3jl>H0E@3jl>H10?ooo`00[@3jl>H00`3=QCl0n_3V0?[`iP190?[`iP030000003jl>H0n_3V02d0
n_3V00<000000?[`iP3jl>H06@3jl>H00`3=QCl0n_3V0?[`iP1C0?[`iP030000003jl>H0n_3V05D0
n_3V0@3oool00:`0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP0^0?[`iP030000
003jl>H0n_3V01P0n_3V00<0cHDo0?[`iP3jl>H0D`3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo
002/0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`
iP0H0?[`iP030<f5?`3jl>H0n_3V0580n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`000P000?nZ
0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0G
0?[`iP030<f5?`3jl>H0n_3V0580n_3V00<000000?[`iP3jl>H0DP3jl>H20000o`40n_3V0@3oool0
0080n_3V0`000?nW0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0<@3jl>H00`00
0000n_3V0?[`iP0F0?[`iP030<f5?`3jl>H0n_3V0580n_3V00<000000?[`iP3jl>H0C`3jl>H30000
o`<0n_3V0@3oool000D0n_3V10000?nR0?[`iP030<f5?`3jl>H0n_3V04/0n_3V00<000000?[`iP3j
l>H0<P3jl>H00`000000n_3V0?[`iP0E0?[`iP030<f5?`3jl>H0n_3V0580n_3V00<000000?[`iP3j
l>H0B`3jl>H40000o`H0n_3V0@3oool000T0n_3V0`000?nO0?[`iP030<f5?`3jl>H0n_3V04/0n_3V
00<000000?[`iP3jl>H0<`3jl>H00`000000n_3V0?[`iP0E0?[`iP030<f5?`3jl>H0n_3V0540n_3V
00<000000?[`iP3jl>H0B03jl>H30000o`X0n_3V0@3oool000`0n_3V0`000?nK0?[`iP030<f5?`3j
l>H0n_3V04`0n_3V00<000000?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP0D0?[`iP030<f5?`3j
l>H0n_3V0540n_3V00<000000?[`iP3jl>H0A@3jl>H30000o`d0n_3V0@3oool000l0n_3V10000?nG
0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP0D
0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0@@3jl>H40000oa00n_3V0@3oool0
01<0n_3V0`000?nD0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0=P3jl>H00`00
0000n_3V0?[`iP0C0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0?P3jl>H30000
oa@0n_3V0@3oool001H0n_3V0`000?nA0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3j
l>H0=`3jl>H00`000000n_3V0?[`iP0B0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3j
l>H0>`3jl>H30000oaL0n_3V0@3oool001T0n_3V0`000?n=0?[`iP030<f5?`3jl>H0n_3V04d0n_3V
00<000000?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP0A0?[`iP030<f5?`3jl>H0n_3V0500n_3V
00<000000?[`iP3jl>H0>03jl>H30000oaX0n_3V0@3oool001`0n_3V0`000?n:0?[`iP030<f5?`3j
l>H0n_3V04d0n_3V00<000000?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP0A0?[`iP030<f5?`3j
l>H0n_3V04l0n_3V00<000000?[`iP3jl>H0=@3jl>H30000oad0n_3V0@3oool001l0n_3V10000?n6
0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP0@
0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0<P3jl>H30000ob00n_3V0@3oool0
02<0n_3V0`000?n30?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0>P3jl>H00`00
0000n_3V0?[`iP0@0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0;`3jl>H30000
ob<0n_3V0@3oool002H0n_3V0`000?mo0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3j
l>H0>`3jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3j
l>H0;03jl>H30000obH0n_3V0@3oool002T0n_3V0`000?ml0?[`iP030<f5?`3jl>H0n_3V04h0n_3V
00<000000?[`iP3jl>H0?03jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V04h0n_3V
00<000000?[`iP3jl>H0:@3jl>H30000obT0n_3V0@3oool002`0n_3V0P000?mj0?[`iP030<f5?`3j
l>H0n_3V04h0n_3V00<000000?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP0>0?[`iP030<f5?`3j
l>H0n_3V04h0n_3V00<000000?[`iP3jl>H09`3jl>H20000ob`0n_3V0@3oool002h0n_3V0P000?mh
0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0=
0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H09@3jl>H20000obh0n_3V0@3oool0
0300n_3V0`000?md0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0?`3jl>H00`00
0000n_3V0?[`iP0<0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H08P3jl>H30000
oc00n_3V0@3oool003<0n_3V0P000?mb0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3j
l>H0@03jl>H00`000000n_3V0?[`iP0<0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3j
l>H0803jl>H20000oc<0n_3V0@3oool003D0n_3V0P000?m`0?[`iP030<f5?`3jl>H0n_3V04l0n_3V
00<000000?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP0;0?[`iP030<f5?`3jl>H0n_3V04d0n_3V
00<000000?[`iP3jl>H07P3jl>H20000ocD0n_3V0@3oool003L0n_3V0`000?m]0?[`iP030<f5?`3j
l>H0n_3V04l0n_3V00<000000?[`iP3jl>H0@P3jl>H00`000000n_3V0?[`iP0:0?[`iP030<f5?`3j
l>H0n_3V04d0n_3V00<000000?[`iP3jl>H06`3jl>H30000ocL0n_3V0@3oool003X0n_3V0P000?m[
0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP09
0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H06@3jl>H20000ocX0n_3V0@3oool0
03`0n_3V0P000?mY0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0A03jl>H00`00
0000n_3V0?[`iP080?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H05`3jl>H20000
oc`0n_3V0@3oool003h0n_3V0`000?mU0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3j
l>H0A@3jl>H00`000000n_3V0?[`iP070?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3j
l>H0503jl>H30000och0n_3V0@3oool00440n_3V0P000?mS0?[`iP030<f5?`3jl>H0n_3V0500n_3V
00<000000?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP070?[`iP030<f5?`3jl>H0n_3V04`0n_3V
00<000000?[`iP3jl>H04P3jl>H20000od40n_3V0@3oool004<0n_3V0P000?mQ0?[`iP030<f5?`3j
l>H0n_3V0500n_3V00<000000?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`iP060?[`iP030<f5?`3j
l>H0n_3V04`0n_3V00<000000?[`iP3jl>H0403jl>H20000od<0n_3V0@3oool004D0n_3V0P000?mO
0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP05
0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H03P3jl>H20000odD0n_3V0@3oool0
04L0n_3V0P000?mM0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0B@3jl>H00`00
0000n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0303jl>H20000
odL0n_3V0@3oool004T0n_3V0`000?mJ0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3j
l>H0BP3jl>H00`000000n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3j
l>H02P3jl>H20000odT0n_3V0@3oool004`0n_3V0P000?mH0?[`iP030<f5?`3jl>H0n_3V0500n_3V
00<000000?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP020?[`iP030<f5?`3jl>H0n_3V04`0n_3V
00<000000?[`iP3jl>H0203jl>H20000od/0n_3V0@3oool004h0n_3V0P000?mF0?[`iP030<f5?`3j
l>H0n_3V04l0n_3V0`00001=0?[`iP050000003jl>H0n_3V0?[`iP3=QCl0CP3jl>H00`000000n_3V
0?[`iP060?[`iP80003oC@3jl>H10?ooo`00D03jl>H20000oe@0n_3V00<0cHDo0?[`iP3jl>H0CP3j
l>H5000004d0n_3V00@000000?[`iP3jl>H0cHDoCP3jl>H00`000000n_3V0?[`iP040?[`iP80003o
C`3jl>H10?ooo`00DP3jl>H20000oe80n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H5000004h0n_3V1000
001<0?[`iP<000000`3jl>H20000oe40n_3V0@3oool005@0n_3V0P000?m@0?[`iP030<f5?`3jl>H0
n_3V04h0n_3V1@00001>0?[`iPD00000BP3jl>H500000080003oD`3jl>H10?ooo`00EP3jl>H20000
odh0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H3000004l0n_3VE000001E0?[`iP40oooo001H0?[`iP80
003oC03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V04h0n_3V1@00001:0?[`iPD0
0000E@3jl>H10?ooo`00FP3jl>H00`000?l0n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V0500n_3V
00<000000?[`iP3jl>H0C`3jl>H4000004T0n_3V0P000?l3000005H0n_3V0@3oool005/0n_3V0P00
0?m90?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H0103=QCl0n_3V0?[`
iP0000160?[`iP80003o0`3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo001M0?[`iP80003oA`3j
l>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00D0cHDo0?[`iP3jl>H0n_3V
000000130?[`iP80003o1@3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo001O0?[`iP80003oA@3j
l>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H00P3j
l>H00`000000n_3V0?[`iP0n0?[`iP80003o1`3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo001Q
0?[`iP030000o`3jl>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@
0?[`iP030<f5?`3jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0>`3jl>H20000o`T0n_3V00<00000
0?[`iP3jl>H0E@3jl>H10?ooo`00HP3jl>H20000od80n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`00
0000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0>03jl>H20000
o`/0n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00I03jl>H20000od00n_3V00<0cHDo0?[`iP3j
l>H0D03jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V00H0n_3V00<000000?[`iP3j
l>H0=@3jl>H20000o`d0n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00IP3jl>H20000ocl0n_3V
00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H0<P3jl>H20000o`l0n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00J03j
l>H00`000?l0n_3V0?[`iP0l0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3j
l>H00`3=QCl0n_3V0?[`iP080?[`iP030000003jl>H0n_3V0300n_3V00<0003o0?[`iP3jl>H03`3j
l>H00`000000n_3V0?[`iP1E0?[`iP40oooo001Y0?[`iP80003o?03jl>H00`3=QCl0n_3V0?[`iP1?
0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0]
0?[`iP80003o4P3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo001[0?[`iP80003o>P3jl>H00`3=
QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H02P3jl>H00`00
0000n_3V0?[`iP0[0?[`iP030000o`3jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0E@3jl>H10?oo
o`00K@3jl>H00`000?l0n_3V0?[`iP0g0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3j
l>H0C`3jl>H00`3=QCl0n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V02P0n_3V0P000?lE0?[`iP03
0000003jl>H0n_3V05D0n_3V0@3oool006h0n_3V0P000?lg0?[`iP030<f5?`3jl>H0n_3V04l0n_3V
00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V02D0n_3V
0P000?lG0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00700n_3V0P000?lf0?[`iP030<f5?`3j
l>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0>0?[`iP030000003j
l>H0n_3V02<0n_3V00<0003o0?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo001b
0?[`iP030000o`3jl>H0n_3V03<0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>
0?[`iP030<f5?`3jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0803jl>H20000oaX0n_3V00<00000
0?[`iP3jl>H0E@3jl>H10?ooo`00L`3jl>H20000oc<0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`00
0000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V0100n_3V00<000000?[`iP3jl>H07P3jl>H00`00
0?l0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool007D0n_3V0P000?la0?[`iP03
0<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP03
0000003jl>H0n_3V01/0n_3V0P000?lM0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool007L0n_3V
00<0003o0?[`iP3jl>H0;`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V04d0n_3V
00<0cHDo0?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0I0?[`iP80003o7`3jl>H00`000000n_3V
0?[`iP1E0?[`iP40oooo001h0?[`iP80003o;`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003j
l>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP0G0?[`iP030000o`3j
l>H0n_3V01l0n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00NP3jl>H20000obd0n_3V00<0cHDo
0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V01@0n_3V00<00000
0?[`iP3jl>H0503jl>H20000ob80n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00O03jl>H00`00
0?l0n_3V0?[`iP0Z0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=
QCl0n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V0180n_3V00<0003o0?[`iP3jl>H08P3jl>H00`00
0000n_3V0?[`iP1E0?[`iP40oooo001m0?[`iP80003o:`3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP03
0000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP0?0?[`iP80
003o9@3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo001o0?[`iP80003o:@3jl>H00`3=QCl0n_3V
0?[`iP1<0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0603jl>H00`000000n_3V
0?[`iP0<0?[`iP80003o9`3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo00210?[`iP030000o`3j
l>H0n_3V02H0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3j
l>H0n_3V01T0n_3V00<000000?[`iP3jl>H02P3jl>H00`000?l0n_3V0?[`iP0W0?[`iP030000003j
l>H0n_3V05D0n_3V0@3oool00880n_3V0P000?lV0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<00000
0?[`iP3jl>H0B`3jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP030000003jl>H0n_3V00L0n_3V0P000?lZ
0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool008@0n_3V0P000?lU0?[`iP030<f5?`3jl>H0n_3V
04/0n_3V00<000000?[`iP3jl>H0B`3jl>H00`3=QCl0n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V
00D0n_3V00<0003o0?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo00260?[`iP03
0000o`3jl>H0n_3V0280n_3V00<0cHDo0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP1:0?[`iP03
0<f5?`3jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H00P3jl>H20000obd0n_3V00<000000?[`iP3j
l>H0E@3jl>H10?ooo`00Q`3jl>H20000ob<0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V
0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V01l0n_3V00@000000?[`iP000?l0003o;`3jl>H00`000000
n_3V0?[`iP1E0?[`iP40oooo00290?[`iP80003o8@3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000
003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H0803jl>H00`000000n_3V0?[`iP0_0?[`iP030000
003jl>H0n_3V05D0n_3V0@3oool008/0n_3V0P000?lO0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<0
00000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0N0?[`iP80003o00<0n_3V0000003jl>H0;`3j
l>H00`000000n_3V0?[`iP1E0?[`iP40oooo002=0?[`iP030000o`3jl>H0n_3V01`0n_3V00<0cHDo
0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V01h0n_3V00<0003o
0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool0
08h0n_3V0P000?lM0?[`iP030<f5?`3jl>H0n_3V04T0n_3V00<000000?[`iP3jl>H0B@3jl>H00`3=
QCl0n_3V0?[`iP0L0?[`iP80003o1P3jl>H00`000000n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V
05D0n_3V0@3oool00900n_3V0P000?lL0?[`iP030<f5?`3jl>H0n_3V04P0n_3V00<000000?[`iP3j
l>H0B03jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP80003o2@3jl>H00`000000n_3V0?[`iP0[0?[`iP03
0000003jl>H0n_3V05D0n_3V0@3oool00980n_3V00<0003o0?[`iP3jl>H06@3jl>H00`3=QCl0n_3V
0?[`iP180?[`iP030000003jl>H0n_3V04L0n_3V00<0cHDo0?[`iP3jl>H06`3jl>H00`000?l0n_3V
0?[`iP0:0?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00T`3j
l>H20000oaX0n_3V00<0cHDo0?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`iP170?[`iP030<f5?`3j
l>H0n_3V01T0n_3V0P000?l>0?[`iP030000003jl>H0n_3V02T0n_3V00<000000?[`iP3jl>H0E@3j
l>H10?ooo`00U@3jl>H00`000?l0n_3V0?[`iP0G0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<00000
0?[`iP3jl>H0AP3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000o`3jl>H0n_3V00l0n_3V00<00000
0?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo002F0?[`iP80003o603jl>H00`3=
QCl0n_3V0?[`iP160?[`iP030000003jl>H0n_3V04H0n_3V00<0cHDo0?[`iP3jl>H05`3jl>H20000
oa<0n_3V00<000000?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo002H0?[`iP03
0000o`3jl>H0n_3V01D0n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP150?[`iP03
0<f5?`3jl>H0n_3V01L0n_3V00<0003o0?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP0V0?[`iP03
0000003jl>H0n_3V05D0n_3V0@3oool009T0n_3V0P000?lF0?[`iP030<f5?`3jl>H0n_3V04D0n_3V
00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP80003o603jl>H00`000000n_3V
0?[`iP0U0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool009/0n_3V00<0003o0?[`iP3jl>H04`3j
l>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H05@3j
l>H00`000?l0n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0E@3j
l>H10?ooo`00W03jl>H20000oa@0n_3V00<0cHDo0?[`iP3jl>H0A03jl>H00`000000n_3V0?[`iP14
0?[`iP030<f5?`3jl>H0n_3V01<0n_3V0P000?lM0?[`iP030000003jl>H0n_3V02<0n_3V00<00000
0?[`iP3jl>H0E@3jl>H10?ooo`00WP3jl>H00`000?l0n_3V0?[`iP0B0?[`iP030<f5?`3jl>H0n_3V
04<0n_3V00<000000?[`iP3jl>H0@`3jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP030000o`3jl>H0n_3V
01h0n_3V00<000000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo002O0?[`iP80
003o4P3jl>H00`3=QCl0n_3V0?[`iP130?[`iP030000003jl>H0n_3V0480n_3V00<0cHDo0?[`iP3j
l>H04P3jl>H20000ob80n_3V00<000000?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP1E0?[`iP40
oooo002Q0?[`iP030000o`3jl>H0n_3V0100n_3V00<0cHDo0?[`iP3jl>H0@P3jl>H00`000000n_3V
0?[`iP120?[`iP030<f5?`3jl>H0n_3V0140n_3V00<0003o0?[`iP3jl>H08`3jl>H00`000000n_3V
0?[`iP0P0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00:80n_3V0P000?lA0?[`iP030<f5?`3j
l>H0n_3V0440n_3V00<000000?[`iP3jl>H0@@3jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP80003o9`3j
l>H00`000000n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00:@0n_3V00<0003o
0?[`iP3jl>H03`3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V0400n_3V00<0cHDo
0?[`iP3jl>H0403jl>H00`000?l0n_3V0?[`iP0X0?[`iP030000003jl>H0n_3V01h0n_3V00<00000
0?[`iP3jl>H0E@3jl>H10?ooo`00Y@3jl>H20000o`l0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`00
0000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0n_3V00l0n_3V0P000?l/0?[`iP030000003jl>H0n_3V
01d0n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00Y`3jl>H00`000?l0n_3V0?[`iP0=0?[`iP03
0<f5?`3jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3=QCl0n_3V0?[`iP0>0?[`iP03
0000o`3jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP1E0?[`iP40
oooo002X0?[`iP80003o3P3jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03h0n_3V
00<0cHDo0?[`iP3jl>H03@3jl>H20000oc40n_3V00<000000?[`iP3jl>H06`3jl>H00`000000n_3V
0?[`iP1E0?[`iP40oooo002Z0?[`iP80003o303jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP030000003j
l>H0n_3V03d0n_3V00<0cHDo0?[`iP3jl>H0303jl>H20000oc@0n_3V00<000000?[`iP3jl>H06P3j
l>H00`000000n_3V0?[`iP1E0?[`iP40oooo002/0?[`iP030000o`3jl>H0n_3V00X0n_3V00<0cHDo
0?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP0m0?[`iP030<f5?`3jl>H0n_3V00X0n_3V0P000?lg
0?[`iP030000003jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00[@3jl>H20000
o`/0n_3V0P3=QClm0?[`iP030000003jl>H0n_3V03/0n_3V0P3=QCl<0?[`iP030000o`3jl>H0n_3V
03P0n_3V00<000000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo002_0?[`iP80
003o2P3jl>H00`3=QCl0n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3j
l>H02P3jl>H20000oc`0n_3V00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP1E0?[`iP40
oooo002a0?[`iP030000o`3jl>H0n_3V00P0n_3V00<0cHDo0?[`iP3jl>H0>P3jl>H00`000000n_3V
0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V00P0n_3V0P000?lo0?[`iP030000003jl>H0n_3V01H0n_3V
00<000000?[`iP3jl>H0E@3jl>H10?ooo`00/P3jl>H20000o`T0n_3V00<0cHDo0?[`iP3jl>H0>@3j
l>H00`000000n_3V0?[`iP0i0?[`iP030<f5?`3jl>H0n_3V00L0n_3V0P000?m20?[`iP030000003j
l>H0n_3V01D0n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00]03jl>H20000o`P0n_3V00<0cHDo
0?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP0h0?[`iP030<f5?`3jl>H0n_3V00L0n_3V00<0003o
0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool0
0;H0n_3V00<0003o0?[`iP3jl>H01P3jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V
03L0n_3V00<0cHDo0?[`iP3jl>H01P3jl>H20000odL0n_3V00<000000?[`iP3jl>H04`3jl>H00`00
0000n_3V0?[`iP1E0?[`iP40oooo002g0?[`iP80003o1`3jl>H20<f5?cL0n_3V00<000000?[`iP3j
l>H0=@3jl>H20<f5?`L0n_3V0P000?m:0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3j
l>H0E@3jl>H10?ooo`00^@3jl>H20000o`H0n_3V00<0cHDo0?[`iP3jl>H0=@3jl>H00`000000n_3V
0?[`iP0d0?[`iP030<f5?`3jl>H0n_3V00D0n_3V0P000?m=0?[`iP030000003jl>H0n_3V0140n_3V
00<000000?[`iP3jl>H0E@3jl>H10?ooo`00^`3jl>H00`000?l0n_3V0?[`iP040?[`iP030<f5?`3j
l>H0n_3V03@0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000o`3j
l>H0n_3V04d0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo002l
0?[`iP80003o1@3jl>H20<f5?c@0n_3V00<000000?[`iP3jl>H0<P3jl>H20<f5?`D0n_3V0P000?mA
0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00_P3jl>H20000
o`D0n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0a0?[`iP030<f5?`3jl>H0n_3V
00<0n_3V0P000?mD0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0E@3jl>H10?oo
o`00`03jl>H00`000?l0n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V0300n_3V00<000000?[`iP3j
l>H0<03jl>H00`3=QCl0n_3V0?[`iP020?[`iP80003oE`3jl>H00`000000n_3V0?[`iP0>0?[`iP03
0000003jl>H0n_3V05D0n_3V0@3oool00<40n_3V0P000?l40?[`iP030<f5?`3jl>H0n_3V02l0n_3V
00<000000?[`iP3jl>H0;`3jl>H0103=QCl0n_3V0?[`iP3jl>H20000oeX0n_3V00<000000?[`iP3j
l>H03@3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo00330?[`iP80003o0`3jl>H20<f5?bl0n_3V
00<000000?[`iP3jl>H0;@3jl>H20<f5?`<0n_3V00<0003o0?[`iP3jl>H0F`3jl>H00`000000n_3V
0?[`iP0<0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00<D0n_3V0P000?l30?[`iP030<f5?`3j
l>H0n_3V02`0n_3V00<000000?[`iP3jl>H0;03jl>H0103=QCl0n_3V0?[`iP3jl>H20000oel0n_3V
00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo00370?[`iP80003o0P3j
l>H20<f5?b`0n_3V00<000000?[`iP3jl>H0:P3jl>H20<f5?`80n_3V0P000?mR0?[`iP030000003j
l>H0n_3V00X0n_3V00<000000?[`iP3jl>H0E@3jl>H10?ooo`00b@3jl>H20000o`80n_3V0P3=QClZ
0?[`iP030000003jl>H0n_3V02P0n_3V0P3=QCl20?[`iP80003oI@3jl>H00`000000n_3V0?[`iP09
0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00</0n_3V0P000?l20?[`iP030<f5?`3jl>H0n_3V
02L0n_3V00<000000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V0?[`iP020000ofP0n_3V00<000000?[`
iP3jl>H0203jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo003=0?[`iP80003o00<0n_3V0<f5?`3=
QCl09`3jl>H00`000000n_3V0?[`iP0U0?[`iP80cHDo00<0n_3V0000o`000?l0J`3jl>H00`000000
n_3V0?[`iP070?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00<l0n_3V0`000?l20<f5?bD0n_3V
00<000000?[`iP3jl>H08`3jl>H20<f5?`030?[`iP000?l0003o06h0n_3V00<000000?[`iP3jl>H0
1P3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo003B0?[`iP<0003o00<0cHDo0?[`iP3jl>H08@3j
l>H00`000000n_3V0?[`iP0Q0?[`iP80cHDo00<0n_3V0000o`000?l0L@3jl>H00`000000n_3V0?[`
iP050?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00=D0n_3V0P000?l00`3=QCl0n_3V0?[`iP0O
0?[`iP030000003jl>H0n_3V01l0n_3V0P3=QCl30000og@0n_3V00<000000?[`iP3jl>H0103jl>H0
0`000000n_3V0?[`iP1E0?[`iP40oooo003G0?[`iP<0003o7`3jl>H00`000000n_3V0?[`iP0M0?[`
iP80cHDo0P000?mh0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0E@3jl>H10?oo
o`00fP3jl>H30000o`030<f5?`3jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06@3jl>H30<f5?`<0
003oN`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V05D0n_3V0@3oool00=d0n_3V
0`000?lI0?[`iP030000003jl>H0n_3V01L0n_3V00<0cHDo0000o`000?l00P000?mo0?[`iP050000
003jl>H0n_3V0?[`iP000000E`3jl>H10?ooo`00h03jl>H40000oaD0n_3V00<000000?[`iP3jl>H0
4`3jl>H00`3=QCl0003o0000o`020000oh@0n_3V00@000000?[`iP3jl>H00000E`3jl>H10?ooo`00
i03jl>H40000oa40n_3V00<000000?[`iP3jl>H03`3jl>H00`3=QCl0003o0000o`020000ohT0n_3V
1000001F0?[`iP40oooo003X0?[`iP@0003o3@3jl>H00`000000n_3V0?[`iP0;0?[`iPD0003oS@3j
l>H5000005D0n_3V0@3oool00>`0cHDo3@000?l00`000000003o0000o`0;0000oi80cHDo1@00001D
0<f5?`40n_3V0@3oool00?l0n_3VVP3jl>H5000005D0n_3V0@3oool00?l0n_3VV`3jl>H3000005H0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00]P3jl>H200000003
06IRGP3<a;/0n_3V02/0n_3V00H0e<c306IRGP000000000008V4OP3Tfm9U0?[`iP060=C<``1VHUh0
000000000029Q7h0i=_BW03jl>H10?ooo`00^03jl>H00`1VHUh000000=cDb`0[0?[`iP0604a9A@33
^k<0n_3V0>cRf@000000RHAnI@3jl>H01P1<BDD0`k^c0?[`iP3/h]T0000008V4OY`0n_3V0@3oool0
08<0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V00@0[jRQ04a9A@000000RHAn1`3jl>H0
1P3Le</0NGE`000000000000RHAn0<c4^`80n_3V00@0[jRQ04a9A@000000RHAn0P3jl>H200000080
n_3V0P0000001@3jl>H0c<Bk0000001iMG00n_3V008000000P3jl>H20000000306IRGP3jl>H0n_3V
00L0n_3V0P0000030?[`iP040<c4^`1<BDD0IV9N0>CKdP80000000<0n_3V0000000000000`3jl>H2
00000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P0000020?[`iP0308V4OP1V
HUh0c<Bk008000001`3jl>H01@3Le</0NGE`0000001<BDD0Y9fF0080n_3V00@0c<Bk04a9A@1VHUh0
i=_B0P0000000`3jl>H00000000000040?[`iP030:BMUP000000Y9fF00<0n_3V00@0[jRQ04a9A@00
0000RHAn1`3jl>H0102_Z:40C4U504a9A@2_Z:420?[`iP8000001P3jl>H2000000050?[`iP33^k<0
00000<>k/`3jl>H00P0000001@3jl>H0c<Bk04a9A@1<BDD0[jRQ0080000000<0n_3V000000000000
0`3jl>H2000000050?[`iP3<a;/0C4U504a9A@2_Z:400P0000040?[`iP80000000<0k>;I0?[`iP3/
h]T00P0000020?[`iP0308V4OP1VHUh0c<Bk0080000000<0n_3V0000000000000P3jl>H200000080
n_3V00@0[jRQ04a9A@000000RHAn0P3jl>H01`3/h]T0Ui6;000000000000NGE`0>CKdP3jl>H00P00
00240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000001`3jl>H0[jRQ00000033
^k<0i=_B00000029Q7h01@3jl>H01@3Tfm80000009NAR`3jl>H0^K:Z0080000000P0n_3V0:nXX@00
0000`k^c0>CKdP000000RHAn0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H0c<Bk00000002000000030>CKdP3jl>H0n_3V00H0n_3V0P0000030?[`iP0406IRGP00
0000i=_B0;VbZP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H00000
0000003jl>H200000080n_3V0P0000001@3jl>H0Y9fF00000033^k<0Y9fF008000001P3jl>H0303T
fm80000009NAR`3jl>H0e<c300000029Q7h0n_3V06IRGP000000i=_B0;VbZP80000000<0n_3V0000
00000000103jl>H3000000080>cRf@3jl>H0[jRQ00000033^k<0i=_B00000029Q7h50?[`iP070;Vb
ZP000000`k^c0<>k/`000000^K:Z0?[`iP02000000H0n_3V0P0000001@3jl>H0Ui6;0000002GTH/0
n_3V0080000000D0n_3V04a9A@000000i=_B0<>k/`02000000030?[`iP000000000000<0n_3V0P00
00001@3jl>H0C4U50000003Tfm80`k^c00800000103jl>H03029Q7h000000=C<``3jl>H0e<c30000
0029Q7h0n_3V0:BMUP000000`k^c0:BMUP80000000<0n_3V0000000000000P3jl>H20000000?0?[`
iP2_Z:4000000<>k/`3Tfm80000008V4OP3jl>H0NGE`0000003Tfm80k>;I0000001VHUh0n_3V0080
0000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V04a9A@000000
2@3jl>H00`2GTH/000000=cDb`020?[`iP80000000<0n_3V04a9A@0000001@3jl>H200000080n_3V
0P0000000`3jl>H00000000000020?[`iP80000000H0n_3V09NAR`000000RHAn0000002_Z:480?[`
iP8000000`3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H20000
00040?[`iP00000000000?[`iP8000000P3jl>H2000000030?[`iP1<BDD000000080n_3V0P000006
0?[`iP0309NAR`000000i=_B00D0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H0
202i/ZX0000008V4OP000000^K:Z0?[`iP1<BDD000002@3jl>H01`1VHUh000000?[`iP3jl>H00000
06IRGP3jl>H00P0000060?[`iP80000000D0n_3V04a9A@000000C4U50?[`iP02000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000030?[`iP80000000<0n_3V0000000000000P3j
l>H2000000@0n_3V00<0[jRQ0000000000000`000000102_Z:40n_3V04a9A@0000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP1<BDD0000000L0n_3V00D0e<c30:BMUP000000
C4U50?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`
iP000000000000@000001@3jl>H00`1<BDD000000?[`iP020?[`iP80000000<0n_3V000000000000
100000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000060?[`
iP1<BDD000000>cRf@000000IV9N203jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P000000
0`3jl>H00000000000020?[`iP8000001P3jl>H2000000H0n_3V0P0000020?[`iP80000000<0n_3V
0000000000000`3jl>H204a9A@040>cRf@1<BDD0C4U50?[`iPH000001@3jl>H200000080n_3V0P00
00000`3jl>H00000000000060?[`iP80000000D0i=_B0000002GTH/000000>CKdP02000000050?[`
iP3<a;/0000009NAR`3Tfm800P0000000`3jl>H00000000000030?[`iP80000000D0n_3V0<c4^`00
0000Ui6;0>CKdP02000000@0n_3V00P0e<c300000029Q7h0n_3V09NAR`000000e<c30?[`iP800000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0000000000004000000030?[`
iP3<a;/0C4U50080000000<0C4U50<c4^`3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3j
l>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP030000001VHUh0n_3V00@0n_3V0P00
00020?[`iP<0000000<0n_3V04a9A@0000000P3jl>H00`000000IV9N0?[`iP0200000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000L0g=C;00000029Q7h0n_3V08V4OP000000i=_B00L0
n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V0P0000020?[`iP80
000000@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V04a9A@0000000P3jl>H20000
00H0n_3V0P0000060?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V00T0c<Bk0000
002TWIH0n_3V0:BMUP000000c<Bk04a9A@0000000P3jl>H00`000000IV9N0?[`iP040?[`iP0706IR
GP000000n_3V0?[`iP000000IV9N0?[`iP02000000H0n_3V0P0000001@3<a;/000000=cDb`000000
c<Bk008000000P3jl>H00`3Le</0[jRQ07UeL002000000030?[`iP000000000000<0n_3V0P000002
0?[`iP030=cDb`2_Z:40NGE`008000001@3jl>H01@000000C4U50?[`iP1<BDD000000080n_3V00@0
C4U50000003jl>H0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V04a9A@000000
0P3jl>H01`000000IV9N0?[`iP1<BDD0000007UeL03<a;/00`3jl>H2000008@0n_3V0@3oool008<0
n_3V0P0000030?[`iP80000000/0Y9fF0>CKdP000000IV9N0?[`iP2i/ZX000000<>k/`3<a;/00000
0;VbZP050?[`iP0304a9A@000000n_3V00D0n_3V00L0^K:Z00000033^k<0c<Bk0000002i/ZX0n_3V
0080000000D0^K:Z0>CKdP000000C4U50?[`iP0200000080n_3V0P0000001`2_Z:4000000<>k/`3j
l>H0`k^c0000002_Z:401`3jl>H2000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000
e<c30P3jl>H2000000050;VbZP3Tfm80000004a9A@3jl>H00P000000303jl>H000000000002i/ZX0
i=_B0000001<BDD0n_3V0:BMUP000000`k^c0:BMUP8000001P3jl>H00`1<BDD000000?[`iP050?[`
iP8000000P3jl>H20000000B0?[`iP00000000000=C<``3jl>H0IV9N0000003/h]T0n_3V0>cRf@00
0000IV9N0;VbZP000000`k^c0<c4^`000000^K:Z1@3jl>H01`2i/ZX000000<>k/`33^k<000000;Vb
ZP3jl>H00P0000060?[`iP80000000D0Y9fF06IRGP3jl>H0IV9N0:BMUP02000000080?[`iP1iMG00
e<c30?[`iP3Tfm80000004a9A@3jl>H2000000030=C<``3jl>H0n_3V0080000000L0n_3V07UeL03D
c<<0n_3V0>CKdP000000C4U500D0n_3V00D0NGE`0000003<a;/0000006IRGP020?[`iP040:BMUP00
0000`k^c0:BMUP80000001H0n_3V000000000000^K:Z0>CKdP000000C4U50?[`iP2i/ZX000000<>k
/`3<a;/000000;VbZP3jl>H0IV9N0000003jl>H0i=_B0000001iMG00n_3V0P0000240?[`iP40oooo
00230?[`iP8000000`3jl>H2000000040=cDb`29Q7h0C4U50<c4^`80n_3V00@0[jRQ000000000000
[jRQ1P3jl>H00`2GTH/000000>CKdP060?[`iP040:nXX@00000000000:nXX@80n_3V0P000000103<
a;/0NGE`04a9A@3<a;/40000000:0?[`iP000000000006IRGP000000k>;I0?[`iP3/h]T0000006IR
GPL0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP000000000008V4OP1iMG00n_3V0P00
00001@3<a;/0NGE`04a9A@3<a;/0n_3V0080000000L0n_3V000000000000c<Bk07UeL01<BDD0c<Bk
0080n_3V00<0RHAn06IRGP3<a;/00P0000060?[`iP0309NAR`000000i=_B00D0n_3V0P0000020?[`
iP80000000@0n_3V000000000000RHAn0P0000002029Q7h0n_3V0?[`iP3jl>H0RHAn0000003Le</0
[jRQ0P0000000`2_Z:40n_3V0?[`iP050?[`iP050:nXX@1<BDD000000:nXX@3jl>H0100000050?[`
iP80000000D0IV9N0:BMUP3jl>H0Ui6;06IRGP02000000030?[`iP3Tfm80RHAn0080000000<0IV9N
0=C<``3jl>H00P0000000`29Q7h0NGE`0?[`iP02000000030?[`iP3Tfm80RHAn0080000000<0IV9N
0=C<``3jl>H0103jl>H01@2TWIH0000008V4OP000000Y9fF00<0n_3V00<0RHAn06IRGP3<a;/00P00
00001`3jl>H000000000003<a;/0NGE`04a9A@3<a;/00P3jl>H0102_Z:4000000000002_Z:420?[`
iP070>CKdP1iMG00000000000029Q7h0i=_B0?[`iP02000008@0n_3V0@3oool008<0n_3V0P000003
0?[`iP800000403jl>H01`3Tfm80000009NAR`3jl>H0e<c30000001iMG003`3jl>H200000080n_3V
0P00000>0?[`iP800000;03jl>H01`3Tfm80000009NAR`3jl>H0e<c300000029Q7h09@3jl>H20000
00H0n_3V0`0000000`3<a;/0n_3V0<>k/`03000001/0n_3V00D0c<Bk00000000000000000<>k/`2T
0?[`iP40oooo00210?[`iPH0000000<0n_3V0000000000004@3jl>H01P3Le</0NGE`000000000000
Ui6;0>cRf@l0n_3V00@0g=C;08V4OP3jl>H0n_3V0P00000<0?[`iPH00000503jl>H2000001D0n_3V
00D0g=C;07UeL000000000000:BMUP0V0?[`iP040<c4^`1VHUh0000008V4OP@0n_3V0`0000000`3/
h]T0n_3V0=cDb`03000000d0n_3V0P00000<0?[`iP050>cRf@00000000000000003Tfm807P3jl>H2
000008@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.86957 .38333 L
s
.86957 .05 m
.86957 .38333 L
s
.66578 .19953 m
.86957 .19953 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.86957 .38333 Mdot
.66578 .19953 Mdot
.86957 .19953 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V2P3=QCl20?[`iP80000000<0n_3V0<f5
?`3=QCl0203=QCn[0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00>L0n_3V1P3=QCl<0?[`iP03
0000003jl>H0000000X0n_3V1`3=QCnT0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00>D0n_3V
0P3=QClB0?[`iP040000003jl>H0n_3V00000100n_3V0P3=QCnR0?[`iP030000003jl>H0n_3V03l0
n_3V0@3oool00>40n_3V103=QClD0?[`iP050000003jl>H0n_3V0?[`iP0000004@3jl>H30<f5?il0
n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00g@3jl>H40<f5?aP0n_3V00<000000?[`iP3jl>H0
0P3jl>H200000180n_3V103=QCnK0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00=/0n_3V0P3=
QClL0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H04`3jl>H20<f5?iT0n_3V00<0
00000?[`iP3jl>H0?`3jl>H10?ooo`00f@3jl>H20<f5?ah0n_3V00<000000?[`iP3jl>H01@3jl>H0
0`000000n_3V0?[`iP0D0?[`iP80cHDoU`3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo003G0?[`
iP80cHDo803jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V01D0n_3V0P3=QCnE0?[`
iP030000003jl>H0n_3V03l0n_3V0@3oool00=D0n_3V0P3=QClR0?[`iP030000003jl>H0n_3V00L0
n_3V00<000000?[`iP3jl>H05P3jl>H20<f5?i<0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00
d`3jl>H20<f5?b@0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0G0?[`iP80cHDo
T@3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo003A0?[`iP80cHDo9P3jl>H00`000000n_3V0?[`
iP090?[`iP030000003jl>H0n_3V01P0n_3V0P3=QCn?0?[`iP030000003jl>H0n_3V03l0n_3V0@3o
ool00<l0n_3V0P3=QClX0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H06@3jl>H2
0<f5?hd0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00cP3jl>H00`3=QCl0n_3V0?[`iP0X0?[`
iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H06P3jl>H00`3=QCl0n_3V0?[`iP2:0?[`
iP030000003jl>H0n_3V03l0n_3V0@3oool00<`0n_3V0P3=QCl[0?[`iP030000003jl>H0n_3V00`0
n_3V0P00000K0?[`iP80cHDoRP3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo003:0?[`iP80cHDo
;@3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V01X0n_3V0P3=QCn80?[`iP030000
003jl>H0n_3V03l0n_3V0@3oool00<T0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`
iP0?0?[`iP030000003jl>H0n_3V01/0n_3V00<0cHDo0?[`iP3jl>H0Q@3jl>H00`000000n_3V0?[`
iP0o0?[`iP40oooo00370?[`iP80cHDo<03jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0
n_3V01/0n_3V0P3=QCn50?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00<H0n_3V00<0cHDo0?[`
iP3jl>H0<03jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V01`0n_3V00<0cHDo0?[`
iP3jl>H0PP3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo00350?[`iP030<f5?`3jl>H0n_3V0340
n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0L0?[`iP030<f5?`3jl>H0n_3V0840
n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00a03jl>H00`3=QCl0n_3V0?[`iP0b0?[`iP030000
003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0703jl>H00`3=QCl0n_3V0?[`iP200?[`iP030000
003jl>H0n_3V03l0n_3V0@3oool00<80n_3V0P3=QCle0?[`iP030000003jl>H0n_3V01@0n_3V00<0
00000?[`iP3jl>H0703jl>H20<f5?h00n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00`@3jl>H0
0`3=QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0703jl>H0
0`3=QCl0n_3V0?[`iP1n0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00<00n_3V00<0cHDo0?[`
iP3jl>H0=P3jl>H00`000000n_3V0?[`iP0F0?[`iP8000007@3jl>H00`3=QCl0n_3V0?[`iP1m0?[`
iP030000003jl>H0n_3V03l0n_3V0@3oool00;l0n_3V00<0cHDo0?[`iP3jl>H0=`3jl>H00`000000
n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V01/0n_3V0P3=QCmm0?[`iP030000003jl>H0n_3V03l0
n_3V0@3oool00;h0n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP0I0?[`iP030000
003jl>H0n_3V01`0n_3V00<0cHDo0?[`iP3jl>H0NP3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo
002m0?[`iP030<f5?`3jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H06P3jl>H00`000000n_3V0?[`
iP0L0?[`iP030<f5?`3jl>H0n_3V07T0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00_03jl>H0
0`3=QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0703jl>H0
0`3=QCl0n_3V0?[`iP1h0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00;/0n_3V00<0cHDo0?[`
iP3jl>H0>`3jl>H00`000000n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V01/0n_3V00<0cHDo0?[`
iP3jl>H0N03jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo002j0?[`iP030<f5?`3jl>H0n_3V03`0
n_3V00<000000?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP0K0?[`iP030<f5?`3jl>H0n_3V07L0
n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00^@3jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP030000
003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H06`3jl>H20<f5?gL0n_3V00<000000?[`iP3jl>H0
?`3jl>H10?ooo`00^03jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V01l0n_3V00<0
00000?[`iP3jl>H06`3jl>H00`3=QCl0n_3V0?[`iP1e0?[`iP030000003jl>H0n_3V03l0n_3V0@3o
ool00;P0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0P0?[`iP800000703jl>H0
0`3=QCl0n_3V0?[`iP1d0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00;L0n_3V00<0cHDo0?[`
iP3jl>H0?`3jl>H00`000000n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V01X0n_3V00<0cHDo0?[`
iP3jl>H0L`3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo002f0?[`iP030<f5?`3jl>H0n_3V0400
n_3V00<000000?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V07<0
n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00]P3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000
003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H06@3jl>H00`3=QCl0n_3V0?[`iP1b0?[`iP030000
003jl>H0n_3V03l0n_3V0@3oool00;D0n_3V00<0cHDo0?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`
iP0U0?[`iP030000003jl>H0n_3V01T0n_3V00<0cHDo0?[`iP3jl>H0L@3jl>H00`000000n_3V0?[`
iP0o0?[`iP40oooo002d0?[`iP030<f5?`3jl>H0n_3V0480n_3V00<000000?[`iP3jl>H09P3jl>H0
0`000000n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V0700n_3V00<000000?[`iP3jl>H0?`3jl>H1
0?ooo`00/`3jl>H00`3=QCl0n_3V0?[`iP130?[`iP030000003jl>H0n_3V02L0n_3V00<000000?[`
iP3jl>H06@3jl>H00`3=QCl0n_3V0?[`iP1_0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00;80
n_3V00<0cHDo0?[`iP3jl>H0A03jl>H00`000000n_3V0?[`iP0X0?[`iP030000003jl>H0n_3V01P0
n_3V00<0cHDo0?[`iP3jl>H0K`3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo002b0?[`iP030<f5
?`3jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H0:@3jl>H00`000000n_3V0?[`iP0H0?[`iP030<f5
?`3jl>H0n_3V06h0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00/@3jl>H00`3=QCl0n_3V0?[`
iP150?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H05`3jl>H00`3=QCl0n_3V0?[`
iP1^0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00;40n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H0
0`000000n_3V0?[`iP0[0?[`iP800000603jl>H00`3=QCl0n_3V0?[`iP1]0?[`iP030000003jl>H0
n_3V03l0n_3V0@3oool00;00n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP0]0?[`
iP030000003jl>H0n_3V01D0n_3V00<0cHDo0?[`iP3jl>H0K@3jl>H00`000000n_3V0?[`iP0o0?[`
iP40oooo002`0?[`iP030<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H0;P3jl>H00`000000
n_3V0?[`iP0E0?[`iP030<f5?`3jl>H0n_3V06`0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00
[`3jl>H00`3=QCl0n_3V0?[`iP170?[`iP030000003jl>H0n_3V02l0n_3V00<000000?[`iP3jl>H0
503jl>H00`3=QCl0n_3V0?[`iP1/0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00:l0n_3V00<0
cHDo0?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V01@0n_3V00<0
cHDo0?[`iP3jl>H0J`3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo002^0?[`iP030<f5?`3jl>H0
n_3V04P0n_3V00<000000?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0D0?[`iP030<f5?`3jl>H0
n_3V06X0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00[@3jl>H00`3=QCl0n_3V0?[`iP190?[`
iP030000003jl>H0n_3V0380n_3V00<000000?[`iP3jl>H04`3jl>H00`3=QCl0n_3V0?[`iP1Z0?[`
iP030000003jl>H0n_3V03l0n_3V0@3oool00:d0n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H00`000000
n_3V0?[`iP0c0?[`iP030000003jl>H0n_3V01<0n_3V00<0cHDo0?[`iP3jl>H0J@3jl>H00`000000
n_3V0?[`iP0o0?[`iP40oooo002/0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0
=03jl>H00`000000n_3V0?[`iP0B0?[`iP030<f5?`3jl>H0n_3V06T0n_3V00<000000?[`iP3jl>H0
?`3jl>H10?ooo`00[03jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V03D0n_3V0P00
000C0?[`iP030<f5?`3jl>H0n_3V06P0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`000P000?nZ
0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0=`3jl>H00`000000n_3V0?[`iP0@
0?[`iP030<f5?`3jl>H0n_3V06P0n_3V00<000000?[`iP3jl>H0?03jl>H20000o`40n_3V0@3oool0
0080n_3V0`000?nW0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0>03jl>H00`00
0000n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V06P0n_3V00<000000?[`iP3jl>H0>@3jl>H30000
o`<0n_3V0@3oool000D0n_3V10000?nR0?[`iP030<f5?`3jl>H0n_3V04/0n_3V00<000000?[`iP3j
l>H0>@3jl>H00`000000n_3V0?[`iP0>0?[`iP030<f5?`3jl>H0n_3V06P0n_3V00<000000?[`iP3j
l>H0=@3jl>H40000o`H0n_3V0@3oool000T0n_3V0`000?nO0?[`iP030<f5?`3jl>H0n_3V04/0n_3V
00<000000?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP0>0?[`iP030<f5?`3jl>H0n_3V06L0n_3V
00<000000?[`iP3jl>H0<P3jl>H30000o`X0n_3V0@3oool000`0n_3V0`000?nK0?[`iP030<f5?`3j
l>H0n_3V04`0n_3V00<000000?[`iP3jl>H0>`3jl>H00`000000n_3V0?[`iP0=0?[`iP030<f5?`3j
l>H0n_3V06L0n_3V00<000000?[`iP3jl>H0;`3jl>H30000o`d0n_3V0@3oool000l0n_3V10000?nG
0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0?03jl>H00`000000n_3V0?[`iP0=
0?[`iP030<f5?`3jl>H0n_3V06H0n_3V00<000000?[`iP3jl>H0:`3jl>H40000oa00n_3V0@3oool0
01<0n_3V0`000?nD0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0?@3jl>H00`00
0000n_3V0?[`iP0<0?[`iP030<f5?`3jl>H0n_3V06H0n_3V00<000000?[`iP3jl>H0:03jl>H30000
oa@0n_3V0@3oool001H0n_3V0`000?nA0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3j
l>H0?P3jl>H00`000000n_3V0?[`iP0;0?[`iP030<f5?`3jl>H0n_3V06H0n_3V00<000000?[`iP3j
l>H09@3jl>H30000oaL0n_3V0@3oool001T0n_3V0`000?n=0?[`iP030<f5?`3jl>H0n_3V04d0n_3V
00<000000?[`iP3jl>H0?`3jl>H2000000/0n_3V00<0cHDo0?[`iP3jl>H0IP3jl>H00`000000n_3V
0?[`iP0R0?[`iP<0003o6P3jl>H10?ooo`00703jl>H30000ohX0n_3V00<0cHDo0?[`iP3jl>H0C@3j
l>H00`000000n_3V0?[`iP110?[`iP030000003jl>H0n_3V00T0n_3V00<0cHDo0?[`iP3jl>H0I@3j
l>H00`000000n_3V0?[`iP0O0?[`iP<0003o7@3jl>H10?ooo`007`3jl>H40000ohH0n_3V00<0cHDo
0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP120?[`iP030000003jl>H0n_3V00P0n_3V00<0cHDo
0?[`iP3jl>H0I@3jl>H00`000000n_3V0?[`iP0L0?[`iP<0003o803jl>H10?ooo`008`3jl>H30000
oh<0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP130?[`iP030000003jl>H0n_3V
00L0n_3V00<0cHDo0?[`iP3jl>H0I@3jl>H00`000000n_3V0?[`iP0I0?[`iP<0003o8`3jl>H10?oo
o`009P3jl>H30000ogl0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP140?[`iP03
0000003jl>H0n_3V00H0n_3V00<0cHDo0?[`iP3jl>H0I@3jl>H00`000000n_3V0?[`iP0F0?[`iP<0
003o9P3jl>H10?ooo`00:@3jl>H30000og`0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V
0?[`iP150?[`iP030000003jl>H0n_3V00H0n_3V00<0cHDo0?[`iP3jl>H0I03jl>H00`000000n_3V
0?[`iP0C0?[`iP<0003o:@3jl>H10?ooo`00;03jl>H20000ogX0n_3V00<0cHDo0?[`iP3jl>H0CP3j
l>H00`000000n_3V0?[`iP160?[`iP030000003jl>H0n_3V00D0n_3V00<0cHDo0?[`iP3jl>H0I03j
l>H00`000000n_3V0?[`iP0A0?[`iP80003o;03jl>H10?ooo`00;P3jl>H20000ogP0n_3V00<0cHDo
0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP170?[`iP030000003jl>H0n_3V00@0n_3V00<0cHDo
0?[`iP3jl>H0I03jl>H00`000000n_3V0?[`iP0?0?[`iP80003o;P3jl>H10?ooo`00<03jl>H30000
og@0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP180?[`iP030000003jl>H0n_3V
00<0n_3V00<0cHDo0?[`iP3jl>H0I03jl>H00`000000n_3V0?[`iP0<0?[`iP<0003o<03jl>H10?oo
o`00<`3jl>H20000og80n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP190?[`iP80
0000103jl>H00`3=QCl0n_3V0?[`iP1S0?[`iP030000003jl>H0n_3V00X0n_3V0P000?lc0?[`iP40
oooo000e0?[`iP80003oL03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04/0n_3V
00D000000?[`iP3jl>H0n_3V0<f5?`1U0?[`iP030000003jl>H0n_3V00P0n_3V0P000?le0?[`iP40
oooo000g0?[`iP<0003oK@3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04`0n_3V
00@000000?[`iP3jl>H0cHDoI@3jl>H00`000000n_3V0?[`iP050?[`iP<0003o=`3jl>H10?ooo`00
>P3jl>H20000of/0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1=0?[`iP030000
003jl>H0cHDo06D0n_3V00<000000?[`iP3jl>H00`3jl>H20000ocX0n_3V0@3oool003`0n_3V0P00
0?mY0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0CP3jl>H400000680n_3V0`00
00020?[`iP80003o?03jl>H10?ooo`00?P3jl>H30000ofD0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H0
0`000000n_3V0?[`iP1>0?[`iPD00000H03jl>H5000000030000o`3jl>H0n_3V03`0n_3V0@3oool0
0440n_3V0P000?mS0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0CP3jl>IZ0000
03l0n_3V0@3oool004<0n_3V0P000?mQ0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3j
l>H0CP3jl>H5000005l0n_3V00<0003o0000000000000`00000o0?[`iP40oooo00150?[`iP80003o
G`3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V04l0n_3V1000001M0?[`iP80003o
0P3jl>H300000400n_3V0@3oool004L0n_3V0P000?mM0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<0
00000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP02000005T0n_3V0P000?l50?[`iP030000003j
l>H0n_3V03l0n_3V0@3oool004T0n_3V0`000?mJ0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<00000
0?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP020?[`iP030000003jl>H0n_3V05@0n_3V0P000?l7
0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool004`0n_3V0P000?mH0?[`iP030<f5?`3jl>H0n_3V
0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP030?[`iP030000003jl>H0n_3V
0540n_3V0P000?l90?[`iP030000003jl>H0n_3V03l0n_3V0@3oool004h0n_3V0P000?mF0?[`iP03
0<f5?`3jl>H0n_3V04l0n_3V0`00001A0?[`iP030<f5?`3jl>H0n_3V00@0n_3V00<000000?[`iP3j
l>H0CP3jl>H20000o`/0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00D03jl>H20000oe@0n_3V
00<0cHDo0?[`iP3jl>H0CP3jl>H500000500n_3V00<0cHDo0?[`iP3jl>H01@3jl>H00`000000n_3V
0?[`iP1;0?[`iP80003o3@3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo001B0?[`iP80003oDP3j
l>H00`3=QCl0n_3V0?[`iP1>0?[`iPD00000D03jl>H00`3=QCl0n_3V0?[`iP060?[`iP030000003j
l>H0n_3V04P0n_3V0P000?l?0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool005@0n_3V0P000?m@
0?[`iP030<f5?`3jl>H0n_3V04h0n_3V1@00001@0?[`iP030<f5?`3jl>H0n_3V00L0n_3V00<00000
0?[`iP3jl>H0A@3jl>H20000oa40n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00EP3jl>H20000
odh0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H300000540n_3V00<0cHDo0?[`iP3jl>H0203jl>H00`00
0000n_3V0?[`iP120?[`iP80003o4`3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo001H0?[`iP80
003oC03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3j
l>H02@3jl>H00`000000n_3V0?[`iP0o0?[`iP80003o5@3jl>H00`000000n_3V0?[`iP0o0?[`iP40
oooo001J0?[`iP030000o`3jl>H0n_3V04T0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V
0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0?03jl>H20000oaL0n_3V
00<000000?[`iP3jl>H0?`3jl>H10?ooo`00F`3jl>H20000odT0n_3V00<0cHDo0?[`iP3jl>H0D03j
l>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V00/0n_3V0P00000j0?[`iP80003o6@3j
l>H00`000000n_3V0?[`iP0o0?[`iP40oooo001M0?[`iP80003oA`3jl>H00`3=QCl0n_3V0?[`iP1@
0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0e
0?[`iP80003o6`3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo001O0?[`iP80003oA@3jl>H00`3=
QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H03P3jl>H00`00
0000n_3V0?[`iP0b0?[`iP80003o7@3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo001Q0?[`iP03
0000o`3jl>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP03
0<f5?`3jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0;`3jl>H20000oal0n_3V00<000000?[`iP3j
l>H0?`3jl>H10?ooo`00HP3jl>H20000od80n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V
0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0;03jl>H20000ob40n_3V
00<000000?[`iP3jl>H0?`3jl>H10?ooo`00I03jl>H20000od00n_3V00<0cHDo0?[`iP3jl>H0D03j
l>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0:@3j
l>H20000ob<0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00IP3jl>H20000ocl0n_3V00<0cHDo
0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V01<0n_3V00<00000
0?[`iP3jl>H09P3jl>H20000obD0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00J03jl>H00`00
0?l0n_3V0?[`iP0l0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=
QCl0n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V02@0n_3V00<0003o0?[`iP3jl>H09@3jl>H00`00
0000n_3V0?[`iP0o0?[`iP40oooo001Y0?[`iP80003o?03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP03
0000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0Q0?[`iP80
003o:03jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo001[0?[`iP80003o>P3jl>H00`3=QCl0n_3V
0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H05P3jl>H200000200n_3V
00<0003o0?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo001]0?[`iP030000o`3j
l>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3j
l>H0n_3V01P0n_3V00<000000?[`iP3jl>H06`3jl>H20000ob/0n_3V00<000000?[`iP3jl>H0?`3j
l>H10?ooo`00KP3jl>H20000ocL0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1>
0?[`iP030<f5?`3jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H0603jl>H20000obd0n_3V00<00000
0?[`iP3jl>H0?`3jl>H10?ooo`00L03jl>H20000ocH0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`00
0000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H05P3jl>H00`00
0?l0n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00780n_3V00<0003o0?[`iP3j
l>H0<`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3j
l>H0703jl>H00`000000n_3V0?[`iP0C0?[`iP80003o<03jl>H00`000000n_3V0?[`iP0o0?[`iP40
oooo001c0?[`iP80003o<`3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04h0n_3V
00<0cHDo0?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000o`3jl>H0n_3V0300n_3V
00<000000?[`iP3jl>H0?`3jl>H10?ooo`00M@3jl>H20000oc40n_3V00<0cHDo0?[`iP3jl>H0CP3j
l>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H03P3j
l>H20000oc<0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00M`3jl>H00`000?l0n_3V0?[`iP0_
0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP0P
0?[`iP030000003jl>H0n_3V00/0n_3V0P000?le0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool0
07P0n_3V0P000?l_0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=
QCl0n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V00T0n_3V00<0003o0?[`iP3jl>H0=@3jl>H00`00
0000n_3V0?[`iP0o0?[`iP40oooo001j0?[`iP80003o;@3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP03
0000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H08P3jl>H2000000L0n_3V0P000?lh0?[`iP03
0000003jl>H0n_3V03l0n_3V0@3oool007`0n_3V00<0003o0?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V
0?[`iP1=0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H09@3jl>H00`000000n_3V
0?[`iP030?[`iP030000o`3jl>H0n_3V03P0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00O@3j
l>H20000ob/0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3j
l>H0n_3V02H0n_3V00<000000?[`iP3jl>H00P000?lk0?[`iP030000003jl>H0n_3V03l0n_3V0@3o
ool007l0n_3V0P000?lY0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0C03jl>H0
0`3=QCl0n_3V0?[`iP0W0?[`iP03000000000?l0n_3V03`0n_3V00<000000?[`iP3jl>H0?`3jl>H1
0?ooo`00P@3jl>H00`000?l0n_3V0?[`iP0V0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`
iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0V0?[`iP030000o`3jl>H0000003d0n_3V00<000000?[`
iP3jl>H0?`3jl>H10?ooo`00PP3jl>H20000obH0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000
n_3V0?[`iP1;0?[`iP030<f5?`3jl>H0n_3V02D0n_3V0P000?l30?[`iP030000003jl>H0n_3V03X0
n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00Q03jl>H20000obD0n_3V00<0cHDo0?[`iP3jl>H0
B`3jl>H00`000000n_3V0?[`iP1;0?[`iP030<f5?`3jl>H0n_3V02@0n_3V00<0003o0?[`iP3jl>H0
103jl>H00`000000n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool008H0n_3V00<0
003o0?[`iP3jl>H08P3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V04X0n_3V00<0
cHDo0?[`iP3jl>H08`3jl>H20000o`P0n_3V00<000000?[`iP3jl>H0>03jl>H00`000000n_3V0?[`
iP0o0?[`iP40oooo00270?[`iP80003o8`3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0
n_3V04X0n_3V00<0cHDo0?[`iP3jl>H08@3jl>H20000o`/0n_3V00<000000?[`iP3jl>H0=`3jl>H0
0`000000n_3V0?[`iP0o0?[`iP40oooo00290?[`iP80003o8@3jl>H00`3=QCl0n_3V0?[`iP1:0?[`
iP030000003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H0803jl>H00`000?l0n_3V0?[`iP0<0?[`
iP800000=`3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo002;0?[`iP80003o7`3jl>H00`3=QCl0
n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H20000oa40
n_3V00<000000?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo002=0?[`iP030000
o`3jl>H0n_3V01`0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP190?[`iP030<f5
?`3jl>H0n_3V01h0n_3V00<0003o0?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0c0?[`iP030000
003jl>H0n_3V03l0n_3V0@3oool008h0n_3V0P000?lM0?[`iP030<f5?`3jl>H0n_3V04T0n_3V00<0
00000?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP0L0?[`iP80003o5P3jl>H00`000000n_3V0?[`
iP0b0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00900n_3V0P000?lL0?[`iP030<f5?`3jl>H0
n_3V04P0n_3V00<000000?[`iP3jl>H0B03jl>H00`3=QCl0n_3V0?[`iP0K0?[`iP80003o6@3jl>H0
0`000000n_3V0?[`iP0a0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00980n_3V00<0003o0?[`
iP3jl>H06@3jl>H00`3=QCl0n_3V0?[`iP180?[`iP030000003jl>H0n_3V04L0n_3V00<0cHDo0?[`
iP3jl>H06`3jl>H00`000?l0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V0300n_3V00<000000?[`
iP3jl>H0?`3jl>H10?ooo`00T`3jl>H20000oaX0n_3V00<0cHDo0?[`iP3jl>H0A`3jl>H00`000000
n_3V0?[`iP170?[`iP030<f5?`3jl>H0n_3V01T0n_3V0P000?lN0?[`iP030000003jl>H0n_3V02l0
n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00U@3jl>H00`000?l0n_3V0?[`iP0G0?[`iP030<f5
?`3jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H0AP3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000
o`3jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0;P3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo
002F0?[`iP80003o603jl>H00`3=QCl0n_3V0?[`iP160?[`iP030000003jl>H0n_3V04H0n_3V00<0
cHDo0?[`iP3jl>H05`3jl>H20000ob<0n_3V00<000000?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`
iP0o0?[`iP40oooo002H0?[`iP030000o`3jl>H0n_3V01D0n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H0
0`000000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<0003o0?[`iP3jl>H0903jl>H0
0`000000n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool009T0n_3V0P000?lF0?[`
iP030<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP0E0?[`
iP80003o:03jl>H2000002`0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00V`3jl>H00`000?l0
n_3V0?[`iP0C0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0A03jl>H00`3=QCl0
n_3V0?[`iP0E0?[`iP030000o`3jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H0:@3jl>H00`000000
n_3V0?[`iP0o0?[`iP40oooo002L0?[`iP80003o503jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000
003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H20000obh0n_3V00<000000?[`iP3jl>H0
:03jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo002N0?[`iP030000o`3jl>H0n_3V0180n_3V00<0
cHDo0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP130?[`iP030<f5?`3jl>H0n_3V01<0n_3V00<0
003o0?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V03l0n_3V0@3o
ool009l0n_3V0P000?lB0?[`iP030<f5?`3jl>H0n_3V04<0n_3V00<000000?[`iP3jl>H0@P3jl>H0
0`3=QCl0n_3V0?[`iP0B0?[`iP80003o<`3jl>H00`000000n_3V0?[`iP0V0?[`iP030000003jl>H0
n_3V03l0n_3V0@3oool00:40n_3V00<0003o0?[`iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP120?[`
iP030000003jl>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H04@3jl>H00`000?l0n_3V0?[`iP0d0?[`
iP030000003jl>H0n_3V02D0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00XP3jl>H20000oa40
n_3V00<0cHDo0?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP110?[`iP030<f5?`3jl>H0n_3V0100
n_3V0P000?lh0?[`iP030000003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00
Y03jl>H00`000?l0n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0
@03jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP030000o`3jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H0
8`3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo002U0?[`iP80003o3`3jl>H00`3=QCl0n_3V0?[`
iP100?[`iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H03`3jl>H20000ocd0n_3V00<0
00000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo002W0?[`iP030000o`3jl>H0
n_3V00d0n_3V00<0cHDo0?[`iP3jl>H0?`3jl>H00`000000n_3V0?[`iP0o0?[`iP030<f5?`3jl>H0
n_3V00h0n_3V00<0003o0?[`iP3jl>H0?P3jl>H200000280n_3V00<000000?[`iP3jl>H0?`3jl>H1
0?ooo`00Z03jl>H20000o`h0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0n0?[`
iP030<f5?`3jl>H0n_3V00d0n_3V0P000?m30?[`iP030000003jl>H0n_3V01l0n_3V00<000000?[`
iP3jl>H0?`3jl>H10?ooo`00ZP3jl>H20000o``0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H00`000000
n_3V0?[`iP0m0?[`iP030<f5?`3jl>H0n_3V00`0n_3V0P000?m60?[`iP030000003jl>H0n_3V01h0
n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00[03jl>H00`000?l0n_3V0?[`iP0:0?[`iP030<f5
?`3jl>H0n_3V03d0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3=QCl0n_3V0?[`iP0:0?[`iP80003o
B@3jl>H00`000000n_3V0?[`iP0M0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00:d0n_3V0P00
0?l;0?[`iP80cHDo?@3jl>H00`000000n_3V0?[`iP0k0?[`iP80cHDo303jl>H00`000?l0n_3V0?[`
iP1:0?[`iP030000003jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00[`3jl>H2
0000o`X0n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H00`000000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0
n_3V00X0n_3V0P000?m>0?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0?`3jl>H1
0?ooo`00/@3jl>H00`000?l0n_3V0?[`iP080?[`iP030<f5?`3jl>H0n_3V03X0n_3V00<000000?[`
iP3jl>H0>P3jl>H00`3=QCl0n_3V0?[`iP080?[`iP80003oD@3jl>H00`000000n_3V0?[`iP0J0?[`
iP030000003jl>H0n_3V03l0n_3V0@3oool00;80n_3V0P000?l90?[`iP030<f5?`3jl>H0n_3V03T0
n_3V00<000000?[`iP3jl>H0>@3jl>H00`3=QCl0n_3V0?[`iP070?[`iP80003oE03jl>H00`000000
n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V03l0n_3V0@3oool00;@0n_3V0P000?l80?[`iP030<f5
?`3jl>H0n_3V03P0n_3V00<000000?[`iP3jl>H0>03jl>H00`3=QCl0n_3V0?[`iP070?[`iP030000
o`3jl>H0n_3V05D0n_3V00<000000?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo
002f0?[`iP030000o`3jl>H0n_3V00H0n_3V00<0cHDo0?[`iP3jl>H0=`3jl>H00`000000n_3V0?[`
iP0g0?[`iP030<f5?`3jl>H0n_3V00H0n_3V0P000?mI0?[`iP800000603jl>H00`000000n_3V0?[`
iP0o0?[`iP40oooo002g0?[`iP80003o1`3jl>H20<f5?cL0n_3V00<000000?[`iP3jl>H0=@3jl>H2
0<f5?`L0n_3V0P000?mM0?[`iP030000003jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0?`3jl>H1
0?ooo`00^@3jl>H20000o`H0n_3V00<0cHDo0?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP0d0?[`
iP030<f5?`3jl>H0n_3V00D0n_3V0P000?mP0?[`iP030000003jl>H0n_3V01@0n_3V00<000000?[`
iP3jl>H0?`3jl>H10?ooo`00^`3jl>H00`000?l0n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V03@0
n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000o`3jl>H0n_3V0640
n_3V00<000000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo002l0?[`iP80003o
1@3jl>H20<f5?c@0n_3V00<000000?[`iP3jl>H0<P3jl>H20<f5?`D0n_3V0P000?mU0?[`iP030000
003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00_P3jl>H20000o`D0n_3V00<0
cHDo0?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0a0?[`iP030<f5?`3jl>H0n_3V00<0n_3V0P00
0?mX0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H0?`3jl>H10?ooo`00`03jl>H0
0`000?l0n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V0300n_3V00<000000?[`iP3jl>H0<03jl>H0
0`3=QCl0n_3V0?[`iP020?[`iP80003oJ`3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0
n_3V03l0n_3V0@3oool00<40n_3V0P000?l40?[`iP030<f5?`3jl>H0n_3V02l0n_3V00<000000?[`
iP3jl>H0;`3jl>H0103=QCl0n_3V0?[`iP3jl>H20000ofh0n_3V00<000000?[`iP3jl>H03`3jl>H0
0`000000n_3V0?[`iP0o0?[`iP40oooo00330?[`iP80003o0`3jl>H20<f5?bl0n_3V00<000000?[`
iP3jl>H0;@3jl>H20<f5?`<0n_3V00<0003o0?[`iP3jl>H0K`3jl>H00`000000n_3V0?[`iP0>0?[`
iP030000003jl>H0n_3V03l0n_3V0@3oool00<D0n_3V0P000?l30?[`iP030<f5?`3jl>H0n_3V02`0
n_3V00<000000?[`iP3jl>H0;03jl>H0103=QCl0n_3V0?[`iP3jl>H20000og<0n_3V0P00000>0?[`
iP030000003jl>H0n_3V03l0n_3V0@3oool00<L0n_3V0P000?l20?[`iP80cHDo;03jl>H00`000000
n_3V0?[`iP0Z0?[`iP80cHDo0P3jl>H20000ogL0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP0o0?[`iP40oooo00390?[`iP80003o0P3jl>H20<f5?bX0n_3V00<000000?[`iP3jl>H0
:03jl>H20<f5?`80n_3V0P000?mj0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0
?`3jl>H10?ooo`00b`3jl>H20000o`80n_3V00<0cHDo0?[`iP3jl>H09`3jl>H00`000000n_3V0?[`
iP0W0?[`iP030<f5?`3jl>H0n_3V0080003oO@3jl>H00`000000n_3V0?[`iP090?[`iP030000003j
l>H0n_3V03l0n_3V0@3oool00<d0n_3V0P000?l00`3jl>H0cHDo0<f5?`0W0?[`iP030000003jl>H0
n_3V02D0n_3V0P3=QCl00`3jl>H0003o0000o`200?[`iP030000003jl>H0n_3V00P0n_3V00<00000
0?[`iP3jl>H0?`3jl>H10?ooo`00c`3jl>H30000o`80cHDo9@3jl>H00`000000n_3V0?[`iP0S0?[`
iP80cHDo00<0n_3V0000o`000?l0P`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V
03l0n_3V0@3oool00=80n_3V0`000?l00`3=QCl0n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V0240
n_3V0P3=QCl00`3jl>H0003o0000o`260?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3j
l>H0?`3jl>H10?ooo`00e@3jl>H20000o`030<f5?`3jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0
7`3jl>H20<f5?`<0003oR@3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V03l0n_3V
0@3oool00=L0n_3V0`000?lO0?[`iP030000003jl>H0n_3V01d0n_3V0P3=QCl20000ohd0n_3V00<0
00000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0o0?[`iP40oooo003J0?[`iP<0003o00<0cHDo
0?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0I0?[`iP<0cHDo0`000?n@0?[`iP800000103jl>H0
0`000000n_3V0?[`iP0o0?[`iP40oooo003M0?[`iP<0003o6@3jl>H00`000000n_3V0?[`iP0G0?[`
iP030<f5?`000?l0003o0080003oU@3jl>H01@000000n_3V0?[`iP3jl>H000000440n_3V0@3oool0
0>00n_3V10000?lE0?[`iP030000003jl>H0n_3V01<0n_3V00<0cHDo0000o`000?l00P000?nJ0?[`
iP040000003jl>H0n_3V00000440n_3V0@3oool00>@0n_3V10000?lA0?[`iP030000003jl>H0n_3V
00l0n_3V00<0cHDo0000o`000?l00P000?nO0?[`iP@00000@03jl>H10?ooo`00j03jl>H40000o`d0
n_3V00<000000?[`iP3jl>H02`3jl>H50000oj<0n_3V1@00000o0?[`iP40oooo003/0<f5?`d0003o
00<000000000o`000?l02`000?nX0<f5?`D00000?P3=QCl10?[`iP40oooo003o0?[`i[00n_3V1@00
000o0?[`iP40oooo003o0?[`i[40n_3V0`0000100?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00;H0n_3V0P0000000`1VHUh0c<Bk0?[`iP0[0?[`iP060=C<``1VHUh0
000000000029Q7h0i=_BI@3jl>H01P3Dc<<0IV9N000000000000RHAn0>CKdY`0n_3V0@3oool00;P0
n_3V00<0IV9N0000003Le</0:`3jl>H01P1<BDD0`k^c0?[`iP3/h]T0000008V4OVD0n_3V00H0C4U5
0<>k/`3jl>H0k>;I00000029Q7jL0?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P00
00020?[`iP040:nXX@1<BDD0000008V4OPL0n_3V00H0g=C;07UeL0000000000008V4OP3<a;/20?[`
iP040:nXX@1<BDD0000008V4OP80n_3V0P0000020?[`iP80000000D0n_3V0<c4^`000000NGE`0?[`
iP0200000080n_3V0P0000000`1VHUh0n_3V0?[`iP070?[`iP8000000`3jl>H0103<a;/0C4U506IR
GP3Tfm82000000030?[`iP000000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000
n_3V0P0000020?[`iP8000000P3jl>H00`29Q7h0IV9N0<c4^`02000000L0n_3V00D0g=C;07UeL000
0000C4U50:BMUP020?[`iP040<c4^`1<BDD0IV9N0>CKdP80000000<0n_3V000000000000103jl>H0
0`2TWIH000000:BMUP030?[`iP040:nXX@1<BDD0000008V4OPL0n_3V00@0[jRQ04a9A@1<BDD0[jRQ
0P3jl>H2000000H0n_3V0P0000001@3jl>H0`k^c00000033^k<0n_3V0080000000D0n_3V0<c4^`1<
BDD0C4U50:nXX@02000000030?[`iP000000000000<0n_3V0P0000001@3jl>H0c<Bk04a9A@1<BDD0
[jRQ00800000103jl>H2000000030>cRf@3jl>H0k>;I008000000P3jl>H00`29Q7h0IV9N0<c4^`02
000000030?[`iP00000000000080n_3V0P0000020?[`iP040:nXX@1<BDD0000008V4OP80n_3V00L0
k>;I09NAR`000000000007UeL03Tfm80n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V
0P0000020?[`iP80000000L0n_3V0:nXX@000000`k^c0>CKdP000000RHAn00D0n_3V00D0i=_B0000
002GTH/0n_3V0;VbZP02000000080?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP3jl>H200000080
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0<c4^`0000000P0000000`3Tfm80
n_3V0?[`iP060?[`iP8000000`3jl>H0101VHUh000000>CKdP2i/ZX2000000030?[`iP0000000000
00<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000D0n_3V
0:BMUP000000`k^c0:BMUP02000000H0n_3V00`0i=_B0000002GTH/0n_3V0=C<``000000RHAn0?[`
iP1VHUh000000>CKdP2i/ZX2000000030?[`iP000000000000@0n_3V0`000000203/h]T0n_3V0:nX
X@000000`k^c0>CKdP000000RHAn1@3jl>H01`2i/ZX000000<>k/`33^k<000000;VbZP3jl>H00P00
00060?[`iP80000000D0n_3V09NAR`000000Ui6;0?[`iP02000000050?[`iP1<BDD000000>CKdP33
^k<00P0000000`3jl>H00000000000030?[`iP80000000D0n_3V04a9A@000000i=_B0<>k/`020000
00@0n_3V00`0RHAn0000003Dc<<0n_3V0=C<``000000RHAn0?[`iP2TWIH000000<>k/`2TWIH20000
00030?[`iP00000000000080n_3V0P0000003`3jl>H0[jRQ00000033^k<0i=_B00000029Q7h0n_3V
07UeL0000000i=_B0>cRf@000000IV9N0?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`
iP8000000P3jl>H2000000030?[`iP1<BDD0000000T0n_3V00<0Ui6;0000003Le</00P3jl>H20000
00030?[`iP1<BDD0000000D0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00060?[`iP2GTH/0000008V4OP000000[jRQ203jl>H2000000<0n_3V0P0000020?[`iP80000000<0
n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V
0P0000000`3jl>H0C4U5000000020?[`iP8000001P3jl>H00`2GTH/000000>CKdP050?[`iP800000
0P3jl>H2000000030?[`iP000000000000<0n_3V00P0^K:Z00000029Q7h000000;VbZP3jl>H0C4U5
000000T0n_3V00L0IV9N0000003jl>H0n_3V0000001VHUh0n_3V008000001P3jl>H2000000050?[`
iP1<BDD0000004a9A@3jl>H00P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
00000`3jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP030:nXX@000000000000<0
000000@0[jRQ0?[`iP1<BDD000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H0C4U5000000070?[`iP050=C<``2TWIH0000004a9A@3jl>H00P0000240?[`iP40oooo00230?[`
iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0000000000004000000D0n_3V00<0C4U50000
003jl>H00P3jl>H2000000030?[`iP000000000000@0000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000001P3jl>H0C4U50000003/h]T0000006IRGPP0n_3V0P00
00030?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V0P0000020?[`iP80000000@0
n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000H0n_3V
0P0000060?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V0P1<BDD0103/h]T0C4U5
04a9A@3jl>H6000000D0n_3V0P0000020?[`iP80000000<0n_3V0000000000001P3jl>H200000005
0>CKdP000000Ui6;0000003Tfm800P0000001@3jl>H0c<Bk0000002GTH/0i=_B0080000000<0n_3V
0000000000000`3jl>H2000000050?[`iP3<a;/0000009NAR`3Tfm800P0000040?[`iP080=C<``00
0000RHAn0?[`iP2GTH/000000=C<``3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V000000000000100000000`3jl>H0c<Bk04a9A@020000000304a9A@3<a;/0n_3V
00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V04a9A@00
00000P3jl>H00`000000IV9N0?[`iP040?[`iP8000000P3jl>H3000000030?[`iP1<BDD000000080
n_3V00<0000006IRGP3jl>H00P0000020?[`iP80000000<0n_3V0000000000000P3jl>H200000007
0=cDb`000000RHAn0?[`iP29Q7h000000>CKdP070?[`iP8000000`3jl>H200000080n_3V0P000000
0`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3j
l>H2000000030?[`iP1<BDD000000080n_3V0P0000060?[`iP8000001P3jl>H200000080n_3V0P00
00000`3jl>H00000000000020?[`iP090<c4^`000000Y9fF0?[`iP2TWIH000000<c4^`1<BDD00000
0080n_3V00<0000006IRGP3jl>H0103jl>H01`1VHUh000000?[`iP3jl>H0000006IRGP3jl>H00P00
00060?[`iP80000000D0c<Bk0000003Le</000000<c4^`0200000080n_3V00<0g=C;0:nXX@1iMG00
0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H00`3Le</0[jRQ07UeL002000000D0n_3V
00D0000004a9A@3jl>H0C4U5000000020?[`iP0404a9A@000000n_3V0?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP1<BDD000000080n_3V00L0000006IRGP3jl>H0C4U50000001i
MG00c<Bk00<0n_3V0P0000240?[`iP40oooo00230?[`iP8000000`3jl>H20000000;0:BMUP3Tfm80
000006IRGP3jl>H0^K:Z00000033^k<0c<Bk0000002i/ZX01@3jl>H00`1<BDD000000?[`iP050?[`
iP070;VbZP000000`k^c0<c4^`000000^K:Z0?[`iP02000000050;VbZP3Tfm80000004a9A@3jl>H0
0P0000020?[`iP80000000L0[jRQ00000033^k<0n_3V0<>k/`000000[jRQ00L0n_3V0P0000030?[`
iP8000000P3jl>H2000000040?[`iP00000000000=C<``80n_3V0P0000001@2i/ZX0i=_B0000001<
BDD0n_3V0080000000`0n_3V000000000000^K:Z0>CKdP000000C4U50?[`iP2TWIH000000<>k/`2T
WIH2000000H0n_3V00<0C4U50000003jl>H01@3jl>H200000080n_3V0P0000004P3jl>H000000000
003Dc<<0n_3V06IRGP000000k>;I0?[`iP3/h]T0000006IRGP2i/ZX000000<>k/`3<a;/000000;Vb
ZPD0n_3V00L0^K:Z00000033^k<0`k^c0000002i/ZX0n_3V008000001P3jl>H2000000050:BMUP1V
HUh0n_3V06IRGP2TWIH00P000000203jl>H0NGE`0=C<``3jl>H0i=_B0000001<BDD0n_3V0P000000
0`3Dc<<0n_3V0?[`iP02000000070?[`iP1iMG00e<c30?[`iP3Tfm80000004a9A@050?[`iP0507Ue
L0000000c<Bk0000001VHUh00P3jl>H0102TWIH000000<>k/`2TWIH20000000F0?[`iP0000000000
0;VbZP3Tfm80000004a9A@3jl>H0^K:Z00000033^k<0c<Bk0000002i/ZX0n_3V06IRGP000000n_3V
0>CKdP000000NGE`0?[`iP800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P000000103Le</0
RHAn04a9A@3<a;/20?[`iP040:nXX@00000000000:nXX@H0n_3V00<0Ui6;0000003Tfm801P3jl>H0
102_Z:4000000000002_Z:420?[`iP80000000@0c<Bk07UeL01<BDD0c<Bk100000002P3jl>H00000
0000001VHUh000000>cRf@3jl>H0k>;I0000001VHUh70?[`iP8000000`3jl>H200000080n_3V0P00
00001P3jl>H0000000000029Q7h0NGE`0?[`iP80000000D0c<Bk07UeL01<BDD0c<Bk0?[`iP020000
00070?[`iP00000000000<c4^`1iMG00C4U50<c4^`020?[`iP0308V4OP1VHUh0c<Bk008000001P3j
l>H00`2GTH/000000>CKdP050?[`iP8000000P3jl>H2000000040?[`iP000000000008V4OP800000
00P0RHAn0?[`iP3jl>H0n_3V08V4OP000000g=C;0:nXX@80000000<0[jRQ0?[`iP3jl>H01@3jl>H0
1@2_Z:40C4U50000002_Z:40n_3V00@000001@3jl>H20000000506IRGP2TWIH0n_3V09NAR`1VHUh0
0P0000000`3jl>H0i=_B08V4OP020000000306IRGP3Dc<<0n_3V0080000000<0RHAn07UeL03jl>H0
0P0000000`3jl>H0i=_B08V4OP020000000306IRGP3Dc<<0n_3V00@0n_3V00D0Y9fF00000029Q7h0
00000:BMUP030?[`iP0308V4OP1VHUh0c<Bk0080000000L0n_3V000000000000c<Bk07UeL01<BDD0
c<Bk0080n_3V00@0[jRQ000000000000[jRQ0P3jl>H01`3Tfm80NGE`000000000000RHAn0>CKdP3j
l>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000100n_3V00L0i=_B0000002GTH/0
n_3V0=C<``000000NGE`00l0n_3V0P0000020?[`iP8000003P3jl>H2000002`0n_3V00L0i=_B0000
002GTH/0n_3V0=C<``000000RHAn02D0n_3V0P0000060?[`iP<0000000<0c<Bk0?[`iP33^k<00`00
000K0?[`iP050<c4^`000000000000000033^k<0Y03jl>H10?ooo`00P@3jl>H6000000030?[`iP00
000000000140n_3V00H0g=C;07UeL0000000000009NAR`3/h]T?0?[`iP040=cDb`29Q7h0n_3V0?[`
iP800000303jl>H6000001@0n_3V0P00000E0?[`iP050=cDb`1iMG0000000000002TWIH09P3jl>H0
103<a;/0IV9N00000029Q7h40?[`iP<0000000<0k>;I0?[`iP3Le</00`00000=0?[`iP800000303j
l>H01@3/h]T00000000000000000i=_B01h0n_3V0P0000240?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo0000
\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.91304 .38333 L
s
.91304 .05 m
.91304 .38333 L
s
.66291 .18147 m
.91304 .18147 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.91304 .38333 Mdot
.66291 .18147 Mdot
.91304 .18147 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V2P3=QCl20?[`iP80000000<0n_3V0<f5
?`3=QCl0203=QCo10?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00>L0n_3V1P3=QCl<0?[`iP04
0000003jl>H00000000000T0n_3V1`3=QCnj0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00>D0
n_3V0P3=QClB0?[`iP050000003jl>H0n_3V0?[`iP0000003`3jl>H20<f5?kP0n_3V00<000000?[`
iP3jl>H0:@3jl>H10?ooo`00h@3jl>H40<f5?a@0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000
n_3V0?[`iP0>0?[`iP<0cHDo]@3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo003M0?[`iP@0cHDo
603jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0100n_3V103=QCna0?[`iP030000
003jl>H0n_3V02T0n_3V0@3oool00=/0n_3V0P3=QClL0?[`iP030000003jl>H0n_3V00@0n_3V0P00
000D0?[`iP80cHDo[`3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo003I0?[`iP80cHDo7P3jl>H0
0`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V01<0n_3V0P3=QCn]0?[`iP030000003jl>H0
n_3V02T0n_3V0@3oool00=L0n_3V0P3=QClP0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`
iP3jl>H0503jl>H20<f5?j/0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00e@3jl>H20<f5?b80
n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0E0?[`iP80cHDoZ@3jl>H00`000000
n_3V0?[`iP0Y0?[`iP40oooo003C0?[`iP80cHDo903jl>H00`000000n_3V0?[`iP090?[`iP800000
5`3jl>H20<f5?jL0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00d@3jl>H20<f5?bH0n_3V00<0
00000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0F0?[`iP80cHDoY@3jl>H00`000000n_3V0?[`
iP0Y0?[`iP40oooo003?0?[`iP80cHDo:03jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0
n_3V01L0n_3V0P3=QCnS0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00<h0n_3V00<0cHDo0?[`
iP3jl>H0:03jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V01P0n_3V00<0cHDo0?[`
iP3jl>H0X03jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo003<0?[`iP80cHDo:`3jl>H00`000000
n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V01P0n_3V0P3=QCnP0?[`iP030000003jl>H0n_3V02T0
n_3V0@3oool00<X0n_3V0P3=QCl]0?[`iP030000003jl>H0n_3V00l0n_3V0P00000J0?[`iP80cHDo
WP3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo00390?[`iP030<f5?`3jl>H0n_3V02d0n_3V00<0
00000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0I0?[`iP030<f5?`3jl>H0n_3V09/0n_3V00<0
00000?[`iP3jl>H0:@3jl>H10?ooo`00a`3jl>H20<f5?c00n_3V00<000000?[`iP3jl>H04P3jl>H0
0`000000n_3V0?[`iP0I0?[`iP80cHDoV`3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo00360?[`
iP030<f5?`3jl>H0n_3V0300n_3V00<000000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP0J0?[`
iP030<f5?`3jl>H0n_3V09P0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00a@3jl>H00`3=QCl0
n_3V0?[`iP0a0?[`iP030000003jl>H0n_3V01@0n_3V0P00000K0?[`iP030<f5?`3jl>H0n_3V09L0
n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00a03jl>H00`3=QCl0n_3V0?[`iP0b0?[`iP030000
003jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H06@3jl>H00`3=QCl0n_3V0?[`iP2F0?[`iP030000
003jl>H0n_3V02T0n_3V0@3oool00<80n_3V0P3=QCle0?[`iP030000003jl>H0n_3V01L0n_3V00<0
00000?[`iP3jl>H06@3jl>H20<f5?iH0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00`@3jl>H0
0`3=QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H06@3jl>H0
0`3=QCl0n_3V0?[`iP2D0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00<00n_3V00<0cHDo0?[`
iP3jl>H0=P3jl>H00`000000n_3V0?[`iP0I0?[`iP8000006P3jl>H00`3=QCl0n_3V0?[`iP2C0?[`
iP030000003jl>H0n_3V02T0n_3V0@3oool00;l0n_3V00<0cHDo0?[`iP3jl>H0=`3jl>H00`000000
n_3V0?[`iP0K0?[`iP030000003jl>H0n_3V01P0n_3V0P3=QCnC0?[`iP030000003jl>H0n_3V02T0
n_3V0@3oool00;h0n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP0L0?[`iP030000
003jl>H0n_3V01T0n_3V00<0cHDo0?[`iP3jl>H0T03jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo
002m0?[`iP030<f5?`3jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H07@3jl>H00`000000n_3V0?[`
iP0I0?[`iP030<f5?`3jl>H0n_3V08l0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00_03jl>H0
0`3=QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V01h0n_3V0P00000J0?[`iP030<f5?`3jl>H0
n_3V08h0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00^`3jl>H00`3=QCl0n_3V0?[`iP0k0?[`
iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H05`3jl>H00`3=QCl0n_3V0?[`iP2>0?[`
iP030000003jl>H0n_3V02T0n_3V0@3oool00;X0n_3V00<0cHDo0?[`iP3jl>H0?03jl>H00`000000
n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V01L0n_3V00<0cHDo0?[`iP3jl>H0S@3jl>H00`000000
n_3V0?[`iP0Y0?[`iP40oooo002i0?[`iP030<f5?`3jl>H0n_3V03d0n_3V00<000000?[`iP3jl>H0
8P3jl>H00`000000n_3V0?[`iP0G0?[`iP80cHDoS@3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo
002h0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H08`3jl>H2000001P0n_3V00<0
cHDo0?[`iP3jl>H0R`3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo002h0?[`iP030<f5?`3jl>H0
n_3V03h0n_3V00<000000?[`iP3jl>H09@3jl>H00`000000n_3V0?[`iP0F0?[`iP030<f5?`3jl>H0
n_3V08X0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00]`3jl>H00`3=QCl0n_3V0?[`iP0o0?[`
iP030000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H05P3jl>H00`3=QCl0n_3V0?[`iP290?[`
iP030000003jl>H0n_3V02T0n_3V0@3oool00;H0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000
n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V01D0n_3V00<0cHDo0?[`iP3jl>H0R@3jl>H00`000000
n_3V0?[`iP0Y0?[`iP40oooo002f0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0
:03jl>H2000001H0n_3V00<0cHDo0?[`iP3jl>H0R03jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo
002e0?[`iP030<f5?`3jl>H0n_3V0440n_3V00<000000?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`
iP0D0?[`iP030<f5?`3jl>H0n_3V08L0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00]03jl>H0
0`3=QCl0n_3V0?[`iP120?[`iP030000003jl>H0n_3V02/0n_3V00<000000?[`iP3jl>H0503jl>H0
0`3=QCl0n_3V0?[`iP260?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00;<0n_3V00<0cHDo0?[`
iP3jl>H0@`3jl>H00`000000n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V01@0n_3V00<0cHDo0?[`
iP3jl>H0Q@3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo002b0?[`iP030<f5?`3jl>H0n_3V04@0
n_3V00<000000?[`iP3jl>H0;@3jl>H2000001@0n_3V00<0cHDo0?[`iP3jl>H0Q@3jl>H00`000000
n_3V0?[`iP0Y0?[`iP40oooo002b0?[`iP030<f5?`3jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H0
;`3jl>H00`000000n_3V0?[`iP0B0?[`iP030<f5?`3jl>H0n_3V08@0n_3V00<000000?[`iP3jl>H0
:@3jl>H10?ooo`00/@3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V0300n_3V00<0
00000?[`iP3jl>H04@3jl>H00`3=QCl0n_3V0?[`iP240?[`iP030000003jl>H0n_3V02T0n_3V0@3o
ool00;40n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP0a0?[`iP030000003jl>H0
n_3V0140n_3V00<0cHDo0?[`iP3jl>H0P`3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo002`0?[`
iP030<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP0@0?[`
iP030<f5?`3jl>H0n_3V08<0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00/03jl>H00`3=QCl0
n_3V0?[`iP160?[`iP030000003jl>H0n_3V03<0n_3V0P00000A0?[`iP030<f5?`3jl>H0n_3V0880
n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00[`3jl>H00`3=QCl0n_3V0?[`iP170?[`iP030000
003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H03P3jl>H00`3=QCl0n_3V0?[`iP220?[`iP030000
003jl>H0n_3V02T0n_3V0@3oool00:l0n_3V00<0cHDo0?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`
iP0f0?[`iP030000003jl>H0n_3V00h0n_3V00<0cHDo0?[`iP3jl>H0P@3jl>H00`000000n_3V0?[`
iP0Y0?[`iP40oooo002^0?[`iP030<f5?`3jl>H0n_3V04P0n_3V00<000000?[`iP3jl>H0=`3jl>H0
0`000000n_3V0?[`iP0>0?[`iP030<f5?`3jl>H0n_3V0800n_3V00<000000?[`iP3jl>H0:@3jl>H1
0?ooo`00[@3jl>H00`3=QCl0n_3V0?[`iP190?[`iP030000003jl>H0n_3V03P0n_3V0P00000>0?[`
iP030<f5?`3jl>H0n_3V0800n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00[@3jl>H00`3=QCl0
n_3V0?[`iP190?[`iP030000003jl>H0n_3V03X0n_3V00<000000?[`iP3jl>H0303jl>H00`3=QCl0
n_3V0?[`iP1o0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00:`0n_3V00<0cHDo0?[`iP3jl>H0
BP3jl>H00`000000n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V00/0n_3V00<0cHDo0?[`iP3jl>H0
O`3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo002/0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<0
00000?[`iP3jl>H0?03jl>H00`000000n_3V0?[`iP0;0?[`iP030<f5?`3jl>H0n_3V07h0n_3V00<0
00000?[`iP3jl>H0:@3jl>H10?ooo`000P000?nZ0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<00000
0?[`iP3jl>H0?@3jl>H2000000/0n_3V00<0cHDo0?[`iP3jl>H0OP3jl>H00`000000n_3V0?[`iP0V
0?[`iP80003o0@3jl>H10?ooo`000P3jl>H30000ojL0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`00
0000n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V00P0n_3V00<0cHDo0?[`iP3jl>H0OP3jl>H00`00
0000n_3V0?[`iP0S0?[`iP<0003o0`3jl>H10?ooo`001@3jl>H40000oj80n_3V00<0cHDo0?[`iP3j
l>H0B`3jl>H00`000000n_3V0?[`iP100?[`iP030000003jl>H0n_3V00L0n_3V00<0cHDo0?[`iP3j
l>H0OP3jl>H00`000000n_3V0?[`iP0O0?[`iP@0003o1P3jl>H10?ooo`002@3jl>H30000oil0n_3V
00<0cHDo0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP110?[`iP030000003jl>H0n_3V00L0n_3V
00<0cHDo0?[`iP3jl>H0O@3jl>H00`000000n_3V0?[`iP0L0?[`iP<0003o2P3jl>H10?ooo`00303j
l>H30000oi/0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP120?[`iP8000001`3j
l>H00`3=QCl0n_3V0?[`iP1m0?[`iP030000003jl>H0n_3V01T0n_3V0`000?l=0?[`iP40oooo000?
0?[`iP@0003oU`3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04@0n_3V00<00000
0?[`iP3jl>H01@3jl>H00`3=QCl0n_3V0?[`iP1l0?[`iP030000003jl>H0n_3V01D0n_3V10000?l@
0?[`iP40oooo000C0?[`iP<0003oU03jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V
04D0n_3V00<000000?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP1l0?[`iP030000003jl>H0n_3V
0180n_3V0`000?lD0?[`iP40oooo000F0?[`iP<0003oT@3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP03
0000003jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H00`3jl>H00`3=QCl0n_3V0?[`iP1l0?[`iP03
0000003jl>H0n_3V00l0n_3V0`000?lG0?[`iP40oooo000I0?[`iP<0003oS@3jl>H00`3=QCl0n_3V
0?[`iP1=0?[`iP030000003jl>H0n_3V04L0n_3V0P0000030?[`iP030<f5?`3jl>H0n_3V07`0n_3V
00<000000?[`iP3jl>H0303jl>H30000oaX0n_3V0@3oool001`0n_3V0`000?n:0?[`iP030<f5?`3j
l>H0n_3V04d0n_3V00<000000?[`iP3jl>H0B@3jl>H01@000000n_3V0?[`iP3jl>H0cHDo07d0n_3V
00<000000?[`iP3jl>H02@3jl>H30000oad0n_3V0@3oool001l0n_3V10000?n60?[`iP030<f5?`3j
l>H0n_3V04d0n_3V00<000000?[`iP3jl>H0BP3jl>H010000000n_3V0?[`iP3=QCmm0?[`iP030000
003jl>H0n_3V00H0n_3V0`000?lP0?[`iP40oooo000S0?[`iP<0003oP`3jl>H00`3=QCl0n_3V0?[`
iP1=0?[`iP030000003jl>H0n_3V04/0n_3V00<000000?[`iP3=QCl0O@3jl>H00`000000n_3V0?[`
iP030?[`iP<0003o8`3jl>H10?ooo`009P3jl>H30000ogl0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H0
0`000000n_3V0?[`iP1<0?[`iP@00000NP3jl>H3000000040?[`iP000?l0003o0000obH0n_3V0@3o
ool002T0n_3V0`000?ml0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0C03jl>H5
000007P0n_3V1@00000Y0?[`iP40oooo000/0?[`iP80003oNP3jl>H00`3=QCl0n_3V0?[`iP1>0?[`
iP030000003jl>H0n_3V04`0n_3VPP00000Y0?[`iP40oooo000^0?[`iP80003oN03jl>H00`3=QCl0
n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04`0n_3V1@00001f0?[`iP80003o1@00000Y0?[`iP40
oooo000`0?[`iP<0003oM03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04d0n_3V
0`0000000`3jl>H000000000001a0?[`iP<0003o0`3jl>H3000002X0n_3V0@3oool003<0n_3V0P00
0?mb0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H01@3=QCl0n_3V0?[`
iP3jl>H0000006h0n_3V0P000?l70?[`iP030000003jl>H0n_3V02T0n_3V0@3oool003D0n_3V0P00
0?m`0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`
iP020?[`iP030000003jl>H0n_3V06T0n_3V0P000?l90?[`iP030000003jl>H0n_3V02T0n_3V0@3o
ool003L0n_3V0`000?m]0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H0
0`3=QCl0n_3V0?[`iP030?[`iP030000003jl>H0n_3V06D0n_3V0`000?l;0?[`iP030000003jl>H0
n_3V02T0n_3V0@3oool003X0n_3V0P000?m[0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`
iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP040?[`iP030000003jl>H0n_3V0680n_3V0P000?l>0?[`
iP030000003jl>H0n_3V02T0n_3V0@3oool003`0n_3V0P000?mY0?[`iP030<f5?`3jl>H0n_3V04l0
n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP050?[`iP800000H03jl>H20000oa00
n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00?P3jl>H30000ofD0n_3V00<0cHDo0?[`iP3jl>H0
D03jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0
FP3jl>H30000oa80n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00@@3jl>H20000of<0n_3V00<0
cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H0E`3jl>H20000oaD0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00@`3jl>H2
0000of40n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0
n_3V00P0n_3V00<000000?[`iP3jl>H0E03jl>H20000oaL0n_3V00<000000?[`iP3jl>H0:@3jl>H1
0?ooo`00A@3jl>H20000oel0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`
iP030<f5?`3jl>H0n_3V00T0n_3V0P00001B0?[`iP80003o6@3jl>H00`000000n_3V0?[`iP0Y0?[`
iP40oooo00170?[`iP80003oG@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500
n_3V00<0cHDo0?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP1=0?[`iP80003o6`3jl>H00`000000
n_3V0?[`iP0Y0?[`iP40oooo00190?[`iP<0003oFP3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000
003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP1:0?[`iP80003o
7@3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo001<0?[`iP80003oF03jl>H00`3=QCl0n_3V0?[`
iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`
iP170?[`iP80003o7`3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo001>0?[`iP80003oEP3jl>H0
0`3=QCl0n_3V0?[`iP1?0?[`iP<00000D@3jl>H00`3=QCl0n_3V0?[`iP0>0?[`iP800000A@3jl>H2
0000ob40n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00D03jl>H20000oe@0n_3V00<0cHDo0?[`
iP3jl>H0CP3jl>H500000500n_3V00<0cHDo0?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP100?[`
iP80003o8`3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo001B0?[`iP80003oDP3jl>H00`3=QCl0
n_3V0?[`iP1>0?[`iPD00000D03jl>H00`3=QCl0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V03d0
n_3V0P000?lU0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool005@0n_3V0P000?m@0?[`iP030<f5
?`3jl>H0n_3V04h0n_3V1@00001@0?[`iP030<f5?`3jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0
>P3jl>H20000obL0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00EP3jl>H20000odh0n_3V00<0
cHDo0?[`iP3jl>H0C`3jl>H300000540n_3V00<0cHDo0?[`iP3jl>H04`3jl>H2000003P0n_3V0P00
0?lY0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool005P0n_3V0P000?m<0?[`iP030<f5?`3jl>H0
n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP030000003jl>H0
n_3V03<0n_3V0P000?l[0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool005X0n_3V00<0003o0?[`
iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`
iP3jl>H05P3jl>H00`000000n_3V0?[`iP0`0?[`iP80003o;@3jl>H00`000000n_3V0?[`iP0Y0?[`
iP40oooo001K0?[`iP80003oB@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500
n_3V00<0cHDo0?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP0]0?[`iP80003o;`3jl>H00`000000
n_3V0?[`iP0Y0?[`iP40oooo001M0?[`iP80003oA`3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000
003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H0603jl>H2000002/0n_3V0P000?la0?[`iP030000
003jl>H0n_3V02T0n_3V0@3oool005l0n_3V0P000?m50?[`iP030<f5?`3jl>H0n_3V0500n_3V00<0
00000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V02H0n_3V0P00
0?lc0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00640n_3V00<0003o0?[`iP3jl>H0@P3jl>H0
0`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H06`3jl>H0
0`000000n_3V0?[`iP0S0?[`iP80003o=@3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo001R0?[`
iP80003o@P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`
iP3jl>H0703jl>H00`000000n_3V0?[`iP0P0?[`iP80003o=`3jl>H00`000000n_3V0?[`iP0Y0?[`
iP40oooo001T0?[`iP80003o@03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V04l0
n_3V00<0cHDo0?[`iP3jl>H07P3jl>H2000001h0n_3V0P000?li0?[`iP030000003jl>H0n_3V02T0
n_3V0@3oool006H0n_3V0P000?lo0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0
C`3jl>H00`3=QCl0n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V01T0n_3V0P000?lk0?[`iP030000
003jl>H0n_3V02T0n_3V0@3oool006P0n_3V00<0003o0?[`iP3jl>H0?03jl>H00`3=QCl0n_3V0?[`
iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`
iP0G0?[`iP030000o`3jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00J@3jl>H2
0000oc`0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0
n_3V0280n_3V00<000000?[`iP3jl>H0503jl>H20000och0n_3V00<000000?[`iP3jl>H0:@3jl>H1
0?ooo`00J`3jl>H20000ocX0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`
iP030<f5?`3jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H04P3jl>H00`000?l0n_3V0?[`iP0n0?[`
iP030000003jl>H0n_3V02T0n_3V0@3oool006d0n_3V00<0003o0?[`iP3jl>H0=`3jl>H00`3=QCl0
n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0903jl>H200000100
n_3V0P000?m10?[`iP030000003jl>H0n_3V02T0n_3V0@3oool006h0n_3V0P000?lg0?[`iP030<f5
?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0W0?[`iP030000
003jl>H0n_3V00/0n_3V0P000?m30?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00700n_3V0P00
0?lf0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`
iP0X0?[`iP030000003jl>H0n_3V00T0n_3V00<0003o0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`
iP0Y0?[`iP40oooo001b0?[`iP030000o`3jl>H0n_3V03<0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H0
0`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V02T0n_3V00<000000?[`iP3jl>H01P3jl>H2
0000odH0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00L`3jl>H20000oc<0n_3V00<0cHDo0?[`
iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V02X0n_3V0P0000050?[`
iP030000o`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00M@3jl>H20000oc40
n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V02d0
n_3V00<000000?[`iP3jl>H00P000?m90?[`iP030000003jl>H0n_3V02T0n_3V0@3oool007L0n_3V
00<0003o0?[`iP3jl>H0;`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V04d0n_3V
00<0cHDo0?[`iP3jl>H0;P3jl>H00`000000003o0?[`iP1:0?[`iP030000003jl>H0n_3V02T0n_3V
0@3oool007P0n_3V0P000?l_0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0C@3j
l>H00`3=QCl0n_3V0?[`iP0]0?[`iP030000o`3jl>H0000004/0n_3V00<000000?[`iP3jl>H0:@3j
l>H10?ooo`00NP3jl>H20000obd0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1=
0?[`iP030<f5?`3jl>H0n_3V02/0n_3V0P000?l30?[`iP800000B@3jl>H00`000000n_3V0?[`iP0Y
0?[`iP40oooo001l0?[`iP030000o`3jl>H0n_3V02X0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`00
0000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02/0n_3V00<0003o0?[`iP3jl>H01@3jl>H00`00
0000n_3V0?[`iP160?[`iP030000003jl>H0n_3V02T0n_3V0@3oool007d0n_3V0P000?l[0?[`iP03
0<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V0?[`iP0Y0?[`iP80
003o2@3jl>H00`000000n_3V0?[`iP150?[`iP030000003jl>H0n_3V02T0n_3V0@3oool007l0n_3V
0P000?lY0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V
0?[`iP0W0?[`iP80003o303jl>H00`000000n_3V0?[`iP140?[`iP030000003jl>H0n_3V02T0n_3V
0@3oool00840n_3V00<0003o0?[`iP3jl>H09P3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003j
l>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H09P3jl>H00`000?l0n_3V0?[`iP0=0?[`iP800000A03j
l>H00`000000n_3V0?[`iP0Y0?[`iP40oooo00220?[`iP80003o9P3jl>H00`3=QCl0n_3V0?[`iP1<
0?[`iP030000003jl>H0n_3V04/0n_3V00<0cHDo0?[`iP3jl>H09@3jl>H20000oa80n_3V00<00000
0?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo00240?[`iP80003o9@3jl>H00`3=
QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V04/0n_3V00<0cHDo0?[`iP3jl>H0903jl>H00`00
0?l0n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0:@3jl>H10?oo
o`00QP3jl>H00`000?l0n_3V0?[`iP0R0?[`iP030<f5?`3jl>H0n_3V04/0n_3V00<000000?[`iP3j
l>H0BP3jl>H00`3=QCl0n_3V0?[`iP0S0?[`iP80003o5`3jl>H00`000000n_3V0?[`iP0o0?[`iP03
0000003jl>H0n_3V02T0n_3V0@3oool008L0n_3V0P000?lS0?[`iP030<f5?`3jl>H0n_3V04X0n_3V
00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0Q0?[`iP80003o6P3jl>H2000003l0n_3V
00<000000?[`iP3jl>H0:@3jl>H10?ooo`00R@3jl>H20000ob40n_3V00<0cHDo0?[`iP3jl>H0BP3j
l>H00`000000n_3V0?[`iP1:0?[`iP030<f5?`3jl>H0n_3V0200n_3V00<0003o0?[`iP3jl>H0703j
l>H00`000000n_3V0?[`iP0l0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool008/0n_3V0P000?lO
0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0N
0?[`iP80003o803jl>H00`000000n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool0
08d0n_3V00<0003o0?[`iP3jl>H0703jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V
04T0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V
03X0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00SP3jl>H20000oad0n_3V00<0cHDo0?[`iP3j
l>H0B@3jl>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V01`0n_3V0P000?lU0?[`iP80
0000>P3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo002@0?[`iP80003o703jl>H00`3=QCl0n_3V
0?[`iP180?[`iP030000003jl>H0n_3V04P0n_3V00<0cHDo0?[`iP3jl>H06`3jl>H20000obT0n_3V
00<000000?[`iP3jl>H0=`3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo002B0?[`iP030000o`3j
l>H0n_3V01T0n_3V00<0cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP170?[`iP030<f5?`3j
l>H0n_3V01/0n_3V00<0003o0?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`iP0f0?[`iP030000003j
l>H0n_3V02T0n_3V0@3oool009<0n_3V0P000?lJ0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<00000
0?[`iP3jl>H0A`3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP80003o;P3jl>H00`000000n_3V0?[`iP0e
0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool009D0n_3V00<0003o0?[`iP3jl>H05`3jl>H00`3=
QCl0n_3V0?[`iP170?[`iP030000003jl>H0n_3V04H0n_3V00<0cHDo0?[`iP3jl>H06@3jl>H00`00
0?l0n_3V0?[`iP0_0?[`iP800000=@3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo002F0?[`iP80
003o603jl>H00`3=QCl0n_3V0?[`iP160?[`iP030000003jl>H0n_3V04H0n_3V00<0cHDo0?[`iP3j
l>H05`3jl>H20000oc@0n_3V00<000000?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP0Y0?[`iP40
oooo002H0?[`iP030000o`3jl>H0n_3V01D0n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V
0?[`iP150?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<0003o0?[`iP3jl>H0=@3jl>H00`000000n_3V
0?[`iP0a0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool009T0n_3V0P000?lF0?[`iP030<f5?`3j
l>H0n_3V04D0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP80003o>@3j
l>H00`000000n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool009/0n_3V00<0003o
0?[`iP3jl>H04`3jl>H00`3=QCl0n_3V0?[`iP150?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo
0?[`iP3jl>H05@3jl>H00`000?l0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V02l0n_3V00<00000
0?[`iP3jl>H0:@3jl>H10?ooo`00W03jl>H20000oa@0n_3V00<0cHDo0?[`iP3jl>H0A03jl>H00`00
0000n_3V0?[`iP140?[`iP030<f5?`3jl>H0n_3V01<0n_3V0P000?ln0?[`iP800000;`3jl>H00`00
0000n_3V0?[`iP0Y0?[`iP40oooo002N0?[`iP030000o`3jl>H0n_3V0180n_3V00<0cHDo0?[`iP3j
l>H0@`3jl>H00`000000n_3V0?[`iP130?[`iP030<f5?`3jl>H0n_3V01<0n_3V00<0003o0?[`iP3j
l>H0@03jl>H00`000000n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool009l0n_3V
0P000?lB0?[`iP030<f5?`3jl>H0n_3V04<0n_3V00<000000?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V
0?[`iP0B0?[`iP80003oA03jl>H00`000000n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V02T0n_3V
0@3oool00:40n_3V00<0003o0?[`iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP120?[`iP030000003j
l>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H04@3jl>H00`000?l0n_3V0?[`iP150?[`iP030000003j
l>H0n_3V02X0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00XP3jl>H20000oa40n_3V00<0cHDo
0?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP110?[`iP030<f5?`3jl>H0n_3V0100n_3V0P000?m9
0?[`iP800000:P3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo002T0?[`iP030000o`3jl>H0n_3V
00l0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP100?[`iP030<f5?`3jl>H0n_3V
0100n_3V00<0003o0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V
02T0n_3V0@3oool00:D0n_3V0P000?l?0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3j
l>H0?`3jl>H00`3=QCl0n_3V0?[`iP0?0?[`iP80003oC`3jl>H00`000000n_3V0?[`iP0V0?[`iP03
0000003jl>H0n_3V02T0n_3V0@3oool00:L0n_3V00<0003o0?[`iP3jl>H03@3jl>H00`3=QCl0n_3V
0?[`iP0o0?[`iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H03P3jl>H00`000?l0n_3V
0?[`iP1@0?[`iP030000003jl>H0n_3V02D0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00Z03j
l>H20000o`h0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0n0?[`iP030<f5?`3j
l>H0n_3V00d0n_3V0P000?mD0?[`iP8000009@3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo002Z
0?[`iP80003o303jl>H00`3=QCl0n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03d0n_3V00<0cHDo
0?[`iP3jl>H0303jl>H20000oeP0n_3V00<000000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP0Y
0?[`iP40oooo002/0?[`iP030000o`3jl>H0n_3V00X0n_3V00<0cHDo0?[`iP3jl>H0?@3jl>H00`00
0000n_3V0?[`iP0m0?[`iP030<f5?`3jl>H0n_3V00X0n_3V0P000?mK0?[`iP030000003jl>H0n_3V
0240n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00[@3jl>H20000o`/0n_3V0P3=QClm0?[`iP03
0000003jl>H0n_3V03/0n_3V0P3=QCl<0?[`iP030000o`3jl>H0n_3V05`0n_3V00<000000?[`iP3j
l>H0803jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo002_0?[`iP80003o2P3jl>H00`3=QCl0n_3V
0?[`iP0k0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H02P3jl>H20000of00n_3V
0P00000P0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00;40n_3V00<0003o0?[`iP3jl>H0203j
l>H00`3=QCl0n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo0?[`iP3jl>H0203j
l>H20000of@0n_3V00<000000?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo002b
0?[`iP80003o2@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V03T0n_3V00<0cHDo
0?[`iP3jl>H01`3jl>H20000ofL0n_3V00<000000?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP0Y
0?[`iP40oooo002d0?[`iP80003o203jl>H00`3=QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V
03P0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP1X0?[`iP030000003jl>H0n_3V
01/0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00]P3jl>H00`000?l0n_3V0?[`iP060?[`iP03
0<f5?`3jl>H0n_3V03L0n_3V00<000000?[`iP3jl>H0=`3jl>H00`3=QCl0n_3V0?[`iP060?[`iP80
003oK03jl>H2000001/0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00]`3jl>H20000o`L0n_3V
0P3=QClg0?[`iP030000003jl>H0n_3V03D0n_3V0P3=QCl70?[`iP80003oL03jl>H00`000000n_3V
0?[`iP0H0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00;T0n_3V0P000?l60?[`iP030<f5?`3j
l>H0n_3V03D0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=QCl0n_3V0?[`iP050?[`iP80003oL`3j
l>H00`000000n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00;/0n_3V00<0003o
0?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0n_3V03@0n_3V00<0cHDo
0?[`iP3jl>H0103jl>H00`000?l0n_3V0?[`iP1d0?[`iP030000003jl>H0n_3V01H0n_3V00<00000
0?[`iP3jl>H0:@3jl>H10?ooo`00_03jl>H20000o`D0n_3V0P3=QCld0?[`iP030000003jl>H0n_3V
0380n_3V0P3=QCl50?[`iP80003oN03jl>H2000001H0n_3V00<000000?[`iP3jl>H0:@3jl>H10?oo
o`00_P3jl>H20000o`D0n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0a0?[`iP03
0<f5?`3jl>H0n_3V00<0n_3V0P000?ml0?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3j
l>H0:@3jl>H10?ooo`00`03jl>H00`000?l0n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V0300n_3V
00<000000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP020?[`iP80003oO`3jl>H00`000000n_3V
0?[`iP0B0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00<40n_3V0P000?l40?[`iP030<f5?`3j
l>H0n_3V02l0n_3V00<000000?[`iP3jl>H0;`3jl>H0103=QCl0n_3V0?[`iP3jl>H20000oh80n_3V
00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo00330?[`iP80003o0`3j
l>H20<f5?bl0n_3V00<000000?[`iP3jl>H0;@3jl>H20<f5?`<0n_3V00<0003o0?[`iP3jl>H0P`3j
l>H200000140n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00a@3jl>H20000o`<0n_3V00<0cHDo
0?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0/0?[`iP040<f5?`3jl>H0n_3V0?[`iP80003oR03j
l>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00<L0n_3V0P000?l2
0?[`iP80cHDo;03jl>H00`000000n_3V0?[`iP0Z0?[`iP80cHDo0P3jl>H20000oh/0n_3V00<00000
0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo00390?[`iP80003o0P3jl>H20<f5
?bX0n_3V00<000000?[`iP3jl>H0:03jl>H20<f5?`80n_3V0P000?n>0?[`iP030000003jl>H0n_3V
00`0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00b`3jl>H20000o`80n_3V00<0cHDo0?[`iP3j
l>H09`3jl>H00`000000n_3V0?[`iP0W0?[`iP030<f5?`3jl>H0n_3V0080003oT@3jl>H00`000000
n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00<d0n_3V0P000?l00`3jl>H0cHDo
0<f5?`0W0?[`iP030000003jl>H0n_3V02D0n_3V0P3=QCl00`3jl>H0003o0000o`2D0?[`iP800000
2`3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo003?0?[`iP<0003o0P3=QClU0?[`iP030000003j
l>H0n_3V02<0n_3V0P3=QCl00`3jl>H0003o0000o`2H0?[`iP030000003jl>H0n_3V00P0n_3V00<0
00000?[`iP3jl>H0:@3jl>H10?ooo`00dP3jl>H30000o`030<f5?`3jl>H0n_3V0240n_3V00<00000
0?[`iP3jl>H08@3jl>H20<f5?`030?[`iP000?l0003o09/0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP0Y0?[`iP40oooo003E0?[`iP80003o00<0cHDo0?[`iP3jl>H07`3jl>H00`00
0000n_3V0?[`iP0O0?[`iP80cHDo0`000?nN0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`
iP3jl>H0:@3jl>H10?ooo`00e`3jl>H30000oal0n_3V00<000000?[`iP3jl>H07@3jl>H20<f5?`80
003oXP3jl>H2000000H0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00fP3jl>H30000o`030<f5
?`3jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06@3jl>H30<f5?`<0003oYP3jl>H00`000000n_3V
0?[`iP030?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00=d0n_3V0`000?lI0?[`iP030000003j
l>H0n_3V01L0n_3V00<0cHDo0000o`000?l00P000?nZ0?[`iP030000003jl>H0n_3V0080n_3V00<0
00000?[`iP3jl>H0:@3jl>H10?ooo`00h03jl>H40000oaD0n_3V00<000000?[`iP3jl>H04`3jl>H0
0`3=QCl0003o0000o`020000ojl0n_3V00D000000?[`iP3jl>H0n_3V0000000[0?[`iP40oooo003T
0?[`iP@0003o4@3jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`000?l0003o0080003o]03jl>H5
000002X0n_3V0@3oool00>P0n_3V10000?l=0?[`iP030000003jl>H0n_3V00/0n_3V1@000?ni0?[`
iPD00000:@3jl>H10?ooo`00k03=QCl=0000o`03000000000?l0003o00/0003o_P3=QCl5000002P0
cHDo0@3jl>H10?ooo`00o`3jl>K60?[`iPD00000:@3jl>H10?ooo`00o`3jl>K70?[`iP<00000:P3j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo002f0?[`iP80000000<0
IV9N0<c4^`3jl>H0:`3jl>H01P3Dc<<0IV9N000000000000RHAn0>CKdVD0n_3V00H0e<c306IRGP00
0000000008V4OP3Tfm:L0?[`iP40oooo002h0?[`iP0306IRGP000000g=C;02/0n_3V00H0C4U50<>k
/`3jl>H0k>;I00000029Q7iU0?[`iP0604a9A@33^k<0n_3V0>cRf@000000RHAnW03jl>H10?ooo`00
P`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H0102_Z:40C4U500000029Q7h70?[`iP06
0=cDb`1iMG00000000000029Q7h0c<Bk0P3jl>H0102_Z:40C4U500000029Q7h20?[`iP8000000P3j
l>H2000000050?[`iP3<a;/0000007UeL03jl>H00P0000020?[`iP80000000<0IV9N0?[`iP3jl>H0
1`3jl>H2000000<0n_3V00@0c<Bk04a9A@1VHUh0i=_B0P0000000`3jl>H00000000000030?[`iP80
00000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H200000080n_3V00<0RHAn06IR
GP3<a;/00P0000070?[`iP050=cDb`1iMG00000004a9A@2TWIH00P3jl>H0103<a;/0C4U506IRGP3T
fm82000000030?[`iP000000000000@0n_3V00<0Y9fF0000002TWIH00`3jl>H0102_Z:40C4U50000
0029Q7h70?[`iP040:nXX@1<BDD0C4U50:nXX@80n_3V0P0000060?[`iP80000000D0n_3V0<>k/`00
0000`k^c0?[`iP02000000050?[`iP3<a;/0C4U504a9A@2_Z:400P0000000`3jl>H0000000000003
0?[`iP80000000D0n_3V0<c4^`1<BDD0C4U50:nXX@02000000@0n_3V0P0000000`3/h]T0n_3V0>cR
f@0200000080n_3V00<0RHAn06IRGP3<a;/00P0000000`3jl>H00000000000020?[`iP8000000P3j
l>H0102_Z:40C4U500000029Q7h20?[`iP070>cRf@2GTH/000000000001iMG00i=_B0?[`iP020000
08@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2000000070?[`iP2_Z:4000000<>k
/`3Tfm80000008V4OP050?[`iP050>CKdP000000Ui6;0?[`iP2i/ZX00P000000203jl>H0[jRQ0000
0033^k<0i=_B00000029Q7h0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP3<a;/000000080000000<0i=_B0?[`iP3jl>H01P3jl>H2000000<0n_3V00@0IV9N0000
003Tfm80^K:Z0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP8000000P3jl>H2000000050?[`iP2TWIH000000<>k/`2TWIH00P0000060?[`iP0<0>CK
dP000000Ui6;0?[`iP3Dc<<0000008V4OP3jl>H0IV9N0000003Tfm80^K:Z0P0000000`3jl>H00000
000000040?[`iP<0000000P0k>;I0?[`iP2_Z:4000000<>k/`3Tfm80000008V4OPD0n_3V00L0^K:Z
00000033^k<0`k^c0000002i/ZX0n_3V008000001P3jl>H2000000050?[`iP2GTH/0000009NAR`3j
l>H00P0000001@3jl>H0C4U50000003Tfm80`k^c0080000000<0n_3V0000000000000`3jl>H20000
00050?[`iP1<BDD000000>CKdP33^k<00P0000040?[`iP0<08V4OP000000e<c30?[`iP3Dc<<00000
08V4OP3jl>H0Y9fF00000033^k<0Y9fF0P0000000`3jl>H00000000000020?[`iP80000000l0n_3V
0:nXX@000000`k^c0>CKdP000000RHAn0?[`iP1iMG0000000>CKdP3/h]T0000006IRGP3jl>H00P00
00240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0C4U500000009
0?[`iP0309NAR`000000g=C;0080n_3V0P0000000`3jl>H0C4U5000000050?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000001P3jl>H0Ui6;00000029Q7h000000:nXX@P0n_3V
0P0000030?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V0P0000020?[`iP800000
00@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V04a9A@0000000P3jl>H2000000H0
n_3V00<0Ui6;0000003Tfm801@3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP08
0;VbZP000000RHAn0000002i/ZX0n_3V04a9A@0000090?[`iP0706IRGP000000n_3V0?[`iP000000
IV9N0?[`iP02000000H0n_3V0P0000001@3jl>H0C4U50000001<BDD0n_3V0080000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000000<0n_3V0P0000000`3jl>H00000000000020?[`
iP800000103jl>H00`2_Z:40000000000003000000040:nXX@3jl>H0C4U500000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V04a9A@0000001`3jl>H01@3Dc<<0Y9fF0000001<
BDD0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V
000000000000100000050?[`iP0304a9A@000000n_3V0080n_3V0P0000000`3jl>H0000000000004
000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000H0n_3V
04a9A@000000k>;I0000001VHUh80?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H00000
000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000060?[`iP8000001P3jl>H200000080n_3V0P0000000`3jl>H0
0000000000030?[`iP80C4U500@0k>;I04a9A@1<BDD0n_3V1P0000050?[`iP8000000P3jl>H20000
00030?[`iP000000000000H0n_3V0P0000001@3Tfm80000009NAR`000000i=_B0080000000D0n_3V
0<c4^`000000Ui6;0>CKdP02000000030?[`iP000000000000<0n_3V0P0000001@3jl>H0c<Bk0000
002GTH/0i=_B00800000103jl>H0203Dc<<0000008V4OP3jl>H0Ui6;0000003Dc<<0n_3V0P000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0000000<0n_3V
0<c4^`1<BDD00P0000000`1<BDD0c<Bk0?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`
iP8000000P3jl>H2000000030?[`iP1<BDD000000080n_3V00<0000006IRGP3jl>H0103jl>H20000
0080n_3V0`0000000`3jl>H0C4U5000000020?[`iP030000001VHUh0n_3V008000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000001`3Le</0000008V4OP3jl>H0RHAn0000003Tfm801`3j
l>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P00
0000103jl>H000000000003jl>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`iP800000
1P3jl>H2000000H0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H02@3<a;/00000
0:BMUP3jl>H0Y9fF0000003<a;/0C4U5000000020?[`iP030000001VHUh0n_3V00@0n_3V00L0IV9N
0000003jl>H0n_3V0000001VHUh0n_3V008000001P3jl>H2000000050<c4^`000000g=C;0000003<
a;/00P0000020?[`iP030=cDb`2_Z:40NGE`0080000000<0n_3V0000000000000`3jl>H200000080
n_3V00<0g=C;0:nXX@1iMG000P0000050?[`iP050000001<BDD0n_3V04a9A@0000000P3jl>H0101<
BDD000000?[`iP3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0C4U500000002
0?[`iP070000001VHUh0n_3V04a9A@000000NGE`0<c4^`030?[`iP800000Q03jl>H10?ooo`00P`3j
l>H2000000<0n_3V0P0000002`2TWIH0i=_B0000001VHUh0n_3V0;VbZP000000`k^c0<c4^`000000
^K:Z00D0n_3V00<0C4U50000003jl>H01@3jl>H01`2i/ZX000000<>k/`3<a;/000000;VbZP3jl>H0
0P0000001@2i/ZX0i=_B0000001<BDD0n_3V008000000P3jl>H2000000070:nXX@000000`k^c0?[`
iP33^k<000000:nXX@070?[`iP8000000`3jl>H200000080n_3V0P000000103jl>H000000000003D
c<<20?[`iP80000000D0^K:Z0>CKdP000000C4U50?[`iP020000000<0?[`iP00000000000;VbZP3T
fm80000004a9A@3jl>H0Y9fF00000033^k<0Y9fF0P0000060?[`iP0304a9A@000000n_3V00D0n_3V
0P0000020?[`iP8000000180n_3V000000000000e<c30?[`iP1VHUh000000>cRf@3jl>H0k>;I0000
001VHUh0^K:Z00000033^k<0c<Bk0000002i/ZX50?[`iP070;VbZP000000`k^c0<>k/`000000^K:Z
0?[`iP02000000H0n_3V0P0000001@2TWIH0IV9N0?[`iP1VHUh0Y9fF0080000000P0n_3V07UeL03D
c<<0n_3V0>CKdP000000C4U50?[`iP80000000<0e<c30?[`iP3jl>H00P0000001`3jl>H0NGE`0=C<
``3jl>H0i=_B0000001<BDD01@3jl>H01@1iMG0000000<c4^`000000IV9N0080n_3V00@0Y9fF0000
0033^k<0Y9fF0P0000005P3jl>H000000000002i/ZX0i=_B0000001<BDD0n_3V0;VbZP000000`k^c
0<c4^`000000^K:Z0?[`iP1VHUh000000?[`iP3Tfm80000007UeL03jl>H2000008@0n_3V0@3oool0
08<0n_3V0P0000030?[`iP80000000@0g=C;08V4OP1<BDD0c<Bk0P3jl>H0102_Z:4000000000002_
Z:460?[`iP0309NAR`000000i=_B00H0n_3V00@0[jRQ000000000000[jRQ0P3jl>H2000000040<c4
^`1iMG00C4U50<c4^`@0000000X0n_3V000000000000IV9N0000003/h]T0n_3V0>cRf@000000IV9N
1`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000RHAn07UeL03jl>H20000
00050<c4^`1iMG00C4U50<c4^`3jl>H00P0000001`3jl>H000000000003<a;/0NGE`04a9A@3<a;/0
0P3jl>H00`29Q7h0IV9N0<c4^`02000000H0n_3V00<0Ui6;0000003Tfm801@3jl>H200000080n_3V
0P000000103jl>H0000000000029Q7h20000000808V4OP3jl>H0n_3V0?[`iP29Q7h000000=cDb`2_
Z:42000000030:nXX@3jl>H0n_3V00D0n_3V00D0[jRQ04a9A@000000[jRQ0?[`iP04000000D0n_3V
0P0000001@1VHUh0Y9fF0?[`iP2GTH/0IV9N0080000000<0n_3V0>CKdP29Q7h00P0000000`1VHUh0
e<c30?[`iP020000000308V4OP1iMG00n_3V0080000000<0n_3V0>CKdP29Q7h00P0000000`1VHUh0
e<c30?[`iP040?[`iP050:BMUP000000RHAn0000002TWIH00`3jl>H00`29Q7h0IV9N0<c4^`020000
00070?[`iP00000000000<c4^`1iMG00C4U50<c4^`020?[`iP040:nXX@00000000000:nXX@80n_3V
00L0i=_B07UeL0000000000008V4OP3Tfm80n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0
n_3V0P00000@0?[`iP070>CKdP000000Ui6;0?[`iP3Dc<<0000007UeL00?0?[`iP8000000P3jl>H2
000000h0n_3V0P00000/0?[`iP070>CKdP000000Ui6;0?[`iP3Dc<<0000008V4OP0U0?[`iP800000
1P3jl>H3000000030<c4^`3jl>H0`k^c00<000006`3jl>H01@3<a;/00000000000000000`k^c0:@0
n_3V0@3oool00840n_3V1P0000000`3jl>H000000000000A0?[`iP060=cDb`1iMG0000000000002G
TH/0k>;I3`3jl>H0103Le</0RHAn0?[`iP3jl>H2000000`0n_3V1P00000D0?[`iP8000005@3jl>H0
1@3Le</0NGE`000000000000Y9fF02H0n_3V00@0c<Bk06IRGP000000RHAn103jl>H3000000030>cR
f@3jl>H0g=C;00<000003@3jl>H2000000`0n_3V00D0k>;I00000000000000000>CKdP0N0?[`iP80
0000Q03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
.95652 .38333 L
s
.95652 .05 m
.95652 .38333 L
s
.65875 .16591 m
.95652 .16591 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
.95652 .38333 Mdot
.65875 .16591 Mdot
.95652 .16591 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V2P3=QCl20?[`iP<000002P3=QCoF0?[`
iP030000003jl>H0n_3V01@0n_3V0@3oool00>L0n_3V1P3=QCl<0?[`iP040000003jl>H0n_3V0000
00T0n_3V1`3=QCo?0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00>D0n_3V0P3=QClB0?[`iP05
0000003jl>H0n_3V0?[`iP0000003`3jl>H20<f5?ld0n_3V00<000000?[`iP3jl>H0503jl>H10?oo
o`00h@3jl>H40<f5?a@0n_3V00<000000?[`iP3jl>H00P3jl>H2000000l0n_3V0`3=QCo:0?[`iP03
0000003jl>H0n_3V01@0n_3V0@3oool00=d0n_3V103=QClH0?[`iP030000003jl>H0n_3V00@0n_3V
00<000000?[`iP3jl>H03`3jl>H40<f5?lH0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00f`3j
l>H20<f5?a`0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0B0?[`iP80cHDoa03j
l>H00`000000n_3V0?[`iP0D0?[`iP40oooo003I0?[`iP80cHDo7P3jl>H00`000000n_3V0?[`iP06
0?[`iP800000503jl>H20<f5?l80n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00e`3jl>H20<f5
?b00n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0C0?[`iP80cHDo`03jl>H00`00
0000n_3V0?[`iP0D0?[`iP40oooo003E0?[`iP80cHDo8P3jl>H00`000000n_3V0?[`iP090?[`iP03
0000003jl>H0n_3V01@0n_3V0P3=QCnn0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00=<0n_3V
0P3=QClT0?[`iP030000003jl>H0n_3V00X0n_3V0P00000F0?[`iP80cHDo_03jl>H00`000000n_3V
0?[`iP0D0?[`iP40oooo003A0?[`iP80cHDo9P3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003j
l>H0n_3V01D0n_3V0P3=QCnj0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00<l0n_3V0P3=QClX
0?[`iP030000003jl>H0n_3V00d0n_3V0P00000G0?[`iP80cHDo^03jl>H00`000000n_3V0?[`iP0D
0?[`iP40oooo003>0?[`iP030<f5?`3jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H03`3jl>H00`00
0000n_3V0?[`iP0F0?[`iP030<f5?`3jl>H0n_3V0;D0n_3V00<000000?[`iP3jl>H0503jl>H10?oo
o`00c03jl>H20<f5?b/0n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0F0?[`iP80
cHDo]@3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo003:0?[`iP80cHDo;@3jl>H00`000000n_3V
0?[`iP0A0?[`iP800000603jl>H20<f5?k<0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00b@3j
l>H00`3=QCl0n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H05`3j
l>H00`3=QCl0n_3V0?[`iP2`0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00<L0n_3V0P3=QCl`
0?[`iP030000003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H05`3jl>H20<f5?k00n_3V00<00000
0?[`iP3jl>H0503jl>H10?ooo`00aP3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V
01D0n_3V0P00000I0?[`iP030<f5?`3jl>H0n_3V0:d0n_3V00<000000?[`iP3jl>H0503jl>H10?oo
o`00a@3jl>H00`3=QCl0n_3V0?[`iP0a0?[`iP030000003jl>H0n_3V01L0n_3V00<000000?[`iP3j
l>H05`3jl>H00`3=QCl0n_3V0?[`iP2/0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00<@0n_3V
00<0cHDo0?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP0H0?[`iP800000603jl>H00`3=QCl0n_3V
0?[`iP2[0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00<80n_3V0P3=QCle0?[`iP030000003j
l>H0n_3V01X0n_3V00<000000?[`iP3jl>H05P3jl>H20<f5?j/0n_3V00<000000?[`iP3jl>H0503j
l>H10?ooo`00`@3jl>H00`3=QCl0n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V01/0n_3V00<00000
0?[`iP3jl>H05P3jl>H00`3=QCl0n_3V0?[`iP2Y0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool0
0<00n_3V00<0cHDo0?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP0L0?[`iP8000005`3jl>H00`3=
QCl0n_3V0?[`iP2X0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00;l0n_3V00<0cHDo0?[`iP3j
l>H0=`3jl>H00`000000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V01D0n_3V0P3=QCnX0?[`iP03
0000003jl>H0n_3V01@0n_3V0@3oool00;h0n_3V00<0cHDo0?[`iP3jl>H0>03jl>H00`000000n_3V
0?[`iP0O0?[`iP030000003jl>H0n_3V01H0n_3V00<0cHDo0?[`iP3jl>H0Y@3jl>H00`000000n_3V
0?[`iP0D0?[`iP40oooo002m0?[`iP030<f5?`3jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H0803j
l>H2000001L0n_3V00<0cHDo0?[`iP3jl>H0Y03jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002l
0?[`iP030<f5?`3jl>H0n_3V03X0n_3V00<000000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP0E
0?[`iP030<f5?`3jl>H0n_3V0:<0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00^`3jl>H00`3=
QCl0n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V02<0n_3V00<000000?[`iP3jl>H0503jl>H00`3=
QCl0n_3V0?[`iP2S0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00;X0n_3V00<0cHDo0?[`iP3j
l>H0?03jl>H00`000000n_3V0?[`iP0T0?[`iP8000005@3jl>H00`3=QCl0n_3V0?[`iP2R0?[`iP03
0000003jl>H0n_3V01@0n_3V0@3oool00;T0n_3V00<0cHDo0?[`iP3jl>H0?@3jl>H00`000000n_3V
0?[`iP0V0?[`iP030000003jl>H0n_3V01<0n_3V0P3=QCnR0?[`iP030000003jl>H0n_3V01@0n_3V
0@3oool00;P0n_3V00<0cHDo0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0W0?[`iP800000503j
l>H00`3=QCl0n_3V0?[`iP2P0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00;P0n_3V00<0cHDo
0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0Y0?[`iP030000003jl>H0n_3V0180n_3V00<0cHDo
0?[`iP3jl>H0W`3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002g0?[`iP030<f5?`3jl>H0n_3V
03l0n_3V00<000000?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`iP0B0?[`iP030<f5?`3jl>H0n_3V
09h0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00]P3jl>H00`3=QCl0n_3V0?[`iP100?[`iP03
0000003jl>H0n_3V02/0n_3V0P00000B0?[`iP030<f5?`3jl>H0n_3V09h0n_3V00<000000?[`iP3j
l>H0503jl>H10?ooo`00]P3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V02d0n_3V
00<000000?[`iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP2M0?[`iP030000003jl>H0n_3V01@0n_3V
0@3oool00;D0n_3V00<0cHDo0?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP0^0?[`iP030000003j
l>H0n_3V0100n_3V00<0cHDo0?[`iP3jl>H0W03jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002d
0?[`iP030<f5?`3jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0;`3jl>H200000140n_3V00<0cHDo
0?[`iP3jl>H0V`3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002c0?[`iP030<f5?`3jl>H0n_3V
04<0n_3V00<000000?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`3jl>H0n_3V
09X0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00/P3jl>H00`3=QCl0n_3V0?[`iP140?[`iP03
0000003jl>H0n_3V0380n_3V0P00000?0?[`iP030<f5?`3jl>H0n_3V09X0n_3V00<000000?[`iP3j
l>H0503jl>H10?ooo`00/P3jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V03@0n_3V
00<000000?[`iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP2I0?[`iP030000003jl>H0n_3V01@0n_3V
0@3oool00;40n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP0e0?[`iP030000003j
l>H0n_3V00`0n_3V00<0cHDo0?[`iP3jl>H0V@3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002a
0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0=P3jl>H2000000d0n_3V00<0cHDo
0?[`iP3jl>H0V03jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002`0?[`iP030<f5?`3jl>H0n_3V
04H0n_3V00<000000?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP0:0?[`iP030<f5?`3jl>H0n_3V
09P0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00/03jl>H00`3=QCl0n_3V0?[`iP160?[`iP03
0000003jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H02P3jl>H00`3=QCl0n_3V0?[`iP2G0?[`iP03
0000003jl>H0n_3V01@0n_3V0@3oool00:l0n_3V00<0cHDo0?[`iP3jl>H0A`3jl>H00`000000n_3V
0?[`iP0j0?[`iP8000002P3jl>H00`3=QCl0n_3V0?[`iP2G0?[`iP030000003jl>H0n_3V01@0n_3V
0@3oool00:l0n_3V00<0cHDo0?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`iP0l0?[`iP030000003j
l>H0n_3V00P0n_3V00<0cHDo0?[`iP3jl>H0UP3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002^
0?[`iP030<f5?`3jl>H0n_3V04P0n_3V00<000000?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP08
0?[`iP030<f5?`3jl>H0n_3V09D0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00[@3jl>H00`3=
QCl0n_3V0?[`iP190?[`iP030000003jl>H0n_3V03h0n_3V0P0000080?[`iP030<f5?`3jl>H0n_3V
09D0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00[@3jl>H00`3=QCl0n_3V0?[`iP190?[`iP03
0000003jl>H0n_3V0400n_3V00<000000?[`iP3jl>H01P3jl>H00`3=QCl0n_3V0?[`iP2D0?[`iP03
0000003jl>H0n_3V01@0n_3V0@3oool00:`0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V
0?[`iP110?[`iP8000001P3jl>H00`3=QCl0n_3V0?[`iP2D0?[`iP030000003jl>H0n_3V01@0n_3V
0@3oool00:`0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP130?[`iP030000003j
l>H0n_3V00@0n_3V00<0cHDo0?[`iP3jl>H0T`3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo0002
0000ojX0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP140?[`iP030000003jl>H0
n_3V00<0n_3V00<0cHDo0?[`iP3jl>H0T`3jl>H00`000000n_3V0?[`iP0A0?[`iP80003o0@3jl>H1
0?ooo`000P3jl>H30000ojL0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP150?[`
iP8000000`3jl>H00`3=QCl0n_3V0?[`iP2C0?[`iP030000003jl>H0n_3V00h0n_3V0`000?l30?[`
iP40oooo00050?[`iP@0003oXP3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V04L0
n_3V00@000000?[`iP3jl>H0cHDoU@3jl>H00`000000n_3V0?[`iP0:0?[`iP@0003o1P3jl>H10?oo
o`002@3jl>H30000oil0n_3V00<0cHDo0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP180?[`iP04
0000003jl>H0n_3V0<f5?i@0n_3V00<000000?[`iP3jl>H01`3jl>H30000o`X0n_3V0@3oool000`0
n_3V0`000?nK0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0B@3jl>H500000940
n_3V0`0000050?[`iP<0003o3@3jl>H10?ooo`003`3jl>H40000oiL0n_3V00<0cHDo0?[`iP3jl>H0
C03jl>H00`000000n_3V0?[`iP1:0?[`iPD00000S`3jl>H5000000@0003o403jl>H10?ooo`004`3j
l>H30000oi@0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP1:0?[`iYT00000503j
l>H10?ooo`005P3jl>H30000oi40n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP1:
0?[`iPD00000SP3jl>H00`000?l0000000000003000001@0n_3V0@3oool001T0n_3V0`000?n=0?[`
iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0B`3jl>H3000000030?[`iP000000n_3V
08T0n_3V0`000?l20?[`iP<000005@3jl>H10?ooo`00703jl>H30000ohX0n_3V00<0cHDo0?[`iP3j
l>H0C@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V00800000Q@3jl>H30000o`H0
n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`007`3jl>H40000ohH0n_3V00<0cHDo0?[`iP3jl>H0
C@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0
O`3jl>H30000o`T0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`008`3jl>H30000oh<0n_3V00<0
cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V00<0n_3V00<0
00000?[`iP3jl>H0N`3jl>H30000o``0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`009P3jl>H3
0000ogl0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0
n_3V00@0n_3V0P00001h0?[`iP<0003o3`3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo000Y0?[`
iP<0003oO03jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04h0n_3V00<0cHDo0?[`
iP3jl>H01@3jl>H00`000000n_3V0?[`iP1b0?[`iP<0003o4P3jl>H00`000000n_3V0?[`iP0D0?[`
iP40oooo000/0?[`iP80003oNP3jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04h0
n_3V00<0cHDo0?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP1_0?[`iP80003o5@3jl>H00`000000
n_3V0?[`iP0D0?[`iP40oooo000^0?[`iP80003oN03jl>H00`3=QCl0n_3V0?[`iP1>0?[`iP030000
003jl>H0n_3V04h0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H2000006d0n_3V0P000?lG0?[`iP030000
003jl>H0n_3V01@0n_3V0@3oool00300n_3V0`000?md0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<0
00000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP090?[`iP030000003jl>H0n_3V06L0n_3V0`00
0?lI0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool003<0n_3V0P000?mb0?[`iP030<f5?`3jl>H0
n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP090?[`iP800000I@3jl>H2
0000oa`0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00=@3jl>H20000og00n_3V00<0cHDo0?[`
iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V00/0n_3V00<000000?[`
iP3jl>H0H03jl>H20000oah0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00=`3jl>H30000ofd0
n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V00`0
n_3V00<000000?[`iP3jl>H0G03jl>H30000ob00n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00
>P3jl>H20000of/0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5
?`3jl>H0n_3V00d0n_3V0P00001J0?[`iP80003o8`3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo
000l0?[`iP80003oJ@3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0n_3V00<0
cHDo0?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP1E0?[`iP80003o9@3jl>H00`000000n_3V0?[`
iP0D0?[`iP40oooo000n0?[`iP<0003oI@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0
n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP1A0?[`iP<0003o9`3jl>H0
0`000000n_3V0?[`iP0D0?[`iP40oooo00110?[`iP80003oH`3jl>H00`3=QCl0n_3V0?[`iP1@0?[`
iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H0403jl>H2000004l0n_3V0P000?lZ0?[`
iP030000003jl>H0n_3V01@0n_3V0@3oool004<0n_3V0P000?mQ0?[`iP030<f5?`3jl>H0n_3V0500
n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V04X0
n_3V0P000?l/0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool004D0n_3V0P000?mO0?[`iP030<f5
?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP030000
003jl>H0n_3V04L0n_3V0P000?l^0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool004L0n_3V0P00
0?mM0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`
iP0D0?[`iP800000A@3jl>H20000oc00n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00B@3jl>H3
0000oeX0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0
n_3V01H0n_3V00<000000?[`iP3jl>H0@03jl>H20000oc80n_3V00<000000?[`iP3jl>H0503jl>H1
0?ooo`00C03jl>H20000oeP0n_3V00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`
iP030<f5?`3jl>H0n_3V01L0n_3V0P00000n0?[`iP80003o=03jl>H00`000000n_3V0?[`iP0D0?[`
iP40oooo001>0?[`iP80003oEP3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP<00000D@3jl>H00`3=QCl0
n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V03T0n_3V0P000?lf0?[`iP030000003jl>H0n_3V01@0
n_3V0@3oool00500n_3V0P000?mD0?[`iP030<f5?`3jl>H0n_3V04h0n_3V1@00001@0?[`iP030<f5
?`3jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H0=P3jl>H20000ocP0n_3V00<000000?[`iP3jl>H0
503jl>H10?ooo`00DP3jl>H20000oe80n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H500000500n_3V00<0
cHDo0?[`iP3jl>H06`3jl>H2000003@0n_3V0P000?lj0?[`iP030000003jl>H0n_3V01@0n_3V0@3o
ool005@0n_3V0P000?m@0?[`iP030<f5?`3jl>H0n_3V04h0n_3V1@00001@0?[`iP030<f5?`3jl>H0
n_3V01d0n_3V00<000000?[`iP3jl>H0;`3jl>H20000oc`0n_3V00<000000?[`iP3jl>H0503jl>H1
0?ooo`00EP3jl>H20000odh0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H300000540n_3V00<0cHDo0?[`
iP3jl>H07P3jl>H00`000000n_3V0?[`iP0/0?[`iP80003o?P3jl>H00`000000n_3V0?[`iP0D0?[`
iP40oooo001H0?[`iP80003oC03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500
n_3V00<0cHDo0?[`iP3jl>H07`3jl>H2000002X0n_3V0P000?m00?[`iP030000003jl>H0n_3V01@0
n_3V0@3oool005X0n_3V00<0003o0?[`iP3jl>H0B@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000
003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0U0?[`iP80003o
@P3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo001K0?[`iP80003oB@3jl>H00`3=QCl0n_3V0?[`
iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H08P3jl>H2000002<0n_3V0P00
0?m40?[`iP030000003jl>H0n_3V01@0n_3V0@3oool005d0n_3V0P000?m70?[`iP030<f5?`3jl>H0
n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP0T0?[`iP030000003jl>H0
n_3V01h0n_3V0P000?m60?[`iP030000003jl>H0n_3V01@0n_3V0@3oool005l0n_3V0P000?m50?[`
iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP0U0?[`
iP030000003jl>H0n_3V01/0n_3V0P000?m80?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00640
n_3V00<0003o0?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500
n_3V00<0cHDo0?[`iP3jl>H09P3jl>H2000001T0n_3V0P000?m:0?[`iP030000003jl>H0n_3V01@0
n_3V0@3oool00680n_3V0P000?m20?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0
D03jl>H00`3=QCl0n_3V0?[`iP0X0?[`iP030000003jl>H0n_3V01@0n_3V0P000?m<0?[`iP030000
003jl>H0n_3V01@0n_3V0@3oool006@0n_3V0P000?m00?[`iP030<f5?`3jl>H0n_3V0500n_3V00<0
00000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V0140n_3V0P00
0?m>0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool006H0n_3V0P000?lo0?[`iP030<f5?`3jl>H0
n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP8000003`3jl>H2
0000oe00n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00J03jl>H00`000?l0n_3V0?[`iP0l0?[`
iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0]0?[`
iP030000003jl>H0n_3V00/0n_3V00<0003o0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0D0?[`
iP40oooo001Y0?[`iP80003o?03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V04l0
n_3V00<0cHDo0?[`iP3jl>H0;P3jl>H00`000000n_3V0?[`iP080?[`iP80003oD`3jl>H00`000000
n_3V0?[`iP0D0?[`iP40oooo001[0?[`iP80003o>P3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000
003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0;`3jl>H2000000L0n_3V00<0003o0?[`iP3jl>H0
D`3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo001]0?[`iP030000o`3jl>H0n_3V03L0n_3V00<0
cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V0340n_3V00<0
00000?[`iP3jl>H00P3jl>H20000oeH0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00KP3jl>H2
0000ocL0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0
n_3V03<0n_3V0P0000020000oeP0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00L03jl>H20000
ocH0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V
03@0n_3V00<0003o0000003jl>H0F03jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo001b0?[`iP03
0000o`3jl>H0n_3V03<0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>0?[`iP03
0<f5?`3jl>H0n_3V0380n_3V0P000?l20?[`iP030000003jl>H0n_3V05H0n_3V00<000000?[`iP3j
l>H0503jl>H10?ooo`00L`3jl>H20000oc<0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V
0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V0340n_3V00<0003o0?[`iP3jl>H00`3jl>H2000005H0n_3V
00<000000?[`iP3jl>H0503jl>H10?ooo`00M@3jl>H20000oc40n_3V00<0cHDo0?[`iP3jl>H0CP3j
l>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V0300n_3V0P000?l80?[`iP030000003j
l>H0n_3V05<0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00M`3jl>H00`000?l0n_3V0?[`iP0_
0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP0^
0?[`iP80003o2`3jl>H00`000000n_3V0?[`iP1B0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool0
07P0n_3V0P000?l_0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=
QCl0n_3V0?[`iP0]0?[`iP030000o`3jl>H0n_3V00`0n_3V0P00001B0?[`iP030000003jl>H0n_3V
01@0n_3V0@3oool007X0n_3V0P000?l]0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3j
l>H0C@3jl>H00`3=QCl0n_3V0?[`iP0[0?[`iP80003o4@3jl>H00`000000n_3V0?[`iP1?0?[`iP03
0000003jl>H0n_3V01@0n_3V0@3oool007`0n_3V00<0003o0?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V
0?[`iP1=0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`000?l0n_3V
0?[`iP0B0?[`iP800000C`3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo001m0?[`iP80003o:`3j
l>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H0:@3j
l>H20000oaL0n_3V00<000000?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo001o
0?[`iP80003o:@3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo
0?[`iP3jl>H09`3jl>H20000oaX0n_3V00<000000?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP0D
0?[`iP40oooo00210?[`iP030000o`3jl>H0n_3V02H0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`00
0000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V02H0n_3V00<0003o0?[`iP3jl>H06`3jl>H20000
04/0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00PP3jl>H20000obH0n_3V00<0cHDo0?[`iP3j
l>H0C03jl>H00`000000n_3V0?[`iP1;0?[`iP030<f5?`3jl>H0n_3V02D0n_3V0P000?lP0?[`iP03
0000003jl>H0n_3V04P0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00Q03jl>H20000obD0n_3V
00<0cHDo0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP1;0?[`iP030<f5?`3jl>H0n_3V02@0n_3V
00<0003o0?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP170?[`iP030000003jl>H0n_3V01@0n_3V
0@3oool008H0n_3V00<0003o0?[`iP3jl>H08P3jl>H00`3=QCl0n_3V0?[`iP1;0?[`iP030000003j
l>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H08`3jl>H20000obD0n_3V0P0000170?[`iP030000003j
l>H0n_3V01@0n_3V0@3oool008L0n_3V0P000?lS0?[`iP030<f5?`3jl>H0n_3V04X0n_3V00<00000
0?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0Q0?[`iP80003o:@3jl>H00`000000n_3V0?[`iP14
0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool008T0n_3V0P000?lQ0?[`iP030<f5?`3jl>H0n_3V
04X0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0P0?[`iP030000o`3jl>H0n_3V
02X0n_3V00<000000?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002;0?[`iP80
003o7`3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V04X0n_3V00<0cHDo0?[`iP3j
l>H07P3jl>H20000obh0n_3V0P0000130?[`iP030000003jl>H0n_3V01@0n_3V0@3oool008d0n_3V
00<0003o0?[`iP3jl>H0703jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V04T0n_3V
00<0cHDo0?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V0400n_3V
00<000000?[`iP3jl>H0503jl>H10?ooo`00SP3jl>H20000oad0n_3V00<0cHDo0?[`iP3jl>H0B@3j
l>H00`000000n_3V0?[`iP190?[`iP030<f5?`3jl>H0n_3V01`0n_3V0P000?ld0?[`iP800000@03j
l>H00`000000n_3V0?[`iP0D0?[`iP40oooo002@0?[`iP80003o703jl>H00`3=QCl0n_3V0?[`iP18
0?[`iP030000003jl>H0n_3V04P0n_3V00<0cHDo0?[`iP3jl>H06`3jl>H20000ocP0n_3V00<00000
0?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002B0?[`iP030000o`3jl>H0n_3V
01T0n_3V00<0cHDo0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP170?[`iP030<f5?`3jl>H0n_3V
01/0n_3V00<0003o0?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP0l0?[`iP030000003jl>H0n_3V
01@0n_3V0@3oool009<0n_3V0P000?lJ0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<000000?[`iP3j
l>H0A`3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP80003o?@3jl>H2000003`0n_3V00<000000?[`iP3j
l>H0503jl>H10?ooo`00U@3jl>H00`000?l0n_3V0?[`iP0G0?[`iP030<f5?`3jl>H0n_3V04L0n_3V
00<000000?[`iP3jl>H0AP3jl>H00`3=QCl0n_3V0?[`iP0I0?[`iP030000o`3jl>H0n_3V03l0n_3V
00<000000?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002F0?[`iP80003o603j
l>H00`3=QCl0n_3V0?[`iP160?[`iP030000003jl>H0n_3V04H0n_3V00<0cHDo0?[`iP3jl>H05`3j
l>H20000od<0n_3V00<000000?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002H
0?[`iP030000o`3jl>H0n_3V01D0n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP15
0?[`iP030<f5?`3jl>H0n_3V01L0n_3V00<0003o0?[`iP3jl>H0A03jl>H2000003P0n_3V00<00000
0?[`iP3jl>H0503jl>H10?ooo`00V@3jl>H20000oaH0n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`00
0000n_3V0?[`iP150?[`iP030<f5?`3jl>H0n_3V01D0n_3V0P000?m90?[`iP030000003jl>H0n_3V
03D0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00V`3jl>H00`000?l0n_3V0?[`iP0C0?[`iP03
0<f5?`3jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0A03jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP03
0000o`3jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP0D0?[`iP40
oooo002L0?[`iP80003o503jl>H00`3=QCl0n_3V0?[`iP140?[`iP030000003jl>H0n_3V04@0n_3V
00<0cHDo0?[`iP3jl>H04`3jl>H20000odh0n_3V0P00000d0?[`iP030000003jl>H0n_3V01@0n_3V
0@3oool009h0n_3V00<0003o0?[`iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`iP130?[`iP030000003j
l>H0n_3V04<0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H00`000?l0n_3V0?[`iP1@0?[`iP030000003j
l>H0n_3V0340n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00W`3jl>H20000oa80n_3V00<0cHDo
0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V0180n_3V0P000?mD
0?[`iP800000<@3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002Q0?[`iP030000o`3jl>H0n_3V
0100n_3V00<0cHDo0?[`iP3jl>H0@P3jl>H00`000000n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V
0140n_3V00<0003o0?[`iP3jl>H0EP3jl>H00`000000n_3V0?[`iP0^0?[`iP030000003jl>H0n_3V
01@0n_3V0@3oool00:80n_3V0P000?lA0?[`iP030<f5?`3jl>H0n_3V0440n_3V00<000000?[`iP3j
l>H0@@3jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP80003oFP3jl>H00`000000n_3V0?[`iP0]0?[`iP03
0000003jl>H0n_3V01@0n_3V0@3oool00:@0n_3V00<0003o0?[`iP3jl>H03`3jl>H00`3=QCl0n_3V
0?[`iP100?[`iP030000003jl>H0n_3V0400n_3V00<0cHDo0?[`iP3jl>H0403jl>H00`000?l0n_3V
0?[`iP1K0?[`iP800000;@3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002U0?[`iP80003o3`3j
l>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V03l0n_3V00<0cHDo0?[`iP3jl>H03`3j
l>H20000of00n_3V00<000000?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002W
0?[`iP030000o`3jl>H0n_3V00d0n_3V00<0cHDo0?[`iP3jl>H0?`3jl>H00`000000n_3V0?[`iP0o
0?[`iP030<f5?`3jl>H0n_3V00h0n_3V00<0003o0?[`iP3jl>H0H@3jl>H00`000000n_3V0?[`iP0Y
0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00:P0n_3V0P000?l>0?[`iP030<f5?`3jl>H0n_3V
03h0n_3V00<000000?[`iP3jl>H0?P3jl>H00`3=QCl0n_3V0?[`iP0=0?[`iP80003oI@3jl>H20000
02T0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00ZP3jl>H20000o``0n_3V00<0cHDo0?[`iP3j
l>H0?P3jl>H00`000000n_3V0?[`iP0m0?[`iP030<f5?`3jl>H0n_3V00`0n_3V0P000?mY0?[`iP03
0000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00[03jl>H00`000?l0n_3V
0?[`iP0:0?[`iP030<f5?`3jl>H0n_3V03d0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3=QCl0n_3V
0?[`iP0:0?[`iP80003oK03jl>H2000002H0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00[@3j
l>H20000o`/0n_3V0P3=QClm0?[`iP030000003jl>H0n_3V03/0n_3V0P3=QCl<0?[`iP030000o`3j
l>H0n_3V06h0n_3V00<000000?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002_
0?[`iP80003o2P3jl>H00`3=QCl0n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V03X0n_3V00<0cHDo
0?[`iP3jl>H02P3jl>H20000og80n_3V00<000000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP0D
0?[`iP40oooo002a0?[`iP030000o`3jl>H0n_3V00P0n_3V00<0cHDo0?[`iP3jl>H0>P3jl>H00`00
0000n_3V0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V00P0n_3V0P000?me0?[`iP8000008P3jl>H00`00
0000n_3V0?[`iP0D0?[`iP40oooo002b0?[`iP80003o2@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP03
0000003jl>H0n_3V03T0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H20000ogT0n_3V00<000000?[`iP3j
l>H07`3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002d0?[`iP80003o203jl>H00`3=QCl0n_3V
0?[`iP0h0?[`iP030000003jl>H0n_3V03P0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H00`000?l0n_3V
0?[`iP1j0?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00]P3j
l>H00`000?l0n_3V0?[`iP060?[`iP030<f5?`3jl>H0n_3V03L0n_3V00<000000?[`iP3jl>H0=`3j
l>H00`3=QCl0n_3V0?[`iP060?[`iP80003oOP3jl>H2000001h0n_3V00<000000?[`iP3jl>H0503j
l>H10?ooo`00]`3jl>H20000o`L0n_3V0P3=QClg0?[`iP030000003jl>H0n_3V03D0n_3V0P3=QCl7
0?[`iP80003oPP3jl>H00`000000n_3V0?[`iP0K0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool0
0;T0n_3V0P000?l60?[`iP030<f5?`3jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0=03jl>H00`3=
QCl0n_3V0?[`iP050?[`iP80003oQ@3jl>H00`000000n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V
01@0n_3V0@3oool00;/0n_3V00<0003o0?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP03
0000003jl>H0n_3V03@0n_3V00<0cHDo0?[`iP3jl>H0103jl>H00`000?l0n_3V0?[`iP260?[`iP80
00006P3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo002l0?[`iP80003o1@3jl>H20<f5?c@0n_3V
00<000000?[`iP3jl>H0<P3jl>H20<f5?`D0n_3V0P000?n;0?[`iP030000003jl>H0n_3V01L0n_3V
00<000000?[`iP3jl>H0503jl>H10?ooo`00_P3jl>H20000o`D0n_3V00<0cHDo0?[`iP3jl>H0<@3j
l>H00`000000n_3V0?[`iP0a0?[`iP030<f5?`3jl>H0n_3V00<0n_3V0P000?n>0?[`iP8000005`3j
l>H00`000000n_3V0?[`iP0D0?[`iP40oooo00300?[`iP030000o`3jl>H0n_3V00<0n_3V00<0cHDo
0?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0`0?[`iP030<f5?`3jl>H0n_3V0080n_3V0P000?nB
0?[`iP030000003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00`@3jl>H20000
o`@0n_3V00<0cHDo0?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0_0?[`iP040<f5?`3jl>H0n_3V
0?[`iP80003oU@3jl>H00`000000n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool0
0<<0n_3V0P000?l30?[`iP80cHDo;`3jl>H00`000000n_3V0?[`iP0]0?[`iP80cHDo0`3jl>H00`00
0?l0n_3V0?[`iP2F0?[`iP8000004`3jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo00350?[`iP80
003o0`3jl>H00`3=QCl0n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V02`0n_3V00@0cHDo0?[`iP3j
l>H0n_3V0P000?nK0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0503jl>H10?oo
o`00a`3jl>H20000o`80n_3V0P3=QCl/0?[`iP030000003jl>H0n_3V02X0n_3V0P3=QCl20?[`iP80
003oWP3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00<T0n_3V
0P000?l20?[`iP80cHDo:P3jl>H00`000000n_3V0?[`iP0X0?[`iP80cHDo0P3jl>H20000oj40n_3V
0P00000?0?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00</0n_3V0P000?l20?[`iP030<f5?`3j
l>H0n_3V02L0n_3V00<000000?[`iP3jl>H09`3jl>H00`3=QCl0n_3V0?[`iP020000ojD0n_3V00<0
00000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo003=0?[`iP80003o00<0n_3V
0<f5?`3=QCl09`3jl>H00`000000n_3V0?[`iP0U0?[`iP80cHDo00<0n_3V0000o`000?l0Z03jl>H2
000000`0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00c`3jl>H30000o`80cHDo9@3jl>H00`00
0000n_3V0?[`iP0S0?[`iP80cHDo00<0n_3V0000o`000?l0[03jl>H00`000000n_3V0?[`iP090?[`
iP030000003jl>H0n_3V01@0n_3V0@3oool00=80n_3V0`000?l00`3=QCl0n_3V0?[`iP0Q0?[`iP03
0000003jl>H0n_3V0240n_3V0P3=QCl00`3jl>H0003o0000o`2_0?[`iP030000003jl>H0n_3V00P0
n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00e@3jl>H20000o`030<f5?`3jl>H0n_3V01l0n_3V
00<000000?[`iP3jl>H07`3jl>H20<f5?`<0003o/P3jl>H2000000P0n_3V00<000000?[`iP3jl>H0
503jl>H10?ooo`00e`3jl>H30000oal0n_3V00<000000?[`iP3jl>H07@3jl>H20<f5?`80003o]`3j
l>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V01@0n_3V0@3oool00=X0n_3V0`000?l0
0`3=QCl0n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V01T0n_3V0`3=QCl30000okX0n_3V00<00000
0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0D0?[`iP40oooo003M0?[`iP<0003o6@3jl>H00`00
0000n_3V0?[`iP0G0?[`iP030<f5?`000?l0003o0080003o_P3jl>H2000000@0n_3V00<000000?[`
iP3jl>H0503jl>H10?ooo`00h03jl>H40000oaD0n_3V00<000000?[`iP3jl>H04`3jl>H00`3=QCl0
003o0000o`020000ol@0n_3V00D000000?[`iP3jl>H0n_3V0000000F0?[`iP40oooo003T0?[`iP@0
003o4@3jl>H00`000000n_3V0?[`iP0?0?[`iP030<f5?`000?l0003o0080003ob@3jl>H00`000000
n_3V00000002000001D0n_3V0@3oool00>P0n_3V10000?l=0?[`iP030000003jl>H0n_3V00/0n_3V
1@000?o>0?[`iPD00000503jl>H10?ooo`00k03=QCl=0000o`03000000000?l0003o00/0003od`3=
QCl5000001<0cHDo0@3jl>H10?ooo`00o`3jl>KK0?[`iPD00000503jl>H10?ooo`00o`3jl>KL0?[`
iP<000005@3jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo002f0?[`
iP80000000<0IV9N0<c4^`3jl>H0:`3jl>H01P3Dc<<0IV9N000000000000RHAn0>CKdVD0n_3V00H0
e<c306IRGP000000000008V4OP3Tfm:L0?[`iP40oooo002h0?[`iP0306IRGP000000g=C;02/0n_3V
00H0C4U50<>k/`3jl>H0k>;I00000029Q7iU0?[`iP0604a9A@33^k<0n_3V0>cRf@000000RHAnW03j
l>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H0102_Z:40C4U500000029
Q7h70?[`iP060=cDb`1iMG00000000000029Q7h0c<Bk0P3jl>H0102_Z:40C4U500000029Q7h20?[`
iP8000000P3jl>H2000000050?[`iP3<a;/0000007UeL03jl>H00P0000020?[`iP80000000<0IV9N
0?[`iP3jl>H01`3jl>H2000000<0n_3V00@0c<Bk04a9A@1VHUh0i=_B0P0000000`3jl>H000000000
00030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H200000080n_3V
00<0RHAn06IRGP3<a;/00P0000070?[`iP050=cDb`1iMG00000004a9A@2TWIH00P3jl>H0103<a;/0
C4U506IRGP3Tfm82000000030?[`iP000000000000@0n_3V00<0Y9fF0000002TWIH00`3jl>H0102_
Z:40C4U500000029Q7h70?[`iP040:nXX@1<BDD0C4U50:nXX@80n_3V0P0000060?[`iP80000000D0
n_3V0<>k/`000000`k^c0?[`iP02000000050?[`iP3<a;/0C4U504a9A@2_Z:400P0000000`3jl>H0
0000000000030?[`iP80000000D0n_3V0<c4^`1<BDD0C4U50:nXX@02000000@0n_3V0P0000000`3/
h]T0n_3V0>cRf@0200000080n_3V00<0RHAn06IRGP3<a;/00P0000000`3jl>H00000000000020?[`
iP8000000P3jl>H0102_Z:40C4U500000029Q7h20?[`iP070>cRf@2GTH/000000000001iMG00i=_B
0?[`iP02000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H2000000070?[`iP2_
Z:4000000<>k/`3Tfm80000008V4OP050?[`iP050>CKdP000000Ui6;0?[`iP2i/ZX00P000000203j
l>H0[jRQ00000033^k<0i=_B00000029Q7h0n_3V0P0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP3<a;/000000080000000<0i=_B0?[`iP3jl>H01P3jl>H2000000<0n_3V
00@0IV9N0000003Tfm80^K:Z0P0000000`3jl>H00000000000030?[`iP8000000P3jl>H200000004
0?[`iP00000000000?[`iP8000000P3jl>H2000000050?[`iP2TWIH000000<>k/`2TWIH00P000006
0?[`iP0<0>CKdP000000Ui6;0?[`iP3Dc<<0000008V4OP3jl>H0IV9N0000003Tfm80^K:Z0P000000
0`3jl>H00000000000040?[`iP<0000000P0k>;I0?[`iP2_Z:4000000<>k/`3Tfm80000008V4OPD0
n_3V00L0^K:Z00000033^k<0`k^c0000002i/ZX0n_3V008000001P3jl>H2000000050?[`iP2GTH/0
000009NAR`3jl>H00P0000001@3jl>H0C4U50000003Tfm80`k^c0080000000<0n_3V000000000000
0`3jl>H2000000050?[`iP1<BDD000000>CKdP33^k<00P0000040?[`iP0<08V4OP000000e<c30?[`
iP3Dc<<0000008V4OP3jl>H0Y9fF00000033^k<0Y9fF0P0000000`3jl>H00000000000020?[`iP80
000000l0n_3V0:nXX@000000`k^c0>CKdP000000RHAn0?[`iP1iMG0000000>CKdP3/h]T0000006IR
GP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0
C4U5000000090?[`iP0309NAR`000000g=C;0080n_3V0P0000000`3jl>H0C4U5000000050?[`iP80
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000001P3jl>H0Ui6;00000029Q7h00000
0:nXX@P0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V0P000002
0?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V04a9A@0000000P3j
l>H2000000H0n_3V00<0Ui6;0000003Tfm801@3jl>H200000080n_3V0P0000000`3jl>H000000000
00030?[`iP080;VbZP000000RHAn0000002i/ZX0n_3V04a9A@0000090?[`iP0706IRGP000000n_3V
0?[`iP000000IV9N0?[`iP02000000H0n_3V0P0000001@3jl>H0C4U50000001<BDD0n_3V00800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000<0n_3V0P0000000`3jl>H00000
000000020?[`iP800000103jl>H00`2_Z:40000000000003000000040:nXX@3jl>H0C4U500000080
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V04a9A@0000001`3jl>H01@3Dc<<0
Y9fF0000001<BDD0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P0000020?[`iP80
000000<0n_3V000000000000100000050?[`iP0304a9A@000000n_3V0080n_3V0P0000000`3jl>H0
000000000004000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000H0n_3V04a9A@000000k>;I0000001VHUh80?[`iP8000000`3jl>H200000080n_3V0P000000
0`3jl>H00000000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3j
l>H2000000030?[`iP00000000000080n_3V0P0000060?[`iP8000001P3jl>H200000080n_3V0P00
00000`3jl>H00000000000030?[`iP80C4U500@0k>;I04a9A@1<BDD0n_3V1P0000050?[`iP800000
0P3jl>H2000000030?[`iP000000000000H0n_3V0P0000001@3Tfm80000009NAR`000000i=_B0080
000000D0n_3V0<c4^`000000Ui6;0>CKdP02000000030?[`iP000000000000<0n_3V0P0000001@3j
l>H0c<Bk0000002GTH/0i=_B00800000103jl>H0203Dc<<0000008V4OP3jl>H0Ui6;0000003Dc<<0
n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0
000000<0n_3V0<c4^`1<BDD00P0000000`1<BDD0c<Bk0?[`iP02000008@0n_3V0@3oool008<0n_3V
0P0000030?[`iP8000000P3jl>H2000000030?[`iP1<BDD000000080n_3V00<0000006IRGP3jl>H0
103jl>H200000080n_3V0`0000000`3jl>H0C4U5000000020?[`iP030000001VHUh0n_3V00800000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000001`3Le</0000008V4OP3jl>H0RHAn0000
003Tfm801`3jl>H2000000<0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H20000
0080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P0000000`3jl>H0C4U500000002
0?[`iP8000001P3jl>H2000000H0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H0
2@3<a;/000000:BMUP3jl>H0Y9fF0000003<a;/0C4U5000000020?[`iP030000001VHUh0n_3V00@0
n_3V00L0IV9N0000003jl>H0n_3V0000001VHUh0n_3V008000001P3jl>H2000000050<c4^`000000
g=C;0000003<a;/00P0000020?[`iP030=cDb`2_Z:40NGE`0080000000<0n_3V0000000000000`3j
l>H200000080n_3V00<0g=C;0:nXX@1iMG000P0000050?[`iP050000001<BDD0n_3V04a9A@000000
0P3jl>H0101<BDD000000?[`iP3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
C4U5000000020?[`iP070000001VHUh0n_3V04a9A@000000NGE`0<c4^`030?[`iP800000Q03jl>H1
0?ooo`00P`3jl>H2000000<0n_3V0P0000002`2TWIH0i=_B0000001VHUh0n_3V0;VbZP000000`k^c
0<c4^`000000^K:Z00D0n_3V00<0C4U50000003jl>H01@3jl>H01`2i/ZX000000<>k/`3<a;/00000
0;VbZP3jl>H00P0000001@2i/ZX0i=_B0000001<BDD0n_3V008000000P3jl>H2000000070:nXX@00
0000`k^c0?[`iP33^k<000000:nXX@070?[`iP8000000`3jl>H200000080n_3V0P000000103jl>H0
00000000003Dc<<20?[`iP80000000D0^K:Z0>CKdP000000C4U50?[`iP020000000<0?[`iP000000
00000;VbZP3Tfm80000004a9A@3jl>H0Y9fF00000033^k<0Y9fF0P0000060?[`iP0304a9A@000000
n_3V00D0n_3V0P0000020?[`iP8000000180n_3V000000000000e<c30?[`iP1VHUh000000>cRf@3j
l>H0k>;I0000001VHUh0^K:Z00000033^k<0c<Bk0000002i/ZX50?[`iP070;VbZP000000`k^c0<>k
/`000000^K:Z0?[`iP02000000H0n_3V0P0000001@2TWIH0IV9N0?[`iP1VHUh0Y9fF0080000000P0
n_3V07UeL03Dc<<0n_3V0>CKdP000000C4U50?[`iP80000000<0e<c30?[`iP3jl>H00P0000001`3j
l>H0NGE`0=C<``3jl>H0i=_B0000001<BDD01@3jl>H01@1iMG0000000<c4^`000000IV9N0080n_3V
00@0Y9fF00000033^k<0Y9fF0P0000005P3jl>H000000000002i/ZX0i=_B0000001<BDD0n_3V0;Vb
ZP000000`k^c0<c4^`000000^K:Z0?[`iP1VHUh000000?[`iP3Tfm80000007UeL03jl>H2000008@0
n_3V0@3oool008<0n_3V0P0000030?[`iP80000000@0g=C;08V4OP1<BDD0c<Bk0P3jl>H0102_Z:40
00000000002_Z:460?[`iP0309NAR`000000i=_B00H0n_3V00@0[jRQ000000000000[jRQ0P3jl>H2
000000040<c4^`1iMG00C4U50<c4^`@0000000X0n_3V000000000000IV9N0000003/h]T0n_3V0>cR
f@000000IV9N1`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000RHAn07Ue
L03jl>H2000000050<c4^`1iMG00C4U50<c4^`3jl>H00P0000001`3jl>H000000000003<a;/0NGE`
04a9A@3<a;/00P3jl>H00`29Q7h0IV9N0<c4^`02000000H0n_3V00<0Ui6;0000003Tfm801@3jl>H2
00000080n_3V0P000000103jl>H0000000000029Q7h20000000808V4OP3jl>H0n_3V0?[`iP29Q7h0
00000=cDb`2_Z:42000000030:nXX@3jl>H0n_3V00D0n_3V00D0[jRQ04a9A@000000[jRQ0?[`iP04
000000D0n_3V0P0000001@1VHUh0Y9fF0?[`iP2GTH/0IV9N0080000000<0n_3V0>CKdP29Q7h00P00
00000`1VHUh0e<c30?[`iP020000000308V4OP1iMG00n_3V0080000000<0n_3V0>CKdP29Q7h00P00
00000`1VHUh0e<c30?[`iP040?[`iP050:BMUP000000RHAn0000002TWIH00`3jl>H00`29Q7h0IV9N
0<c4^`02000000070?[`iP00000000000<c4^`1iMG00C4U50<c4^`020?[`iP040:nXX@0000000000
0:nXX@80n_3V00L0i=_B07UeL0000000000008V4OP3Tfm80n_3V00800000Q03jl>H10?ooo`00P`3j
l>H2000000<0n_3V0P00000@0?[`iP070>CKdP000000Ui6;0?[`iP3Dc<<0000007UeL00?0?[`iP80
00000P3jl>H2000000h0n_3V0P00000/0?[`iP070>CKdP000000Ui6;0?[`iP3Dc<<0000008V4OP0U
0?[`iP8000001P3jl>H3000000030<c4^`3jl>H0`k^c00<000006`3jl>H01@3<a;/0000000000000
0000`k^c0:@0n_3V0@3oool00840n_3V1P0000000`3jl>H000000000000A0?[`iP060=cDb`1iMG00
00000000002GTH/0k>;I3`3jl>H0103Le</0RHAn0?[`iP3jl>H2000000`0n_3V1P00000D0?[`iP80
00005@3jl>H01@3Le</0NGE`000000000000Y9fF02H0n_3V00@0c<Bk06IRGP000000RHAn103jl>H3
000000030>cRf@3jl>H0g=C;00<000003@3jl>H2000000`0n_3V00D0k>;I00000000000000000>CK
dP0N0?[`iP800000Q03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55 
%%ImageSize: 500 275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.0555556 0.05 0.0555556 [
[ 0 0 0 0 ]
[ 1 .55 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .55 L
0 .55 L
closepath
clip
newpath
.804 .522 .247 r
.5 Mabswid
newpath
.5 .21667 .16667 0 365.73 arc
s
0 .38333 m
1 .38333 L
s
0 0 1 r
0 .15256 m
.04057 .16495 L
.08481 .18064 L
.12636 .19772 L
.16632 .21649 L
.20885 .23908 L
.2498 .26321 L
.29331 .29077 L
.33524 .31789 L
.37557 .34257 L
.39599 .35376 L
.41848 .36452 L
.44006 .37289 L
.4598 .37856 L
.47025 .3807 L
.47506 .38148 L
.48018 .38216 L
.48303 .38247 L
.48562 .38271 L
.48825 .38292 L
.49066 .38307 L
.49349 .38321 L
.49498 .38326 L
.49574 .38328 L
.49655 .3833 L
.49792 .38332 L
.4992 .38333 L
.49998 .38333 L
.50072 .38333 L
.5021 .38332 L
.5033 .3833 L
.50459 .38327 L
.50581 .38323 L
.50692 .38319 L
.50951 .38306 L
.51224 .38288 L
.51738 .38243 L
.52301 .38175 L
.53303 .38009 L
.54235 .37804 L
.56383 .37154 L
.58335 .36372 L
.62533 .34205 L
.66572 .31727 L
.70868 .28947 L
.75006 .2633 L
.78984 .23982 L
.83219 .21724 L
.87296 .19802 L
.9163 .18022 L
Mistroke
.95805 .16541 L
.99821 .15308 L
1 .15256 L
Mfstroke
0 0 0 r
.5 .05 m
1 .38333 L
s
1 .05 m
1 .38333 L
s
.65385 .15256 m
1 .15256 L
s
.5 .05 m
.5 .38333 L
s
5 Mabswid
.5 .21667 Mdot
1 .38333 Mdot
.65385 .15256 Mdot
1 .15256 Mdot
gsave
.5 .46667 -182.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.563 16.125 moveto
(Gently) show
128.000 16.125 moveto
(Turning) show
175.875 16.125 moveto
(Curve) show
213.063 16.125 moveto
(of) show
228.000 16.125 moveto
(Maria) show
262.563 16.125 moveto
(Agnesi) show
302.375 16.125 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 275},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d00014b000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00m`000002
0<f5?`030000003=QCl0cHDo0?L000000@3oool00>d0n_3V2P3=QCl20?[`iP<000002P3=QCo]0?[`
iP40oooo003W0?[`iPH0cHDo303jl>H010000000n_3V0?[`iP0000090?[`iPL0cHDoiP3jl>H10?oo
o`00i@3jl>H20<f5?a80n_3V00@000000?[`iP3jl>H0n_3V0P00000>0?[`iP80cHDoi03jl>H10?oo
o`00h@3jl>H40<f5?a@0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0=0?[`iP<0
cHDoh@3jl>H10?ooo`00g@3jl>H40<f5?aP0n_3V00<000000?[`iP3jl>H0103jl>H200000100n_3V
103=QCoM0?[`iP40oooo003K0?[`iP80cHDo703jl>H00`000000n_3V0?[`iP060?[`iP030000003j
l>H0n_3V0140n_3V0P3=QCoK0?[`iP40oooo003I0?[`iP80cHDo7P3jl>H00`000000n_3V0?[`iP07
0?[`iP8000004`3jl>H20<f5?mT0n_3V0@3oool00=L0n_3V0P3=QClP0?[`iP030000003jl>H0n_3V
00T0n_3V00<000000?[`iP3jl>H04P3jl>H20<f5?mL0n_3V0@3oool00=D0n_3V0P3=QClR0?[`iP03
0000003jl>H0n_3V00X0n_3V0P00000D0?[`iP80cHDoe@3jl>H10?ooo`00d`3jl>H20<f5?b@0n_3V
00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0C0?[`iP80cHDod`3jl>H10?ooo`00d@3j
l>H20<f5?bH0n_3V00<000000?[`iP3jl>H03@3jl>H2000001D0n_3V0P3=QCoA0?[`iP40oooo003?
0?[`iP80cHDo:03jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V01@0n_3V0P3=QCo?
0?[`iP40oooo003>0?[`iP030<f5?`3jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H0403jl>H20000
01H0n_3V00<0cHDo0?[`iP3jl>H0c03jl>H10?ooo`00c03jl>H20<f5?b/0n_3V00<000000?[`iP3j
l>H04P3jl>H00`000000n_3V0?[`iP0D0?[`iP80cHDoc03jl>H10?ooo`00bP3jl>H20<f5?bd0n_3V
00<000000?[`iP3jl>H04`3jl>H2000001H0n_3V0P3=QCo:0?[`iP40oooo00390?[`iP030<f5?`3j
l>H0n_3V02d0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0E0?[`iP030<f5?`3j
l>H0n_3V0<L0n_3V0@3oool00<L0n_3V0P3=QCl`0?[`iP030000003jl>H0n_3V01H0n_3V0P00000F
0?[`iP80cHDoa`3jl>H10?ooo`00aP3jl>H00`3=QCl0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V
01P0n_3V00<000000?[`iP3jl>H05@3jl>H00`3=QCl0n_3V0?[`iP340?[`iP40oooo00350?[`iP03
0<f5?`3jl>H0n_3V0340n_3V00<000000?[`iP3jl>H06@3jl>H2000001H0n_3V00<0cHDo0?[`iP3j
l>H0``3jl>H10?ooo`00a03jl>H00`3=QCl0n_3V0?[`iP0b0?[`iP030000003jl>H0n_3V01/0n_3V
00<000000?[`iP3jl>H0503jl>H00`3=QCl0n_3V0?[`iP320?[`iP40oooo00320?[`iP80cHDo=@3j
l>H00`000000n_3V0?[`iP0L0?[`iP8000005@3jl>H20<f5?l80n_3V0@3oool00<40n_3V00<0cHDo
0?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V01<0n_3V00<0cHDo
0?[`iP3jl>H0`03jl>H10?ooo`00`03jl>H00`3=QCl0n_3V0?[`iP0f0?[`iP030000003jl>H0n_3V
01l0n_3V0P00000D0?[`iP030<f5?`3jl>H0n_3V0;l0n_3V0@3oool00;l0n_3V00<0cHDo0?[`iP3j
l>H0=`3jl>H00`000000n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V0180n_3V0P3=QCno0?[`iP40
oooo002n0?[`iP030<f5?`3jl>H0n_3V03P0n_3V00<000000?[`iP3jl>H08P3jl>H2000001@0n_3V
00<0cHDo0?[`iP3jl>H0_03jl>H10?ooo`00_@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003j
l>H0n_3V02@0n_3V00<000000?[`iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`iP2k0?[`iP40oooo002l
0?[`iP030<f5?`3jl>H0n_3V03X0n_3V00<000000?[`iP3jl>H09@3jl>H2000001<0n_3V00<0cHDo
0?[`iP3jl>H0^P3jl>H10?ooo`00^`3jl>H00`3=QCl0n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V
02L0n_3V00<000000?[`iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP2j0?[`iP40oooo002j0?[`iP03
0<f5?`3jl>H0n_3V03`0n_3V00<000000?[`iP3jl>H0:03jl>H200000140n_3V00<0cHDo0?[`iP3j
l>H0^@3jl>H10?ooo`00^@3jl>H00`3=QCl0n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V02X0n_3V
00<000000?[`iP3jl>H03`3jl>H20<f5?kT0n_3V0@3oool00;P0n_3V00<0cHDo0?[`iP3jl>H0?P3j
l>H00`000000n_3V0?[`iP0[0?[`iP800000403jl>H00`3=QCl0n_3V0?[`iP2g0?[`iP40oooo002h
0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP0>
0?[`iP030<f5?`3jl>H0n_3V0;H0n_3V0@3oool00;L0n_3V00<0cHDo0?[`iP3jl>H0?`3jl>H00`00
0000n_3V0?[`iP0^0?[`iP8000003`3jl>H00`3=QCl0n_3V0?[`iP2e0?[`iP40oooo002f0?[`iP03
0<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0<0?[`iP03
0<f5?`3jl>H0n_3V0;D0n_3V0@3oool00;H0n_3V00<0cHDo0?[`iP3jl>H0@03jl>H00`000000n_3V
0?[`iP0a0?[`iP8000003@3jl>H00`3=QCl0n_3V0?[`iP2d0?[`iP40oooo002e0?[`iP030<f5?`3j
l>H0n_3V0440n_3V00<000000?[`iP3jl>H0<`3jl>H00`000000n_3V0?[`iP0;0?[`iP030<f5?`3j
l>H0n_3V0;<0n_3V0@3oool00;@0n_3V00<0cHDo0?[`iP3jl>H0@P3jl>H00`000000n_3V0?[`iP0d
0?[`iP800000303jl>H00`3=QCl0n_3V0?[`iP2b0?[`iP40oooo002c0?[`iP030<f5?`3jl>H0n_3V
04<0n_3V00<000000?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP0:0?[`iP030<f5?`3jl>H0n_3V
0;40n_3V0@3oool00;80n_3V00<0cHDo0?[`iP3jl>H0A03jl>H00`000000n_3V0?[`iP0g0?[`iP80
00002P3jl>H00`3=QCl0n_3V0?[`iP2a0?[`iP40oooo002b0?[`iP030<f5?`3jl>H0n_3V04@0n_3V
00<000000?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP080?[`iP030<f5?`3jl>H0n_3V0;00n_3V
0@3oool00;40n_3V00<0cHDo0?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP0j0?[`iP800000203j
l>H00`3=QCl0n_3V0?[`iP2`0?[`iP40oooo002a0?[`iP030<f5?`3jl>H0n_3V04D0n_3V00<00000
0?[`iP3jl>H0?03jl>H00`000000n_3V0?[`iP060?[`iP030<f5?`3jl>H0n_3V0:l0n_3V0@3oool0
0;00n_3V00<0cHDo0?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP0m0?[`iP8000001P3jl>H00`3=
QCl0n_3V0?[`iP2_0?[`iP40oooo002`0?[`iP030<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3j
l>H0?`3jl>H00`000000n_3V0?[`iP040?[`iP030<f5?`3jl>H0n_3V0:h0n_3V0@3oool00:l0n_3V
00<0cHDo0?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`iP100?[`iP800000103jl>H00`3=QCl0n_3V
0?[`iP2^0?[`iP40oooo002_0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H0@P3j
l>H00`000000n_3V0?[`iP020?[`iP030<f5?`3jl>H0n_3V0:d0n_3V0@3oool00:h0n_3V00<0cHDo
0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP130?[`iP8000000`3jl>H00`3=QCl0n_3V0?[`iP2/
0?[`iP40oooo002]0?[`iP030<f5?`3jl>H0n_3V04T0n_3V00<000000?[`iP3jl>H0A@3jl>H01000
0000n_3V0?[`iP3=QCn^0?[`iP40oooo002]0?[`iP030<f5?`3jl>H0n_3V04T0n_3V00<000000?[`
iP3jl>H0AP3jl>H2000000030?[`iP3=QCl0n_3V0:`0n_3V0@3oool00:`0n_3V00<0cHDo0?[`iP3j
l>H0BP3jl>H00`000000n_3V0?[`iP180?[`iP@00000Z@3jl>H100000040n_3V0@3oool00:`0n_3V
00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP180?[`iPD00000Y`3jl>H200000040n_3V
0@3oool00080003oZP3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V04P0n_3V[P00
00010?[`iP40oooo00020?[`iP<0003oY`3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0
n_3V04P0n_3V1P00002S0?[`iP<0003o0P0000010?[`iP40oooo00050?[`iP@0003oXP3jl>H00`3=
QCl0n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V04T0n_3V0`0000020?[`iP030000003jl>H0n_3V
09`0n_3V10000?l40?[`iP4000000@3jl>H10?ooo`002@3jl>H30000oil0n_3V00<0cHDo0?[`iP3j
l>H0B`3jl>H00`000000n_3V0?[`iP1;0?[`iP040<f5?`3jl>H0n_3V0?[`iP800000V@3jl>H30000
o`X0n_3V0@3oool000`0n_3V0`000?nK0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3j
l>H0B`3jl>H00`3=QCl0n_3V0?[`iP030?[`iP030000003jl>H0n_3V09<0n_3V0`000?l=0?[`iP40
oooo000?0?[`iP@0003oU`3jl>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04`0n_3V
00<0cHDo0?[`iP3jl>H00`3jl>H2000008l0n_3V10000?l@0?[`iP40oooo000C0?[`iP<0003oU03j
l>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H01@3j
l>H00`000000n_3V0?[`iP290?[`iP<0003o503jl>H10?ooo`005P3jl>H30000oi40n_3V00<0cHDo
0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V00H0n_3V0P000026
0?[`iP<0003o5`3jl>H10?ooo`006@3jl>H30000ohd0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`00
0000n_3V0?[`iP1<0?[`iP030<f5?`3jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0P03jl>H30000
oaX0n_3V0@3oool001`0n_3V0`000?n:0?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3j
l>H0C@3jl>H00`3=QCl0n_3V0?[`iP080?[`iP800000O@3jl>H30000oad0n_3V0@3oool001l0n_3V
10000?n60?[`iP030<f5?`3jl>H0n_3V04d0n_3V00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V
0?[`iP0:0?[`iP030000003jl>H0n_3V07L0n_3V0`000?lP0?[`iP40oooo000S0?[`iP<0003oP`3j
l>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H02`3j
l>H2000007@0n_3V0`000?lS0?[`iP40oooo000V0?[`iP<0003oO`3jl>H00`3=QCl0n_3V0?[`iP1>
0?[`iP030000003jl>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP1^
0?[`iP<0003o9P3jl>H10?ooo`00:@3jl>H30000og`0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`00
0000n_3V0?[`iP1>0?[`iP030<f5?`3jl>H0n_3V00d0n_3V0P00001[0?[`iP<0003o:@3jl>H10?oo
o`00;03jl>H20000ogX0n_3V00<0cHDo0?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>0?[`iP03
0<f5?`3jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0IP3jl>H20000ob`0n_3V0@3oool002h0n_3V
0P000?mh0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V
0?[`iP0@0?[`iP800000I03jl>H20000obh0n_3V0@3oool00300n_3V0`000?md0?[`iP030<f5?`3j
l>H0n_3V04l0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP030000003j
l>H0n_3V05h0n_3V0`000?l`0?[`iP40oooo000c0?[`iP80003oLP3jl>H00`3=QCl0n_3V0?[`iP1?
0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H04P3jl>H2000005`0n_3V0P000?lc
0?[`iP40oooo000e0?[`iP80003oL03jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V
04l0n_3V00<0cHDo0?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP1G0?[`iP80003o=@3jl>H10?oo
o`00=`3jl>H30000ofd0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP03
0<f5?`3jl>H0n_3V01D0n_3V0P00001D0?[`iP<0003o=`3jl>H10?ooo`00>P3jl>H20000of/0n_3V
00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP030<f5?`3jl>H0n_3V01L0n_3V
00<000000?[`iP3jl>H0C`3jl>H20000ocX0n_3V0@3oool003`0n_3V0P000?mY0?[`iP030<f5?`3j
l>H0n_3V04l0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0H0?[`iP800000C@3j
l>H20000oc`0n_3V0@3oool003h0n_3V0`000?mU0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<00000
0?[`iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V04L0n_3V0`000?ln
0?[`iP40oooo00110?[`iP80003oH`3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V
0500n_3V00<0cHDo0?[`iP3jl>H06P3jl>H2000004D0n_3V0P000?m10?[`iP40oooo00130?[`iP80
003oH@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3j
l>H0703jl>H00`000000n_3V0?[`iP100?[`iP80003o@`3jl>H10?ooo`00A@3jl>H20000oel0n_3V
00<0cHDo0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V01d0n_3V
0P00000n0?[`iP80003oA@3jl>H10?ooo`00A`3jl>H20000oed0n_3V00<0cHDo0?[`iP3jl>H0D03j
l>H00`000000n_3V0?[`iP1@0?[`iP030<f5?`3jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0>@3j
l>H20000odL0n_3V0@3oool004T0n_3V0`000?mJ0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<00000
0?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP0P0?[`iP800000=`3jl>H20000odT0n_3V0@3oool0
04`0n_3V0P000?mH0?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=
QCl0n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V0380n_3V0P000?m;0?[`iP40oooo001>0?[`iP80
003oEP3jl>H00`3=QCl0n_3V0?[`iP1?0?[`iP<00000D@3jl>H00`3=QCl0n_3V0?[`iP0S0?[`iP80
0000<03jl>H20000odd0n_3V0@3oool00500n_3V0P000?mD0?[`iP030<f5?`3jl>H0n_3V04h0n_3V
1@00001@0?[`iP030<f5?`3jl>H0n_3V02D0n_3V00<000000?[`iP3jl>H0:`3jl>H20000odl0n_3V
0@3oool00580n_3V0P000?mB0?[`iP030<f5?`3jl>H0n_3V04h0n_3V1@00001@0?[`iP030<f5?`3j
l>H0n_3V02H0n_3V0P00000Y0?[`iP80003oD@3jl>H10?ooo`00E03jl>H20000oe00n_3V00<0cHDo
0?[`iP3jl>H0CP3jl>H500000500n_3V00<0cHDo0?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP0T
0?[`iP80003oD`3jl>H10?ooo`00EP3jl>H20000odh0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H30000
0540n_3V00<0cHDo0?[`iP3jl>H0:@3jl>H200000280n_3V0P000?mE0?[`iP40oooo001H0?[`iP80
003oC03jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3j
l>H0:`3jl>H00`000000n_3V0?[`iP0M0?[`iP80003oE`3jl>H10?ooo`00FP3jl>H00`000?l0n_3V
0?[`iP190?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V
0?[`iP0/0?[`iP8000006`3jl>H20000oeT0n_3V0@3oool005/0n_3V0P000?m90?[`iP030<f5?`3j
l>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V0?[`iP0^0?[`iP030000003j
l>H0n_3V01H0n_3V0P000?mK0?[`iP40oooo001M0?[`iP80003oA`3jl>H00`3=QCl0n_3V0?[`iP1@
0?[`iP030000003jl>H0n_3V0500n_3V00<0cHDo0?[`iP3jl>H0;`3jl>H2000001@0n_3V0P000?mM
0?[`iP40oooo001O0?[`iP80003oA@3jl>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V
0500n_3V00<0cHDo0?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0?0?[`iP80003oG`3jl>H10?oo
o`00H@3jl>H00`000?l0n_3V0?[`iP120?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3j
l>H0D03jl>H00`3=QCl0n_3V0?[`iP0b0?[`iP8000003@3jl>H20000of40n_3V0@3oool00680n_3V
0P000?m20?[`iP030<f5?`3jl>H0n_3V0500n_3V00<000000?[`iP3jl>H0D03jl>H00`3=QCl0n_3V
0?[`iP0d0?[`iP030000003jl>H0n_3V00P0n_3V0P000?mS0?[`iP40oooo001T0?[`iP80003o@03j
l>H00`3=QCl0n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0=P3j
l>H2000000H0n_3V0P000?mU0?[`iP40oooo001V0?[`iP80003o?`3jl>H00`3=QCl0n_3V0?[`iP1?
0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0>03jl>H010000000n_3V0?[`iP3j
l>H20000ofL0n_3V0@3oool006P0n_3V00<0003o0?[`iP3jl>H0?03jl>H00`3=QCl0n_3V0?[`iP1?
0?[`iP030000003jl>H0n_3V04l0n_3V00<0cHDo0?[`iP3jl>H0>@3jl>H2000000030000o`3jl>H0
n_3V06L0n_3V0@3oool006T0n_3V0P000?ll0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`
iP3jl>H0C`3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP80003o00<000000?[`iP3jl>H0I`3jl>H10?oo
o`00J`3jl>H20000ocX0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP03
0<f5?`3jl>H0n_3V03P0n_3V00@0003o0?[`iP3jl>H0n_3V0P00001W0?[`iP40oooo001]0?[`iP03
0000o`3jl>H0n_3V03L0n_3V00<0cHDo0?[`iP3jl>H0C`3jl>H00`000000n_3V0?[`iP1?0?[`iP03
0<f5?`3jl>H0n_3V03H0n_3V0P000?l60?[`iP030000003jl>H0n_3V06@0n_3V0@3oool006h0n_3V
0P000?lg0?[`iP030<f5?`3jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V
0?[`iP0e0?[`iP80003o2@3jl>H2000006@0n_3V0@3oool00700n_3V0P000?lf0?[`iP030<f5?`3j
l>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000o`3j
l>H0n_3V00/0n_3V00<000000?[`iP3jl>H0H@3jl>H10?ooo`00LP3jl>H00`000?l0n_3V0?[`iP0c
0?[`iP030<f5?`3jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0b
0?[`iP80003o3`3jl>H200000640n_3V0@3oool007<0n_3V0P000?lc0?[`iP030<f5?`3jl>H0n_3V
04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`3=QCl0n_3V0?[`iP0a0?[`iP030000o`3jl>H0n_3V
0140n_3V00<000000?[`iP3jl>H0GP3jl>H10?ooo`00M@3jl>H20000oc40n_3V00<0cHDo0?[`iP3j
l>H0CP3jl>H00`000000n_3V0?[`iP1=0?[`iP030<f5?`3jl>H0n_3V0300n_3V0P000?lE0?[`iP80
0000GP3jl>H10?ooo`00M`3jl>H00`000?l0n_3V0?[`iP0_0?[`iP030<f5?`3jl>H0n_3V04d0n_3V
00<000000?[`iP3jl>H0C@3jl>H00`3=QCl0n_3V0?[`iP0^0?[`iP80003o6@3jl>H00`000000n_3V
0?[`iP1K0?[`iP40oooo001h0?[`iP80003o;`3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003j
l>H0n_3V04d0n_3V00<0cHDo0?[`iP3jl>H0;@3jl>H00`000?l0n_3V0?[`iP0J0?[`iP800000F`3j
l>H10?ooo`00NP3jl>H20000obd0n_3V00<0cHDo0?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP1=
0?[`iP030<f5?`3jl>H0n_3V02/0n_3V0P000?lO0?[`iP030000003jl>H0n_3V05P0n_3V0@3oool0
07`0n_3V00<0003o0?[`iP3jl>H0:P3jl>H00`3=QCl0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V
04`0n_3V00<0cHDo0?[`iP3jl>H0:`3jl>H00`000?l0n_3V0?[`iP0P0?[`iP800000F03jl>H10?oo
o`00O@3jl>H20000ob/0n_3V00<0cHDo0?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP1<0?[`iP03
0<f5?`3jl>H0n_3V02T0n_3V0P000?lU0?[`iP030000003jl>H0n_3V05D0n_3V0@3oool007l0n_3V
0P000?lY0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0C03jl>H00`3=QCl0n_3V
0?[`iP0W0?[`iP80003o:03jl>H2000005D0n_3V0@3oool00840n_3V00<0003o0?[`iP3jl>H09P3j
l>H00`3=QCl0n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V04`0n_3V00<0cHDo0?[`iP3jl>H09P3j
l>H00`000?l0n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V0580n_3V0@3oool00880n_3V0P000?lV
0?[`iP030<f5?`3jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0B`3jl>H00`3=QCl0n_3V0?[`iP0U
0?[`iP80003o;P3jl>H200000580n_3V0@3oool008@0n_3V0P000?lU0?[`iP030<f5?`3jl>H0n_3V
04/0n_3V00<000000?[`iP3jl>H0B`3jl>H00`3=QCl0n_3V0?[`iP0T0?[`iP030000o`3jl>H0n_3V
0300n_3V00<000000?[`iP3jl>H0C`3jl>H10?ooo`00QP3jl>H00`000?l0n_3V0?[`iP0R0?[`iP03
0<f5?`3jl>H0n_3V04/0n_3V00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0S0?[`iP80
003o=03jl>H2000004l0n_3V0@3oool008L0n_3V0P000?lS0?[`iP030<f5?`3jl>H0n_3V04X0n_3V
00<000000?[`iP3jl>H0BP3jl>H00`3=QCl0n_3V0?[`iP0Q0?[`iP80003o>03jl>H00`000000n_3V
0?[`iP1<0?[`iP40oooo00290?[`iP80003o8@3jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003j
l>H0n_3V04X0n_3V00<0cHDo0?[`iP3jl>H0803jl>H00`000?l0n_3V0?[`iP0i0?[`iP800000C03j
l>H10?ooo`00R`3jl>H20000oal0n_3V00<0cHDo0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP1:
0?[`iP030<f5?`3jl>H0n_3V01h0n_3V0P000?ln0?[`iP030000003jl>H0n_3V04T0n_3V0@3oool0
08d0n_3V00<0003o0?[`iP3jl>H0703jl>H00`3=QCl0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V
04T0n_3V00<0cHDo0?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP0o0?[`iP800000B@3jl>H10?oo
o`00SP3jl>H20000oad0n_3V00<0cHDo0?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`iP190?[`iP03
0<f5?`3jl>H0n_3V01`0n_3V0P000?m40?[`iP030000003jl>H0n_3V04H0n_3V0@3oool00900n_3V
0P000?lL0?[`iP030<f5?`3jl>H0n_3V04P0n_3V00<000000?[`iP3jl>H0B03jl>H00`3=QCl0n_3V
0?[`iP0K0?[`iP80003oA`3jl>H2000004H0n_3V0@3oool00980n_3V00<0003o0?[`iP3jl>H06@3j
l>H00`3=QCl0n_3V0?[`iP180?[`iP030000003jl>H0n_3V04L0n_3V00<0cHDo0?[`iP3jl>H06`3j
l>H00`000?l0n_3V0?[`iP190?[`iP030000003jl>H0n_3V04<0n_3V0@3oool009<0n_3V0P000?lJ
0?[`iP030<f5?`3jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H0A`3jl>H00`3=QCl0n_3V0?[`iP0I
0?[`iP80003oC@3jl>H2000004<0n_3V0@3oool009D0n_3V00<0003o0?[`iP3jl>H05`3jl>H00`3=
QCl0n_3V0?[`iP170?[`iP030000003jl>H0n_3V04H0n_3V00<0cHDo0?[`iP3jl>H06@3jl>H00`00
0?l0n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V0400n_3V0@3oool009H0n_3V0P000?lH0?[`iP03
0<f5?`3jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H0AP3jl>H00`3=QCl0n_3V0?[`iP0G0?[`iP80
003oD`3jl>H200000400n_3V0@3oool009P0n_3V00<0003o0?[`iP3jl>H05@3jl>H00`3=QCl0n_3V
0?[`iP160?[`iP030000003jl>H0n_3V04D0n_3V00<0cHDo0?[`iP3jl>H05`3jl>H00`000?l0n_3V
0?[`iP1E0?[`iP030000003jl>H0n_3V03d0n_3V0@3oool009T0n_3V0P000?lF0?[`iP030<f5?`3j
l>H0n_3V04D0n_3V00<000000?[`iP3jl>H0A@3jl>H00`3=QCl0n_3V0?[`iP0E0?[`iP80003oF@3j
l>H2000003d0n_3V0@3oool009/0n_3V00<0003o0?[`iP3jl>H04`3jl>H00`3=QCl0n_3V0?[`iP15
0?[`iP030000003jl>H0n_3V04@0n_3V00<0cHDo0?[`iP3jl>H05@3jl>H00`000?l0n_3V0?[`iP1K
0?[`iP030000003jl>H0n_3V03X0n_3V0@3oool009`0n_3V0P000?lD0?[`iP030<f5?`3jl>H0n_3V
04@0n_3V00<000000?[`iP3jl>H0A03jl>H00`3=QCl0n_3V0?[`iP0C0?[`iP80003oG`3jl>H20000
03X0n_3V0@3oool009h0n_3V00<0003o0?[`iP3jl>H04P3jl>H00`3=QCl0n_3V0?[`iP130?[`iP03
0000003jl>H0n_3V04<0n_3V00<0cHDo0?[`iP3jl>H04`3jl>H00`000?l0n_3V0?[`iP1Q0?[`iP03
0000003jl>H0n_3V03L0n_3V0@3oool009l0n_3V0P000?lB0?[`iP030<f5?`3jl>H0n_3V04<0n_3V
00<000000?[`iP3jl>H0@P3jl>H00`3=QCl0n_3V0?[`iP0B0?[`iP80003oI@3jl>H2000003L0n_3V
0@3oool00:40n_3V00<0003o0?[`iP3jl>H0403jl>H00`3=QCl0n_3V0?[`iP120?[`iP030000003j
l>H0n_3V0480n_3V00<0cHDo0?[`iP3jl>H04@3jl>H00`000?l0n_3V0?[`iP1W0?[`iP030000003j
l>H0n_3V03@0n_3V0@3oool00:80n_3V0P000?lA0?[`iP030<f5?`3jl>H0n_3V0440n_3V00<00000
0?[`iP3jl>H0@@3jl>H00`3=QCl0n_3V0?[`iP0@0?[`iP80003oJ`3jl>H2000003@0n_3V0@3oool0
0:@0n_3V00<0003o0?[`iP3jl>H03`3jl>H00`3=QCl0n_3V0?[`iP100?[`iP030000003jl>H0n_3V
0400n_3V00<0cHDo0?[`iP3jl>H0403jl>H00`000?l0n_3V0?[`iP1]0?[`iP030000003jl>H0n_3V
0340n_3V0@3oool00:D0n_3V0P000?l?0?[`iP030<f5?`3jl>H0n_3V0400n_3V00<000000?[`iP3j
l>H0?`3jl>H00`3=QCl0n_3V0?[`iP0?0?[`iP80003oL@3jl>H200000340n_3V0@3oool00:L0n_3V
00<0003o0?[`iP3jl>H03@3jl>H00`3=QCl0n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V03l0n_3V
00<0cHDo0?[`iP3jl>H03P3jl>H00`000?l0n_3V0?[`iP1c0?[`iP030000003jl>H0n_3V02h0n_3V
0@3oool00:P0n_3V0P000?l>0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0?P3j
l>H00`3=QCl0n_3V0?[`iP0=0?[`iP80003oM`3jl>H2000002h0n_3V0@3oool00:X0n_3V0P000?l<
0?[`iP030<f5?`3jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3=QCl0n_3V0?[`iP0<
0?[`iP80003oN`3jl>H00`000000n_3V0?[`iP0[0?[`iP40oooo002/0?[`iP030000o`3jl>H0n_3V
00X0n_3V00<0cHDo0?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP0m0?[`iP030<f5?`3jl>H0n_3V
00X0n_3V0P000?mn0?[`iP800000:`3jl>H10?ooo`00[@3jl>H20000o`/0n_3V0P3=QClm0?[`iP03
0000003jl>H0n_3V03/0n_3V0P3=QCl<0?[`iP030000o`3jl>H0n_3V0800n_3V00<000000?[`iP3j
l>H0:03jl>H10?ooo`00[`3jl>H20000o`X0n_3V00<0cHDo0?[`iP3jl>H0>`3jl>H00`000000n_3V
0?[`iP0j0?[`iP030<f5?`3jl>H0n_3V00X0n_3V0P000?n40?[`iP800000:03jl>H10?ooo`00/@3j
l>H00`000?l0n_3V0?[`iP080?[`iP030<f5?`3jl>H0n_3V03X0n_3V00<000000?[`iP3jl>H0>P3j
l>H00`3=QCl0n_3V0?[`iP080?[`iP80003oR03jl>H00`000000n_3V0?[`iP0U0?[`iP40oooo002b
0?[`iP80003o2@3jl>H00`3=QCl0n_3V0?[`iP0i0?[`iP030000003jl>H0n_3V03T0n_3V00<0cHDo
0?[`iP3jl>H01`3jl>H20000oh/0n_3V0P00000U0?[`iP40oooo002d0?[`iP80003o203jl>H00`3=
QCl0n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V03P0n_3V00<0cHDo0?[`iP3jl>H01`3jl>H00`00
0?l0n_3V0?[`iP2=0?[`iP030000003jl>H0n_3V0280n_3V0@3oool00;H0n_3V00<0003o0?[`iP3j
l>H01P3jl>H00`3=QCl0n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V03L0n_3V00<0cHDo0?[`iP3j
l>H01P3jl>H20000oi40n_3V0P00000R0?[`iP40oooo002g0?[`iP80003o1`3jl>H20<f5?cL0n_3V
00<000000?[`iP3jl>H0=@3jl>H20<f5?`L0n_3V0P000?nE0?[`iP030000003jl>H0n_3V01l0n_3V
0@3oool00;T0n_3V0P000?l60?[`iP030<f5?`3jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0=03j
l>H00`3=QCl0n_3V0?[`iP050?[`iP80003oV03jl>H2000001l0n_3V0@3oool00;/0n_3V00<0003o
0?[`iP3jl>H0103jl>H00`3=QCl0n_3V0?[`iP0d0?[`iP030000003jl>H0n_3V03@0n_3V00<0cHDo
0?[`iP3jl>H0103jl>H00`000?l0n_3V0?[`iP2J0?[`iP030000003jl>H0n_3V01`0n_3V0@3oool0
0;`0n_3V0P000?l50?[`iP80cHDo=03jl>H00`000000n_3V0?[`iP0b0?[`iP80cHDo1@3jl>H20000
oih0n_3V0P00000L0?[`iP40oooo002n0?[`iP80003o1@3jl>H00`3=QCl0n_3V0?[`iP0a0?[`iP03
0000003jl>H0n_3V0340n_3V00<0cHDo0?[`iP3jl>H00`3jl>H20000oj80n_3V00<000000?[`iP3j
l>H06@3jl>H10?ooo`00`03jl>H00`000?l0n_3V0?[`iP030?[`iP030<f5?`3jl>H0n_3V0300n_3V
00<000000?[`iP3jl>H0<03jl>H00`3=QCl0n_3V0?[`iP020?[`iP80003oY@3jl>H2000001T0n_3V
0@3oool00<40n_3V0P000?l40?[`iP030<f5?`3jl>H0n_3V02l0n_3V00<000000?[`iP3jl>H0;`3j
l>H0103=QCl0n_3V0?[`iP3jl>H20000ojT0n_3V00<000000?[`iP3jl>H05P3jl>H10?ooo`00``3j
l>H20000o`<0n_3V0P3=QCl_0?[`iP030000003jl>H0n_3V02d0n_3V0P3=QCl30?[`iP030000o`3j
l>H0n_3V0:X0n_3V0P00000F0?[`iP40oooo00350?[`iP80003o0`3jl>H00`3=QCl0n_3V0?[`iP0/
0?[`iP030000003jl>H0n_3V02`0n_3V00@0cHDo0?[`iP3jl>H0n_3V0P000?n_0?[`iP030000003j
l>H0n_3V01<0n_3V0@3oool00<L0n_3V0P000?l20?[`iP80cHDo;03jl>H00`000000n_3V0?[`iP0Z
0?[`iP80cHDo0P3jl>H20000ok80n_3V0P00000C0?[`iP40oooo00390?[`iP80003o0P3jl>H20<f5
?bX0n_3V00<000000?[`iP3jl>H0:03jl>H20<f5?`80n_3V0P000?nf0?[`iP030000003jl>H0n_3V
0100n_3V0@3oool00</0n_3V0P000?l20?[`iP030<f5?`3jl>H0n_3V02L0n_3V00<000000?[`iP3j
l>H09`3jl>H00`3=QCl0n_3V0?[`iP020000okT0n_3V0P00000@0?[`iP40oooo003=0?[`iP80003o
00<0n_3V0<f5?`3=QCl09`3jl>H00`000000n_3V0?[`iP0U0?[`iP80cHDo00<0n_3V0000o`000?l0
_@3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo003?0?[`iP<0003o0P3=QClU0?[`iP030000003j
l>H0n_3V02<0n_3V0P3=QCl00`3jl>H0003o0000o`300?[`iP8000003@3jl>H10?ooo`00dP3jl>H3
0000o`030<f5?`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H08@3jl>H20<f5?`030?[`iP000?l0
003o0<@0n_3V00<000000?[`iP3jl>H02P3jl>H10?ooo`00e@3jl>H20000o`030<f5?`3jl>H0n_3V
01l0n_3V00<000000?[`iP3jl>H07`3jl>H20<f5?`<0003oa`3jl>H2000000X0n_3V0@3oool00=L0
n_3V0`000?lO0?[`iP030000003jl>H0n_3V01d0n_3V0P3=QCl20000ol`0n_3V00<000000?[`iP3j
l>H01`3jl>H10?ooo`00fP3jl>H30000o`030<f5?`3jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H0
6@3jl>H30<f5?`<0003oc`3jl>H2000000L0n_3V0@3oool00=d0n_3V0`000?lI0?[`iP030000003j
l>H0n_3V01L0n_3V00<0cHDo0000o`000?l00P000?oD0?[`iP030000003jl>H0n_3V00@0n_3V0@3o
ool00>00n_3V10000?lE0?[`iP030000003jl>H0n_3V01<0n_3V00<0cHDo0000o`000?l00P000?oI
0?[`iP800000103jl>H10?ooo`00i03jl>H40000oa40n_3V00<000000?[`iP3jl>H03`3jl>H00`3=
QCl0003o0000o`020000oml0n_3V00@000000?[`iP000000n_3V0@3oool00>P0n_3V10000?l=0?[`
iP030000003jl>H0n_3V00/0n_3V1@000?oT0?[`iP8000000@3jl>H10?ooo`00k03=QCl=0000o`03
000000000?l0003o00/0003oj@3=QCl200000040n_3V0@3oool00?l0n_3Vl@3jl>H200000040n_3V
0@3oool00?l0n_3VlP3jl>H100000040n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00]P3jl>H20000000306IRGP3<a;/0n_3V02/0n_3V00H0e<c306IRGP0000000000
08V4OP3Tfm9U0?[`iP060=C<``1VHUh0000000000029Q7h0i=_BW03jl>H10?ooo`00^03jl>H00`1V
HUh000000=cDb`0[0?[`iP0604a9A@33^k<0n_3V0>cRf@000000RHAnI@3jl>H01P1<BDD0`k^c0?[`
iP3/h]T0000008V4OY`0n_3V0@3oool008<0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V
00@0[jRQ04a9A@000000RHAn1`3jl>H01P3Le</0NGE`000000000000RHAn0<c4^`80n_3V00@0[jRQ
04a9A@000000RHAn0P3jl>H200000080n_3V0P0000001@3jl>H0c<Bk0000001iMG00n_3V00800000
0P3jl>H20000000306IRGP3jl>H0n_3V00L0n_3V0P0000030?[`iP040<c4^`1<BDD0IV9N0>CKdP80
000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H000000000003jl>H20000
0080n_3V0P0000020?[`iP0308V4OP1VHUh0c<Bk008000001`3jl>H01@3Le</0NGE`0000001<BDD0
Y9fF0080n_3V00@0c<Bk04a9A@1VHUh0i=_B0P0000000`3jl>H00000000000040?[`iP030:BMUP00
0000Y9fF00<0n_3V00@0[jRQ04a9A@000000RHAn1`3jl>H0102_Z:40C4U504a9A@2_Z:420?[`iP80
00001P3jl>H2000000050?[`iP33^k<000000<>k/`3jl>H00P0000001@3jl>H0c<Bk04a9A@1<BDD0
[jRQ0080000000<0n_3V0000000000000`3jl>H2000000050?[`iP3<a;/0C4U504a9A@2_Z:400P00
00040?[`iP80000000<0k>;I0?[`iP3/h]T00P0000020?[`iP0308V4OP1VHUh0c<Bk0080000000<0
n_3V0000000000000P3jl>H200000080n_3V00@0[jRQ04a9A@000000RHAn0P3jl>H01`3/h]T0Ui6;
000000000000NGE`0>CKdP3jl>H00P0000240?[`iP40oooo00230?[`iP8000000`3jl>H200000080
n_3V0P0000001`3jl>H0[jRQ00000033^k<0i=_B00000029Q7h01@3jl>H01@3Tfm80000009NAR`3j
l>H0^K:Z0080000000P0n_3V0:nXX@000000`k^c0>CKdP000000RHAn0?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H0c<Bk00000002000000030>CKdP3jl>H0n_3V
00H0n_3V0P0000030?[`iP0406IRGP000000i=_B0;VbZP80000000<0n_3V0000000000000`3jl>H2
00000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P0000001@3jl>H0Y9fF0000
0033^k<0Y9fF008000001P3jl>H0303Tfm80000009NAR`3jl>H0e<c300000029Q7h0n_3V06IRGP00
0000i=_B0;VbZP80000000<0n_3V000000000000103jl>H3000000080>cRf@3jl>H0[jRQ00000033
^k<0i=_B00000029Q7h50?[`iP070;VbZP000000`k^c0<>k/`000000^K:Z0?[`iP02000000H0n_3V
0P0000001@3jl>H0Ui6;0000002GTH/0n_3V0080000000D0n_3V04a9A@000000i=_B0<>k/`020000
00030?[`iP000000000000<0n_3V0P0000001@3jl>H0C4U50000003Tfm80`k^c00800000103jl>H0
3029Q7h000000=C<``3jl>H0e<c300000029Q7h0n_3V0:BMUP000000`k^c0:BMUP80000000<0n_3V
0000000000000P3jl>H20000000?0?[`iP2_Z:4000000<>k/`3Tfm80000008V4OP3jl>H0NGE`0000
003Tfm80k>;I0000001VHUh0n_3V00800000Q03jl>H10?ooo`00P`3jl>H2000000<0n_3V0P000002
0?[`iP80000000<0n_3V04a9A@0000002@3jl>H00`2GTH/000000=cDb`020?[`iP80000000<0n_3V
04a9A@0000001@3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000H0n_3V
09NAR`000000RHAn0000002_Z:480?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H00000
000000030?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H200000003
0?[`iP1<BDD000000080n_3V0P0000060?[`iP0309NAR`000000i=_B00D0n_3V0P0000020?[`iP80
000000<0n_3V0000000000000`3jl>H0202i/ZX0000008V4OP000000^K:Z0?[`iP1<BDD000002@3j
l>H01`1VHUh000000?[`iP3jl>H0000006IRGP3jl>H00P0000060?[`iP80000000D0n_3V04a9A@00
0000C4U50?[`iP02000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000030?[`
iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V00<0[jRQ0000000000000`000000102_
Z:40n_3V04a9A@0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP1<BDD0
000000L0n_3V00D0e<c30:BMUP000000C4U50?[`iP02000008@0n_3V0@3oool008<0n_3V0P000003
0?[`iP8000000P3jl>H2000000030?[`iP000000000000@000001@3jl>H00`1<BDD000000?[`iP02
0?[`iP80000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000060?[`iP1<BDD000000>cRf@000000IV9N203jl>H2000000<0n_3V
0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H200000080n_3V0P000000103jl>H00000
0000003jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP8000001P3jl>H2000000H0
n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H204a9A@040>cRf@1<BDD0C4U50?[`
iPH000001@3jl>H200000080n_3V0P0000000`3jl>H00000000000060?[`iP80000000D0i=_B0000
002GTH/000000>CKdP02000000050?[`iP3<a;/0000009NAR`3Tfm800P0000000`3jl>H000000000
00030?[`iP80000000D0n_3V0<c4^`000000Ui6;0>CKdP02000000@0n_3V00P0e<c300000029Q7h0
n_3V09NAR`000000e<c30?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H0000000000004000000030?[`iP3<a;/0C4U50080000000<0C4U50<c4^`3jl>H00P000024
0?[`iP40oooo00230?[`iP8000000`3jl>H200000080n_3V0P0000000`3jl>H0C4U5000000020?[`
iP030000001VHUh0n_3V00@0n_3V0P0000020?[`iP<0000000<0n_3V04a9A@0000000P3jl>H00`00
0000IV9N0?[`iP0200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000L0g=C;0000
0029Q7h0n_3V08V4OP000000i=_B00L0n_3V0P0000030?[`iP8000000P3jl>H2000000030?[`iP00
0000000000<0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP800000
00<0n_3V04a9A@0000000P3jl>H2000000H0n_3V0P0000060?[`iP8000000P3jl>H2000000030?[`
iP00000000000080n_3V00T0c<Bk0000002TWIH0n_3V0:BMUP000000c<Bk04a9A@0000000P3jl>H0
0`000000IV9N0?[`iP040?[`iP0706IRGP000000n_3V0?[`iP000000IV9N0?[`iP02000000H0n_3V
0P0000001@3<a;/000000=cDb`000000c<Bk008000000P3jl>H00`3Le</0[jRQ07UeL00200000003
0?[`iP000000000000<0n_3V0P0000020?[`iP030=cDb`2_Z:40NGE`008000001@3jl>H01@000000
C4U50?[`iP1<BDD000000080n_3V00@0C4U50000003jl>H0n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V04a9A@0000000P3jl>H01`000000IV9N0?[`iP1<BDD0000007UeL03<a;/0
0`3jl>H2000008@0n_3V0@3oool008<0n_3V0P0000030?[`iP80000000/0Y9fF0>CKdP000000IV9N
0?[`iP2i/ZX000000<>k/`3<a;/000000;VbZP050?[`iP0304a9A@000000n_3V00D0n_3V00L0^K:Z
00000033^k<0c<Bk0000002i/ZX0n_3V0080000000D0^K:Z0>CKdP000000C4U50?[`iP0200000080
n_3V0P0000001`2_Z:4000000<>k/`3jl>H0`k^c0000002_Z:401`3jl>H2000000<0n_3V0P000002
0?[`iP80000000@0n_3V000000000000e<c30P3jl>H2000000050;VbZP3Tfm80000004a9A@3jl>H0
0P000000303jl>H000000000002i/ZX0i=_B0000001<BDD0n_3V0:BMUP000000`k^c0:BMUP800000
1P3jl>H00`1<BDD000000?[`iP050?[`iP8000000P3jl>H20000000B0?[`iP00000000000=C<``3j
l>H0IV9N0000003/h]T0n_3V0>cRf@000000IV9N0;VbZP000000`k^c0<c4^`000000^K:Z1@3jl>H0
1`2i/ZX000000<>k/`33^k<000000;VbZP3jl>H00P0000060?[`iP80000000D0Y9fF06IRGP3jl>H0
IV9N0:BMUP02000000080?[`iP1iMG00e<c30?[`iP3Tfm80000004a9A@3jl>H2000000030=C<``3j
l>H0n_3V0080000000L0n_3V07UeL03Dc<<0n_3V0>CKdP000000C4U500D0n_3V00D0NGE`0000003<
a;/0000006IRGP020?[`iP040:BMUP000000`k^c0:BMUP80000001H0n_3V000000000000^K:Z0>CK
dP000000C4U50?[`iP2i/ZX000000<>k/`3<a;/000000;VbZP3jl>H0IV9N0000003jl>H0i=_B0000
001iMG00n_3V0P0000240?[`iP40oooo00230?[`iP8000000`3jl>H2000000040=cDb`29Q7h0C4U5
0<c4^`80n_3V00@0[jRQ000000000000[jRQ1P3jl>H00`2GTH/000000>CKdP060?[`iP040:nXX@00
000000000:nXX@80n_3V0P000000103<a;/0NGE`04a9A@3<a;/40000000:0?[`iP000000000006IR
GP000000k>;I0?[`iP3/h]T0000006IRGPL0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`
iP000000000008V4OP1iMG00n_3V0P0000001@3<a;/0NGE`04a9A@3<a;/0n_3V0080000000L0n_3V
000000000000c<Bk07UeL01<BDD0c<Bk0080n_3V00<0RHAn06IRGP3<a;/00P0000060?[`iP0309NA
R`000000i=_B00D0n_3V0P0000020?[`iP80000000@0n_3V000000000000RHAn0P0000002029Q7h0
n_3V0?[`iP3jl>H0RHAn0000003Le</0[jRQ0P0000000`2_Z:40n_3V0?[`iP050?[`iP050:nXX@1<
BDD000000:nXX@3jl>H0100000050?[`iP80000000D0IV9N0:BMUP3jl>H0Ui6;06IRGP0200000003
0?[`iP3Tfm80RHAn0080000000<0IV9N0=C<``3jl>H00P0000000`29Q7h0NGE`0?[`iP0200000003
0?[`iP3Tfm80RHAn0080000000<0IV9N0=C<``3jl>H0103jl>H01@2TWIH0000008V4OP000000Y9fF
00<0n_3V00<0RHAn06IRGP3<a;/00P0000001`3jl>H000000000003<a;/0NGE`04a9A@3<a;/00P3j
l>H0102_Z:4000000000002_Z:420?[`iP070>CKdP1iMG00000000000029Q7h0i=_B0?[`iP020000
08@0n_3V0@3oool008<0n_3V0P0000030?[`iP800000403jl>H01`3Tfm80000009NAR`3jl>H0e<c3
0000001iMG003`3jl>H200000080n_3V0P00000>0?[`iP800000;03jl>H01`3Tfm80000009NAR`3j
l>H0e<c300000029Q7h09@3jl>H2000000H0n_3V0`0000000`3<a;/0n_3V0<>k/`03000001/0n_3V
00D0c<Bk00000000000000000<>k/`2T0?[`iP40oooo00210?[`iPH0000000<0n_3V000000000000
4@3jl>H01P3Le</0NGE`000000000000Ui6;0>cRf@l0n_3V00@0g=C;08V4OP3jl>H0n_3V0P00000<
0?[`iPH00000503jl>H2000001D0n_3V00D0g=C;07UeL000000000000:BMUP0V0?[`iP040<c4^`1V
HUh0000008V4OP@0n_3V0`0000000`3/h]T0n_3V0=cDb`03000000d0n_3V0P00000<0?[`iP050>cR
f@00000000000000003Tfm807P3jl>H2000008@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {274, 0}} -> {-9.01486, -0.900049, 0.0361317, \
0.0361317}}]
}, Closed]]
}, Open  ]],

Cell[BoxData[
    \(Clear[eqns, ysols, agnesi]\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowSize->{744, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 57, 0, 67, "Title"],
Cell[1814, 53, 73, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[1912, 58, 62, 0, 52, "Subsection"],
Cell[1977, 60, 739, 11, 105, "Text"],
Cell[2719, 73, 1854, 35, 21, "Input",
  CellOpen->False],
Cell[4576, 110, 623, 13, 86, "Text"],

Cell[CellGroupData[{
Cell[5224, 127, 116, 2, 51, "Input"],
Cell[5343, 131, 112, 2, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5492, 138, 59, 1, 50, "Input"],
Cell[5554, 141, 105, 2, 66, "Output"]
}, Open  ]],
Cell[5674, 146, 90, 2, 29, "Text"],
Cell[5767, 150, 91, 1, 66, "Input"],
Cell[5861, 153, 97, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[5983, 159, 1446, 26, 391, "Input"],
Cell[7432, 187, 40799, 654, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[48246, 844, 43, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[48314, 848, 1912, 32, 492, "Input"],
Cell[50229, 882, 392, 6, 44, "Message"],

Cell[CellGroupData[{
Cell[50646, 892, 38845, 630, 283, 3393, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[89494, 1524, 40252, 647, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[129749, 2173, 40442, 649, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[170194, 2824, 40645, 652, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[210842, 3478, 40863, 654, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[251708, 4134, 40786, 653, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[292497, 4789, 40717, 652, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[333217, 5443, 40685, 652, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[373905, 6097, 39592, 639, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[413500, 6738, 40201, 646, 283, 3413, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[453704, 7386, 40150, 645, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[493857, 8033, 37846, 617, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[531706, 8652, 37862, 617, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[569571, 9271, 40187, 646, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[609761, 9919, 40209, 646, 283, 3413, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[649973, 10567, 39579, 638, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[689555, 11207, 40713, 652, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[730271, 11861, 40742, 653, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[771016, 12516, 40774, 653, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[811793, 13171, 40843, 654, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[852639, 13827, 40641, 652, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[893283, 14481, 40434, 649, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[933720, 15132, 40203, 646, 283, 3423, 188, "GraphicsData", "PostScript", \
"Graphics"],
Cell[973926, 15780, 35661, 590, 283, 3393, 188, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],
Cell[1009614, 16374, 59, 1, 50, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

