(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    597244,      15491]*)
(*NotebookOutlinePosition[    597923,      15514]*)
(*  CellTagsIndexPosition[    597879,      15510]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Using Legends", "Title"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input"],

Cell["\<\
PlotLegend can be used within DrawGraphics, but is not very useful. The \
better alternatives are to use ShadowBox or ShowLegend. ShowLegend is the \
best approach.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Using ShadowBox", "Subsection"],

Cell["\<\
ShadowBox is quite easy to use within DrawingPaper. It is a graphics \
primitive that fits in very nicely. All the coordinates used in ShadowBox are \
the natural coordinates of the Plot. First you lay down the ShadowBox. Then \
draw any graphics or text you want within it. Here we use Draw to place \
little Sin and Cos waves within the ShadowBox. This approach allows you to \
tailor exactly the kind of legend you wish, although it is a little \
painstaking.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Blue, \[IndentingNewLine]Draw[
            7\ Sin[x], {x, \(-10\), 
              10}], \[IndentingNewLine]Red, \[IndentingNewLine]Draw[
            7\ Cos[x], {x, \(-10\), 
              10}], \[IndentingNewLine]\[IndentingNewLine]ShadowBox[{\(-9\), \
\(-11\)}, {7, 3}, \[IndentingNewLine]ShadowBackground \[Rule] 
              NavyBlue, \[IndentingNewLine]ShadowForeground \[Rule] 
              AliceBlue, \[IndentingNewLine]ShadowOffset \[Rule] {1\/4, \
\(-\(1\/4\)\)}], \[IndentingNewLine]Blue, \[IndentingNewLine]Draw[\(-9\) + 
              1\/4\ Sin[7\ x], {x, \(-8\), \(-6\)}], \[IndentingNewLine]Red, 
          Draw[\(-10\) + 
              1\/4\ Cos[
                  7\ x], {x, \(-8\), \(-6\)}], \[IndentingNewLine]Black, \
\[IndentingNewLine]Text[
            7\ Sin[\[Theta]], {\(-5\), \(-9\)}, {\(-1\), 
              0}], \[IndentingNewLine]Text[
            7\ Cos[\[Theta]], {\(-5\), \(-10\)}, {\(-1\), 
              0}]}, \[IndentingNewLine]\[IndentingNewLine]AspectRatio \[Rule] 
          1/GoldenRatio, \[IndentingNewLine]PlotRange \[Rule] {{\(-10\), 
              10}, {\(-12\), 10}}, \[IndentingNewLine]Background \[Rule] 
          Linen, Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {\[Theta], 
            None}, \[IndentingNewLine]ImageSize \[Rule] 
          500, \[IndentingNewLine]TextStyle \[Rule] {FontSize \[Rule] 12, 
            FontWeight \[Rule] "\<Bold\>"}, \[IndentingNewLine]PlotLabel \
\[Rule] "\<Building a Legend with a ShadowBox\>"];\)\)], "Input",
  GeneratedCell->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.05 0.337109 0.0280925 [
[.125 -0.0125 -16.75 -15.5625 ]
[.125 -0.0125 16.75 0 ]
[.25 -0.0125 -9.5625 -15.5625 ]
[.25 -0.0125 9.5625 0 ]
[.375 -0.0125 -16.75 -15.5625 ]
[.375 -0.0125 16.75 0 ]
[.5 -0.0125 -5.59375 -15.5625 ]
[.5 -0.0125 5.59375 0 ]
[.625 -0.0125 -12.7813 -15.5625 ]
[.625 -0.0125 12.7813 0 ]
[.75 -0.0125 -5.59375 -15.5625 ]
[.75 -0.0125 5.59375 0 ]
[.875 -0.0125 -12.7813 -15.5625 ]
[.875 -0.0125 12.7813 0 ]
[1 -0.0125 -9.1875 -15.5625 ]
[1 -0.0125 9.1875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.59375 -31.125 ]
[.5 -0.0125 5.59375 -15.5625 ]
[-0.0125 .05618 -26.3125 -7.78125 ]
[-0.0125 .05618 0 7.78125 ]
[-0.0125 .19665 -19.125 -7.78125 ]
[-0.0125 .19665 0 7.78125 ]
[-0.0125 .33711 -11.1875 -7.78125 ]
[-0.0125 .33711 0 7.78125 ]
[-0.0125 .47757 -11.1875 -7.78125 ]
[-0.0125 .47757 0 7.78125 ]
[-0.0125 .61803 -18.375 -7.78125 ]
[-0.0125 .61803 0 7.78125 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -124.25 0 ]
[.5 .63053 124.25 15.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -77.75 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.5) show
1.000 setlinewidth
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -77.75 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -73.7813 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -73.7813 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.5) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -70.1875 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.5938 -35.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
1.000 setlinewidth
grestore
0 .05618 m
.00625 .05618 L
s
gsave
-0.0125 .05618 -87.3125 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .19665 m
.00625 .19665 L
s
gsave
-0.0125 .19665 -80.125 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .33711 m
.00625 .33711 L
s
gsave
-0.0125 .33711 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .47757 m
.00625 .47757 L
s
gsave
-0.0125 .47757 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -79.375 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
0 .58994 m
.00375 .58994 L
s
0 .02809 m
.00375 .02809 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.125 .61178 m
.125 .61803 L
s
.25 .61178 m
.25 .61803 L
s
.375 .61178 m
.375 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.625 .61178 m
.625 .61803 L
s
.75 .61178 m
.75 .61803 L
s
.875 .61178 m
.875 .61803 L
s
.125 Mabswid
.025 .61428 m
.025 .61803 L
s
.05 .61428 m
.05 .61803 L
s
.075 .61428 m
.075 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.175 .61428 m
.175 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.225 .61428 m
.225 .61803 L
s
.275 .61428 m
.275 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.325 .61428 m
.325 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.425 .61428 m
.425 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.475 .61428 m
.475 .61803 L
s
.525 .61428 m
.525 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.575 .61428 m
.575 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.675 .61428 m
.675 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.725 .61428 m
.725 .61803 L
s
.775 .61428 m
.775 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.825 .61428 m
.825 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.925 .61428 m
.925 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.975 .61428 m
.975 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05618 m
1 .05618 L
s
.99375 .19665 m
1 .19665 L
s
.99375 .33711 m
1 .33711 L
s
.99375 .47757 m
1 .47757 L
s
.125 Mabswid
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.99625 .58994 m
1 .58994 L
s
.99625 .02809 m
1 .02809 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -185.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Building) show
127.688 15.000 moveto
(a) show
142.063 15.000 moveto
(Legend) show
192.500 15.000 moveto
(with) show
228.438 15.000 moveto
(a) show
242.813 15.000 moveto
(ShadowBox) show
307.500 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
0 .44409 m
.04057 .29111 L
.06168 .21679 L
.07365 .18333 L
.07939 .17032 L
.08481 .16003 L
.08985 .15232 L
.0925 .14901 L
.09532 .14608 L
.09769 .14409 L
.09894 .1432 L
.10029 .14239 L
.10153 .14177 L
.10266 .14131 L
.1038 .14094 L
.10488 .14069 L
.10624 .14051 L
.10746 .14046 L
.10814 .14049 L
.10888 .14056 L
.11021 .14079 L
.11146 .14114 L
.11278 .14164 L
.11515 .14288 L
.11792 .14488 L
.12049 .14727 L
.12636 .15458 L
.13162 .16326 L
.13733 .17488 L
.14773 .20132 L
.16721 .26553 L
.18757 .3439 L
.21003 .42859 L
.22027 .46206 L
.2313 .49226 L
.23637 .5037 L
.24171 .5139 L
.24663 .52149 L
.25126 .52703 L
.25378 .52936 L
.25652 .53133 L
.25772 .53201 L
.259 .53262 L
.26019 .53307 L
.26129 .53338 L
.26256 .53363 L
.26392 .53375 L
.26518 .53373 L
.26638 .5336 L
.26706 .53347 L
Mistroke
.26778 .5333 L
.26907 .53289 L
.2706 .53224 L
.27199 .53148 L
.27448 .52976 L
.27677 .52775 L
.28193 .52177 L
.28648 .51486 L
.29128 .50598 L
.30126 .48266 L
.31194 .45131 L
.3312 .38277 L
.35205 .30142 L
.37469 .22041 L
.38525 .18981 L
.39104 .17576 L
.39646 .16453 L
.40146 .15599 L
.40603 .14975 L
.41111 .14466 L
.41378 .14278 L
.41512 .14204 L
.41658 .1414 L
.41726 .14116 L
.41797 .14094 L
.41925 .14065 L
.42063 .14049 L
.42142 .14046 L
.42215 .14048 L
.42347 .14062 L
.42468 .14087 L
.42535 .14106 L
.42607 .1413 L
.4274 .14185 L
.42987 .14323 L
.43249 .14523 L
.43721 .15014 L
.4426 .15778 L
.44767 .16687 L
.45922 .19393 L
.48039 .26194 L
.49981 .33637 L
.52134 .41851 L
.53184 .45403 L
.54138 .48191 L
.55132 .50532 L
.55588 .5139 L
.5607 .52138 L
.56316 .52452 L
.56586 .52746 L
Mistroke
.56834 .52968 L
.57061 .53129 L
.57189 .53202 L
.57329 .53267 L
.57405 .53297 L
.57476 .5332 L
.57548 .53339 L
.57616 .53353 L
.57748 .53371 L
.57868 .53376 L
.57997 .53368 L
.5807 .53357 L
.58136 .53344 L
.58269 .53308 L
.58395 .53261 L
.5863 .53139 L
.58884 .5296 L
.5916 .52709 L
.59656 .52113 L
.60114 .514 L
.61167 .49215 L
.62285 .46147 L
.6625 .31582 L
.68454 .23445 L
.69419 .20419 L
.70474 .17679 L
.7097 .1663 L
.715 .15695 L
.72 .14998 L
.72454 .14527 L
.72722 .14323 L
.72969 .14184 L
.73098 .14131 L
.7324 .14087 L
.73311 .14071 L
.73388 .14058 L
.73526 .14047 L
.73656 .1405 L
.7373 .14057 L
.73798 .14068 L
.73923 .14097 L
.74055 .14142 L
.74186 .14199 L
.74309 .14265 L
.74538 .1442 L
.75029 .14887 L
.75567 .15606 L
.76129 .16581 L
.76652 .17684 L
.78594 .23191 L
Mistroke
.82687 .38655 L
.84772 .45942 L
.8595 .49197 L
.86511 .50457 L
.87037 .51447 L
.87542 .52214 L
.88005 .5275 L
.88268 .52982 L
.88518 .53154 L
.88646 .53223 L
.88783 .53282 L
.88861 .5331 L
.88932 .53331 L
.88999 .53347 L
.89071 .5336 L
.89206 .53374 L
.8928 .53376 L
.89349 .53373 L
.89472 .5336 L
.89605 .53332 L
.89679 .5331 L
.8976 .53281 L
.89906 .53217 L
.90182 .5305 L
.90445 .52835 L
.90725 .52548 L
.91228 .51886 L
.92212 .50069 L
.93272 .47406 L
.95191 .41125 L
.99509 .24681 L
1 .23013 L
Mfstroke
1 0 0 r
0 .17211 m
.00488 .16247 L
.00942 .15498 L
.01441 .1485 L
.01721 .14569 L
.01975 .14365 L
.02104 .1428 L
.02242 .14204 L
.0236 .14151 L
.02488 .14105 L
.02625 .14071 L
.02753 .14052 L
.02831 .14047 L
.02906 .14047 L
.02972 .1405 L
.03045 .14057 L
.03178 .14082 L
.03299 .14117 L
.03438 .1417 L
.0357 .14235 L
.03804 .14384 L
.04057 .14592 L
.04591 .15191 L
.05177 .16092 L
.06361 .18632 L
.07457 .21739 L
.08481 .2516 L
.12566 .40771 L
.13634 .44502 L
.14796 .47998 L
.15329 .49353 L
.15894 .50597 L
.16424 .51568 L
.16909 .52283 L
.17388 .52816 L
.17629 .53018 L
.17893 .53188 L
.18032 .53256 L
.18159 .53305 L
.18229 .53326 L
.18305 .53345 L
.18442 .53368 L
.18572 .53376 L
.18708 .5337 L
.18825 .53353 L
.18954 .53322 L
.19082 .53278 L
.19203 .53225 L
.19432 .53094 L
.19677 .52907 L
Mistroke
.19945 .52651 L
.20427 .52055 L
.20873 .51351 L
.21985 .48998 L
.23032 .46094 L
.24987 .39338 L
.2904 .23932 L
.30126 .20486 L
.31138 .17831 L
.32194 .15752 L
.32753 .14971 L
.33066 .14634 L
.33351 .14393 L
.33592 .14239 L
.33729 .14171 L
.33858 .1412 L
.33993 .14081 L
.34116 .14058 L
.34252 .14047 L
.3432 .14047 L
.34395 .1405 L
.34522 .14067 L
.34637 .14093 L
.3477 .14136 L
.34895 .14189 L
.35118 .14314 L
.35359 .14492 L
.35911 .15068 L
.36495 .15924 L
.3754 .18052 L
.38534 .20709 L
.396 .24124 L
.41524 .31271 L
.43602 .39356 L
.44698 .43318 L
.45864 .47022 L
.46895 .49704 L
.47443 .5086 L
.48034 .51875 L
.48297 .52246 L
.48575 .52582 L
.48831 .52841 L
.4907 .53037 L
.49295 .53181 L
.4941 .53239 L
.49535 .53291 L
.49672 .53333 L
.49802 .5336 L
.49928 .53374 L
.50044 .53375 L
Mistroke
.50175 .53364 L
.503 .5334 L
.50412 .53309 L
.50534 .53264 L
.50807 .5312 L
.5106 .52935 L
.51521 .52473 L
.52012 .51805 L
.52597 .50782 L
.53148 .49605 L
.54178 .46901 L
.58228 .32242 L
.60282 .24533 L
.6137 .20995 L
.62535 .17874 L
.63112 .16638 L
.63658 .15676 L
.64148 .14995 L
.64402 .14714 L
.64681 .14459 L
.64942 .14277 L
.65186 .14153 L
.6532 .14105 L
.65444 .14074 L
.65579 .14053 L
.65647 .14048 L
.65722 .14046 L
.65848 .14054 L
.65963 .14072 L
.66095 .14105 L
.6622 .14149 L
.66443 .14258 L
.66684 .14419 L
.66931 .14632 L
.67198 .14913 L
.67678 .15554 L
.68772 .17625 L
.69927 .20642 L
.70982 .24009 L
.75159 .39886 L
.76246 .43768 L
.77268 .46989 L
.78263 .49594 L
.79177 .51437 L
.79662 .52178 L
.80173 .52771 L
.80438 .53001 L
.80686 .53166 L
.80828 .5324 L
.80958 .53293 L
Mistroke
.81029 .53317 L
.81107 .53338 L
.8118 .53354 L
.81248 .53365 L
.81375 .53375 L
.81511 .53372 L
.8164 .53356 L
.81757 .5333 L
.81895 .53286 L
.82045 .5322 L
.82318 .53057 L
.82603 .52824 L
.82906 .52509 L
.83452 .51767 L
.84014 .50779 L
.84532 .4968 L
.85699 .4659 L
.87817 .39345 L
.8996 .31004 L
.91962 .23627 L
.9295 .20511 L
.93885 .18029 L
.94402 .16889 L
.94964 .15853 L
.95475 .15106 L
.95948 .14588 L
.96197 .14383 L
.96426 .14238 L
.96556 .14173 L
.96677 .14125 L
.96803 .14087 L
.96941 .14059 L
.97062 .14048 L
.97177 .14047 L
.9728 .14056 L
.97392 .14074 L
.97514 .14106 L
.97642 .14152 L
.97874 .14267 L
.98126 .1444 L
.98397 .1468 L
.98886 .15255 L
.99468 .16168 L
1 .17211 L
Mfstroke
0 0 .502 r
.0625 .02107 m
.0625 .10535 L
.4125 .10535 L
.4125 .02107 L
F
.941 .973 1 r
.05 .02809 m
.05 .11237 L
.4 .11237 L
.4 .02809 L
F
0 g
.001 w
.05 .02809 m
.4 .02809 L
.4 .11237 L
.05 .11237 L
.05 .02809 L
s
0 0 1 r
.5 Mabswid
.1 .08794 m
.10197 .08944 L
.10298 .09005 L
.10406 .09059 L
.10463 .09081 L
.10515 .09098 L
.10567 .09112 L
.10617 .09121 L
.10645 .09125 L
.1066 .09127 L
.10674 .09128 L
.10687 .09129 L
.107 .09129 L
.10707 .0913 L
.10714 .0913 L
.10728 .0913 L
.10735 .0913 L
.10742 .0913 L
.1075 .0913 L
.10758 .0913 L
.10771 .09129 L
.10785 .09128 L
.10801 .09127 L
.10818 .09125 L
.10848 .0912 L
.109 .0911 L
.10948 .09098 L
.11054 .09059 L
.11153 .0901 L
.11247 .08954 L
.11649 .08625 L
.12077 .0821 L
.1229 .08024 L
.1249 .07881 L
.12583 .07828 L
.12681 .07784 L
.12732 .07765 L
.12788 .07749 L
.12812 .07743 L
.12839 .07738 L
.12861 .07734 L
.12886 .07731 L
.12913 .07728 L
.12928 .07727 L
.12935 .07726 L
.12942 .07726 L
.12955 .07726 L
.12967 .07725 L
.1298 .07725 L
.12987 .07726 L
Mistroke
.12994 .07726 L
.13001 .07726 L
.13009 .07726 L
.13023 .07727 L
.13037 .07728 L
.1305 .07729 L
.13079 .07733 L
.1311 .07738 L
.13163 .0775 L
.13211 .07764 L
.13322 .07807 L
.13432 .07865 L
.13536 .07932 L
.13731 .08084 L
.14134 .08465 L
.14338 .08661 L
.14563 .08855 L
.14665 .0893 L
.14776 .09 L
.14879 .09053 L
.14976 .0909 L
.15024 .09104 L
.15076 .09116 L
.15106 .09121 L
.15134 .09125 L
.15159 .09128 L
.15173 .09129 L
.15186 .09129 L
.15199 .0913 L
.15213 .0913 L
.15226 .0913 L
.15238 .0913 L
.15252 .09129 L
.15259 .09129 L
.15267 .09128 L
.15281 .09127 L
.15294 .09126 L
.1532 .09123 L
.15349 .09118 L
.15408 .09105 L
.15457 .09091 L
.15511 .09072 L
.1562 .09022 L
.15814 .089 L
.1624 .08526 L
.16649 .08133 L
.16858 .07962 L
.16968 .07887 L
.17085 .07821 L
.17188 .07776 L
Mistroke
.17247 .07757 L
.17303 .07743 L
.17329 .07738 L
.17353 .07734 L
.17376 .07731 L
.174 .07728 L
.17413 .07727 L
.17426 .07726 L
.17438 .07726 L
.1745 .07726 L
.17463 .07725 L
.17476 .07726 L
.17489 .07726 L
.17496 .07726 L
.17504 .07727 L
.17518 .07728 L
.1753 .07729 L
.17559 .07732 L
.17584 .07736 L
.17611 .07741 L
.17658 .07752 L
.17709 .07767 L
.17822 .07813 L
.17929 .0787 L
.18141 .08019 L
.18335 .08188 L
.18751 .08591 L
.18961 .08782 L
.19152 .08929 L
.19251 .08992 L
.19358 .09048 L
.19417 .09073 L
.19471 .09092 L
.19523 .09107 L
.19551 .09114 L
.19578 .09119 L
.19603 .09123 L
.1963 .09126 L
.19642 .09127 L
.19654 .09128 L
.19666 .09129 L
.19677 .09129 L
.19691 .0913 L
.19703 .0913 L
.19717 .0913 L
.19724 .0913 L
.19732 .0913 L
.19745 .09129 L
.19759 .09128 L
.19772 .09127 L
Mistroke
.19784 .09126 L
.19831 .09119 L
.19858 .09114 L
.19882 .09109 L
.19976 .09081 L
.2 .09071 L
Mfstroke
1 0 0 r
.1 .06218 m
.10406 .05927 L
.10848 .05503 L
.11063 .05303 L
.11264 .05141 L
.11457 .05021 L
.11565 .04972 L
.11612 .04956 L
.11663 .04941 L
.11714 .04929 L
.11742 .04925 L
.11768 .04921 L
.1178 .0492 L
.11792 .04919 L
.11803 .04918 L
.11814 .04917 L
.11827 .04917 L
.11838 .04916 L
.11852 .04916 L
.11864 .04916 L
.11878 .04917 L
.11885 .04917 L
.11892 .04917 L
.11906 .04918 L
.11918 .04919 L
.11946 .04922 L
.11977 .04927 L
.12032 .04938 L
.12082 .04952 L
.12187 .04992 L
.12283 .0504 L
.12501 .05186 L
.12913 .05559 L
.1331 .05936 L
.1353 .06111 L
.13626 .06174 L
.13732 .06231 L
.13781 .06254 L
.13834 .06274 L
.1388 .06289 L
.1393 .06302 L
.13959 .06308 L
.13986 .06312 L
.14011 .06316 L
.14025 .06317 L
.14039 .06319 L
.14051 .06319 L
.14063 .0632 L
.14075 .0632 L
.14086 .06321 L
Mistroke
.14099 .06321 L
.14111 .06321 L
.14124 .0632 L
.14131 .0632 L
.14138 .0632 L
.14162 .06318 L
.14176 .06316 L
.14189 .06315 L
.14243 .06306 L
.1429 .06295 L
.1434 .0628 L
.14455 .06234 L
.14559 .06178 L
.1476 .06039 L
.14978 .0585 L
.15407 .05435 L
.1562 .05244 L
.1582 .05095 L
.15913 .05038 L
.16011 .0499 L
.16062 .04969 L
.16118 .0495 L
.16169 .04936 L
.16217 .04927 L
.16244 .04922 L
.1627 .0492 L
.16283 .04918 L
.16298 .04917 L
.16305 .04917 L
.16313 .04917 L
.16321 .04916 L
.16327 .04916 L
.16341 .04916 L
.16353 .04916 L
.16367 .04917 L
.16373 .04917 L
.16381 .04917 L
.16394 .04918 L
.16407 .04919 L
.16432 .04922 L
.16455 .04925 L
.16481 .0493 L
.16534 .04942 L
.16627 .04972 L
.16735 .05021 L
.16833 .05077 L
.17053 .05238 L
.17472 .05628 L
.17876 .06003 L
.18084 .06156 L
Mistroke
.18189 .06216 L
.18249 .06245 L
.18305 .06268 L
.18356 .06285 L
.18411 .063 L
.18436 .06306 L
.18462 .06311 L
.18486 .06314 L
.18509 .06317 L
.18522 .06318 L
.18537 .06319 L
.18552 .0632 L
.18561 .0632 L
.18568 .06321 L
.18575 .06321 L
.18582 .06321 L
.18595 .06321 L
.18609 .0632 L
.18617 .0632 L
.18624 .0632 L
.18636 .06319 L
.18648 .06318 L
.18675 .06315 L
.187 .06312 L
.18728 .06307 L
.1878 .06294 L
.18829 .0628 L
.18939 .06236 L
.19046 .06179 L
.1916 .06104 L
.19596 .05726 L
.2 .05338 L
Mfstroke
0 0 0 r
gsave
.25 .08428 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
73.375 15.000 moveto
(Sin) show
%%IncludeResource: font Mathematica2Mono-Bold
%%IncludeFont: Mathematica2Mono-Bold
/Mathematica2Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
94.938 15.000 moveto
(@) show
102.125 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Mathematica2Mono-Bold
%%IncludeFont: Mathematica2Mono-Bold
/Mathematica2Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.313 15.000 moveto
(D) show
1.000 setlinewidth
grestore
gsave
.25 .05618 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
73.375 15.000 moveto
(Cos) show
%%IncludeResource: font Mathematica2Mono-Bold
%%IncludeFont: Mathematica2Mono-Bold
/Mathematica2Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
94.938 15.000 moveto
(@) show
102.125 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Mathematica2Mono-Bold
%%IncludeFont: Mathematica2Mono-Bold
/Mathematica2Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.313 15.000 moveto
(D) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V0`3jl>H400000>d0n_3V0@3oool00?l0
n_3V0P3jl>H200000080n_3V0P00003/0?[`iP40oooo003o0?[`iP80n_3V0P0000020?[`iP800000
k03jl>H10?ooo`00o`3jl>H20?[`iP8000000`3jl>H200000>/0n_3V0@3oool00?l0n_3V0P3jl>H7
00000>/0n_3V0@3oool00?l0n_3V0`3jl>H010000000n_3V0?[`iP3jl>H200000>/0n_3V0@3oool0
0?l0n_3V0`3jl>H200000080n_3V0P00003[0?[`iP40oooo003o0?[`iP@0n_3V1000003/0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00J03jl>H2000000@0n_3V0P0000050?[`iP<00000:@3jl>H30000
02L0n_3V1@0000030?[`iP8000001@3jl>H3000002H0n_3V0`00000W0?[`iPD000000`3jl>H20000
00D0n_3V0`00000Y0?[`iP<00000:P3jl>H2000000@0n_3V0P0000050?[`iP<00000903jl>H60000
0080n_3V0`00000O0?[`iP40oooo001X0?[`iP800000103jl>H2000000@0n_3V00<000000?[`iP3j
l>H00P00000W0?[`iP030000003jl>H0n_3V008000009P3jl>H2000000H0n_3V0P0000040?[`iP03
0000003jl>H0n_3V00800000903jl>H2000000030?[`iP000000000002H0n_3V0P0000060?[`iP80
0000103jl>H00`000000n_3V0?[`iP02000002L0n_3V00<000000?[`iP3jl>H00P00000Y0?[`iP80
0000103jl>H2000000@0n_3V00<000000?[`iP3jl>H00P00000U0?[`iP8000000`3jl>H200000003
0?[`iP000000000001h0n_3V0@3oool005h0n_3V1@0000050?[`iP8000003@3jl>H2000001l0n_3V
1@0000060?[`iP8000007`3jl>H5000000<0n_3V0P00000>0?[`iP800000903jl>H2000000030?[`
iP000000000002L0n_3V0P00000>0?[`iP800000:P3jl>H2000002T0n_3V0P00000=0?[`iP800000
9@3jl>H2000000<0n_3V0P0000000`3jl>H000000000000N0?[`iP40oooo001X0?[`iP8000003@3j
l>H2000002X0n_3V0P00000X0?[`iP8000003@3jl>H2000002@0n_3V0P0000000`3jl>H000000000
000X0?[`iP8000003@3jl>H2000002X0n_3V0P00000Y0?[`iP8000003@3jl>H2000002D0n_3V0P00
00030?[`iP80000000<0n_3V0000000000007P3jl>H10?ooo`00J@3jl>H2000000T0n_3V00<00000
0?[`iP3jl>H00P00000W0?[`iP030000003jl>H0n_3V00800000:@3jl>H2000000T0n_3V00<00000
0?[`iP3jl>H00P00000T0?[`iP80000000<0n_3V000000000000:@3jl>H2000000T0n_3V00<00000
0?[`iP3jl>H00P00000W0?[`iP030000003jl>H0n_3V00800000:P3jl>H2000000T0n_3V00<00000
0?[`iP3jl>H00P00000U0?[`iP8000000`3jl>H2000000030?[`iP000000000001h0n_3V0@3oool0
06T0n_3V0P0000090?[`iP@00000:03jl>H4000002L0n_3V0P0000000`3jl>H00000000000090?[`
iP@000009@3jl>H2000000030?[`iP000000000002H0n_3V0P0000000`3jl>H00000000000090?[`
iP@00000:03jl>H4000002/0n_3V0P0000090?[`iP@000009P3jl>H2000000<0n_3V0P0000000`3j
l>H000000000000N0?[`iP40oooo001V0?[`iP030000003jl>H0n_3V008000002@3jl>H2000002X0
n_3V0P00000Y0?[`iP80000000<0n_3V0000000000002@3jl>H2000002L0n_3V0P0000000`3jl>H0
00000000000V0?[`iP80000000<0n_3V0000000000002@3jl>H2000002X0n_3V0P00000Z0?[`iP03
0000003jl>H0n_3V008000002@3jl>H2000002H0n_3V100000030?[`iP80000000<0n_3V00000000
00007P3jl>H10?ooo`00IP3jl>H5000000T0n_3V1@00000W0?[`iPD000009`3jl>H3000000X0n_3V
1@00000U0?[`iP<00000:03jl>H3000000X0n_3V1@00000W0?[`iPD000009`3jl>H5000000T0n_3V
1@00000U0?[`iP800000103jl>H3000001l0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00>@3jl>Ko000009P000008`3jl>H10?oo
o`00>@3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H0203jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V
00<000000?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V02l0n_3V
00<000000?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V0300n_3V
00<000000?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V0240n_3V
0@3oool003T0n_3V00<000000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3o
ool003T0n_3V00<000000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3oool0
03T0n_3V00<000000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0
n_3V00<000000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V
00<000000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<0
00000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<00000
0?[`iP3jl>H05P3jl>J?0000P>h0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`00
0000n_3V0?[`iP0F0?[`iXl00020kP3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP80
00004P3jl>J?000000D00020k@3jl>H2000002<0n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H0
4@3jl>H00`000000l?Wo0?3io`2;0?3io`03000000000800002000<00020kP3jl>H00`000000n_3V
0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V0140n_3V00<000000?3io`3`nOl0R`3`
nOl00`00000000200000P0030000P>h0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H0
0`000000n_3V0?[`iP0A0?[`iP030000003`nOl0l?Wo08/0l?Wo00<000000000P00008000`00083^
0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H04@3jl>H00`00
0000l?Wo0?3io`2;0?3io`03000000000800002000<00020kP3jl>H00`000000n_3V0?[`iP0Q0?[`
iP40oooo000i0?[`iP030000003jl>H0n_3V0140n_3V00<000000?3io`3`nOl0R`3`nOl00`000000
00200000P0030000P>h0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V
0?[`iP0A0?[`iP030000003`nOl0l?Wo08/0l?Wo00<000000000P00008000`00083^0?[`iP030000
003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000l?Wo0?3i
o`1b0?3io`@000002P3`nOl4000000L0l?Wo00<000000000P00008000`00083^0?[`iP030000003j
l>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000l?Wo0?3io`0I
0?3io`030?l0003`nOl0l?Wo00l0l?Wo0P3o00150?3io`8000003P3`nOl2000000L0l?Wo00<00000
0000P00008000`00083^0?[`iP030000003jl>H0n_3V0240n_3V0@3oool002D0n_3V1P0000020?[`
iP<000002@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003`nOl0l?Wo01L0l?Wo1@3o000=0?3i
o`D0o`009P3`nOl2000000L0l?Wo0`0000030?3io`@000000P3`nOl5000000@0l?Wo0P0000050?3i
o`@000001@3`nOl2000000L0l?Wo00<000000000P00008000`00083^0?[`iP030000003jl>H0n_3V
0240n_3V0@3oool002L0n_3V0P0000030?[`iP80000000<0n_3V000000000000203jl>H00`000000
n_3V0?[`iP0A0?[`iP030000003`nOl0l?Wo01H0l?Wo0P3o00040?3io`030?l0003`nOl0l?Wo00T0
l?Wo00<0o`000?3io`3`nOl00`3`nOl00`3o0000l?Wo0?3io`090?3io`030?l0003`nOl0l?Wo01L0
l?Wo0P0000060?3io`8000000P3`nOl010000000l?Wo0000000000020?3io`80000000<0l?Wo0000
000000000P3`nOl2000000<0l?Wo0P0000040?3io`8000000P3`nOl2000000@0l?Wo0P0000070?3i
o`03000000000800002000<00020kP3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000M0?[`iPD0
00001@3jl>H2000000<0n_3V0P0000000`3jl>H00000000000080?[`iP030000003jl>H0n_3V0140
n_3V00<000000?3io`3`nOl05@3`nOl00`3o0000l?Wo0?3io`050?3io`030?l0003`nOl0l?Wo00P0
l?Wo00<0o`000?3io`3`nOl0103`nOl00`3o0000l?Wo0?3io`070?3io`030?l0003`nOl0l?Wo01P0
l?Wo0P0000050?3io`8000001@3`nOl200000080l?Wo0P0000030?3io`@000000`3`nOl2000000@0
l?Wo0P0000020?3io`800000103`nOl2000000L0l?Wo00<000000000P00008000`00083^0?[`iP03
0000003jl>H0n_3V0240n_3V0@3oool002L0n_3V0P0000030?[`iP80000000<0n_3V000000000000
203jl>H300000140n_3V00<000000?3io`3`nOl0503`nOl00`3o0000l?Wo0?3io`070?3io`030?l0
003`nOl0l?Wo00D0l?Wo0P3o00080?3io`030?l0003`nOl0l?Wo00H0l?Wo00<0o`000?3io`3`nOl0
603`nOl2000000D0l?Wo0P0000050?3io`8000000P3`nOl2000000030?3io`000000000000800000
1@3`nOl2000000@0l?Wo0P0000030?3io`8000000`3`nOl2000000L0l?Wo00<000000000P0000800
0`00083/0?[`iP<000008`3jl>H10?ooo`009`3jl>H2000000<0n_3V0P0000000`3jl>H000000000
00080?[`iP030000003jl>H0n_3V0140n_3V00<000000?3io`3`nOl04`3`nOl00`3o0000l?Wo0?3i
o`090?3io`030?l0003`nOl0l?Wo00<0l?Wo00<0o`000?3io`3`nOl02@3`nOl20?l000D0l?Wo00<0
o`000?3io`3`nOl06P3`nOl2000000@0l?Wo0P0000050?3io`8000000P3`nOl2000000030?3io`00
000000000080l?Wo0P0000030?3io`800000103`nOl7000000<0l?Wo0P0000070?3io`0300000000
0800002000<00020kP3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000W0?[`iP8000000`3jl>H2
000000030?[`iP000000000000P0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000l?Wo0?3io`0B
0?3io`030?l0003`nOl0l?Wo00/0l?Wo1@3o000=0?3io`H0o`007@3`nOl2000000@0l?Wo0P000003
0?3io`030000003`nOl0l?Wo00@000000`3`nOl5000000<0l?Wo0P0000050?3io`040000003`nOl0
l?Wo0?3io`8000000`3`nOl2000000L0l?Wo00<000000000P00008000`00083^0?[`iP030000003j
l>H0n_3V0240n_3V0@3oool002D0n_3V100000030?[`iP80000000<0n_3V000000000000203jl>H0
0`000000n_3V0?[`iP0A0?[`iP030000003`nOl0l?Wo0580l?Wo00<000000?3io`3`nOl00P000005
0?3io`8000000P3`nOl00`000000l?Wo0?3io`0?0?3io`8000001@3`nOl200000080l?Wo0P000003
0?3io`8000001`3`nOl00`00000000200000P0030000P>h0n_3V00<000000?[`iP3jl>H08@3jl>H1
0?ooo`009`3jl>H2000000@0n_3V0`0000090?[`iP030000003jl>H0n_3V0140n_3V00<000000?3i
o`3`nOl0DP3`nOl5000000H0l?Wo1000000A0?3io`@00000103`nOl400000080l?Wo100000070?3i
o`03000000000800002000<00020kP3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP03
0000003jl>H0n_3V0140n_3V00<000000?3io`3`nOl0R`3`nOl00`00000000200000P0030000P>h0
n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000
003`nOl0l?Wo08/0l?Wo00<000000000P00008000`00083^0?[`iP030000003jl>H0n_3V0240n_3V
0@3oool003T0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000l?Wo0?3io`1b0?3io`@000002P3`
nOl4000000L0l?Wo00<000000000P00008000`00083^0?[`iP030000003jl>H0n_3V0240n_3V0@3o
ool003T0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000l?Wo0?3io`0L0?3io`@0003o3P3`nOl4
0000od00l?Wo0P00000>0?3io`8000001`3`nOl00`00000000200000P0030000P>h0n_3V00<00000
0?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003`nOl0l?Wo
01/0l?Wo0P000?l30?3io`030000o`3`nOl0l?Wo00X0l?Wo0P000?l30?3io`80003o803`nOl20000
00D0l?Wo1@0000020?3io`H0000000D0l?Wo00000000000000000?3io`0300000080l?Wo0P000005
0?3io`@000001@3`nOl2000000L0l?Wo00<000000000P00008000`00083^0?[`iP030000003jl>H0
n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000l?Wo0?3io`0J0?3i
o`030000o`3`nOl0l?Wo00@0l?Wo00<0003o0?3io`3`nOl02@3`nOl00`000?l0l?Wo0?3io`030?3i
o`030000o`3`nOl0l?Wo01h0l?Wo0P0000050?3io`040000003`nOl0l?Wo0?3io`8000000`3`nOl2
000000@0l?Wo0P0000000`3`nOl00000000000030?3io`800000103`nOl200000080l?Wo0P000004
0?3io`8000001`3`nOl00`00000000200000P0030000P>h0n_3V00<000000?[`iP3jl>H08@3jl>H1
0?ooo`00>@3jl>H200000180n_3V00<000000?3io`3`nOl06@3`nOl00`000?l0l?Wo0?3io`060?3i
o`030000o`3`nOl0l?Wo00H0l?Wo0P000?l70?3io`030000o`3`nOl0l?Wo01d0l?Wo0P0000090?3i
o`8000000`3`nOl2000000@0l?Wo0P0000000`3`nOl00000000000030?3io`800000103`nOl20000
0080l?Wo0P0000040?3io`8000001`3`nOl00`00000000200000P0030000P>d0n_3V0P00000S0?[`
iP40oooo000i0?[`iP030000003jl>H0n_3V0140n_3V00<000000?3io`3`nOl04P3`nOl00`000?l0
l?Wo0?3io`030?3io`030000o`3`nOl0l?Wo00P0l?Wo00<0003o0?3io`3`nOl0103`nOl00`000?l0
l?Wo0?3io`080?3io`80003o7@3`nOl2000000L0l?Wo0`0000040?3io`800000103`nOl200000003
0?3io`000000000000<0l?Wo0P0000040?3io`8000000`3`nOl2000000<0l?Wo0P0000070?3io`03
000000000800002000<00020kP3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000
003jl>H0n_3V0140n_3V00<000000?3io`3`nOl04P3`nOl20000o`80l?Wo0P000?l<0?3io`80003o
0P3`nOl20000o`d0l?Wo0P000?lL0?3io`8000001@3`nOl3000000D0l?Wo0P0000040?3io`800000
00<0l?Wo0000000000000`3`nOl2000000@0l?Wo1`0000030?3io`8000001`3`nOl00`0000000020
0000P0030000P>h0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`
iP0A0?[`iP030000003`nOl0l?Wo01<0l?Wo10000?l?0?3io`<0003o3`3`nOl30000oaX0l?Wo0P00
00040?3io`8000001@3`nOl4000000<0l?Wo1@0000040?3io`8000001@3`nOl010000000l?Wo0?3i
o`3`nOl2000000<0l?Wo0P0000070?3io`03000000000800002000<00020kP3jl>H00`000000n_3V
0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V0140n_3V00<000000?3io`3`nOl0DP3`
nOl00`000000l?Wo0?3io`02000000@0l?Wo0P0000030?3io`030000003`nOl0l?Wo00l0l?Wo0P00
00050?3io`8000000P3`nOl2000000<0l?Wo0P0000070?3io`03000000000800002000<00020kP3j
l>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V0140n_3V00<00000
0?3io`3`nOl0DP3`nOl5000000D0l?Wo1@0000030?3io`800000303`nOl4000000@0l?Wo10000002
0?3io`@000001`3`nOl00`00000000200000P0030000P>h0n_3V00<000000?[`iP3jl>H08@3jl>H1
0?ooo`00>@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003`nOl0l?Wo08/0l?Wo00<000000000
P00008000`00083^0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000l?Wo0?3io`2;0?3io`03000000000800002000<00020kP3jl>H00`000000
n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V0140n_3V00<000000?3io`3`nOl0
R`3`nOl00`00000000200000P0030000P>h0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3j
l>H00`000000n_3V0?[`iP0A0?[`iP030000003`nOl0l?Wo08/0l?Wo00<000000000P00008000`00
083^0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H04@3jl>H0
0`000000l?Wo0?3io`2;0?3io`030000003jl>H0n_3V0?40n_3V00<000000?[`iP3jl>H08@3jl>H1
0?ooo`00>@3jl>H200000180n_3VS`00003b0?[`iP8000008`3jl>H10?ooo`00>@3jl>H00`000000
n_3V0?[`iP3o0?[`iY@0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V
0?[`iP3o0?[`iY@0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`
iP3o0?[`iY@0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o
0?[`iY@0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`
iY@0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0
n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0n_3V
00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0n_3V00<0
00000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0n_3V00<00000
0?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0n_3V00<000000?[`
iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0n_3V00<000000?[`iP3j
l>H08@3jl>H10?ooo`00>@3jl>H2000000L0n_3V1P3o000J0?[`iPH0003oFP3jl>H60?l001X0n_3V
1P000?mJ0?[`iPD0o`006P3jl>H60000oeX0n_3V1P3o00070?[`iP8000008`3jl>H10?ooo`00>@3j
l>H00`000000n_3V0?[`iP050?[`iP030?l0003jl>H0n_3V00<0n_3V0P3o000H0?[`iP80003o1@3j
l>H00`000?l0n_3V0?[`iP1E0?[`iP80o`001P3jl>H00`3o0000n_3V0?[`iP0E0?[`iP80003o1P3j
l>H00`000?l0n_3V0?[`iP1E0?[`iP80o`001@3jl>H20?l001L0n_3V00<0003o0?[`iP3jl>H0103j
l>H20000oeL0n_3V0P3o00050?[`iP80o`001P3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i
0?[`iP030000003jl>H0n_3V00@0n_3V00<0o`000?[`iP3jl>H01P3jl>H00`3o0000n_3V0?[`iP0D
0?[`iP030000o`3jl>H0n_3V00H0n_3V00<0003o0?[`iP3jl>H0D`3jl>H00`3o0000n_3V0?[`iP07
0?[`iP030?l0003jl>H0n_3V01<0n_3V00<0003o0?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP1C
0?[`iP030?l0003jl>H0n_3V00L0n_3V00<0o`000?[`iP3jl>H04`3jl>H00`000?l0n_3V0?[`iP07
0?[`iP030000o`3jl>H0n_3V05<0n_3V00<0o`000?[`iP3jl>H01`3jl>H00`3o0000n_3V0?[`iP03
0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H00`3jl>H00`3o
0000n_3V0?[`iP080?[`iP80o`004`3jl>H00`000?l0n_3V0?[`iP080?[`iP030000o`3jl>H0n_3V
0540n_3V00<0o`000?[`iP3jl>H02@3jl>H00`3o0000n_3V0?[`iP0B0?[`iP030000o`3jl>H0n_3V
00P0n_3V00<0003o0?[`iP3jl>H0D@3jl>H00`3o0000n_3V0?[`iP090?[`iP030?l0003jl>H0n_3V
0140n_3V00<0003o0?[`iP3jl>H02@3jl>H00`000?l0n_3V0?[`iP1A0?[`iP030?l0003jl>H0n_3V
00T0n_3V00<0o`000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP03
0000003jl>H0n_3V0080n_3V00<0o`000?[`iP3jl>H02`3jl>H00`3o0000n_3V0?[`iP0?0?[`iP03
0000o`3jl>H0n_3V00X0n_3V00<0003o0?[`iP3jl>H0D03jl>H00`3o0000n_3V0?[`iP0:0?[`iP03
0?l0003jl>H0n_3V0100n_3V00<0003o0?[`iP3jl>H02P3jl>H00`000?l0n_3V0?[`iP1@0?[`iP03
0?l0003jl>H0n_3V00X0n_3V00<0o`000?[`iP3jl>H0403jl>H00`000?l0n_3V0?[`iP0:0?[`iP03
0000o`3jl>H0n_3V04l0n_3V00<0o`000?[`iP3jl>H02P3jl>H00`3o0000n_3V0?[`iP020?[`iP03
0000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H00P3jl>H00`3o0000n_3V
0?[`iP0;0?[`iP030?l0003jl>H0n_3V00h0n_3V00<0003o0?[`iP3jl>H02`3jl>H00`000?l0n_3V
0?[`iP1?0?[`iP030?l0003jl>H0n_3V00`0n_3V00<0o`000?[`iP3jl>H03P3jl>H00`000?l0n_3V
0?[`iP0<0?[`iP030000o`3jl>H0n_3V04h0n_3V00<0o`000?[`iP3jl>H02`3jl>H00`3o0000n_3V
0?[`iP0>0?[`iP80003o3@3jl>H00`000?l0n_3V0?[`iP1>0?[`iP030?l0003jl>H0n_3V00`0n_3V
00D0o`000?[`iP3jl>H0n_3V0000000S0?[`iP40oooo000i0?[`iP050000003jl>H0n_3V0?[`iP3o
00003`3jl>H00`3o0000n_3V0?[`iP0<0?[`iP030000o`3jl>H0n_3V00d0n_3V00<0003o0?[`iP3j
l>H0CP3jl>H00`3o0000n_3V0?[`iP0<0?[`iP030?l0003jl>H0n_3V00d0n_3V00<0003o0?[`iP3j
l>H03@3jl>H00`000?l0n_3V0?[`iP1=0?[`iP030?l0003jl>H0n_3V00d0n_3V00<0o`000?[`iP3j
l>H0303jl>H00`000?l0n_3V0?[`iP0>0?[`iP030000o`3jl>H0n_3V04d0n_3V00<0o`000?[`iP3j
l>H03@3jl>H0103o0000n_3V0?[`iP00000S0?[`iP40oooo000i0?[`iP040000003jl>H0n_3V0?l0
0100n_3V00<0o`000?[`iP3jl>H0303jl>H00`000?l0n_3V0?[`iP0>0?[`iP030000o`3jl>H0n_3V
04`0n_3V00<0o`000?[`iP3jl>H03P3jl>H00`3o0000n_3V0?[`iP0;0?[`iP030000o`3jl>H0n_3V
00l0n_3V00<0003o0?[`iP3jl>H0B`3jl>H00`3o0000n_3V0?[`iP0>0?[`iP030?l0003jl>H0n_3V
00/0n_3V00<0003o0?[`iP3jl>H03`3jl>H00`000?l0n_3V0?[`iP1<0?[`iP030?l0003jl>H0n_3V
00h0n_3V00@0o`000?[`iP3jl>H000008`3jl>H10?ooo`00>@3jl>H010000000n_3V0?[`iP3o000A
0?[`iP030?l0003jl>H0n_3V00X0n_3V00<0003o0?[`iP3jl>H03`3jl>H00`000?l0n_3V0?[`iP1;
0?[`iP030?l0003jl>H0n_3V00l0n_3V00<0o`000?[`iP3jl>H02`3jl>H00`000?l0n_3V0?[`iP0?
0?[`iP030000o`3jl>H0n_3V04X0n_3V00<0o`000?[`iP3jl>H0403jl>H00`3o0000n_3V0?[`iP0:
0?[`iP030000o`3jl>H0n_3V0100n_3V00<0003o0?[`iP3jl>H0BP3jl>H00`3o0000n_3V0?[`iP0@
0?[`iP030?l0003jl>H0000002<0n_3V0@3oool003T0n_3V00<000000?[`iP3o00004P3jl>H00`3o
0000n_3V0?[`iP090?[`iP030000o`3jl>H0n_3V0140n_3V00<0003o0?[`iP3jl>H0BP3jl>H00`3o
0000n_3V0?[`iP0@0?[`iP030?l0003jl>H0n_3V00T0n_3V00<0003o0?[`iP3jl>H04@3jl>H00`00
0?l0n_3V0?[`iP190?[`iP030?l0003jl>H0n_3V0100n_3V00<0o`000?[`iP3jl>H02@3jl>H00`00
0?l0n_3V0?[`iP0A0?[`iP030000o`3jl>H0n_3V04X0n_3V00<0o`000?[`iP3jl>H0403jl>H00`3o
0000n_3V0000000S0?[`iP40oooo000i0?[`iP030000003o0000n_3V01<0n_3V00<0o`000?[`iP3j
l>H0203jl>H00`000?l0n_3V0?[`iP0B0?[`iP030000o`3jl>H0n_3V04P0n_3V00<0o`000?[`iP3j
l>H04@3jl>H00`3o0000n_3V0?[`iP090?[`iP030000o`3jl>H0n_3V0140n_3V00<0003o0?[`iP3j
l>H0B03jl>H00`3o0000n_3V0?[`iP0B0?[`iP030?l0003jl>H0n_3V00P0n_3V00<0003o0?[`iP3j
l>H04P3jl>H00`000?l0n_3V0?[`iP180?[`iP030?l0003jl>H0n_3V0180n_3V00<0o`000000003j
l>H08P3jl>H10?ooo`00>@3jl>H00`000000o`000?[`iP0C0?[`iP030?l0003jl>H0n_3V00L0n_3V
00<0003o0?[`iP3jl>H04`3jl>H00`000?l0n_3V0?[`iP170?[`iP030?l0003jl>H0n_3V01<0n_3V
00<0o`000?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP0C0?[`iP030000o`3jl>H0n_3V04L0n_3V
00<0o`000?[`iP3jl>H04P3jl>H00`3o0000n_3V0?[`iP080?[`iP030000o`3jl>H0n_3V0180n_3V
00<0003o0?[`iP3jl>H0B03jl>H00`3o0000n_3V0?[`iP0B0?[`iP030?l000000000n_3V0280n_3V
0@3oool003T0n_3V00<0o`000?[`iP3jl>H0503jl>H00`3o0000n_3V0?[`iP060?[`iP030000o`3j
l>H0n_3V01@0n_3V00<0003o0?[`iP3jl>H0AP3jl>H00`3o0000n_3V0?[`iP0C0?[`iP030?l0003j
l>H0n_3V00L0n_3V00<0003o0?[`iP3jl>H04`3jl>H00`000?l0n_3V0?[`iP160?[`iP030?l0003j
l>H0n_3V01@0n_3V00<0o`000?[`iP3jl>H01P3jl>H00`000?l0n_3V0?[`iP0D0?[`iP030000o`3j
l>H0n_3V04H0n_3V00<0o`000?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i
0?[`iP030?l0003jl>H0n_3V01@0n_3V00<0o`000?[`iP3jl>H01P3jl>H00`000?l0n_3V0?[`iP0D
0?[`iP030000o`3jl>H0n_3V04D0n_3V00<0o`000?[`iP3jl>H05@3jl>H00`3o0000n_3V0?[`iP05
0?[`iP030000o`3jl>H0n_3V01D0n_3V00<0003o0?[`iP3jl>H0A@3jl>H00`3o0000n_3V0?[`iP0D
0?[`iP030?l0003jl>H0n_3V00H0n_3V00<0003o0?[`iP3jl>H0503jl>H00`000?l0n_3V0?[`iP16
0?[`iP030?l0003jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`00
0000n_3V0?[`iP0E0?[`iP030?l0003jl>H0n_3V00@0n_3V00<0003o0?[`iP3jl>H05P3jl>H00`00
0?l0n_3V0?[`iP140?[`iP030?l0003jl>H0n_3V01D0n_3V00<0o`000?[`iP3jl>H01@3jl>H00`00
0?l0n_3V0?[`iP0E0?[`iP030000o`3jl>H0n_3V04@0n_3V00<0o`000?[`iP3jl>H05P3jl>H00`3o
0000n_3V0?[`iP040?[`iP030000o`3jl>H0n_3V01H0n_3V00<0003o0?[`iP3jl>H0A03jl>H00`3o
0000n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3j
l>H05@3jl>H00`3o0000n_3V0?[`iP040?[`iP030000o`3jl>H0n_3V01H0n_3V00<0003o0?[`iP3j
l>H0@`3jl>H00`3o0000n_3V0?[`iP0G0?[`iP030?l0003jl>H0n_3V00<0n_3V00<0003o0?[`iP3j
l>H05`3jl>H00`000?l0n_3V0?[`iP130?[`iP030?l0003jl>H0n_3V01H0n_3V00<0o`000?[`iP3j
l>H0103jl>H00`000?l0n_3V0?[`iP0F0?[`iP030000o`3jl>H0n_3V04@0n_3V00<0o`000?[`iP3j
l>H05@3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V01H0n_3V
00<0o`000?[`iP3jl>H00P3jl>H00`000?l0n_3V0?[`iP0H0?[`iP030000o`3jl>H0n_3V0480n_3V
00<0o`000?[`iP3jl>H05`3jl>H00`3o0000n_3V0?[`iP030?[`iP030000o`3jl>H0n_3V01L0n_3V
00<0003o0?[`iP3jl>H0@`3jl>H00`3o0000n_3V0?[`iP0G0?[`iP030?l0003jl>H0n_3V00<0n_3V
00<0003o0?[`iP3jl>H05P3jl>H00`000?l0n_3V0?[`iP130?[`iP030?l0003jl>H0n_3V01H0n_3V
00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0F0?[`iP030?l0003j
l>H0n_3V0080n_3V00<0003o0?[`iP3jl>H0603jl>H00`000?l0n_3V0?[`iP110?[`iP030?l0003j
l>H0n_3V01P0n_3V00<0o`000?[`iP3jl>H00P3jl>H00`000?l0n_3V0?[`iP0I0?[`iP030000o`3j
l>H0n_3V0440n_3V00<0o`000?[`iP3jl>H0603jl>H00`3o0000n_3V0?[`iP020?[`iP030000o`3j
l>H0n_3V01P0n_3V00<0003o0?[`iP3jl>H0@P3jl>H00`3o0000n_3V0?[`iP0F0?[`iP030000003j
l>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H05`3jl>H01@3o0000n_3V0?[`iP3j
l>H0003o01X0n_3V00<0003o0?[`iP3jl>H0@@3jl>H00`3o0000n_3V0?[`iP0I0?[`iP050?l0003j
l>H0n_3V0?[`iP000?l06`3jl>H00`000?l0n_3V0?[`iP110?[`iP030?l0003jl>H0n_3V01T0n_3V
00D0o`000?[`iP3jl>H0n_3V0000o`0J0?[`iP030000o`3jl>H0n_3V0440n_3V00<0o`000?[`iP3j
l>H05`3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V01L0n_3V
00@0o`000?[`iP3jl>H0003o703jl>H00`000?l0n_3V0?[`iP100?[`iP030?l0003jl>H0n_3V01T0
n_3V00@0o`000?[`iP3jl>H0003o7@3jl>H00`000?l0n_3V0?[`iP0o0?[`iP030?l0003jl>H0n_3V
01X0n_3V00D0o`000?[`iP3jl>H0n_3V0000o`0J0?[`iP030000o`3jl>H0n_3V0440n_3V00<0o`00
0?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000]0?[`iP<000002@3jl>H00`00
0000n_3V0?[`iP0H0?[`iP030?l0003jl>H0003o01`0n_3V00<0003o0?[`iP3jl>H0?`3jl>H00`3o
0000n_3V0?[`iP0K0?[`iP030?l0003jl>H0003o01d0n_3V00<0003o0?[`iP3jl>H0?`3jl>H00`3o
0000n_3V0?[`iP0J0?[`iP040?l0003jl>H0n_3V0000oa`0n_3V00<0003o0?[`iP3jl>H0@03jl>H0
0`3o0000n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V0240n_3V0@3oool002`0n_3V00<000000?[`
iP3jl>H00P0000080?[`iP030000003jl>H0n_3V01P0n_3V00<0o`000?[`iP000?l07@3jl>H00`00
0?l0n_3V0?[`iP0n0?[`iP030?l0003jl>H0n_3V01/0n_3V00<0o`000?[`iP000?l07P3jl>H00`00
0?l0n_3V0?[`iP0n0?[`iP030?l0003jl>H0n_3V01/0n_3V00<0o`000?[`iP000?l0703jl>H00`00
0?l0n_3V0?[`iP0o0?[`iP030?l0003jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H08@3jl>H10?oo
o`00903jl>H5000000H0n_3V0P0000080?[`iP030000003jl>H0n_3V01P0n_3V00<0o`000000o`3j
l>H07@3jl>H00`000?l0n_3V0?[`iP0m0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0o`000?[`iP3j
l>H07@3jl>H00`000?l0n_3V0?[`iP0m0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0o`000000o`3j
l>H07@3jl>H00`000?l0n_3V0?[`iP0n0?[`iP030?l0003jl>H0n_3V01P0n_3V00<000000?[`iP3j
l>H08@3jl>H10?ooo`00;`3jl>H2000000P0n_3V0`00000I0?[`iP030?l0003jl>H0n_3V01`0n_3V
00<0003o0?[`iP3jl>H0?@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030?l0003jl>H0n_3V01d0n_3V
00<0003o0?[`iP3jl>H0?@3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030?l000000?l0n_3V01d0n_3V
00<0003o0?[`iP3jl>H0?P3jl>H00`3o0000n_3V0?[`iP0F0?[`iP<000008`3jl>H10?ooo`00;03j
l>H00`000000n_3V0?[`iP02000000P0n_3V00<000000?[`iP3jl>H0603jl>H00`000?l0o`000?[`
iP0N0?[`iP030000o`3jl>H0n_3V03`0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0o`000?[`
iP0N0?[`iP030000o`3jl>H0n_3V03`0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`3o0000n_3V0?[`
iP0L0?[`iP030000o`3jl>H0n_3V03h0n_3V00<0o`000?[`iP3jl>H0603jl>H00`000000n_3V0?[`
iP0Q0?[`iP40oooo000/0?[`iP@000002@3jl>H00`000000n_3V0?[`iP0H0?[`iP030000o`3o0000
n_3V01h0n_3V00<0003o0?[`iP3jl>H0>`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0
o`0001l0n_3V00<0003o0?[`iP3jl>H0>`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3o0000
n_3V01h0n_3V00<0003o0?[`iP3jl>H0?03jl>H00`3o0000n_3V0?[`iP0I0?[`iP030000003jl>H0
n_3V0240n_3V0@3oool002`0n_3V0P00000;0?[`iP030000003jl>H0n_3V01P0n_3V00<0003o0?l0
003jl>H07P3jl>H00`000?l0n_3V0?[`iP0k0?[`iP030?l0003jl>H0n_3V01d0n_3V00@0003o0?[`
iP3jl>H0o`007P3jl>H00`000?l0n_3V0?[`iP0k0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o
0?[`iP3o00007P3jl>H00`000?l0n_3V0?[`iP0l0?[`iP030?l0003jl>H0n_3V01T0n_3V00<00000
0?[`iP3jl>H08@3jl>H10?ooo`00;03jl>H5000000P0n_3V00<000000?[`iP3jl>H05`3jl>H01000
0?l0n_3V0?[`iP3o000O0?[`iP030000o`3jl>H0n_3V03X0n_3V00<0o`000?[`iP3jl>H07@3jl>H0
10000?l0n_3V0?[`iP3o000N0?[`iP030000o`3jl>H0n_3V03X0n_3V00<0o`000?[`iP3jl>H07P3j
l>H00`000?l0n_3V0?l0000N0?[`iP030000o`3jl>H0n_3V03`0n_3V00<0o`000?[`iP3jl>H06@3j
l>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V01L0n_3V00@0003o
0?[`iP3jl>H0o`007`3jl>H00`000?l0n_3V0?[`iP0i0?[`iP030?l0003jl>H0n_3V01d0n_3V00D0
003o0?[`iP3jl>H0n_3V0?l0000O0?[`iP030000o`3jl>H0n_3V03T0n_3V00<0o`000?[`iP3jl>H0
7@3jl>H010000?l0n_3V0?[`iP3o000O0?[`iP030000o`3jl>H0n_3V03X0n_3V00<0o`000?[`iP3j
l>H06P3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V01L0n_3V
00@0003o0?[`iP3jl>H0o`007`3jl>H00`000?l0n_3V0?[`iP0i0?[`iP030?l0003jl>H0n_3V01d0
n_3V00<0003o0?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V03T0
n_3V00<0o`000?[`iP3jl>H07@3jl>H01@000?l0n_3V0?[`iP3jl>H0o`0001h0n_3V00<0003o0?[`
iP3jl>H0>P3jl>H00`3o0000n_3V0?[`iP0J0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0
n_3V00<000000?[`iP3jl>H05P3jl>H00`000?l0n_3V0?[`iP020?[`iP030?l0003jl>H0n_3V01d0
n_3V00<0003o0?[`iP3jl>H0>03jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0080
n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP0h0?[`iP030?l0003jl>H0n_3V01h0
n_3V00D0003o0?[`iP3jl>H0n_3V0?l0000N0?[`iP030000o`3jl>H0n_3V03X0n_3V00<0o`000?[`
iP3jl>H06P3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V01H0
n_3V00<0003o0?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V03P0
n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V01d0
n_3V00<0003o0?[`iP3jl>H0=`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0080
n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0h0?[`iP030?l0003jl>H0n_3V01/0
n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0F0?[`iP030000
o`3jl>H0n_3V0080n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0g0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V03L0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP030?[`iP030?l0
003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H0>03jl>H00`3o0000n_3V0?[`iP0K0?[`iP030000
003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H05@3jl>H00`000?l0n_3V0?[`
iP040?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H0=`3jl>H00`3o0000n_3V0?[`
iP0M0?[`iP030000o`3jl>H0n_3V00@0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`
iP0g0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`
iP0M0?[`iP030000o`3jl>H0n_3V03L0n_3V00<0o`000?[`iP3jl>H06`3jl>H00`000000n_3V0?[`
iP0Q0?[`iP40oooo000i0?[`iP8000005P3jl>H00`000?l0n_3V0?[`iP040?[`iP030?l0003jl>H0
n_3V01d0n_3V00<0003o0?[`iP3jl>H0=P3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0
n_3V00D0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0e0?[`iP030?l0003jl>H0
n_3V01d0n_3V00<0003o0?[`iP3jl>H0103jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0
n_3V03L0n_3V00<0o`000?[`iP3jl>H06P3jl>H2000002<0n_3V0@3oool003T0n_3V00<000000?[`
iP3jl>H05@3jl>H00`000?l0n_3V0?[`iP040?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`
iP3jl>H0=@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00D0n_3V00<0o`000?[`
iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0e0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`
iP3jl>H0103jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V03H0n_3V00<0o`000?[`
iP3jl>H0703jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V01@0
n_3V00<0003o0?[`iP3jl>H01@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V03D0
n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP060?[`iP030?l0003jl>H0n_3V01`0
n_3V00<0003o0?[`iP3jl>H0=@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00D0
n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0e0?[`iP030?l0003jl>H0n_3V01`0
n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0D0?[`iP030000
o`3jl>H0n_3V00H0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0d0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H01P3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000
o`3jl>H0n_3V03@0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP060?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0=@3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000
003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H0503jl>H00`000?l0n_3V0?[`
iP060?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0=03jl>H00`3o0000n_3V0?[`
iP0L0?[`iP030000o`3jl>H0n_3V00L0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`
iP0c0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H01P3jl>H00`3o0000n_3V0?[`
iP0M0?[`iP030000o`3jl>H0n_3V03@0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l000000?[`
iP0R0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V01@0n_3V00<0003o0?[`iP3jl>H01P3jl>H0
0`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V03<0n_3V00<0o`000?[`iP3jl>H07@3jl>H0
0`000?l0n_3V0?[`iP070?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0<`3jl>H0
0`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00L0n_3V00<0o`000?[`iP3jl>H07@3jl>H0
0`000?l0n_3V0?[`iP0c0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0000003jl>H08P3jl>H1
0?ooo`00>@3jl>H00`000000n_3V0?[`iP0C0?[`iP030000o`3jl>H0n_3V00P0n_3V00<0o`000?[`
iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0b0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`
iP3jl>H0203jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V03<0n_3V00<0o`000?[`
iP3jl>H0703jl>H00`000?l0n_3V0?[`iP080?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`
iP3jl>H0<`3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`000000n_3V0280n_3V0@3oool003T0
n_3V00<000000?[`iP3jl>H04`3jl>H00`000?l0n_3V0?[`iP080?[`iP030?l0003jl>H0n_3V01d0
n_3V00<0003o0?[`iP3jl>H0<P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00P0
n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0a0?[`iP030?l0003jl>H0n_3V01d0
n_3V00<0003o0?[`iP3jl>H0203jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0380
n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l000000?[`iP0R0?[`iP40oooo000i0?[`iP030000
003jl>H0n_3V01<0n_3V00<0003o0?[`iP3jl>H0203jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V0340n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP090?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0<@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V00T0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP0b0?[`iP030?l0
003jl>H0n_3V01`0n_3V00<0003o0?[`iP0000008`3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`
iP0B0?[`iP030000o`3jl>H0n_3V00T0n_3V00<0o`000?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`
iP0`0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H02P3jl>H00`3o0000n_3V0?[`
iP0L0?[`iP030000o`3jl>H0n_3V0340n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`
iP090?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0<@3jl>H00`3o0000n_3V0?[`
iP0L0?[`iP030000o`3jl>H0000002<0n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H04P3jl>H0
0`000?l0n_3V0?[`iP0:0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0<03jl>H0
0`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00X0n_3V00<0o`000?[`iP3jl>H07@3jl>H0
0`000?l0n_3V0?[`iP0_0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H02P3jl>H0
0`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0300n_3V00<0o`000?[`iP3jl>H07@3jl>H0
0`000?l0n_3V0000000S0?[`iP40oooo000i0?[`iP8000004`3jl>H00`000?l0n_3V0?[`iP0:0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0<03jl>H00`3o0000n_3V0?[`iP0L0?[`
iP030000o`3jl>H0n_3V00/0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0_0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H02P3jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V0300n_3V00<0o`000?[`iP3jl>H0703jl>H010000?l0n_3V00000000000S
0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V0140n_3V00<0003o0?[`iP3jl>H02`3jl>H00`3o
0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02l0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`00
0?l0n_3V0?[`iP0;0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0;`3jl>H00`3o
0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00/0n_3V00<0o`000?[`iP3jl>H0703jl>H00`00
0?l0n_3V0?[`iP0`0?[`iP030?l0003jl>H0n_3V01`0n_3V00@0003o0?[`iP3jl>H000008`3jl>H1
0?ooo`00>@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000o`3jl>H0n_3V00`0n_3V00<0o`000?[`
iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0^0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`
iP3jl>H0303jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V02l0n_3V00<0o`000?[`
iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0;0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`
iP3jl>H0;`3jl>H00`3o0000n_3V0?[`iP0L0?[`iP040000o`3jl>H0n_3V000002<0n_3V0@3oool0
03T0n_3V00<000000?[`iP3jl>H04@3jl>H00`000?l0n_3V0?[`iP0<0?[`iP030?l0003jl>H0n_3V
01d0n_3V00<0003o0?[`iP3jl>H0;P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V
00`0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0]0?[`iP030?l0003jl>H0n_3V
01d0n_3V00<0003o0?[`iP3jl>H0303jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V
02h0n_3V00<0o`000?[`iP3jl>H07@3jl>H010000?l0n_3V0?[`iP00000S0?[`iP40oooo000i0?[`
iP030000003jl>H0n_3V0140n_3V00<0003o0?[`iP3jl>H0303jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V02h0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP0=0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0;@3jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V00`0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0^0?[`
iP030?l0003jl>H0n_3V01`0n_3V00D0003o0?[`iP3jl>H0n_3V0000000S0?[`iP40oooo000i0?[`
iP030000003jl>H0n_3V0100n_3V00<0003o0?[`iP3jl>H03@3jl>H00`3o0000n_3V0?[`iP0N0?[`
iP030000o`3jl>H0n_3V02`0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0=0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0;@3jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V00d0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0]0?[`
iP030?l0003jl>H0n_3V01`0n_3V00D0003o0?[`iP3jl>H0n_3V0000000S0?[`iP40oooo000i0?[`
iP030000003jl>H0n_3V0100n_3V00<0003o0?[`iP3jl>H03P3jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V02`0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0>0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0;03jl>H00`3o0000n_3V0?[`iP0L0?[`
iP030000o`3jl>H0n_3V00h0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0/0?[`
iP030?l0003jl>H0n_3V01d0n_3V00D0003o0?[`iP3jl>H0n_3V0000000S0?[`iP40oooo000i0?[`
iP030000003jl>H0n_3V0100n_3V00<0003o0?[`iP3jl>H03P3jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V02`0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0>0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0:`3jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V00h0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0/0?[`
iP030?l0003jl>H0n_3V01d0n_3V00D0003o0?[`iP3jl>H0n_3V0000000S0?[`iP40oooo000i0?[`
iP030000003jl>H0n_3V00l0n_3V00<0003o0?[`iP3jl>H03`3jl>H00`3o0000n_3V0?[`iP0N0?[`
iP030000o`3jl>H0n_3V02X0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0?0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0:`3jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V00h0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0/0?[`
iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0Q0?[`
iP40oooo000i0?[`iP030000003jl>H0n_3V00l0n_3V00<0003o0?[`iP3jl>H03`3jl>H00`3o0000
n_3V0?[`iP0N0?[`iP030000o`3jl>H0n_3V02X0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0
n_3V0?[`iP0@0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H0:`3jl>H00`3o0000
n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00l0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0
n_3V0?[`iP0Z0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H00P3jl>H00`000000
n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V00l0n_3V00<0003o0?[`iP3jl>H0
403jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02X0n_3V00<0o`000?[`iP3jl>H0
7@3jl>H00`000?l0n_3V0?[`iP0@0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0
:P3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V0100n_3V00<0o`000?[`iP3jl>H0
7@3jl>H00`000?l0n_3V0?[`iP0Z0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0
0P3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V00h0n_3V00<0
003o0?[`iP3jl>H04@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02X0n_3V00<0
o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP0A0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0
003o0?[`iP3jl>H0:@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0100n_3V00<0
o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0Z0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0
003o0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP8000003`3jl>H0
0`000?l0n_3V0?[`iP0A0?[`iP030?l0003jl>H0n_3V01h0n_3V00<0003o0?[`iP3jl>H0:03jl>H0
0`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0140n_3V00<0o`000?[`iP3jl>H07@3jl>H0
0`000?l0n_3V0?[`iP0Y0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0403jl>H0
0`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02X0n_3V00<0o`000?[`iP3jl>H0703jl>H0
0`000?l0n_3V0?[`iP020?[`iP8000008`3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0>0?[`
iP030000o`3jl>H0n_3V0180n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0X0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H04P3jl>H00`3o0000n_3V0?[`iP0L0?[`
iP030000o`3jl>H0n_3V02T0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0A0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0:03jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000
n_3V0?[`iP0>0?[`iP030000o`3jl>H0n_3V0180n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0
n_3V0?[`iP0X0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H04P3jl>H00`3o0000
n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02P0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0
n_3V0?[`iP0B0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0:03jl>H00`3o0000
n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00
>@3jl>H00`000000n_3V0?[`iP0=0?[`iP030000o`3jl>H0n_3V01<0n_3V00<0o`000?[`iP3jl>H0
7@3jl>H00`000?l0n_3V0?[`iP0X0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H0
4`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02L0n_3V00<0o`000?[`iP3jl>H0
7@3jl>H00`000?l0n_3V0?[`iP0B0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0
:03jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0
8@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0=0?[`iP030000o`3jl>H0n_3V01<0n_3V00<0
o`000?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP0V0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0
003o0?[`iP3jl>H0503jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V02L0n_3V00<0
o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0B0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0
003o0?[`iP3jl>H09`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00@0n_3V00<0
00000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0=0?[`iP030000o`3jl>H0
n_3V01@0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0V0?[`iP030?l0003jl>H0
n_3V01d0n_3V00<0003o0?[`iP3jl>H0503jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0
n_3V02L0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP0D0?[`iP030?l0003jl>H0
n_3V01d0n_3V00<0003o0?[`iP3jl>H09P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0
n_3V00@0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0<0?[`
iP030000o`3jl>H0n_3V01D0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0V0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0503jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V02H0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP0D0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H09P3jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000
n_3V0?[`iP0<0?[`iP030000o`3jl>H0n_3V01D0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0
n_3V0?[`iP0V0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H05@3jl>H00`3o0000
n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02D0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0
n_3V0?[`iP0D0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H09@3jl>H00`3o0000
n_3V0?[`iP0N0?[`iP030000o`3jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00
>@3jl>H00`000000n_3V0?[`iP0<0?[`iP030000o`3jl>H0n_3V01D0n_3V00<0o`000?[`iP3jl>H0
7P3jl>H00`000?l0n_3V0?[`iP0T0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0
5P3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V02D0n_3V00<0o`000?[`iP3jl>H0
7@3jl>H00`000?l0n_3V0?[`iP0E0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0
903jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0
8@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0<0?[`iP030000o`3jl>H0n_3V01H0n_3V00<0
o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0T0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0
003o0?[`iP3jl>H05P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02@0n_3V00<0
o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP0F0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0
003o0?[`iP3jl>H0903jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00D0n_3V00<0
00000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0;0?[`iP030000o`3jl>H0
n_3V01L0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0T0?[`iP030?l0003jl>H0
n_3V01d0n_3V00<0003o0?[`iP3jl>H05P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0
n_3V02@0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP0F0?[`iP030?l0003jl>H0
n_3V01d0n_3V00<0003o0?[`iP3jl>H0903jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0
n_3V00D0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H2000000`0n_3V00<0003o0?[`
iP3jl>H05`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02<0n_3V00<0o`000?[`
iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0G0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`
iP3jl>H08`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01H0n_3V00<0o`000?[`
iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0S0?[`iP030?l0003jl>H0n_3V01h0n_3V00<0003o0?[`
iP3jl>H0103jl>H2000002<0n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H02`3jl>H00`000?l0
n_3V0?[`iP0G0?[`iP030?l0003jl>H0n_3V01h0n_3V00<0003o0?[`iP3jl>H08P3jl>H00`3o0000
n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01P0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0
n_3V0?[`iP0S0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H05`3jl>H00`3o0000
n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0280n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0
n_3V0?[`iP060?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H0
2`3jl>H00`000?l0n_3V0?[`iP0H0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0
8P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01P0n_3V00<0o`000?[`iP3jl>H0
7@3jl>H00`000?l0n_3V0?[`iP0R0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H0
603jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0280n_3V00<0o`000?[`iP3jl>H0
7@3jl>H00`000?l0n_3V0?[`iP060?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<0
00000?[`iP3jl>H02P3jl>H00`000?l0n_3V0?[`iP0I0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0
003o0?[`iP3jl>H08P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01P0n_3V00<0
o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0R0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0
003o0?[`iP3jl>H0603jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0280n_3V00<0
o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP060?[`iP030000003jl>H0n_3V0240n_3V0@3o
ool003T0n_3V00<000000?[`iP3jl>H02P3jl>H00`000?l0n_3V0?[`iP0I0?[`iP030?l0003jl>H0
n_3V01d0n_3V00<0003o0?[`iP3jl>H08@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0
n_3V01T0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0Q0?[`iP030?l0003jl>H0
n_3V01d0n_3V00<0003o0?[`iP3jl>H0603jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0
n_3V0240n_3V00<0o`000?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP060?[`iP030000003jl>H0
n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H02P3jl>H00`000?l0n_3V0?[`iP0J0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0803jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V01X0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP0Q0?[`
iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H06P3jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V0200n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP070?[`
iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H02P3jl>H00`000?l0
n_3V0?[`iP0J0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0803jl>H00`3o0000
n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01X0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0
n_3V0?[`iP0P0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H06P3jl>H00`3o0000
n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0200n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0
n_3V0?[`iP070?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H0
2@3jl>H00`000?l0n_3V0?[`iP0K0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0
803jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01X0n_3V00<0o`000?[`iP3jl>H0
7@3jl>H00`000?l0n_3V0?[`iP0P0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H0
6P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0200n_3V00<0o`000?[`iP3jl>H0
7@3jl>H00`000?l0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<0
00000?[`iP3jl>H02@3jl>H00`000?l0n_3V0?[`iP0K0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0
003o0?[`iP3jl>H07`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01/0n_3V00<0
o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0O0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0
003o0?[`iP3jl>H06P3jl>H00`3o0000n_3V0?[`iP0N0?[`iP030000o`3jl>H0n_3V01h0n_3V00<0
o`000?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0240n_3V0@3o
ool002d0n_3V0`0000090?[`iP030000003jl>H0n_3V00T0n_3V00<0003o0?[`iP3jl>H0703jl>H0
0`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01h0n_3V00<0o`000?[`iP3jl>H07@3jl>H0
0`000?l0n_3V0?[`iP0L0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H07`3jl>H0
0`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V01`0n_3V00<0o`000?[`iP3jl>H07@3jl>H0
0`000?l0n_3V0?[`iP0N0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0203jl>H0
0`000000n_3V0?[`iP0Q0?[`iP40oooo000/0?[`iP80000000<0n_3V000000000000203jl>H00`00
0000n_3V0?[`iP090?[`iP030000o`3jl>H0n_3V01`0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`00
0?l0n_3V0?[`iP0N0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0703jl>H00`3o
0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01h0n_3V00<0o`000?[`iP3jl>H0703jl>H00`00
0?l0n_3V0?[`iP0L0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H07P3jl>H00`3o
0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H08@3jl>H10?oo
o`00;03jl>H2000000030?[`iP000000000000P0n_3V00<000000?[`iP3jl>H0203jl>H00`000?l0
n_3V0?[`iP0M0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H07@3jl>H00`3o0000
n_3V0?[`iP0N0?[`iP030000o`3jl>H0n_3V01`0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0
n_3V0?[`iP0N0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H0703jl>H00`3o0000
n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01h0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0
n_3V0?[`iP080?[`iP030000003jl>H0n_3V0240n_3V0@3oool002`0n_3V0P0000000`3jl>H00000
000000080?[`iP<00000203jl>H00`000?l0n_3V0?[`iP0M0?[`iP030?l0003jl>H0n_3V01d0n_3V
00<0003o0?[`iP3jl>H07@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01d0n_3V
00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0M0?[`iP030?l0003jl>H0n_3V01d0n_3V
00<0003o0?[`iP3jl>H0703jl>H00`3o0000n_3V0?[`iP0N0?[`iP030000o`3jl>H0n_3V01`0n_3V
00<0o`000?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP060?[`iP<000008`3jl>H10?ooo`00;03j
l>H2000000030?[`iP000000000000P0n_3V00<000000?[`iP3jl>H0203jl>H00`000?l0n_3V0?[`
iP0N0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0703jl>H00`3o0000n_3V0?[`
iP0M0?[`iP030000o`3jl>H0n_3V01h0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`
iP0L0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H07P3jl>H00`3o0000n_3V0?[`
iP0M0?[`iP030000o`3jl>H0n_3V01`0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`
iP090?[`iP030000003jl>H0n_3V0240n_3V0@3oool002`0n_3V0P0000000`3jl>H0000000000008
0?[`iP030000003jl>H0n_3V00P0n_3V00<0003o0?[`iP3jl>H07P3jl>H00`3o0000n_3V0?[`iP0M
0?[`iP030000o`3jl>H0n_3V01`0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0N
0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0703jl>H00`3o0000n_3V0?[`iP0L
0?[`iP030000o`3jl>H0n_3V01h0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0L
0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0Q
0?[`iP40oooo000/0?[`iP80000000<0n_3V000000000000203jl>H00`000000n_3V0?[`iP070?[`
iP030000o`3jl>H0n_3V01l0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0K0?[`
iP030?l0003jl>H0n_3V01h0n_3V00<0003o0?[`iP3jl>H07P3jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V01/0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0N0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0703jl>H00`3o0000n_3V0?[`iP0M0?[`
iP030000o`3jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00;@3jl>H3000000T0
n_3V00<000000?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP0P0?[`iP030?l0003jl>H0n_3V01d0
n_3V00<0003o0?[`iP3jl>H06P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01l0
n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0K0?[`iP030?l0003jl>H0n_3V01`0
n_3V00<0003o0?[`iP3jl>H0803jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01X0
n_3V00<0o`000?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP090?[`iP030000003jl>H0n_3V0240
n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP0P0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H06P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V0200n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0J0?[`iP030?l0
003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H0803jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V01X0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0:0?[`iP030000
003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`
iP0P0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H06P3jl>H00`3o0000n_3V0?[`
iP0M0?[`iP030000o`3jl>H0n_3V0200n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`
iP0J0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H0803jl>H00`3o0000n_3V0?[`
iP0M0?[`iP030000o`3jl>H0n_3V01X0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`
iP0:0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H01P3jl>H0
0`000?l0n_3V0?[`iP0Q0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H06@3jl>H0
0`3o0000n_3V0?[`iP0N0?[`iP030000o`3jl>H0n_3V0200n_3V00<0o`000?[`iP3jl>H07@3jl>H0
0`000?l0n_3V0?[`iP0I0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0803jl>H0
0`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01X0n_3V00<0o`000?[`iP3jl>H07@3jl>H0
0`000?l0n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`
iP3jl>H01P3jl>H00`000?l0n_3V0?[`iP0R0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`
iP3jl>H0603jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0240n_3V00<0o`000?[`
iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0I0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`
iP3jl>H08P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01T0n_3V00<0o`000?[`
iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0
n_3V00<000000?[`iP3jl>H01P3jl>H00`000?l0n_3V0?[`iP0R0?[`iP030?l0003jl>H0n_3V01d0
n_3V00<0003o0?[`iP3jl>H0603jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0280
n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0H0?[`iP030?l0003jl>H0n_3V01`0
n_3V00<0003o0?[`iP3jl>H08P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01P0
n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V0240
n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H01P3jl>H00`000?l0n_3V0?[`iP0R0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0603jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V0280n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0G0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H08P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V01P0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0;0?[`iP030000
003jl>H0n_3V0240n_3V0@3oool003T0n_3V0P0000060?[`iP030000o`3jl>H0n_3V02<0n_3V00<0
o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0G0?[`iP030?l0003jl>H0n_3V01h0n_3V00<0
003o0?[`iP3jl>H08P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01L0n_3V00<0
o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0R0?[`iP030?l0003jl>H0n_3V01h0n_3V00<0
003o0?[`iP3jl>H05`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00X0n_3V0P00
000S0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V00D0n_3V00<0003o0?[`iP3jl>H0903jl>H0
0`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01H0n_3V00<0o`000?[`iP3jl>H07@3jl>H0
0`000?l0n_3V0?[`iP0S0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H05`3jl>H0
0`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V02@0n_3V00<0o`000?[`iP3jl>H07@3jl>H0
0`000?l0n_3V0?[`iP0G0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H02`3jl>H0
0`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V00D0n_3V00<0003o0?[`
iP3jl>H0903jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01H0n_3V00<0o`000?[`
iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0T0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`
iP3jl>H05P3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V02@0n_3V00<0o`000?[`
iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0F0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`
iP3jl>H0303jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V00@0
n_3V00<0003o0?[`iP3jl>H09@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01D0
n_3V00<0o`000?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP0T0?[`iP030?l0003jl>H0n_3V01d0
n_3V00<0003o0?[`iP3jl>H05@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02@0
n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0F0?[`iP030?l0003jl>H0n_3V01d0
n_3V00<0003o0?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000
003jl>H0n_3V00@0n_3V00<0003o0?[`iP3jl>H09@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V01D0n_3V00<0o`000?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP0T0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H05@3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000
o`3jl>H0n_3V02D0n_3V00<0o`000?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP0E0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo
000i0?[`iP030000003jl>H0n_3V00@0n_3V00<0003o0?[`iP3jl>H09P3jl>H00`3o0000n_3V0?[`
iP0M0?[`iP030000o`3jl>H0n_3V01@0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`
iP0U0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H05@3jl>H00`3o0000n_3V0?[`
iP0L0?[`iP030000o`3jl>H0n_3V02H0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`
iP0E0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0303jl>H00`000000n_3V0?[`
iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V00@0n_3V00<0003o0?[`iP3jl>H09P3jl>H0
0`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01@0n_3V00<0o`000?[`iP3jl>H07@3jl>H0
0`000?l0n_3V0?[`iP0V0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H04`3jl>H0
0`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02H0n_3V00<0o`000?[`iP3jl>H07@3jl>H0
0`000?l0n_3V0?[`iP0D0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H03@3jl>H0
0`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V00<0n_3V00<0003o0?[`
iP3jl>H09`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01<0n_3V00<0o`000?[`
iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP0V0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`
iP3jl>H04`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02H0n_3V00<0o`000?[`
iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0D0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`
iP3jl>H03@3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V00<0
n_3V00<0003o0?[`iP3jl>H0:03jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V01<0
n_3V00<0o`000?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP0V0?[`iP030?l0003jl>H0n_3V01d0
n_3V00<0003o0?[`iP3jl>H04`3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V02L0
n_3V00<0o`000?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP0C0?[`iP030?l0003jl>H0n_3V01d0
n_3V00<0003o0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000
003jl>H0n_3V00<0n_3V00<0003o0?[`iP3jl>H0:03jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V0180n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0W0?[`iP030?l0
003jl>H0n_3V01h0n_3V00<0003o0?[`iP3jl>H04P3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000
o`3jl>H0n_3V02P0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0C0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo
000i0?[`iP030000003jl>H0n_3V00<0n_3V00<0003o0?[`iP3jl>H0:03jl>H00`3o0000n_3V0?[`
iP0M0?[`iP030000o`3jl>H0n_3V0180n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`
iP0X0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H04@3jl>H00`3o0000n_3V0?[`
iP0M0?[`iP030000o`3jl>H0n_3V02P0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`
iP0B0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H03P3jl>H00`000000n_3V0?[`
iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V0080n_3V00<0003o0?[`iP3jl>H0:@3jl>H0
0`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0140n_3V00<0o`000?[`iP3jl>H07P3jl>H0
0`000?l0n_3V0?[`iP0X0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H04@3jl>H0
0`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02P0n_3V00<0o`000?[`iP3jl>H07P3jl>H0
0`000?l0n_3V0?[`iP0A0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H03P3jl>H0
0`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP8000000`3jl>H00`000?l0n_3V0?[`iP0Z0?[`
iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H04@3jl>H00`3o0000n_3V0?[`iP0N0?[`
iP030000o`3jl>H0n_3V02P0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0A0?[`
iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H0:@3jl>H00`3o0000n_3V0?[`iP0N0?[`
iP030000o`3jl>H0n_3V0140n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0=0?[`
iP8000008`3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP020?[`iP030000o`3jl>H0n_3V02X0
n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0@0?[`iP030?l0003jl>H0n_3V01d0
n_3V00<0003o0?[`iP3jl>H0:@3jl>H00`3o0000n_3V0?[`iP0N0?[`iP030000o`3jl>H0n_3V00l0
n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0Z0?[`iP030?l0003jl>H0n_3V01d0
n_3V00<0003o0?[`iP3jl>H04@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00h0
n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP020?[`iP030000
o`3jl>H0n_3V02X0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0?0?[`iP030?l0
003jl>H0n_3V01h0n_3V00<0003o0?[`iP3jl>H0:P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V00l0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0Z0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0403jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H01@000000n_3V0?[`
iP3jl>H0003o02d0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0?0?[`iP030?l0
003jl>H0n_3V01h0n_3V00<0003o0?[`iP3jl>H0:P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V00l0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0Z0?[`iP030?l0
003jl>H0n_3V01h0n_3V00<0003o0?[`iP3jl>H03`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H01@000000n_3V0?[`
iP3jl>H0003o02h0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP0?0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0:`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V00h0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0/0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H03`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H01@000000n_3V0?[`
iP3jl>H0003o02h0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0>0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0;03jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V00d0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0/0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H03P3jl>H00`3o0000n_3V0?[`iP0N0?[`iP030000
o`3jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H01@000000n_3V0?[`
iP3jl>H0003o02h0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0=0?[`iP030?l0
003jl>H0n_3V01h0n_3V00<0003o0?[`iP3jl>H0;03jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V00d0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0/0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H03P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000
o`3jl>H0n_3V0100n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H010000000n_3V0?[`
iP000?l_0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H03@3jl>H00`3o0000n_3V
0?[`iP0N0?[`iP030000o`3jl>H0n_3V02`0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V
0?[`iP0=0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H0;P3jl>H00`3o0000n_3V
0?[`iP0M0?[`iP030000o`3jl>H0n_3V00d0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V
0?[`iP0@0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00@000000?[`iP3jl>H0003o
<03jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V00d0n_3V00<0o`000?[`iP3jl>H0
7@3jl>H00`000?l0n_3V0?[`iP0]0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0
303jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V02h0n_3V00<0o`000?[`iP3jl>H0
7@3jl>H00`000?l0n_3V0?[`iP0=0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0
403jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP040000003jl>H0n_3V0000oc00n_3V
00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0<0?[`iP030?l0003jl>H0n_3V01d0n_3V
00<0003o0?[`iP3jl>H0;P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00/0n_3V
00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0^0?[`iP030?l0003jl>H0n_3V01d0n_3V
00<0003o0?[`iP3jl>H0303jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0140n_3V
00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H010000000n_3V0?[`iP000?l`0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H02`3jl>H00`3o0000n_3V0?[`iP0N0?[`iP030000
o`3jl>H0n_3V02h0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0;0?[`iP030?l0
003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0;P3jl>H00`3o0000n_3V0?[`iP0N0?[`iP030000
o`3jl>H0n_3V00/0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0A0?[`iP030000
003jl>H0n_3V0240n_3V0@3oool003T0n_3V0P0000000`000?l0n_3V0?[`iP0_0?[`iP030?l0003j
l>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H02`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3j
l>H0n_3V02l0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0:0?[`iP030?l0003j
l>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0<03jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3j
l>H0n_3V00/0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0@0?[`iP8000008`3j
l>H10?ooo`00>@3jl>H00`000000n_3V0000o`0b0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o
0?[`iP3jl>H02`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0300n_3V00<0o`00
0?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP090?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o
0?[`iP3jl>H0<03jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00X0n_3V00<0o`00
0?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V0240n_3V0@3oool0
03T0n_3V00<000000?[`iP000?l0<P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V
00X0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0`0?[`iP030?l0003jl>H0n_3V
01d0n_3V00<0003o0?[`iP3jl>H02@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V
0300n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0:0?[`iP030?l0003jl>H0n_3V
01d0n_3V00<0003o0?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP03
0000003jl>H0003o0380n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP090?[`iP03
0?l0003jl>H0n_3V01h0n_3V00<0003o0?[`iP3jl>H0<03jl>H00`3o0000n_3V0?[`iP0M0?[`iP03
0000o`3jl>H0n_3V00T0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0a0?[`iP03
0?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H02@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP03
0000o`3jl>H0n_3V0180n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000003o
0?[`iP0b0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H02@3jl>H00`3o0000n_3V
0?[`iP0M0?[`iP030000o`3jl>H0n_3V0380n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V
0?[`iP080?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0<P3jl>H00`3o0000n_3V
0?[`iP0M0?[`iP030000o`3jl>H0n_3V00P0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V
0?[`iP0C0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000000o`3jl>H0<`3j
l>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00P0n_3V00<0o`000?[`iP3jl>H07@3j
l>H00`000?l0n_3V0?[`iP0b0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H01`3j
l>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0380n_3V00<0o`000?[`iP3jl>H07@3j
l>H00`000?l0n_3V0?[`iP080?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H04`3j
l>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP03000000000?l0n_3V03<0n_3V00<0o`00
0?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP080?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o
0?[`iP3jl>H0<P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00L0n_3V00<0o`00
0?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0c0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o
0?[`iP3jl>H01`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V01<0n_3V00<00000
0?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000003o0?[`iP0c0?[`iP030?l0003jl>H0n_3V
01d0n_3V00<0003o0?[`iP3jl>H01`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V
03@0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP060?[`iP030?l0003jl>H0n_3V
01d0n_3V00<0003o0?[`iP3jl>H0=03jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V
00H0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V
0240n_3V0@3oool003T0n_3V00<0003o0?[`iP3jl>H0<`3jl>H00`3o0000n_3V0?[`iP0N0?[`iP03
0000o`3jl>H0n_3V00H0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0d0?[`iP03
0?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H01@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP03
0000o`3jl>H0n_3V03@0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP060?[`iP03
0?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo000i0?[`iP030000o`3jl>H0n_3V03@0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V
0?[`iP060?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0=03jl>H00`3o0000n_3V
0?[`iP0M0?[`iP030000o`3jl>H0n_3V00D0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V
0?[`iP0e0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H01P3jl>H00`3o0000n_3V
0?[`iP0M0?[`iP030000o`3jl>H0n_3V01@0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3j
l>H00`000000n_3V0?[`iP0d0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H01P3j
l>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V03@0n_3V00<0o`000?[`iP3jl>H07@3j
l>H00`000?l0n_3V0?[`iP050?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0=@3j
l>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V00@0n_3V00<0o`000?[`iP3jl>H07P3j
l>H00`000?l0n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V0P00000e
0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H01@3jl>H00`3o0000n_3V0?[`iP0M
0?[`iP030000o`3jl>H0n_3V03H0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP04
0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H0=P3jl>H00`3o0000n_3V0?[`iP0M
0?[`iP030000o`3jl>H0n_3V00@0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0D
0?[`iP8000008`3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0e0?[`iP030?l0003jl>H0n_3V
01d0n_3V00<0003o0?[`iP3jl>H0103jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V
03H0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V
01d0n_3V00<0003o0?[`iP3jl>H0=`3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V
00@0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V
0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H0=@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP03
0000o`3jl>H0n_3V00@0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0f0?[`iP03
0?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP03
0000o`3jl>H0n_3V03L0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP040?[`iP03
0?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo000i0?[`iP030000003jl>H0n_3V03D0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V
0?[`iP040?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H0=`3jl>H00`3o0000n_3V
0?[`iP0M0?[`iP030000o`3jl>H0n_3V0080n_3V00<0o`000?[`iP3jl>H07P3jl>H00`000?l0n_3V
0?[`iP0g0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H00P3jl>H00`3o0000n_3V
0?[`iP0M0?[`iP030000o`3jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3j
l>H00`000000n_3V0?[`iP0f0?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H00P3j
l>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V03P0n_3V00<0o`000?[`iP3jl>H07@3j
l>H01@000?l0n_3V0?[`iP3jl>H0o`0001l0n_3V00<0003o0?[`iP3jl>H0>03jl>H00`3o0000n_3V
0?[`iP0M0?[`iP030000o`3jl>H0n_3V0080n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V
0?[`iP0F0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H0=P3j
l>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V0080n_3V00<0o`000?[`iP3jl>H0703j
l>H00`000?l0n_3V0?[`iP0i0?[`iP030?l0003jl>H0n_3V01d0n_3V00D0003o0?[`iP3jl>H0n_3V
0?l0000O0?[`iP030000o`3jl>H0n_3V03T0n_3V00<0o`000?[`iP3jl>H0703jl>H00`000?l0n_3V
0?[`iP020?[`iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H05P3jl>H00`000000n_3V
0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V03H0n_3V00<0o`000?[`iP3jl>H07@3j
l>H00`000?l0n_3V0?[`iP020?[`iP030?l0003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H0>@3j
l>H00`3o0000n_3V0?[`iP0M0?[`iP050000o`3jl>H0n_3V0?[`iP3o00007`3jl>H00`000?l0n_3V
0?[`iP0i0?[`iP030?l0003jl>H0n_3V01d0n_3V00@0003o0?[`iP3jl>H0o`007`3jl>H00`000?l0
n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H0
=`3jl>H00`3o0000n_3V0?[`iP0M0?[`iP040000o`3jl>H0n_3V0?l001l0n_3V00<0003o0?[`iP3j
l>H0>@3jl>H00`3o0000n_3V0?[`iP0N0?[`iP030000o`3jl>H0o`0001l0n_3V00<0003o0?[`iP3j
l>H0>P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP040000o`3jl>H0n_3V0?l001l0n_3V00<0003o0?[`
iP3jl>H05`3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V03L0
n_3V00<0o`000?[`iP3jl>H07@3jl>H010000?l0n_3V0?[`iP3o000N0?[`iP030000o`3jl>H0n_3V
03/0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0n_3V0?l0000O0?[`iP030000o`3jl>H0n_3V
03/0n_3V00<0o`000?[`iP3jl>H0703jl>H010000?l0n_3V0?[`iP3o000O0?[`iP030000o`3jl>H0
n_3V01L0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0h0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?l0003jl>H07P3jl>H00`000?l0n_3V0?[`iP0k0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?[`iP3o00007P3jl>H00`000?l0n_3V0?[`iP0l0?[`
iP030?l0003jl>H0n_3V01d0n_3V00<0003o0?l0003jl>H07P3jl>H00`000?l0n_3V0?[`iP0H0?[`
iP030000003jl>H0n_3V0240n_3V0@3oool002d0n_3V0`0000090?[`iP030000003jl>H0n_3V03P0
n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0o`000?[`iP0N0?[`iP030000o`3jl>H0n_3V03/0
n_3V00<0o`000?[`iP3jl>H07P3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030000o`3jl>H0n_3V03`0
n_3V00<0o`000?[`iP3jl>H07@3jl>H00`000?l0o`000?[`iP0N0?[`iP030000o`3jl>H0n_3V01P0
n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00;03jl>H00`000000n_3V0?[`iP02000000P0n_3V
00<000000?[`iP3jl>H0>03jl>H00`3o0000n_3V0?[`iP0M0?[`iP030?l0003jl>H0n_3V01d0n_3V
00<0003o0?[`iP3jl>H0?@3jl>H00`3o0000n_3V0?[`iP0M0?[`iP030?l0003jl>H0n_3V01d0n_3V
00<0003o0?[`iP3jl>H0?@3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030?l0003jl>H0n_3V01h0n_3V
00<0003o0?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000_0?[`iP800000203j
l>H3000003T0n_3V00<0o`000?[`iP3jl>H0703jl>H00`3o0000003o0?[`iP0M0?[`iP030000o`3j
l>H0n_3V03d0n_3V00<0o`000?[`iP3jl>H07@3jl>H00`3o0000n_3V0?[`iP0L0?[`iP030000o`3j
l>H0n_3V03h0n_3V00<0o`000?[`iP3jl>H0703jl>H00`3o0000003o0?[`iP0M0?[`iP030000o`3j
l>H0n_3V01L0n_3V0`00000S0?[`iP40oooo000_0?[`iP800000203jl>H00`000000n_3V0?[`iP0i
0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0o`000000o`3jl>H0703jl>H00`000?l0n_3V0?[`iP0n
0?[`iP030?l0003jl>H0n_3V01`0n_3V00<0o`000?[`iP000?l07@3jl>H00`000?l0n_3V0?[`iP0o
0?[`iP030?l0003jl>H0n_3V01/0n_3V00<0o`000000o`3jl>H07@3jl>H00`000?l0n_3V0?[`iP0I
0?[`iP030000003jl>H0n_3V0240n_3V0@3oool002`0n_3V00<000000?[`iP3jl>H00P0000080?[`
iP030000003jl>H0n_3V03T0n_3V00<0o`000?[`iP3jl>H06`3jl>H00`3o0000n_3V0000o`0M0?[`
iP030000o`3jl>H0n_3V03l0n_3V00<0o`000?[`iP3jl>H06`3jl>H00`3o0000n_3V0000o`0M0?[`
iP030000o`3jl>H0n_3V03l0n_3V00<0o`000?[`iP3jl>H06P3jl>H0103o0000n_3V0?[`iP000?lM
0?[`iP030000o`3jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00;03jl>H40000
00T0n_3V00<000000?[`iP3jl>H0>P3jl>H00`3o0000n_3V0?[`iP0J0?[`iP040?l0003jl>H0n_3V
0000oa`0n_3V00<0003o0?[`iP3jl>H0?`3jl>H00`3o0000n_3V0?[`iP0J0?[`iP040?l0003jl>H0
n_3V0000oa`0n_3V00<0003o0?[`iP3jl>H0@03jl>H00`3o0000n_3V0?[`iP0J0?[`iP040?l0003j
l>H0n_3V0000oa`0n_3V00<0003o0?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo
000/0?[`iP8000002`3jl>H00`000000n_3V0?[`iP0j0?[`iP030?l0003jl>H0n_3V01T0n_3V00D0
o`000?[`iP3jl>H0n_3V0000o`0K0?[`iP030000o`3jl>H0n_3V0440n_3V00<0o`000?[`iP3jl>H0
6@3jl>H01@3o0000n_3V0?[`iP3jl>H0003o01/0n_3V00<0003o0?[`iP3jl>H0@@3jl>H00`3o0000
n_3V0?[`iP0I0?[`iP040?l0003jl>H0n_3V0000oa`0n_3V00<0003o0?[`iP3jl>H06P3jl>H00`00
0000n_3V0?[`iP0Q0?[`iP40oooo000/0?[`iPD00000203jl>H00`000000n_3V0?[`iP0k0?[`iP03
0?l0003jl>H0n_3V01P0n_3V00<0o`000?[`iP3jl>H00P3jl>H00`000?l0n_3V0?[`iP0H0?[`iP03
0000o`3jl>H0n_3V0440n_3V00<0o`000?[`iP3jl>H06@3jl>H01@3o0000n_3V0?[`iP3jl>H0003o
01X0n_3V00<0003o0?[`iP3jl>H0@P3jl>H00`3o0000n_3V0?[`iP0H0?[`iP030?l0003jl>H0n_3V
0080n_3V00<0003o0?[`iP3jl>H0603jl>H00`000?l0n_3V0?[`iP0K0?[`iP030000003jl>H0n_3V
0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H0>`3jl>H00`3o0000n_3V0?[`iP0H0?[`iP03
0?l0003jl>H0n_3V0080n_3V00<0003o0?[`iP3jl>H05`3jl>H00`000?l0n_3V0?[`iP120?[`iP03
0?l0003jl>H0n_3V01P0n_3V00<0o`000?[`iP3jl>H00`3jl>H00`000?l0n_3V0?[`iP0G0?[`iP03
0000o`3jl>H0n_3V04<0n_3V00<0o`000?[`iP3jl>H05`3jl>H00`3o0000n_3V0?[`iP020?[`iP03
0000o`3jl>H0n_3V01P0n_3V00<0003o0?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo000i0?[`iP030000003jl>H0n_3V03`0n_3V00<0o`000?[`iP3jl>H05P3jl>H00`3o0000n_3V
0?[`iP030?[`iP030000o`3jl>H0n_3V01L0n_3V00<0003o0?[`iP3jl>H0@`3jl>H00`3o0000n_3V
0?[`iP0G0?[`iP030?l0003jl>H0n_3V00<0n_3V00<0003o0?[`iP3jl>H05`3jl>H00`000?l0n_3V
0?[`iP130?[`iP030?l0003jl>H0n_3V01H0n_3V00<0o`000?[`iP3jl>H00`3jl>H00`000?l0n_3V
0?[`iP0H0?[`iP030000o`3jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3j
l>H00`000000n_3V0?[`iP0l0?[`iP030?l0003jl>H0n_3V01H0n_3V00<0o`000?[`iP3jl>H0103j
l>H00`000?l0n_3V0?[`iP0E0?[`iP030000o`3jl>H0n_3V04@0n_3V00<0o`000?[`iP3jl>H05`3j
l>H00`3o0000n_3V0?[`iP040?[`iP030000o`3jl>H0n_3V01D0n_3V00<0003o0?[`iP3jl>H0A03j
l>H00`3o0000n_3V0?[`iP0F0?[`iP030?l0003jl>H0n_3V00@0n_3V00<0003o0?[`iP3jl>H05P3j
l>H00`000?l0n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<00000
0?[`iP3jl>H0?@3jl>H00`3o0000n_3V0?[`iP0D0?[`iP030?l0003jl>H0n_3V00D0n_3V00<0003o
0?[`iP3jl>H05@3jl>H00`000?l0n_3V0?[`iP150?[`iP030?l0003jl>H0n_3V01D0n_3V00<0o`00
0?[`iP3jl>H01@3jl>H00`000?l0n_3V0?[`iP0E0?[`iP030000o`3jl>H0n_3V04D0n_3V00<0o`00
0?[`iP3jl>H0503jl>H00`3o0000n_3V0?[`iP050?[`iP030000o`3jl>H0n_3V01H0n_3V00<0003o
0?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V
03d0n_3V00<0o`000?[`iP3jl>H0503jl>H00`3o0000n_3V0?[`iP060?[`iP030000o`3jl>H0n_3V
01<0n_3V00<0003o0?[`iP3jl>H0AP3jl>H00`3o0000n_3V0?[`iP0E0?[`iP030?l0003jl>H0n_3V
00H0n_3V00<0003o0?[`iP3jl>H04`3jl>H00`000?l0n_3V0?[`iP160?[`iP030?l0003jl>H0n_3V
01@0n_3V00<0o`000?[`iP3jl>H01P3jl>H00`000?l0n_3V0?[`iP0D0?[`iP030000o`3jl>H0n_3V
01d0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H2000003l0n_3V00<0o`000?[`iP3j
l>H04P3jl>H00`3o0000n_3V0?[`iP070?[`iP030000o`3jl>H0n_3V01<0n_3V00<0003o0?[`iP3j
l>H0A`3jl>H00`3o0000n_3V0?[`iP0C0?[`iP030?l0003jl>H0n_3V00L0n_3V00<0003o0?[`iP3j
l>H04`3jl>H00`000?l0n_3V0?[`iP170?[`iP030?l0003jl>H0n_3V0180n_3V00<0o`000?[`iP3j
l>H01`3jl>H00`000?l0n_3V0?[`iP0D0?[`iP030000o`3jl>H0n_3V01`0n_3V0P00000S0?[`iP40
oooo000i0?[`iP030000003jl>H0n_3V03h0n_3V00<0o`000?[`iP3jl>H04P3jl>H00`3o0000n_3V
0?[`iP080?[`iP030000o`3jl>H0n_3V0140n_3V00<0003o0?[`iP3jl>H0B@3jl>H00`3o0000n_3V
0?[`iP0B0?[`iP030?l0003jl>H0n_3V00L0n_3V00<0003o0?[`iP3jl>H04P3jl>H00`000?l0n_3V
0?[`iP180?[`iP030?l0003jl>H0n_3V0180n_3V00<0o`000?[`iP3jl>H0203jl>H00`000?l0n_3V
0?[`iP0B0?[`iP030000o`3jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3j
l>H00`000000n_3V0?[`iP0o0?[`iP030?l0003jl>H0n_3V0100n_3V00<0o`000?[`iP3jl>H02@3j
l>H00`000?l0n_3V0?[`iP0A0?[`iP030000o`3jl>H0n_3V04T0n_3V00<0o`000?[`iP3jl>H04@3j
l>H00`3o0000n_3V0?[`iP090?[`iP030000o`3jl>H0n_3V0140n_3V00<0003o0?[`iP3jl>H0B@3j
l>H00`3o0000n_3V0?[`iP0@0?[`iP030?l0003jl>H0n_3V00T0n_3V00<0003o0?[`iP3jl>H04P3j
l>H00`000?l0n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<00000
0?[`iP3jl>H0?`3jl>H00`3o0000n_3V0?[`iP0@0?[`iP030?l0003jl>H0n_3V00X0n_3V00<0003o
0?[`iP3jl>H03`3jl>H00`000?l0n_3V0?[`iP1;0?[`iP030?l0003jl>H0n_3V00l0n_3V00<0o`00
0?[`iP3jl>H02P3jl>H00`000?l0n_3V0?[`iP0@0?[`iP030000o`3jl>H0n_3V04X0n_3V00<0o`00
0?[`iP3jl>H0403jl>H00`3o0000n_3V0?[`iP0:0?[`iP030000o`3jl>H0n_3V0100n_3V00<0003o
0?[`iP3jl>H07`3jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V
0400n_3V00<0o`000?[`iP3jl>H03P3jl>H00`3o0000n_3V0?[`iP0;0?[`iP030000o`3jl>H0n_3V
00l0n_3V00<0003o0?[`iP3jl>H0B`3jl>H00`3o0000n_3V0?[`iP0?0?[`iP030?l0003jl>H0n_3V
00/0n_3V00<0003o0?[`iP3jl>H03`3jl>H00`000?l0n_3V0?[`iP1;0?[`iP030?l0003jl>H0n_3V
00h0n_3V00<0o`000?[`iP3jl>H0303jl>H00`000?l0n_3V0?[`iP0?0?[`iP030000o`3jl>H0n_3V
01l0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP110?[`iP03
0?l0003jl>H0n_3V00d0n_3V00<0o`000?[`iP3jl>H0303jl>H00`000?l0n_3V0?[`iP0=0?[`iP03
0000o`3jl>H0n_3V04d0n_3V00<0o`000?[`iP3jl>H03@3jl>H00`3o0000n_3V0?[`iP0=0?[`iP03
0000o`3jl>H0n_3V00d0n_3V00<0003o0?[`iP3jl>H0C@3jl>H00`3o0000n_3V0?[`iP0=0?[`iP03
0?l0003jl>H0n_3V00d0n_3V00<0003o0?[`iP3jl>H03@3jl>H00`000?l0n_3V0?[`iP0P0?[`iP03
0000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H0@@3jl>H00`3o0000n_3V
0?[`iP0<0?[`iP030?l0003jl>H0n_3V00d0n_3V00<0003o0?[`iP3jl>H03@3jl>H00`000?l0n_3V
0?[`iP1=0?[`iP030?l0003jl>H0n_3V00`0n_3V00<0o`000?[`iP3jl>H03P3jl>H00`000?l0n_3V
0?[`iP0<0?[`iP030000o`3jl>H0n_3V04h0n_3V00<0o`000?[`iP3jl>H0303jl>H00`3o0000n_3V
0?[`iP0>0?[`iP030000o`3jl>H0n_3V00d0n_3V00<0003o0?[`iP3jl>H0803jl>H00`000000n_3V
0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V0480n_3V00<0o`000?[`iP3jl>H02P3j
l>H00`3o0000n_3V0?[`iP0?0?[`iP030000o`3jl>H0n_3V00/0n_3V00<0003o0?[`iP3jl>H0C`3j
l>H00`3o0000n_3V0?[`iP0;0?[`iP030?l0003jl>H0n_3V00l0n_3V00<0003o0?[`iP3jl>H02P3j
l>H00`000?l0n_3V0?[`iP1@0?[`iP030?l0003jl>H0n_3V00/0n_3V00<0o`000?[`iP3jl>H03`3j
l>H00`000?l0n_3V0?[`iP0;0?[`iP030000o`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H08@3j
l>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP130?[`iP030?l0003jl>H0n_3V00T0n_3V00<0o`00
0?[`iP3jl>H0403jl>H00`000?l0n_3V0?[`iP090?[`iP030000o`3jl>H0n_3V0540n_3V00<0o`00
0?[`iP3jl>H02@3jl>H00`3o0000n_3V0?[`iP0A0?[`iP030000o`3jl>H0n_3V00T0n_3V00<0003o
0?[`iP3jl>H0D@3jl>H00`3o0000n_3V0?[`iP090?[`iP030?l0003jl>H0n_3V0140n_3V00<0003o
0?[`iP3jl>H02@3jl>H00`000?l0n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V0240n_3V0@3oool0
03T0n_3V00<000000?[`iP3jl>H0A03jl>H00`3o0000n_3V0?[`iP070?[`iP030?l0003jl>H0n_3V
0180n_3V00<0003o0?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP1C0?[`iP030?l0003jl>H0n_3V
00L0n_3V00<0o`000?[`iP3jl>H04`3jl>H00`000?l0n_3V0?[`iP070?[`iP030000o`3jl>H0n_3V
05<0n_3V00<0o`000?[`iP3jl>H01`3jl>H00`3o0000n_3V0?[`iP0C0?[`iP030000o`3jl>H0n_3V
00H0n_3V0P000?lU0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`iP3j
l>H0A@3jl>H00`3o0000n_3V0?[`iP040?[`iP80o`005P3jl>H00`000?l0n_3V0?[`iP050?[`iP03
0000o`3jl>H0n_3V05D0n_3V00<0o`000?[`iP3jl>H01@3jl>H00`3o0000n_3V0?[`iP0E0?[`iP03
0000o`3jl>H0n_3V00D0n_3V00<0003o0?[`iP3jl>H0E@3jl>H00`3o0000n_3V0?[`iP040?[`iP80
o`005`3jl>H00`000?l0n_3V0?[`iP040?[`iP030000o`3jl>H0n_3V02D0n_3V00<000000?[`iP3j
l>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP160?[`iP80o`000P3jl>H20?l001T0n_3V
0`000?l0103jl>H0003o0000o`000?mI0?[`iP<0o`0000@0n_3V0?l0003o0000o`006@3jl>H30000
o`040?[`iP000?l0003o0000oeT0n_3V0`3o00000`3jl>H0o`000?l0000J0?[`iP<0003o00<0n_3V
0000o`000?l0:03jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP800000B@3jl>H20?l0
01h0n_3V0P000?mM0?[`iP<0o`007@3jl>H30000oed0n_3V0`3o000M0?[`iP<0003o:03jl>H20000
02<0n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240
n_3V0@3oool003T0n_3V00<000000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V
0@3oool003T0n_3V00<000000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3o
ool003T0n_3V00<000000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3oool0
03T0n_3V00<000000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0
n_3V00<000000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V
00<000000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<0
00000?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<00000
0?[`iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V00<000000?[`
iP3jl>H0o`3jl>JD0?[`iP030000003jl>H0n_3V0240n_3V0@3oool003T0n_3V0P00003o0?[`iY@0
n_3V0P00000S0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V0?l0n_3VU03jl>H00`000000n_3V
0?[`iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V0?l0n_3VU03jl>H00`000000n_3V0?[`
iP0Q0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V0?l0n_3VU03jl>H00`000000n_3V0?[`iP0Q
0?[`iP40oooo000i0?[`iP030000003jl>H0n_3V0?l0n_3VU03jl>H00`000000n_3V0?[`iP0Q0?[`
iP40oooo000i0?[`iP030000003jl>H0n_3V0?l0n_3VU03jl>H00`000000n_3V0?[`iP0Q0?[`iP40
oooo000i0?[`iP030000003jl>H0n_3V0?l0n_3VU03jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo
000i0?[`iP030000003jl>H0n_3V0?l0n_3VU03jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i
0?[`iP030000003jl>H0n_3V0?l0n_3VU03jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`
iP030000003jl>H0n_3V0?l0n_3VU03jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP03
0000003jl>H0n_3V0?l0n_3VU03jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000i0?[`iP800000
o`3jl>JD0?[`iP8000008`3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0n_3V00<0
00000?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0n_3V00<00000
0?[`iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0n_3V00<000000?[`
iP3jl>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0n_3V00<000000?[`iP3j
l>H08@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0n_3V00<000000?[`iP3jl>H0
8@3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0n_3V00<000000?[`iP3jl>H08@3j
l>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0n_3V00<000000?[`iP3jl>H08@3jl>H1
0?ooo`00>@3jl>H00`000000n_3V0?[`iP3o0?[`iY@0n_3V00<000000?[`iP3jl>H08@3jl>H10?oo
o`00>@3jl>H00`000000n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V0300n_3V00<000000?[`iP3j
l>H0;`3jl>H00`000000n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V0300n_3V00<000000?[`iP3j
l>H0<03jl>H00`000000n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V0300n_3V00<000000?[`iP3j
l>H08@3jl>H10?ooo`009@3jl>H600000080n_3V0`0000090?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00P0n_3V
00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00P0n_3V
00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H08@3jl>H10?ooo`009`3jl>H2000000<0n_3V0P0000000`3jl>H000000000
00080?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP080?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`009`3jl>H2
000000<0n_3V0P0000000`3jl>H00000000000080?[`i_l00000V000000S0?[`iP40oooo000W0?[`
iP8000000`3jl>H2000000030?[`iP00000000000?l0n_3V``3jl>H10?ooo`009`3jl>H2000000<0
n_3V0P0000000`3jl>H000000000003o0?[`i/<0n_3V0@3oool002L0n_3V0P0000030?[`iP800000
00<0n_3V000000000000o`3jl>K30?[`iP40oooo000U0?[`iP@000000`3jl>H2000000030?[`iP00
000000000?l0n_3V``3jl>H10?ooo`009`3jl>H2000000@0n_3V0`00003o0?[`i/@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo002l0?[`iP@00000:03jl>H400000?l0n_3V
203jl>H10?ooo`00_`3jl>H2000002X0n_3V0P00003o0?[`iPL0n_3V0@3oool008T0n_3V1P000004
0?[`iP/0000000<0n_3V000000000000100000020?[`iP80000000<0n_3V0000000000001`000000
1@3jl>H00000000000000000n_3V00<0000000@0n_3V000000000000n_3V0P00000;0?[`iPH00000
1P3jl>H700000080n_3V100000030?[`iP80000000<0n_3V0000000000000P3jl>H400000080n_3V
0`0000001@3jl>H00000000000000000n_3V0080000000@0n_3V00000000000000002@3jl>H20000
00040?[`iP00000000000?[`iPH000000`3jl>H300000080n_3V0`000000103jl>H0000000000000
00090?[`iPH00000203jl>H500000080n_3V0`0000001@3jl>H00000000000000000n_3V00H00000
00@0n_3V000000000000n_3V0`0000000`3jl>H0000000000002000000<0n_3V0P0000000`3jl>H0
000000000006000000<0n_3V100000020?[`iP<0000000@0n_3V0000000000000000MP3jl>H10?oo
o`00RP3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H2000000D0
n_3V0P0000030?[`iP80000000@0n_3V00000000000000000`3jl>H2000000@0n_3V0P000000103j
l>H000000000003jl>H2000000040?[`iP0000000000000000X0n_3V0P0000020?[`iP800000203j
l>H2000000<0n_3V00@000000?[`iP00000000000`3jl>H01@000000n_3V000000000000n_3V00<0
000000<0n_3V0000000000000`3jl>H00`000000n_3V0?[`iP02000000040?[`iP00000000000?[`
iP80000000@0n_3V00000000000000002P3jl>H2000000030?[`iP000000000000<0n_3V0P000004
0?[`iP8000000P3jl>H00`000000n_3V0?[`iP02000000030?[`iP000000000000T0n_3V0P000002
0?[`iP8000002@3jl>H010000000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000
003jl>H200000080n_3V0P000000103jl>H000000000003jl>H3000000030?[`iP00000000000080
n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P3jl>H200000080n_3V0P0000000`3jl>H000000000001g0?[`iP40oooo002:0?[`iP80
00000P3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP8000001@3jl>H2000000<0
n_3V0P0000020?[`iP8000000`3jl>H2000000@0n_3V0P000000103jl>H000000000003jl>H20000
0080n_3V0P00000:0?[`iP8000000P3jl>H2000000P0n_3V0P0000030?[`iP040000003jl>H00000
000000D0n_3V0P0000020?[`iP80000000<0n_3V0000000000001P3jl>H2000000040?[`iP000000
00000?[`iP8000000P3jl>H2000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000D0n_3V0P0000000`3jl>H00000000000090?[`iP8000000P3jl>H2000000d0n_3V0P00
00020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`iP80000000@0n_3V000000000000
n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000<0n_3V0`00001h0?[`iP40
oooo002:0?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP800000
1@3jl>H2000000<0n_3V0P0000020?[`iP8000000`3jl>H2000000@0n_3V0P000000103jl>H00000
0000003jl>H200000080n_3V0P00000;0?[`iPD00000203jl>H2000000D0n_3V1P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V000000000000100000020?[`iP80000000@0n_3V00000000
0000n_3V0P0000020?[`iP8000002@3jl>H2000000030?[`iP000000n_3V008000000P3jl>H20000
00@0n_3V0P0000050?[`iP80000000<0n_3V0000000000002P3jl>H5000000/0n_3V0`0000030?[`
iP80000000<0n_3V0000000000000P3jl>H5000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H400000080n_3V0P00
00000`3jl>H00000000000020?[`iP8000000`3jl>H3000007P0n_3V0@3oool008X0n_3V1@000003
0?[`iP80000000<0n_3V0000000000000`3jl>H2000000D0n_3V0P0000030?[`iP80000000@0n_3V
00000000000000000`3jl>H2000000@0n_3V0P000000103jl>H000000000003jl>H2000000040?[`
iP0000000000000000h0n_3V0P0000080?[`iP8000001@3jl>H200000080n_3V0P000000103jl>H0
00000000003jl>H3000000030?[`iP00000000000080n_3V0P0000020?[`iP80000000@0n_3V0000
00000000n_3V0P000000103jl>H000000000000000090?[`iP80000000<0n_3V0000003jl>H00P00
00020?[`iP800000103jl>H2000000D0n_3V0P0000000`3jl>H000000000000=0?[`iP8000002P3j
l>H3000000@0n_3V0P0000000`3jl>H00000000000050?[`iP80000000@0n_3V000000000000n_3V
0`0000000`3jl>H00000000000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H70000
0080n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000007L0n_3V0@3oool008X0
n_3V0P0000020?[`iP80000000D0n_3V00000000000000000?[`iP02000000030?[`iP0000000000
008000001@3jl>H2000000@0n_3V0P000000103jl>H000000000003jl>H4000000<0n_3V1@000003
0?[`iP80000000@0n_3V00000000000000002P3jl>H4000000T0n_3V0P0000060?[`iP@000000`3j
l>H2000000050?[`iP00000000000000003jl>H0100000020?[`iPD000000`3jl>H2000000030?[`
iP000000000000P0n_3V100000000`3jl>H0000000000005000000<0n_3V1@0000030?[`iP@00000
2`3jl>H4000000X0n_3V0P0000060?[`iP@000000`3jl>H4000000<0n_3V0P0000000`3jl>H00000
000000020?[`iP@0000000<0n_3V0000000000000P0000000`3jl>H000000000000300000080n_3V
0P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000000007H0n_3V0@3oool008X0n_3V
0P0000020?[`iP8000004@3jl>H2000000L0n_3V0P00000]0?[`iP8000009@3jl>H2000001P0n_3V
0P0000050?[`iP8000006`3jl>H2000000<0n_3V00<000000?[`iP3jl>H00P00000?0?[`iP800000
3`3jl>H200000080n_3V0P0000250?[`iP40oooo00290?[`iPH000002`3jl>H2000000<0n_3V1000
00060?[`iP<000000`3jl>H2000002L0n_3V1000000S0?[`iP<000004P3jl>H2000000@0n_3V0P00
00040?[`iP<00000703jl>H5000000040?[`iP0000000000000000h0n_3V0`00000>0?[`iPH00000
QP3jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-12.8258, -15.1715, 0.0492159, \
0.0875961}}]
}, Open  ]],

Cell["\<\
One problem with this is that the ShadowBox is always within the Frame, if \
you use a Frame.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using ShowLegend", "Subsection"],

Cell["\<\
Probably the best way to use legends with DrawingPaper is to use the \
ShowLegend statement. Here are two curves drawn using DrawingPaper.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Blue, 
          Draw[Sin[x], {x, \(-3\), 
              3}], \[IndentingNewLine]OrangeRed, \
\[IndentingNewLine]ParametricDraw[
            2\ {Sin[t], Sin[t]\ Cos[t]}, {t, 0, 
              2\ \[Pi]}]}, \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]ImageSize \[Rule] 
          500, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]TextStyle \[Rule] {FontSize \[Rule] 12, 
            FontWeight \[Rule] "\<Bold\>"}, \[IndentingNewLine]PlotLabel \
\[Rule] "\<Two Curves\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 500 166.667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.15873 0.166667 0.15873 [
[.02381 -0.0125 -9.5625 -15.5625 ]
[.02381 -0.0125 9.5625 0 ]
[.18254 -0.0125 -9.5625 -15.5625 ]
[.18254 -0.0125 9.5625 0 ]
[.34127 -0.0125 -9.5625 -15.5625 ]
[.34127 -0.0125 9.5625 0 ]
[.5 -0.0125 -5.59375 -15.5625 ]
[.5 -0.0125 5.59375 0 ]
[.65873 -0.0125 -5.59375 -15.5625 ]
[.65873 -0.0125 5.59375 0 ]
[.81746 -0.0125 -5.59375 -15.5625 ]
[.81746 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -15.5625 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -19.125 -7.78125 ]
[-0.0125 .00794 0 7.78125 ]
[-0.0125 .0873 -33.5 -7.78125 ]
[-0.0125 .0873 0 7.78125 ]
[-0.0125 .16667 -11.1875 -7.78125 ]
[-0.0125 .16667 0 7.78125 ]
[-0.0125 .24603 -25.5625 -7.78125 ]
[-0.0125 .24603 0 7.78125 ]
[-0.0125 .3254 -11.1875 -7.78125 ]
[-0.0125 .3254 0 7.78125 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[.5 .34583 -37.9375 0 ]
[.5 .34583 37.9375 15.5625 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
gsave
-0.0125 .00794 -80.125 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .0873 m
.00625 .0873 L
s
gsave
-0.0125 .0873 -94.5 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .16667 m
.00625 .16667 L
s
gsave
-0.0125 .16667 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .24603 m
.00625 .24603 L
s
gsave
-0.0125 .24603 -86.5625 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .3254 m
.00625 .3254 L
s
gsave
-0.0125 .3254 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .07143 m
.00375 .07143 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .13492 m
.00375 .13492 L
s
0 .15079 m
.00375 .15079 L
s
0 .18254 m
.00375 .18254 L
s
0 .19841 m
.00375 .19841 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .2619 m
.00375 .2619 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.18254 .32708 m
.18254 .33333 L
s
.34127 .32708 m
.34127 .33333 L
s
.5 .32708 m
.5 .33333 L
s
.65873 .32708 m
.65873 .33333 L
s
.81746 .32708 m
.81746 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.05556 .32958 m
.05556 .33333 L
s
.0873 .32958 m
.0873 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.15079 .32958 m
.15079 .33333 L
s
.21429 .32958 m
.21429 .33333 L
s
.24603 .32958 m
.24603 .33333 L
s
.27778 .32958 m
.27778 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.37302 .32958 m
.37302 .33333 L
s
.40476 .32958 m
.40476 .33333 L
s
.43651 .32958 m
.43651 .33333 L
s
.46825 .32958 m
.46825 .33333 L
s
.53175 .32958 m
.53175 .33333 L
s
.56349 .32958 m
.56349 .33333 L
s
.59524 .32958 m
.59524 .33333 L
s
.62698 .32958 m
.62698 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.72222 .32958 m
.72222 .33333 L
s
.75397 .32958 m
.75397 .33333 L
s
.78571 .32958 m
.78571 .33333 L
s
.84921 .32958 m
.84921 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.9127 .32958 m
.9127 .33333 L
s
.94444 .32958 m
.94444 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .07143 m
1 .07143 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .13492 m
1 .13492 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .19841 m
1 .19841 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
gsave
.5 .34583 -98.9375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Two) show
91.750 15.000 moveto
(Curves) show
134.875 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .14427 m
.06244 .10705 L
.10458 .07055 L
.14415 .04235 L
.16408 .03097 L
.18221 .02247 L
.20178 .01541 L
.21254 .01249 L
.21738 .01141 L
.22272 .01039 L
.22739 .00964 L
.23241 .00899 L
.23518 .00869 L
.23772 .00846 L
.2403 .00828 L
.24269 .00814 L
.24488 .00804 L
.2461 .008 L
.24721 .00797 L
.24843 .00795 L
.24975 .00794 L
.251 .00794 L
.25214 .00794 L
.25322 .00796 L
.25423 .00798 L
.25533 .008 L
.25651 .00804 L
.25893 .00815 L
.26113 .00828 L
.26594 .00867 L
.27104 .00924 L
.28022 .01068 L
.29008 .01281 L
.30098 .01584 L
.32032 .02298 L
.34118 .03305 L
.38232 .05947 L
.42194 .09172 L
.46005 .12714 L
.50061 .16728 L
.53966 .20591 L
.58116 .24433 L
.62114 .27638 L
.6596 .3007 L
.67948 .31027 L
.68962 .3143 L
.70052 .31795 L
.71075 .32073 L
.7201 .32271 L
.72459 .32347 L
Mistroke
.72949 .32416 L
.73412 .32467 L
.73841 .32502 L
.74106 .32518 L
.7435 .32529 L
.74478 .32533 L
.74618 .32537 L
.74689 .32538 L
.74764 .32539 L
.74836 .32539 L
.749 .3254 L
.75028 .32539 L
.75146 .32538 L
.75275 .32536 L
.75341 .32534 L
.75413 .32532 L
.75663 .32523 L
.75897 .3251 L
.76365 .32475 L
.76794 .32431 L
.77759 .32289 L
.78742 .32085 L
.79655 .31842 L
.81727 .31108 L
.83777 .30139 L
.85637 .29066 L
.8964 .262 L
.93492 .22871 L
.97589 .18936 L
.97619 .18907 L
Mfstroke
1 .271 0 r
.5 .16667 m
.58004 .24412 L
.61998 .27775 L
.6403 .29252 L
.66127 .30558 L
.6802 .31502 L
.69665 .32104 L
.70429 .32304 L
.70851 .3239 L
.71236 .32452 L
.71567 .32493 L
.71753 .3251 L
.71927 .32523 L
.72108 .32533 L
.72273 .32538 L
.72461 .3254 L
.72639 .32537 L
.72821 .32531 L
.72922 .32525 L
.73016 .32519 L
.73186 .32504 L
.73364 .32484 L
.7367 .3244 L
.74 .32376 L
.74346 .32291 L
.7471 .3218 L
.75345 .31928 L
.75955 .31612 L
.76507 .31254 L
.77472 .30433 L
.78429 .29318 L
.79319 .27909 L
.79973 .26543 L
.80579 .24882 L
.80839 .23985 L
.81079 .23006 L
.81416 .21187 L
.81553 .20141 L
.81648 .19154 L
.81688 .18581 L
.81715 .18059 L
.81727 .17769 L
.81732 .17616 L
.81736 .17454 L
.81739 .17312 L
.81742 .17156 L
.81745 .16882 L
.81746 .16611 L
.81745 .16359 L
.81741 .16084 L
Mistroke
.81737 .1593 L
.81734 .1579 L
.81726 .15534 L
.81715 .15258 L
.81688 .14758 L
.81655 .1427 L
.81611 .13757 L
.81512 .12847 L
.81363 .11808 L
.81191 .10859 L
.80684 .08797 L
.80049 .06973 L
.79315 .05416 L
.7855 .04182 L
.77607 .03036 L
.76579 .02132 L
.75949 .01718 L
.75328 .01397 L
.74999 .01258 L
.74645 .01132 L
.74333 .01039 L
.73994 .00956 L
.7362 .00885 L
.73451 .0086 L
.73266 .00837 L
.73152 .00826 L
.73046 .00817 L
.72946 .0081 L
.72836 .00803 L
.72644 .00796 L
.72538 .00794 L
.72439 .00794 L
.72252 .00796 L
.72157 .00799 L
.72051 .00803 L
.71864 .00815 L
.71687 .00829 L
.71283 .00875 L
.70841 .00946 L
.70014 .01131 L
.69235 .01364 L
.67697 .01975 L
.66008 .02843 L
.62317 .05315 L
.58691 .08307 L
.50633 .16034 L
.42035 .24377 L
.3791 .27846 L
.36166 .29118 L
.34304 .3031 L
Mistroke
.32695 .31175 L
.31034 .31876 L
.3015 .32158 L
.29363 .32348 L
.28992 .32417 L
.28594 .32474 L
.28413 .32495 L
.28223 .32512 L
.28044 .32525 L
.27883 .32533 L
.27703 .32538 L
.27536 .3254 L
.27355 .32537 L
.27162 .3253 L
.27065 .32524 L
.26961 .32517 L
.26773 .325 L
.26425 .32455 L
.26102 .32398 L
.25765 .32321 L
.25176 .3214 L
.24523 .31867 L
.23937 .31547 L
.23328 .31132 L
.22699 .30599 L
.21706 .29497 L
.20789 .28105 L
.20061 .26624 L
.19492 .25104 L
.19216 .24189 L
.18956 .2316 L
.1876 .22225 L
.18588 .2121 L
.18463 .20278 L
.18408 .19778 L
.18359 .19237 L
.18322 .18738 L
.18295 .1828 L
.18285 .1806 L
.18275 .17819 L
.18268 .17606 L
.18262 .17381 L
.18259 .17247 L
.18257 .17101 L
.18254 .16843 L
.18254 .16698 L
.18254 .16543 L
.18255 .16396 L
.18257 .16263 L
.18261 .16004 L
Mistroke
.18264 .15858 L
.18268 .15723 L
.18287 .15214 L
.18311 .14763 L
.18345 .14269 L
.18438 .13276 L
.18574 .12216 L
.18762 .11101 L
.19211 .09165 L
.19794 .07373 L
.20584 .05605 L
.21473 .0415 L
.22419 .0301 L
.2296 .02499 L
.2358 .02018 L
.24156 .01658 L
.24792 .01344 L
.25392 .0112 L
.25742 .01019 L
.26076 .00941 L
.26389 .00884 L
.26678 .00844 L
.2684 .00827 L
.27017 .00812 L
.27187 .00802 L
.27344 .00796 L
.27518 .00794 L
.27701 .00795 L
.2786 .008 L
.28034 .00808 L
.28224 .00821 L
.28428 .0084 L
.288 .00887 L
.29183 .0095 L
.29549 .01025 L
.30246 .01203 L
.31907 .018 L
.33795 .02732 L
.37501 .05177 L
.41659 .08619 L
.49493 .16159 L
.5 .16667 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 166.625},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000YR000`400?l00000o`00003oo`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool005`0n_3V0`00000g0?[`iPD00000=`3jl>H600000380n_3V0`00000h
0?[`iPH00000=P3jl>H5000003L0n_3V0`00000c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V
00800000=P3jl>H2000003`0n_3V0P00000c0?[`iP80000000<0n_3V000000000000>@3jl>H20000
03P0n_3V0P00000i0?[`iP030000003jl>H0n_3V00800000<P3jl>H10?ooo`00D`3jl>H5000000H0
n_3V0P00000^0?[`iPD00000103jl>H200000340n_3V1@0000050?[`iP800000<`3jl>H200000003
0?[`iP000000000003T0n_3V0P00000i0?[`iP800000>`3jl>H200000380n_3V0@3oool005h0n_3V
0P00000h0?[`iP800000>P3jl>H2000003<0n_3V0P0000000`3jl>H000000000000i0?[`iP800000
>P3jl>H2000003X0n_3V0P00000b0?[`iP40oooo001L0?[`iP<00000>P3jl>H2000003T0n_3V0P00
000c0?[`iP80000000<0n_3V000000000000>@3jl>H2000003/0n_3V0P00000g0?[`iP<00000<`3j
l>H10?ooo`00GP3jl>H2000003H0n_3V0P0000000`3jl>H000000000000i0?[`iP800000<`3jl>H2
000000030?[`iP000000000003T0n_3V0P00000h0?[`iP80000000<0n_3V000000000000>@3jl>H2
00000380n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H00P00000f0?[`iP80000000<0n_3V0000
00000000=`3jl>H4000003<0n_3V0P0000000`3jl>H000000000000g0?[`iP@00000>03jl>H20000
00030?[`iP000000000003H0n_3V00<000000?[`iP3jl>H00P00000b0?[`iP40oooo001L0?[`iP<0
0000>03jl>H3000003X0n_3V0P00000d0?[`iP<00000>P3jl>H2000003T0n_3V0`00000h0?[`iP<0
0000<`3jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo001@0?[`i_l00000NP00000Z0?[`iP40oooo00140?[`iPH000001P3jl>H00`00
0000n_3V0?[`iP060?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0:03jl>H10?oo
o`00AP3jl>H2000000P0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP090?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP060?[`iP03
0000003jl>H0n_3V02P0n_3V0@3oool003`0n_3V1@0000050?[`iP800000203jl>H4000005D0n_3V
2P000?l:0?m509l0n_3V2P3oA@1O0?[`iP@00000:P3jl>H10?ooo`00AP3jl>H2000000P0n_3V00<0
00000?[`iP3jl>H0C`3jl>H70000o`H0n_3V103oA@020?[`iPL0003o00<0n_3V0?m5003oA@000P3o
A@2E0?[`iPH0odD02P3jl>H40?m505h0n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00AP3jl>H2
000000P0n_3V00<000000?[`iP3jl>H0C03jl>H30000o`/0n_3V0P3oA@0=0?[`iP<0003o0P3jl>H3
0?m50900n_3V0P3oA@0D0?[`iP80odD0G03jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo00160?[`
iP800000203jl>H00`000000n_3V0?[`iP180?[`iP@0003o303jl>H20?m50180n_3V10000?l0103j
l>H0odD00?m5003oA@2;0?[`iP80odD0603jl>H00`3oA@00n_3V0?[`iP1I0?[`iP030000003jl>H0
n_3V02P0n_3V0@3oool004@0n_3V100000080?[`iP030000003jl>H0n_3V04H0n_3V0P000?l?0?[`
iP030?m5003jl>H0n_3V01H0n_3V0P000?l20?[`iP<0odD0QP3jl>H20?m501/0n_3V0P3oA@1I0?[`
iP030000003jl>H0n_3V02P0n_3V0@3oool004H0n_3V0P0000080?[`iP030000003jl>H0n_3V04@0
n_3V0P000?l@0?[`iP030?m5003jl>H0n_3V01T0n_3V0`000?l20?[`iP80odD0PP3jl>H20?m501l0
n_3V0P3oA@1G0?[`iP030000003jl>H0n_3V02P0n_3V0@3oool00500n_3V0`0000110?[`iP<0003o
4@3jl>H00`3oA@00n_3V0?[`iP0M0?[`iP80003o0P3jl>H20?m507h0n_3V0P3oA@0S0?[`iP030?m5
003jl>H0n_3V0580n_3V0`00000Z0?[`iP40oooo001@0?[`iP030000003jl>H0n_3V03l0n_3V0P00
0?lC0?[`iP030?m5003jl>H0n_3V0200n_3V0P000?l20?[`iP80odD0NP3jl>H20?m502H0n_3V00<0
odD00?[`iP3jl>H0D`3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP030000003jl>H0
n_3V03d0n_3V0P000?lC0?[`iP80odD09@3jl>H20000o`80n_3V0P3oA@1f0?[`iP80odD0:@3jl>H0
0`3oA@00n_3V0?[`iP1B0?[`iP030000003jl>H0n_3V02P0n_3V0@3oool00500n_3V00<000000?[`
iP3jl>H0>`3jl>H20000oa@0n_3V00<0odD00?[`iP3jl>H09`3jl>H20000o`80n_3V00<0odD00?[`
iP3jl>H0L@3jl>H20?m502`0n_3V00<0odD00?[`iP3jl>H0D@3jl>H00`000000n_3V0?[`iP0X0?[`
iP40oooo001@0?[`iP030000003jl>H0n_3V03T0n_3V0P000?lE0?[`iP030?m5003jl>H0n_3V02X0
n_3V00@0003o0?[`iP3jl>H0odD0L@3jl>H00`3oA@00n_3V0?[`iP0]0?[`iP030?m5003jl>H0n_3V
0500n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00D03jl>H00`000000n_3V0?[`iP0g0?[`iP80
003o5`3jl>H00`3oA@00n_3V0?[`iP0[0?[`iP80003o00<0n_3V0?m5003oA@00K@3jl>H20?m50300
n_3V00<0odD00?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP<00000
=@3jl>H20000oaP0n_3V00<0odD00?[`iP3jl>H0;P3jl>H20000o`030?[`iP3oA@00n_3V06X0n_3V
00<0odD00?[`iP3jl>H0<@3jl>H00`3oA@00n_3V0?[`iP1=0?[`iP<00000:P3jl>H10?ooo`00D03j
l>H00`000000n_3V0?[`iP0c0?[`iP80003o6@3jl>H00`3oA@00n_3V0?[`iP0a0?[`iP80003o0P3o
A@1W0?[`iP80odD0=@3jl>H00`3oA@00n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V02P0n_3V0@3o
ool00500n_3V00<000000?[`iP3jl>H0<P3jl>H00`000?l0n_3V0?[`iP0H0?[`iP030?m5003jl>H0
n_3V03@0n_3V00<0003o0?[`iP3oA@00I03jl>H20?m503P0n_3V00<0odD00?[`iP3jl>H0C@3jl>H0
0`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP030000003jl>H0n_3V0300n_3V0P000?lK0?[`
iP030?m5003jl>H0n_3V03D0n_3V0P000?l00`3oA@00n_3V0?[`iP1P0?[`iP030?m5003jl>H0n_3V
03P0n_3V00<0odD00?[`iP3jl>H0C@3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP03
0000003jl>H0n_3V02l0n_3V00<0003o0?[`iP3jl>H06P3jl>H00`3oA@00n_3V0?[`iP0h0?[`iP03
0000o`3oA@00odD005h0n_3V0P3oA@0l0?[`iP030?m5003jl>H0n_3V04`0n_3V00<000000?[`iP3j
l>H0:03jl>H10?ooo`00D03jl>H00`000000n_3V0?[`iP0^0?[`iP030000o`3jl>H0n_3V01/0n_3V
00<0odD00?[`iP3jl>H0>P3jl>H00`000?l0odD00?[`iP1K0?[`iP030?m5003jl>H0n_3V03d0n_3V
00<0odD00?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP<00000;@3j
l>H00`000?l0n_3V0?[`iP0K0?[`iP030?m5003jl>H0n_3V03d0n_3V00<0odD00000o`3jl>H0F03j
l>H00`3oA@00n_3V0?[`iP0n0?[`iP030?m5003jl>H0n_3V04T0n_3V0`00000Z0?[`iP40oooo001@
0?[`iP030000003jl>H0n_3V02/0n_3V0P000?lN0?[`iP030?m5003jl>H0n_3V03h0n_3V0P3oA@1G
0?[`iP030?m5003jl>H0n_3V0400n_3V00<0odD00?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP0X
0?[`iP40oooo001@0?[`iP030000003jl>H0n_3V02X0n_3V00<0003o0?[`iP3jl>H07@3jl>H00`3o
A@00n_3V0?[`iP110?[`iP030?m5003jl>H0n_3V0580n_3V0P3oA@130?[`iP030?m5003jl>H0n_3V
04X0n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00D03jl>H00`000000n_3V0?[`iP0Y0?[`iP03
0000o`3jl>H0n_3V01h0n_3V00<0odD00?[`iP3jl>H0@P3jl>H00`3oA@00n_3V0?[`iP1@0?[`iP03
0?m5003jl>H0n_3V04@0n_3V00<0odD00?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`iP0X0?[`iP40
oooo001@0?[`iP030000003jl>H0n_3V02L0n_3V0P000?lP0?[`iP030?m5003jl>H0n_3V04@0n_3V
0P3oA@1?0?[`iP030?m5003jl>H0n_3V04D0n_3V00<0odD00?[`iP3jl>H0B@3jl>H00`000000n_3V
0?[`iP0X0?[`iP40oooo001@0?[`iP030000003jl>H0n_3V02H0n_3V00<0003o0?[`iP3jl>H0803j
l>H00`3oA@00n_3V0?[`iP160?[`iP030?m5003jl>H0n_3V04/0n_3V00<0odD00?[`iP3jl>H0A`3j
l>H00`3oA@00n_3V0?[`iP180?[`iP030000003jl>H0n_3V02P0n_3V0@3oool00500n_3V0`00000U
0?[`iP030000o`3jl>H0n_3V0200n_3V00<0odD00?[`iP3jl>H0B03jl>H00`3oA@00n_3V0?[`iP19
0?[`iP030?m5003jl>H0n_3V04P0n_3V00<0odD00?[`iP3jl>H0AP3jl>H3000002X0n_3V0@3oool0
0500n_3V00<000000?[`iP3jl>H0903jl>H00`000?l0n_3V0?[`iP0Q0?[`iP030?m5003jl>H0n_3V
04T0n_3V0P3oA@170?[`iP80odD0C03jl>H00`3oA@00n_3V0?[`iP170?[`iP030000003jl>H0n_3V
02P0n_3V0@3oool00500n_3V00<000000?[`iP3jl>H08P3jl>H20000ob@0n_3V00<0odD00?[`iP3j
l>H0BP3jl>H00`000?l0odD00?[`iP140?[`iP030?m5003jl>H0n_3V04`0n_3V00<0odD00?[`iP3j
l>H0A`3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP030000003jl>H0n_3V0240n_3V
00<0003o0?[`iP3jl>H08`3jl>H00`3oA@00n_3V0?[`iP1<0?[`iP030000o`3oA@00n_3V0480n_3V
00<0odD00?[`iP3jl>H0C@3jl>H00`3oA@00n_3V0?[`iP170?[`iP030000003jl>H0n_3V02P0n_3V
0@3oool003H0n_3V0`0000040?[`iP8000001@3jl>H3000000T0n_3V00<000000?[`iP3jl>H0803j
l>H00`000?l0n_3V0?[`iP0T0?[`iP030?m5003jl>H0n_3V04d0n_3V00<0003o0?m5003oA@00@03j
l>H00`3oA@00n_3V0?[`iP1>0?[`iP030?m5003jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H0:03j
l>H10?ooo`00=@3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP030000003jl>H0
n_3V00800000203jl>H00`000000n_3V0?[`iP0O0?[`iP030000o`3jl>H0n_3V02@0n_3V00<0odD0
0?[`iP3jl>H0C`3jl>H20000o`030?m5003jl>H0n_3V03`0n_3V00<0odD00?[`iP3jl>H0D03jl>H0
0`3oA@00n_3V0?[`iP160?[`iP030000003jl>H0n_3V02P0n_3V0@3oool002d0n_3V1@0000030?[`
iP80000000<0n_3V000000000000303jl>H2000000P0n_3V1000000M0?[`iP030000o`3jl>H0n_3V
02D0n_3V00<0odD00?[`iP3jl>H0D@3jl>H00`000?l0odD00?[`iP0k0?[`iP030?m5003jl>H0n_3V
0540n_3V00<0odD00?[`iP3jl>H0@`3jl>H4000002X0n_3V0@3oool003D0n_3V0P0000000`3jl>H0
00000000000<0?[`iP800000203jl>H00`000000n_3V0?[`iP0L0?[`iP80003o9`3jl>H00`3oA@00
n_3V0?[`iP1C0?[`iP030000o`3oA@00n_3V03T0n_3V00<0odD00?[`iP3jl>H0DP3jl>H00`3oA@00
n_3V0?[`iP160?[`iP030000003jl>H0n_3V02P0n_3V0@3oool003D0n_3V0P0000000`3jl>H00000
000000090?[`iP030000003jl>H0n_3V00800000203jl>H00`000000n_3V0?[`iP0K0?[`iP030000
o`3jl>H0n_3V02L0n_3V00<0odD00?[`iP3jl>H0E03jl>H00`000?l0odD00?[`iP0g0?[`iP030?m5
003jl>H0n_3V05<0n_3V00<0odD00?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo
000e0?[`iP80000000<0n_3V0000000000002@3jl>H4000000T0n_3V00<000000?[`iP3jl>H06P3j
l>H00`000?l0n_3V0?[`iP0X0?[`iP030?m5003jl>H0n_3V05D0n_3V00<0003o0?m5003jl>H0=@3j
l>H00`3oA@00n_3V0?[`iP1E0?[`iP030?m5003jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0:03j
l>H10?ooo`00=@3jl>H2000000030?[`iP000000000000T0n_3V0P00000;0?[`iP030000003jl>H0
n_3V01T0n_3V00<0003o0?[`iP3jl>H0:@3jl>H00`3oA@00n_3V0?[`iP1F0?[`iP030000o`3oA@00
n_3V03<0n_3V00<0odD00?[`iP3jl>H0EP3jl>H00`3oA@00n_3V0?[`iP150?[`iP030000003jl>H0
n_3V02P0n_3V0@3oool003H0n_3V0`00000:0?[`iPD00000203jl>H00`000000n_3V0?[`iP0G0?[`
iP80003o;03jl>H00`3oA@00n_3V0?[`iP1G0?[`iP030000o`3oA@00n_3V0300n_3V0P3oA@1I0?[`
iP030?m5003jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00D03jl>H3000001H0
n_3V00<0003o0?[`iP3jl>H0:`3jl>H00`3oA@00n_3V0?[`iP1I0?[`iP030000o`3oA@00n_3V02h0
n_3V00<0odD00?[`iP3jl>H0F@3jl>H00`3oA@00n_3V0?[`iP130?[`iP<00000:P3jl>H10?ooo`00
D03jl>H00`000000n_3V0?[`iP0E0?[`iP030000o`3jl>H0n_3V02`0n_3V00<0odD00?[`iP3jl>H0
FP3jl>H00`000?l0odD00?[`iP0/0?[`iP030?m5003jl>H0n_3V05/0n_3V00<0odD00?[`iP3jl>H0
A03jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP030000003jl>H0n_3V01@0n_3V00<0
003o0?[`iP3jl>H0;@3jl>H00`3oA@00n_3V0?[`iP1K0?[`iP030000o`3oA@00n_3V02X0n_3V00<0
odD00?[`iP3jl>H0G03jl>H00`3oA@00n_3V0?[`iP140?[`iP030000003jl>H0n_3V02P0n_3V0@3o
ool00500n_3V00<000000?[`iP3jl>H04`3jl>H00`000?l0n_3V0?[`iP0^0?[`iP030?m5003jl>H0
n_3V05`0n_3V00<0003o0?m5003jl>H0:03jl>H00`3oA@00n_3V0?[`iP1M0?[`iP030?m5003jl>H0
n_3V04@0n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00D03jl>H00`000000n_3V0?[`iP0B0?[`
iP030000o`3jl>H0n_3V02l0n_3V00<0odD00?[`iP3jl>H0GP3jl>H00`3oA@00n_3V0?[`iP0U0?[`
iP030?m5003jl>H0n_3V05l0n_3V00<0odD00?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP0X0?[`
iP40oooo001@0?[`iP030000003jl>H0n_3V0140n_3V00<0003o0?[`iP3jl>H0;`3jl>H00`3oA@00
n_3V0?[`iP1P0?[`iP030?m5003jl>H0n_3V02<0n_3V00<0odD00?[`iP3jl>H0H03jl>H00`3oA@00
n_3V0?[`iP130?[`iP030000003jl>H0n_3V02P0n_3V0@3oool00500n_3V0`00000@0?[`iP030000
o`3jl>H0n_3V0300n_3V00<0odD00?[`iP3jl>H0H@3jl>H00`3oA@00n_3V0?[`iP0Q0?[`iP030?m5
003jl>H0n_3V0640n_3V00<0odD00?[`iP3jl>H0@@3jl>H3000002X0n_3V0@3oool00500n_3V00<0
00000?[`iP3jl>H03`3jl>H00`000?l0n_3V0?[`iP0a0?[`iP030?m5003jl>H0n_3V0680n_3V00<0
odD00?[`iP3jl>H07`3jl>H00`3oA@00n_3V0?[`iP1R0?[`iP030?m5003jl>H0n_3V04<0n_3V00<0
00000?[`iP3jl>H0:03jl>H10?ooo`00D03jl>H00`000000n_3V0?[`iP0=0?[`iP80003o=03jl>H0
0`3oA@00n_3V0?[`iP1S0?[`iP030?m5003jl>H0n_3V01d0n_3V00<0odD00?[`iP3jl>H0H`3jl>H0
0`3oA@00n_3V0?[`iP130?[`iP030000003jl>H0n_3V02P0n_3V0@3oool00500n_3V00<000000?[`
iP3jl>H0303jl>H00`000?l0n_3V0?[`iP0d0?[`iP030?m5003jl>H0n_3V06@0n_3V00<0odD00?[`
iP3jl>H06`3jl>H00`3oA@00n_3V0?[`iP1T0?[`iP030?m5003jl>H0n_3V04<0n_3V00<000000?[`
iP3jl>H0:03jl>H10?ooo`00D03jl>H00`000000n_3V0?[`iP0;0?[`iP030000o`3jl>H0n_3V03D0
n_3V00<0odD00?[`iP3jl>H0I@3jl>H00`3oA@00n_3V0?[`iP0I0?[`iP030?m5003jl>H0n_3V06D0
n_3V00<0odD00?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP030000
003jl>H0n_3V00X0n_3V00<0003o0?[`iP3jl>H0=P3jl>H00`3oA@00n_3V0?[`iP1V0?[`iP030?m5
003jl>H0n_3V01L0n_3V00<0odD00?[`iP3jl>H0IP3jl>H00`3oA@00n_3V0?[`iP130?[`iP030000
003jl>H0n_3V02P0n_3V0@3oool00500n_3V0`0000090?[`iP030000o`3jl>H0n_3V03L0n_3V00<0
odD00?[`iP3jl>H0I`3jl>H00`3oA@00n_3V0?[`iP0E0?[`iP030?m5003jl>H0n_3V06P0n_3V00<0
odD00?[`iP3jl>H0@03jl>H3000002X0n_3V0@3oool00500n_3V00<000000?[`iP3jl>H0203jl>H0
0`000?l0n_3V0?[`iP0g0?[`iP030?m5003jl>H0n_3V06T0n_3V00<0odD00?[`iP3jl>H04`3jl>H0
0`3oA@00n_3V0?[`iP1Y0?[`iP030?m5003jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0:03jl>H1
0?ooo`00D03jl>H00`000000n_3V0?[`iP070?[`iP030000o`3jl>H0n_3V03P0n_3V00<0odD00?[`
iP3jl>H0JP3jl>H00`3oA@00n_3V0?[`iP0@0?[`iP80odD0K03jl>H00`3oA@00n_3V0?[`iP120?[`
iP030000003jl>H0n_3V02P0n_3V0@3oool00500n_3V00<000000?[`iP3jl>H01P3jl>H00`000?l0
n_3V0?[`iP0i0?[`iP030?m5003jl>H0n_3V06/0n_3V00<0odD00?[`iP3jl>H03P3jl>H00`3oA@00
n_3V0?[`iP1/0?[`iP030?m5003jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00
D03jl>H00`000000n_3V0?[`iP120?[`iP030?m5003jl>H0n_3V06`0n_3V00<0odD00?[`iP3jl>H0
303jl>H00`3oA@00n_3V0?[`iP1]0?[`iP030?m5003jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0
:03jl>H10?ooo`00D03jl>H00`000000n_3V0?[`iP120?[`iP030?m5003jl>H0n_3V06d0n_3V00<0
odD00?[`iP3jl>H02P3jl>H00`3oA@00n_3V0?[`iP1^0?[`iP030?m5003jl>H0n_3V0480n_3V00<0
00000?[`iP3jl>H0:03jl>H10?ooo`00D03jl>H300000480n_3V00<0odD00?[`iP3jl>H0KP3jl>H0
0`3oA@00n_3V0?[`iP080?[`iP030?m5003jl>H0n_3V06l0n_3V00<0odD00?[`iP3jl>H0@03jl>H3
000002X0n_3V0@3oool00500n_3V00<000000?[`iP3jl>H0@P3jl>H00`3oA@00n_3V0?[`iP1_0?[`
iP030?m5003jl>H0n_3V00H0n_3V00<0odD00?[`iP3jl>H0L03jl>H00`3oA@00n_3V0?[`iP120?[`
iP030000003jl>H0n_3V02P0n_3V0@3oool00500n_3V00<000000?[`iP3jl>H0@P3jl>H00`3oA@00
n_3V0?[`iP1`0?[`iP030?m5003jl>H0n_3V00@0n_3V00<0odD00?[`iP3jl>H0L@3jl>H00`3oA@00
n_3V0?[`iP120?[`iP030000003jl>H0n_3V02P0n_3V0@3oool004@0n_3V0`0000090?[`iP030000
003jl>H0n_3V0480n_3V00<0odD00?[`iP3jl>H0L@3jl>H00`3oA@00n_3V0?[`iP020?[`iP030?m5
003jl>H0n_3V0780n_3V00<0odD00?[`iP3jl>H0@P3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo
00130?[`iP80000000<0n_3V000000000000203jl>H00`000000n_3V0?[`iP120?[`iP030?m5003j
l>H0n_3V0780n_3V00@0odD00?[`iP3jl>H0odD0M@3jl>H00`3oA@00n_3V0?[`iP120?[`iP030000
003jl>H0n_3V02P0n_3V0@3oool004<0n_3V0P0000000`3jl>H00000000000080?[`iP030000003j
l>H0n_3V0480n_3V00<0odD00?[`iP3jl>H0L`3jl>H20?m507H0n_3V00<0odD00?[`iP3jl>H0@P3j
l>H00`000000n_3V0?[`iP0X0?[`iP40oooo00130?[`iP80000000<0n_3V000000000000203jl>H4
00000440n_3V00<0odD00?[`iP3jl>H0L`3jl>H20?m507H0n_3V00<0odD00?[`iP3jl>H0?`3jl>H4
000002X0n_3V0@3oool004<0n_3V0P0000000`3jl>H00000000000080?[`iP030000003jl>H0n_3V
0480n_3V00<0odD00?[`iP3jl>H0LP3jl>H0103oA@00n_3V0?[`iP3oA@1e0?[`iP030?m5003jl>H0
n_3V0480n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00@`3jl>H2000000030?[`iP0000000000
00P0n_3V00<000000?[`iP3jl>H0@P3jl>H00`3oA@00n_3V0?[`iP1a0?[`iP030?m5003jl>H0n_3V
0080n_3V00<0odD00?[`iP3jl>H0LP3jl>H00`3oA@00n_3V0?[`iP120?[`iP030000003jl>H0n_3V
02P0n_3V0@3oool004<0n_3V0P0000000`3jl>H00000000000080?[`iP030000003jl>H0n_3V0480
n_3V00<0odD00?[`iP3jl>H0L03jl>H00`3oA@00n_3V0?[`iP040?[`iP030?m5003jl>H0n_3V0740
n_3V00<0odD00?[`iP3jl>H0@P3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo00140?[`iP<00000
2@3jl>H00`000000n_3V0?[`iP120?[`iP030?m5003jl>H0n_3V06l0n_3V00<0odD00?[`iP3jl>H0
1P3jl>H00`3oA@00n_3V0?[`iP1`0?[`iP030?m5003jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0
:03jl>H10?ooo`00D03jl>H00`000000n_3V0?[`iP120?[`iP030?m5003jl>H0n_3V06h0n_3V00<0
odD00?[`iP3jl>H0203jl>H00`3oA@00n_3V0?[`iP1_0?[`iP030?m5003jl>H0n_3V0480n_3V00<0
00000?[`iP3jl>H0:03jl>H10?ooo`00D03jl>H300000480n_3V00<0odD00?[`iP3jl>H0K@3jl>H0
0`3oA@00n_3V0?[`iP0:0?[`iP030?m5003jl>H0n_3V06h0n_3V00<0odD00?[`iP3jl>H0@03jl>H3
000002X0n_3V0@3oool00500n_3V00<000000?[`iP3jl>H0@P3jl>H00`3oA@00n_3V0?[`iP1/0?[`
iP030?m5003jl>H0n_3V00`0n_3V00<0odD00000o`3jl>H0K@3jl>H00`3oA@00n_3V0?[`iP120?[`
iP030000003jl>H0n_3V02P0n_3V0@3oool00500n_3V00<000000?[`iP3jl>H0@P3jl>H00`3oA@00
n_3V0?[`iP1[0?[`iP030?m5003jl>H0n_3V00h0n_3V00<0odD00000o`3jl>H0K03jl>H00`3oA@00
n_3V0?[`iP0i0?[`iP030000o`3jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00
D03jl>H00`000000n_3V0?[`iP120?[`iP030?m5003jl>H0n_3V06X0n_3V00<0odD00?[`iP3jl>H0
403jl>H00`3oA@00003o0?[`iP1[0?[`iP030?m5003jl>H0n_3V03P0n_3V00<0003o0?[`iP3jl>H0
1`3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP030000003jl>H0n_3V0480n_3V00<0
odD00?[`iP3jl>H0J@3jl>H00`3oA@00n_3V0?[`iP0B0?[`iP030?m500000?l0n_3V06X0n_3V00<0
odD00?[`iP3jl>H0=`3jl>H00`000?l0n_3V0?[`iP080?[`iP030000003jl>H0n_3V02P0n_3V0@3o
ool00500n_3V00<000000?[`iP3jl>H0@P3jl>H00`3oA@00n_3V0?[`iP1X0?[`iP030?m5003jl>H0
n_3V01@0n_3V00<0odD00000o`3jl>H0J03jl>H00`3oA@00n_3V0?[`iP0g0?[`iP030000o`3jl>H0
n_3V00T0n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00D03jl>H300000480n_3V00<0odD00?[`
iP3jl>H0I`3jl>H00`3oA@00n_3V0?[`iP0F0?[`iP030?m500000?l0n_3V06L0n_3V00<0odD00?[`
iP3jl>H0=P3jl>H00`000?l0n_3V0?[`iP080?[`iP<00000:P3jl>H10?ooo`00D03jl>H00`000000
n_3V0?[`iP130?[`iP030?m5003jl>H0n_3V06D0n_3V00<0odD00?[`iP3jl>H0603jl>H00`3oA@00
003o0?[`iP1V0?[`iP030?m5003jl>H0n_3V03D0n_3V00<0003o0?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP030000003jl>H0n_3V04<0n_3V00<0odD00?[`iP3jl>H0
I03jl>H00`3oA@00n_3V0?[`iP0J0?[`iP030?m500000?l0n_3V06D0n_3V00<0odD00?[`iP3jl>H0
=03jl>H00`000?l0n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V02P0n_3V0@3oool00500n_3V00<0
00000?[`iP3jl>H0@`3jl>H00`3oA@00n_3V0?[`iP1S0?[`iP030?m5003jl>H0n_3V01`0n_3V0P3o
A@1U0?[`iP030?m5003jl>H0n_3V03<0n_3V00<0003o0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`
iP0X0?[`iP40oooo001@0?[`iP030000003jl>H0n_3V04<0n_3V00<0odD00?[`iP3jl>H0HP3jl>H0
0`3oA@00n_3V0?[`iP0O0?[`iP030?m5003jl>H0n_3V0680n_3V00<0odD00?[`iP3jl>H0<@3jl>H2
0000oa00n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00D03jl>H00`000000n_3V0?[`iP130?[`
iP030?m5003jl>H0n_3V0640n_3V00<0odD00?[`iP3jl>H08@3jl>H00`3oA@00n_3V0?[`iP1Q0?[`
iP030?m5003jl>H0n_3V0300n_3V00<0003o0?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0X0?[`
iP40oooo001@0?[`iP<00000@`3jl>H00`3oA@00n_3V0?[`iP1P0?[`iP030?m5003jl>H0n_3V02<0
n_3V00<0odD00?[`iP3jl>H0H03jl>H00`3oA@00n_3V0?[`iP0_0?[`iP030000o`3jl>H0n_3V00l0
n_3V0`00000Z0?[`iP40oooo001@0?[`iP030000003jl>H0n_3V04<0n_3V00<0odD00?[`iP3jl>H0
G`3jl>H00`3oA@00n_3V0?[`iP0U0?[`iP030?m5003jl>H0n_3V05l0n_3V00<0odD00?[`iP3jl>H0
;P3jl>H00`000?l0n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V02P0n_3V0@3oool00500n_3V00<0
00000?[`iP3jl>H0A03jl>H00`3oA@00n_3V0?[`iP1M0?[`iP030?m5003jl>H0n_3V02L0n_3V00<0
odD00?[`iP3jl>H0G@3jl>H00`3oA@00n_3V0?[`iP0^0?[`iP030000o`3jl>H0n_3V01<0n_3V00<0
00000?[`iP3jl>H0:03jl>H10?ooo`00D03jl>H00`000000n_3V0?[`iP140?[`iP030?m5003jl>H0
n_3V05`0n_3V00<0odD00?[`iP3jl>H0:@3jl>H00`3oA@00n_3V0?[`iP1L0?[`iP030?m5003jl>H0
n_3V02d0n_3V00<0003o0?[`iP3jl>H0503jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`
iP030000003jl>H0n_3V04@0n_3V00<0odD00?[`iP3jl>H0F`3jl>H00`3oA@00n_3V0?[`iP0[0?[`
iP030?m5003jl>H0n_3V05/0n_3V00<0odD00?[`iP3jl>H0;03jl>H00`000?l0n_3V0?[`iP0E0?[`
iP030000003jl>H0n_3V02P0n_3V0@3oool00500n_3V00<000000?[`iP3jl>H0A@3jl>H00`3oA@00
n_3V0?[`iP1I0?[`iP030?m5003jl>H0n_3V02d0n_3V00<0odD00?[`iP3jl>H0FP3jl>H00`3oA@00
n_3V0?[`iP0[0?[`iP030000o`3jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00
D03jl>H3000004D0n_3V00<0odD00?[`iP3jl>H0F03jl>H00`3oA@00n_3V0?[`iP0_0?[`iP030?m5
003jl>H0n_3V05T0n_3V00<0odD00?[`iP3jl>H0:P3jl>H00`000?l0n_3V0?[`iP0E0?[`iP<00000
:P3jl>H10?ooo`00D03jl>H00`000000n_3V0?[`iP150?[`iP030?m5003jl>H0n_3V05L0n_3V00<0
odD00?[`iP3jl>H0<@3jl>H00`3oA@00n_3V0?[`iP1G0?[`iP030?m5003jl>H0n_3V02X0n_3V00<0
003o0?[`iP3jl>H0603jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP030000003jl>H0
n_3V04D0n_3V00<0odD00?[`iP3jl>H0EP3jl>H00`3oA@00n_3V0?[`iP0c0?[`iP030?m5003jl>H0
n_3V05H0n_3V00<0odD00?[`iP3jl>H0:03jl>H20000oa/0n_3V00<000000?[`iP3jl>H0:03jl>H1
0?ooo`00=P3jl>H3000000@0n_3V0P0000050?[`iP<000002@3jl>H00`000000n_3V0?[`iP150?[`
iP030?m5003jl>H0n_3V05D0n_3V00<0odD00?[`iP3jl>H0=@3jl>H00`3oA@00n_3V0?[`iP1E0?[`
iP030?m5003jl>H0n_3V02L0n_3V00<0003o0?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP0X0?[`
iP40oooo000e0?[`iP80000000<0n_3V0000000000000`3jl>H2000000@0n_3V00<000000?[`iP3j
l>H00P0000080?[`iP030000003jl>H0n_3V04D0n_3V00<0odD00?[`iP3jl>H0E03jl>H00`3oA@00
n_3V0?[`iP0g0?[`iP030?m5003jl>H0n_3V05@0n_3V00<0odD00?[`iP3jl>H09P3jl>H00`000?l0
n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V02P0n_3V0@3oool003D0n_3V0P0000000`3jl>H00000
0000000<0?[`iP800000203jl>H4000004D0n_3V00<0odD00?[`iP3jl>H0DP3jl>H00`3oA@00n_3V
0?[`iP0i0?[`iP030?m5003jl>H0n_3V0580n_3V00<0odD00?[`iP3jl>H09P3jl>H00`000?l0n_3V
0?[`iP0J0?[`iP@00000:P3jl>H10?ooo`00=@3jl>H2000000030?[`iP000000000000`0n_3V0P00
00080?[`iP030000003jl>H0n_3V04H0n_3V00<0odD00?[`iP3jl>H0D@3jl>H00`3oA@00n_3V0?[`
iP0k0?[`iP030?m5003jl>H0n_3V0540n_3V00<0odD00?[`iP3jl>H09@3jl>H00`000?l0n_3V0?[`
iP0N0?[`iP030000003jl>H0n_3V02P0n_3V0@3oool003D0n_3V0P0000000`3jl>H0000000000009
0?[`iP030000003jl>H0n_3V00800000203jl>H00`000000n_3V0?[`iP170?[`iP030?m5003jl>H0
n_3V04l0n_3V00<0odD00?[`iP3jl>H0?@3jl>H20?m50540n_3V00<0odD00?[`iP3jl>H0903jl>H0
0`000?l0n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V02P0n_3V0@3oool003D0n_3V0P0000000`3j
l>H00000000000090?[`iP@000002@3jl>H00`000000n_3V0?[`iP170?[`iP030?m5003jl>H0n_3V
04d0n_3V0P3oA@120?[`iP030?m5003jl>H0n_3V04h0n_3V00<0odD00?[`iP3jl>H08P3jl>H20000
ob80n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00=@3jl>H2000000030?[`iP000000000000T0
n_3V0P00000;0?[`iP030000003jl>H0n_3V04P0n_3V00<0odD00?[`iP3jl>H0B`3jl>H00`3oA@00
n_3V0?[`iP130?[`iP030?m5003jl>H0n_3V04`0n_3V00<0odD00?[`iP3jl>H08P3jl>H00`000?l0
n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V02P0n_3V0@3oool003H0n_3V0`00000:0?[`iPD00000
203jl>H00`000000n_3V0?[`iP180?[`iP030?m5003jl>H0n_3V04X0n_3V00<0odD00?[`iP3jl>H0
A@3jl>H00`3oA@00003o0?[`iP1;0?[`iP030?m5003jl>H0n_3V0240n_3V00<0003o0?[`iP3jl>H0
8`3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP<00000B03jl>H00`3oA@00n_3V0?[`
iP190?[`iP030?m5003jl>H0n_3V04L0n_3V0P3oA@1;0?[`iP030?m5003jl>H0n_3V0200n_3V00<0
003o0?[`iP3jl>H08P3jl>H3000002X0n_3V0@3oool00500n_3V00<000000?[`iP3jl>H0B@3jl>H0
0`3oA@00n_3V0?[`iP170?[`iP030?m5003jl>H0n_3V04X0n_3V00<0odD00?[`iP3jl>H0A`3jl>H0
0`3oA@00n_3V0?[`iP0O0?[`iP80003o9`3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`
iP030000003jl>H0n_3V04T0n_3V00<0odD00?[`iP3jl>H0AP3jl>H00`3oA@00n_3V0?[`iP1<0?[`
iP030?m500000?l0n_3V04H0n_3V00<0odD00?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP0W0?[`
iP030000003jl>H0n_3V02P0n_3V0@3oool00500n_3V00<000000?[`iP3jl>H0B@3jl>H00`3oA@00
n_3V0?[`iP150?[`iP030?m5003jl>H0n_3V04h0n_3V00<0odD00000o`3jl>H0A03jl>H00`3oA@00
n_3V0?[`iP0N0?[`iP030000o`3jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00
D03jl>H00`000000n_3V0?[`iP1:0?[`iP030?m5003jl>H0n_3V0480n_3V0P3oA@1B0?[`iP80odD0
A03jl>H00`3oA@00n_3V0?[`iP0L0?[`iP80003o:`3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo
001@0?[`iP030000003jl>H0n_3V04X0n_3V00<0odD00?[`iP3jl>H0@@3jl>H00`3oA@00n_3V0?[`
iP1D0?[`iP030?m500000?l0n_3V0400n_3V00<0odD00?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`
iP0[0?[`iP030000003jl>H0n_3V02P0n_3V0@3oool00500n_3V0`00001:0?[`iP030?m5003jl>H0
n_3V0400n_3V00<0odD00?[`iP3jl>H0EP3jl>H00`3oA@00003o0?[`iP0o0?[`iP030?m5003jl>H0
n_3V01/0n_3V00<0003o0?[`iP3jl>H0:P3jl>H3000002X0n_3V0@3oool00500n_3V00<000000?[`
iP3jl>H0B`3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030?m5003jl>H0n_3V05P0n_3V00<0odD00000
o`000?l0?@3jl>H00`3oA@00n_3V0?[`iP0J0?[`iP80003o;`3jl>H00`000000n_3V0?[`iP0X0?[`
iP40oooo001@0?[`iP030000003jl>H0n_3V04/0n_3V00<0odD00?[`iP3jl>H0?03jl>H20?m505`0
n_3V0P3oA@000`000?l0n_3V0?[`iP0i0?[`iP030?m5003jl>H0n_3V01X0n_3V00<0003o0?[`iP3j
l>H0;`3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP030000003jl>H0n_3V04`0n_3V
00<0odD00?[`iP3jl>H0>@3jl>H20?m50600n_3V00<0odD00000o`000?l0>@3jl>H00`3oA@00n_3V
0?[`iP0I0?[`iP030000o`3jl>H0n_3V0300n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00D03j
l>H00`000000n_3V0?[`iP1=0?[`iP030?m5003jl>H0n_3V03H0n_3V0P3oA@1S0?[`iP030?m5003j
l>H0003o03L0n_3V00<0odD00?[`iP3jl>H0603jl>H20000oc<0n_3V00<000000?[`iP3jl>H0:03j
l>H10?ooo`00D03jl>H00`000000n_3V0?[`iP1=0?[`iP030?m5003jl>H0n_3V03D0n_3V00<0odD0
0?[`iP3jl>H0I03jl>H20?m50080003o=@3jl>H00`3oA@00n_3V0?[`iP0G0?[`iP030000o`3jl>H0
n_3V03<0n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00D03jl>H3000004h0n_3V00<0odD00?[`
iP3jl>H0<P3jl>H20?m506T0n_3V00@0odD00?[`iP000?l0003o<P3jl>H00`3oA@00n_3V0?[`iP0F
0?[`iP80003o=03jl>H3000002X0n_3V0@3oool00500n_3V00<000000?[`iP3jl>H0C`3jl>H00`3o
A@00n_3V0?[`iP0`0?[`iP030?m5003jl>H0n_3V06X0n_3V0P3oA@000`3jl>H0003o0?[`iP0_0?[`
iP030?m5003jl>H0n_3V01D0n_3V0P000?lh0?[`iP030000003jl>H0n_3V02P0n_3V0@3oool00500
n_3V00<000000?[`iP3jl>H0D03jl>H00`3oA@00n_3V0?[`iP0^0?[`iP030?m5003jl>H0n_3V06d0
n_3V00@0odD00?[`iP000?l0003o;@3jl>H00`3oA@00n_3V0?[`iP0D0?[`iP80003o>P3jl>H00`00
0000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP030000003jl>H0n_3V0540n_3V00<0odD00?[`iP3j
l>H0:`3jl>H20?m50740n_3V0P3oA@000`3jl>H0003o0?[`iP0Z0?[`iP030?m5003jl>H0n_3V01@0
n_3V00<0003o0?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP0X0?[`iP40oooo001@0?[`iP030000
003jl>H0n_3V0580n_3V00<0odD00?[`iP3jl>H0:@3jl>H00`3oA@00n_3V0?[`iP1c0?[`iP80odD0
0P000?lX0?[`iP030?m5003jl>H0n_3V01<0n_3V0P000?lm0?[`iP030000003jl>H0n_3V02P0n_3V
0@3oool00500n_3V00<000000?[`iP3jl>H0D`3jl>H00`3oA@00n_3V0?[`iP0V0?[`iP80odD0N03j
l>H20?m50080003o9@3jl>H00`3oA@00n_3V0?[`iP0B0?[`iP80003o?`3jl>H00`000000n_3V0?[`
iP0X0?[`iP40oooo001@0?[`iP<00000E03jl>H00`3oA@00n_3V0?[`iP0S0?[`iP80odD0O03jl>H2
0?m50080003o8P3jl>H00`3oA@00n_3V0?[`iP0A0?[`iP80003o?`3jl>H3000002X0n_3V0@3oool0
0500n_3V00<000000?[`iP3jl>H0E@3jl>H00`3oA@00n_3V0?[`iP0P0?[`iP80odD0P03jl>H20?m5
0080003o7`3jl>H00`3oA@00n_3V0?[`iP0?0?[`iP<0003o@`3jl>H00`000000n_3V0?[`iP0X0?[`
iP40oooo001@0?[`iP030000003jl>H0n_3V05H0n_3V00<0odD00?[`iP3jl>H07@3jl>H20?m508@0
n_3V0P3oA@040000oaT0n_3V0P3oA@0@0?[`iP80003oAP3jl>H00`000000n_3V0?[`iP0X0?[`iP40
oooo001@0?[`iP030000003jl>H0n_3V05L0n_3V00<0odD00?[`iP3jl>H06P3jl>H20?m508P0n_3V
0P3oA@020?[`iP<0003o5@3jl>H00`3oA@00n_3V0?[`iP0=0?[`iP<0003oB03jl>H00`000000n_3V
0?[`iP0X0?[`iP40oooo00130?[`iPH000001`3jl>H00`000000n_3V0?[`iP1H0?[`iP<0odD05P3j
l>H30?m508`0n_3V0P3oA@030?[`iP80003o4@3jl>H20?m500d0n_3V0`000?m;0?[`iP030000003j
l>H0n_3V02P0n_3V0@3oool004D0n_3V0P0000090?[`iP030000003jl>H0n_3V05/0n_3V103oA@0?
0?[`iP<0odD0T@3jl>H50?m500H0003o1`3jl>H40?m500P0n_3V1`000?m>0?[`iP030000003jl>H0
n_3V02P0n_3V0@3oool004D0n_3V0P0000090?[`iP@00000GP3jl>H?0?m509T0n_3V3@3oA@0<0000
oe80n_3V1000000Z0?[`iP40oooo00150?[`iP8000002@3jl>H00`000000n_3V0?[`iP060?[`iP03
0000003jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP0i0?[`iP03
0000003jl>H0n_3V03T0n_3V00<000000?[`iP3jl>H0>03jl>H00`000000n_3V0?[`iP0i0?[`iP03
0000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00A@3jl>H2000000T0n_3V
00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V02P0n_3V
0@3oool004D0n_3V0P0000090?[`i_l00000NP00000Z0?[`iP40oooo00130?[`iP@00000o`3jl>J]
0?[`iP40oooo00150?[`iP800000o`3jl>J]0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00>T0n_3V100000030?[`iP80000000<0
n_3V0000000000000P3jl>H4000000`0n_3V0`0000040?[`iPX00000103jl>H3000000<0n_3V1000
00020?[`iPD00000aP3jl>H10?ooo`00jP3jl>H2000000@0n_3V0P000000103jl>H000000000003j
l>H200000080n_3V0P00000:0?[`iP8000000P3jl>H00`000000n_3V0?[`iP02000000030?[`iP00
000000000080n_3V0P0000060?[`iP<000000P3jl>H2000000<0n_3V00@000000?[`iP0000000000
0P3jl>H200000<D0n_3V0@3oool00>X0n_3V0P0000040?[`iP80000000@0n_3V000000000000n_3V
0P0000020?[`iP8000002@3jl>H2000000H0n_3V0P0000000`3jl>H00000000000020?[`iP800000
1P3jl>H00`000000n_3V000000020?[`iP8000001`3jl>H400000<D0n_3V0@3oool00>X0n_3V0P00
00030?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000002@3jl>H2000000H0n_3V0P00
00000`3jl>H00000000000020?[`iP8000001@3jl>H2000000040?[`iP00000000000?[`iPH00000
00<0n_3V0000000000000P0000370?[`iP40oooo003Z0?[`iP8000000`3jl>H2000000030?[`iP00
0000n_3V00@000000P3jl>H2000000T0n_3V0P0000060?[`iP80000000<0n_3V0000000000000P3j
l>H3000000040?[`iP000000n_3V0?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80
000000<0n_3V0000000000000P3jl>H200000<D0n_3V0@3oool00>P0n_3V00D000000?[`iP000000
00000?[`iP05000000030?[`iP000000000000H000002P3jl>H2000000<0n_3V00<000000?[`iP00
00000P000000103jl>H000000000003jl>H3000000040?[`iP00000000000?[`iP<0000000D0n_3V
00000000000000000?[`iP04000000<0n_3V1@0000350?[`iP40oooo003X0?[`iP060000003jl>H0
00000000003jl>H00000603jl>H200000080n_3V00<000000?[`iP3jl>H0iP3jl>H10?ooo`00j03j
l>H6000001T0n_3V1000003X0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {165.625, 0}} -> {-4.50718, -1.38997, \
0.0167844, 0.0167844}}]
}, Open  ]],

Cell["\<\
Here we add a legend using the ShowLegend statement. The code above was just \
incorporated as the first item and DontShow was used instead of Show to \
suppress the extra display. The advantage of this method is that the legend \
does not have to be in the frame. The legend coordinates are as described in \
the documentation. They are relative to the largest dimension of the \
graphics.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowLegend[\[IndentingNewLine]DontShow[
          Graphics[\[IndentingNewLine]{Blue, \[IndentingNewLine]Draw[
                Sin[x], {x, \(-3\), 
                  3}], \[IndentingNewLine]OrangeRed, \
\[IndentingNewLine]ParametricDraw[
                2 {Sin[t], Sin[t] Cos[t]}, {t, 0, 
                  2  \[Pi]}]}], \[IndentingNewLine]Background \[Rule] 
            Linen, \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]ImageSize \[Rule] 
            500, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]PlotLabel \[Rule] "\<Two Curves\>"], \
\[IndentingNewLine]\[IndentingNewLine]{{{Red, "\<Figure Eight\>"}, {Blue, \
"\<Sine Wave\>"}}, \[IndentingNewLine]LegendPosition \[Rule] {\(-0.8\), \
\(-0.6\)}, \[IndentingNewLine]LegendSize \[Rule] {0.7, 
              0.2}, \[IndentingNewLine]LegendTextOffset \[Rule] {\(-0.6\), 
              0}, \[IndentingNewLine]LegendSpacing \[Rule] 
            0.6}, \[IndentingNewLine]TextStyle \[Rule] {FontSize \[Rule] 12, 
            FontWeight \[Rule] "\<Bold\>"}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49167 
%%ImageSize: 500 245.833 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.47619 0.32123 0.47619 [
[ 0 0 0 0 ]
[ 1 .49167 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.1625 0.97619 0.47996 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.15873 0.166667 0.15873 [
[.02381 -0.0125 -9.5625 -15.5625 ]
[.02381 -0.0125 9.5625 0 ]
[.18254 -0.0125 -9.5625 -15.5625 ]
[.18254 -0.0125 9.5625 0 ]
[.34127 -0.0125 -9.5625 -15.5625 ]
[.34127 -0.0125 9.5625 0 ]
[.5 -0.0125 -5.59375 -15.5625 ]
[.5 -0.0125 5.59375 0 ]
[.65873 -0.0125 -5.59375 -15.5625 ]
[.65873 -0.0125 5.59375 0 ]
[.81746 -0.0125 -5.59375 -15.5625 ]
[.81746 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -15.5625 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -19.125 -7.78125 ]
[-0.0125 .00794 0 7.78125 ]
[-0.0125 .0873 -33.5 -7.78125 ]
[-0.0125 .0873 0 7.78125 ]
[-0.0125 .16667 -11.1875 -7.78125 ]
[-0.0125 .16667 0 7.78125 ]
[-0.0125 .24603 -25.5625 -7.78125 ]
[-0.0125 .24603 0 7.78125 ]
[-0.0125 .3254 -11.1875 -7.78125 ]
[-0.0125 .3254 0 7.78125 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[.5 .34583 -37.9375 0 ]
[.5 .34583 37.9375 15.5625 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
gsave
-0.0125 .00794 -80.125 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .0873 m
.00625 .0873 L
s
gsave
-0.0125 .0873 -94.5 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .16667 m
.00625 .16667 L
s
gsave
-0.0125 .16667 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .24603 m
.00625 .24603 L
s
gsave
-0.0125 .24603 -86.5625 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .3254 m
.00625 .3254 L
s
gsave
-0.0125 .3254 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .07143 m
.00375 .07143 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .13492 m
.00375 .13492 L
s
0 .15079 m
.00375 .15079 L
s
0 .18254 m
.00375 .18254 L
s
0 .19841 m
.00375 .19841 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .2619 m
.00375 .2619 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.18254 .32708 m
.18254 .33333 L
s
.34127 .32708 m
.34127 .33333 L
s
.5 .32708 m
.5 .33333 L
s
.65873 .32708 m
.65873 .33333 L
s
.81746 .32708 m
.81746 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.05556 .32958 m
.05556 .33333 L
s
.0873 .32958 m
.0873 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.15079 .32958 m
.15079 .33333 L
s
.21429 .32958 m
.21429 .33333 L
s
.24603 .32958 m
.24603 .33333 L
s
.27778 .32958 m
.27778 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.37302 .32958 m
.37302 .33333 L
s
.40476 .32958 m
.40476 .33333 L
s
.43651 .32958 m
.43651 .33333 L
s
.46825 .32958 m
.46825 .33333 L
s
.53175 .32958 m
.53175 .33333 L
s
.56349 .32958 m
.56349 .33333 L
s
.59524 .32958 m
.59524 .33333 L
s
.62698 .32958 m
.62698 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.72222 .32958 m
.72222 .33333 L
s
.75397 .32958 m
.75397 .33333 L
s
.78571 .32958 m
.78571 .33333 L
s
.84921 .32958 m
.84921 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.9127 .32958 m
.9127 .33333 L
s
.94444 .32958 m
.94444 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .07143 m
1 .07143 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .13492 m
1 .13492 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .19841 m
1 .19841 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
gsave
.5 .34583 -98.9375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Two) show
91.750 15.000 moveto
(Curves) show
134.875 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .14427 m
.06244 .10705 L
.10458 .07055 L
.14415 .04235 L
.16408 .03097 L
.18221 .02247 L
.20178 .01541 L
.21254 .01249 L
.21738 .01141 L
.22272 .01039 L
.22739 .00964 L
.23241 .00899 L
.23518 .00869 L
.23772 .00846 L
.2403 .00828 L
.24269 .00814 L
.24488 .00804 L
.2461 .008 L
.24721 .00797 L
.24843 .00795 L
.24975 .00794 L
.251 .00794 L
.25214 .00794 L
.25322 .00796 L
.25423 .00798 L
.25533 .008 L
.25651 .00804 L
.25893 .00815 L
.26113 .00828 L
.26594 .00867 L
.27104 .00924 L
.28022 .01068 L
.29008 .01281 L
.30098 .01584 L
.32032 .02298 L
.34118 .03305 L
.38232 .05947 L
.42194 .09172 L
.46005 .12714 L
.50061 .16728 L
.53966 .20591 L
.58116 .24433 L
.62114 .27638 L
.6596 .3007 L
.67948 .31027 L
.68962 .3143 L
.70052 .31795 L
.71075 .32073 L
.7201 .32271 L
.72459 .32347 L
Mistroke
.72949 .32416 L
.73412 .32467 L
.73841 .32502 L
.74106 .32518 L
.7435 .32529 L
.74478 .32533 L
.74618 .32537 L
.74689 .32538 L
.74764 .32539 L
.74836 .32539 L
.749 .3254 L
.75028 .32539 L
.75146 .32538 L
.75275 .32536 L
.75341 .32534 L
.75413 .32532 L
.75663 .32523 L
.75897 .3251 L
.76365 .32475 L
.76794 .32431 L
.77759 .32289 L
.78742 .32085 L
.79655 .31842 L
.81727 .31108 L
.83777 .30139 L
.85637 .29066 L
.8964 .262 L
.93492 .22871 L
.97589 .18936 L
.97619 .18907 L
Mfstroke
1 .271 0 r
.5 .16667 m
.58004 .24412 L
.61998 .27775 L
.6403 .29252 L
.66127 .30558 L
.6802 .31502 L
.69665 .32104 L
.70429 .32304 L
.70851 .3239 L
.71236 .32452 L
.71567 .32493 L
.71753 .3251 L
.71927 .32523 L
.72108 .32533 L
.72273 .32538 L
.72461 .3254 L
.72639 .32537 L
.72821 .32531 L
.72922 .32525 L
.73016 .32519 L
.73186 .32504 L
.73364 .32484 L
.7367 .3244 L
.74 .32376 L
.74346 .32291 L
.7471 .3218 L
.75345 .31928 L
.75955 .31612 L
.76507 .31254 L
.77472 .30433 L
.78429 .29318 L
.79319 .27909 L
.79973 .26543 L
.80579 .24882 L
.80839 .23985 L
.81079 .23006 L
.81416 .21187 L
.81553 .20141 L
.81648 .19154 L
.81688 .18581 L
.81715 .18059 L
.81727 .17769 L
.81732 .17616 L
.81736 .17454 L
.81739 .17312 L
.81742 .17156 L
.81745 .16882 L
.81746 .16611 L
.81745 .16359 L
.81741 .16084 L
Mistroke
.81737 .1593 L
.81734 .1579 L
.81726 .15534 L
.81715 .15258 L
.81688 .14758 L
.81655 .1427 L
.81611 .13757 L
.81512 .12847 L
.81363 .11808 L
.81191 .10859 L
.80684 .08797 L
.80049 .06973 L
.79315 .05416 L
.7855 .04182 L
.77607 .03036 L
.76579 .02132 L
.75949 .01718 L
.75328 .01397 L
.74999 .01258 L
.74645 .01132 L
.74333 .01039 L
.73994 .00956 L
.7362 .00885 L
.73451 .0086 L
.73266 .00837 L
.73152 .00826 L
.73046 .00817 L
.72946 .0081 L
.72836 .00803 L
.72644 .00796 L
.72538 .00794 L
.72439 .00794 L
.72252 .00796 L
.72157 .00799 L
.72051 .00803 L
.71864 .00815 L
.71687 .00829 L
.71283 .00875 L
.70841 .00946 L
.70014 .01131 L
.69235 .01364 L
.67697 .01975 L
.66008 .02843 L
.62317 .05315 L
.58691 .08307 L
.50633 .16034 L
.42035 .24377 L
.3791 .27846 L
.36166 .29118 L
.34304 .3031 L
Mistroke
.32695 .31175 L
.31034 .31876 L
.3015 .32158 L
.29363 .32348 L
.28992 .32417 L
.28594 .32474 L
.28413 .32495 L
.28223 .32512 L
.28044 .32525 L
.27883 .32533 L
.27703 .32538 L
.27536 .3254 L
.27355 .32537 L
.27162 .3253 L
.27065 .32524 L
.26961 .32517 L
.26773 .325 L
.26425 .32455 L
.26102 .32398 L
.25765 .32321 L
.25176 .3214 L
.24523 .31867 L
.23937 .31547 L
.23328 .31132 L
.22699 .30599 L
.21706 .29497 L
.20789 .28105 L
.20061 .26624 L
.19492 .25104 L
.19216 .24189 L
.18956 .2316 L
.1876 .22225 L
.18588 .2121 L
.18463 .20278 L
.18408 .19778 L
.18359 .19237 L
.18322 .18738 L
.18295 .1828 L
.18285 .1806 L
.18275 .17819 L
.18268 .17606 L
.18262 .17381 L
.18259 .17247 L
.18257 .17101 L
.18254 .16843 L
.18254 .16698 L
.18254 .16543 L
.18255 .16396 L
.18257 .16263 L
.18261 .16004 L
Mistroke
.18264 .15858 L
.18268 .15723 L
.18287 .15214 L
.18311 .14763 L
.18345 .14269 L
.18438 .13276 L
.18574 .12216 L
.18762 .11101 L
.19211 .09165 L
.19794 .07373 L
.20584 .05605 L
.21473 .0415 L
.22419 .0301 L
.2296 .02499 L
.2358 .02018 L
.24156 .01658 L
.24792 .01344 L
.25392 .0112 L
.25742 .01019 L
.26076 .00941 L
.26389 .00884 L
.26678 .00844 L
.2684 .00827 L
.27017 .00812 L
.27187 .00802 L
.27344 .00796 L
.27518 .00794 L
.27701 .00795 L
.2786 .008 L
.28034 .00808 L
.28224 .00821 L
.28428 .0084 L
.288 .00887 L
.29183 .0095 L
.29549 .01025 L
.30246 .01203 L
.31907 .018 L
.33795 .02732 L
.37501 .05177 L
.41659 .08619 L
.49493 .16159 L
.5 .16667 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.14286 .01171 m
.14286 .10694 L
.47619 .10694 L
.47619 .01171 L
F
1 g
.11905 .03552 m
.11905 .13075 L
.45238 .13075 L
.45238 .03552 L
F
0 g
.001 w
[ ] 0 setdash
.11905 .03552 m
.45238 .03552 L
.45238 .13075 L
.11905 .13075 L
.11905 .03552 L
s
% Start of sub-graphic
p
0.119048 0.0355159 0.452381 0.130754 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0227273 0.227273 0.00621118 0.0621118 [
[ 0 0 0 0 ]
[ 1 .28571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .28571 L
0 .28571 L
closepath
clip
newpath
0 0 1 r
.15909 .04348 m
.15909 .10559 L
.38636 .10559 L
.38636 .04348 L
F
0 g
gsave
.53409 .07453 -74.8125 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sine) show
99.313 15.000 moveto
(Wave) show
128.063 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.15909 .18012 m
.15909 .24224 L
.38636 .24224 L
.38636 .18012 L
F
0 g
gsave
.53409 .21118 -79.05 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Figure) show
113.313 15.000 moveto
(Eight) show
149.250 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .49167 L
0 .49167 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 245.813},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000mB000`400?l00000o`00003oo`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo00170?[`iZH0
0000o`3jl>H70?[`iP40oooo00170?[`iZH00000o`3jl>H70?[`iP40oooo00170?[`iZH00000o`3j
l>H70?[`iP40oooo00170?[`iZH00000o`3jl>H70?[`iP40oooo00170?[`iZH00000o`3jl>H70?[`
iP40oooo00170?[`iZH00000o`3jl>H70?[`iP40oooo00170?[`iZH00000o`3jl>H70?[`iP40oooo
00170?[`iZH00000o`3jl>H70?[`iP40oooo00170?[`iZH00000o`3jl>H70?[`iP40oooo00170?[`
iZH00000o`3jl>H70?[`iP40oooo000k0?[`i[800000o`3jl>H70?[`iP40oooo000k0?[`iP030000
003oool0oooo0:<0oooo3000003o0?[`iPL0n_3V0@3oool003/0n_3V00<000000?ooo`3oool0X`3o
ool<00000?l0n_3V1`3jl>H10?ooo`00>`3jl>H00`000000oooo0?ooo`2S0?ooo``00000o`3jl>H7
0?[`iP40oooo000k0?[`iP030000003oool0oooo0:<0oooo3000003o0?[`iPL0n_3V0@3oool003/0
n_3V00<000000?ooo`3oool0X`3oool<00000?l0n_3V1`3jl>H10?ooo`00>`3jl>H00`000000oooo
0?ooo`2S0?ooo``00000o`3jl>H70?[`iP40oooo000k0?[`iP030000003oool0oooo0:<0oooo3000
003o0?[`iPL0n_3V0@3oool003/0n_3V00<000000?ooo`3oool0X`3oool<00000?l0n_3V1`3jl>H1
0?ooo`00>`3jl>H00`000000oooo0?ooo`0H0?ooobD0003oIP3oool<00000?l0n_3V1`3jl>H10?oo
o`00>`3jl>H00`000000oooo0?ooo`0H0?ooobD0003oIP3oool<00000?l0n_3V1`3jl>H10?ooo`00
>`3jl>H00`000000oooo0?ooo`0H0?ooobD0003o3@3oool500000080oooo1P0000001@3oool00000
000000000000oooo00<0000000<0oooo0000000000000P00000;0?ooo`80000000<0oooo00000000
00000P3oool600000080oooo0`0000030?ooo`@000006`3oool<00000?l0n_3V1`3jl>H10?ooo`00
>`3jl>H00`000000oooo0?ooo`0H0?ooobD0003o3@3oool010000000oooo0?ooo`3oool2000000<0
oooo0P0000040?ooo`80000000@0oooo000000000000oooo0P0000030?ooo`030000003oool0oooo
00P0oooo0P000000103oool000000000003oool200000080oooo0P0000030?ooo`<000000P3oool2
000000<0oooo00<000000?ooo`3oool0603oool<00000?l0n_3V1`3jl>H10?ooo`00>`3jl>H00`00
0000oooo0?ooo`0H0?ooobD0003o4@3oool2000000<0oooo0P0000040?ooo`80000000@0oooo0000
00000000oooo0P00000>0?ooo`80000000@0oooo000000000000oooo0P0000020?ooo`8000000`3o
ool00`000000oooo000000020?ooo`8000007P3oool<00000?l0n_3V1`3jl>H10?ooo`00>`3jl>H0
0`000000oooo0?ooo`0H0?ooobD0003o3`3oool3000000@0oooo0P0000040?ooo`80000000@0oooo
000000000000oooo1P00000:0?ooo`80000000<0oooo0000000000000P3oool500000080oooo0P00
0000103oool000000000003oool6000001X0oooo3000003o0?[`iPL0n_3V0@3oool003/0n_3V00<0
00000?ooo`3oool0603ooolU0000o`h0oooo0`0000050?ooo`800000103oool2000000040?ooo`00
000000000?ooo`8000000P3oool2000000X0oooo00D000000?ooo`000000oooo000000050?ooo`80
00000P3oool2000000040?ooo`00000000000?ooo`8000000P3oool2000001X0oooo3000003o0?[`
iPL0n_3V0@3oool003/0n_3V00<000000?ooo`3oool0603ooolU0000o`d0oooo0P0000050?ooo`@0
00000`3oool5000000<0oooo1000000:0?ooo`80000000<0oooo0000003oool00P0000000`3oool0
00000000000200000080oooo0`0000001@3oool00000000000000000oooo00@000006`3oool<0000
0?l0n_3V1`3jl>H10?ooo`00>`3jl>H00`000000oooo0?ooo`0H0?ooobD0003o3@3oool2000000<0
oooo00<000000?ooo`3oool0703oool2000000<0oooo0P00000^0?ooo``00000o`3jl>H70?[`iP40
oooo000k0?[`iP030000003oool0oooo01P0oooo9@000?l>0?ooo`D000000`3oool2000001P0oooo
100000000`3oool0000000000002000002d0oooo3000003o0?[`iPL0n_3V0@3oool003/0n_3V00<0
00000?ooo`3oool0X`3oool<00000?l0n_3V1`3jl>H10?ooo`00>`3jl>H00`000000oooo0?ooo`2S
0?ooo``00000o`3jl>H70?[`iP40oooo000k0?[`iP030000003oool0oooo0:<0oooo3000003o0?[`
iPL0n_3V0@3oool003/0n_3V00<000000?ooo`3oool0X`3oool<00000?l0n_3V1`3jl>H10?ooo`00
>`3jl>H00`000000oooo0?ooo`2S0?ooo``00000o`3jl>H70?[`iP40oooo000k0?[`iP030000003o
ool0oooo0:<0oooo3000003o0?[`iPL0n_3V0@3oool003/0n_3V00<000000?ooo`3oool0X`3oool<
00000?l0n_3V1`3jl>H10?ooo`00>`3jl>H00`000000oooo0?ooo`2S0?ooo``00000o`3jl>H70?[`
iP40oooo000k0?[`iP030000003oool0oooo0:<0oooo3000003o0?[`iPL0n_3V0@3oool003/0n_3V
00<000000?ooo`3oool0X`3oool<00000?l0n_3V1`3jl>H10?ooo`00>`3jl>H00`000000oooo0?oo
o`2S0?ooo``00000o`3jl>H70?[`iP40oooo000k0?[`iP030000003oool0oooo0:<0oooo3000003o
0?[`iPL0n_3V0@3oool003/0n_3V00<000000?ooo`3oool0603ooolU0?l001P0oooo1000000^0?oo
o`@00000603oool<00000?l0n_3V1`3jl>H10?ooo`00>`3jl>H00`000000oooo0?ooo`0H0?ooobD0
o`006`3oool200000300oooo0P00000G0?ooo``00000o`3jl>H70?[`iP40oooo000k0?[`iP030000
003oool0oooo01P0oooo9@3o00080?ooo`D000000`3oool600000080oooo0P0000000`3oool00000
000000030?ooo`X000000`3oool4000000T0oooo1`0000000`3oool000000000000400000080oooo
0P000000103oool000000000003oool3000000040?ooo`000000000000000080oooo0`00000:0?oo
o``00000o`3jl>H70?[`iP40oooo000k0?[`iP030000003oool0oooo01P0oooo9@3o00090?ooo`80
00001`3oool2000000<0oooo0P000000103oool000000000000000020?ooo`80000000<0oooo0000
000000000P3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo00L0oooo0P0000030?oo
o`040000003oool0oooo0?ooo`8000000`3oool2000000040?ooo`000000000000000080oooo0P00
00000`3oool00000000000020?ooo`8000000P3oool00`000000oooo0?ooo`070?ooo``00000o`3j
l>H70?[`iP40oooo000k0?[`iP030000003oool0oooo01P0oooo9@3o00090?ooo`8000001`3oool2
000000<0oooo0P0000020?ooo`8000000P3oool2000000030?ooo`00000000000080oooo0P000004
0?ooo`8000003@3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`8000000P3o
ool200000080oooo0P0000000`3oool00000000000020?ooo`800000303oool<00000?l0n_3V1`3j
l>H10?ooo`00>`3jl>H00`000000oooo0?ooo`0H0?ooobD0o`002@3oool2000000030?ooo`000000
oooo00@0oooo0P0000030?ooo`8000000P3oool200000080oooo0P0000000`3oool0000000000002
0?ooo`800000103oool6000000T0oooo0P0000000`3oool000000?ooo`040?ooo`8000000`3oool2
00000080oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool2000000`0oooo3000003o
0?[`iPL0n_3V0@3oool003/0n_3V00<000000?ooo`3oool0603ooolU0?l000T0oooo100000050?oo
o`8000000`3oool2000000040?ooo`000000000000000080oooo0P0000000`3oool0000000000002
0?ooo`<0000000<0oooo0000003oool00P0000020?ooo`8000002@3oool4000000D0oooo0P000003
0?ooo`80000000@0oooo00000000000000000P3oool2000000030?ooo`00000000000080oooo0P00
000<0?ooo`030000003jl>H0n_3V0?l0n_3V403jl>H10?ooo`00>`3jl>H00`000000oooo0?ooo`0H
0?ooobD0o`002@3oool2000000050?ooo`000000oooo0000003oool0100000040?ooo`80000000<0
oooo00000000000010000000103oool000000000003oool3000000030?ooo`00000000000080oooo
1000000:0?ooo`80000000D0oooo0000003oool000000?ooo`04000000@0oooo0P0000001@3oool0
0000000000000000oooo00@000000P3oool5000000X0oooo00<000000?[`iP3jl>H0o`3jl>H@0?[`
iP40oooo000k0?[`iP030000003oool0oooo01P0oooo9@3o00090?ooo`8000000`3oool00`000000
oooo0?ooo`0Z0?ooo`8000000`3oool00`000000oooo0?ooo`0>0?ooo`8000001@3oool2000000`0
oooo00<000000?[`iP3jl>H0o`3jl>H@0?[`iP40oooo000k0?[`iP030000003oool0oooo01P0oooo
9@3o00080?ooo`L000000`3oool2000002H0oooo1`0000030?ooo`8000002P3oool3000000D0oooo
0P00000<0?ooo`030000003jl>H0n_3V0?l0n_3V403jl>H10?ooo`00>`3jl>H00`000000oooo0?oo
o`0H0?ooobD0o`00IP3oool00`000000n_3V0?[`iP3o0?[`iQ00n_3V0@3oool003/0n_3V00<00000
0?ooo`3oool0X`3oool00`000000n_3V0?[`iP3o0?[`iQ00n_3V0@3oool003/0n_3V00<000000?oo
o`3oool0X`3oool00`000000n_3V0?[`iP3o0?[`iQ00n_3V0@3oool003/0n_3V00<000000?ooo`3o
ool0X`3oool00`000000n_3V0?[`iP3o0?[`iQ00n_3V0@3oool003/0n_3V00<000000?ooo`3oool0
X`3oool00`000000n_3V0?[`iP3o0?[`iQ00n_3V0@3oool003/0n_3V00<000000?ooo`3oool0X`3o
ool00`000000n_3V0?[`iP3o0?[`iQ00n_3V0@3oool003/0n_3V00<000000?ooo`3oool0X`3oool0
0`000000n_3V0?[`iP3o0?[`iQ00n_3V0@3oool003/0n_3VY`00003o0?[`iQ80n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo001V0?[`iP<00000=03jl>H5000003<0
n_3V1P00000_0?[`iP<00000=@3jl>H600000380n_3V1@00000d0?[`iP<00000?@3jl>H10?ooo`00
I@3jl>H00`000000n_3V0?[`iP02000003<0n_3V0P00000h0?[`iP800000<03jl>H2000000030?[`
iP000000000003H0n_3V0P00000d0?[`iP800000=P3jl>H00`000000n_3V0?[`iP02000003`0n_3V
0@3oool005d0n_3V1@0000060?[`iP800000:`3jl>H5000000@0n_3V0P00000]0?[`iPD000001@3j
l>H200000300n_3V0P0000000`3jl>H000000000000f0?[`iP800000=@3jl>H2000003P0n_3V0P00
000l0?[`iP40oooo001X0?[`iP800000=@3jl>H2000003H0n_3V0P00000`0?[`iP80000000<0n_3V
000000000000=P3jl>H2000003H0n_3V0P00000g0?[`iP800000?03jl>H10?ooo`00IP3jl>H30000
03L0n_3V0P00000e0?[`iP800000<03jl>H2000000030?[`iP000000000003H0n_3V0P00000g0?[`
iP800000=03jl>H3000003d0n_3V0@3oool006P0n_3V0P00000c0?[`iP80000000<0n_3V00000000
0000=@3jl>H200000300n_3V0P0000000`3jl>H000000000000f0?[`iP800000=03jl>H200000003
0?[`iP000000000003H0n_3V0P00000l0?[`iP40oooo001U0?[`iP030000003jl>H0n_3V00800000
<`3jl>H2000000030?[`iP000000000003<0n_3V1000000`0?[`iP80000000<0n_3V000000000000
=03jl>H4000003@0n_3V0P0000000`3jl>H000000000000c0?[`iP030000003jl>H0n_3V00800000
?03jl>H10?ooo`00IP3jl>H3000003D0n_3V0`00000f0?[`iP800000<@3jl>H3000003L0n_3V0P00
000e0?[`iP<00000=@3jl>H3000003d0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00CP3jl>H6000000L0n_3Vo`00001T000003D0
n_3V0@3oool00500n_3V0P0000090?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0
203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0
203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0
203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0
2@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0
203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0
203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0
203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0
2@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0
203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0
203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0
1@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo00160?[`iPD000001@3jl>H2000000T0n_3V0`00
00050?[`iP030000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H04`3jl>H60000o`<0n_3V1@3o
A@0E0?[`iP030000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`
iP0C0?[`iP@0odD07P3jl>H00`000000n_3V0?[`iP0f0?[`iP030000003jl>H0n_3V00<0n_3V0`00
000e0?[`iP40oooo001@0?[`iP8000002@3jl>H00`000000n_3V0?[`iP1<0?[`iPL0003o1@3jl>H5
0?m500@0003o1P3oA@2@0?[`iPD0odD0103jl>H50?m505X0n_3V00<000000?[`iP3jl>H0<`3jl>H1
0?ooo`00D03jl>H2000000T0n_3V00<000000?[`iP3jl>H0A`3jl>H50000o`P0n_3V103oA@0:0?[`
iP@0003o00@0n_3V0?m5003oA@00odD0R03jl>H50?m500h0n_3V0P3oA@1H0?[`iP030000003jl>H0
n_3V03<0n_3V0@3oool00500n_3V0P0000090?[`iP030000003jl>H0n_3V04<0n_3V10000?l;0?[`
iP80odD04P3jl>H30000o`040?[`iP3oA@00odD00?m508<0n_3V0P3oA@0E0?[`iP80odD0EP3jl>H0
0`000000n_3V0?[`iP0c0?[`iP40oooo001>0?[`iP@000002@3jl>H00`000000n_3V0?[`iP110?[`
iP80003o3P3jl>H00`3oA@00n_3V0?[`iP0E0?[`iP80003o0P3jl>H20?m507l0n_3V0P3oA@0I0?[`
iP80odD0E03jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001@0?[`iP8000002@3jl>H00`000000
n_3V0?[`iP0o0?[`iP80003o3`3jl>H00`3oA@00n_3V0?[`iP0H0?[`iP80003o0P3jl>H20?m507`0
n_3V00<0odD00?[`iP3jl>H06`3jl>H20?m50580n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00
F`3jl>H2000003h0n_3V0P000?l?0?[`iP80odD07@3jl>H30000o`030?[`iP3oA@00odD007P0n_3V
0P3oA@0P0?[`iP030?m5003jl>H0n_3V04h0n_3V0P00000e0?[`iP40oooo001K0?[`iP030000003j
l>H0n_3V03/0n_3V0P000?l@0?[`iP030?m5003jl>H0n_3V0200n_3V0P000?l00`3jl>H0odD00?m5
001d0?[`iP80odD08`3jl>H20?m504l0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H0
0`000000n_3V0?[`iP0i0?[`iP80003o4@3jl>H00`3oA@00n_3V0?[`iP0S0?[`iP<0003o0P3oA@1`
0?[`iP80odD09`3jl>H00`3oA@00n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool0
05/0n_3V00<000000?[`iP3jl>H0=`3jl>H20000oa80n_3V00<0odD00?[`iP3jl>H09`3jl>H20000
o`030?m5003jl>H0n_3V06/0n_3V0P3oA@0Z0?[`iP030?m5003jl>H0n_3V04/0n_3V00<000000?[`
iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0e0?[`iP80003o4`3jl>H00`3oA@00
n_3V0?[`iP0Z0?[`iP030000o`3oA@00odD006T0n_3V0P3oA@0/0?[`iP030?m5003jl>H0n_3V04/0
n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0c0?[`iP80003o
5@3jl>H00`3oA@00n_3V0?[`iP0/0?[`iP030000o`3oA@00n_3V06H0n_3V00<0odD00?[`iP3jl>H0
;@3jl>H00`3oA@00n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V0P00
000b0?[`iP80003o5P3jl>H00`3oA@00n_3V0?[`iP0^0?[`iP030000o`3oA@00odD006<0n_3V0P3o
A@0a0?[`iP030?m5003jl>H0n_3V04P0n_3V0P00000e0?[`iP40oooo001K0?[`iP030000003jl>H0
n_3V0300n_3V00<0003o0?[`iP3jl>H05@3jl>H00`3oA@00n_3V0?[`iP0`0?[`iP80003o0P3oA@1P
0?[`iP030?m5003jl>H0n_3V0380n_3V00<0odD00?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP0c
0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V02h0n_3V0P000?lH0?[`iP030?m5003jl>H0n_3V
0380n_3V00<0003o0?[`iP3oA@00G@3jl>H20?m503D0n_3V00<0odD00?[`iP3jl>H0B03jl>H00`00
0000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V02d0n_3V00<0003o0?[`iP3j
l>H05`3jl>H00`3oA@00n_3V0?[`iP0d0?[`iP80003o0P3oA@1I0?[`iP80odD0>03jl>H00`3oA@00
n_3V0?[`iP170?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0
;03jl>H00`000?l0n_3V0?[`iP0H0?[`iP030?m5003jl>H0n_3V03H0n_3V00<0003o0?[`iP3oA@00
E`3jl>H00`3oA@00n_3V0?[`iP0h0?[`iP030?m5003jl>H0n_3V04L0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00F`3jl>H2000002/0n_3V0P000?lJ0?[`iP030?m5003jl>H0n_3V03P0n_3V00<0
003o0?[`iP3oA@00E@3jl>H00`3oA@00n_3V0?[`iP0j0?[`iP030?m5003jl>H0n_3V04D0n_3V0P00
000e0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V02T0n_3V00<0003o0?[`iP3jl>H06P3jl>H0
0`3oA@00n_3V0?[`iP0i0?[`iP80003o00<0odD00?[`iP3jl>H0D@3jl>H00`3oA@00n_3V0?[`iP0k
0?[`iP030?m5003jl>H0n_3V04H0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`00
0000n_3V0?[`iP0W0?[`iP80003o703jl>H00`3oA@00n_3V0?[`iP0l0?[`iP030000o`3oA@00odD0
04l0n_3V0P3oA@0o0?[`iP030?m5003jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0<`3jl>H10?oo
o`00F`3jl>H00`000000n_3V0?[`iP0V0?[`iP030000o`3jl>H0n_3V01`0n_3V00<0odD00?[`iP3j
l>H0?@3jl>H00`000?l0n_3V0?m5001=0?[`iP030?m5003jl>H0n_3V03l0n_3V00<0odD00?[`iP3j
l>H0A@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V02D0n_3V
00<0003o0?[`iP3jl>H0703jl>H00`3oA@00n_3V0?[`iP0o0?[`iP80003o00<0odD00?[`iP3jl>H0
B@3jl>H00`3oA@00n_3V0?[`iP110?[`iP030?m5003jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0S0?[`iP80003o7`3jl>H00`3oA@00n_3V0?[`
iP110?[`iP030000o`3oA@00n_3V04P0n_3V00<0odD00?[`iP3jl>H0@P3jl>H00`3oA@00n_3V0?[`
iP140?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V0P00000S0?[`iP030000o`3jl>H0
n_3V01h0n_3V00<0odD00?[`iP3jl>H0@`3jl>H00`000?l0odD00?[`iP160?[`iP030?m5003jl>H0
n_3V04<0n_3V00<0odD00?[`iP3jl>H0@`3jl>H2000003D0n_3V0@3oool005/0n_3V00<000000?[`
iP3jl>H08@3jl>H00`000?l0n_3V0?[`iP0O0?[`iP030?m5003jl>H0n_3V04@0n_3V00<0003o0?m5
003jl>H0@`3jl>H20?m504L0n_3V00<0odD00?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP0c0?[`
iP40oooo001K0?[`iP030000003jl>H0n_3V0200n_3V00<0003o0?[`iP3jl>H0803jl>H00`3oA@00
n_3V0?[`iP150?[`iP030000o`3oA@00odD00440n_3V00<0odD00?[`iP3jl>H0A`3jl>H00`3oA@00
n_3V0?[`iP130?[`iP030000003jl>H0n_3V03<0n_3V0@3oool00440n_3V0`0000040?[`iP800000
1@3jl>H3000000T0n_3V00<000000?[`iP3jl>H07P3jl>H20000ob80n_3V00<0odD00?[`iP3jl>H0
B03jl>H00`000?l0odD00?[`iP0n0?[`iP030?m5003jl>H0n_3V04T0n_3V00<0odD00?[`iP3jl>H0
@P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo00100?[`iP80000000<0n_3V0000000000000`3j
l>H2000000@0n_3V00<000000?[`iP3jl>H00P0000080?[`iP030000003jl>H0n_3V01d0n_3V00<0
003o0?[`iP3jl>H08P3jl>H00`3oA@00n_3V0?[`iP190?[`iP030000o`3oA@00n_3V03`0n_3V00<0
odD00?[`iP3jl>H0BP3jl>H00`3oA@00n_3V0?[`iP120?[`iP030000003jl>H0n_3V03<0n_3V0@3o
ool003P0n_3V1@0000030?[`iP80000000<0n_3V000000000000303jl>H2000000P0n_3V00<00000
0?[`iP3jl>H0703jl>H00`000?l0n_3V0?[`iP0S0?[`iP030?m5003jl>H0n_3V04X0n_3V00<0003o
0?m5003jl>H0>P3jl>H00`3oA@00n_3V0?[`iP1<0?[`iP030?m5003jl>H0n_3V0440n_3V00<00000
0?[`iP3jl>H0<`3jl>H10?ooo`00@03jl>H2000000030?[`iP000000000000`0n_3V0P0000080?[`
iP<000006`3jl>H00`000?l0n_3V0?[`iP0S0?[`iP030?m5003jl>H0n_3V04d0n_3V00<0odD00?[`
iP3jl>H0=`3jl>H00`3oA@00n_3V0?[`iP1=0?[`iP030?m5003jl>H0n_3V03l0n_3V0`00000e0?[`
iP40oooo00100?[`iP80000000<0n_3V0000000000002@3jl>H00`000000n_3V0?[`iP02000000P0
n_3V00<000000?[`iP3jl>H06P3jl>H00`000?l0n_3V0?[`iP0T0?[`iP030?m5003jl>H0n_3V04h0
n_3V00<0odD00?[`iP3jl>H0=@3jl>H00`3oA@00n_3V0?[`iP1>0?[`iP030?m5003jl>H0n_3V0440
n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00@03jl>H2000000030?[`iP000000000000T0n_3V
100000090?[`iP030000003jl>H0n_3V01T0n_3V00<0003o0?[`iP3jl>H09@3jl>H00`3oA@00n_3V
0?[`iP1?0?[`iP030?m5003jl>H0n_3V03<0n_3V00<0odD00?[`iP3jl>H0C`3jl>H00`3oA@00n_3V
0?[`iP110?[`iP030000003jl>H0n_3V03<0n_3V0@3oool00400n_3V0P0000000`3jl>H000000000
00090?[`iP8000002`3jl>H00`000000n_3V0?[`iP0H0?[`iP030000o`3jl>H0n_3V02D0n_3V00<0
odD00?[`iP3jl>H0D@3jl>H00`3oA@00n_3V0?[`iP0a0?[`iP030?m5003jl>H0n_3V0500n_3V00<0
odD00?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo00110?[`iP<000002P3jl>H5
000000P0n_3V00<000000?[`iP3jl>H05P3jl>H20000obP0n_3V00<0odD00?[`iP3jl>H0DP3jl>H0
0`3oA@00n_3V0?[`iP0_0?[`iP030?m5003jl>H0n_3V0580n_3V00<0odD00?[`iP3jl>H0@03jl>H0
0`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP8000005P3jl>H00`000?l0n_3V0?[`iP0X0?[`
iP030?m5003jl>H0n_3V05<0n_3V00<0odD00?[`iP3jl>H0;03jl>H20?m505D0n_3V00<0odD00?[`
iP3jl>H0?`3jl>H2000003D0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0503jl>H00`000?l0
n_3V0?[`iP0Y0?[`iP030?m5003jl>H0n_3V05@0n_3V00<0odD00?[`iP3jl>H0:P3jl>H00`3oA@00
n_3V0?[`iP1E0?[`iP030?m5003jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00
F`3jl>H00`000000n_3V0?[`iP0C0?[`iP030000o`3jl>H0n_3V02T0n_3V00<0odD00?[`iP3jl>H0
EP3jl>H00`3oA@00n_3V0?[`iP0X0?[`iP030?m5003jl>H0n_3V05H0n_3V00<0odD00?[`iP3jl>H0
@03jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V0180n_3V00<0
003o0?[`iP3jl>H0:P3jl>H00`3oA@00n_3V0?[`iP1G0?[`iP030?m500000?l0n_3V02H0n_3V00<0
odD00?[`iP3jl>H0E`3jl>H00`3oA@00n_3V0?[`iP100?[`iP030000003jl>H0n_3V03<0n_3V0@3o
ool005/0n_3V00<000000?[`iP3jl>H04@3jl>H00`000?l0n_3V0?[`iP0[0?[`iP030?m5003jl>H0
n_3V05P0n_3V00<0odD00000o`3jl>H0903jl>H00`3oA@00n_3V0?[`iP1I0?[`iP030?m5003jl>H0
n_3V03l0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0@0?[`
iP030000o`3jl>H0n_3V02`0n_3V00<0odD00?[`iP3jl>H0F@3jl>H00`3oA@00003o0?[`iP0R0?[`
iP030?m5003jl>H0n_3V05X0n_3V00<0odD00?[`iP3jl>H0?`3jl>H00`000000n_3V0?[`iP0c0?[`
iP40oooo001K0?[`iP800000403jl>H00`000?l0n_3V0?[`iP0]0?[`iP030?m5003jl>H0n_3V05X0
n_3V00<0odD00000o`3jl>H0803jl>H00`3oA@00n_3V0?[`iP1K0?[`iP030?m5003jl>H0n_3V03h0
n_3V0P00000e0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V00h0n_3V00<0003o0?[`iP3jl>H0
;P3jl>H00`3oA@00n_3V0?[`iP1K0?[`iP030?m500000?l0n_3V01h0n_3V00<0odD00?[`iP3jl>H0
G03jl>H00`3oA@00n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<0
00000?[`iP3jl>H03@3jl>H00`000?l0n_3V0?[`iP0_0?[`iP030?m5003jl>H0n_3V05`0n_3V0P3o
A@0M0?[`iP030?m5003jl>H0n_3V05h0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`
iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V00/0n_3V0P000?la0?[`iP030?m5003jl>H0
n_3V05l0n_3V00<0odD00?[`iP3jl>H06@3jl>H00`3oA@00n_3V0?[`iP1O0?[`iP030?m5003jl>H0
n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0:0?[`
iP030000o`3jl>H0n_3V0340n_3V00<0odD00?[`iP3jl>H0H03jl>H00`3oA@00n_3V0?[`iP0G0?[`
iP030?m5003jl>H0n_3V0600n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`
iP40oooo001K0?[`iP8000002P3jl>H00`000?l0n_3V0?[`iP0b0?[`iP030?m5003jl>H0n_3V0640
n_3V00<0odD00?[`iP3jl>H05@3jl>H00`3oA@00n_3V0?[`iP1Q0?[`iP030?m5003jl>H0n_3V03d0
n_3V0P00000e0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V00P0n_3V00<0003o0?[`iP3jl>H0
<`3jl>H00`3oA@00n_3V0?[`iP1R0?[`iP030?m5003jl>H0n_3V01<0n_3V00<0odD00?[`iP3jl>H0
HP3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP0d0?[`iP030?m5003jl>H0n_3V06<0n_3V00<0
odD00?[`iP3jl>H0403jl>H20?m506D0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`
iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V00H0n_3V00<0003o0?[`iP3jl>H0=@3jl>H0
0`3oA@00n_3V0?[`iP1T0?[`iP030?m5003jl>H0n_3V00h0n_3V00<0odD00?[`iP3jl>H0I@3jl>H0
0`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`
iP3jl>H01@3jl>H00`000?l0n_3V0?[`iP0f0?[`iP030?m5003jl>H0n_3V06D0n_3V00<0odD00?[`
iP3jl>H0303jl>H00`3oA@00n_3V0?[`iP1V0?[`iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`
iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0n0?[`iP030?m5003jl>H0n_3V06H0
n_3V00<0odD00?[`iP3jl>H02P3jl>H00`3oA@00n_3V0?[`iP1W0?[`iP030?m5003jl>H0n_3V03h0
n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H2000003l0n_3V00<0odD00?[`iP3jl>H0
I`3jl>H00`3oA@00n_3V0?[`iP080?[`iP030?m5003jl>H0n_3V06P0n_3V00<0odD00?[`iP3jl>H0
?@3jl>H2000003D0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?P3jl>H00`3oA@00n_3V0?[`
iP1X0?[`iP030?m5003jl>H0n_3V00H0n_3V00<0odD00?[`iP3jl>H0J@3jl>H00`3oA@00n_3V0?[`
iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?@3jl>H0
0`3oA@00n_3V0?[`iP1Z0?[`iP030?m5003jl>H0n_3V00@0n_3V00<0odD00?[`iP3jl>H0JP3jl>H0
0`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool004l0n_3V0`0000090?[`
iP030000003jl>H0n_3V03d0n_3V00<0odD00?[`iP3jl>H0J`3jl>H00`3oA@00n_3V0?[`iP020?[`
iP030?m5003jl>H0n_3V06/0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`
iP40oooo001>0?[`iP80000000<0n_3V000000000000203jl>H00`000000n_3V0?[`iP0m0?[`iP03
0?m5003jl>H0n_3V06`0n_3V00@0odD00?[`iP3jl>H0odD0KP3jl>H00`3oA@00n_3V0?[`iP0n0?[`
iP030000003jl>H0n_3V03<0n_3V0@3oool004h0n_3V0P0000000`3jl>H00000000000080?[`iP03
0000003jl>H0n_3V03d0n_3V00<0odD00?[`iP3jl>H0K@3jl>H20?m506l0n_3V00<0odD00?[`iP3j
l>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001>0?[`iP80000000<0n_3V000000000000
203jl>H3000003d0n_3V00<0odD00?[`iP3jl>H0K@3jl>H20?m506l0n_3V00<0odD00?[`iP3jl>H0
?03jl>H3000003D0n_3V0@3oool004h0n_3V0P0000000`3jl>H00000000000080?[`iP030000003j
l>H0n_3V03d0n_3V00<0odD00?[`iP3jl>H0K03jl>H0103oA@00n_3V0?[`iP3oA@1^0?[`iP030?m5
003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00CP3jl>H2000000030?[`iP00
0000000000P0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3oA@00n_3V0?[`iP1[0?[`iP030?m5003j
l>H0n_3V0080n_3V00<0odD00?[`iP3jl>H0J`3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003j
l>H0n_3V03<0n_3V0@3oool004h0n_3V0P0000000`3jl>H00000000000080?[`iP030000003jl>H0
n_3V03d0n_3V00<0odD00?[`iP3jl>H0JP3jl>H00`3oA@00n_3V0?[`iP040?[`iP030?m5003jl>H0
n_3V06X0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001?0?[`
iP<000002@3jl>H00`000000n_3V0?[`iP0m0?[`iP030?m5003jl>H0n_3V06T0n_3V00<0odD00?[`
iP3jl>H01P3jl>H00`3oA@00n_3V0?[`iP1Y0?[`iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`
iP3jl>H0<`3jl>H10?ooo`00F`3jl>H2000003l0n_3V00<0odD00?[`iP3jl>H0I`3jl>H00`3oA@00
n_3V0?[`iP080?[`iP030?m5003jl>H0n_3V06P0n_3V00<0odD00?[`iP3jl>H0?@3jl>H2000003D0
n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?P3jl>H00`3oA@00n_3V0?[`iP1V0?[`iP030?m5
003jl>H0n_3V00X0n_3V00<0odD00?[`iP3jl>H0I`3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000
003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?P3jl>H00`3oA@00n_3V0?[`
iP1U0?[`iP030?m5003jl>H0n_3V00`0n_3V00<0odD00?[`iP3jl>H0IP3jl>H00`3oA@00n_3V0?[`
iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?P3jl>H0
0`3oA@00n_3V0?[`iP1T0?[`iP030?m5003jl>H0n_3V00h0n_3V00<0odD00?[`iP3jl>H0I@3jl>H0
0`3oA@00n_3V0?[`iP0e0?[`iP80003o1`3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`
iP030000003jl>H0n_3V03h0n_3V00<0odD00?[`iP3jl>H0H`3jl>H00`3oA@00n_3V0?[`iP0@0?[`
iP030?m5003jl>H0n_3V06@0n_3V00<0odD00?[`iP3jl>H0=03jl>H00`000?l0n_3V0?[`iP070?[`
iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?P3jl>H00`3oA@00
n_3V0?[`iP1R0?[`iP030?m5003jl>H0n_3V0180n_3V00<0odD00?[`iP3jl>H0H`3jl>H00`3oA@00
n_3V0?[`iP0c0?[`iP030000o`3jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00
F`3jl>H2000003l0n_3V00<0odD00?[`iP3jl>H0H@3jl>H00`3oA@00n_3V0?[`iP0D0?[`iP030?m5
003jl>H0n_3V0680n_3V00<0odD00?[`iP3jl>H0<P3jl>H00`000?l0n_3V0?[`iP080?[`iP800000
=@3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0n0?[`iP030?m5003jl>H0n_3V0600n_3V00<0
odD00?[`iP3jl>H05P3jl>H00`3oA@00n_3V0?[`iP1Q0?[`iP030?m5003jl>H0n_3V0340n_3V00<0
003o0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0
n_3V03h0n_3V00<0odD00?[`iP3jl>H0G`3jl>H00`3oA@00n_3V0?[`iP0H0?[`iP030?m5003jl>H0
n_3V0600n_3V00<0odD00?[`iP3jl>H0<03jl>H00`000?l0n_3V0?[`iP0;0?[`iP030000003jl>H0
n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?P3jl>H00`3oA@00n_3V0?[`iP1N0?[`
iP030?m5003jl>H0n_3V01X0n_3V0P3oA@1O0?[`iP030?m5003jl>H0n_3V0300n_3V00<0003o0?[`
iP3jl>H0303jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V03l0
n_3V00<0odD00?[`iP3jl>H0G03jl>H00`3oA@00n_3V0?[`iP0L0?[`iP030000o`3oA@00n_3V05d0
n_3V00<0odD00?[`iP3jl>H0;`3jl>H00`000?l0n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V03<0
n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3oA@00n_3V0?[`iP1K0?[`iP030?m5
003jl>H0n_3V01h0n_3V00<0003o0?m5003jl>H0G03jl>H00`3oA@00n_3V0?[`iP0^0?[`iP030000
o`3jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H200000400n_3V00<0
odD00?[`iP3jl>H0FP3jl>H00`3oA@00n_3V0?[`iP0P0?[`iP030000o`3oA@00n_3V05/0n_3V00<0
odD00?[`iP3jl>H0;@3jl>H00`000?l0n_3V0?[`iP0>0?[`iP800000=@3jl>H10?ooo`00F`3jl>H0
0`000000n_3V0?[`iP0o0?[`iP030?m5003jl>H0n_3V05T0n_3V00<0odD00?[`iP3jl>H08`3jl>H0
0`3oA@00n_3V0?[`iP1I0?[`iP030?m5003jl>H0n_3V02`0n_3V00<0003o0?[`iP3jl>H0403jl>H0
0`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V03l0n_3V00<0odD00?[`
iP3jl>H0F03jl>H00`3oA@00n_3V0?[`iP0U0?[`iP030?m5003jl>H0n_3V05L0n_3V00<0odD00?[`
iP3jl>H0;03jl>H00`000?l0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0
n_3V00<000000?[`iP3jl>H0?`3jl>H00`3oA@00n_3V0?[`iP1G0?[`iP030?m5003jl>H0n_3V02L0
n_3V00<0odD00?[`iP3jl>H0EP3jl>H00`3oA@00n_3V0?[`iP0[0?[`iP030000o`3jl>H0n_3V0180
n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0o0?[`iP030?m5
003jl>H0n_3V05H0n_3V00<0odD00?[`iP3jl>H0:@3jl>H00`3oA@00n_3V0?[`iP1E0?[`iP030?m5
003jl>H0n_3V02X0n_3V00<0003o0?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo
001K0?[`iP800000@@3jl>H00`3oA@00n_3V0?[`iP1D0?[`iP030?m5003jl>H0n_3V02/0n_3V00<0
odD00?[`iP3jl>H0E03jl>H00`3oA@00n_3V0?[`iP0Y0?[`iP030000o`3jl>H0n_3V01<0n_3V0P00
000e0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V0400n_3V00<0odD00?[`iP3jl>H0D`3jl>H0
0`3oA@00n_3V0?[`iP0]0?[`iP030?m5003jl>H0n_3V05<0n_3V00<0odD00?[`iP3jl>H0:03jl>H0
0`000?l0n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`
iP3jl>H0@03jl>H00`3oA@00n_3V0?[`iP1B0?[`iP030?m5003jl>H0n_3V02l0n_3V00<0odD00000
o`3jl>H0D@3jl>H00`3oA@00n_3V0?[`iP0W0?[`iP80003o603jl>H00`000000n_3V0?[`iP0c0?[`
iP40oooo001K0?[`iP030000003jl>H0n_3V0440n_3V00<0odD00?[`iP3jl>H0D03jl>H00`3oA@00
n_3V0?[`iP0a0?[`iP030?m500000?l0n_3V0500n_3V00<0odD00?[`iP3jl>H09P3jl>H00`000?l0
n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool00440n_3V0`0000040?[`iP800000
1@3jl>H3000000T0n_3V00<000000?[`iP3jl>H0@@3jl>H00`3oA@00n_3V0?[`iP1?0?[`iP030?m5
003jl>H0n_3V03<0n_3V00<0odD00000o`3jl>H0C`3jl>H00`3oA@00n_3V0?[`iP0U0?[`iP030000
o`3jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00@03jl>H2000000030?[`iP00
0000000000<0n_3V0P0000040?[`iP030000003jl>H0n_3V00800000203jl>H00`000000n_3V0?[`
iP110?[`iP030?m5003jl>H0n_3V04h0n_3V00<0odD00?[`iP3jl>H0=@3jl>H00`3oA@00003o0?[`
iP1>0?[`iP030?m5003jl>H0n_3V02@0n_3V00<0003o0?[`iP3jl>H06P3jl>H00`000000n_3V0?[`
iP0c0?[`iP40oooo00100?[`iP80000000<0n_3V000000000000303jl>H2000000P0n_3V0`000011
0?[`iP030?m5003jl>H0n_3V04d0n_3V00<0odD00?[`iP3jl>H0=`3jl>H00`3oA@00003o0?[`iP1<
0?[`iP030?m5003jl>H0n_3V02<0n_3V0P000?lK0?[`iP<00000=@3jl>H10?ooo`00@03jl>H20000
00030?[`iP000000000000`0n_3V0P0000080?[`iP030000003jl>H0n_3V0480n_3V00<0odD00?[`
iP3jl>H0BP3jl>H20?m503/0n_3V00<0odD00000o`3jl>H0B`3jl>H00`3oA@00n_3V0?[`iP0R0?[`
iP030000o`3jl>H0n_3V01d0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00@03jl>H200000003
0?[`iP000000000000T0n_3V00<000000?[`iP3jl>H00P0000080?[`iP030000003jl>H0n_3V0480
n_3V00<0odD00?[`iP3jl>H0B@3jl>H00`3oA@00n_3V0?[`iP0l0?[`iP80odD000<0003o0?[`iP3j
l>H0B03jl>H00`3oA@00n_3V0?[`iP0Q0?[`iP030000o`3jl>H0n_3V01h0n_3V00<000000?[`iP3j
l>H0<`3jl>H10?ooo`00@03jl>H2000000030?[`iP000000000000T0n_3V100000090?[`iP030000
003jl>H0n_3V0480n_3V00<0odD00?[`iP3jl>H0B03jl>H00`3oA@00n_3V0?[`iP0o0?[`iP030?m5
00000?l0n_3V04L0n_3V00<0odD00?[`iP3jl>H0803jl>H20000ob40n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00@03jl>H2000000030?[`iP000000000000T0n_3V0P00000;0?[`iP030000003j
l>H0n_3V04<0n_3V00<0odD00?[`iP3jl>H0AP3jl>H00`3oA@00n_3V0?[`iP110?[`iP030?m50000
0?l0n_3V04H0n_3V00<0odD00?[`iP3jl>H07`3jl>H00`000?l0n_3V0?[`iP0Q0?[`iP030000003j
l>H0n_3V03<0n_3V0@3oool00440n_3V0`00000:0?[`iPD00000203jl>H2000004@0n_3V00<0odD0
0?[`iP3jl>H0A03jl>H20?m504D0n_3V00<0odD00000o`3jl>H0A@3jl>H00`3oA@00n_3V0?[`iP0N
0?[`iP030000o`3jl>H0n_3V0240n_3V0P00000e0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V
04@0n_3V00<0odD00?[`iP3jl>H0@P3jl>H00`3oA@00n_3V0?[`iP160?[`iP030?m500000?l0n_3V
04<0n_3V00<0odD00?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP0S0?[`iP030000003jl>H0n_3V
03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0A03jl>H00`3oA@00n_3V0?[`iP110?[`iP03
0?m5003jl>H0n_3V04P0n_3V00<0odD00000o`3jl>H0@P3jl>H00`3oA@00n_3V0?[`iP0L0?[`iP80
003o9P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04@0n_3V
00<0odD00?[`iP3jl>H0@03jl>H00`3oA@00n_3V0?[`iP1:0?[`iP80odD000<0003o0?[`iP3jl>H0
?P3jl>H00`3oA@00n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP150?[`iP030?m5003jl>H0n_3V03d0n_3V0P3o
A@1?0?[`iP030?m500000?l0n_3V03h0n_3V00<0odD00?[`iP3jl>H06`3jl>H00`000?l0n_3V0?[`
iP0W0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0A@3jl>H0
0`3oA@00n_3V0?[`iP0l0?[`iP030?m5003jl>H0n_3V0500n_3V00<0odD00000o`3jl>H0?03jl>H0
0`3oA@00n_3V0?[`iP0K0?[`iP030000o`3jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H0<`3jl>H1
0?ooo`00F`3jl>H2000004L0n_3V00<0odD00?[`iP3jl>H0>P3jl>H00`3oA@00n_3V0?[`iP1B0?[`
iP030?m500000?l0n_3V03/0n_3V00<0odD00?[`iP3jl>H06@3jl>H20000obX0n_3V0P00000e0?[`
iP40oooo001K0?[`iP030000003jl>H0n_3V04H0n_3V00<0odD00?[`iP3jl>H0>@3jl>H00`3oA@00
n_3V0?[`iP1D0?[`iP80odD000<0003o0?[`iP3jl>H0=`3jl>H00`3oA@00n_3V0?[`iP0I0?[`iP03
0000o`3jl>H0n_3V02/0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V
0?[`iP170?[`iP030?m5003jl>H0n_3V03L0n_3V00<0odD00?[`iP3jl>H0E`3jl>H00`3oA@00003o
0000o`0g0?[`iP030?m5003jl>H0n_3V01P0n_3V00<0003o0?[`iP3jl>H0;03jl>H00`000000n_3V
0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04P0n_3V00<0odD00?[`iP3jl>H0=03j
l>H20?m505/0n_3V0P3oA@000`000?l0n_3V0?[`iP0c0?[`iP030?m5003jl>H0n_3V01L0n_3V0P00
0?l_0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0B03jl>H0
0`3oA@00n_3V0?[`iP0c0?[`iP030?m5003jl>H0n_3V05d0n_3V0P3oA@000`000?l0n_3V0?[`iP0a
0?[`iP030?m5003jl>H0n_3V01H0n_3V00<0003o0?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0c
0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04T0n_3V00<0odD00?[`iP3jl>H0<@3jl>H00`3o
A@00n_3V0?[`iP1P0?[`iP030?m500000?l0n_3V0300n_3V00<0odD00?[`iP3jl>H05P3jl>H00`00
0?l0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V0P00001;0?[`iP03
0?m5003jl>H0n_3V02h0n_3V0P3oA@1T0?[`iP80odD000<0003o0?[`iP3jl>H0;03jl>H00`3oA@00
n_3V0?[`iP0E0?[`iP80003o<P3jl>H2000003D0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0
B`3jl>H00`3oA@00n_3V0?[`iP0[0?[`iP80odD0J03jl>H00`3oA@00003o0000o`0[0?[`iP030?m5
003jl>H0n_3V01@0n_3V0P000?le0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<0
00000?[`iP3jl>H0B`3jl>H00`3oA@00n_3V0?[`iP0Y0?[`iP80odD0J`3jl>H00`3oA@00n_3V0000
o`0Y0?[`iP030?m5003jl>H0n_3V01<0n_3V0P000?lg0?[`iP030000003jl>H0n_3V03<0n_3V0@3o
ool005/0n_3V00<000000?[`iP3jl>H0C03jl>H00`3oA@00n_3V0?[`iP0W0?[`iP030?m5003jl>H0
n_3V06`0n_3V0P3oA@020000obH0n_3V00<0odD00?[`iP3jl>H04P3jl>H20000ocT0n_3V00<00000
0?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP1=0?[`iP030?m5003jl>H0n_3V
02@0n_3V0P3oA@1a0?[`iP80odD00P000?lS0?[`iP030?m5003jl>H0n_3V0140n_3V0P000?lk0?[`
iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V0P00001?0?[`iP030?m5003jl>H0n_3V0240
n_3V0P3oA@1e0?[`iP80odD00P000?lP0?[`iP030?m5003jl>H0n_3V0100n_3V0P000?ll0?[`iP80
0000=@3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP1?0?[`iP80odD0803jl>H00`3oA@00n_3V
0?[`iP1g0?[`iP80odD00P000?lM0?[`iP030?m5003jl>H0n_3V00h0n_3V0`000?lo0?[`iP030000
003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0D@3jl>H20?m501`0n_3V0P3o
A@1l0?[`iP<0odD00`000?lH0?[`iP030?m5003jl>H0n_3V00/0n_3V10000?m20?[`iP030000003j
l>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0D`3jl>H00`3oA@00n_3V0?[`iP0G
0?[`iP80odD0P@3jl>H30?m500@0003o4`3jl>H00`3oA@00n_3V0?[`iP090?[`iP<0003oAP3jl>H0
0`000000n_3V0?[`iP0c0?[`iP40oooo001>0?[`iPH000001`3jl>H00`000000n_3V0?[`iP1D0?[`
iP<0odD04`3jl>H30?m508H0n_3V0P3oA@020?[`iP@0003o303jl>H30?m500T0n_3V0`000?m90?[`
iP030000003jl>H0n_3V03<0n_3V0@3oool00500n_3V0P0000090?[`iP030000003jl>H0n_3V05L0
n_3V0`3oA@090?[`iPL0odD0R`3jl>H40?m50080n_3V1@000?l30?[`iP@0odD01P3jl>H60000od`0
n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00D03jl>H2000000T0n_3V0`0000050?[`iP030000
003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H06P3jl>H90?m501<0n_3V00<000000?[`iP3jl>H0
=@3jl>H00`000000n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V0100n_3V2P3oA@0:0000oa40n_3V
00<000000?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP030?[`iP<00000=@3jl>H10?ooo`00D03j
l>H2000000T0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP080?[`iP030000003j
l>H0n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003j
l>H0n_3V00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP030000003j
l>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003j
l>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003j
l>H0n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003j
l>H0n_3V00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP030000003j
l>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003j
l>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003j
l>H0n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003j
l>H0n_3V00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP050?[`iP030000003j
l>H0n_3V03<0n_3V0@3oool00500n_3V0P0000090?[`iP030000003jl>H0n_3V00D0n_3V00<00000
0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V00<00000
0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<00000
0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<00000
0?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<00000
0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V00<00000
0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<00000
0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<00000
0?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<00000
0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V00<00000
0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<00000
0?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001@0?[`iP8000002@3jl>Ko0000
06@00000=@3jl>H10?ooo`00CP3jl>H400000?l0n_3VXP3jl>H10?ooo`00D03jl>H200000?l0n_3V
XP3jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003Y0?[`iP@000000`3jl>H2000000030?[`iP00000000000080n_3V1000000<0?[`
iP<00000103jl>H:000000@0n_3V0`0000030?[`iP@000000P3jl>H500000<H0n_3V0@3oool00>X0
n_3V0P0000040?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000002P3jl>H20000
0080n_3V00<000000?[`iP3jl>H00P0000000`3jl>H00000000000020?[`iP8000001P3jl>H30000
0080n_3V0P0000030?[`iP040000003jl>H0000000000080n_3V0P0000350?[`iP40oooo003Z0?[`
iP800000103jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000T0n_3V0P000006
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000H0n_3V00<000000?[`iP0000000P3jl>H2
000000L0n_3V100000350?[`iP40oooo003Z0?[`iP8000000`3jl>H2000000030?[`iP000000n_3V
00@000000P3jl>H2000000T0n_3V0P0000060?[`iP80000000<0n_3V0000000000000P3jl>H20000
00D0n_3V0P000000103jl>H000000000003jl>H6000000030?[`iP000000000000800000a`3jl>H1
0?ooo`00jP3jl>H2000000<0n_3V0P0000000`3jl>H000000?[`iP0400000080n_3V0P0000090?[`
iP8000001P3jl>H2000000030?[`iP00000000000080n_3V0`000000103jl>H000000?[`iP3jl>H2
000000040?[`iP00000000000?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P00
00350?[`iP40oooo003X0?[`iP050000003jl>H000000000003jl>H01@0000000`3jl>H000000000
0006000000X0n_3V0P0000030?[`iP030000003jl>H000000080000000@0n_3V000000000000n_3V
0`000000103jl>H000000000003jl>H3000000050?[`iP00000000000000003jl>H0100000030?[`
iPD00000a@3jl>H10?ooo`00j03jl>H01P000000n_3V000000000000n_3V000001P0n_3V0P000002
0?[`iP030000003jl>H0n_3V0>H0n_3V0@3oool00>P0n_3V1P00000I0?[`iP@00000j03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {244.813, 0}} -> {-1.05229, -0.674589, \
0.00421759, 0.00421759}, {{12.375, 486.563}, {163.875, 5.8125}} -> {-4.7728, \
-2.84496, 0.0177844, 0.0177844}, {{59.8125, 225.75}, {227.125, 179.688}} -> \
{-1.68602, -1.81749, 0.0265162, 0.0970255}}]
}, Open  ]],

Cell["The following draws lines instead of the normal boxy keys.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowLegend[\[IndentingNewLine]DontShow[
          Graphics[\[IndentingNewLine]{Blue, \[IndentingNewLine]Draw[
                Sin[x], {x, \(-3\), 
                  3}], \[IndentingNewLine]OrangeRed, \
\[IndentingNewLine]ParametricDraw[
                2 {Sin[t], Sin[t] Cos[t]}, {t, 0, 
                  2  \[Pi]}]}], \[IndentingNewLine]Background \[Rule] 
            Linen, \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]ImageSize \[Rule] 
            500, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]PlotLabel \[Rule] "\<Two Curves\>"], \
\[IndentingNewLine]\[IndentingNewLine]{{{Graphics[{Red, 
                  Line[{{0, 0}, {1, 
                        0}}]}], "\<Figure Eight\>"}, {Graphics[{Blue, 
                  Line[{{0, 0}, {1, 
                        0}}]}], "\<Sine Wave\>"}}, \
\[IndentingNewLine]LegendPosition \[Rule] {\(-0.8\), \(-0.6\)}, \
\[IndentingNewLine]LegendSize \[Rule] {0.7, 
              0.2}, \[IndentingNewLine]LegendTextOffset \[Rule] {\(-1\), 
              0}, \[IndentingNewLine]LegendBackground \[Rule] 
            AliceBlue, \[IndentingNewLine]LegendShadow \[Rule] {0.02, \(-0.02\
\)}, \[IndentingNewLine]ShadowBackground \[Rule] 
            RoyalBlue}, \[IndentingNewLine]TextStyle \[Rule] {FontSize \
\[Rule] 12, FontWeight \[Rule] "\<Bold\>"}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47667 
%%ImageSize: 500 238.333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.47619 0.306587 0.47619 [
[ 0 0 0 0 ]
[ 1 .47667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.147857 0.97619 0.465317 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.15873 0.166667 0.15873 [
[.02381 -0.0125 -9.5625 -15.5625 ]
[.02381 -0.0125 9.5625 0 ]
[.18254 -0.0125 -9.5625 -15.5625 ]
[.18254 -0.0125 9.5625 0 ]
[.34127 -0.0125 -9.5625 -15.5625 ]
[.34127 -0.0125 9.5625 0 ]
[.5 -0.0125 -5.59375 -15.5625 ]
[.5 -0.0125 5.59375 0 ]
[.65873 -0.0125 -5.59375 -15.5625 ]
[.65873 -0.0125 5.59375 0 ]
[.81746 -0.0125 -5.59375 -15.5625 ]
[.81746 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -15.5625 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -19.125 -7.78125 ]
[-0.0125 .00794 0 7.78125 ]
[-0.0125 .0873 -33.5 -7.78125 ]
[-0.0125 .0873 0 7.78125 ]
[-0.0125 .16667 -11.1875 -7.78125 ]
[-0.0125 .16667 0 7.78125 ]
[-0.0125 .24603 -25.5625 -7.78125 ]
[-0.0125 .24603 0 7.78125 ]
[-0.0125 .3254 -11.1875 -7.78125 ]
[-0.0125 .3254 0 7.78125 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[.5 .34583 -37.9375 0 ]
[.5 .34583 37.9375 15.5625 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
gsave
-0.0125 .00794 -80.125 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .0873 m
.00625 .0873 L
s
gsave
-0.0125 .0873 -94.5 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .16667 m
.00625 .16667 L
s
gsave
-0.0125 .16667 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .24603 m
.00625 .24603 L
s
gsave
-0.0125 .24603 -86.5625 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .3254 m
.00625 .3254 L
s
gsave
-0.0125 .3254 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .07143 m
.00375 .07143 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .13492 m
.00375 .13492 L
s
0 .15079 m
.00375 .15079 L
s
0 .18254 m
.00375 .18254 L
s
0 .19841 m
.00375 .19841 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .2619 m
.00375 .2619 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.18254 .32708 m
.18254 .33333 L
s
.34127 .32708 m
.34127 .33333 L
s
.5 .32708 m
.5 .33333 L
s
.65873 .32708 m
.65873 .33333 L
s
.81746 .32708 m
.81746 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.05556 .32958 m
.05556 .33333 L
s
.0873 .32958 m
.0873 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.15079 .32958 m
.15079 .33333 L
s
.21429 .32958 m
.21429 .33333 L
s
.24603 .32958 m
.24603 .33333 L
s
.27778 .32958 m
.27778 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.37302 .32958 m
.37302 .33333 L
s
.40476 .32958 m
.40476 .33333 L
s
.43651 .32958 m
.43651 .33333 L
s
.46825 .32958 m
.46825 .33333 L
s
.53175 .32958 m
.53175 .33333 L
s
.56349 .32958 m
.56349 .33333 L
s
.59524 .32958 m
.59524 .33333 L
s
.62698 .32958 m
.62698 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.72222 .32958 m
.72222 .33333 L
s
.75397 .32958 m
.75397 .33333 L
s
.78571 .32958 m
.78571 .33333 L
s
.84921 .32958 m
.84921 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.9127 .32958 m
.9127 .33333 L
s
.94444 .32958 m
.94444 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .07143 m
1 .07143 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .13492 m
1 .13492 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .19841 m
1 .19841 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
gsave
.5 .34583 -98.9375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Two) show
91.750 15.000 moveto
(Curves) show
134.875 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .14427 m
.06244 .10705 L
.10458 .07055 L
.14415 .04235 L
.16408 .03097 L
.18221 .02247 L
.20178 .01541 L
.21254 .01249 L
.21738 .01141 L
.22272 .01039 L
.22739 .00964 L
.23241 .00899 L
.23518 .00869 L
.23772 .00846 L
.2403 .00828 L
.24269 .00814 L
.24488 .00804 L
.2461 .008 L
.24721 .00797 L
.24843 .00795 L
.24975 .00794 L
.251 .00794 L
.25214 .00794 L
.25322 .00796 L
.25423 .00798 L
.25533 .008 L
.25651 .00804 L
.25893 .00815 L
.26113 .00828 L
.26594 .00867 L
.27104 .00924 L
.28022 .01068 L
.29008 .01281 L
.30098 .01584 L
.32032 .02298 L
.34118 .03305 L
.38232 .05947 L
.42194 .09172 L
.46005 .12714 L
.50061 .16728 L
.53966 .20591 L
.58116 .24433 L
.62114 .27638 L
.6596 .3007 L
.67948 .31027 L
.68962 .3143 L
.70052 .31795 L
.71075 .32073 L
.7201 .32271 L
.72459 .32347 L
Mistroke
.72949 .32416 L
.73412 .32467 L
.73841 .32502 L
.74106 .32518 L
.7435 .32529 L
.74478 .32533 L
.74618 .32537 L
.74689 .32538 L
.74764 .32539 L
.74836 .32539 L
.749 .3254 L
.75028 .32539 L
.75146 .32538 L
.75275 .32536 L
.75341 .32534 L
.75413 .32532 L
.75663 .32523 L
.75897 .3251 L
.76365 .32475 L
.76794 .32431 L
.77759 .32289 L
.78742 .32085 L
.79655 .31842 L
.81727 .31108 L
.83777 .30139 L
.85637 .29066 L
.8964 .262 L
.93492 .22871 L
.97589 .18936 L
.97619 .18907 L
Mfstroke
1 .271 0 r
.5 .16667 m
.58004 .24412 L
.61998 .27775 L
.6403 .29252 L
.66127 .30558 L
.6802 .31502 L
.69665 .32104 L
.70429 .32304 L
.70851 .3239 L
.71236 .32452 L
.71567 .32493 L
.71753 .3251 L
.71927 .32523 L
.72108 .32533 L
.72273 .32538 L
.72461 .3254 L
.72639 .32537 L
.72821 .32531 L
.72922 .32525 L
.73016 .32519 L
.73186 .32504 L
.73364 .32484 L
.7367 .3244 L
.74 .32376 L
.74346 .32291 L
.7471 .3218 L
.75345 .31928 L
.75955 .31612 L
.76507 .31254 L
.77472 .30433 L
.78429 .29318 L
.79319 .27909 L
.79973 .26543 L
.80579 .24882 L
.80839 .23985 L
.81079 .23006 L
.81416 .21187 L
.81553 .20141 L
.81648 .19154 L
.81688 .18581 L
.81715 .18059 L
.81727 .17769 L
.81732 .17616 L
.81736 .17454 L
.81739 .17312 L
.81742 .17156 L
.81745 .16882 L
.81746 .16611 L
.81745 .16359 L
.81741 .16084 L
Mistroke
.81737 .1593 L
.81734 .1579 L
.81726 .15534 L
.81715 .15258 L
.81688 .14758 L
.81655 .1427 L
.81611 .13757 L
.81512 .12847 L
.81363 .11808 L
.81191 .10859 L
.80684 .08797 L
.80049 .06973 L
.79315 .05416 L
.7855 .04182 L
.77607 .03036 L
.76579 .02132 L
.75949 .01718 L
.75328 .01397 L
.74999 .01258 L
.74645 .01132 L
.74333 .01039 L
.73994 .00956 L
.7362 .00885 L
.73451 .0086 L
.73266 .00837 L
.73152 .00826 L
.73046 .00817 L
.72946 .0081 L
.72836 .00803 L
.72644 .00796 L
.72538 .00794 L
.72439 .00794 L
.72252 .00796 L
.72157 .00799 L
.72051 .00803 L
.71864 .00815 L
.71687 .00829 L
.71283 .00875 L
.70841 .00946 L
.70014 .01131 L
.69235 .01364 L
.67697 .01975 L
.66008 .02843 L
.62317 .05315 L
.58691 .08307 L
.50633 .16034 L
.42035 .24377 L
.3791 .27846 L
.36166 .29118 L
.34304 .3031 L
Mistroke
.32695 .31175 L
.31034 .31876 L
.3015 .32158 L
.29363 .32348 L
.28992 .32417 L
.28594 .32474 L
.28413 .32495 L
.28223 .32512 L
.28044 .32525 L
.27883 .32533 L
.27703 .32538 L
.27536 .3254 L
.27355 .32537 L
.27162 .3253 L
.27065 .32524 L
.26961 .32517 L
.26773 .325 L
.26425 .32455 L
.26102 .32398 L
.25765 .32321 L
.25176 .3214 L
.24523 .31867 L
.23937 .31547 L
.23328 .31132 L
.22699 .30599 L
.21706 .29497 L
.20789 .28105 L
.20061 .26624 L
.19492 .25104 L
.19216 .24189 L
.18956 .2316 L
.1876 .22225 L
.18588 .2121 L
.18463 .20278 L
.18408 .19778 L
.18359 .19237 L
.18322 .18738 L
.18295 .1828 L
.18285 .1806 L
.18275 .17819 L
.18268 .17606 L
.18262 .17381 L
.18259 .17247 L
.18257 .17101 L
.18254 .16843 L
.18254 .16698 L
.18254 .16543 L
.18255 .16396 L
.18257 .16263 L
.18261 .16004 L
Mistroke
.18264 .15858 L
.18268 .15723 L
.18287 .15214 L
.18311 .14763 L
.18345 .14269 L
.18438 .13276 L
.18574 .12216 L
.18762 .11101 L
.19211 .09165 L
.19794 .07373 L
.20584 .05605 L
.21473 .0415 L
.22419 .0301 L
.2296 .02499 L
.2358 .02018 L
.24156 .01658 L
.24792 .01344 L
.25392 .0112 L
.25742 .01019 L
.26076 .00941 L
.26389 .00884 L
.26678 .00844 L
.2684 .00827 L
.27017 .00812 L
.27187 .00802 L
.27344 .00796 L
.27518 .00794 L
.27701 .00795 L
.2786 .008 L
.28034 .00808 L
.28224 .00821 L
.28428 .0084 L
.288 .00887 L
.29183 .0095 L
.29549 .01025 L
.30246 .01203 L
.31907 .018 L
.33795 .02732 L
.37501 .05177 L
.41659 .08619 L
.49493 .16159 L
.5 .16667 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
.255 .412 .882 r
.12857 .01135 m
.12857 .10659 L
.4619 .10659 L
.4619 .01135 L
F
.941 .973 1 r
.11905 .02087 m
.11905 .11611 L
.45238 .11611 L
.45238 .02087 L
F
0 g
.001 w
[ ] 0 setdash
.11905 .02087 m
.45238 .02087 L
.45238 .11611 L
.11905 .11611 L
.11905 .02087 L
s
% Start of sub-graphic
p
0.119048 0.020873 0.452381 0.116111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0113379 0.113379 [
[ 0 0 0 0 ]
[ 1 .28571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .28571 L
0 .28571 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0204082 0.35119 0.133787 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .0771 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sine) show
99.313 15.000 moveto
(Wave) show
128.063 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.151927 0.35119 0.265306 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20862 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Figure) show
113.313 15.000 moveto
(Eight) show
149.250 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .47667 L
0 .47667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 238.313},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000kR000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00@03jl>JV045YhOl0
n_3V3P3jl>H10?ooo`00@03jl>JV045YhOl0n_3V3P3jl>H10?ooo`00@03jl>JV045YhOl0n_3V3P3j
l>H10?ooo`00@03jl>JV045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>JW000000@0@FWQo`3jl>H>0?[`
iP40oooo000k0?[`iP030000003`nOl0l?Wo0:<0l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0
n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000@FWQ045Yh@02045YhOl0n_3V
3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`0300000011JN40@FWQ0080@FWQo`3j
l>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0:<0l?Wo00<00000045Yh@11JN400P11JN7o
0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000@FWQ045Yh@02045Y
hOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`0300000011JN40@FWQ0080
@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0:<0l?Wo00<00000045Yh@11JN40
0P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000@FWQ045Y
h@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`0300000011JN40
@FWQ0080@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0400l?Wo1@0000020?3i
o`H0000000D0l?Wo00000000000000000?3io`03000000030?3io`0000000000008000002`3`nOl2
000000030?3io`00000000000080l?Wo1P0000020?3io`<000000`3`nOl4000002D0l?Wo00<00000
045Yh@11JN400P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0@03`nOl01000
0000l?Wo0?3io`3`nOl2000000<0l?Wo0P0000040?3io`80000000@0l?Wo000000000000l?Wo0P00
00030?3io`030000003`nOl0l?Wo00P0l?Wo0P000000103`nOl000000000003`nOl200000080l?Wo
0P0000030?3io`<000000P3`nOl2000000<0l?Wo00<000000?3io`3`nOl08P3`nOl00`000000@FWQ
045Yh@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`0@0?3ioah0003o5P3`
nOl2000000<0l?Wo0P0000040?3io`80000000@0l?Wo000000000000l?Wo0P00000>0?3io`800000
00@0l?Wo000000000000l?Wo0P0000020?3io`8000000`3`nOl00`000000l?Wo000000020?3io`80
0000:03`nOl00`000000@FWQ045Yh@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo
0?3io`120?3io`<00000103`nOl2000000@0l?Wo0P000000103`nOl000000000003`nOl6000000X0
l?Wo0P0000000`3`nOl00000000000020?3io`D000000P3`nOl2000000040?3io`00000000000?3i
o`H00000903`nOl00`000000@FWQ045Yh@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000
l?Wo0?3io`110?3io`<000001@3`nOl2000000@0l?Wo0P000000103`nOl000000000003`nOl20000
0080l?Wo0P00000:0?3io`050000003`nOl000000?3io`0000001@3`nOl200000080l?Wo0P000000
103`nOl000000000003`nOl200000080l?Wo0P00000T0?3io`0300000011JN40@FWQ0080@FWQo`3j
l>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0400l?Wo0P0000050?3io`@000000`3`nOl5
000000<0l?Wo1000000:0?3io`80000000<0l?Wo0000003`nOl00P0000000`3`nOl0000000000002
00000080l?Wo0`0000001@3`nOl00000000000000000l?Wo00@000009@3`nOl00`000000@FWQ045Y
h@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`100?3io`8000000`3`nOl0
0`000000l?Wo0?3io`0L0?3io`8000000`3`nOl2000003P0l?Wo00<00000045Yh@11JN400P11JN7o
0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0@@3`nOl5000000<0l?Wo0P00000H0?3i
o`@0000000<0l?Wo0000000000000P00000g0?3io`0300000011JN40@FWQ0080@FWQo`3jl>H>0?[`
iP40oooo000k0?[`iP030000003`nOl0l?Wo0:<0l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0
n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000@FWQ045Yh@02045YhOl0n_3V
3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`0300000011JN40@FWQ0080@FWQo`3j
l>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0:<0l?Wo00<00000045Yh@11JN400P11JN7o
0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000@FWQ045Yh@02045Y
hOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`0300000011JN40@FWQ0080
@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0:<0l?Wo00<00000045Yh@11JN40
0P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000@FWQ045Y
h@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`0300000011JN40
@FWQ0080@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0:<0l?Wo00<00000045Y
h@11JN400P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000
@FWQ045Yh@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`030000
0011JN40@FWQ0080@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo04l0l?Wo1000
000^0?3io`@000007P3`nOl00`000000@FWQ045Yh@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H0
0`000000l?Wo0?3io`1B0?3io`800000<03`nOl2000001d0l?Wo00<00000045Yh@11JN400P11JN7o
0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0?`3`nOl5000000<0l?Wo1P0000020?3i
o`80000000<0l?Wo0000000000000`3`nOl:000000<0l?Wo100000090?3io`L0000000<0l?Wo0000
00000000100000020?3io`80000000@0l?Wo000000000000l?Wo0`000000103`nOl0000000000000
00020?3io`<00000403`nOl00`000000@FWQ045Yh@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H0
0`000000l?Wo0?3io`100?3io`8000001`3`nOl2000000<0l?Wo0P000000103`nOl0000000000000
00020?3io`80000000<0l?Wo0000000000000P3`nOl2000000@0l?Wo0P0000030?3io`030000003`
nOl0l?Wo00L0l?Wo0P0000030?3io`040000003`nOl0l?Wo0?3io`8000000`3`nOl2000000040?3i
o`000000000000000080l?Wo0P0000000`3`nOl00000000000020?3io`8000000P3`nOl00`000000
l?Wo0?3io`0=0?3io`0300000011JN40@FWQ0080@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP030000
003`nOl0l?Wo0100l?Wo7P3o000B0?3io`8000001`3`nOl2000000<0l?Wo0P0000020?3io`800000
0P3`nOl2000000030?3io`00000000000080l?Wo0P0000040?3io`8000003@3`nOl2000000<0l?Wo
00@000000?3io`3`nOl0l?Wo0P0000030?3io`8000000P3`nOl200000080l?Wo0P0000000`3`nOl0
0000000000020?3io`8000004P3`nOl00`000000@FWQ045Yh@02045YhOl0n_3V3P3jl>H10?ooo`00
>`3jl>H00`000000l?Wo0?3io`100?3io`80000000<0l?Wo0000003`nOl0103`nOl2000000<0l?Wo
0P0000020?3io`8000000P3`nOl2000000030?3io`00000000000080l?Wo0P0000040?3io`H00000
2@3`nOl2000000030?3io`000000l?Wo00@0l?Wo0P0000030?3io`8000000P3`nOl200000080l?Wo
0P0000000`3`nOl00000000000020?3io`8000004P3`nOl00`000000@FWQ045Yh@02045YhOl0n_3V
3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`100?3io`@000001@3`nOl2000000<0l?Wo0P00
0000103`nOl000000000000000020?3io`80000000<0l?Wo0000000000000P3`nOl3000000030?3i
o`000000l?Wo008000000P3`nOl2000000T0l?Wo100000050?3io`8000000`3`nOl2000000040?3i
o`000000000000000080l?Wo0P0000000`3`nOl00000000000020?3io`8000004P3`nOl00`000000
@FWQ045Yh@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`100?3io`800000
00D0l?Wo0000003`nOl000000?3io`04000000@0l?Wo0P0000000`3`nOl000000000000400000004
0?3io`00000000000?3io`<0000000<0l?Wo0000000000000P3`nOl4000000X0l?Wo0P0000001@3`
nOl000000?3io`000000l?Wo00@00000103`nOl2000000050?3io`00000000000000003`nOl01000
00020?3io`D00000403`nOl00`000000@FWQ045Yh@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H0
0`000000l?Wo0?3io`100?3io`8000000`3`nOl00`000000l?Wo0?3io`0Z0?3io`8000000`3`nOl0
0`000000l?Wo0?3io`0>0?3io`8000001@3`nOl200000180l?Wo00<00000045Yh@11JN400P11JN7o
0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0?`3`nOl7000000<0l?Wo0P00000V0?3i
o`L000000`3`nOl2000000X0l?Wo0`0000050?3io`8000004P3`nOl00`000000@FWQ045Yh@02045Y
hOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`0300000011JN40@FWQ0080
@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0:<0l?Wo00<00000045Yh@11JN40
0P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000@FWQ045Y
h@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`030000003jl>H0
n_3V0?l0n_3V403jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`030000003jl>H0n_3V
0?l0n_3V403jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`030000003jl>H0n_3V0?l0
n_3V403jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`030000003jl>H0n_3V0?l0n_3V
403jl>H10?ooo`00>`3jl>JW00000?l0n_3V4P3jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool006H0n_3V0`00000d0?[`iPD00000<`3jl>H6000002l0n_3V0`00000e
0?[`iPH00000<P3jl>H5000003@0n_3V0`00000m0?[`iP40oooo001U0?[`iP030000003jl>H0n_3V
00800000<`3jl>H2000003P0n_3V0P00000`0?[`iP80000000<0n_3V000000000000=P3jl>H20000
03@0n_3V0P00000f0?[`iP030000003jl>H0n_3V00800000?03jl>H10?ooo`00G@3jl>H5000000H0
n_3V0P00000[0?[`iPD00000103jl>H2000002d0n_3V1@0000050?[`iP800000<03jl>H200000003
0?[`iP000000000003H0n_3V0P00000e0?[`iP800000>03jl>H2000003`0n_3V0@3oool006P0n_3V
0P00000e0?[`iP800000=P3jl>H200000300n_3V0P0000000`3jl>H000000000000f0?[`iP800000
=P3jl>H2000003L0n_3V0P00000l0?[`iP40oooo001V0?[`iP<00000=`3jl>H2000003D0n_3V0P00
000`0?[`iP80000000<0n_3V000000000000=P3jl>H2000003L0n_3V0P00000d0?[`iP<00000?@3j
l>H10?ooo`00J03jl>H2000003<0n_3V0P0000000`3jl>H000000000000e0?[`iP800000<03jl>H2
000000030?[`iP000000000003H0n_3V0P00000d0?[`iP80000000<0n_3V000000000000=P3jl>H2
000003`0n_3V0@3oool006D0n_3V00<000000?[`iP3jl>H00P00000c0?[`iP80000000<0n_3V0000
00000000<`3jl>H400000300n_3V0P0000000`3jl>H000000000000d0?[`iP@00000=03jl>H20000
00030?[`iP000000000003<0n_3V00<000000?[`iP3jl>H00P00000l0?[`iP40oooo001V0?[`iP<0
0000=@3jl>H3000003H0n_3V0P00000a0?[`iP<00000=`3jl>H2000003D0n_3V0`00000e0?[`iP<0
0000?@3jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo001>0?[`iPH000001`3jl>Ko000006@00000=@3jl>H10?ooo`00D03jl>H20000
00T0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V
03<0n_3V0@3oool004H0n_3V1@0000050?[`iP8000002@3jl>H00`000000n_3V0?[`iP050?[`iP03
0000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP0e0?[`iP03
0000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP0f0?[`iP03
0000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00D03jl>H2000000T0n_3V
0`00001<0?[`iP`0003o3`3oA@2@0?[`iPh0odD0F03jl>H3000003D0n_3V0@3oool00500n_3V0P00
00090?[`iP030000003jl>H0n_3V04L0n_3V1@000?l;0?[`iP030?m5003jl>H0n_3V00D0n_3V1`00
0?l0103jl>H0odD00?m5003oA@2:0?[`iP<0odD03P3jl>H20?m505P0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00D03jl>H2000000T0n_3V00<000000?[`iP3jl>H0@`3jl>H40000o`d0n_3V0`3o
A@0?0?[`iP<0003o00@0n_3V0?m5003oA@00odD0Q03jl>H30?m501<0n_3V0P3oA@1F0?[`iP030000
003jl>H0n_3V03<0n_3V0@3oool004h0n_3V100000090?[`iP030000003jl>H0n_3V0440n_3V0P00
0?l?0?[`iP80odD05@3jl>H20000o`80n_3V0P3oA@200?[`iP80odD0603jl>H20?m505@0n_3V00<0
00000?[`iP3jl>H0<`3jl>H10?ooo`00D03jl>H2000000T0n_3V00<000000?[`iP3jl>H0?`3jl>H2
0000o`l0n_3V0P3oA@0I0?[`iP80003o0P3jl>H20?m507`0n_3V0P3oA@0L0?[`iP80odD0DP3jl>H0
0`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP800000?P3jl>H20000oa00n_3V00<0odD00?[`
iP3jl>H06`3jl>H20000o`80n_3V0P3oA@1h0?[`iP80odD0803jl>H00`3oA@00n_3V0?[`iP1>0?[`
iP800000=@3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0k0?[`iP80003o4@3jl>H00`3oA@00
n_3V0?[`iP0N0?[`iP80003o0P3jl>H20?m507@0n_3V0P3oA@0S0?[`iP030?m5003jl>H0n_3V04h0
n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0i0?[`iP80003o
4@3jl>H20?m502<0n_3V0P000?l20?[`iP80odD0L03jl>H20?m502H0n_3V00<0odD00?[`iP3jl>H0
C@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V03L0n_3V0P00
0?lB0?[`iP030?m5003jl>H0n_3V02D0n_3V0P000?l20?[`iP030?m5003jl>H0n_3V06/0n_3V0P3o
A@0Y0?[`iP030?m5003jl>H0n_3V04`0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H0
0`000000n_3V0?[`iP0e0?[`iP80003o503jl>H00`3oA@00n_3V0?[`iP0W0?[`iP80003o00<0n_3V
0?m5003oA@00JP3jl>H00`3oA@00n_3V0?[`iP0Z0?[`iP030?m5003jl>H0n_3V04/0n_3V00<00000
0?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0c0?[`iP80003o5@3jl>H00`3o
A@00n_3V0?[`iP0Z0?[`iP80003o00<0n_3V0?m5003jl>H0IP3jl>H20?m502d0n_3V00<0odD00?[`
iP3jl>H0B`3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP800000<P3jl>H20000oaL0
n_3V00<0odD00?[`iP3jl>H0;03jl>H010000?l0n_3V0?m5003oA@1T0?[`iP030?m5003jl>H0n_3V
02h0n_3V00<0odD00?[`iP3jl>H0B@3jl>H2000003D0n_3V0@3oool005/0n_3V00<000000?[`iP3j
l>H0<03jl>H00`000?l0n_3V0?[`iP0F0?[`iP030?m5003jl>H0n_3V02h0n_3V0P000?l00`3jl>H0
odD00?m5001Q0?[`iP030?m5003jl>H0n_3V0300n_3V00<0odD00?[`iP3jl>H0B@3jl>H00`000000
n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V02h0n_3V0P000?lH0?[`iP030?m5
003jl>H0n_3V0340n_3V00@0003o0?[`iP3jl>H0odD0GP3jl>H20?m503@0n_3V00<0odD00?[`iP3j
l>H0B03jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V02d0n_3V
00<0003o0?[`iP3jl>H0603jl>H00`3oA@00n_3V0?[`iP0b0?[`iP80003o00<0n_3V0?m5003oA@00
F`3jl>H00`3oA@00n_3V0?[`iP0d0?[`iP030?m5003jl>H0n_3V04P0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0/0?[`iP030000o`3jl>H0n_3V01P0n_3V00<0
odD00?[`iP3jl>H0=@3jl>H20000o`030?[`iP3oA@00n_3V05L0n_3V0P3oA@0h0?[`iP030?m5003j
l>H0n_3V04L0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H2000002/0n_3V0P000?lK
0?[`iP030?m5003jl>H0n_3V03L0n_3V00<0003o0?[`iP3oA@00EP3jl>H00`3oA@00n_3V0?[`iP0i
0?[`iP030?m5003jl>H0n_3V04D0n_3V0P00000e0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V
02T0n_3V00<0003o0?[`iP3jl>H06P3jl>H00`3oA@00n_3V0?[`iP0i0?[`iP80003o00<0odD00?[`
iP3jl>H0DP3jl>H00`3oA@00n_3V0?[`iP0j0?[`iP030?m5003jl>H0n_3V04H0n_3V00<000000?[`
iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0W0?[`iP80003o703jl>H00`3oA@00
n_3V0?[`iP0l0?[`iP030000o`3oA@00odD00500n_3V0P3oA@0n0?[`iP030?m5003jl>H0n_3V04D0
n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0V0?[`iP030000
o`3jl>H0n_3V01`0n_3V00<0odD00?[`iP3jl>H0?@3jl>H00`000?l0n_3V0?m5001>0?[`iP030?m5
003jl>H0n_3V03h0n_3V00<0odD00?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo
001K0?[`iP030000003jl>H0n_3V02D0n_3V00<0003o0?[`iP3jl>H0703jl>H00`3oA@00n_3V0?[`
iP0o0?[`iP80003o00<0odD00?[`iP3jl>H0BP3jl>H00`3oA@00n_3V0?[`iP0o0?[`iP030?m5003j
l>H0n_3V04D0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0S
0?[`iP80003o7`3jl>H00`3oA@00n_3V0?[`iP110?[`iP030000o`3oA@00n_3V04P0n_3V0P3oA@13
0?[`iP030?m5003jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H20000
02<0n_3V00<0003o0?[`iP3jl>H07P3jl>H00`3oA@00n_3V0?[`iP130?[`iP030000o`3oA@00n_3V
04H0n_3V00<0odD00?[`iP3jl>H0@`3jl>H00`3oA@00n_3V0?[`iP130?[`iP800000=@3jl>H10?oo
o`00F`3jl>H00`000000n_3V0?[`iP0Q0?[`iP030000o`3jl>H0n_3V01l0n_3V00<0odD00?[`iP3j
l>H0A03jl>H00`000?l0odD00?[`iP140?[`iP030?m5003jl>H0n_3V04@0n_3V00<0odD00?[`iP3j
l>H0A03jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V0200n_3V
00<0003o0?[`iP3jl>H0803jl>H00`3oA@00n_3V0?[`iP150?[`iP030000o`3oA@00odD00440n_3V
0P3oA@180?[`iP030?m5003jl>H0n_3V04<0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3j
l>H00`000000n_3V0?[`iP0N0?[`iP80003o8P3jl>H00`3oA@00n_3V0?[`iP180?[`iP030000o`3o
A@00n_3V03h0n_3V00<0odD00?[`iP3jl>H0B03jl>H00`3oA@00n_3V0?[`iP130?[`iP030000003j
l>H0n_3V03<0n_3V0@3oool00440n_3V0`0000040?[`iP8000001@3jl>H3000000T0n_3V00<00000
0?[`iP3jl>H07@3jl>H00`000?l0n_3V0?[`iP0R0?[`iP030?m5003jl>H0n_3V04T0n_3V00<0003o
0?m5003jl>H0?03jl>H00`3oA@00n_3V0?[`iP1:0?[`iP030?m5003jl>H0n_3V0480n_3V00<00000
0?[`iP3jl>H0<`3jl>H10?ooo`00@03jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`
iP030000003jl>H0n_3V00800000203jl>H00`000000n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V
02<0n_3V00<0odD00?[`iP3jl>H0BP3jl>H00`000?l0odD00?[`iP0j0?[`iP030?m5003jl>H0n_3V
04/0n_3V00<0odD00?[`iP3jl>H0@P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo000h0?[`iPD0
00000`3jl>H2000000030?[`iP000000000000`0n_3V0P0000080?[`iP<000006`3jl>H00`000?l0
n_3V0?[`iP0S0?[`iP030?m5003jl>H0n_3V04d0n_3V00<0odD00?[`iP3jl>H0=`3jl>H00`3oA@00
n_3V0?[`iP1=0?[`iP030?m5003jl>H0n_3V03l0n_3V0`00000e0?[`iP40oooo00100?[`iP800000
00<0n_3V000000000000303jl>H2000000P0n_3V00<000000?[`iP3jl>H06P3jl>H00`000?l0n_3V
0?[`iP0T0?[`iP030?m5003jl>H0n_3V04h0n_3V00<0odD00?[`iP3jl>H0=@3jl>H00`3oA@00n_3V
0?[`iP1>0?[`iP030?m5003jl>H0n_3V0440n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00@03j
l>H2000000030?[`iP000000000000T0n_3V00<000000?[`iP3jl>H00P0000080?[`iP030000003j
l>H0n_3V01T0n_3V00<0003o0?[`iP3jl>H09@3jl>H00`3oA@00n_3V0?[`iP1?0?[`iP030?m5003j
l>H0n_3V03<0n_3V00<0odD00?[`iP3jl>H0C`3jl>H00`3oA@00n_3V0?[`iP110?[`iP030000003j
l>H0n_3V03<0n_3V0@3oool00400n_3V0P0000000`3jl>H00000000000090?[`iP@000002@3jl>H0
0`000000n_3V0?[`iP0H0?[`iP030000o`3jl>H0n_3V02D0n_3V00<0odD00?[`iP3jl>H0D@3jl>H0
0`3oA@00n_3V0?[`iP0a0?[`iP030?m5003jl>H0n_3V0500n_3V00<0odD00?[`iP3jl>H0@@3jl>H0
0`000000n_3V0?[`iP0c0?[`iP40oooo00100?[`iP80000000<0n_3V0000000000002@3jl>H20000
00/0n_3V00<000000?[`iP3jl>H05P3jl>H20000obP0n_3V00<0odD00?[`iP3jl>H0DP3jl>H00`3o
A@00n_3V0?[`iP0_0?[`iP030?m5003jl>H0n_3V0580n_3V00<0odD00?[`iP3jl>H0@03jl>H00`00
0000n_3V0?[`iP0c0?[`iP40oooo00110?[`iP<000002P3jl>H5000000P0n_3V0P00000F0?[`iP03
0000o`3jl>H0n_3V02P0n_3V00<0odD00?[`iP3jl>H0D`3jl>H00`3oA@00n_3V0?[`iP0]0?[`iP03
0?m5003jl>H0n_3V05<0n_3V00<0odD00?[`iP3jl>H0?`3jl>H2000003D0n_3V0@3oool005/0n_3V
00<000000?[`iP3jl>H0503jl>H00`000?l0n_3V0?[`iP0Y0?[`iP030?m5003jl>H0n_3V05@0n_3V
00<0odD00?[`iP3jl>H0:`3jl>H00`3oA@00n_3V0?[`iP1D0?[`iP030?m5003jl>H0n_3V0400n_3V
00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0C0?[`iP030000o`3j
l>H0n_3V02T0n_3V00<0odD00?[`iP3jl>H0EP3jl>H00`3oA@00n_3V0?[`iP0Y0?[`iP030?m5003j
l>H0n_3V05D0n_3V00<0odD00?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K
0?[`iP030000003jl>H0n_3V0180n_3V00<0003o0?[`iP3jl>H0:P3jl>H00`3oA@00n_3V0?[`iP1G
0?[`iP030?m500000?l0n_3V02L0n_3V00<0odD00?[`iP3jl>H0EP3jl>H00`3oA@00n_3V0?[`iP10
0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H04@3jl>H00`00
0?l0n_3V0?[`iP0[0?[`iP030?m5003jl>H0n_3V05P0n_3V00<0odD00000o`3jl>H09@3jl>H00`3o
A@00n_3V0?[`iP1G0?[`iP030?m5003jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0<`3jl>H10?oo
o`00F`3jl>H00`000000n_3V0?[`iP0@0?[`iP030000o`3jl>H0n_3V02`0n_3V00<0odD00?[`iP3j
l>H0F@3jl>H00`3oA@00003o0?[`iP0S0?[`iP030?m5003jl>H0n_3V05T0n_3V00<0odD00?[`iP3j
l>H0?`3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP800000403jl>H00`000?l0n_3V
0?[`iP0]0?[`iP030?m5003jl>H0n_3V05X0n_3V00<0odD00000o`3jl>H08@3jl>H00`3oA@00n_3V
0?[`iP1J0?[`iP030?m5003jl>H0n_3V03h0n_3V0P00000e0?[`iP40oooo001K0?[`iP030000003j
l>H0n_3V00h0n_3V00<0003o0?[`iP3jl>H0;P3jl>H00`3oA@00n_3V0?[`iP1K0?[`iP030?m50000
0?l0n_3V01h0n_3V0P3oA@1M0?[`iP030?m5003jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H0<`3j
l>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0=0?[`iP030000o`3jl>H0n_3V02l0n_3V00<0odD0
0?[`iP3jl>H0G03jl>H20?m501d0n_3V00<0odD00?[`iP3jl>H0GP3jl>H00`3oA@00n_3V0?[`iP0n
0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H02`3jl>H20000
oc40n_3V00<0odD00?[`iP3jl>H0G`3jl>H00`3oA@00n_3V0?[`iP0I0?[`iP030?m5003jl>H0n_3V
05l0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP03
0000003jl>H0n_3V00X0n_3V00<0003o0?[`iP3jl>H0<@3jl>H00`3oA@00n_3V0?[`iP1P0?[`iP03
0?m5003jl>H0n_3V01L0n_3V00<0odD00?[`iP3jl>H0H03jl>H00`3oA@00n_3V0?[`iP0n0?[`iP03
0000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H02@3jl>H00`000?l0n_3V
0?[`iP0b0?[`iP030?m5003jl>H0n_3V0640n_3V00<0odD00?[`iP3jl>H05@3jl>H00`3oA@00n_3V
0?[`iP1Q0?[`iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3j
l>H2000000T0n_3V00<0003o0?[`iP3jl>H0<`3jl>H00`3oA@00n_3V0?[`iP1R0?[`iP030?m5003j
l>H0n_3V01<0n_3V00<0odD00?[`iP3jl>H0HP3jl>H00`3oA@00n_3V0?[`iP0m0?[`iP800000=@3j
l>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP070?[`iP030000o`3jl>H0n_3V03@0n_3V00<0odD0
0?[`iP3jl>H0H`3jl>H00`3oA@00n_3V0?[`iP0A0?[`iP030?m5003jl>H0n_3V06<0n_3V00<0odD0
0?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V
00H0n_3V00<0003o0?[`iP3jl>H0=@3jl>H00`3oA@00n_3V0?[`iP1T0?[`iP030?m5003jl>H0n_3V
00l0n_3V00<0odD00?[`iP3jl>H0I03jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V
03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H01@3jl>H00`000?l0n_3V0?[`iP0f0?[`iP03
0?m5003jl>H0n_3V06D0n_3V00<0odD00?[`iP3jl>H03@3jl>H00`3oA@00n_3V0?[`iP1U0?[`iP03
0?m5003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V
0?[`iP0n0?[`iP030?m5003jl>H0n_3V06H0n_3V00<0odD00?[`iP3jl>H02`3jl>H00`3oA@00n_3V
0?[`iP1V0?[`iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3j
l>H2000003l0n_3V00<0odD00?[`iP3jl>H0I`3jl>H00`3oA@00n_3V0?[`iP090?[`iP030?m5003j
l>H0n_3V06L0n_3V00<0odD00?[`iP3jl>H0?@3jl>H2000003D0n_3V0@3oool005/0n_3V00<00000
0?[`iP3jl>H0?P3jl>H00`3oA@00n_3V0?[`iP1X0?[`iP030?m5003jl>H0n_3V00L0n_3V00<0odD0
0?[`iP3jl>H0J03jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool0
05/0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3oA@00n_3V0?[`iP1Z0?[`iP030?m5003jl>H0n_3V
00D0n_3V00<0odD00?[`iP3jl>H0J@3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V
03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3oA@00n_3V0?[`iP1[0?[`iP03
0?m5003jl>H0n_3V00<0n_3V00<0odD00?[`iP3jl>H0JP3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP03
0000003jl>H0n_3V03<0n_3V0@3oool004l0n_3V0`0000090?[`iP030000003jl>H0n_3V03d0n_3V
00<0odD00?[`iP3jl>H0K03jl>H01@3oA@00n_3V0?[`iP3jl>H0odD006d0n_3V00<0odD00?[`iP3j
l>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001>0?[`iP80000000<0n_3V000000000000
203jl>H00`000000n_3V0?[`iP0m0?[`iP030?m5003jl>H0n_3V06d0n_3V00<0odD00?[`iP3oA@00
KP3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool004h0n_3V0P00
00000`3jl>H00000000000080?[`iP<00000?@3jl>H00`3oA@00n_3V0?[`iP1^0?[`iP030?m5003j
l>H0n_3V06d0n_3V00<0odD00?[`iP3jl>H0?03jl>H3000003D0n_3V0@3oool004h0n_3V0P000000
0`3jl>H00000000000080?[`iP030000003jl>H0n_3V03d0n_3V00<0odD00?[`iP3jl>H0K@3jl>H0
0`3oA@00n_3V0?m5001^0?[`iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H1
0?ooo`00CP3jl>H2000000030?[`iP000000000000P0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3o
A@00n_3V0?[`iP1/0?[`iP050?m5003jl>H0n_3V0?[`iP3oA@00K@3jl>H00`3oA@00n_3V0?[`iP0n
0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool004h0n_3V0P0000000`3jl>H00000000000080?[`
iP030000003jl>H0n_3V03d0n_3V00<0odD00?[`iP3jl>H0J`3jl>H00`3oA@00n_3V0?[`iP030?[`
iP030?m5003jl>H0n_3V06X0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`
iP40oooo001>0?[`iP80000000<0n_3V000000000000203jl>H00`000000n_3V0?[`iP0m0?[`iP03
0?m5003jl>H0n_3V06X0n_3V00<0odD00?[`iP3jl>H01@3jl>H00`3oA@00n_3V0?[`iP1Y0?[`iP03
0?m5003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00C`3jl>H3000000T0n_3V
0P00000o0?[`iP030?m5003jl>H0n_3V06P0n_3V00<0odD00?[`iP3jl>H01`3jl>H00`3oA@00n_3V
0?[`iP1X0?[`iP030?m5003jl>H0n_3V03d0n_3V0P00000e0?[`iP40oooo001K0?[`iP030000003j
l>H0n_3V03h0n_3V00<0odD00?[`iP3jl>H0I`3jl>H00`3oA@00n_3V0?[`iP090?[`iP030?m5003j
l>H0n_3V06L0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K
0?[`iP030000003jl>H0n_3V03h0n_3V00<0odD00?[`iP3jl>H0IP3jl>H00`3oA@00n_3V0?[`iP0;
0?[`iP030?m5003jl>H0n_3V06H0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c
0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V03h0n_3V00<0odD00?[`iP3jl>H0I@3jl>H00`3o
A@00n_3V0?[`iP0=0?[`iP030?m5003jl>H0n_3V06D0n_3V00<0odD00?[`iP3jl>H0=@3jl>H20000
o`L0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0n0?[`iP03
0?m5003jl>H0n_3V06@0n_3V00<0odD00?[`iP3jl>H03`3jl>H00`3oA@00n_3V0?[`iP1T0?[`iP03
0?m5003jl>H0n_3V03@0n_3V00<0003o0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0c0?[`iP40
oooo001K0?[`iP030000003jl>H0n_3V03h0n_3V00<0odD00?[`iP3jl>H0H`3jl>H00`3oA@00n_3V
0?[`iP0A0?[`iP030?m5003jl>H0n_3V06<0n_3V00<0odD00?[`iP3jl>H0<`3jl>H00`000?l0n_3V
0?[`iP080?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V0P00000o0?[`iP030?m5003j
l>H0n_3V0680n_3V00<0odD00?[`iP3jl>H04`3jl>H00`3oA@00n_3V0?[`iP1R0?[`iP030?m5003j
l>H0n_3V0380n_3V00<0003o0?[`iP3jl>H0203jl>H2000003D0n_3V0@3oool005/0n_3V00<00000
0?[`iP3jl>H0?P3jl>H00`3oA@00n_3V0?[`iP1Q0?[`iP030?m5003jl>H0n_3V01D0n_3V00<0odD0
0?[`iP3jl>H0H@3jl>H00`3oA@00n_3V0?[`iP0a0?[`iP030000o`3jl>H0n_3V00X0n_3V00<00000
0?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0n0?[`iP030?m5003jl>H0n_3V
05l0n_3V0P3oA@0I0?[`iP030?m5003jl>H0n_3V0600n_3V00<0odD00?[`iP3jl>H0<03jl>H00`00
0?l0n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3j
l>H0?P3jl>H00`3oA@00n_3V0?[`iP1N0?[`iP030?m5003jl>H0n_3V01X0n_3V0P3oA@1O0?[`iP03
0?m5003jl>H0n_3V0300n_3V00<0003o0?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0c0?[`iP40
oooo001K0?[`iP030000003jl>H0n_3V03l0n_3V00<0odD00?[`iP3jl>H0G03jl>H00`3oA@00n_3V
0?[`iP0L0?[`iP030000o`3oA@00n_3V05d0n_3V00<0odD00?[`iP3jl>H0;`3jl>H00`000?l0n_3V
0?[`iP0=0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?`3j
l>H00`3oA@00n_3V0?[`iP1K0?[`iP030?m5003jl>H0n_3V01h0n_3V00<0003o0?m5003jl>H0G03j
l>H00`3oA@00n_3V0?[`iP0^0?[`iP030000o`3jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0<`3j
l>H10?ooo`00F`3jl>H200000400n_3V00<0odD00?[`iP3jl>H0FP3jl>H00`3oA@00n_3V0?[`iP0P
0?[`iP030000o`3oA@00n_3V05/0n_3V00<0odD00?[`iP3jl>H0;@3jl>H00`000?l0n_3V0?[`iP0>
0?[`iP800000=@3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0o0?[`iP030?m5003jl>H0n_3V
05T0n_3V00<0odD00?[`iP3jl>H08`3jl>H00`3oA@00n_3V0?[`iP1I0?[`iP030?m5003jl>H0n_3V
02`0n_3V00<0003o0?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP03
0000003jl>H0n_3V03l0n_3V00<0odD00?[`iP3jl>H0F03jl>H00`3oA@00n_3V0?[`iP0U0?[`iP03
0?m5003jl>H0n_3V05L0n_3V00<0odD00?[`iP3jl>H0;03jl>H00`000?l0n_3V0?[`iP0A0?[`iP03
0000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3oA@00n_3V
0?[`iP1G0?[`iP030?m5003jl>H0n_3V02L0n_3V00<0odD00?[`iP3jl>H0EP3jl>H00`3oA@00n_3V
0?[`iP0[0?[`iP030000o`3jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3j
l>H00`000000n_3V0?[`iP0o0?[`iP030?m5003jl>H0n_3V05H0n_3V00<0odD00?[`iP3jl>H0:@3j
l>H00`3oA@00n_3V0?[`iP1E0?[`iP030?m5003jl>H0n_3V02X0n_3V00<0003o0?[`iP3jl>H04`3j
l>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP800000@@3jl>H00`3oA@00n_3V0?[`iP1D
0?[`iP030?m5003jl>H0n_3V02/0n_3V00<0odD00?[`iP3jl>H0E03jl>H00`3oA@00n_3V0?[`iP0Y
0?[`iP030000o`3jl>H0n_3V01<0n_3V0P00000e0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V
0400n_3V00<0odD00?[`iP3jl>H0D`3jl>H00`3oA@00n_3V0?[`iP0]0?[`iP030?m5003jl>H0n_3V
05<0n_3V00<0odD00?[`iP3jl>H0:03jl>H00`000?l0n_3V0?[`iP0E0?[`iP030000003jl>H0n_3V
03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0@03jl>H00`3oA@00n_3V0?[`iP1B0?[`iP03
0?m5003jl>H0n_3V02l0n_3V00<0odD00000o`3jl>H0D@3jl>H00`3oA@00n_3V0?[`iP0X0?[`iP03
0000o`3jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V
0?[`iP110?[`iP030?m5003jl>H0n_3V0500n_3V00<0odD00?[`iP3jl>H0<@3jl>H00`3oA@00003o
0?[`iP1@0?[`iP030?m5003jl>H0n_3V02H0n_3V0P000?lI0?[`iP030000003jl>H0n_3V03<0n_3V
0@3oool00440n_3V0`0000040?[`iP8000001@3jl>H3000000T0n_3V00<000000?[`iP3jl>H0@@3j
l>H00`3oA@00n_3V0?[`iP1?0?[`iP030?m5003jl>H0n_3V03<0n_3V00<0odD00000o`3jl>H0C`3j
l>H00`3oA@00n_3V0?[`iP0U0?[`iP030000o`3jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H0<`3j
l>H10?ooo`00@03jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP030000003jl>H0
n_3V00800000203jl>H00`000000n_3V0?[`iP110?[`iP030?m5003jl>H0n_3V04h0n_3V00<0odD0
0?[`iP3jl>H0=@3jl>H00`3oA@00003o0?[`iP1>0?[`iP030?m5003jl>H0n_3V02@0n_3V00<0003o
0?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo00100?[`iP80000000<0n_3V0000
00000000303jl>H2000000P0n_3V0`0000110?[`iP030?m5003jl>H0n_3V04d0n_3V00<0odD00?[`
iP3jl>H0=`3jl>H00`3oA@00003o0?[`iP1<0?[`iP030?m5003jl>H0n_3V02@0n_3V00<0003o0?[`
iP3jl>H06@3jl>H3000003D0n_3V0@3oool00400n_3V0P0000000`3jl>H000000000000<0?[`iP80
0000203jl>H00`000000n_3V0?[`iP120?[`iP030?m5003jl>H0n_3V04X0n_3V0P3oA@0k0?[`iP03
0?m500000?l0n_3V04/0n_3V00<0odD00?[`iP3jl>H08`3jl>H00`000?l0n_3V0?[`iP0L0?[`iP03
0000003jl>H0n_3V03<0n_3V0@3oool00400n_3V0P0000000`3jl>H00000000000090?[`iP030000
003jl>H0n_3V00800000203jl>H00`000000n_3V0?[`iP120?[`iP030?m5003jl>H0n_3V04T0n_3V
00<0odD00?[`iP3jl>H0?03jl>H20?m500030000o`3jl>H0n_3V04P0n_3V00<0odD00?[`iP3jl>H0
8P3jl>H00`000?l0n_3V0?[`iP0M0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool00400n_3V0P00
00000`3jl>H00000000000090?[`iP@000002@3jl>H00`000000n_3V0?[`iP120?[`iP030?m5003j
l>H0n_3V04P0n_3V00<0odD00?[`iP3jl>H0?`3jl>H00`3oA@00003o0?[`iP170?[`iP030?m5003j
l>H0n_3V0240n_3V0P000?lP0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool00400n_3V0P000000
0`3jl>H00000000000090?[`iP8000002`3jl>H00`000000n_3V0?[`iP130?[`iP030?m5003jl>H0
n_3V04H0n_3V00<0odD00?[`iP3jl>H0@@3jl>H00`3oA@00003o0?[`iP160?[`iP030?m5003jl>H0
n_3V0200n_3V00<0003o0?[`iP3jl>H0803jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo00110?[`
iP<000002P3jl>H5000000P0n_3V00<000000?[`iP3jl>H0@`3jl>H00`3oA@00n_3V0?[`iP140?[`
iP80odD0A@3jl>H00`3oA@00003o0?[`iP150?[`iP030?m5003jl>H0n_3V01l0n_3V00<0003o0?[`
iP3jl>H08@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP800000A@3jl>H00`3oA@00
n_3V0?[`iP120?[`iP030?m5003jl>H0n_3V04H0n_3V00<0odD00000o`3jl>H0@`3jl>H00`3oA@00
n_3V0?[`iP0O0?[`iP030000o`3jl>H0n_3V0240n_3V0P00000e0?[`iP40oooo001K0?[`iP030000
003jl>H0n_3V04@0n_3V00<0odD00?[`iP3jl>H0@@3jl>H00`3oA@00n_3V0?[`iP180?[`iP030?m5
00000?l0n_3V0480n_3V00<0odD00?[`iP3jl>H07@3jl>H20000obD0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP140?[`iP030?m5003jl>H0n_3V0400n_3V00<0
odD00?[`iP3jl>H0BP3jl>H20?m500030000o`3jl>H0n_3V03l0n_3V00<0odD00?[`iP3jl>H0703j
l>H00`000?l0n_3V0?[`iP0U0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<00000
0?[`iP3jl>H0A@3jl>H00`3oA@00n_3V0?[`iP0m0?[`iP80odD0C`3jl>H00`3oA@00003o0?[`iP0n
0?[`iP030?m5003jl>H0n_3V01`0n_3V00<0003o0?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP0c
0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04D0n_3V00<0odD00?[`iP3jl>H0?03jl>H00`3o
A@00n_3V0?[`iP1@0?[`iP030?m500000?l0n_3V03d0n_3V00<0odD00?[`iP3jl>H06P3jl>H20000
obT0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H2000004L0n_3V00<0odD00?[`iP3j
l>H0>P3jl>H00`3oA@00n_3V0?[`iP1B0?[`iP030?m500000?l0n_3V03/0n_3V00<0odD00?[`iP3j
l>H06P3jl>H00`000?l0n_3V0?[`iP0X0?[`iP800000=@3jl>H10?ooo`00F`3jl>H00`000000n_3V
0?[`iP160?[`iP030?m5003jl>H0n_3V03T0n_3V00<0odD00?[`iP3jl>H0E03jl>H20?m500030000
o`3jl>H0n_3V03P0n_3V00<0odD00?[`iP3jl>H0603jl>H20000ob`0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP170?[`iP030?m5003jl>H0n_3V03L0n_3V00<0
odD00?[`iP3jl>H0E`3jl>H00`3oA@00003o0000o`0g0?[`iP030?m5003jl>H0n_3V01P0n_3V00<0
003o0?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0
n_3V04P0n_3V00<0odD00?[`iP3jl>H0=03jl>H20?m505/0n_3V0P3oA@000`000?l0n_3V0?[`iP0d
0?[`iP030?m5003jl>H0n_3V01L0n_3V00<0003o0?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP0c
0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04P0n_3V00<0odD00?[`iP3jl>H0<`3jl>H00`3o
A@00n_3V0?[`iP1M0?[`iP80odD000<0003o0?[`iP3jl>H0<@3jl>H00`3oA@00n_3V0?[`iP0F0?[`
iP80003o<03jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04T0
n_3V00<0odD00?[`iP3jl>H0<@3jl>H00`3oA@00n_3V0?[`iP1P0?[`iP030?m500000?l0n_3V0340
n_3V00<0odD00?[`iP3jl>H05@3jl>H00`000?l0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V03<0
n_3V0@3oool005/0n_3V0P00001;0?[`iP030?m5003jl>H0n_3V02h0n_3V0P3oA@1T0?[`iP80odD0
00<0003o0?[`iP3jl>H0;@3jl>H00`3oA@00n_3V0?[`iP0D0?[`iP80003o<P3jl>H2000003D0n_3V
0@3oool005/0n_3V00<000000?[`iP3jl>H0B`3jl>H00`3oA@00n_3V0?[`iP0[0?[`iP80odD0J03j
l>H00`3oA@00003o0000o`0/0?[`iP030?m5003jl>H0n_3V01@0n_3V00<0003o0?[`iP3jl>H0<`3j
l>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04/0n_3V00<0odD0
0?[`iP3jl>H0:@3jl>H20?m506/0n_3V00<0odD00?[`iP000?l0:P3jl>H00`3oA@00n_3V0?[`iP0C
0?[`iP80003o=P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V
04`0n_3V00<0odD00?[`iP3jl>H09`3jl>H00`3oA@00n_3V0?[`iP1/0?[`iP80odD00P000?lW0?[`
iP030?m5003jl>H0n_3V0180n_3V0P000?lh0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0
n_3V00<000000?[`iP3jl>H0C@3jl>H00`3oA@00n_3V0?[`iP0T0?[`iP80odD0L@3jl>H20?m50080
003o903jl>H00`3oA@00n_3V0?[`iP0A0?[`iP80003o>P3jl>H00`000000n_3V0?[`iP0c0?[`iP40
oooo001K0?[`iP800000C`3jl>H00`3oA@00n_3V0?[`iP0Q0?[`iP80odD0M@3jl>H20?m50080003o
8@3jl>H00`3oA@00n_3V0?[`iP0?0?[`iP<0003o>`3jl>H2000003D0n_3V0@3oool005/0n_3V00<0
00000?[`iP3jl>H0C`3jl>H00`3oA@00n_3V0?[`iP0O0?[`iP030?m5003jl>H0n_3V07L0n_3V0P3o
A@020000oah0n_3V00<0odD00?[`iP3jl>H03@3jl>H30000ocl0n_3V00<000000?[`iP3jl>H0<`3j
l>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP1@0?[`iP80odD07@3jl>H20?m507`0n_3V0P3oA@04
0000oaT0n_3V00<0odD00?[`iP3jl>H0303jl>H20000od80n_3V00<000000?[`iP3jl>H0<`3jl>H1
0?ooo`00F`3jl>H00`000000n_3V0?[`iP1B0?[`iP030?m5003jl>H0n_3V01P0n_3V0P3oA@200?[`
iP80odD00P3jl>H40000oa<0n_3V0P3oA@0=0?[`iP80003oA03jl>H00`000000n_3V0?[`iP0c0?[`
iP40oooo001>0?[`iPH000001`3jl>H00`000000n_3V0?[`iP1C0?[`iP80odD05@3jl>H30?m508@0
n_3V0P3oA@040?[`iP@0003o303jl>H30?m500T0n_3V1P000?m60?[`iP030000003jl>H0n_3V03<0
n_3V0@3oool00500n_3V0P0000090?[`iP030000003jl>H0n_3V05D0n_3V103oA@0<0?[`iPD0odD0
R@3jl>H40?m500@0n_3V0`000?l50?[`iP@0odD0203jl>H40000od`0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00D03jl>H2000000T0n_3V0`00001I0?[`iP`0odD0TP3jl>H<0?m500`0003oCP3j
l>H3000003D0n_3V0@3oool00500n_3V0P0000090?[`iP030000003jl>H0n_3V00D0n_3V00<00000
0?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP0f0?[`iP030000003jl>H0n_3V03D0n_3V00<00000
0?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V03H0n_3V00<00000
0?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001@0?[`iP8000002@3jl>H00`00
0000n_3V0?[`iP050?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`00
0000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`00
0000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`00
0000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`00
0000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0<`3jl>H10?oo
o`00D03jl>H2000000T0n_3Vo`00001T000003D0n_3V0@3oool004h0n_3V1000003o0?[`iZ80n_3V
0@3oool00500n_3V0P00003o0?[`iZ80n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00j@3jl>H4000000<0n_3V0P0000000`3jl>H0
0000000000020?[`iP@00000303jl>H3000000@0n_3V2P0000040?[`iP<000000`3jl>H400000080
n_3V1@0000360?[`iP40oooo003Z0?[`iP800000103jl>H2000000040?[`iP00000000000?[`iP80
00000P3jl>H2000000X0n_3V0P0000020?[`iP030000003jl>H0n_3V0080000000<0n_3V00000000
00000P3jl>H2000000H0n_3V0`0000020?[`iP8000000`3jl>H010000000n_3V0000000000020?[`
iP800000a@3jl>H10?ooo`00jP3jl>H2000000@0n_3V0P000000103jl>H000000000003jl>H20000
0080n_3V0P0000090?[`iP8000001P3jl>H2000000030?[`iP00000000000080n_3V0P0000060?[`
iP030000003jl>H000000080n_3V0P0000070?[`iP@00000a@3jl>H10?ooo`00jP3jl>H2000000<0
n_3V0P0000000`3jl>H000000?[`iP0400000080n_3V0P0000090?[`iP8000001P3jl>H200000003
0?[`iP00000000000080n_3V0P0000050?[`iP80000000@0n_3V000000000000n_3V1P0000000`3j
l>H000000000000200000<L0n_3V0@3oool00>X0n_3V0P0000030?[`iP80000000<0n_3V0000003j
l>H0100000020?[`iP8000002@3jl>H2000000H0n_3V0P0000000`3jl>H00000000000020?[`iP<0
000000@0n_3V0000003jl>H0n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P000000
0`3jl>H00000000000020?[`iP800000a@3jl>H10?ooo`00j03jl>H01@000000n_3V000000000000
n_3V00D0000000<0n_3V0000000000001P00000:0?[`iP8000000`3jl>H00`000000n_3V00000002
000000040?[`iP00000000000?[`iP<0000000@0n_3V000000000000n_3V0`0000001@3jl>H00000
000000000000n_3V00@000000`3jl>H500000<D0n_3V0@3oool00>P0n_3V00H000000?[`iP000000
00000?[`iP00000H0?[`iP8000000P3jl>H00`000000n_3V0?[`iP3V0?[`iP40oooo003X0?[`iPH0
00006@3jl>H400000>P0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {237.313, 0}} -> {-1.05243, -0.643838, \
0.00421814, 0.00421814}, {{12.375, 486.563}, {163.688, 5.625}} -> {-4.7728, \
-2.71491, 0.0177844, 0.0177844}, {{59.8125, 225.75}, {226.875, 179.5}} -> \
{-1.31328, -0.655206, 0.0202638, 0.0531922}, {{68.75, 118.063}, {223.438, \
204.688}} -> {-2.73279, -2.60402, 0.03461, 0.112}, {{68.75, 118.063}, \
{201.625, 182.875}} -> {-2.73279, -5.04702, 0.03461, 0.112}}]
}, Open  ]],

Cell["\<\
By adjusting the AspectRatio of the key box graphics we can get the lines to \
actually fill the width of the boxes. Since the keys are often long and \
narrow, the default AspectRatio does not always work well. Click on the \
graphics above and below to see the difference.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowLegend[\[IndentingNewLine]DontShow[
          Graphics[\[IndentingNewLine]{Blue, 
              AbsoluteDashing[{4}], \[IndentingNewLine]Draw[
                Sin[x], {x, \(-3\), 3}], \[IndentingNewLine]OrangeRed, 
              AbsoluteDashing[{}], \[IndentingNewLine]ParametricDraw[
                2 {Sin[t], Sin[t] Cos[t]}, {t, 0, 
                  2  \[Pi]}]}], \[IndentingNewLine]Background \[Rule] 
            Linen, \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]ImageSize \[Rule] 
            500, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]PlotLabel \[Rule] "\<Two Curves\>"], \
\[IndentingNewLine]\[IndentingNewLine]{{{Graphics[{Red, 
                  Line[{{0, 0}, {1, 0}}]}, 
                AspectRatio \[Rule] 
                  0.3], "\<Figure Eight\>"}, {Graphics[{Blue, 
                  AbsoluteDashing[{4}], Line[{{0, 0}, {1, 0}}]}, 
                AspectRatio \[Rule] 
                  0.3], "\<Sine Wave\>"}}, \[IndentingNewLine]LegendPosition \
\[Rule] {\(-0.8\), \(-0.6\)}, \[IndentingNewLine]LegendSize \[Rule] {0.8, 
              0.2}, \[IndentingNewLine]LegendTextOffset \[Rule] {\(-1\), 
              0}, \[IndentingNewLine]LegendBackground \[Rule] 
            AliceBlue, \[IndentingNewLine]LegendShadow \[Rule] {0.02, \(-0.02\
\)}, \[IndentingNewLine]ShadowBackground \[Rule] 
            RoyalBlue}, \[IndentingNewLine]TextStyle \[Rule] {FontSize \
\[Rule] 12, FontWeight \[Rule] "\<Bold\>"}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47667 
%%ImageSize: 500 238.333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.47619 0.306587 0.47619 [
[ 0 0 0 0 ]
[ 1 .47667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.147857 0.97619 0.465317 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.15873 0.166667 0.15873 [
[.02381 -0.0125 -9.5625 -15.5625 ]
[.02381 -0.0125 9.5625 0 ]
[.18254 -0.0125 -9.5625 -15.5625 ]
[.18254 -0.0125 9.5625 0 ]
[.34127 -0.0125 -9.5625 -15.5625 ]
[.34127 -0.0125 9.5625 0 ]
[.5 -0.0125 -5.59375 -15.5625 ]
[.5 -0.0125 5.59375 0 ]
[.65873 -0.0125 -5.59375 -15.5625 ]
[.65873 -0.0125 5.59375 0 ]
[.81746 -0.0125 -5.59375 -15.5625 ]
[.81746 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -15.5625 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -19.125 -7.78125 ]
[-0.0125 .00794 0 7.78125 ]
[-0.0125 .0873 -33.5 -7.78125 ]
[-0.0125 .0873 0 7.78125 ]
[-0.0125 .16667 -11.1875 -7.78125 ]
[-0.0125 .16667 0 7.78125 ]
[-0.0125 .24603 -25.5625 -7.78125 ]
[-0.0125 .24603 0 7.78125 ]
[-0.0125 .3254 -11.1875 -7.78125 ]
[-0.0125 .3254 0 7.78125 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[.5 .34583 -37.9375 0 ]
[.5 .34583 37.9375 15.5625 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
gsave
-0.0125 .00794 -80.125 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .0873 m
.00625 .0873 L
s
gsave
-0.0125 .0873 -94.5 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .16667 m
.00625 .16667 L
s
gsave
-0.0125 .16667 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .24603 m
.00625 .24603 L
s
gsave
-0.0125 .24603 -86.5625 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .3254 m
.00625 .3254 L
s
gsave
-0.0125 .3254 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .07143 m
.00375 .07143 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .13492 m
.00375 .13492 L
s
0 .15079 m
.00375 .15079 L
s
0 .18254 m
.00375 .18254 L
s
0 .19841 m
.00375 .19841 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .2619 m
.00375 .2619 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.18254 .32708 m
.18254 .33333 L
s
.34127 .32708 m
.34127 .33333 L
s
.5 .32708 m
.5 .33333 L
s
.65873 .32708 m
.65873 .33333 L
s
.81746 .32708 m
.81746 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.05556 .32958 m
.05556 .33333 L
s
.0873 .32958 m
.0873 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.15079 .32958 m
.15079 .33333 L
s
.21429 .32958 m
.21429 .33333 L
s
.24603 .32958 m
.24603 .33333 L
s
.27778 .32958 m
.27778 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.37302 .32958 m
.37302 .33333 L
s
.40476 .32958 m
.40476 .33333 L
s
.43651 .32958 m
.43651 .33333 L
s
.46825 .32958 m
.46825 .33333 L
s
.53175 .32958 m
.53175 .33333 L
s
.56349 .32958 m
.56349 .33333 L
s
.59524 .32958 m
.59524 .33333 L
s
.62698 .32958 m
.62698 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.72222 .32958 m
.72222 .33333 L
s
.75397 .32958 m
.75397 .33333 L
s
.78571 .32958 m
.78571 .33333 L
s
.84921 .32958 m
.84921 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.9127 .32958 m
.9127 .33333 L
s
.94444 .32958 m
.94444 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .07143 m
1 .07143 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .13492 m
1 .13492 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .19841 m
1 .19841 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
gsave
.5 .34583 -98.9375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Two) show
91.750 15.000 moveto
(Curves) show
134.875 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ 4 ] 0 Mabsdash
.02381 .14427 m
.06244 .10705 L
.10458 .07055 L
.14415 .04235 L
.16408 .03097 L
.18221 .02247 L
.20178 .01541 L
.21254 .01249 L
.21738 .01141 L
.22272 .01039 L
.22739 .00964 L
.23241 .00899 L
.23518 .00869 L
.23772 .00846 L
.2403 .00828 L
.24269 .00814 L
.24488 .00804 L
.2461 .008 L
.24721 .00797 L
.24843 .00795 L
.24975 .00794 L
.251 .00794 L
.25214 .00794 L
.25322 .00796 L
.25423 .00798 L
.25533 .008 L
.25651 .00804 L
.25893 .00815 L
.26113 .00828 L
.26594 .00867 L
.27104 .00924 L
.28022 .01068 L
.29008 .01281 L
.30098 .01584 L
.32032 .02298 L
.34118 .03305 L
.38232 .05947 L
.42194 .09172 L
.46005 .12714 L
.50061 .16728 L
.53966 .20591 L
.58116 .24433 L
.62114 .27638 L
.6596 .3007 L
.67948 .31027 L
.68962 .3143 L
.70052 .31795 L
.71075 .32073 L
.7201 .32271 L
.72459 .32347 L
Mistroke
.72949 .32416 L
.73412 .32467 L
.73841 .32502 L
.74106 .32518 L
.7435 .32529 L
.74478 .32533 L
.74618 .32537 L
.74689 .32538 L
.74764 .32539 L
.74836 .32539 L
.749 .3254 L
.75028 .32539 L
.75146 .32538 L
.75275 .32536 L
.75341 .32534 L
.75413 .32532 L
.75663 .32523 L
.75897 .3251 L
.76365 .32475 L
.76794 .32431 L
.77759 .32289 L
.78742 .32085 L
.79655 .31842 L
.81727 .31108 L
.83777 .30139 L
.85637 .29066 L
.8964 .262 L
.93492 .22871 L
.97589 .18936 L
.97619 .18907 L
Mfstroke
1 .271 0 r
[ ] 0 Mabsdash
.5 .16667 m
.58004 .24412 L
.61998 .27775 L
.6403 .29252 L
.66127 .30558 L
.6802 .31502 L
.69665 .32104 L
.70429 .32304 L
.70851 .3239 L
.71236 .32452 L
.71567 .32493 L
.71753 .3251 L
.71927 .32523 L
.72108 .32533 L
.72273 .32538 L
.72461 .3254 L
.72639 .32537 L
.72821 .32531 L
.72922 .32525 L
.73016 .32519 L
.73186 .32504 L
.73364 .32484 L
.7367 .3244 L
.74 .32376 L
.74346 .32291 L
.7471 .3218 L
.75345 .31928 L
.75955 .31612 L
.76507 .31254 L
.77472 .30433 L
.78429 .29318 L
.79319 .27909 L
.79973 .26543 L
.80579 .24882 L
.80839 .23985 L
.81079 .23006 L
.81416 .21187 L
.81553 .20141 L
.81648 .19154 L
.81688 .18581 L
.81715 .18059 L
.81727 .17769 L
.81732 .17616 L
.81736 .17454 L
.81739 .17312 L
.81742 .17156 L
.81745 .16882 L
.81746 .16611 L
.81745 .16359 L
.81741 .16084 L
Mistroke
.81737 .1593 L
.81734 .1579 L
.81726 .15534 L
.81715 .15258 L
.81688 .14758 L
.81655 .1427 L
.81611 .13757 L
.81512 .12847 L
.81363 .11808 L
.81191 .10859 L
.80684 .08797 L
.80049 .06973 L
.79315 .05416 L
.7855 .04182 L
.77607 .03036 L
.76579 .02132 L
.75949 .01718 L
.75328 .01397 L
.74999 .01258 L
.74645 .01132 L
.74333 .01039 L
.73994 .00956 L
.7362 .00885 L
.73451 .0086 L
.73266 .00837 L
.73152 .00826 L
.73046 .00817 L
.72946 .0081 L
.72836 .00803 L
.72644 .00796 L
.72538 .00794 L
.72439 .00794 L
.72252 .00796 L
.72157 .00799 L
.72051 .00803 L
.71864 .00815 L
.71687 .00829 L
.71283 .00875 L
.70841 .00946 L
.70014 .01131 L
.69235 .01364 L
.67697 .01975 L
.66008 .02843 L
.62317 .05315 L
.58691 .08307 L
.50633 .16034 L
.42035 .24377 L
.3791 .27846 L
.36166 .29118 L
.34304 .3031 L
Mistroke
.32695 .31175 L
.31034 .31876 L
.3015 .32158 L
.29363 .32348 L
.28992 .32417 L
.28594 .32474 L
.28413 .32495 L
.28223 .32512 L
.28044 .32525 L
.27883 .32533 L
.27703 .32538 L
.27536 .3254 L
.27355 .32537 L
.27162 .3253 L
.27065 .32524 L
.26961 .32517 L
.26773 .325 L
.26425 .32455 L
.26102 .32398 L
.25765 .32321 L
.25176 .3214 L
.24523 .31867 L
.23937 .31547 L
.23328 .31132 L
.22699 .30599 L
.21706 .29497 L
.20789 .28105 L
.20061 .26624 L
.19492 .25104 L
.19216 .24189 L
.18956 .2316 L
.1876 .22225 L
.18588 .2121 L
.18463 .20278 L
.18408 .19778 L
.18359 .19237 L
.18322 .18738 L
.18295 .1828 L
.18285 .1806 L
.18275 .17819 L
.18268 .17606 L
.18262 .17381 L
.18259 .17247 L
.18257 .17101 L
.18254 .16843 L
.18254 .16698 L
.18254 .16543 L
.18255 .16396 L
.18257 .16263 L
.18261 .16004 L
Mistroke
.18264 .15858 L
.18268 .15723 L
.18287 .15214 L
.18311 .14763 L
.18345 .14269 L
.18438 .13276 L
.18574 .12216 L
.18762 .11101 L
.19211 .09165 L
.19794 .07373 L
.20584 .05605 L
.21473 .0415 L
.22419 .0301 L
.2296 .02499 L
.2358 .02018 L
.24156 .01658 L
.24792 .01344 L
.25392 .0112 L
.25742 .01019 L
.26076 .00941 L
.26389 .00884 L
.26678 .00844 L
.2684 .00827 L
.27017 .00812 L
.27187 .00802 L
.27344 .00796 L
.27518 .00794 L
.27701 .00795 L
.2786 .008 L
.28034 .00808 L
.28224 .00821 L
.28428 .0084 L
.288 .00887 L
.29183 .0095 L
.29549 .01025 L
.30246 .01203 L
.31907 .018 L
.33795 .02732 L
.37501 .05177 L
.41659 .08619 L
.49493 .16159 L
.5 .16667 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
.255 .412 .882 r
.12857 .01135 m
.12857 .10659 L
.50952 .10659 L
.50952 .01135 L
F
.941 .973 1 r
.11905 .02087 m
.11905 .11611 L
.5 .11611 L
.5 .02087 L
F
0 g
.001 w
[ ] 0 setdash
.11905 .02087 m
.5 .02087 L
.5 .11611 L
.11905 .11611 L
.11905 .02087 L
s
% Start of sub-graphic
p
0.119048 0.020873 0.5 0.116111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.00992063 0.0992063 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0178571 0.35119 0.117063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.15 0.142857 [
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ 4 ] 0 Mabsdash
.02381 .15 m
.97619 .15 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .06746 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sine) show
99.313 15.000 moveto
(Wave) show
128.063 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.132937 0.35119 0.232143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.15 0.142857 [
[ 0 0 0 0 ]
[ 1 .3 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3 L
0 .3 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.02381 .15 m
.97619 .15 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .18254 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Figure) show
113.313 15.000 moveto
(Eight) show
149.250 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .47667 L
0 .47667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 238.313},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000kR000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00@03jl>Jn045YhOD0
n_3V0@3oool00400n_3V_P11JN7e0?[`iP40oooo00100?[`i[h0@FWQm@3jl>H10?ooo`00@03jl>Jn
045YhOD0n_3V0@3oool003/0n_3V_`000004045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`
nOl0^`3`nOl00`000000@FWQ045Yh@02045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0
^`3`nOl00`000000@FWQ045Yh@02045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0^`3`
nOl00`000000@FWQ045Yh@02045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0^`3`nOl0
0`000000@FWQ045Yh@02045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0^`3`nOl00`00
0000@FWQ045Yh@02045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0^`3`nOl00`000000
@FWQ045Yh@02045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0^`3`nOl00`000000@FWQ
045Yh@02045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0^`3`nOl00`000000@FWQ045Y
h@02045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0^`3`nOl00`000000@FWQ045Yh@02
045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0B@3`nOl500000080l?Wo1P0000001@3`
nOl00000000000000000l?Wo00<0000000<0l?Wo0000000000000P00000<0?3io`80000000<0l?Wo
0000000000000P3`nOl600000080l?Wo0`0000030?3io`@00000<`3`nOl00`000000@FWQ045Yh@02
045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0B@3`nOl010000000l?Wo0?3io`3`nOl2
000000<0l?Wo0P0000040?3io`80000000@0l?Wo000000000000l?Wo0P0000030?3io`030000003`
nOl0l?Wo00T0l?Wo0P000000103`nOl000000000003`nOl200000080l?Wo0P0000030?3io`<00000
0P3`nOl2000000<0l?Wo00<000000?3io`3`nOl0<03`nOl00`000000@FWQ045Yh@02045YhOD0n_3V
0@3oool003/0n_3V00<000000?3io`3`nOl02@3`nOl50000o`<0l?Wo1@000?l30?3io`D0003o0`3`
nOl50000o`<0l?Wo1@000?l30?3io`D0003o0`3`nOl50000o`l0l?Wo0P0000030?3io`800000103`
nOl2000000040?3io`00000000000?3io`8000003`3`nOl2000000040?3io`00000000000?3io`80
00000P3`nOl2000000<0l?Wo00<000000?3io`0000000P3`nOl2000003H0l?Wo00<00000045Yh@11
JN400P11JN7e0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo04/0l?Wo0`0000040?3io`800000
103`nOl2000000040?3io`00000000000?3io`H000002`3`nOl2000000030?3io`00000000000080
l?Wo1@0000020?3io`80000000@0l?Wo000000000000l?Wo1P00000b0?3io`0300000011JN40@FWQ
0080@FWQm@3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`1:0?3io`<000001@3`nOl2000000@0
l?Wo0P000000103`nOl000000000003`nOl200000080l?Wo0P00000;0?3io`050000003`nOl00000
0?3io`0000001@3`nOl200000080l?Wo0P000000103`nOl000000000003`nOl200000080l?Wo0P00
000b0?3io`0300000011JN40@FWQ0080@FWQm@3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`19
0?3io`8000001@3`nOl4000000<0l?Wo1@0000030?3io`@000002`3`nOl2000000030?3io`000000
l?Wo0080000000<0l?Wo0000000000000P0000020?3io`<0000000D0l?Wo00000000000000000?3i
o`04000003<0l?Wo00<00000045Yh@11JN400P11JN7e0?[`iP40oooo000k0?[`iP030000003`nOl0
l?Wo04T0l?Wo0P0000030?3io`030000003`nOl0l?Wo01d0l?Wo0P0000030?3io`800000AP3`nOl0
0`000000@FWQ045Yh@02045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0BP3`nOl50000
00<0l?Wo0P00000I0?3io`@0000000<0l?Wo0000000000000P0000150?3io`0300000011JN40@FWQ
0080@FWQm@3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2k0?3io`0300000011JN40@FWQ0080
@FWQm@3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2k0?3io`0300000011JN40@FWQ0080@FWQ
m@3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2k0?3io`0300000011JN40@FWQ0080@FWQm@3j
l>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2k0?3io`0300000011JN40@FWQ0080@FWQm@3jl>H1
0?ooo`00>`3jl>H00`000000l?Wo0?3io`2k0?3io`0300000011JN40@FWQ0080@FWQm@3jl>H10?oo
o`00>`3jl>H00`000000l?Wo0?3io`2k0?3io`0300000011JN40@FWQ0080@FWQm@3jl>H10?ooo`00
>`3jl>H00`000000l?Wo0?3io`2k0?3io`0300000011JN40@FWQ0080@FWQm@3jl>H10?ooo`00>`3j
l>H00`000000l?Wo0?3io`2k0?3io`0300000011JN40@FWQ0080@FWQm@3jl>H10?ooo`00>`3jl>H0
0`000000l?Wo0?3io`2k0?3io`0300000011JN40@FWQ0080@FWQm@3jl>H10?ooo`00>`3jl>H00`00
0000l?Wo0?3io`2k0?3io`0300000011JN40@FWQ0080@FWQm@3jl>H10?ooo`00>`3jl>H00`000000
l?Wo0?3io`2k0?3io`0300000011JN40@FWQ0080@FWQm@3jl>H10?ooo`00>`3jl>H00`000000l?Wo
0?3io`2k0?3io`0300000011JN40@FWQ0080@FWQm@3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3i
o`1H0?3io`@00000;`3`nOl4000002`0l?Wo00<00000045Yh@11JN400P11JN7e0?[`iP40oooo000k
0?[`iP030000003`nOl0l?Wo05/0l?Wo0P00000a0?3io`800000:`3`nOl00`000000@FWQ045Yh@02
045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0B03`nOl5000000<0l?Wo1P0000020?3i
o`80000000<0l?Wo0000000000000`3`nOl:000000<0l?Wo1000000:0?3io`L0000000<0l?Wo0000
00000000100000020?3io`80000000@0l?Wo000000000000l?Wo0`000000103`nOl0000000000000
00020?3io`<000007P3`nOl00`000000@FWQ045Yh@02045YhOD0n_3V0@3oool003/0n_3V00<00000
0?3io`3`nOl0B@3`nOl2000000L0l?Wo0P0000030?3io`80000000@0l?Wo00000000000000000P3`
nOl2000000030?3io`00000000000080l?Wo0P0000040?3io`8000000`3`nOl00`000000l?Wo0?3i
o`080?3io`8000000`3`nOl010000000l?Wo0?3io`3`nOl2000000<0l?Wo0P000000103`nOl00000
0000000000020?3io`80000000<0l?Wo0000000000000P3`nOl200000080l?Wo00<000000?3io`3`
nOl06`3`nOl00`000000@FWQ045Yh@02045YhOD0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0
2@3`nOlg0?l000T0l?Wo0P0000070?3io`8000000`3`nOl200000080l?Wo0P0000020?3io`800000
00<0l?Wo0000000000000P3`nOl2000000@0l?Wo0P00000>0?3io`8000000`3`nOl010000000l?Wo
0?3io`3`nOl2000000<0l?Wo0P0000020?3io`8000000P3`nOl2000000030?3io`00000000000080
l?Wo0P00000P0?3io`0300000011JN40@FWQ0080@FWQm@3jl>H10?ooo`00>`3jl>H00`000000l?Wo
0?3io`190?3io`80000000<0l?Wo0000003`nOl0103`nOl2000000<0l?Wo0P0000020?3io`800000
0P3`nOl2000000030?3io`00000000000080l?Wo0P0000040?3io`H000002P3`nOl2000000030?3i
o`000000l?Wo00@0l?Wo0P0000030?3io`8000000P3`nOl200000080l?Wo0P0000000`3`nOl00000
000000020?3io`800000803`nOl00`000000@FWQ045Yh@02045YhOD0n_3V0@3oool003/0n_3V00<0
00000?3io`3`nOl0B@3`nOl4000000D0l?Wo0P0000030?3io`80000000@0l?Wo0000000000000000
0P3`nOl2000000030?3io`00000000000080l?Wo0`0000000`3`nOl000000?3io`0200000080l?Wo
0P00000:0?3io`@000001@3`nOl2000000<0l?Wo0P000000103`nOl000000000000000020?3io`80
000000<0l?Wo0000000000000P3`nOl200000200l?Wo00<00000045Yh@11JN400P11JN7e0?[`iP40
oooo000k0?[`iP030000003`nOl0l?Wo04T0l?Wo0P0000001@3`nOl000000?3io`000000l?Wo00@0
0000103`nOl2000000030?3io`000000000000@0000000@0l?Wo000000000000l?Wo0`0000000`3`
nOl00000000000020?3io`@000002`3`nOl2000000050?3io`000000l?Wo0000003`nOl010000004
0?3io`80000000D0l?Wo00000000000000000?3io`0400000080l?Wo1@00000N0?3io`0300000011
JN40@FWQ0080@FWQm@3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`190?3io`8000000`3`nOl0
0`000000l?Wo0?3io`0[0?3io`8000000`3`nOl00`000000l?Wo0?3io`0>0?3io`8000001@3`nOl2
00000200l?Wo00<00000045Yh@11JN400P11JN7e0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo
04P0l?Wo1`0000030?3io`8000009`3`nOl7000000<0l?Wo0P00000:0?3io`<000001@3`nOl20000
0200l?Wo00<00000045Yh@11JN400P11JN7e0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0;/0
l?Wo00<00000045Yh@11JN400P11JN7e0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0;/0l?Wo
00<00000045Yh@11JN400P11JN7e0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0;/0l?Wo00<0
0000045Yh@11JN400P11JN7e0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0;/0l?Wo00<00000
0?[`iP3jl>H0m`3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2k0?3io`030000003jl>H0n_3V
0?L0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0^`3`nOl00`000000n_3V0?[`iP3g0?[`iP40
oooo000k0?[`iP030000003`nOl0l?Wo0;/0l?Wo00<000000?[`iP3jl>H0m`3jl>H10?ooo`00>`3j
l>Jo00000?T0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo001V
0?[`iP<00000=03jl>H5000003<0n_3V1P00000_0?[`iP<00000=@3jl>H600000380n_3V1@00000d
0?[`iP<00000?@3jl>H10?ooo`00I@3jl>H00`000000n_3V0?[`iP02000003<0n_3V0P00000h0?[`
iP800000<03jl>H2000000030?[`iP000000000003H0n_3V0P00000d0?[`iP800000=P3jl>H00`00
0000n_3V0?[`iP02000003`0n_3V0@3oool005d0n_3V1@0000060?[`iP800000:`3jl>H5000000@0
n_3V0P00000]0?[`iPD000001@3jl>H200000300n_3V0P0000000`3jl>H000000000000f0?[`iP80
0000=@3jl>H2000003P0n_3V0P00000l0?[`iP40oooo001X0?[`iP800000=@3jl>H2000003H0n_3V
0P00000`0?[`iP80000000<0n_3V000000000000=P3jl>H2000003H0n_3V0P00000g0?[`iP800000
?03jl>H10?ooo`00IP3jl>H3000003L0n_3V0P00000e0?[`iP800000<03jl>H2000000030?[`iP00
0000000003H0n_3V0P00000g0?[`iP800000=03jl>H3000003d0n_3V0@3oool006P0n_3V0P00000c
0?[`iP80000000<0n_3V000000000000=@3jl>H200000300n_3V0P0000000`3jl>H000000000000f
0?[`iP800000=03jl>H2000000030?[`iP000000000003H0n_3V0P00000l0?[`iP40oooo001U0?[`
iP030000003jl>H0n_3V00800000<`3jl>H2000000030?[`iP000000000003<0n_3V1000000`0?[`
iP80000000<0n_3V000000000000=03jl>H4000003@0n_3V0P0000000`3jl>H000000000000c0?[`
iP030000003jl>H0n_3V00800000?03jl>H10?ooo`00IP3jl>H3000003D0n_3V0`00000f0?[`iP80
0000<@3jl>H3000003L0n_3V0P00000e0?[`iP<00000=@3jl>H3000003d0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00CP3jl>H6
000000L0n_3Vo`00001T000003D0n_3V0@3oool00500n_3V0P0000090?[`iP030000003jl>H0n_3V
00D0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00T0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo00160?[`iPD0
00001@3jl>H2000000T0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0e0?[`iP03
0000003jl>H0n_3V03H0n_3V00<000000?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP0e0?[`iP03
0000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP050?[`iP03
0000003jl>H0n_3V03<0n_3V0@3oool00500n_3V0P0000090?[`iP<00000C`3jl>H50000o`<0n_3V
00<0003o0?m5003oA@003@3oA@2@0?[`iPh0odD0F03jl>H3000003D0n_3V0@3oool00500n_3V0P00
00090?[`iP030000003jl>H0n_3V04L0n_3V1@000?l;0?[`iP030?m5003jl>H0n_3V00H0n_3V1000
0?l30?[`iP<0odD0RP3jl>H30?m500h0n_3V0P3oA@1H0?[`iP030000003jl>H0n_3V03<0n_3V0@3o
ool00500n_3V0P0000090?[`iP030000003jl>H0n_3V05@0n_3V0`3oA@0@0?[`iP030000o`3jl>H0
n_3V00<0odD0Q03jl>H30?m501<0n_3V0P3oA@1F0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool0
04h0n_3V100000090?[`iP030000003jl>H0n_3V04<0n_3V0P000?l=0?[`iP80odD0503jl>H20000
o`<0n_3V0P3oA@200?[`iP80odD0603jl>H20?m505@0n_3V00<000000?[`iP3jl>H0<`3jl>H10?oo
o`00D03jl>H2000000T0n_3V00<000000?[`iP3jl>H0@03jl>H30000o`d0n_3V0P3oA@0H0?[`iP80
003o0`3jl>H20?m507`0n_3V0P3oA@0L0?[`iP80odD0DP3jl>H00`000000n_3V0?[`iP0c0?[`iP40
oooo001K0?[`iP800000?@3jl>H00`000?l0n_3V0?[`iP0@0?[`iP030?m5003jl>H0n_3V01`0n_3V
00<0003o0?[`iP3jl>H00P3oA@1h0?[`iP80odD0803jl>H00`3oA@00n_3V0?[`iP1>0?[`iP800000
=@3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0j0?[`iP80003o4P3jl>H00`3oA@00n_3V0?[`
iP0N0?[`iP80003o0P3jl>H20?m507@0n_3V0P3oA@0S0?[`iP030?m5003jl>H0n_3V04h0n_3V00<0
00000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0h0?[`iP80003o4P3jl>H2
0?m502<0n_3V0P000?l20?[`iP80odD0L03jl>H20?m502H0n_3V00<0odD00?[`iP3jl>H0C@3jl>H0
0`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04/0n_3V00<0odD00?[`
iP3jl>H0:@3jl>H00`3oA@00n_3V0?[`iP1[0?[`iP80odD0:@3jl>H00`3oA@00n_3V0?[`iP1<0?[`
iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0=@3jl>H00`000?l0
n_3V0?[`iP0C0?[`iP030?m5003jl>H0n_3V02P0n_3V00@0003o0?[`iP3oA@00odD0JP3jl>H00`3o
A@00n_3V0?[`iP0Z0?[`iP030?m5003jl>H0n_3V04/0n_3V00<000000?[`iP3jl>H0<`3jl>H10?oo
o`00F`3jl>H00`000000n_3V0?[`iP0c0?[`iP80003o5@3jl>H00`3oA@00n_3V0?[`iP0Z0?[`iP80
003o00<0n_3V0?m5003jl>H0IP3jl>H20?m502d0n_3V00<0odD00?[`iP3jl>H0B`3jl>H00`000000
n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP800000<P3jl>H20000oaL0n_3V00<0odD00?[`iP3jl>H0
;03jl>H010000?l0n_3V0?m5003oA@1T0?[`iP030?m5003jl>H0n_3V02h0n_3V00<0odD00?[`iP3j
l>H0B@3jl>H2000003D0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0B@3jl>H00`3oA@00n_3V
0?[`iP0a0?[`iP80odD0H@3jl>H00`3oA@00n_3V0?[`iP0`0?[`iP030?m5003jl>H0n_3V04T0n_3V
00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0^0?[`iP030000o`3j
l>H0n_3V01L0n_3V00<0odD00?[`iP3jl>H0<@3jl>H010000?l0n_3V0?[`iP3oA@1N0?[`iP80odD0
=03jl>H00`3oA@00n_3V0?[`iP180?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<0
00000?[`iP3jl>H0;03jl>H20000oaX0n_3V00<0odD00?[`iP3jl>H0<P3jl>H20000o`030?[`iP3o
A@00odD005/0n_3V00<0odD00?[`iP3jl>H0=03jl>H00`3oA@00n_3V0?[`iP180?[`iP030000003j
l>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0:`3jl>H00`000?l0n_3V0?[`iP0I
0?[`iP030?m5003jl>H0n_3V03D0n_3V0P000?l00`3jl>H0odD00?[`iP1G0?[`iP80odD0>03jl>H0
0`3oA@00n_3V0?[`iP170?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V0P0000180?[`
iP030?m5003jl>H0n_3V03T0n_3V00<0odD00?[`iP3jl>H0E03jl>H00`3oA@00n_3V0?[`iP0i0?[`
iP030?m5003jl>H0n_3V04D0n_3V0P00000e0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04H0
n_3V00<0odD00?[`iP3jl>H0>P3jl>H00`000?l0odD00?[`iP1C0?[`iP030?m5003jl>H0n_3V03X0
n_3V00<0odD00?[`iP3jl>H0AP3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000
003jl>H0n_3V02P0n_3V00<0003o0?[`iP3jl>H06P3jl>H00`3oA@00n_3V0?[`iP0l0?[`iP030000
o`3oA@00odD00500n_3V0P3oA@0n0?[`iP030?m5003jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0V0?[`iP80003o7@3jl>H00`3oA@00n_3V0?[`
iP0m0?[`iP030000o`3jl>H0odD004h0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`3oA@00n_3V0?[`
iP150?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0903jl>H2
0000oah0n_3V00<0odD00?[`iP3jl>H0?`3jl>H00`000?l0n_3V0?m5001<0?[`iP030?m5003jl>H0
n_3V03l0n_3V00<0odD00?[`iP3jl>H0A@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`
iP030000003jl>H0n_3V04@0n_3V00<0odD00?[`iP3jl>H0@P3jl>H00`3oA@00n_3V0?[`iP170?[`
iP80odD0@`3jl>H00`3oA@00n_3V0?[`iP140?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0
n_3V0P00000R0?[`iP030000o`3jl>H0n_3V01l0n_3V00<0odD00?[`iP3jl>H0@`3jl>H00`000?l0
odD00?[`iP160?[`iP030?m5003jl>H0n_3V04<0n_3V00<0odD00?[`iP3jl>H0@`3jl>H2000003D0
n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0803jl>H00`000?l0n_3V0?[`iP0P0?[`iP030?m5
003jl>H0n_3V04@0n_3V00<0003o0?m5003jl>H0A03jl>H00`3oA@00n_3V0?[`iP140?[`iP030?m5
003jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`
iP0O0?[`iP030000o`3jl>H0n_3V0240n_3V00<0odD00?[`iP3jl>H0A@3jl>H00`000?l0odD00?m5
00110?[`iP80odD0B03jl>H00`3oA@00n_3V0?[`iP130?[`iP030000003jl>H0n_3V03<0n_3V0@3o
ool005/0n_3V00<000000?[`iP3jl>H07P3jl>H00`000?l0n_3V0?[`iP0Q0?[`iP030?m5003jl>H0
n_3V04P0n_3V00<0003o0?m5003jl>H0?P3jl>H00`3oA@00n_3V0?[`iP180?[`iP030?m5003jl>H0
n_3V04<0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00@@3jl>H3000000@0n_3V0P0000050?[`
iP<000002@3jl>H00`000000n_3V0?[`iP120?[`iP030?m5003jl>H0n_3V04X0n_3V00<0odD00?[`
iP3jl>H0>`3jl>H00`3oA@00n_3V0?[`iP1:0?[`iP030?m5003jl>H0n_3V0480n_3V00<000000?[`
iP3jl>H0<`3jl>H10?ooo`00@03jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP03
0000003jl>H0n_3V00800000203jl>H00`000000n_3V0?[`iP120?[`iP030?m5003jl>H0n_3V04/0
n_3V00<0odD00?[`iP3jl>H0>@3jl>H00`3oA@00n_3V0?[`iP1;0?[`iP030?m5003jl>H0n_3V0480
n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00>03jl>H5000000<0n_3V0P0000000`3jl>H00000
0000000<0?[`iP800000203jl>H3000001/0n_3V00<0003o0?[`iP3jl>H08`3jl>H00`3oA@00n_3V
0?[`iP1=0?[`iP030?m5003jl>H0n_3V03L0n_3V00<0odD00?[`iP3jl>H0C@3jl>H00`3oA@00n_3V
0?[`iP0o0?[`iP<00000=@3jl>H10?ooo`00@03jl>H2000000030?[`iP000000000000`0n_3V0P00
00080?[`iP030000003jl>H0n_3V01T0n_3V0P000?lV0?[`iP030?m5003jl>H0n_3V04h0n_3V00<0
odD00?[`iP3jl>H0=@3jl>H00`3oA@00n_3V0?[`iP1>0?[`iP030?m5003jl>H0n_3V0440n_3V00<0
00000?[`iP3jl>H0<`3jl>H10?ooo`00@03jl>H2000000030?[`iP000000000000T0n_3V00<00000
0?[`iP3jl>H00P0000080?[`iP030000003jl>H0n_3V01P0n_3V00<0003o0?[`iP3jl>H09P3jl>H0
0`3oA@00n_3V0?[`iP1?0?[`iP030?m5003jl>H0n_3V03<0n_3V00<0odD00?[`iP3jl>H0C`3jl>H0
0`3oA@00n_3V0?[`iP110?[`iP030000003jl>H0n_3V03<0n_3V0@3oool00400n_3V0P0000000`3j
l>H00000000000090?[`iP@000002@3jl>H00`000000n_3V0?[`iP100?[`iP030?m5003jl>H0n_3V
0540n_3V00<0odD00?[`iP3jl>H0<@3jl>H00`3oA@00n_3V0?[`iP1@0?[`iP030?m5003jl>H0n_3V
0440n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00@03jl>H2000000030?[`iP000000000000T0
n_3V0P00000;0?[`iP030000003jl>H0n_3V0400n_3V00<0odD00?[`iP3jl>H0DP3jl>H00`3oA@00
n_3V0?[`iP0_0?[`iP030?m5003jl>H0n_3V0580n_3V00<0odD00?[`iP3jl>H0@03jl>H00`000000
n_3V0?[`iP0c0?[`iP40oooo00110?[`iP<000002P3jl>H5000000P0n_3V0P00000F0?[`iP030000
o`3jl>H0n_3V02P0n_3V00<0odD00?[`iP3jl>H0D`3jl>H00`3oA@00n_3V0?[`iP0]0?[`iP030?m5
003jl>H0n_3V05<0n_3V00<0odD00?[`iP3jl>H0?`3jl>H2000003D0n_3V0@3oool005/0n_3V00<0
00000?[`iP3jl>H0503jl>H00`000?l0n_3V0?[`iP0Y0?[`iP030?m5003jl>H0n_3V05@0n_3V00<0
odD00000o`3jl>H0:`3jl>H00`3oA@00n_3V0?[`iP1D0?[`iP030?m5003jl>H0n_3V0400n_3V00<0
00000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0C0?[`iP030000o`3jl>H0
n_3V02T0n_3V00<0odD00?[`iP3jl>H0EP3jl>H00`3oA@00003o0?[`iP0Y0?[`iP030?m5003jl>H0
n_3V05D0n_3V00<0odD00?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`
iP030000003jl>H0n_3V0180n_3V00<0003o0?[`iP3jl>H0:P3jl>H00`3oA@00n_3V0?[`iP1G0?[`
iP030?m5003jl>H0n_3V02L0n_3V00<0odD00?[`iP3jl>H0EP3jl>H00`3oA@00n_3V0?[`iP100?[`
iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3oA@00
n_3V0?[`iP1H0?[`iP030?m5003jl>H0n_3V02D0n_3V00<0odD00?[`iP3jl>H0E`3jl>H00`3oA@00
n_3V0?[`iP100?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0
3`3jl>H00`000?l0n_3V0?[`iP0]0?[`iP030?m5003jl>H0n_3V05T0n_3V00<0odD00?[`iP3jl>H0
8`3jl>H00`3oA@00n_3V0?[`iP1I0?[`iP030?m5003jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00F`3jl>H2000000l0n_3V00<0003o0?[`iP3jl>H0;P3jl>H00`3oA@00n_3V0?[`
iP1J0?[`iP030?m5003jl>H0n_3V0240n_3V00<0odD00?[`iP3jl>H0FP3jl>H00`3oA@00n_3V0?[`
iP0n0?[`iP800000=@3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0=0?[`iP030000o`3jl>H0
n_3V02l0n_3V00<0odD00?[`iP3jl>H0F`3jl>H00`3oA@00n_3V0?[`iP0N0?[`iP80odD0G@3jl>H0
0`3oA@00n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`
iP3jl>H0303jl>H00`000?l0n_3V0?[`iP0`0?[`iP030?m5003jl>H0n_3V05`0n_3V0P3oA@0M0?[`
iP030?m5003jl>H0n_3V05h0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`
iP40oooo001K0?[`iP030000003jl>H0n_3V03h0n_3V00<0odD00?[`iP3jl>H0G`3jl>H00`3oA@00
n_3V0?[`iP0I0?[`iP030?m5003jl>H0n_3V05l0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000
n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V03h0n_3V00<0odD00?[`iP3jl>H0
H03jl>H00`3oA@00n_3V0?[`iP0G0?[`iP030?m5003jl>H0n_3V0600n_3V00<0odD00?[`iP3jl>H0
?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V00T0n_3V00<0
003o0?[`iP3jl>H0<P3jl>H00`3oA@00n_3V0?[`iP1Q0?[`iP030?m5003jl>H0n_3V01D0n_3V00<0
odD00?[`iP3jl>H0H@3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3o
ool005/0n_3V0P0000090?[`iP030000o`3jl>H0n_3V03<0n_3V00<0odD00?[`iP3jl>H0HP3jl>H0
0`3oA@00n_3V0?[`iP0C0?[`iP030?m5003jl>H0n_3V0680n_3V00<0odD00?[`iP3jl>H0?@3jl>H2
000003D0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP0d0?[`
iP030?m5003jl>H0n_3V06<0n_3V00<0odD00?[`iP3jl>H04@3jl>H00`3oA@00n_3V0?[`iP1S0?[`
iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000
n_3V0?[`iP060?[`iP030000o`3jl>H0n_3V03D0n_3V00<0odD00?[`iP3jl>H0I03jl>H00`3oA@00
n_3V0?[`iP0?0?[`iP030?m5003jl>H0n_3V06@0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000
n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V03h0n_3V00<0odD00?[`iP3jl>H0
I@3jl>H00`3oA@00n_3V0?[`iP0=0?[`iP030?m5003jl>H0n_3V06D0n_3V00<0odD00?[`iP3jl>H0
?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V03h0n_3V00<0
odD00?[`iP3jl>H0IP3jl>H00`3oA@00n_3V0?[`iP0;0?[`iP030?m5003jl>H0n_3V06H0n_3V00<0
odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP800000?`3jl>H0
0`3oA@00n_3V0?[`iP1W0?[`iP030?m5003jl>H0n_3V00T0n_3V00<0odD00?[`iP3jl>H0I`3jl>H0
0`3oA@00n_3V0?[`iP0m0?[`iP800000=@3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0n0?[`
iP030?m5003jl>H0n_3V06P0n_3V00<0odD00?[`iP3jl>H01`3jl>H00`3oA@00n_3V0?[`iP1X0?[`
iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000
n_3V0?[`iP0m0?[`iP030?m5003jl>H0n_3V06X0n_3V00<0odD00?[`iP3jl>H01@3jl>H00`3oA@00
n_3V0?[`iP1Y0?[`iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00
F`3jl>H00`000000n_3V0?[`iP0m0?[`iP030?m5003jl>H0n_3V06/0n_3V00<0odD00?[`iP3jl>H0
0`3jl>H00`3oA@00n_3V0?[`iP1Z0?[`iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00C`3jl>H3000000T0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3oA@00n_3V0?[`
iP1/0?[`iP050?m5003jl>H0n_3V0?[`iP3oA@00K@3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000
003jl>H0n_3V03<0n_3V0@3oool004h0n_3V0P0000000`3jl>H00000000000080?[`iP030000003j
l>H0n_3V03d0n_3V00<0odD00?[`iP3jl>H0K@3jl>H00`3oA@00n_3V0?m5001^0?[`iP030?m5003j
l>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00CP3jl>H2000000030?[`iP000000
000000P0n_3V0`00000m0?[`iP030?m5003jl>H0n_3V06h0n_3V00<0odD00?[`iP3jl>H0K@3jl>H0
0`3oA@00n_3V0?[`iP0l0?[`iP<00000=@3jl>H10?ooo`00CP3jl>H2000000030?[`iP0000000000
00P0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3oA@00n_3V0?[`iP1]0?[`iP030?m5003jl>H0odD0
06h0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001>0?[`iP80
000000<0n_3V000000000000203jl>H00`000000n_3V0?[`iP0m0?[`iP030?m5003jl>H0n_3V06`0
n_3V00D0odD00?[`iP3jl>H0n_3V0?m5001]0?[`iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`
iP3jl>H0<`3jl>H10?ooo`00CP3jl>H2000000030?[`iP000000000000P0n_3V00<000000?[`iP3j
l>H0?@3jl>H00`3oA@00n_3V0?[`iP1[0?[`iP030?m5003jl>H0n_3V00<0n_3V00<0odD00?[`iP3j
l>H0JP3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool004h0n_3V
0P0000000`3jl>H00000000000080?[`iP030000003jl>H0n_3V03d0n_3V00<0odD00?[`iP3jl>H0
JP3jl>H00`3oA@00n_3V0?[`iP050?[`iP030?m5003jl>H0n_3V06T0n_3V00<0odD00?[`iP3jl>H0
?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001?0?[`iP<000002@3jl>H2000003l0n_3V00<0
odD00?[`iP3jl>H0J03jl>H00`3oA@00n_3V0?[`iP070?[`iP030?m5003jl>H0n_3V06P0n_3V00<0
odD00?[`iP3jl>H0?@3jl>H2000003D0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?P3jl>H0
0`3oA@00n_3V0?[`iP1W0?[`iP030?m5003jl>H0n_3V00T0n_3V00<0odD00?[`iP3jl>H0I`3jl>H0
0`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`
iP3jl>H0?P3jl>H00`3oA@00n_3V0?[`iP1V0?[`iP030?m5003jl>H0n_3V00/0n_3V00<0odD00?[`
iP3jl>H0IP3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0
n_3V00<000000?[`iP3jl>H0?P3jl>H00`3oA@00n_3V0?[`iP1U0?[`iP030?m5003jl>H0n_3V00d0
n_3V00<0odD00?[`iP3jl>H0I@3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0
n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?P3jl>H00`3oA@00n_3V0?[`iP1T0?[`iP030?m5
003jl>H0n_3V00l0n_3V00<0odD00?[`iP3jl>H0I03jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000
003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?P3jl>H00`3oA@00n_3V0?[`
iP1S0?[`iP030?m5003jl>H0n_3V0140n_3V00<0odD00?[`iP3jl>H0H`3jl>H00`3oA@00n_3V0?[`
iP0c0?[`iP030000o`3jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H2
000003l0n_3V00<0odD00?[`iP3jl>H0HP3jl>H00`3oA@00n_3V0?[`iP0C0?[`iP030?m5003jl>H0
n_3V0680n_3V00<0odD00?[`iP3jl>H0<P3jl>H00`000?l0n_3V0?[`iP080?[`iP800000=@3jl>H1
0?ooo`00F`3jl>H00`000000n_3V0?[`iP0n0?[`iP030?m5003jl>H0n_3V0640n_3V00<0odD00?[`
iP3jl>H05@3jl>H00`3oA@00n_3V0?[`iP1Q0?[`iP030?m5003jl>H0n_3V0340n_3V00<0003o0?[`
iP3jl>H02P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V03h0
n_3V00<0odD00?[`iP3jl>H0G`3jl>H20?m501T0n_3V00<0odD00?[`iP3jl>H0H03jl>H00`3oA@00
n_3V0?[`iP0`0?[`iP030000o`3jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00
F`3jl>H00`000000n_3V0?[`iP0n0?[`iP030?m5003jl>H0n_3V05h0n_3V00<0odD00?[`iP3jl>H0
6P3jl>H20?m505l0n_3V00<0odD00?[`iP3jl>H0?`3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo
001K0?[`iP030000003jl>H0n_3V03l0n_3V00<0odD00?[`iP3jl>H0G03jl>H00`3oA@00n_3V0?[`
iP0M0?[`iP030?m5003jl>H0n_3V05`0n_3V00<0odD00?[`iP3jl>H0?`3jl>H00`000000n_3V0?[`
iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V03l0n_3V00<0odD00?[`iP3jl>H0F`3jl>H0
0`3oA@00n_3V0?[`iP0N0?[`iP030000o`3oA@00n_3V05`0n_3V00<0odD00?[`iP3jl>H0;`3jl>H0
0`000?l0n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V0P0000100?[`
iP030?m5003jl>H0n_3V05X0n_3V00<0odD00?[`iP3jl>H0803jl>H00`000?l0odD00?[`iP1K0?[`
iP030?m5003jl>H0n_3V02d0n_3V0P000?l?0?[`iP800000=@3jl>H10?ooo`00F`3jl>H00`000000
n_3V0?[`iP0o0?[`iP030?m5003jl>H0n_3V05T0n_3V00<0odD00?[`iP3jl>H08`3jl>H00`3oA@00
n_3V0?[`iP1I0?[`iP030?m5003jl>H0n_3V02`0n_3V00<0003o0?[`iP3jl>H0403jl>H00`000000
n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V03l0n_3V00<0odD00?[`iP3jl>H0
F03jl>H00`3oA@00n_3V0?[`iP0U0?[`iP030?m5003jl>H0n_3V05L0n_3V00<0odD00?[`iP3jl>H0
@03jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V03l0n_3V00<0
odD00?[`iP3jl>H0E`3jl>H00`3oA@00n_3V0?[`iP0W0?[`iP030?m5003jl>H0n_3V05H0n_3V00<0
odD00?[`iP3jl>H0@03jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0
n_3V03l0n_3V00<0odD00?[`iP3jl>H0EP3jl>H00`3oA@00n_3V0?[`iP0Y0?[`iP030?m5003jl>H0
n_3V05D0n_3V00<0odD00?[`iP3jl>H0:P3jl>H00`000?l0n_3V0?[`iP0C0?[`iP030000003jl>H0
n_3V03<0n_3V0@3oool005/0n_3V0P0000110?[`iP030?m5003jl>H0n_3V05@0n_3V00<0odD00?[`
iP3jl>H0:`3jl>H00`3oA@00n_3V0?[`iP1D0?[`iP030?m5003jl>H0n_3V02T0n_3V00<0003o0?[`
iP3jl>H04`3jl>H2000003D0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0@03jl>H00`3oA@00
n_3V0?[`iP1C0?[`iP030?m5003jl>H0n_3V02d0n_3V00<0odD00?[`iP3jl>H0D`3jl>H00`3oA@00
n_3V0?[`iP0X0?[`iP030000o`3jl>H0n_3V01D0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00
F`3jl>H00`000000n_3V0?[`iP100?[`iP030?m5003jl>H0n_3V0580n_3V00<0odD00?[`iP3jl>H0
;`3jl>H00`3oA@00n_3V0?[`iP1A0?[`iP030?m5003jl>H0n_3V02P0n_3V00<0003o0?[`iP3jl>H0
5P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V0440n_3V00<0
odD00?[`iP3jl>H0D03jl>H00`3oA@00n_3V0?[`iP0a0?[`iP030?m5003jl>H0n_3V0500n_3V00<0
odD00?[`iP3jl>H0@@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo00110?[`iP<00000103jl>H2
000000D0n_3V0`0000090?[`iP030000003jl>H0n_3V0440n_3V00<0odD00?[`iP3jl>H0C`3jl>H0
0`3oA@00n_3V0?[`iP0c0?[`iP030?m500000?l0n_3V04l0n_3V00<0odD00?[`iP3jl>H09@3jl>H0
0`000?l0n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool00400n_3V0P0000000`3j
l>H00000000000030?[`iP800000103jl>H00`000000n_3V0?[`iP02000000P0n_3V00<000000?[`
iP3jl>H0@@3jl>H00`3oA@00n_3V0?[`iP1>0?[`iP030?m5003jl>H0n_3V03D0n_3V00<0odD00000
o`3jl>H0CP3jl>H00`3oA@00n_3V0?[`iP0T0?[`iP030000o`3jl>H0n_3V01X0n_3V00<000000?[`
iP3jl>H0<`3jl>H10?ooo`00@03jl>H2000000030?[`iP000000000000`0n_3V0P0000080?[`iP<0
0000@@3jl>H00`3oA@00n_3V0?[`iP1=0?[`iP030?m5003jl>H0n_3V03L0n_3V00<0odD00000o`3j
l>H0C03jl>H00`3oA@00n_3V0?[`iP0T0?[`iP030000o`3jl>H0n_3V01T0n_3V0`00000e0?[`iP40
oooo00100?[`iP80000000<0n_3V000000000000303jl>H2000000P0n_3V00<000000?[`iP3jl>H0
@P3jl>H00`3oA@00n_3V0?[`iP1:0?[`iP80odD0>`3jl>H00`3oA@00003o0?[`iP1;0?[`iP030?m5
003jl>H0n_3V02<0n_3V00<0003o0?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo
00100?[`iP80000000<0n_3V0000000000002@3jl>H00`000000n_3V0?[`iP02000000P0n_3V00<0
00000?[`iP3jl>H0@P3jl>H00`3oA@00n_3V0?[`iP190?[`iP030?m5003jl>H0n_3V03`0n_3V0P3o
A@1;0?[`iP030?m5003jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00@03jl>H2
000000030?[`iP000000000000T0n_3V100000090?[`iP030000003jl>H0n_3V0480n_3V00<0odD0
0?[`iP3jl>H0B03jl>H00`3oA@00n_3V0?[`iP0o0?[`iP030?m500000?l0n_3V04L0n_3V00<0odD0
0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo00100?[`iP80000000<0n_3V0000
000000002@3jl>H2000000/0n_3V00<000000?[`iP3jl>H0@`3jl>H00`3oA@00n_3V0?[`iP160?[`
iP030?m5003jl>H0n_3V0440n_3V00<0odD00000o`3jl>H0AP3jl>H00`3oA@00n_3V0?[`iP0Q0?[`
iP030000o`3jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00@@3jl>H3000000X0
n_3V1@0000080?[`iP030000003jl>H0n_3V04<0n_3V00<0odD00?[`iP3jl>H0A03jl>H20?m504D0
n_3V00<0odD00000o`3jl>H0A@3jl>H00`3oA@00n_3V0?[`iP0O0?[`iP80003o8P3jl>H00`000000
n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP800000A@3jl>H00`3oA@00n_3V0?[`iP120?[`iP030?m5
003jl>H0n_3V04H0n_3V00<0odD00000o`3jl>H0@`3jl>H00`3oA@00n_3V0?[`iP0O0?[`iP030000
o`3jl>H0n_3V0240n_3V0P00000e0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04@0n_3V00<0
odD00?[`iP3jl>H0@@3jl>H00`3oA@00n_3V0?[`iP180?[`iP030?m5003jl>H0n_3V0480n_3V00<0
odD00?[`iP3jl>H0A03jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0
n_3V04@0n_3V00<0odD00?[`iP3jl>H0@03jl>H00`3oA@00n_3V0?[`iP1:0?[`iP80odD000<0003o
0?[`iP3jl>H0?`3jl>H00`3oA@00n_3V0?[`iP0K0?[`iP030000o`3jl>H0n_3V02H0n_3V00<00000
0?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP150?[`iP030?m5003jl>H0n_3V
03d0n_3V0P3oA@1?0?[`iP030?m500000?l0n_3V03h0n_3V00<0odD00?[`iP3jl>H06`3jl>H00`00
0?l0n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3j
l>H0A@3jl>H00`3oA@00n_3V0?[`iP0l0?[`iP030?m5003jl>H0n_3V0500n_3V00<0odD00000o`3j
l>H0?@3jl>H00`3oA@00n_3V0?[`iP0J0?[`iP030000o`3jl>H0n_3V02P0n_3V00<000000?[`iP3j
l>H0<`3jl>H10?ooo`00F`3jl>H2000004L0n_3V00<0odD00?[`iP3jl>H0>P3jl>H00`3oA@00n_3V
0?[`iP1B0?[`iP030?m500000?l0n_3V03/0n_3V00<0odD00?[`iP3jl>H06P3jl>H00`000?l0n_3V
0?[`iP0X0?[`iP800000=@3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP160?[`iP030?m5003j
l>H0n_3V03T0n_3V00<0odD00?[`iP3jl>H0E03jl>H20?m503/0n_3V00<0odD00?[`iP3jl>H0AP3j
l>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04L0n_3V00<0odD0
0?[`iP3jl>H0=`3jl>H00`3oA@00n_3V0?[`iP1G0?[`iP030?m500000?l0n_3V03L0n_3V00<0odD0
0?[`iP3jl>H0603jl>H00`000?l0n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool0
05/0n_3V00<000000?[`iP3jl>H0B03jl>H00`3oA@00n_3V0?[`iP0d0?[`iP80odD0F`3jl>H20?m5
00030000o`3jl>H0n_3V03@0n_3V00<0odD00?[`iP3jl>H05P3jl>H20000obl0n_3V00<000000?[`
iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP180?[`iP030?m5003jl>H0n_3V03<0
n_3V00<0odD00?[`iP3jl>H0G@3jl>H20?m500030000o`3jl>H0n_3V0340n_3V00<0odD00?[`iP3j
l>H05P3jl>H00`000?l0n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V
00<000000?[`iP3jl>H0B@3jl>H00`3oA@00n_3V0?[`iP0a0?[`iP030?m5003jl>H0n_3V0600n_3V
00<0odD00?[`iP3jl>H0<@3jl>H00`3oA@00n_3V0?[`iP180?[`iP030000003jl>H0n_3V03<0n_3V
0@3oool005/0n_3V0P00001;0?[`iP030?m5003jl>H0n_3V02h0n_3V0P3oA@1T0?[`iP80odD000<0
003o0?[`iP3jl>H0;@3jl>H00`3oA@00n_3V0?[`iP0C0?[`iP030000o`3jl>H0n_3V0380n_3V0P00
000e0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04/0n_3V00<0odD00?[`iP3jl>H0:`3jl>H2
0?m506P0n_3V00<0odD00000o`000?l0;03jl>H00`3oA@00n_3V0?[`iP0B0?[`iP80003o=P3jl>H0
0`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04/0n_3V00<0odD00?[`
iP3jl>H0:@3jl>H20?m506/0n_3V00@0odD00?[`iP000?l0003o:@3jl>H00`3oA@00n_3V0?[`iP0B
0?[`iP030000o`3jl>H0n_3V03H0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`00
0000n_3V0?[`iP1<0?[`iP030?m5003jl>H0n_3V02L0n_3V00<0odD00?[`iP3jl>H0K03jl>H20?m5
02T0n_3V00<0odD00?[`iP3jl>H0C03jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP03
0000003jl>H0n_3V04d0n_3V00<0odD00?[`iP3jl>H0903jl>H20?m50740n_3V0P3oA@000`3jl>H0
003o0?[`iP0S0?[`iP030?m5003jl>H0n_3V0100n_3V00<0003o0?[`iP3jl>H0>P3jl>H00`000000
n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP800000C`3jl>H00`3oA@00n_3V0?[`iP0Q0?[`iP80odD0
M@3jl>H20?m50080003o8@3jl>H00`3oA@00n_3V0?[`iP0?0?[`iP80003o?03jl>H2000003D0n_3V
0@3oool005/0n_3V00<000000?[`iP3jl>H0C`3jl>H00`3oA@00n_3V0?[`iP0O0?[`iP030?m5003j
l>H0n_3V07L0n_3V0P3oA@020000oah0n_3V00<0odD00?[`iP3jl>H03`3jl>H00`000?l0n_3V0?[`
iP0m0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0D03jl>H2
0?m501d0n_3V0P3oA@1l0?[`iP80odD00`3jl>H20000oaP0n_3V00<0odD00?[`iP3jl>H0303jl>H0
0`000?l0n_3V0?[`iP110?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`
iP3jl>H0DP3jl>H00`3oA@00n_3V0?[`iP0H0?[`iP80odD0P03jl>H20?m500<0n_3V0P000?lD0?[`
iP80odD03@3jl>H20000od@0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00CP3jl>H6000000L0
n_3V00<000000?[`iP3jl>H0D`3jl>H20?m501D0n_3V0`3oA@240?[`iP80odD00P3jl>H00`000?l0
n_3V0?[`iP0?0?[`iP<0odD03@3jl>H20000odH0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00
D03jl>H2000000T0n_3V00<000000?[`iP3jl>H0E@3jl>H40?m500`0n_3V1@3oA@290?[`iP@0odD0
0P3jl>H50000o`D0n_3V103oA@080?[`iPD0003oB`3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo
001@0?[`iP8000002@3jl>H3000005T0n_3V303oA@2B0?[`iP`0odD000@0003o0?[`iP3jl>H0n_3V
1@000?mA0?[`iP<00000=@3jl>H10?ooo`00D03jl>H2000000T0n_3V00<000000?[`iP3jl>H01@3j
l>H00`000000n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V03H0n_3V00<000000?[`iP3jl>H0=@3j
l>H00`000000n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0=P3j
l>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V03<0n_3V0@3oool00500n_3V0P000009
0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP09
0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP08
0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP08
0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP08
0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP09
0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP08
0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP08
0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP08
0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP09
0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP08
0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0c
0?[`iP40oooo001@0?[`iP8000002@3jl>Ko000006@00000=@3jl>H10?ooo`00CP3jl>H400000?l0
n_3VXP3jl>H10?ooo`00D03jl>H200000?l0n_3VXP3jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003Y0?[`iP@000000`3jl>H20000
00030?[`iP00000000000080n_3V1000000<0?[`iP<00000103jl>H:000000@0n_3V0`0000030?[`
iP@000000P3jl>H500000<H0n_3V0@3oool00>X0n_3V0P0000040?[`iP80000000@0n_3V00000000
0000n_3V0P0000020?[`iP8000002P3jl>H200000080n_3V00<000000?[`iP3jl>H00P0000000`3j
l>H00000000000020?[`iP8000001P3jl>H300000080n_3V0P0000030?[`iP040000003jl>H00000
00000080n_3V0P0000350?[`iP40oooo003Z0?[`iP800000103jl>H2000000040?[`iP0000000000
0?[`iP8000000P3jl>H2000000T0n_3V0P0000060?[`iP80000000<0n_3V0000000000000P3jl>H2
000000H0n_3V00<000000?[`iP0000000P3jl>H2000000L0n_3V100000350?[`iP40oooo003Z0?[`
iP8000000`3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H2000000T0n_3V0P0000060?[`
iP80000000<0n_3V0000000000000P3jl>H2000000D0n_3V0P000000103jl>H000000000003jl>H6
000000030?[`iP000000000000800000a`3jl>H10?ooo`00jP3jl>H2000000<0n_3V0P0000000`3j
l>H000000?[`iP0400000080n_3V0P0000090?[`iP8000001P3jl>H2000000030?[`iP0000000000
0080n_3V0`000000103jl>H000000?[`iP3jl>H2000000040?[`iP00000000000?[`iP8000000P3j
l>H2000000030?[`iP00000000000080n_3V0P0000350?[`iP40oooo003X0?[`iP050000003jl>H0
00000000003jl>H01@0000000`3jl>H0000000000006000000X0n_3V0P0000030?[`iP030000003j
l>H000000080000000@0n_3V000000000000n_3V0`000000103jl>H000000000003jl>H300000005
0?[`iP00000000000000003jl>H0100000030?[`iPD00000a@3jl>H10?ooo`00j03jl>H01P000000
n_3V000000000000n_3V000001P0n_3V0P0000020?[`iP030000003jl>H0n_3V0>H0n_3V0@3oool0
0>P0n_3V1P00000I0?[`iP@00000j03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {237.313, 0}} -> {-1.05243, -0.643838, \
0.00421814, 0.00421814}, {{12.375, 486.563}, {163.688, 5.625}} -> {-4.7728, \
-2.71491, 0.0177844, 0.0177844}, {{59.8125, 249.5}, {226.875, 179.5}} -> \
{-1.16222, -0.655216, 0.0177311, 0.0531932}, {{70, 126.438}, {223.438, \
204.688}} -> {-1.32734, -2.88375, 0.0186048, 0.124032}, {{70, 126.438}, \
{201.625, 182.875}} -> {-1.32734, -5.58921, 0.0186048, 0.124032}}]
}, Open  ]],

Cell["\<\
Here, the two curves are actually reproduced as the keys in the legend.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowLegend[\[IndentingNewLine]DontShow[
          Graphics[\[IndentingNewLine]{Blue, \[IndentingNewLine]Draw[
                Sin[x], {x, \(-3\), 
                  3}], \[IndentingNewLine]OrangeRed, \
\[IndentingNewLine]ParametricDraw[
                2 {Sin[t], Sin[t] Cos[t]}, {t, 0, 
                  2  \[Pi]}]}], \[IndentingNewLine]Background \[Rule] 
            Linen, \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]ImageSize \[Rule] 
            500, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]PlotLabel \[Rule] "\<Two Curves\>"], \
\[IndentingNewLine]\[IndentingNewLine]{{{Graphics[{OrangeRed, 
                  ParametricDraw[
                    2 {Sin[t], Sin[t] Cos[t]}, {t, 0, 
                      2  \[Pi]}]}], "\<Figure Eight\>"}, \
\[IndentingNewLine]{Graphics[{Blue, 
                  Draw[Sin[x], {x, \(-3\), 
                      3}]}], "\<Sine Wave\>"}}, \
\[IndentingNewLine]LegendPosition \[Rule] {\(-0.8\), \(-0.6\)}, \
\[IndentingNewLine]LegendSize \[Rule] {0.7, 
              0.2}, \[IndentingNewLine]LegendTextOffset \[Rule] {\(-1\), 
              0}, \[IndentingNewLine]LegendBackground \[Rule] 
            AliceBlue, \[IndentingNewLine]LegendShadow \[Rule] {0.02, \(-0.02\
\)}, \[IndentingNewLine]ShadowBackground \[Rule] 
            RoyalBlue}, \[IndentingNewLine]TextStyle \[Rule] {FontSize \
\[Rule] 12, FontWeight \[Rule] "\<Bold\>"}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47667 
%%ImageSize: 500 238.333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.47619 0.306587 0.47619 [
[ 0 0 0 0 ]
[ 1 .47667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.147857 0.97619 0.465317 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.15873 0.166667 0.15873 [
[.02381 -0.0125 -9.5625 -15.5625 ]
[.02381 -0.0125 9.5625 0 ]
[.18254 -0.0125 -9.5625 -15.5625 ]
[.18254 -0.0125 9.5625 0 ]
[.34127 -0.0125 -9.5625 -15.5625 ]
[.34127 -0.0125 9.5625 0 ]
[.5 -0.0125 -5.59375 -15.5625 ]
[.5 -0.0125 5.59375 0 ]
[.65873 -0.0125 -5.59375 -15.5625 ]
[.65873 -0.0125 5.59375 0 ]
[.81746 -0.0125 -5.59375 -15.5625 ]
[.81746 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -15.5625 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -19.125 -7.78125 ]
[-0.0125 .00794 0 7.78125 ]
[-0.0125 .0873 -33.5 -7.78125 ]
[-0.0125 .0873 0 7.78125 ]
[-0.0125 .16667 -11.1875 -7.78125 ]
[-0.0125 .16667 0 7.78125 ]
[-0.0125 .24603 -25.5625 -7.78125 ]
[-0.0125 .24603 0 7.78125 ]
[-0.0125 .3254 -11.1875 -7.78125 ]
[-0.0125 .3254 0 7.78125 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[.5 .34583 -37.9375 0 ]
[.5 .34583 37.9375 15.5625 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -70.5625 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
gsave
-0.0125 .00794 -80.125 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .0873 m
.00625 .0873 L
s
gsave
-0.0125 .0873 -94.5 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.938 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .16667 m
.00625 .16667 L
s
gsave
-0.0125 .16667 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .24603 m
.00625 .24603 L
s
gsave
-0.0125 .24603 -86.5625 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .3254 m
.00625 .3254 L
s
gsave
-0.0125 .3254 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .07143 m
.00375 .07143 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .13492 m
.00375 .13492 L
s
0 .15079 m
.00375 .15079 L
s
0 .18254 m
.00375 .18254 L
s
0 .19841 m
.00375 .19841 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .2619 m
.00375 .2619 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.18254 .32708 m
.18254 .33333 L
s
.34127 .32708 m
.34127 .33333 L
s
.5 .32708 m
.5 .33333 L
s
.65873 .32708 m
.65873 .33333 L
s
.81746 .32708 m
.81746 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.05556 .32958 m
.05556 .33333 L
s
.0873 .32958 m
.0873 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.15079 .32958 m
.15079 .33333 L
s
.21429 .32958 m
.21429 .33333 L
s
.24603 .32958 m
.24603 .33333 L
s
.27778 .32958 m
.27778 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.37302 .32958 m
.37302 .33333 L
s
.40476 .32958 m
.40476 .33333 L
s
.43651 .32958 m
.43651 .33333 L
s
.46825 .32958 m
.46825 .33333 L
s
.53175 .32958 m
.53175 .33333 L
s
.56349 .32958 m
.56349 .33333 L
s
.59524 .32958 m
.59524 .33333 L
s
.62698 .32958 m
.62698 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.72222 .32958 m
.72222 .33333 L
s
.75397 .32958 m
.75397 .33333 L
s
.78571 .32958 m
.78571 .33333 L
s
.84921 .32958 m
.84921 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.9127 .32958 m
.9127 .33333 L
s
.94444 .32958 m
.94444 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .07143 m
1 .07143 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .13492 m
1 .13492 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .19841 m
1 .19841 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
gsave
.5 .34583 -98.9375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Two) show
91.750 15.000 moveto
(Curves) show
134.875 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .14427 m
.06244 .10705 L
.10458 .07055 L
.14415 .04235 L
.16408 .03097 L
.18221 .02247 L
.20178 .01541 L
.21254 .01249 L
.21738 .01141 L
.22272 .01039 L
.22739 .00964 L
.23241 .00899 L
.23518 .00869 L
.23772 .00846 L
.2403 .00828 L
.24269 .00814 L
.24488 .00804 L
.2461 .008 L
.24721 .00797 L
.24843 .00795 L
.24975 .00794 L
.251 .00794 L
.25214 .00794 L
.25322 .00796 L
.25423 .00798 L
.25533 .008 L
.25651 .00804 L
.25893 .00815 L
.26113 .00828 L
.26594 .00867 L
.27104 .00924 L
.28022 .01068 L
.29008 .01281 L
.30098 .01584 L
.32032 .02298 L
.34118 .03305 L
.38232 .05947 L
.42194 .09172 L
.46005 .12714 L
.50061 .16728 L
.53966 .20591 L
.58116 .24433 L
.62114 .27638 L
.6596 .3007 L
.67948 .31027 L
.68962 .3143 L
.70052 .31795 L
.71075 .32073 L
.7201 .32271 L
.72459 .32347 L
Mistroke
.72949 .32416 L
.73412 .32467 L
.73841 .32502 L
.74106 .32518 L
.7435 .32529 L
.74478 .32533 L
.74618 .32537 L
.74689 .32538 L
.74764 .32539 L
.74836 .32539 L
.749 .3254 L
.75028 .32539 L
.75146 .32538 L
.75275 .32536 L
.75341 .32534 L
.75413 .32532 L
.75663 .32523 L
.75897 .3251 L
.76365 .32475 L
.76794 .32431 L
.77759 .32289 L
.78742 .32085 L
.79655 .31842 L
.81727 .31108 L
.83777 .30139 L
.85637 .29066 L
.8964 .262 L
.93492 .22871 L
.97589 .18936 L
.97619 .18907 L
Mfstroke
1 .271 0 r
.5 .16667 m
.58004 .24412 L
.61998 .27775 L
.6403 .29252 L
.66127 .30558 L
.6802 .31502 L
.69665 .32104 L
.70429 .32304 L
.70851 .3239 L
.71236 .32452 L
.71567 .32493 L
.71753 .3251 L
.71927 .32523 L
.72108 .32533 L
.72273 .32538 L
.72461 .3254 L
.72639 .32537 L
.72821 .32531 L
.72922 .32525 L
.73016 .32519 L
.73186 .32504 L
.73364 .32484 L
.7367 .3244 L
.74 .32376 L
.74346 .32291 L
.7471 .3218 L
.75345 .31928 L
.75955 .31612 L
.76507 .31254 L
.77472 .30433 L
.78429 .29318 L
.79319 .27909 L
.79973 .26543 L
.80579 .24882 L
.80839 .23985 L
.81079 .23006 L
.81416 .21187 L
.81553 .20141 L
.81648 .19154 L
.81688 .18581 L
.81715 .18059 L
.81727 .17769 L
.81732 .17616 L
.81736 .17454 L
.81739 .17312 L
.81742 .17156 L
.81745 .16882 L
.81746 .16611 L
.81745 .16359 L
.81741 .16084 L
Mistroke
.81737 .1593 L
.81734 .1579 L
.81726 .15534 L
.81715 .15258 L
.81688 .14758 L
.81655 .1427 L
.81611 .13757 L
.81512 .12847 L
.81363 .11808 L
.81191 .10859 L
.80684 .08797 L
.80049 .06973 L
.79315 .05416 L
.7855 .04182 L
.77607 .03036 L
.76579 .02132 L
.75949 .01718 L
.75328 .01397 L
.74999 .01258 L
.74645 .01132 L
.74333 .01039 L
.73994 .00956 L
.7362 .00885 L
.73451 .0086 L
.73266 .00837 L
.73152 .00826 L
.73046 .00817 L
.72946 .0081 L
.72836 .00803 L
.72644 .00796 L
.72538 .00794 L
.72439 .00794 L
.72252 .00796 L
.72157 .00799 L
.72051 .00803 L
.71864 .00815 L
.71687 .00829 L
.71283 .00875 L
.70841 .00946 L
.70014 .01131 L
.69235 .01364 L
.67697 .01975 L
.66008 .02843 L
.62317 .05315 L
.58691 .08307 L
.50633 .16034 L
.42035 .24377 L
.3791 .27846 L
.36166 .29118 L
.34304 .3031 L
Mistroke
.32695 .31175 L
.31034 .31876 L
.3015 .32158 L
.29363 .32348 L
.28992 .32417 L
.28594 .32474 L
.28413 .32495 L
.28223 .32512 L
.28044 .32525 L
.27883 .32533 L
.27703 .32538 L
.27536 .3254 L
.27355 .32537 L
.27162 .3253 L
.27065 .32524 L
.26961 .32517 L
.26773 .325 L
.26425 .32455 L
.26102 .32398 L
.25765 .32321 L
.25176 .3214 L
.24523 .31867 L
.23937 .31547 L
.23328 .31132 L
.22699 .30599 L
.21706 .29497 L
.20789 .28105 L
.20061 .26624 L
.19492 .25104 L
.19216 .24189 L
.18956 .2316 L
.1876 .22225 L
.18588 .2121 L
.18463 .20278 L
.18408 .19778 L
.18359 .19237 L
.18322 .18738 L
.18295 .1828 L
.18285 .1806 L
.18275 .17819 L
.18268 .17606 L
.18262 .17381 L
.18259 .17247 L
.18257 .17101 L
.18254 .16843 L
.18254 .16698 L
.18254 .16543 L
.18255 .16396 L
.18257 .16263 L
.18261 .16004 L
Mistroke
.18264 .15858 L
.18268 .15723 L
.18287 .15214 L
.18311 .14763 L
.18345 .14269 L
.18438 .13276 L
.18574 .12216 L
.18762 .11101 L
.19211 .09165 L
.19794 .07373 L
.20584 .05605 L
.21473 .0415 L
.22419 .0301 L
.2296 .02499 L
.2358 .02018 L
.24156 .01658 L
.24792 .01344 L
.25392 .0112 L
.25742 .01019 L
.26076 .00941 L
.26389 .00884 L
.26678 .00844 L
.2684 .00827 L
.27017 .00812 L
.27187 .00802 L
.27344 .00796 L
.27518 .00794 L
.27701 .00795 L
.2786 .008 L
.28034 .00808 L
.28224 .00821 L
.28428 .0084 L
.288 .00887 L
.29183 .0095 L
.29549 .01025 L
.30246 .01203 L
.31907 .018 L
.33795 .02732 L
.37501 .05177 L
.41659 .08619 L
.49493 .16159 L
.5 .16667 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
.255 .412 .882 r
.12857 .01135 m
.12857 .10659 L
.4619 .10659 L
.4619 .01135 L
F
.941 .973 1 r
.11905 .02087 m
.11905 .11611 L
.45238 .11611 L
.45238 .02087 L
F
0 g
.001 w
[ ] 0 setdash
.11905 .02087 m
.45238 .02087 L
.45238 .11611 L
.11905 .11611 L
.11905 .02087 L
s
% Start of sub-graphic
p
0.119048 0.020873 0.452381 0.116111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0113379 0.113379 [
[ 0 0 0 0 ]
[ 1 .28571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .28571 L
0 .28571 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0204082 0.35119 0.133787 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.294303 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .26748 m
.06244 .19849 L
.10458 .1308 L
.14415 .07853 L
.16408 .05743 L
.18221 .04166 L
.20178 .02856 L
.21254 .02316 L
.21738 .02116 L
.22272 .01927 L
.22739 .01787 L
.23241 .01666 L
.23518 .01611 L
.23772 .01569 L
.2403 .01534 L
.24269 .01509 L
.24488 .01491 L
.2461 .01484 L
.24721 .01478 L
.24843 .01474 L
.24975 .01472 L
.251 .01472 L
.25214 .01473 L
.25322 .01475 L
.25423 .01479 L
.25533 .01484 L
.25651 .01491 L
.25893 .01511 L
.26113 .01535 L
.26594 .01608 L
.27104 .01714 L
.28022 .0198 L
.29008 .02374 L
.30098 .02937 L
.32032 .0426 L
.34118 .06128 L
.38232 .11027 L
.42194 .17005 L
.46005 .23573 L
.50061 .31015 L
.53966 .38178 L
.58116 .45302 L
.62114 .51244 L
.6596 .55754 L
.67948 .57528 L
.68962 .58274 L
.70052 .58951 L
.71075 .59467 L
.7201 .59834 L
.72459 .59975 L
Mistroke
.72949 .60102 L
.73412 .60197 L
.73841 .60262 L
.74106 .60292 L
.7435 .60312 L
.74478 .6032 L
.74618 .60326 L
.74689 .60328 L
.74764 .6033 L
.74836 .60331 L
.749 .60332 L
.75028 .60331 L
.75146 .60329 L
.75275 .60325 L
.75341 .60322 L
.75413 .60319 L
.75663 .60301 L
.75897 .60278 L
.76365 .60212 L
.76794 .6013 L
.77759 .59867 L
.78742 .59489 L
.79655 .59039 L
.81727 .57677 L
.83777 .55881 L
.85637 .53891 L
.8964 .48578 L
.93492 .42406 L
.97589 .3511 L
.97619 .35055 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .0771 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sine) show
99.313 15.000 moveto
(Wave) show
128.063 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.151927 0.35119 0.265306 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .271 0 r
.5 Mabswid
[ ] 0 setdash
.5 .30902 m
.62007 .45263 L
.67997 .51497 L
.71045 .54237 L
.74191 .56657 L
.77031 .58409 L
.79497 .59525 L
.80643 .59894 L
.81277 .60054 L
.81853 .60169 L
.8235 .60245 L
.8263 .60277 L
.8289 .60301 L
.83162 .60319 L
.83409 .60328 L
.83692 .60332 L
.83958 .60328 L
.84231 .60315 L
.84384 .60305 L
.84523 .60293 L
.84779 .60266 L
.85047 .6023 L
.85505 .60147 L
.86 .60029 L
.8652 .59871 L
.87065 .59665 L
.88018 .59199 L
.88932 .58612 L
.8976 .57947 L
.91209 .56427 L
.92644 .54359 L
.93979 .51747 L
.9496 .49213 L
.95868 .46134 L
.96259 .4447 L
.96618 .42656 L
.97124 .39282 L
.9733 .37343 L
.97472 .35513 L
.97532 .34451 L
.97573 .33483 L
.9759 .32945 L
.97598 .32662 L
.97604 .32361 L
.97609 .32099 L
.97613 .3181 L
.97618 .31301 L
.97619 .30798 L
.97617 .30332 L
.97611 .29821 L
Mistroke
.97606 .29535 L
.97601 .29277 L
.97589 .28802 L
.97572 .2829 L
.97533 .27363 L
.97482 .26457 L
.97417 .25506 L
.97268 .23819 L
.97044 .21893 L
.96786 .20134 L
.96026 .16311 L
.95073 .12928 L
.93973 .10042 L
.92824 .07753 L
.9141 .05629 L
.89869 .03954 L
.88923 .03185 L
.87992 .0259 L
.87499 .02333 L
.86968 .02099 L
.865 .01926 L
.85991 .01772 L
.8543 .01641 L
.85176 .01595 L
.84899 .01553 L
.84728 .01531 L
.84569 .01514 L
.8442 .01501 L
.84255 .01489 L
.83966 .01476 L
.83808 .01472 L
.83659 .01472 L
.83378 .01476 L
.83235 .01481 L
.83077 .0149 L
.82796 .0151 L
.8253 .01537 L
.81925 .01622 L
.81262 .01753 L
.80021 .02097 L
.78852 .0253 L
.76545 .03661 L
.74012 .05271 L
.68475 .09854 L
.63037 .15403 L
.50949 .29728 L
.38052 .45198 L
.31865 .51629 L
.29249 .53988 L
.26455 .56198 L
Mistroke
.24043 .57801 L
.21551 .59101 L
.20225 .59624 L
.19045 .59977 L
.18489 .60104 L
.17891 .60211 L
.1762 .60248 L
.17334 .60281 L
.17066 .60304 L
.16825 .60319 L
.16555 .60329 L
.16305 .60332 L
.16032 .60327 L
.15743 .60314 L
.15598 .60304 L
.15442 .6029 L
.1516 .60258 L
.14638 .60176 L
.14153 .60069 L
.13647 .59926 L
.12763 .59591 L
.11784 .59084 L
.10905 .58492 L
.09993 .57722 L
.09049 .56734 L
.07559 .54691 L
.06183 .52109 L
.05092 .49364 L
.04238 .46546 L
.03825 .44849 L
.03434 .42941 L
.03141 .41207 L
.02882 .39326 L
.02694 .37597 L
.02612 .3667 L
.02538 .35667 L
.02483 .34742 L
.02443 .33894 L
.02427 .33485 L
.02412 .33038 L
.02402 .32643 L
.02393 .32225 L
.02389 .31978 L
.02385 .31706 L
.02382 .31229 L
.02381 .3096 L
.02381 .30672 L
.02383 .30401 L
.02385 .30153 L
.02391 .29674 L
Mistroke
.02396 .29403 L
.02402 .29153 L
.02431 .28208 L
.02467 .27373 L
.02518 .26456 L
.02657 .24614 L
.02861 .22651 L
.03143 .20582 L
.03816 .16992 L
.04691 .1367 L
.05876 .10393 L
.07209 .07695 L
.08629 .0558 L
.09441 .04634 L
.1037 .03742 L
.11233 .03074 L
.12188 .02492 L
.13087 .02077 L
.13613 .01889 L
.14114 .01744 L
.14583 .01638 L
.15017 .01564 L
.1526 .01533 L
.15526 .01506 L
.1578 .01487 L
.16016 .01477 L
.16276 .01472 L
.16552 .01474 L
.16789 .01482 L
.17051 .01498 L
.17335 .01523 L
.17642 .01558 L
.18201 .01644 L
.18774 .01761 L
.19323 .019 L
.20369 .0223 L
.2286 .03337 L
.25692 .05065 L
.31252 .096 L
.37489 .1598 L
.49239 .29961 L
.5 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20862 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Figure) show
113.313 15.000 moveto
(Eight) show
149.250 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .47667 L
0 .47667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 238.313},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000kR000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00@03jl>JV045YhOl0
n_3V3P3jl>H10?ooo`00@03jl>JV045YhOl0n_3V3P3jl>H10?ooo`00@03jl>JV045YhOl0n_3V3P3j
l>H10?ooo`00@03jl>JV045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>JW000000@0@FWQo`3jl>H>0?[`
iP40oooo000k0?[`iP030000003`nOl0l?Wo0:<0l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0
n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000@FWQ045Yh@02045YhOl0n_3V
3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`0300000011JN40@FWQ0080@FWQo`3j
l>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo01D0l?Wo1@000?n90?3io`0300000011JN40
@FWQ0080@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo01@0l?Wo0P000?l40?3i
o`030000o`3`nOl0l?Wo08H0l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0n_3V0@3oool003/0
n_3V00<000000?3io`3`nOl04`3`nOl00`000?l0l?Wo0?3io`050?3io`030000o`3`nOl0l?Wo08D0
l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0
4`3`nOl00`000?l0l?Wo0?3io`060?3io`030000o`3`nOl0l?Wo08@0l?Wo00<00000045Yh@11JN40
0P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl04P3`nOl00`000?l0l?Wo0?3i
o`080?3io`030000o`3`nOl0l?Wo08<0l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0n_3V0@3o
ool003/0n_3V00<000000?3io`3`nOl04P3`nOl00`000?l0l?Wo0?3io`080?3io`030000o`3`nOl0
l?Wo08<0l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3i
o`3`nOl04@3`nOl00`000?l0l?Wo0?3io`0:0?3io`030000o`3`nOl0l?Wo01l0l?Wo1@0000020?3i
o`H0000000D0l?Wo00000000000000000?3io`03000000030?3io`0000000000008000002`3`nOl2
000000030?3io`00000000000080l?Wo1P0000020?3io`<000000`3`nOl4000002D0l?Wo00<00000
045Yh@11JN400P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0403`nOl00`00
0?l0l?Wo0?3io`0;0?3io`030000o`3`nOl0l?Wo01l0l?Wo00@000000?3io`3`nOl0l?Wo0P000003
0?3io`800000103`nOl2000000040?3io`00000000000?3io`8000000`3`nOl00`000000l?Wo0?3i
o`080?3io`80000000@0l?Wo000000000000l?Wo0P0000020?3io`8000000`3`nOl300000080l?Wo
0P0000030?3io`030000003`nOl0l?Wo0280l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0n_3V
0@3oool003/0n_3V00<000000?3io`3`nOl07`3`nOl00`000?l0l?Wo0?3io`0R0?3io`8000000`3`
nOl2000000@0l?Wo0P000000103`nOl000000000003`nOl2000000h0l?Wo0P000000103`nOl00000
0000003`nOl200000080l?Wo0P0000030?3io`030000003`nOl000000080l?Wo0P00000X0?3io`03
00000011JN40@FWQ0080@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo01l0l?Wo
00<0003o0?3io`3`nOl0803`nOl3000000@0l?Wo0P0000040?3io`80000000@0l?Wo000000000000
l?Wo1P00000:0?3io`80000000<0l?Wo0000000000000P3`nOl500000080l?Wo0P000000103`nOl0
00000000003`nOl6000002@0l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0n_3V0@3oool003/0
n_3V00<000000?3io`3`nOl0803`nOl00`000?l0l?Wo0?3io`0:0?3io`030000o`3`nOl0l?Wo0140
l?Wo0`0000050?3io`800000103`nOl2000000040?3io`00000000000?3io`8000000P3`nOl20000
00X0l?Wo00D000000?3io`000000l?Wo000000050?3io`8000000P3`nOl2000000040?3io`000000
00000?3io`8000000P3`nOl2000002@0l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0n_3V0@3o
ool003/0n_3V00<000000?3io`3`nOl0803`nOl00`000?l0l?Wo0?3io`090?3io`030000o`3`nOl0
l?Wo0140l?Wo0P0000050?3io`@000000`3`nOl5000000<0l?Wo1000000:0?3io`80000000<0l?Wo
0000003`nOl00P0000000`3`nOl000000000000200000080l?Wo0`0000001@3`nOl0000000000000
0000l?Wo00@000009@3`nOl00`000000@FWQ045Yh@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H0
0`000000l?Wo0?3io`0P0?3io`030000o`3`nOl0l?Wo00T0l?Wo00<0003o0?3io`3`nOl04@3`nOl2
000000<0l?Wo00<000000?3io`3`nOl0703`nOl2000000<0l?Wo0P00000h0?3io`0300000011JN40
@FWQ0080@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0240l?Wo00<0003o0?3i
o`3`nOl01`3`nOl00`000?l0l?Wo0?3io`0C0?3io`D000000`3`nOl2000001P0l?Wo100000000`3`
nOl0000000000002000003L0l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0n_3V0@3oool003/0
n_3V00<000000?3io`3`nOl08P3`nOl00`000?l0l?Wo0?3io`060?3io`030000o`3`nOl0l?Wo07D0
l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0
8`3`nOl00`000?l0l?Wo0?3io`040?3io`030000o`3`nOl0l?Wo07H0l?Wo00<00000045Yh@11JN40
0P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0903`nOl00`000?l0l?Wo0?3i
o`020?3io`030000o`3`nOl0l?Wo07L0l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0n_3V0@3o
ool003/0n_3V00<000000?3io`3`nOl0903`nOl60000ogT0l?Wo00<00000045Yh@11JN400P11JN7o
0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000@FWQ045Yh@02045Y
hOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`2S0?3io`0300000011JN40@FWQ0080
@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0:<0l?Wo00<00000045Yh@11JN40
0P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000@FWQ045Y
h@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`0C0?3io`80odD000@0l?Wo
0?m5003oA@00odD03@3`nOl30?m500030?3io`3oA@00odD007L0l?Wo00<00000045Yh@11JN400P11
JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl04P3`nOl00`3oA@00l?Wo0?3io`03
0?3io`030?m5003`nOl0l?Wo00X0l?Wo00<0odD00?3io`3`nOl00`3`nOl20?m507H0l?Wo00<00000
045Yh@11JN400P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl04P3`nOl00`3o
A@00l?Wo0?3io`040?3io`030?m5003`nOl0l?Wo00T0l?Wo00<0odD00?3io`3`nOl0103`nOl00`3o
A@00l?Wo0?3io`1d0?3io`0300000011JN40@FWQ0080@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP03
0000003`nOl0l?Wo0140l?Wo00<0odD00?3io`3`nOl01P3`nOl00`3oA@00l?Wo0?3io`070?3io`03
0?m5003`nOl0l?Wo00H0l?Wo00<0odD00?3io`3`nOl0L`3`nOl00`000000@FWQ045Yh@02045YhOl0
n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`0A0?3io`030?m5003`nOl0l?Wo00L0l?Wo
00<0odD00?3io`3`nOl01@3`nOl00`3oA@00l?Wo0?3io`070?3io`030?m5003`nOl0l?Wo01l0l?Wo
1000000^0?3io`@000007P3`nOl00`000000@FWQ045Yh@02045YhOl0n_3V3P3jl>H10?ooo`00>`3j
l>H00`000000l?Wo0?3io`0A0?3io`030?m5003`nOl0l?Wo00P0l?Wo00<0odD00?3io`3`nOl00`3`
nOl00`3oA@00l?Wo0?3io`080?3io`030?m5003`nOl0l?Wo0280l?Wo0P00000`0?3io`8000007@3`
nOl00`000000@FWQ045Yh@02045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`0A
0?3io`030?m5003`nOl0l?Wo00T0l?Wo00D0odD00?3io`3`nOl0l?Wo0?m5000;0?3io`030?m5003`
nOl0l?Wo00l0l?Wo1@0000030?3io`H000000P3`nOl2000000030?3io`000000000000<0l?Wo2P00
00030?3io`@000002@3`nOl7000000030?3io`000000000000@000000P3`nOl2000000040?3io`00
000000000?3io`<0000000@0l?Wo00000000000000000P3`nOl300000100l?Wo00<00000045Yh@11
JN400P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0403`nOl20?m500`0l?Wo
00<0odD00?3io`3oA@00303`nOl00`3oA@00l?Wo0?3io`0@0?3io`8000001`3`nOl2000000<0l?Wo
0P000000103`nOl000000000000000020?3io`80000000<0l?Wo0000000000000P3`nOl2000000@0
l?Wo0P0000030?3io`030000003`nOl0l?Wo00L0l?Wo0P0000030?3io`040000003`nOl0l?Wo0?3i
o`8000000`3`nOl2000000040?3io`000000000000000080l?Wo0P0000000`3`nOl0000000000002
0?3io`8000000P3`nOl00`000000l?Wo0?3io`0=0?3io`0300000011JN40@FWQ0080@FWQo`3jl>H>
0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0100l?Wo00<0odD00?3io`3`nOl0303`nOl00`3o
A@00l?Wo0?3io`0;0?3io`030?m5003`nOl0l?Wo0100l?Wo0P0000070?3io`8000000`3`nOl20000
0080l?Wo0P0000020?3io`80000000<0l?Wo0000000000000P3`nOl2000000@0l?Wo0P00000=0?3i
o`8000000`3`nOl010000000l?Wo0?3io`3`nOl2000000<0l?Wo0P0000020?3io`8000000P3`nOl2
000000030?3io`00000000000080l?Wo0P00000B0?3io`0300000011JN40@FWQ0080@FWQo`3jl>H>
0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0100l?Wo00<0odD00?3io`3`nOl02`3`nOl00`3o
A@00l?Wo0?m5000<0?3io`030?m5003`nOl0l?Wo0100l?Wo0P0000000`3`nOl000000?3io`040?3i
o`8000000`3`nOl200000080l?Wo0P0000020?3io`80000000<0l?Wo0000000000000P3`nOl20000
00@0l?Wo1P0000090?3io`80000000<0l?Wo0000003`nOl0103`nOl2000000<0l?Wo0P0000020?3i
o`8000000P3`nOl2000000030?3io`00000000000080l?Wo0P00000B0?3io`0300000011JN40@FWQ
0080@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo0140l?Wo00<0odD00?3io`3`
nOl02@3`nOl01@3oA@00l?Wo0?3io`3`nOl0odD000/0l?Wo00<0odD00?3io`3`nOl0403`nOl40000
00D0l?Wo0P0000030?3io`80000000@0l?Wo00000000000000000P3`nOl2000000030?3io`000000
00000080l?Wo0`0000000`3`nOl000000?3io`0200000080l?Wo0P0000090?3io`@000001@3`nOl2
000000<0l?Wo0P000000103`nOl000000000000000020?3io`80000000<0l?Wo0000000000000P3`
nOl200000180l?Wo00<00000045Yh@11JN400P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<00000
0?3io`3`nOl04@3`nOl00`3oA@00l?Wo0?3io`090?3io`050?m5003`nOl0l?Wo0?3io`3oA@002`3`
nOl00`3oA@00l?Wo0?3io`0@0?3io`80000000D0l?Wo0000003`nOl000000?3io`04000000@0l?Wo
0P0000000`3`nOl0000000000004000000040?3io`00000000000?3io`<0000000<0l?Wo00000000
00000P3`nOl4000000X0l?Wo0P0000001@3`nOl000000?3io`000000l?Wo00@00000103`nOl20000
00050?3io`00000000000000003`nOl0100000020?3io`D00000403`nOl00`000000@FWQ045Yh@02
045YhOl0n_3V3P3jl>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`0A0?3io`030?m5003`nOl0l?Wo
00P0l?Wo00<0odD00?3io`3`nOl00`3`nOl00`3oA@00l?Wo0?3io`080?3io`030?m5003`nOl0l?Wo
0100l?Wo0P0000030?3io`030000003`nOl0l?Wo02X0l?Wo0P0000030?3io`030000003`nOl0l?Wo
00h0l?Wo0P0000050?3io`8000004P3`nOl00`000000@FWQ045Yh@02045YhOl0n_3V3P3jl>H10?oo
o`00>`3jl>H00`000000l?Wo0?3io`0A0?3io`030?m5003`nOl0l?Wo00L0l?Wo00<0odD00?3io`3`
nOl01@3`nOl00`3oA@00l?Wo0?3io`070?3io`030?m5003`nOl0l?Wo00l0l?Wo1`0000030?3io`80
00009P3`nOl7000000<0l?Wo0P00000:0?3io`<000001@3`nOl200000180l?Wo00<00000045Yh@11
JN400P11JN7o0?[`iPh0n_3V0@3oool003/0n_3V00<000000?3io`3`nOl04@3`nOl00`3oA@00l?Wo
0?3io`060?3io`030?m5003`nOl0l?Wo00L0l?Wo00<0odD00?3io`3`nOl01P3`nOl00`3oA@00l?Wo
0?3io`1c0?3io`0300000011JN40@FWQ0080@FWQo`3jl>H>0?[`iP40oooo000k0?[`iP030000003`
nOl0l?Wo0180l?Wo00<0odD00?3io`3`nOl0103`nOl00`3oA@00l?Wo0?3io`090?3io`030?m5003`
nOl0l?Wo00@0l?Wo00<0odD00?3io`3`nOl0M03`nOl00`000000@FWQ045Yh@02045YhOl0n_3V3P3j
l>H10?ooo`00>`3jl>H00`000000l?Wo0?3io`0B0?3io`80odD00`3`nOl20?m500d0l?Wo00<0odD0
0?3io`3`nOl00P3`nOl00`3oA@00l?Wo0?3io`1e0?3io`0300000011JN40@FWQ0080@FWQo`3jl>H>
0?[`iP40oooo000k0?[`iP030000003`nOl0l?Wo01<0l?Wo103oA@0@0?3io`D0odD0M`3`nOl00`00
0000n_3V0?[`iP3o0?[`iQ00n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000
n_3V0?[`iP3o0?[`iQ00n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000n_3V
0?[`iP3o0?[`iQ00n_3V0@3oool003/0n_3V00<000000?3io`3`nOl0X`3`nOl00`000000n_3V0?[`
iP3o0?[`iQ00n_3V0@3oool003/0n_3VY`00003o0?[`iQ80n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo
003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo001V0?[`iP<00000=03jl>H5000003<0n_3V1P00000_0?[`
iP<00000=@3jl>H600000380n_3V1@00000d0?[`iP<00000?@3jl>H10?ooo`00I@3jl>H00`000000
n_3V0?[`iP02000003<0n_3V0P00000h0?[`iP800000<03jl>H2000000030?[`iP000000000003H0
n_3V0P00000d0?[`iP800000=P3jl>H00`000000n_3V0?[`iP02000003`0n_3V0@3oool005d0n_3V
1@0000060?[`iP800000:`3jl>H5000000@0n_3V0P00000]0?[`iPD000001@3jl>H200000300n_3V
0P0000000`3jl>H000000000000f0?[`iP800000=@3jl>H2000003P0n_3V0P00000l0?[`iP40oooo
001X0?[`iP800000=@3jl>H2000003H0n_3V0P00000`0?[`iP80000000<0n_3V000000000000=P3j
l>H2000003H0n_3V0P00000g0?[`iP800000?03jl>H10?ooo`00IP3jl>H3000003L0n_3V0P00000e
0?[`iP800000<03jl>H2000000030?[`iP000000000003H0n_3V0P00000g0?[`iP800000=03jl>H3
000003d0n_3V0@3oool006P0n_3V0P00000c0?[`iP80000000<0n_3V000000000000=@3jl>H20000
0300n_3V0P0000000`3jl>H000000000000f0?[`iP800000=03jl>H2000000030?[`iP0000000000
03H0n_3V0P00000l0?[`iP40oooo001U0?[`iP030000003jl>H0n_3V00800000<`3jl>H200000003
0?[`iP000000000003<0n_3V1000000`0?[`iP80000000<0n_3V000000000000=03jl>H4000003@0
n_3V0P0000000`3jl>H000000000000c0?[`iP030000003jl>H0n_3V00800000?03jl>H10?ooo`00
IP3jl>H3000003D0n_3V0`00000f0?[`iP800000<@3jl>H3000003L0n_3V0P00000e0?[`iP<00000
=@3jl>H3000003d0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00CP3jl>H6000000L0n_3Vo`00001T000003D0n_3V0@3oool00500
n_3V0P0000090?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0203jl>H00`000000
n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000
n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000
n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000
n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000
n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000
n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000
n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000
n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000
n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000
n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000
n_3V0?[`iP0c0?[`iP40oooo00160?[`iPD000001@3jl>H2000000T0n_3V00<000000?[`iP3jl>H0
1@3jl>H00`000000n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V03H0n_3V00<000000?[`iP3jl>H0
=@3jl>H00`000000n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0
=P3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V03<0n_3V0@3oool00500n_3V0P00
00090?[`iP<00000C03jl>H<0000o`l0odD0T03jl>H>0?m505P0n_3V0`00000e0?[`iP40oooo001@
0?[`iP8000002@3jl>H00`000000n_3V0?[`iP170?[`iPD0003o2`3jl>H00`3oA@00n_3V0?[`iP05
0?[`iPL0003o00@0n_3V0?m5003oA@00odD0RP3jl>H30?m500h0n_3V0P3oA@1H0?[`iP030000003j
l>H0n_3V03<0n_3V0@3oool00500n_3V0P0000090?[`iP030000003jl>H0n_3V04<0n_3V10000?l=
0?[`iP<0odD03`3jl>H30000o`040?[`iP3oA@00odD00?m508@0n_3V0`3oA@0C0?[`iP80odD0EP3j
l>H00`000000n_3V0?[`iP0c0?[`iP40oooo001>0?[`iP@000002@3jl>H00`000000n_3V0?[`iP11
0?[`iP80003o3`3jl>H20?m501D0n_3V0P000?l20?[`iP80odD0P03jl>H20?m501P0n_3V0P3oA@1D
0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool00500n_3V0P0000090?[`iP030000003jl>H0n_3V
03l0n_3V0P000?l?0?[`iP80odD06@3jl>H20000o`80n_3V0P3oA@1l0?[`iP80odD0703jl>H20?m5
0580n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H2000003h0n_3V0P000?l@0?[`iP03
0?m5003jl>H0n_3V01/0n_3V0P000?l20?[`iP80odD0N03jl>H20?m50200n_3V00<0odD00?[`iP3j
l>H0CP3jl>H2000003D0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0>`3jl>H20000oa40n_3V
00<0odD00?[`iP3jl>H07P3jl>H20000o`80n_3V0P3oA@1d0?[`iP80odD08`3jl>H00`3oA@00n_3V
0?[`iP1>0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0>@3j
l>H20000oa40n_3V0P3oA@0S0?[`iP80003o0P3jl>H20?m50700n_3V0P3oA@0V0?[`iP030?m5003j
l>H0n_3V04d0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0g
0?[`iP80003o4P3jl>H00`3oA@00n_3V0?[`iP0U0?[`iP80003o0P3jl>H00`3oA@00n_3V0?[`iP1[
0?[`iP80odD0:@3jl>H00`3oA@00n_3V0?[`iP1<0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool0
05/0n_3V00<000000?[`iP3jl>H0=@3jl>H20000oa@0n_3V00<0odD00?[`iP3jl>H09`3jl>H20000
o`030?[`iP3oA@00odD006X0n_3V00<0odD00?[`iP3jl>H0:P3jl>H00`3oA@00n_3V0?[`iP1;0?[`
iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0<`3jl>H20000oaD0
n_3V00<0odD00?[`iP3jl>H0:P3jl>H20000o`030?[`iP3oA@00n_3V06H0n_3V0P3oA@0]0?[`iP03
0?m5003jl>H0n_3V04/0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H200000380n_3V
0P000?lG0?[`iP030?m5003jl>H0n_3V02`0n_3V00@0003o0?[`iP3oA@00odD0I03jl>H00`3oA@00
n_3V0?[`iP0^0?[`iP030?m5003jl>H0n_3V04T0n_3V0P00000e0?[`iP40oooo001K0?[`iP030000
003jl>H0n_3V0300n_3V00<0003o0?[`iP3jl>H05P3jl>H00`3oA@00n_3V0?[`iP0^0?[`iP80003o
00<0n_3V0?m5003oA@00H@3jl>H00`3oA@00n_3V0?[`iP0`0?[`iP030?m5003jl>H0n_3V04T0n_3V
00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0^0?[`iP80003o603j
l>H00`3oA@00n_3V0?[`iP0a0?[`iP040000o`3jl>H0n_3V0?m505h0n_3V0P3oA@0d0?[`iP030?m5
003jl>H0n_3V04P0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`
iP0]0?[`iP030000o`3jl>H0n_3V01P0n_3V00<0odD00?[`iP3jl>H0<P3jl>H20000o`030?[`iP3o
A@00odD005/0n_3V00<0odD00?[`iP3jl>H0=03jl>H00`3oA@00n_3V0?[`iP180?[`iP030000003j
l>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0;03jl>H00`000?l0n_3V0?[`iP0H
0?[`iP030?m5003jl>H0n_3V03D0n_3V0P000?l00`3jl>H0odD00?[`iP1G0?[`iP80odD0>03jl>H0
0`3oA@00n_3V0?[`iP170?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V0P00000[0?[`
iP80003o6`3jl>H00`3oA@00n_3V0?[`iP0g0?[`iP030000o`3jl>H0odD005H0n_3V00<0odD00?[`
iP3jl>H0>@3jl>H00`3oA@00n_3V0?[`iP150?[`iP800000=@3jl>H10?ooo`00F`3jl>H00`000000
n_3V0?[`iP0Y0?[`iP030000o`3jl>H0n_3V01X0n_3V00<0odD00?[`iP3jl>H0>@3jl>H20000o`03
0?m5003jl>H0n_3V0580n_3V00<0odD00?[`iP3jl>H0>P3jl>H00`3oA@00n_3V0?[`iP160?[`iP03
0000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H09`3jl>H20000oa`0n_3V
00<0odD00?[`iP3jl>H0?03jl>H00`000?l0odD00?m5001@0?[`iP80odD0?P3jl>H00`3oA@00n_3V
0?[`iP150?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H09P3j
l>H00`000?l0n_3V0?[`iP0L0?[`iP030?m5003jl>H0n_3V03d0n_3V00<0003o0?[`iP3oA@00CP3j
l>H00`3oA@00n_3V0?[`iP0n0?[`iP030?m5003jl>H0n_3V04D0n_3V00<000000?[`iP3jl>H0<`3j
l>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0U0?[`iP030000o`3jl>H0n_3V01`0n_3V00<0odD0
0?[`iP3jl>H0?`3jl>H20000o`030?m5003jl>H0n_3V04X0n_3V00<0odD00?[`iP3jl>H0?`3jl>H0
0`3oA@00n_3V0?[`iP150?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`
iP3jl>H08`3jl>H20000oal0n_3V00<0odD00?[`iP3jl>H0@@3jl>H00`000?l0odD00?[`iP180?[`
iP80odD0@`3jl>H00`3oA@00n_3V0?[`iP140?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0
n_3V0P00000S0?[`iP030000o`3jl>H0n_3V01h0n_3V00<0odD00?[`iP3jl>H0@`3jl>H00`000?l0
odD00?[`iP160?[`iP030?m5003jl>H0n_3V04<0n_3V00<0odD00?[`iP3jl>H0@`3jl>H2000003D0
n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H08@3jl>H00`000?l0n_3V0?[`iP0O0?[`iP030?m5
003jl>H0n_3V04@0n_3V00<0003o0?m5003jl>H0A03jl>H00`3oA@00n_3V0?[`iP140?[`iP030?m5
003jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`
iP0P0?[`iP030000o`3jl>H0n_3V0200n_3V00<0odD00?[`iP3jl>H0A@3jl>H00`000?l0odD00?m5
00110?[`iP80odD0B03jl>H00`3oA@00n_3V0?[`iP130?[`iP030000003jl>H0n_3V03<0n_3V0@3o
ool005/0n_3V00<000000?[`iP3jl>H07P3jl>H20000ob80n_3V00<0odD00?[`iP3jl>H0B03jl>H0
0`000?l0odD00?[`iP0n0?[`iP030?m5003jl>H0n_3V04P0n_3V00<0odD00?[`iP3jl>H0@`3jl>H0
0`000000n_3V0?[`iP0c0?[`iP40oooo00110?[`iP<00000103jl>H2000000D0n_3V0`0000090?[`
iP030000003jl>H0n_3V01d0n_3V00<0003o0?[`iP3jl>H08P3jl>H00`3oA@00n_3V0?[`iP190?[`
iP030000o`3oA@00n_3V03`0n_3V00<0odD00?[`iP3jl>H0BP3jl>H00`3oA@00n_3V0?[`iP120?[`
iP030000003jl>H0n_3V03<0n_3V0@3oool00400n_3V0P0000000`3jl>H00000000000030?[`iP80
0000103jl>H00`000000n_3V0?[`iP02000000P0n_3V00<000000?[`iP3jl>H0703jl>H00`000?l0
n_3V0?[`iP0S0?[`iP030?m5003jl>H0n_3V04X0n_3V00<0003o0?m5003jl>H0>P3jl>H00`3oA@00
n_3V0?[`iP1;0?[`iP030?m5003jl>H0n_3V0480n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00
>03jl>H5000000<0n_3V0P0000000`3jl>H000000000000<0?[`iP800000203jl>H3000001/0n_3V
00<0003o0?[`iP3jl>H08`3jl>H00`3oA@00n_3V0?[`iP1=0?[`iP030?m5003jl>H0n_3V03L0n_3V
00<0odD00?[`iP3jl>H0C@3jl>H00`3oA@00n_3V0?[`iP0o0?[`iP<00000=@3jl>H10?ooo`00@03j
l>H2000000030?[`iP000000000000`0n_3V0P0000080?[`iP030000003jl>H0n_3V01X0n_3V00<0
003o0?[`iP3jl>H0903jl>H00`3oA@00n_3V0?[`iP1>0?[`iP030?m5003jl>H0n_3V03D0n_3V00<0
odD00?[`iP3jl>H0CP3jl>H00`3oA@00n_3V0?[`iP110?[`iP030000003jl>H0n_3V03<0n_3V0@3o
ool00400n_3V0P0000000`3jl>H00000000000090?[`iP030000003jl>H0n_3V00800000203jl>H0
0`000000n_3V0?[`iP0I0?[`iP030000o`3jl>H0n_3V02D0n_3V00<0odD00?[`iP3jl>H0C`3jl>H0
0`3oA@00n_3V0?[`iP0c0?[`iP030?m5003jl>H0n_3V04l0n_3V00<0odD00?[`iP3jl>H0@@3jl>H0
0`000000n_3V0?[`iP0c0?[`iP40oooo00100?[`iP80000000<0n_3V0000000000002@3jl>H40000
00T0n_3V00<000000?[`iP3jl>H0603jl>H00`000?l0n_3V0?[`iP0U0?[`iP030?m5003jl>H0n_3V
0540n_3V00<0odD00?[`iP3jl>H0<@3jl>H00`3oA@00n_3V0?[`iP1@0?[`iP030?m5003jl>H0n_3V
0440n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00@03jl>H2000000030?[`iP000000000000T0
n_3V0P00000;0?[`iP030000003jl>H0n_3V01H0n_3V0P000?lX0?[`iP030?m5003jl>H0n_3V0580
n_3V00<0odD00?[`iP3jl>H0;`3jl>H00`3oA@00n_3V0?[`iP1B0?[`iP030?m5003jl>H0n_3V0400
n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00@@3jl>H3000000X0n_3V1@0000080?[`iP800000
5P3jl>H00`000?l0n_3V0?[`iP0X0?[`iP030?m5003jl>H0n_3V05<0n_3V00<0odD00?[`iP3jl>H0
;@3jl>H00`3oA@00n_3V0?[`iP1C0?[`iP030?m5003jl>H0n_3V03l0n_3V0P00000e0?[`iP40oooo
001K0?[`iP030000003jl>H0n_3V01@0n_3V00<0003o0?[`iP3jl>H0:@3jl>H00`3oA@00n_3V0?[`
iP1D0?[`iP030?m5003jl>H0n_3V02/0n_3V00<0odD00?[`iP3jl>H0E03jl>H00`3oA@00n_3V0?[`
iP100?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H04`3jl>H0
0`000?l0n_3V0?[`iP0Y0?[`iP030?m5003jl>H0n_3V05H0n_3V00<0odD00?[`iP3jl>H0:@3jl>H0
0`3oA@00n_3V0?[`iP1E0?[`iP030?m5003jl>H0n_3V0400n_3V00<000000?[`iP3jl>H0<`3jl>H1
0?ooo`00F`3jl>H00`000000n_3V0?[`iP0B0?[`iP030000o`3jl>H0n_3V02X0n_3V00<0odD00?[`
iP3jl>H0E`3jl>H00`3oA@00003o0?[`iP0W0?[`iP030?m5003jl>H0n_3V05H0n_3V00<0odD00?[`
iP3jl>H0@03jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V0140
n_3V00<0003o0?[`iP3jl>H0:`3jl>H00`3oA@00n_3V0?[`iP1H0?[`iP030?m500000?l0n_3V02D0
n_3V00<0odD00?[`iP3jl>H0E`3jl>H00`3oA@00n_3V0?[`iP100?[`iP030000003jl>H0n_3V03<0
n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0403jl>H00`000?l0n_3V0?[`iP0/0?[`iP030?m5
003jl>H0n_3V05T0n_3V00<0odD00000o`3jl>H08`3jl>H00`3oA@00n_3V0?[`iP1I0?[`iP030?m5
003jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H200000100n_3V00<0
003o0?[`iP3jl>H0;@3jl>H00`3oA@00n_3V0?[`iP1J0?[`iP030?m500000?l0n_3V0240n_3V00<0
odD00?[`iP3jl>H0FP3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP800000=@3jl>H10?ooo`00F`3jl>H0
0`000000n_3V0?[`iP0>0?[`iP030000o`3jl>H0n_3V02h0n_3V00<0odD00?[`iP3jl>H0F`3jl>H0
0`3oA@00003o0?[`iP0N0?[`iP80odD0G@3jl>H00`3oA@00n_3V0?[`iP0o0?[`iP030000003jl>H0
n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H03@3jl>H00`000?l0n_3V0?[`iP0_0?[`
iP030?m5003jl>H0n_3V05`0n_3V0P3oA@0M0?[`iP030?m5003jl>H0n_3V05h0n_3V00<0odD00?[`
iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V00/0
n_3V0P000?la0?[`iP030?m5003jl>H0n_3V05l0n_3V00<0odD00?[`iP3jl>H06@3jl>H00`3oA@00
n_3V0?[`iP1O0?[`iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00
F`3jl>H00`000000n_3V0?[`iP0:0?[`iP030000o`3jl>H0n_3V0340n_3V00<0odD00?[`iP3jl>H0
H03jl>H00`3oA@00n_3V0?[`iP0G0?[`iP030?m5003jl>H0n_3V0600n_3V00<0odD00?[`iP3jl>H0
?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V00T0n_3V00<0
003o0?[`iP3jl>H0<P3jl>H00`3oA@00n_3V0?[`iP1Q0?[`iP030?m5003jl>H0n_3V01D0n_3V00<0
odD00?[`iP3jl>H0H@3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3o
ool005/0n_3V0P0000090?[`iP030000o`3jl>H0n_3V03<0n_3V00<0odD00?[`iP3jl>H0HP3jl>H0
0`3oA@00n_3V0?[`iP0C0?[`iP030?m5003jl>H0n_3V0680n_3V00<0odD00?[`iP3jl>H0?@3jl>H2
000003D0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H01`3jl>H00`000?l0n_3V0?[`iP0d0?[`
iP030?m5003jl>H0n_3V06<0n_3V00<0odD00?[`iP3jl>H04@3jl>H00`3oA@00n_3V0?[`iP1S0?[`
iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000
n_3V0?[`iP060?[`iP030000o`3jl>H0n_3V03D0n_3V00<0odD00?[`iP3jl>H0I03jl>H00`3oA@00
n_3V0?[`iP0?0?[`iP030?m5003jl>H0n_3V06@0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000
n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V00D0n_3V00<0003o0?[`iP3jl>H0
=P3jl>H00`3oA@00n_3V0?[`iP1U0?[`iP030?m5003jl>H0n_3V00d0n_3V00<0odD00?[`iP3jl>H0
I@3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<0
00000?[`iP3jl>H0?P3jl>H00`3oA@00n_3V0?[`iP1V0?[`iP030?m5003jl>H0n_3V00/0n_3V00<0
odD00?[`iP3jl>H0IP3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3o
ool005/0n_3V0P00000o0?[`iP030?m5003jl>H0n_3V06L0n_3V00<0odD00?[`iP3jl>H02@3jl>H0
0`3oA@00n_3V0?[`iP1W0?[`iP030?m5003jl>H0n_3V03d0n_3V0P00000e0?[`iP40oooo001K0?[`
iP030000003jl>H0n_3V03h0n_3V00<0odD00?[`iP3jl>H0J03jl>H00`3oA@00n_3V0?[`iP070?[`
iP030?m5003jl>H0n_3V06P0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`
iP40oooo001K0?[`iP030000003jl>H0n_3V03d0n_3V00<0odD00?[`iP3jl>H0JP3jl>H00`3oA@00
n_3V0?[`iP050?[`iP030?m5003jl>H0n_3V06T0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000
n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V03d0n_3V00<0odD00?[`iP3jl>H0
J`3jl>H00`3oA@00n_3V0?[`iP030?[`iP030?m5003jl>H0n_3V06X0n_3V00<0odD00?[`iP3jl>H0
?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001?0?[`iP<000002@3jl>H00`000000n_3V0?[`
iP0m0?[`iP030?m5003jl>H0n_3V06`0n_3V00D0odD00?[`iP3jl>H0n_3V0?m5001]0?[`iP030?m5
003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00CP3jl>H2000000030?[`iP00
0000000000P0n_3V00<000000?[`iP3jl>H0?@3jl>H00`3oA@00n_3V0?[`iP1]0?[`iP030?m5003j
l>H0odD006h0n_3V00<0odD00?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001>
0?[`iP80000000<0n_3V000000000000203jl>H3000003d0n_3V00<0odD00?[`iP3jl>H0KP3jl>H0
0`3oA@00n_3V0?[`iP1]0?[`iP030?m5003jl>H0n_3V03`0n_3V0`00000e0?[`iP40oooo001>0?[`
iP80000000<0n_3V000000000000203jl>H00`000000n_3V0?[`iP0m0?[`iP030?m5003jl>H0n_3V
06d0n_3V00<0odD00?[`iP3oA@00KP3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V
03<0n_3V0@3oool004h0n_3V0P0000000`3jl>H00000000000080?[`iP030000003jl>H0n_3V03d0
n_3V00<0odD00?[`iP3jl>H0K03jl>H01@3oA@00n_3V0?[`iP3jl>H0odD006d0n_3V00<0odD00?[`
iP3jl>H0?P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001>0?[`iP80000000<0n_3V00000000
0000203jl>H00`000000n_3V0?[`iP0m0?[`iP030?m5003jl>H0n_3V06/0n_3V00<0odD00?[`iP3j
l>H00`3jl>H00`3oA@00n_3V0?[`iP1Z0?[`iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`iP3j
l>H0<`3jl>H10?ooo`00CP3jl>H2000000030?[`iP000000000000P0n_3V00<000000?[`iP3jl>H0
?@3jl>H00`3oA@00n_3V0?[`iP1Z0?[`iP030?m5003jl>H0n_3V00D0n_3V00<0odD00?[`iP3jl>H0
J@3jl>H00`3oA@00n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool004l0n_3V0`00
00090?[`iP800000?`3jl>H00`3oA@00n_3V0?[`iP1X0?[`iP030?m5003jl>H0n_3V00L0n_3V00<0
odD00?[`iP3jl>H0J03jl>H00`3oA@00n_3V0?[`iP0m0?[`iP800000=@3jl>H10?ooo`00F`3jl>H0
0`000000n_3V0?[`iP0n0?[`iP030?m5003jl>H0n_3V06L0n_3V00<0odD00?[`iP3jl>H02@3jl>H0
0`3oA@00n_3V0?[`iP1W0?[`iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0<`3jl>H1
0?ooo`00F`3jl>H00`000000n_3V0?[`iP0n0?[`iP030?m5003jl>H0n_3V06H0n_3V00<0odD00?[`
iP3jl>H02`3jl>H00`3oA@00n_3V0?[`iP1V0?[`iP030?m5003jl>H0n_3V03h0n_3V00<000000?[`
iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0n0?[`iP030?m5003jl>H0n_3V06D0
n_3V00<0odD00?[`iP3jl>H03@3jl>H00`3oA@00n_3V0?[`iP1U0?[`iP030?m5003jl>H0n_3V03D0
n_3V0P000?l70?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0
?P3jl>H00`3oA@00n_3V0?[`iP1T0?[`iP030?m5003jl>H0n_3V00l0n_3V00<0odD00?[`iP3jl>H0
I03jl>H00`3oA@00n_3V0?[`iP0d0?[`iP030000o`3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0n0?[`iP030?m5003jl>H0n_3V06<0n_3V00<0
odD00?[`iP3jl>H04@3jl>H00`3oA@00n_3V0?[`iP1S0?[`iP030?m5003jl>H0n_3V03<0n_3V00<0
003o0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP800000?`3jl>H0
0`3oA@00n_3V0?[`iP1R0?[`iP030?m5003jl>H0n_3V01<0n_3V00<0odD00?[`iP3jl>H0HP3jl>H0
0`3oA@00n_3V0?[`iP0b0?[`iP030000o`3jl>H0n_3V00P0n_3V0P00000e0?[`iP40oooo001K0?[`
iP030000003jl>H0n_3V03h0n_3V00<0odD00?[`iP3jl>H0H@3jl>H00`3oA@00n_3V0?[`iP0E0?[`
iP030?m5003jl>H0n_3V0640n_3V00<0odD00?[`iP3jl>H0<@3jl>H00`000?l0n_3V0?[`iP0:0?[`
iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?P3jl>H00`3oA@00
n_3V0?[`iP1O0?[`iP80odD06@3jl>H00`3oA@00n_3V0?[`iP1P0?[`iP030?m5003jl>H0n_3V0300
n_3V00<0003o0?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000
003jl>H0n_3V03h0n_3V00<0odD00?[`iP3jl>H0GP3jl>H00`3oA@00n_3V0?[`iP0J0?[`iP80odD0
G`3jl>H00`3oA@00n_3V0?[`iP0`0?[`iP030000o`3jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP0o0?[`iP030?m5003jl>H0n_3V05`0n_3V00<0
odD00?[`iP3jl>H0703jl>H00`000?l0odD00?[`iP1M0?[`iP030?m5003jl>H0n_3V02l0n_3V00<0
003o0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0
n_3V03l0n_3V00<0odD00?[`iP3jl>H0F`3jl>H00`3oA@00n_3V0?[`iP0N0?[`iP030000o`3oA@00
n_3V05`0n_3V00<0odD00?[`iP3jl>H0;P3jl>H00`000?l0n_3V0?[`iP0>0?[`iP030000003jl>H0
n_3V03<0n_3V0@3oool005/0n_3V0P0000100?[`iP030?m5003jl>H0n_3V05X0n_3V00<0odD00?[`
iP3jl>H0803jl>H00`000?l0odD00?[`iP1K0?[`iP030?m5003jl>H0n_3V02d0n_3V00<0003o0?[`
iP3jl>H03P3jl>H2000003D0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3oA@00
n_3V0?[`iP1I0?[`iP030?m5003jl>H0n_3V02<0n_3V00<0odD00?[`iP3jl>H0F@3jl>H00`3oA@00
n_3V0?[`iP0/0?[`iP030000o`3jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00
F`3jl>H00`000000n_3V0?[`iP0o0?[`iP030?m5003jl>H0n_3V05P0n_3V00<0odD00?[`iP3jl>H0
9@3jl>H00`3oA@00n_3V0?[`iP1G0?[`iP030?m5003jl>H0n_3V02`0n_3V00<0003o0?[`iP3jl>H0
4@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V03l0n_3V00<0
odD00?[`iP3jl>H0E`3jl>H00`3oA@00n_3V0?[`iP0W0?[`iP030?m5003jl>H0n_3V05H0n_3V00<0
odD00?[`iP3jl>H0:`3jl>H00`000?l0n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V03<0n_3V0@3o
ool005/0n_3V00<000000?[`iP3jl>H0?`3jl>H00`3oA@00n_3V0?[`iP1F0?[`iP030?m5003jl>H0
n_3V02T0n_3V00<0odD00?[`iP3jl>H0E@3jl>H00`3oA@00n_3V0?[`iP0Z0?[`iP030000o`3jl>H0
n_3V01<0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H200000440n_3V00<0odD00?[`
iP3jl>H0E03jl>H00`3oA@00n_3V0?[`iP0[0?[`iP030?m5003jl>H0n_3V05@0n_3V00<0odD00?[`
iP3jl>H0:@3jl>H00`000?l0n_3V0?[`iP0C0?[`iP800000=@3jl>H10?ooo`00F`3jl>H00`000000
n_3V0?[`iP100?[`iP030?m5003jl>H0n_3V05<0n_3V00<0odD00?[`iP3jl>H0;@3jl>H00`3oA@00
n_3V0?[`iP1C0?[`iP030?m5003jl>H0n_3V02P0n_3V00<0003o0?[`iP3jl>H05@3jl>H00`000000
n_3V0?[`iP0c0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V0400n_3V00<0odD00?[`iP3jl>H0
DP3jl>H00`3oA@00n_3V0?[`iP0_0?[`iP030?m500000?l0n_3V0540n_3V00<0odD00?[`iP3jl>H0
:03jl>H00`000?l0n_3V0?[`iP0F0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V00<0
00000?[`iP3jl>H0@@3jl>H00`3oA@00n_3V0?[`iP1@0?[`iP030?m5003jl>H0n_3V0340n_3V00<0
odD00000o`3jl>H0D03jl>H00`3oA@00n_3V0?[`iP0V0?[`iP80003o6@3jl>H00`000000n_3V0?[`
iP0c0?[`iP40oooo00110?[`iP<00000103jl>H2000000D0n_3V0`0000090?[`iP030000003jl>H0
n_3V0440n_3V00<0odD00?[`iP3jl>H0C`3jl>H00`3oA@00n_3V0?[`iP0c0?[`iP030?m500000?l0
n_3V04l0n_3V00<0odD00?[`iP3jl>H09@3jl>H00`000?l0n_3V0?[`iP0I0?[`iP030000003jl>H0
n_3V03<0n_3V0@3oool00400n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H00`00
0000n_3V0?[`iP02000000P0n_3V00<000000?[`iP3jl>H0@@3jl>H00`3oA@00n_3V0?[`iP1>0?[`
iP030?m5003jl>H0n_3V03D0n_3V00<0odD00000o`3jl>H0CP3jl>H00`3oA@00n_3V0?[`iP0T0?[`
iP030000o`3jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00@03jl>H200000003
0?[`iP000000000000`0n_3V0P0000080?[`iP<00000@@3jl>H00`3oA@00n_3V0?[`iP1=0?[`iP03
0?m5003jl>H0n_3V03L0n_3V00<0odD00000o`3jl>H0C03jl>H00`3oA@00n_3V0?[`iP0T0?[`iP03
0000o`3jl>H0n_3V01T0n_3V0`00000e0?[`iP40oooo00100?[`iP80000000<0n_3V000000000000
303jl>H2000000P0n_3V00<000000?[`iP3jl>H0@P3jl>H00`3oA@00n_3V0?[`iP1:0?[`iP80odD0
>`3jl>H00`3oA@00003o0?[`iP1;0?[`iP030?m5003jl>H0n_3V02<0n_3V00<0003o0?[`iP3jl>H0
703jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo00100?[`iP80000000<0n_3V0000000000002@3j
l>H00`000000n_3V0?[`iP02000000P0n_3V00<000000?[`iP3jl>H0@P3jl>H00`3oA@00n_3V0?[`
iP190?[`iP030?m5003jl>H0n_3V03`0n_3V0P3oA@000`000?l0n_3V0?[`iP180?[`iP030?m5003j
l>H0n_3V0280n_3V00<0003o0?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo0010
0?[`iP80000000<0n_3V0000000000002@3jl>H4000000T0n_3V00<000000?[`iP3jl>H0@P3jl>H0
0`3oA@00n_3V0?[`iP180?[`iP030?m5003jl>H0n_3V03l0n_3V00<0odD00000o`3jl>H0A`3jl>H0
0`3oA@00n_3V0?[`iP0Q0?[`iP80003o803jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo00100?[`
iP80000000<0n_3V0000000000002@3jl>H2000000/0n_3V00<000000?[`iP3jl>H0@`3jl>H00`3o
A@00n_3V0?[`iP160?[`iP030?m5003jl>H0n_3V0440n_3V00<0odD00000o`3jl>H0AP3jl>H00`3o
A@00n_3V0?[`iP0P0?[`iP030000o`3jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0<`3jl>H10?oo
o`00@@3jl>H3000000X0n_3V1@0000080?[`iP030000003jl>H0n_3V04<0n_3V00<0odD00?[`iP3j
l>H0A03jl>H20?m504D0n_3V00<0odD00000o`3jl>H0A@3jl>H00`3oA@00n_3V0?[`iP0O0?[`iP03
0000o`3jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H2000004D0n_3V
00<0odD00?[`iP3jl>H0@P3jl>H00`3oA@00n_3V0?[`iP160?[`iP030?m500000?l0n_3V04<0n_3V
00<0odD00?[`iP3jl>H07`3jl>H00`000?l0n_3V0?[`iP0Q0?[`iP800000=@3jl>H10?ooo`00F`3j
l>H00`000000n_3V0?[`iP140?[`iP030?m5003jl>H0n_3V0440n_3V00<0odD00?[`iP3jl>H0B03j
l>H00`3oA@00003o0?[`iP120?[`iP030?m5003jl>H0n_3V01d0n_3V0P000?lU0?[`iP030000003j
l>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0A03jl>H00`3oA@00n_3V0?[`iP10
0?[`iP030?m5003jl>H0n_3V04X0n_3V0P3oA@000`000?l0n_3V0?[`iP0o0?[`iP030?m5003jl>H0
n_3V01`0n_3V00<0003o0?[`iP3jl>H09@3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo001K0?[`
iP030000003jl>H0n_3V04D0n_3V00<0odD00?[`iP3jl>H0?@3jl>H20?m504l0n_3V00<0odD00000
o`3jl>H0?P3jl>H00`3oA@00n_3V0?[`iP0L0?[`iP030000o`3jl>H0n_3V02H0n_3V00<000000?[`
iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP150?[`iP030?m5003jl>H0n_3V03`0
n_3V00<0odD00?[`iP3jl>H0D03jl>H00`3oA@00003o0?[`iP0m0?[`iP030?m5003jl>H0n_3V01X0
n_3V0P000?lY0?[`iP030000003jl>H0n_3V03<0n_3V0@3oool005/0n_3V0P0000170?[`iP030?m5
003jl>H0n_3V03X0n_3V00<0odD00?[`iP3jl>H0DP3jl>H00`3oA@00003o0?[`iP0k0?[`iP030?m5
003jl>H0n_3V01X0n_3V00<0003o0?[`iP3jl>H0:03jl>H2000003D0n_3V0@3oool005/0n_3V00<0
00000?[`iP3jl>H0AP3jl>H00`3oA@00n_3V0?[`iP0i0?[`iP030?m5003jl>H0n_3V05@0n_3V0P3o
A@000`000?l0n_3V0?[`iP0h0?[`iP030?m5003jl>H0n_3V01P0n_3V0P000?l/0?[`iP030000003j
l>H0n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0A`3jl>H00`3oA@00n_3V0?[`iP0g
0?[`iP030?m5003jl>H0n_3V05L0n_3V00<0odD00000o`000?l0=`3jl>H00`3oA@00n_3V0?[`iP0H
0?[`iP030000o`3jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`00
0000n_3V0?[`iP180?[`iP030?m5003jl>H0n_3V03@0n_3V0P3oA@1K0?[`iP80odD000<0003o0?[`
iP3jl>H0=03jl>H00`3oA@00n_3V0?[`iP0G0?[`iP030000o`3jl>H0n_3V02d0n_3V00<000000?[`
iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP180?[`iP030?m5003jl>H0n_3V03<0
n_3V00<0odD00?[`iP3jl>H0G@3jl>H20?m500030000o`3jl>H0n_3V0340n_3V00<0odD00?[`iP3j
l>H05P3jl>H20000oc00n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V
0?[`iP190?[`iP030?m5003jl>H0n_3V0340n_3V00<0odD00?[`iP3jl>H0H03jl>H00`3oA@00003o
0?[`iP0a0?[`iP030?m5003jl>H0n_3V01D0n_3V00<0003o0?[`iP3jl>H0<03jl>H00`000000n_3V
0?[`iP0c0?[`iP40oooo001K0?[`iP800000B`3jl>H00`3oA@00n_3V0?[`iP0^0?[`iP80odD0I03j
l>H20?m500030000o`3jl>H0n_3V02d0n_3V00<0odD00?[`iP3jl>H0503jl>H20000oc80n_3V0P00
000e0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V04/0n_3V00<0odD00?[`iP3jl>H0:`3jl>H2
0?m506P0n_3V00<0odD00000o`000?l0;03jl>H00`3oA@00n_3V0?[`iP0D0?[`iP030000o`3jl>H0
n_3V03<0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000n_3V0?[`iP1;0?[`
iP030?m5003jl>H0n_3V02T0n_3V0P3oA@1[0?[`iP030?m5003jl>H0003o02X0n_3V00<0odD00?[`
iP3jl>H04`3jl>H20000ocH0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00F`3jl>H00`000000
n_3V0?[`iP1<0?[`iP030?m5003jl>H0n_3V02L0n_3V00<0odD00?[`iP3jl>H0K03jl>H20?m50080
003o9`3jl>H00`3oA@00n_3V0?[`iP0B0?[`iP80003o>03jl>H00`000000n_3V0?[`iP0c0?[`iP40
oooo001K0?[`iP030000003jl>H0n_3V04d0n_3V00<0odD00?[`iP3jl>H0903jl>H20?m50740n_3V
0P3oA@020000ob@0n_3V00<0odD00?[`iP3jl>H04@3jl>H20000ocX0n_3V00<000000?[`iP3jl>H0
<`3jl>H10?ooo`00F`3jl>H2000004l0n_3V00<0odD00?[`iP3jl>H08@3jl>H20?m507D0n_3V0P3o
A@020000ob40n_3V00<0odD00?[`iP3jl>H03`3jl>H30000oc/0n_3V0P00000e0?[`iP40oooo001K
0?[`iP030000003jl>H0n_3V04l0n_3V00<0odD00?[`iP3jl>H07`3jl>H00`3oA@00n_3V0?[`iP1g
0?[`iP80odD00P000?lN0?[`iP030?m5003jl>H0n_3V00d0n_3V0`000?lo0?[`iP030000003jl>H0
n_3V03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0D03jl>H20?m501d0n_3V0P3oA@1l0?[`
iP80odD010000?lI0?[`iP030?m5003jl>H0n_3V00`0n_3V0P000?m20?[`iP030000003jl>H0n_3V
03<0n_3V0@3oool005/0n_3V00<000000?[`iP3jl>H0DP3jl>H00`3oA@00n_3V0?[`iP0H0?[`iP80
odD0P03jl>H20?m50080n_3V10000?lC0?[`iP80odD03@3jl>H20000od@0n_3V00<000000?[`iP3j
l>H0<`3jl>H10?ooo`00CP3jl>H6000000L0n_3V00<000000?[`iP3jl>H0D`3jl>H20?m501D0n_3V
0`3oA@240?[`iP80odD0103jl>H40000o``0n_3V0`3oA@090?[`iPH0003oAP3jl>H00`000000n_3V
0?[`iP0c0?[`iP40oooo001@0?[`iP8000002@3jl>H00`000000n_3V0?[`iP1E0?[`iP@0odD0303j
l>H50?m508T0n_3V103oA@040?[`iP<0003o1@3jl>H40?m500P0n_3V10000?m<0?[`iP030000003j
l>H0n_3V03<0n_3V0@3oool00500n_3V0P0000090?[`iP<00000F@3jl>H<0?m50980n_3V303oA@0<
0000odh0n_3V0`00000e0?[`iP40oooo001@0?[`iP8000002@3jl>H00`000000n_3V0?[`iP050?[`
iP030000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP0e0?[`
iP030000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0=@3jl>H00`000000n_3V0?[`iP0f0?[`
iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00D03jl>H2000000T0
n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0
n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0
n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0
n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0
n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0
n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0
n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0
n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0
n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0
n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0
n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V03<0
n_3V0@3oool00500n_3V0P0000090?[`i_l00000I000000e0?[`iP40oooo001>0?[`iP@00000o`3j
l>JR0?[`iP40oooo001@0?[`iP800000o`3jl>JR0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00>T0n_3V100000030?[`iP800000
00<0n_3V0000000000000P3jl>H4000000`0n_3V0`0000040?[`iPX00000103jl>H3000000<0n_3V
100000020?[`iPD00000aP3jl>H10?ooo`00jP3jl>H2000000@0n_3V0P000000103jl>H000000000
003jl>H200000080n_3V0P00000:0?[`iP8000000P3jl>H00`000000n_3V0?[`iP02000000030?[`
iP00000000000080n_3V0P0000060?[`iP<000000P3jl>H2000000<0n_3V00@000000?[`iP000000
00000P3jl>H200000<D0n_3V0@3oool00>X0n_3V0P0000040?[`iP80000000@0n_3V000000000000
n_3V0P0000020?[`iP8000002@3jl>H2000000H0n_3V0P0000000`3jl>H00000000000020?[`iP80
00001P3jl>H00`000000n_3V000000020?[`iP8000001`3jl>H400000<D0n_3V0@3oool00>X0n_3V
0P0000030?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000002@3jl>H2000000H0n_3V
0P0000000`3jl>H00000000000020?[`iP8000001@3jl>H2000000040?[`iP00000000000?[`iPH0
000000<0n_3V0000000000000P0000370?[`iP40oooo003Z0?[`iP8000000`3jl>H2000000030?[`
iP000000n_3V00@000000P3jl>H2000000T0n_3V0P0000060?[`iP80000000<0n_3V000000000000
0P3jl>H3000000040?[`iP000000n_3V0?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`
iP80000000<0n_3V0000000000000P3jl>H200000<D0n_3V0@3oool00>P0n_3V00D000000?[`iP00
000000000?[`iP05000000030?[`iP000000000000H000002P3jl>H2000000<0n_3V00<000000?[`
iP0000000P000000103jl>H000000000003jl>H3000000040?[`iP00000000000?[`iP<0000000D0
n_3V00000000000000000?[`iP04000000<0n_3V1@0000350?[`iP40oooo003X0?[`iP060000003j
l>H000000000003jl>H00000603jl>H200000080n_3V00<000000?[`iP3jl>H0iP3jl>H10?ooo`00
j03jl>H6000001T0n_3V1000003X0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {237.313, 0}} -> {-1.05243, -0.643838, \
0.00421814, 0.00421814}, {{12.375, 486.563}, {163.688, 5.625}} -> {-4.7728, \
-2.71491, 0.0177844, 0.0177844}, {{59.8125, 225.75}, {226.875, 179.5}} -> \
{-1.31328, -0.655206, 0.0202638, 0.0531922}, {{68.75, 118.063}, {223.438, \
204.688}} -> {-19.3968, -2.60401, 0.20766, 0.112}, {{68.75, 118.063}, \
{201.625, 182.875}} -> {-12.9312, -5.04702, 0.13844, 0.112}}]
}, Open  ]],

Cell[TextData[{
  "This displays the density plot shown in the Legend documentation using \
DrawingPaper. A much better legend, but one which requires more work, is \
illustrated in ",
  ButtonBox["Fancy Contour Plot",
    ButtonData:>{"Fancy Contour Plot"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowLegend[\[IndentingNewLine]DontShow[
          Graphics[\[IndentingNewLine]{DensityDraw[
                Sin[x\ y], {x, 0, \[Pi]}, {y, 0, \[Pi]}, Mesh \[Rule] False, 
                PlotPoints \[Rule] 30, 
                ColorFunction \[Rule] 
                  Hue]}], \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]Background \[Rule] 
            Linen, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
              y}, \[IndentingNewLine]PlotLabel \[Rule] 
            Sin[x\ y], \[IndentingNewLine]ImageSize \[Rule] 
            500], \[IndentingNewLine]\[IndentingNewLine]{Hue[1 - #] &, 
          20, "\<1\>", "\<-1\>", \[IndentingNewLine]LegendPosition \[Rule] \
{1.1, \(-0.6\)}, \[IndentingNewLine]LegendSize \[Rule] {0.3, 
              1.2}, \[IndentingNewLine]LegendBackground \[Rule] 
            AliceBlue, \[IndentingNewLine]ShadowBackground \[Rule] 
            RoyalBlue}, \[IndentingNewLine]TextStyle \[Rule] {FontSize \
\[Rule] 12, FontWeight \[Rule] "\<Bold\>"}\[IndentingNewLine]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81633 
%%ImageSize: 500 408.163 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.412536 0.388727 0.408163 0.388727 [
[ 0 0 0 0 ]
[ 1 .81633 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0194363 0.801263 0.79689 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.0238095 0.303152 0.0238095 0.303152 [
[.02381 -0.0125 -5.59375 -15.5625 ]
[.02381 -0.0125 5.59375 0 ]
[.17539 -0.0125 -12.7813 -15.5625 ]
[.17539 -0.0125 12.7813 0 ]
[.32696 -0.0125 -5.59375 -15.5625 ]
[.32696 -0.0125 5.59375 0 ]
[.47854 -0.0125 -12.7813 -15.5625 ]
[.47854 -0.0125 12.7813 0 ]
[.63011 -0.0125 -5.59375 -15.5625 ]
[.63011 -0.0125 5.59375 0 ]
[.78169 -0.0125 -12.7813 -15.5625 ]
[.78169 -0.0125 12.7813 0 ]
[.93327 -0.0125 -5.59375 -15.5625 ]
[.93327 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.59375 -31.125 ]
[.5 -0.0125 5.59375 -15.5625 ]
[-0.0125 .02381 -11.1875 -7.78125 ]
[-0.0125 .02381 0 7.78125 ]
[-0.0125 .17539 -25.5625 -7.78125 ]
[-0.0125 .17539 0 7.78125 ]
[-0.0125 .32696 -11.1875 -7.78125 ]
[-0.0125 .32696 0 7.78125 ]
[-0.0125 .47854 -25.5625 -7.78125 ]
[-0.0125 .47854 0 7.78125 ]
[-0.0125 .63011 -11.1875 -7.78125 ]
[-0.0125 .63011 0 7.78125 ]
[-0.0125 .78169 -25.5625 -7.78125 ]
[-0.0125 .78169 0 7.78125 ]
[-0.0125 .93327 -11.1875 -7.78125 ]
[-0.0125 .93327 0 7.78125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -41.125 -5.59375 ]
[-0.01875 .5 -25.5625 5.59375 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -28.75 0 ]
[.5 1.0125 28.75 15.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.17539 0 m
.17539 .00625 L
s
gsave
.17539 -0.0125 -73.7813 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.32696 0 m
.32696 .00625 L
s
gsave
.32696 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.47854 0 m
.47854 .00625 L
s
gsave
.47854 -0.0125 -73.7813 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.63011 0 m
.63011 .00625 L
s
gsave
.63011 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.78169 0 m
.78169 .00625 L
s
gsave
.78169 -0.0125 -73.7813 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.93327 0 m
.93327 .00625 L
s
gsave
.93327 -0.0125 -66.5938 -19.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75137 0 m
.75137 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.5938 -35.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .17539 m
.00625 .17539 L
s
gsave
-0.0125 .17539 -86.5625 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .32696 m
.00625 .32696 L
s
gsave
-0.0125 .32696 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .47854 m
.00625 .47854 L
s
gsave
-0.0125 .47854 -86.5625 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .63011 m
.00625 .63011 L
s
gsave
-0.0125 .63011 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .78169 m
.00625 .78169 L
s
gsave
-0.0125 .78169 -86.5625 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
0 .93327 m
.00625 .93327 L
s
gsave
-0.0125 .93327 -72.1875 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05412 m
.00375 .05412 L
s
0 .08444 m
.00375 .08444 L
s
0 .11476 m
.00375 .11476 L
s
0 .14507 m
.00375 .14507 L
s
0 .2057 m
.00375 .2057 L
s
0 .23602 m
.00375 .23602 L
s
0 .26633 m
.00375 .26633 L
s
0 .29665 m
.00375 .29665 L
s
0 .35728 m
.00375 .35728 L
s
0 .38759 m
.00375 .38759 L
s
0 .41791 m
.00375 .41791 L
s
0 .44822 m
.00375 .44822 L
s
0 .50885 m
.00375 .50885 L
s
0 .53917 m
.00375 .53917 L
s
0 .56948 m
.00375 .56948 L
s
0 .5998 m
.00375 .5998 L
s
0 .66043 m
.00375 .66043 L
s
0 .69074 m
.00375 .69074 L
s
0 .72106 m
.00375 .72106 L
s
0 .75137 m
.00375 .75137 L
s
0 .81201 m
.00375 .81201 L
s
0 .84232 m
.00375 .84232 L
s
0 .87264 m
.00375 .87264 L
s
0 .90295 m
.00375 .90295 L
s
0 .96358 m
.00375 .96358 L
s
0 .9939 m
.00375 .9939 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -99.9375 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
66.5938 11.7813 translate
90 rotate
-66.5938 -11.7813 translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.02381 .99375 m
.02381 1 L
s
.17539 .99375 m
.17539 1 L
s
.32696 .99375 m
.32696 1 L
s
.47854 .99375 m
.47854 1 L
s
.63011 .99375 m
.63011 1 L
s
.78169 .99375 m
.78169 1 L
s
.93327 .99375 m
.93327 1 L
s
.125 Mabswid
.05412 .99625 m
.05412 1 L
s
.08444 .99625 m
.08444 1 L
s
.11476 .99625 m
.11476 1 L
s
.14507 .99625 m
.14507 1 L
s
.2057 .99625 m
.2057 1 L
s
.23602 .99625 m
.23602 1 L
s
.26633 .99625 m
.26633 1 L
s
.29665 .99625 m
.29665 1 L
s
.35728 .99625 m
.35728 1 L
s
.38759 .99625 m
.38759 1 L
s
.41791 .99625 m
.41791 1 L
s
.44822 .99625 m
.44822 1 L
s
.50885 .99625 m
.50885 1 L
s
.53917 .99625 m
.53917 1 L
s
.56948 .99625 m
.56948 1 L
s
.5998 .99625 m
.5998 1 L
s
.66043 .99625 m
.66043 1 L
s
.69074 .99625 m
.69074 1 L
s
.72106 .99625 m
.72106 1 L
s
.75137 .99625 m
.75137 1 L
s
.81201 .99625 m
.81201 1 L
s
.84232 .99625 m
.84232 1 L
s
.87264 .99625 m
.87264 1 L
s
.90295 .99625 m
.90295 1 L
s
.96358 .99625 m
.96358 1 L
s
.9939 .99625 m
.9939 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .17539 m
1 .17539 L
s
.99375 .32696 m
1 .32696 L
s
.99375 .47854 m
1 .47854 L
s
.99375 .63011 m
1 .63011 L
s
.99375 .78169 m
1 .78169 L
s
.99375 .93327 m
1 .93327 L
s
.125 Mabswid
.99625 .05412 m
1 .05412 L
s
.99625 .08444 m
1 .08444 L
s
.99625 .11476 m
1 .11476 L
s
.99625 .14507 m
1 .14507 L
s
.99625 .2057 m
1 .2057 L
s
.99625 .23602 m
1 .23602 L
s
.99625 .26633 m
1 .26633 L
s
.99625 .29665 m
1 .29665 L
s
.99625 .35728 m
1 .35728 L
s
.99625 .38759 m
1 .38759 L
s
.99625 .41791 m
1 .41791 L
s
.99625 .44822 m
1 .44822 L
s
.99625 .50885 m
1 .50885 L
s
.99625 .53917 m
1 .53917 L
s
.99625 .56948 m
1 .56948 L
s
.99625 .5998 m
1 .5998 L
s
.99625 .66043 m
1 .66043 L
s
.99625 .69074 m
1 .69074 L
s
.99625 .72106 m
1 .72106 L
s
.99625 .75137 m
1 .75137 L
s
.99625 .81201 m
1 .81201 L
s
.99625 .84232 m
1 .84232 L
s
.99625 .87264 m
1 .87264 L
s
.99625 .90295 m
1 .90295 L
s
.99625 .96358 m
1 .96358 L
s
.99625 .9939 m
1 .9939 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -89.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sin) show
%%IncludeResource: font Mathematica2Mono-Bold
%%IncludeFont: Mathematica2Mono-Bold
/Mathematica2Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
84.563 15.000 moveto
(@) show
91.750 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
102.125 15.000 moveto
(y) show
%%IncludeResource: font Mathematica2Mono-Bold
%%IncludeFont: Mathematica2Mono-Bold
/Mathematica2Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.313 15.000 moveto
(D) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
90 string
30 30 8 [30 0 0 30 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00F7FF00EEFF00E5FF00DCFF00D3FF00CAFF00C1FF00B8FF00AFFF00A6FF009DFF
0094FF008BFF0082FF0079FF0070FF0067FF005EFF0056FF004DFF0044FF003BFF0033FF
002AFF0021FF0019FF0010FF0008FF0000FF
00FFFF00EEFF00DCFF00CAFF00B8FF00A6FF0094FF0082FF0070FF005EFF004DFF003BFF
002AFF0019FF0008FF0800FF1900FF2A00FF3A00FF4B00FF5B00FF6B00FF7B00FF8A00FF
9A00FFA900FFB800FFC600FFD500FFE300FF
00FFFF00E5FF00CAFF00AFFF0094FF0079FF005EFF0044FF002AFF0010FF0800FF2200FF
3A00FF5300FF6B00FF8200FF9A00FFB000FFC600FFDC00FFF100FFFF00FAFF00E6FF00D3
FF00C1FF00AFFF009FFF008FFF007FFF0071
00FFFF00DCFF00B8FF0094FF0070FF004DFF002AFF0008FF1900FF3A00FF5B00FF7B00FF
9A00FFB800FFD500FFF100FFFF00F3FF00DAFF00C1FF00AAFF0094FF007FFF006CFF005A
FF004AFF003BFF002EFF0023FF0019FF0010
00FFFF00D3FF00A6FF0079FF004DFF0021FF0800FF3200FF5B00FF8200FFA900FFCE00FF
F100FFFF00EDFF00CDFF00AFFF0094FF007AFF0063FF004EFF003BFF002BFF001DFF0012
FF000AFF0004FF0000FF0000FF0001FF0006
00FFFF00CAFF0094FF005EFF002AFF0800FF3A00FF6B00FF9A00FFC600FFF100FFFF00E6
FF00C1FF009FFF007FFF0063FF004AFF0034FF0023FF0014FF000AFF0003FF0000FF0000
FF0005FF000DFF0019FF0029FF003CFF0053
00FFFF00C1FF0082FF0044FF0008FF3200FF6B00FFA100FFD500FFFF00FAFF00CDFF00A4
FF007FFF005FFF0042FF002BFF0019FF000BFF0003FF0000FF0001FF0009FF0015FF0026
FF003CFF0057FF0077FF009BFF00C3FF00EF
00FFFF00B8FF0070FF002AFF1900FF5B00FF9A00FFD500FFFF00F3FF00C1FF0094FF006C
FF004AFF002EFF0019FF000AFF0001FF0000FF0005FF0011FF0023FF003CFF005CFF0081
FF00ABFF00DCEF00FFB500FF7800FF3800FF
00FFFF00AFFF005EFF0010FF3A00FF8200FFC600FFFF00FAFF00C1FF008FFF0063FF003F
FF0023FF000EFF0003FF0000FF0005FF0013FF0029FF0047FF006DFF009BFF00CFF500FF
B500FF7000FF2700FF0024FF0073FF00C3FF
00FFFF00A6FF004DFF0800FF5B00FFA900FFF100FFFF00CDFF0094FF0063FF003BFF001D
FF000AFF0000FF0001FF000DFF0023FF0044FF006DFF00A0FF00DCE100FF9700FF4800FF
000AFF0061FF00BAFF00FFEB00FF9100FF39
00FFFF009DFF003BFF2200FF7B00FFCE00FFFF00E6FF00A4FF006CFF003FFF001DFF0008
FF0000FF0004FF0015FF0032FF005CFF0090FF00CFE800FF9700FF4000FF001BFF007CFF
00DEFF00FFBE00FF5C02FF005DFF00B3FF00
00FFFF0094FF002AFF3A00FF9A00FFF100FFFF00C1FF007FFF004AFF0023FF000AFF0000
FF0005FF0019FF003CFF006DFF00ABFF00F5B500FF5800FF000AFF0073FF00DEFF00FFB5
00FF4A1CFF007DFF00D7FF00FFD800FF9200
00FFFF008BFF0019FF5300FFB800FFFF00EDFF009FFF005FFF002EFF000EFF0000FF0004
FF0019FF0040FF0077FF00BDEF00FF9000FF2700FF0047FF00BAFF00FFD000FF5C13FF00
7DFF00DEFF00FFCB00FF8300FF4900FF1F00
00FFFF0082FF0008FF6B00FFD500FFFF00CDFF007FFF0042FF0019FF0003FF0001FF0015
FF003CFF0077FF00C3E100FF7800FF0600FF0073FF00F0FF00FF9100FF165DFF00C9FF00
FFD800FF8800FF4900FF1D00FF0400FF0000
00FFFF0079FF0800FF8200FFF100FFFF00AFFF0063FF002BFF000AFF0000FF000DFF0032
FF006DFF00BDE100FF7000FF000AFF008EFF00FFEB00FF651CFF0094FF00FFFF00FFA200
FF5900FF2400FF0600FF0000FF1100FF3A00
00FFFF0070FF1900FF9A00FFFF00F3FF0094FF004AFF0019FF0001FF0005FF0023FF005C
FF00ABEF00FF7800FF000AFF0096FF00FFD900FF4A3DFF00BAFF00FFD800FF7E00FF3A00
FF1000FF0000FF0A00FF3000FF6F00FFC500
00FFFF0067FF2A00FFB000FFFF00DAFF007AFF0034FF000BFF0000FF0013FF0044FF0090
FF00F59000FF0600FF008EFF00FFD900FF414DFF00D0FF00FFBF00FF6600FF2700FF0500
FF0200FF1C00FF5400FFA700EDFF006EFF00
00FFFF005EFF3A00FFC600FFFF00C1FF0063FF0023FF0003FF0005FF0029FF006DFF00CF
B500FF2700FF0073FF00FFEB00FF4A4DFF00D7FF00FFB300FF5900FF1D00FF0100FF0800
FF3000FF7800FFDD00A4FF0014FF0000FF87
00FFFF0056FF4B00FFDC00FFFF00AAFF004EFF0014FF0000FF0011FF0047FF00A0E800FF
5800FF0047FF00F0FF00FF653DFF00D0FF00FFB300FF5500FF1800FF0000FF0E00FF4100
FF9700F4FF0066FF0000FF3800FFE10074FF
00FFFF004DFF5B00FFF100FFFF0094FF003BFF000AFF0001FF0023FF006DFF00DC9700FF
000AFF00BAFF00FF911CFF00BAFF00FFBF00FF5900FF1800FF0000FF1100FF4C00FFAD00
D0FF0036FF0000FF7500D6FF0025FF7F00FF
00FFFF0044FF6B00FFFF00FAFF007FFF002BFF0003FF0009FF003CFF009BE100FF4000FF
0073FF00FFD000FF1694FF00FFD800FF6600FF1D00FF0000FF1100FF5000FFB900BBFF00
14FF0000FFA200A0FF1600FFBC00FFFF00B8
00FFFF003BFF7B00FFFF00E6FF006CFF001DFF0000FF0015FF005CFF00CF9700FF001BFF
00DEFF00FF5C5DFF00FFFF00FF7E00FF2700FF0100FF0E00FF4C00FFB900B3FF0003FF00
00FFBD007DFF3F00FFE700FFFF0091FF0033
00FFFF0033FF8A00FFFF00D3FF005AFF0012FF0000FF0026FF0081F500FF4800FF007CFF
00FFB513FF00C9FF00FFA200FF3A00FF0500FF0800FF4100FFAD00BBFF0003FF0000FFC6
006BFF5800FFFF00FDFF0077FF0021FF0000
00FFFF002AFF9A00FFFF00C1FF004AFF000AFF0005FF003CFF00ABB500FF000AFF00DEFF
00FF4A7DFF00FFD800FF5900FF1000FF0200FF3000FF9700D0FF0014FF0000FFBD006BFF
6000FFFF00EFFF0069FF0017FF0000FF0025
00FFFF0021FFA900FFFF00AFFF003BFF0004FF000DFF0057FF00DC7000FF0061FF00FFBE
1CFF00DEFF00FF8800FF2400FF0000FF1C00FF7800F4FF0036FF0000FFA2007DFF5800FF
FF00EFFF0065FF0013FF0001FF0031FF009E
00FFFF0019FFB800FFFF009FFF002EFF0000FF0019FF0077EF00FF2700FF00BAFF00FF5C
7DFF00FFCB00FF4900FF0600FF0A00FF5400FFDD0066FF0000FF7500A0FF3F00FFFF00FD
FF0069FF0013FF0002FF0038FF00AFA200FF
00FFFF0010FFC600FFFF008FFF0023FF0000FF0029FF009BB500FF0024FF00FFEB02FF00
D7FF00FF8300FF1D00FF0000FF3000FFA700A4FF0000FF3800D6FF1600FFE700FFFF0077
FF0017FF0001FF0038FF00B59300FF004CFF
00FFFF0008FFD500FFFF007FFF0019FF0001FF003CFF00C37800FF0073FF00FF915DFF00
FFD800FF4900FF0400FF1100FF6F00EDFF0014FF0000FFE10025FFBC00FFFF0091FF0021
FF0000FF0031FF00AF9300FF0055FF00FFAF
00FFFF0000FFE300FFFF0071FF0010FF0006FF0053FF00EF3800FF00C3FF00FF39B3FF00
FF9200FF1F00FF0000FF3A00FFC5006EFF0000FF870074FF7F00FFFF00B8FF0033FF0000
FF0025FF009EA200FF004CFF00FFAF4AFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
.255 .412 .882 r
.85957 .15549 m
.85957 .62196 L
.97619 .62196 L
.97619 .15549 L
F
.941 .973 1 r
.84014 .17493 m
.84014 .6414 L
.95675 .6414 L
.95675 .17493 L
F
0 g
.001 w
[ ] 0 setdash
.84014 .17493 m
.95675 .17493 L
.95675 .6414 L
.84014 .6414 L
.84014 .17493 L
s
% Start of sub-graphic
p
0.840136 0.174927 0.956754 0.641399 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.03125 0.3125 0.019802 0.19802 [
[ 0 0 0 0 ]
[ 1 4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 4 L
0 4 L
closepath
clip
newpath
1 0 0 r
.03125 .0198 m
.03125 .21782 L
.34375 .21782 L
.34375 .0198 L
F
0 g
gsave
.35938 .11881 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.188 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
77.375 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 .316 0 r
.03125 .21782 m
.03125 .41584 L
.34375 .41584 L
.34375 .21782 L
F
1 .632 0 r
.03125 .41584 m
.03125 .61386 L
.34375 .61386 L
.34375 .41584 L
F
1 .947 0 r
.03125 .61386 m
.03125 .81188 L
.34375 .81188 L
.34375 .61386 L
F
.737 1 0 r
.03125 .81188 m
.03125 1.0099 L
.34375 1.0099 L
.34375 .81188 L
F
.421 1 0 r
.03125 1.0099 m
.03125 1.20792 L
.34375 1.20792 L
.34375 1.0099 L
F
.105 1 0 r
.03125 1.20792 m
.03125 1.40594 L
.34375 1.40594 L
.34375 1.20792 L
F
0 1 .211 r
.03125 1.40594 m
.03125 1.60396 L
.34375 1.60396 L
.34375 1.40594 L
F
0 1 .526 r
.03125 1.60396 m
.03125 1.80198 L
.34375 1.80198 L
.34375 1.60396 L
F
0 1 .842 r
.03125 1.80198 m
.03125 2 L
.34375 2 L
.34375 1.80198 L
F
0 .842 1 r
.03125 2 m
.03125 2.19802 L
.34375 2.19802 L
.34375 2 L
F
0 .526 1 r
.03125 2.19802 m
.03125 2.39604 L
.34375 2.39604 L
.34375 2.19802 L
F
0 .211 1 r
.03125 2.39604 m
.03125 2.59406 L
.34375 2.59406 L
.34375 2.39604 L
F
.105 0 1 r
.03125 2.59406 m
.03125 2.79208 L
.34375 2.79208 L
.34375 2.59406 L
F
.421 0 1 r
.03125 2.79208 m
.03125 2.9901 L
.34375 2.9901 L
.34375 2.79208 L
F
.737 0 1 r
.03125 2.9901 m
.03125 3.18812 L
.34375 3.18812 L
.34375 2.9901 L
F
1 0 .947 r
.03125 3.18812 m
.03125 3.38614 L
.34375 3.38614 L
.34375 3.18812 L
F
1 0 .632 r
.03125 3.38614 m
.03125 3.58416 L
.34375 3.58416 L
.34375 3.38614 L
F
1 0 .316 r
.03125 3.58416 m
.03125 3.78218 L
.34375 3.78218 L
.34375 3.58416 L
F
1 0 0 r
.03125 3.78218 m
.03125 3.9802 L
.34375 3.9802 L
.34375 3.78218 L
F
0 g
gsave
.35938 3.88119 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
70.188 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .81633 L
0 .81633 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 408.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001V2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00h@3jl>H3000000040?[`iP000000000000000?l0n_3V303jl>H1
0?ooo`00hP3jl>H2000000030?[`iP00000000000?l0n_3V3@3jl>H10?ooo`00h`3jl>H300000?l0
n_3V3P3jl>H10?ooo`00h`3jl>H300000?l0n_3V3P3jl>H10?ooo`00hP3jl>H2000000030?[`iP00
000000000?l0n_3V3@3jl>H10?ooo`00h@3jl>H3000000040?[`iP000000000000000?l0n_3V303j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00A@3jl>H3000002P0n_3V0`00
00040?[`iP8000001@3jl>H3000002P0n_3V1P00000U0?[`iPH000000P3jl>H2000000D0n_3V0`00
000X0?[`iPD000009P3jl>H5000000<0n_3V0P0000050?[`iP<00000:@3jl>H3000007`0n_3V0@3o
ool004@0n_3V0P0000000`3jl>H000000000000V0?[`iP80000000<0n_3V0000000000000`3jl>H2
000000@0n_3V00<000000?[`iP3jl>H00P00000Y0?[`iP800000:@3jl>H2000000@0n_3V0P000004
0?[`iP030000003jl>H0n_3V008000009`3jl>H2000002T0n_3V0P0000060?[`iP800000103jl>H0
0`000000n_3V0?[`iP02000002L0n_3V00<000000?[`iP3jl>H00P00001k0?[`iP40oooo00140?[`
iP80000000<0n_3V0000000000009P3jl>H2000000030?[`iP000000000000`0n_3V0P00000Y0?[`
iP800000:@3jl>H2000000d0n_3V0P00000X0?[`iP800000:@3jl>H2000000h0n_3V0P00000Z0?[`
iP800000N`3jl>H10?ooo`00A03jl>H2000000030?[`iP000000000002H0n_3V0P0000000`3jl>H0
00000000000<0?[`iP800000:@3jl>H2000002T0n_3V0P00000=0?[`iP800000:@3jl>H2000002T0
n_3V0P00000=0?[`iP800000:P3jl>H2000007/0n_3V0@3oool004@0n_3V0P0000000`3jl>H00000
0000000V0?[`iP80000000<0n_3V0000000000002@3jl>H00`000000n_3V0?[`iP02000002T0n_3V
0P00000Y0?[`iP8000002P3jl>H00`000000n_3V0?[`iP02000002X0n_3V0P00000Y0?[`iP800000
2@3jl>H00`000000n_3V0?[`iP02000002P0n_3V0`00001l0?[`iP40oooo00140?[`iP80000000<0
n_3V0000000000009P3jl>H2000000030?[`iP000000000000T0n_3V1000000Z0?[`iP800000:@3j
l>H2000000X0n_3V1000000X0?[`iP80000000<0n_3V0000000000009P3jl>H2000000030?[`iP00
0000000000T0n_3V1000000[0?[`iP800000N`3jl>H10?ooo`00A03jl>H2000000030?[`iP000000
000002H0n_3V0P0000000`3jl>H00000000000090?[`iP800000:P3jl>H4000002L0n_3V1000000:
0?[`iP800000:P3jl>H2000000030?[`iP000000000002H0n_3V0P0000000`3jl>H0000000000009
0?[`iP800000:P3jl>H00`000000n_3V0?[`iP02000007/0n_3V0@3oool004D0n_3V0`00000X0?[`
iP<000002P3jl>H5000002T0n_3V0P00000Y0?[`iP8000002P3jl>H5000002P0n_3V0`00000X0?[`
iP<000002P3jl>H5000002P0n_3V0`00001l0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo000o0?[`i_l00000CP00001W0?[`iP40oooo000o0?[`iP030000003j
l>H0n_3V00D0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00P0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP080?[`iP030000003j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0000006L0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP000000I`3jl>H10?ooo`00?`3jl>H00`00
0000n_3V0?[`iP3o0?[`iTX0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000
n_3V0?[`iP3o0?[`iTX0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000n_3V
0?[`iP3o0?[`iTX0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00<`3jl>H3000000T0n_3V00<0
00000?[`iP3jl>H0o`3jl>I:0?[`iP030000003jl>H0n_3V06D0n_3V0@3oool00380n_3V0P000000
0`3jl>H00000000000080?[`iP030000003jl>H0n_3V0?l0n_3VBP3jl>H00`000000n_3V0?[`iP1U
0?[`iP40oooo000b0?[`iP80000000<0n_3V000000000000203jl>H300000?l0n_3VB03jl>H30000
06L0n_3V0@3oool00380n_3V0P0000000`3jl>H00000000000080?[`iP030000003jl>H0n_3V00D0
n_3Vo`00ooln003oo`L0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00<P3jl>H2000000030?[`
iP000000000000P0n_3V00<000000?[`iP3jl>H01@3jl>Ko003ooch00?oo1`3jl>H00`000000n_3V
0?[`iP1U0?[`iP40oooo000b0?[`iP80000000<0n_3V000000000000203jl>H00`000000n_3V0?[`
iP050?[`i_l00?oo?P00ool70?[`iP030000003jl>H0n_3V06D0n_3V0@3oool00380n_3V0P000000
0`3jl>H00000000000080?[`iP030000003jl>H0n_3V00D0n_3Vo`00ooln003oo`L0n_3V00<00000
0?[`iP3jl>H0I@3jl>H10?ooo`00<`3jl>H3000000T0n_3V00<000000?[`iP3jl>H01@3jl>Ko003o
och00?oo1`3jl>H00`000000n_3V0?[`iP1U0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0
n_3Vo`00ooln003oo`L0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000n_3V
0?[`iP050?[`i_l00?oo?P00ool70?[`iP030000003jl>H0n_3V06D0n_3V0@3oool003l0n_3V00<0
00000?[`iP3jl>H01@3jl>Ko003ooch00?oo1`3jl>H00`000000n_3V0?[`iP1U0?[`iP40oooo000o
0?[`iP030000003jl>H0n_3V00D0n_3Vo`00ooln003oo`L0n_3V00<000000?[`iP3jl>H0I@3jl>H1
0?ooo`00?`3jl>H2000000H0n_3Vo`00ooln003oo`H0n_3V0P00001W0?[`iP40oooo000o0?[`iP03
0000003jl>H0n_3V00D0n_3Vo`00ooln003oo`L0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00
?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00mol:003^o`/00>Go2P00g?l;003Co`/00<[o
2P00`Ol;002ho`X00:oo2`00Y_l;002Mo`X009Co2`00Rol:0022o`/007Wo2`00L?l:001Wo`/005ko
2P00E_l;001=o`/004Co2P00>ol;000co`X002[o2`008Ol;000Io`X0013o2`002?l:0000o`L0n_3V
00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00
mol:003^o`/00>Go2P00g?l;003Co`/00<[o2P00`Ol;002ho`X00:oo2`00Y_l;002Mo`X009Co2`00
Rol:0022o`/007Wo2`00L?l:001Wo`/005ko2P00E_l;001=o`/004Co2P00>ol;000co`X002[o2`00
8Ol;000Io`X0013o2`002?l:0000o`L0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H0
0`000000n_3V0?[`iP050?[`iPX00?oo2`00mol:003^o`/00>Go2P00g?l;003Co`/00<[o2P00`Ol;
002ho`X00:oo2`00Y_l;002Mo`X009Co2`00Rol:0022o`/007Wo2`00L?l:001Wo`/005ko2P00E_l;
001=o`/004Co2P00>ol;000co`X002[o2`008Ol;000Io`X0013o2`002?l:0000o`L0n_3V00<00000
0?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00mol:003^
o`/00>Go2P00g?l;003Co`/00<[o2P00`Ol;002ho`X00:oo2`00Y_l;002Mo`X009Co2`00Rol:0022
o`/007Wo2`00L?l:001Wo`/005ko2P00E_l;001=o`/004Co2P00>ol;000co`X002[o2`008Ol;000I
o`X0013o2`002?l:0000o`L0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000
n_3V0?[`iP050?[`iPX00?oo2`00mol:003^o`/00>Go2P00g?l;003Co`/00<[o2P00`Ol;002ho`X0
0:oo2`00Y_l;002Mo`X009Co2`00Rol:0022o`/007Wo2`00L?l:001Wo`/005ko2P00E_l;001=o`/0
04Co2P00>ol;000co`X002[o2`008Ol;000Io`X0013o2`002?l:0000o`L0n_3V00<000000?[`iP3j
l>H0I@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00mol:003^o`/00>Go
2P00g?l;003Co`/00<[o2P00`Ol;002ho`X00:oo2`00Y_l;002Mo`X009Co2`00Rol:0022o`/007Wo
2`00L?l:001Wo`/005ko2P00E_l;001=o`/004Co2P00>ol;000co`X002[o2`008Ol;000Io`X0013o
2`002?l:0000o`L0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`
iP050?[`iPX00?oo2`00mol:003^o`/00>Go2P00g?l;003Co`/00<[o2P00`Ol;002ho`X00:oo2`00
Y_l;002Mo`X009Co2`00Rol:0022o`/007Wo2`00L?l:001Wo`/005ko2P00E_l;001=o`/004Co2P00
>ol;000co`X002[o2`008Ol;000Io`X0013o2`002?l:0000o`L0n_3V00<000000?[`iP3jl>H0I@3j
l>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00mol:003^o`/00>Go2P00g?l;
003Co`/00<[o2P00`Ol;002ho`X00:oo2`00Y_l;002Mo`X009Co2`00Rol:0022o`/007Wo2`00L?l:
001Wo`/005ko2P00E_l;001=o`/004Co2P00>ol;000co`X002[o2`008Ol;000Io`X0013o2`002?l:
0000o`L0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H2000000H0n_3V2P00ool;003g
o`X00>ko2`00iOl:003Lo`/00=?o2`00b_l:0031o`/00;So2P00[ol;002Vo`/009go2P00U?l;002;
o`X008;o2`00NOl;001`o`X006Oo2`00G_l:001Fo`/004go2`00A?l:000ko`/003?o2P00:_l;000Q
o`/001Wo2P004?l;0008o`X0003o1P3jl>H2000006L0n_3V0@3oool003l0n_3V00<000000?[`iP3j
l>H01@3jl>H:003oo`/00?Oo2P00k_l;003Uo`X00=co2`00dol;003:o`X00<7o2`00^?l:002_o`/0
0:Ko2`00WOl:002Do`/008_o2P00P_l;001io`/0073o2P00Iol;001No`X005Ko2`00COl;0014o`X0
03_o2`00<ol:000Zo`/0027o2`006Ol:000@o`/000So2P000?l70?[`iP030000003jl>H0n_3V06D0
n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/00>ko2P00g?l;003:o`X00;So
2`00Y_l;002Do`X008;o2`00L?l:001No`/004go2`00>ol:000Zo`/001Wo2P002?l;00P0o`/06@3o
2P0Z0?l;03X0o`X0B`3o2`1K0?l;06/0o`X0N`3o2`2:0?l:09X0o`/0Z@3o2`2h0?l:0<H0o`/0e@3o
2P3S0?l70?[`iP030000003jl>H0n_3V06D0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3j
l>H:003oo`/00>ko2P00g?l;003:o`X00;So2`00Y_l;002Do`X008;o2`00L?l:001No`/004go2`00
>ol:000Zo`/001Wo2P002?l;00P0o`/06@3o2P0Z0?l;03X0o`X0B`3o2`1K0?l;06/0o`X0N`3o2`2:
0?l:09X0o`/0Z@3o2`2h0?l:0<H0o`/0e@3o2P3S0?l70?[`iP030000003jl>H0n_3V06D0n_3V0@3o
ool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/00>ko2P00g?l;003:o`X00;So2`00Y_l;
002Do`X008;o2`00L?l:001No`/004go2`00>ol:000Zo`/001Wo2P002?l;00P0o`/06@3o2P0Z0?l;
03X0o`X0B`3o2`1K0?l;06/0o`X0N`3o2`2:0?l:09X0o`/0Z@3o2`2h0?l:0<H0o`/0e@3o2P3S0?l7
0?[`iP030000003jl>H0n_3V06D0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003o
o`/00>ko2P00g?l;003:o`X00;So2`00Y_l;002Do`X008;o2`00L?l:001No`/004go2`00>ol:000Z
o`/001Wo2P002?l;00P0o`/06@3o2P0Z0?l;03X0o`X0B`3o2`1K0?l;06/0o`X0N`3o2`2:0?l:09X0
o`/0Z@3o2`2h0?l:0<H0o`/0e@3o2P3S0?l70?[`iP030000003jl>H0n_3V06D0n_3V0@3oool003l0
n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/00>ko2P00g?l;003:o`X00;So2`00Y_l;002Do`X0
08;o2`00L?l:001No`/004go2`00>ol:000Zo`/001Wo2P002?l;00P0o`/06@3o2P0Z0?l;03X0o`X0
B`3o2`1K0?l;06/0o`X0N`3o2`2:0?l:09X0o`/0Z@3o2`2h0?l:0<H0o`/0e@3o2P3S0?l70?[`iP03
0000003jl>H0n_3V01h0n_3V>P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V
2P00ool;003^o`X00=co2`00b_l:002ho`/00:Ko2`00U?l:0022o`/0073o2P00G_l;001=o`/003_o
2P00:_l;000Io`X000So2`080?l;01T0o`X0:P3o2`0j0?l:04/0o`/0F`3o2`1[0?l:07/0o`/0RP3o
2P2J0?l;0:T0o`/0^03o2P360?l;0=D0o`X0h`3o1`3jl>H00`000000n_3V0?[`iP0N0?[`iSX0@FWQ
3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00k_l:003Lo`/00<[o2P00
^?l;002Vo`/009Co2P00P_l;001`o`X005ko2`00COl;000ko`X002[o2`006Ol:0008o`/0203o2`0I
0?l:02X0o`/0>P3o2P1;0?l;05/0o`/0J`3o2P1k0?l;08X0o`X0VP3o2`2Y0?l;0;P0o`X0aP3o2`3E
0?l:0><0o`L0n_3V00<000000?[`iP3jl>H07P3jl>Hj045Yh@d0n_3V0@3oool003l0n_3V00<00000
0?[`iP3jl>H01@3jl>H:003oo`/00>ko2P00g?l;003:o`X00;So2`00Y_l;002Do`X008;o2`00L?l:
001No`/004go2`00>ol:000Zo`/001Wo2P002?l;00P0o`/06@3o2P0Z0?l;03X0o`X0B`3o2`1K0?l;
06/0o`X0N`3o2`2:0?l:09X0o`/0Z@3o2`2h0?l:0<H0o`/0e@3o2P3S0?l70?[`iP030000003jl>H0
n_3V01h0n_3V>P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;003^
o`X00=co2`00b_l:002ho`/00:Ko2`00U?l:0022o`/0073o2P00G_l;001=o`/003_o2P00:_l;000I
o`X000So2`080?l;01T0o`X0:P3o2`0j0?l:04/0o`/0F`3o2`1[0?l:07/0o`/0RP3o2P2J0?l;0:T0
o`/0^03o2P360?l;0=D0o`X0h`3o1`3jl>H00`000000n_3V0?[`iP0N0?[`iSX0@FWQ3@3jl>H10?oo
o`00?`3jl>H2000000H0n_3V2P00ool;003^o`X00=co2`00b_l:002ho`/00:Ko2`00U?l:0022o`/0
073o2P00G_l;001=o`/003_o2P00:_l;000Io`X000So2`080?l;01T0o`X0:P3o2`0j0?l:04/0o`/0
F`3o2`1[0?l:07/0o`/0RP3o2P2J0?l;0:T0o`/0^03o2P360?l;0=D0o`X0h`3o1P3jl>H200000200
n_3V>P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;003^o`X00=co
2`00b_l:002ho`/00:Ko2`00U?l:0022o`/0073o2P00G_l;001=o`/003_o2P00:_l;000Io`X000So
2`080?l;01T0o`X0:P3o2`0j0?l:04/0o`/0F`3o2`1[0?l:07/0o`/0RP3o2P2J0?l;0:T0o`/0^03o
2P360?l;0=D0o`X0h`3o1`3jl>H00`000000n_3V0?[`iP0N0?[`iSX0@FWQ3@3jl>H10?ooo`00?`3j
l>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00iOl:003:o`/00:oo2P00U?l;001io`/005ko2P00
A?l;000Zo`X0013o2`080?l;0280o`X0>P3o2`1C0?l:06/0o`/0PP3o2`2J0?l:0;00o`/0aP3o2P3L
0?l;0?40o`/0o`3j2P3o0>H;0?l0d`X0o`312`3o0:l;0?l0W`X0o`2?2`3o07l:0?l0L@L0n_3V00<0
00000?[`iP3jl>H07P3jl>Hj045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:
003oo`/00>Go2P00b_l;002_o`X009Co2`00NOl;001No`X004Co2`00:_l:000@o`/0203o2`0R0?l:
03X0o`/0D`3o2P1[0?l;0880o`/0VP3o2P2`0?l;0<H0o`X0g03o2`3a0?l;0?l0nPX0o`3V2`3o0=<:
0?l0`@/0o`2_2`3o09l:0?l0S`/0o`1o2P3o07470?[`iP030000003jl>H0n_3V01h0n_3V>P11JN4=
0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;003Uo`X00<[o2`00[ol:002D
o`/007Wo2`00G_l:0014o`/002[o2P004?l;00P0o`/08P3o2P0j0?l;05<0o`X0J`3o2`220?l;09X0
o`X0/03o2`360?l:0=`0o`/0l@3o2`3o0?X:0?l0iP/0o`3C2P3o0<4;0?l0[`/0o`2O2P3o08l;0?l0
O`X0o`1a1`3jl>H00`000000n_3V0?[`iP0E0?[`iS/000002011JN4=0?[`iP40oooo000o0?[`iP03
0000003jl>H0n_3V00D0n_3V2P00ool;003Uo`X00<[o2`00[ol:002Do`/007Wo2`00G_l:0014o`/0
02[o2P004?l;00P0o`/08P3o2P0j0?l;05<0o`X0J`3o2`220?l;09X0o`X0/03o2`360?l:0=`0o`/0
l@3o2`3o0?X:0?l0iP/0o`3C2P3o0<4;0?l0[`/0o`2O2P3o08l;0?l0O`X0o`1a1`3jl>H00`000000
n_3V0?[`iP0E0?[`iP030000003`nOl0l?Wo03L0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40
oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;003Uo`X00<[o2`00[ol:002Do`/007Wo
2`00G_l:0014o`/002[o2P004?l;00P0o`/08P3o2P0j0?l;05<0o`X0J`3o2`220?l;09X0o`X0/03o
2`360?l:0=`0o`/0l@3o2`3o0?X:0?l0iP/0o`3C2P3o0<4;0?l0[`/0o`2O2P3o08l;0?l0O`X0o`1a
1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003o0000o`000140o`009P3`nOl00`000000@FWQ
045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/00>Go2P00
b_l;002_o`X009Co2`00NOl;001No`X004Co2`00:_l:000@o`/0203o2`0R0?l:03X0o`/0D`3o2P1[
0?l;0880o`/0VP3o2P2`0?l;0<H0o`X0g03o2`3a0?l;0?l0nPX0o`3V2`3o0=<:0?l0`@/0o`2_2`3o
09l:0?l0S`/0o`1o2P3o07470?[`iP030000003jl>H0n_3V01D0n_3V00<000000?l0003o00004@3o
000V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP05
0?[`iPX00?oo2`00iOl:003:o`/00:oo2P00U?l;001io`/005ko2P00A?l;000Zo`X0013o2`080?l;
0280o`X0>P3o2`1C0?l:06/0o`/0PP3o2`2J0?l:0;00o`/0aP3o2P3L0?l;0?40o`/0o`3j2P3o0>H;
0?l0d`X0o`312`3o0:l;0?l0W`X0o`2?2`3o07l:0?l0L@L0n_3V00<000000?[`iP3jl>H05@3jl>H0
0`000000o`000?l0000A0?l000/0l?Wo1P00000E0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H1
0?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00iOl:003:o`/00:oo2P00U?l;001i
o`/005ko2P00A?l;000Zo`X0013o2`080?l;0280o`X0>P3o2`1C0?l:06/0o`/0PP3o2`2J0?l:0;00
o`/0aP3o2P3L0?l;0?40o`/0o`3j2P3o0>H;0?l0d`X0o`312`3o0:l;0?l0W`X0o`2?2`3o07l:0?l0
L@L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000o`000?l0000A0?l000d0l?Wo0P00000G0?3i
o`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H2000000H0n_3V2P00ool;003Uo`X0
0<[o2`00[ol:002Do`/007Wo2`00G_l:0014o`/002[o2P004?l;00P0o`/08P3o2P0j0?l;05<0o`X0
J`3o2`220?l;09X0o`X0/03o2`360?l:0=`0o`/0l@3o2`3o0?X:0?l0iP/0o`3C2P3o0<4;0?l0[`/0
o`2O2P3o08l;0?l0O`X0o`1a1P3jl>H2000001L0n_3V00<000000?l0003o00004@3o00040?3io`D0
0000103`nOl2000001L0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000
003jl>H0n_3V00D0n_3V2P00ool;003Uo`X00<[o2`00[ol:002Do`/007Wo2`00G_l:0014o`/002[o
2P004?l;00P0o`/08P3o2P0j0?l;05<0o`X0J`3o2`220?l;09X0o`X0/03o2`360?l:0=`0o`/0l@3o
2`3o0?X:0?l0iP/0o`3C2P3o0<4;0?l0[`/0o`2O2P3o08l;0?l0O`X0o`1a1`3jl>H00`000000n_3V
0?[`iP0E0?[`iP030000003o0000o`000140o`003@3`nOl2000001L0l?Wo00<00000045Yh@11JN40
1P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;003Lo`X00;So2`00
U?l:001`o`/004go2`00:_l:0008o`/06@3o2P0j0?l;05/0o`/0N`3o2P2J0?l;0;P0o`X0e@3o2`3a
0?l;0?l0l`X0o`3J2`3o0<4:0?l0ZP/0o`2D2`3o07l:0?l0K0/0o`1J2P3o04X;0?l0>`/0o`0^2P3o
02<;0?l06@X0o`0@1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003o0000o`000140o`003@3`
nOl2000001L0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0
n_3V00D0n_3V2P00ool;003Lo`X00;So2`00U?l:001`o`/004go2`00:_l:0008o`/06@3o2P0j0?l;
05/0o`/0N`3o2P2J0?l;0;P0o`X0e@3o2`3a0?l;0?l0l`X0o`3J2`3o0<4:0?l0ZP/0o`2D2`3o07l:
0?l0K0/0o`1J2P3o04X;0?l0>`/0o`0^2P3o02<;0?l06@X0o`0@1`3jl>H00`000000n_3V0?[`iP0E
0?[`iP030000003o0000o`000140o`003@3`nOl2000001L0l?Wo00<00000045Yh@11JN401P11JN4=
0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;003Lo`X00;So2`00U?l:001`
o`/004go2`00:_l:0008o`/06@3o2P0j0?l;05/0o`/0N`3o2P2J0?l;0;P0o`X0e@3o2`3a0?l;0?l0
l`X0o`3J2`3o0<4:0?l0ZP/0o`2D2`3o07l:0?l0K0/0o`1J2P3o04X;0?l0>`/0o`0^2P3o02<;0?l0
6@X0o`0@1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003o0000o`000140o`002`3`nOl40000
01L0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0
n_3V2P00ool;003Lo`X00;So2`00U?l:001`o`/004go2`00:_l:0008o`/06@3o2P0j0?l;05/0o`/0
N`3o2P2J0?l;0;P0o`X0e@3o2`3a0?l;0?l0l`X0o`3J2`3o0<4:0?l0ZP/0o`2D2`3o07l:0?l0K0/0
o`1J2P3o04X;0?l0>`/0o`0^2P3o02<;0?l06@X0o`0@1`3jl>H00`000000n_3V0?[`iP0E0?[`iP03
0000003o0000o`000140o`003@3`nOl2000001L0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40
oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;003Lo`X00;So2`00U?l:001`o`/004go
2`00:_l:0008o`/06@3o2P0j0?l;05/0o`/0N`3o2P2J0?l;0;P0o`X0e@3o2`3a0?l;0?l0l`X0o`3J
2`3o0<4:0?l0ZP/0o`2D2`3o07l:0?l0K0/0o`1J2P3o04X;0?l0>`/0o`0^2P3o02<;0?l06@X0o`0@
1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003o0000o`000140o`009P3`nOl00`000000@FWQ
045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/00=co2P00
^?l;002Do`X0073o2`00COl;000Zo`X000So2`0I0?l:03X0o`/0F`3o2`1k0?l:09X0o`/0^03o2P3E
0?l;0?40o`/0o`3c2P3o0=X;0?l0`@X0o`2Z2`3o09@;0?l0O`X0o`1/2`3o05X:0?l0BP/0o`0k2`3o
02h:0?l08`/0o`0I2P3o01070?[`iP030000003jl>H0n_3V01D0n_3V00<000000?m@003oD0004@3o
D00V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`009@3jl>H3000000@0n_3V0P000005
0?[`iP<000002@3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00g?l:002ho`/009Co2P00L?l;
001=o`/002[o2P002?l;01T0o`X0>P3o2`1K0?l;07/0o`X0VP3o2`2h0?l:0=D0o`/0l@3o2`3o0?<:
0?l0fP/0o`312P3o0:X;0?l0U0/0o`1o2P3o06`;0?l0FPX0o`1:2`3o03/;0?l0;PX0o`0S2`3o01T:
0?l040L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000oe000?m@000A0?m@02H0l?Wo00<00000
045Yh@11JN401P11JN4=0?[`iP40oooo000T0?[`iP80000000<0n_3V0000000000000`3jl>H20000
00@0n_3V00<000000?[`iP3jl>H00P0000080?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;003L
o`X00;So2`00U?l:001`o`/004go2`00:_l:0008o`/06@3o2P0j0?l;05/0o`/0N`3o2P2J0?l;0;P0
o`X0e@3o2`3a0?l;0?l0l`X0o`3J2`3o0<4:0?l0ZP/0o`2D2`3o07l:0?l0K0/0o`1J2P3o04X;0?l0
>`/0o`0^2P3o02<;0?l06@X0o`0@1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003oD000oe00
0140oe009P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool002@0n_3V0P0000000`3jl>H0
00000000000<0?[`iP800000203jl>H3000000D0n_3V2P00ool;003Lo`X00;So2`00U?l:001`o`/0
04go2`00:_l:0008o`/06@3o2P0j0?l;05/0o`/0N`3o2P2J0?l;0;P0o`X0e@3o2`3a0?l;0?l0l`X0
o`3J2`3o0<4:0?l0ZP/0o`2D2`3o07l:0?l0K0/0o`1J2P3o04X;0?l0>`/0o`0^2P3o02<;0?l06@X0
o`0@1@3jl>H3000001L0n_3V00<000000?m@003oD0004@3oD00V0?3io`0300000011JN40@FWQ00H0
@FWQ3@3jl>H10?ooo`00903jl>H2000000030?[`iP000000000000`0n_3V0P0000080?[`iP030000
003jl>H0n_3V00D0n_3V2P00ool;003Lo`X00;So2`00U?l:001`o`/004go2`00:_l:0008o`/06@3o
2P0j0?l;05/0o`/0N`3o2P2J0?l;0;P0o`X0e@3o2`3a0?l;0?l0l`X0o`3J2`3o0<4:0?l0ZP/0o`2D
2`3o07l:0?l0K0/0o`1J2P3o04X;0?l0>`/0o`0^2P3o02<;0?l06@X0o`0@1`3jl>H00`000000n_3V
0?[`iP0E0?[`iP030000003oD000oe000140oe009P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V
0@3oool002@0n_3V0P0000000`3jl>H00000000000090?[`iP030000003jl>H0n_3V00800000203j
l>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00g?l:002ho`/009Co2P00L?l;001=o`/002[o2P00
2?l;01T0o`X0>P3o2`1K0?l;07/0o`X0VP3o2`2h0?l:0=D0o`/0l@3o2`3o0?<:0?l0fP/0o`312P3o
0:X;0?l0U0/0o`1o2P3o06`;0?l0FPX0o`1:2`3o03/;0?l0;PX0o`0S2`3o01T:0?l040L0n_3V00<0
00000?[`iP3jl>H05@3jl>H00`000000oe000?m@000A0?m@02H0l?Wo00<00000045Yh@11JN401P11
JN4=0?[`iP40oooo000T0?[`iP80000000<0n_3V0000000000002@3jl>H4000000T0n_3V00<00000
0?[`iP3jl>H01@3jl>H:003oo`/00=?o2P00Y_l;001io`X004go2`008Ol;00P0o`X0<P3o2`1K0?l:
0880o`/0Z@3o2`3>0?l:0?40o`/0o`3]2P3o0<d;0?l0[`/0o`2D2P3o07X;0?l0H`X0o`1>2`3o03/;
0?l0:`X0o`0M2`3o018:0?l02P/0o`045@3o000;0?l00@X0o`061`3jl>H00`000000n_3V0?[`iP0E
0?[`iP030000003oD000oe000140oe009P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool0
02@0n_3V0P0000000`3jl>H00000000000090?[`iP8000002`3jl>H00`000000n_3V0?[`iP050?[`
iPX00?oo2`00dol:002Vo`/007Wo2P00COl;000Qo`/0203o2P0b0?l;05/0o`X0PP3o2`2Y0?l;0<h0
o`X0l@3o2`3o0>d:0?l0c@/0o`2_2`3o09@:0?l0NP/0o`1S2P3o04h;0?l0>`/0o`0[2P3o01d;0?l0
4PX0o`0:2`3o00@E0?l000/0o`012P3o00H70?[`iP030000003jl>H0n_3V01D0n_3V00<000000?m@
003oD0004@3oD00V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`009@3jl>H3000000X0
n_3V1@0000080?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;003Co`X00:Ko2`00NOl:001=o`/0
027o2`080?l:0380o`/0F`3o2P220?l;0:T0o`/0cP3o2P3a0?l;0?l0k@X0o`3=2`3o0:l;0?l0U0X0
o`1j2`3o06<:0?l0CP/0o`0k2`3o02/:0?l07@/0o`0B2P3o00X;0?l011D0o`002`3o004:0?l01PL0
n_3V00<000000?[`iP3jl>H05@3jl>H00`000000oe000?m@000A0?m@02H0l?Wo00<00000045Yh@11
JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;003Co`X00:Ko
2`00NOl:001=o`/0027o2`080?l:0380o`/0F`3o2P220?l;0:T0o`/0cP3o2P3a0?l;0?l0k@X0o`3=
2`3o0:l;0?l0U0X0o`1j2`3o06<:0?l0CP/0o`0k2`3o02/:0?l07@/0o`0B2P3o00X;0?l011D0o`00
2`3o004:0?l01PL0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000oe000?m@000A0?m@02H0l?Wo
00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00
ool;003Co`X00:Ko2`00NOl:001=o`/0027o2`080?l:0380o`/0F`3o2P220?l;0:T0o`/0cP3o2P3a
0?l;0?l0k@X0o`3=2`3o0:l;0?l0U0X0o`1j2`3o06<:0?l0CP/0o`0k2`3o02/:0?l07@/0o`0B2P3o
00X;0?l011D0o`002`3o004:0?l01PL0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000oe000?m@
000A0?m@02H0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0
n_3V00D0n_3V2P00ool;003Co`X00:Ko2`00NOl:001=o`/0027o2`080?l:0380o`/0F`3o2P220?l;
0:T0o`/0cP3o2P3a0?l;0?l0k@X0o`3=2`3o0:l;0?l0U0X0o`1j2`3o06<:0?l0CP/0o`0k2`3o02/:
0?l07@/0o`0B2P3o00X;0?l011D0o`002`3o004:0?l01PL0n_3V00<000000?[`iP3jl>H05@3jl>H0
0`000000oe000?m@000A0?m@02H0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`
iP030000003jl>H0n_3V00D0n_3V2P00ool;003Co`X00:Ko2`00NOl:001=o`/0027o2`080?l:0380
o`/0F`3o2P220?l;0:T0o`/0cP3o2P3a0?l;0?l0k@X0o`3=2`3o0:l;0?l0U0X0o`1j2`3o06<:0?l0
CP/0o`0k2`3o02/:0?l07@/0o`0B2P3o00X;0?l011D0o`002`3o004:0?l01PL0n_3V00<000000?[`
iP3jl>H05@3jl>H00`000000oj400?nQ000A0?nQ02H0l?Wo00<00000045Yh@11JN401P11JN4=0?[`
iP40oooo000o0?[`iP8000001P3jl>H:003oo`/00=?o2P00Y_l;001io`X004go2`008Ol;00P0o`X0
<P3o2`1K0?l:0880o`/0Z@3o2`3>0?l:0?40o`/0o`3]2P3o0<d;0?l0[`/0o`2D2P3o07X;0?l0H`X0
o`1>2`3o03/;0?l0:`X0o`0M2`3o018:0?l02P/0o`045@3o000;0?l00@X0o`061P3jl>H2000001L0
n_3V00<000000?nQ003oX@004@3oX@0V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00
?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00dol:002Vo`/007Wo2P00COl;000Qo`/0203o
2P0b0?l;05/0o`X0PP3o2`2Y0?l;0<h0o`X0l@3o2`3o0>d:0?l0c@/0o`2_2`3o09@:0?l0NP/0o`1S
2P3o04h;0?l0>`/0o`0[2P3o01d;0?l04PX0o`0:2`3o00@E0?l000/0o`012P3o00H70?[`iP030000
003jl>H0n_3V01D0n_3V00<000000?nQ003oX@004@3oX@0V0?3io`0300000011JN40@FWQ00H0@FWQ
3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00dol:002Vo`/007Wo2P00
COl;000Qo`/0203o2P0b0?l;05/0o`X0PP3o2`2Y0?l;0<h0o`X0l@3o2`3o0>d:0?l0c@/0o`2_2`3o
09@:0?l0NP/0o`1S2P3o04h;0?l0>`/0o`0[2P3o01d;0?l04PX0o`0:2`3o00@E0?l000/0o`012P3o
00H70?[`iP030000003jl>H0n_3V01D0n_3V00<000000?nQ003oX@004@3oX@0V0?3io`0300000011
JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00dol:
002Vo`/007Wo2P00COl;000Qo`/0203o2P0b0?l;05/0o`X0PP3o2`2Y0?l;0<h0o`X0l@3o2`3o0>d:
0?l0c@/0o`2_2`3o09@:0?l0NP/0o`1S2P3o04h;0?l0>`/0o`0[2P3o01d;0?l04PX0o`0:2`3o00@E
0?l000/0o`012P3o00H70?[`iP030000003jl>H0n_3V01D0n_3V00<000000?nQ003oX@004@3oX@0V
0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`
iPX00?oo2`00b_l:002Do`/005ko2P00:_l;00P0o`/0>P3o2P1[0?l;09X0o`X0aP3o2`3a0?l;0?l0
iPX0o`312`3o09l:0?l0O`/0o`1S2`3o04X:0?l0=0/0o`0S2P3o01@;0?l02P/0o`035@3o000:0?l0
1@/0o`0=2`3o01T:0?l0:@/0o`0l2P3o05<70?[`iP030000003jl>H0n_3V01D0n_3V00<000000?nQ
003oX@004@3oX@0V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000
n_3V0?[`iP050?[`iPX00?oo2`00b_l:002Do`/005ko2P00:_l;00P0o`/0>P3o2P1[0?l;09X0o`X0
aP3o2`3a0?l;0?l0iPX0o`312`3o09l:0?l0O`/0o`1S2`3o04X:0?l0=0/0o`0S2P3o01@;0?l02P/0
o`035@3o000:0?l01@/0o`0=2`3o01T:0?l0:@/0o`0l2P3o05<70?[`iP030000003jl>H0n_3V01D0
n_3V00<000000?nQ003oX@004@3oX@0V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00
?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00b_l:002Do`/005ko2P00:_l;00P0o`/0>P3o
2P1[0?l;09X0o`X0aP3o2`3a0?l;0?l0iPX0o`312`3o09l:0?l0O`/0o`1S2`3o04X:0?l0=0/0o`0S
2P3o01@;0?l02P/0o`035@3o000:0?l01@/0o`0=2`3o01T:0?l0:@/0o`0l2P3o05<70?[`iP030000
003jl>H0n_3V01D0n_3V00<000000?nQ003oX@004@3oX@0V0?3io`0300000011JN40@FWQ00H0@FWQ
3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00b_l:002Do`/005ko2P00
:_l;00P0o`/0>P3o2P1[0?l;09X0o`X0aP3o2`3a0?l;0?l0iPX0o`312`3o09l:0?l0O`/0o`1S2`3o
04X:0?l0=0/0o`0S2P3o01@;0?l02P/0o`035@3o000:0?l01@/0o`0=2`3o01T:0?l0:@/0o`0l2P3o
05<70?[`iP030000003jl>H0n_3V01D0n_3V00<000000?nQ003oX@004@3oX@0V0?3io`0300000011
JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00b_l:
002Do`/005ko2P00:_l;00P0o`/0>P3o2P1[0?l;09X0o`X0aP3o2`3a0?l;0?l0iPX0o`312`3o09l:
0?l0O`/0o`1S2`3o04X:0?l0=0/0o`0S2P3o01@;0?l02P/0o`035@3o000:0?l01@/0o`0=2`3o01T:
0?l0:@/0o`0l2P3o05<70?[`iP030000003jl>H0n_3V01D0n_3V00<000000?nQ003oX@004@3oX@0V
0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`
iPX00?oo2`00b_l:002Do`/005ko2P00:_l;00P0o`/0>P3o2P1[0?l;09X0o`X0aP3o2`3a0?l;0?l0
iPX0o`312`3o09l:0?l0O`/0o`1S2`3o04X:0?l0=0/0o`0S2P3o01@;0?l02P/0o`035@3o000:0?l0
1@/0o`0=2`3o01T:0?l0:@/0o`0l2P3o05<70?[`iP030000003jl>H0n_3V01D0n_3V00<000000?nQ
003oX@004@3oX@0V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H2000000H0
n_3V2P00ool;003:o`X009Co2`00G_l:000Zo`/0203o2`0j0?l:06/0o`/0VP3o2P360?l;0?40o`/0
o`3V2P3o0<4;0?l0W`X0o`1o2`3o06<;0?l0BPX0o`0d2`3o02<:0?l050/0o`0:2`3o00<E0?l000X0
o`052`3o00d;0?l06@X0o`0Y2`3o03`:0?l0D`H0n_3V0P00000G0?[`iP030000003olP00oo800140
oo809P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H0
1@3jl>H:003oo`/00<[o2P00U?l;001No`X002[o2`080?l;03X0o`X0J`3o2`2J0?l:0<H0o`/0l@3o
2`3o0>H:0?l0`@/0o`2O2P3o07l;0?l0H`/0o`1:2P3o03@;0?l08`X0o`0D2`3o00X;0?l00aD0o`00
2P3o00D;0?l03@/0o`0I2P3o02T;0?l0?0X0o`1C1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000
003olP00oo800140oo809P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<0
00000?[`iP3jl>H01@3jl>H:003oo`/00<[o2P00U?l;001No`X002[o2`080?l;03X0o`X0J`3o2`2J
0?l:0<H0o`/0l@3o2`3o0>H:0?l0`@/0o`2O2P3o07l;0?l0H`/0o`1:2P3o03@;0?l08`X0o`0D2`3o
00X;0?l00aD0o`002P3o00D;0?l03@/0o`0I2P3o02T;0?l0?0X0o`1C1`3jl>H00`000000n_3V0?[`
iP0E0?[`iP030000003olP00oo800140oo809P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3o
ool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/00<[o2P00U?l;001No`X002[o2`080?l;
03X0o`X0J`3o2`2J0?l:0<H0o`/0l@3o2`3o0>H:0?l0`@/0o`2O2P3o07l;0?l0H`/0o`1:2P3o03@;
0?l08`X0o`0D2`3o00X;0?l00aD0o`002P3o00D;0?l03@/0o`0I2P3o02T;0?l0?0X0o`1C1`3jl>H0
0`000000n_3V0?[`iP0E0?[`iP030000003olP00oo800140oo809P3`nOl00`000000@FWQ045Yh@06
045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/00<7o2P00P_l;0014
o`X000So2`0b0?l;06/0o`X0X@3o2`3E0?l:0?l0nP/0o`3=2`3o0:@:0?l0O`/0o`1O2P3o048;0?l0
:`/0o`0I2P3o00/;0?l00`X0o`002`3o004;0?l02@X0o`0E2`3o02H:0?l0?0/0o`1G2`3o07L:0?l0
V`/0o`332P3o0>l70?[`iP030000003jl>H0n_3V01D0n_3V00<000000?ob003olP004@3olP0V0?3i
o`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX0
0?oo2`00`Ol:0022o`/004Co2P002?l;0380o`/0J`3o2P2Q0?l;0=D0o`X0o`3j2`3o0<d;0?l0Y0X0
o`1o2`3o05l:0?l0@P/0o`0[2`3o01T:0?l02`/0o`032P3o000;0?l00@/0o`092P3o01D;0?l09PX0
o`0l2`3o05L;0?l0M`X0o`2K2`3o0<<:0?l0k`L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000
oo800?ob000A0?ob02H0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000
003jl>H0n_3V00D0n_3V2P00ool;0031o`X008;o2`00A?l:0008o`/0<P3o2`1[0?l:0:40o`/0e@3o
2P3o0?X;0?l0c@/0o`2T2P3o07l;0?l0G`X0o`122`3o02/;0?l06@X0o`0;2`3o00<:0?l000/0o`01
2`3o00T:0?l05@/0o`0V2P3o03`;0?l0E`/0o`1g2P3o09/;0?l0``X0o`3_1`3jl>H00`000000n_3V
0?[`iP0E0?[`iP030000003olP00oo800140oo809P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V
0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/00<7o2P00P_l;0014o`X000So2`0b
0?l;06/0o`X0X@3o2`3E0?l:0?l0nP/0o`3=2`3o0:@:0?l0O`/0o`1O2P3o048;0?l0:`/0o`0I2P3o
00/;0?l00`X0o`002`3o004;0?l02@X0o`0E2`3o02H:0?l0?0/0o`1G2`3o07L:0?l0V`/0o`332P3o
0>l70?[`iP030000003jl>H0n_3V01D0n_3V00<000000?ob003olP004@3olP0V0?3io`0300000011
JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00`Ol:
0022o`/004Co2P002?l;0380o`/0J`3o2P2Q0?l;0=D0o`X0o`3j2`3o0<d;0?l0Y0X0o`1o2`3o05l:
0?l0@P/0o`0[2`3o01T:0?l02`/0o`032P3o000;0?l00@/0o`092P3o01D;0?l09PX0o`0l2`3o05L;
0?l0M`X0o`2K2`3o0<<:0?l0k`L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000oo800?ob000A
0?ob02H0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V
00D0n_3V2P00ool;0031o`X008;o2`00A?l:0008o`/0<P3o2`1[0?l:0:40o`/0e@3o2P3o0?X;0?l0
c@/0o`2T2P3o07l;0?l0G`X0o`122`3o02/;0?l06@X0o`0;2`3o00<:0?l000/0o`012`3o00T:0?l0
5@/0o`0V2P3o03`;0?l0E`/0o`1g2P3o09/;0?l0``X0o`3_1`3jl>H00`000000n_3V0?[`iP0E0?[`
iP030000003olP00oo800140oo809P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0
n_3V0P0000060?[`iPX00?oo2`00`Ol:0022o`/004Co2P002?l;0380o`/0J`3o2P2Q0?l;0=D0o`X0
o`3j2`3o0<d;0?l0Y0X0o`1o2`3o05l:0?l0@P/0o`0[2`3o01T:0?l02`/0o`032P3o000;0?l00@/0
o`092P3o01D;0?l09PX0o`0l2`3o05L;0?l0M`X0o`2K2`3o0<<:0?l0k`H0n_3V0P00000G0?[`iP03
0000003olP00oo800140oo809P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V
00<000000?[`iP3jl>H01@3jl>H:003oo`/00<7o2P00P_l;0014o`X000So2`0b0?l;06/0o`X0X@3o
2`3E0?l:0?l0nP/0o`3=2`3o0:@:0?l0O`/0o`1O2P3o048;0?l0:`/0o`0I2P3o00/;0?l00`X0o`00
2`3o004;0?l02@X0o`0E2`3o02H:0?l0?0/0o`1G2`3o07L:0?l0V`/0o`332P3o0>l70?[`iP030000
003jl>H0n_3V01D0n_3V00<000000?ob003olP004@3olP0V0?3io`0300000011JN40@FWQ00H0@FWQ
3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00`Ol:0022o`/004Co2P00
2?l;0380o`/0J`3o2P2Q0?l;0=D0o`X0o`3j2`3o0<d;0?l0Y0X0o`1o2`3o05l:0?l0@P/0o`0[2`3o
01T:0?l02`/0o`032P3o000;0?l00@/0o`092P3o01D;0?l09PX0o`0l2`3o05L;0?l0M`X0o`2K2`3o
0<<:0?l0k`L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000_?l00;co000A0;co02H0l?Wo00<0
0000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;
0031o`X008;o2`00A?l:0008o`/0<P3o2`1[0?l:0:40o`/0e@3o2P3o0?X;0?l0c@/0o`2T2P3o07l;
0?l0G`X0o`122`3o02/;0?l06@X0o`0;2`3o00<:0?l000/0o`012`3o00T:0?l05@/0o`0V2P3o03`;
0?l0E`/0o`1g2P3o09/;0?l0``X0o`3_1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000002lo`00
_?l00140_?l09P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`
iP3jl>H01@3jl>H:003oo`/00<7o2P00P_l;0014o`X000So2`0b0?l;06/0o`X0X@3o2`3E0?l:0?l0
nP/0o`3=2`3o0:@:0?l0O`/0o`1O2P3o048;0?l0:`/0o`0I2P3o00/;0?l00`X0o`002`3o004;0?l0
2@X0o`0E2`3o02H:0?l0?0/0o`1G2`3o07L:0?l0V`/0o`332P3o0>l70?[`iP030000003jl>H0n_3V
01D0n_3V00<000000;co002lo`004@2lo`0V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?oo
o`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00^?l:001`o`/002[o2P0I0?l;05/0o`/0
VP3o2P3E0?l;0?l0l`X0o`312`3o09@;0?l0K0X0o`1:2`3o02h:0?l06@/0o`0:2`3o004:0?l000/0
o`052P3o014;0?l08`/0o`0l2P3o05`;0?l0P@X0o`2[2`3o0=`;0>l0o`X0]@3o2`1h0?l:03P0o`L0
n_3V00<000000?[`iP3jl>H05@3jl>H00`000000_?l00;co000A0;co02H0l?Wo00<00000045Yh@11
JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;002ho`X0073o
2`00:_l:01T0o`/0F`3o2`2J0?l:0=D0o`/0o`3c2P3o0<4;0?l0U0/0o`1/2P3o04X;0?l0;PX0o`0I
2`3o00X;0?l00@X0o`002`3o00D:0?l04@/0o`0S2`3o03`:0?l0G0/0o`212P3o0:/;0?l0g0/0k`3o
2P2e0?l;07P0o`X0>03o1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000002lo`00_?l00140_?l0
9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3j
l>H:003oo`/00;So2P00L?l;000Zo`X06@3o2`1K0?l;09X0o`X0e@3o2`3o0?<:0?l0`@/0o`2D2`3o
06`:0?l0BP/0o`0^2P3o01T;0?l02P/0o`012P3o000;0?l01@X0o`0A2`3o02<;0?l0?0X0o`1L2`3o
084:0?l0Z`/0o`3L2`3_0?l:0;D0o`/0N03o2P0h0?l70?[`iP030000003jl>H0n_3V01D0n_3V00<0
00000;co002lo`004@2lo`0V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H0
0`000000n_3V0?[`iP050?[`iPX00?oo2`00^?l:001`o`/002[o2P0I0?l;05/0o`/0VP3o2P3E0?l;
0?l0l`X0o`312`3o09@;0?l0K0X0o`1:2`3o02h:0?l06@/0o`0:2`3o004:0?l000/0o`052P3o014;
0?l08`/0o`0l2P3o05`;0?l0P@X0o`2[2`3o0=`;0>l0o`X0]@3o2`1h0?l:03P0o`L0n_3V00<00000
0?[`iP3jl>H05@3jl>H00`000000_?l00;co000A0;co02H0l?Wo00<00000045Yh@11JN401P11JN4=
0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;002ho`X0073o2`00:_l:01T0
o`/0F`3o2`2J0?l:0=D0o`/0o`3c2P3o0<4;0?l0U0/0o`1/2P3o04X;0?l0;PX0o`0I2`3o00X;0?l0
0@X0o`002`3o00D:0?l04@/0o`0S2`3o03`:0?l0G0/0o`212P3o0:/;0?l0g0/0k`3o2P2e0?l;07P0
o`X0>03o1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000002lo`00_?l00140_?l09P3`nOl00`00
0000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V0P0000060?[`iPX00?oo2`00^?l:001`o`/0
02[o2P0I0?l;05/0o`/0VP3o2P3E0?l;0?l0l`X0o`312`3o09@;0?l0K0X0o`1:2`3o02h:0?l06@/0
o`0:2`3o004:0?l000/0o`052P3o014;0?l08`/0o`0l2P3o05`;0?l0P@X0o`2[2`3o0=`;0>l0o`X0
]@3o2`1h0?l:03P0o`H0n_3V0P00000G0?[`iP030000002lo`00_?l00140_?l09P3`nOl00`000000
@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/00;So
2P00L?l;000Zo`X06@3o2`1K0?l;09X0o`X0e@3o2`3o0?<:0?l0`@/0o`2D2`3o06`:0?l0BP/0o`0^
2P3o01T;0?l02P/0o`012P3o000;0?l01@X0o`0A2`3o02<;0?l0?0X0o`1L2`3o084:0?l0Z`/0o`3L
2`3_0?l:0;D0o`/0N03o2P0h0?l70?[`iP030000003jl>H0n_3V01D0n_3V00<000000;co002lo`00
4@2lo`0V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`
iP050?[`iPX00?oo2`00^?l:001`o`/002[o2P0I0?l;05/0o`/0VP3o2P3E0?l;0?l0l`X0o`312`3o
09@;0?l0K0X0o`1:2`3o02h:0?l06@/0o`0:2`3o004:0?l000/0o`052P3o014;0?l08`/0o`0l2P3o
05`;0?l0P@X0o`2[2`3o0=`;0>l0o`X0]@3o2`1h0?l:03P0o`L0n_3V00<000000?[`iP3jl>H05@3j
l>H00`000000_?l00;co000A0;co02H0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o
0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;002ho`X0073o2`00:_l:01T0o`/0F`3o2`2J0?l:
0=D0o`/0o`3c2P3o0<4;0?l0U0/0o`1/2P3o04X;0?l0;PX0o`0I2`3o00X;0?l00@X0o`002`3o00D:
0?l04@/0o`0S2`3o03`:0?l0G0/0o`212P3o0:/;0?l0g0/0k`3o2P2e0?l;07P0o`X0>03o1`3jl>H0
0`000000n_3V0?[`iP0E0?[`iP030000001[o`00Jol00140Jol09P3`nOl00`000000@FWQ045Yh@06
045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/00;So2P00L?l;000Z
o`X06@3o2`1K0?l;09X0o`X0e@3o2`3o0?<:0?l0`@/0o`2D2`3o06`:0?l0BP/0o`0^2P3o01T;0?l0
2P/0o`012P3o000;0?l01@X0o`0A2`3o02<;0?l0?0X0o`1L2`3o084:0?l0Z`/0o`3L2`3_0?l:0;D0
o`/0N03o2P0h0?l70?[`iP030000003jl>H0n_3V01D0n_3V00<0000006_o001[o`004@1[o`0V0?3i
o`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX0
0?oo2`00[ol:001No`/0013o2P0j0?l;0880o`/0aP3o2P3o0?X;0?l0`@X0o`2?2`3o06<;0?l0?`X0
o`0S2`3o00h:0?l00`/0o`002`3o00D:0?l04`/0o`0Y2P3o04L;0?l0K@/0o`2K2P3o0<l;0?D0o`X0
]@3o2`1`0?l;02L0o`X002Co2`00Lol:0033o`L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000
Jol006_o000A06_o02H0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000
003jl>H0n_3V00D0n_3V2P00ool;002_o`X005ko2`004?l:03X0o`/0PP3o2`360?l:0?l0nP/0o`31
2P3o08l;0?l0H`/0o`0o2P3o02<;0?l03PX0o`032`3o000;0?l01@X0o`0C2`3o02T:0?l0A`/0o`1]
2`3o09/:0?l0c`/0m@3o2P2e0?l;0700o`/09`3o2P009?l;001co`X00<?o1`3jl>H00`000000n_3V
0?[`iP0E0?[`iP030000001[o`00Jol00140Jol09P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V
0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/00:oo2P00G_l;000@o`X0>P3o2`22
0?l;0<H0o`X0o`3j2`3o0<4:0?l0S`/0o`1S2`3o03l:0?l08`/0o`0>2P3o00<;0?l000/0o`052P3o
01<;0?l0:@X0o`172`3o06d;0?l0V`X0o`3?2`3e0?l:0;D0o`/0L03o2`0W0?l:000To`/007?o2P00
`ol70?[`iP030000003jl>H0n_3V01D0n_3V00<0000006_o001[o`004@1[o`0V0?3io`0300000011
JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00<P3jl>H6000000L0n_3V00<000000?[`iP3jl>H01@3jl>H:
003oo`/00:oo2P00G_l;000@o`X0>P3o2`220?l;0<H0o`X0o`3j2`3o0<4:0?l0S`/0o`1S2`3o03l:
0?l08`/0o`0>2P3o00<;0?l000/0o`052P3o01<;0?l0:@X0o`172`3o06d;0?l0V`X0o`3?2`3e0?l:
0;D0o`/0L03o2`0W0?l:000To`/007?o2P00`ol70?[`iP030000003jl>H0n_3V01D0n_3V00<00000
06_o001[o`004@1[o`0V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00=03jl>H20000
00T0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/00:oo2P00G_l;000@o`X0>P3o2`220?l;0<H0
o`X0o`3j2`3o0<4:0?l0S`/0o`1S2`3o03l:0?l08`/0o`0>2P3o00<;0?l000/0o`052P3o01<;0?l0
:@X0o`172`3o06d;0?l0V`X0o`3?2`3e0?l:0;D0o`/0L03o2`0W0?l:000To`/007?o2P00`ol70?[`
iP030000003jl>H0n_3V01D0n_3V00<0000006_o001[o`004@1[o`0V0?3io`0300000011JN40@FWQ
00H0@FWQ3@3jl>H10?ooo`00=03jl>H2000000T0n_3V0`0000050?[`iPX00?oo2`00[ol:001No`/0
013o2P0j0?l;0880o`/0aP3o2P3o0?X;0?l0`@X0o`2?2`3o06<;0?l0?`X0o`0S2`3o00h:0?l00`/0
o`002`3o00D:0?l04`/0o`0Y2P3o04L;0?l0K@/0o`2K2P3o0<l;0?D0o`X0]@3o2`1`0?l;02L0o`X0
02Co2`00Lol:0033o`D0n_3V0`00000G0?[`iP030000001[o`00Jol00140Jol09P3`nOl00`000000
@FWQ045Yh@06045Yh@d0n_3V0@3oool003@0n_3V0P0000090?[`iP030000003jl>H0n_3V00D0n_3V
2P00ool;002_o`X005ko2`004?l:03X0o`/0PP3o2`360?l:0?l0nP/0o`312P3o08l;0?l0H`/0o`0o
2P3o02<;0?l03PX0o`032`3o000;0?l01@X0o`0C2`3o02T:0?l0A`/0o`1]2`3o09/:0?l0c`/0m@3o
2P2e0?l;0700o`/09`3o2P009?l;001co`X00<?o1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000
001[o`00Jol00140Jol09P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003@0n_3V0P00
00090?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;002_o`X005ko2`004?l:03X0o`/0PP3o2`36
0?l:0?l0nP/0o`312P3o08l;0?l0H`/0o`0o2P3o02<;0?l03PX0o`032`3o000;0?l01@X0o`0C2`3o
02T:0?l0A`/0o`1]2`3o09/:0?l0c`/0m@3o2P2e0?l;0700o`/09`3o2P009?l;001co`X00<?o1`3j
l>H00`000000n_3V0?[`iP0E0?[`iP030000001[o`00Jol00140Jol09P3`nOl00`000000@FWQ045Y
h@06045Yh@d0n_3V0@3oool003@0n_3V0P0000090?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;
002_o`X005ko2`004?l:03X0o`/0PP3o2`360?l:0?l0nP/0o`312P3o08l;0?l0H`/0o`0o2P3o02<;
0?l03PX0o`032`3o000;0?l01@X0o`0C2`3o02T:0?l0A`/0o`1]2`3o09/:0?l0c`/0m@3o2P2e0?l;
0700o`/09`3o2P009?l;001co`X00<?o1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000001[o`00
Jol00140Jol09P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool00380n_3V100000090?[`
iP030000003jl>H0n_3V00D0n_3V2P00ool;002_o`X005ko2`004?l:03X0o`/0PP3o2`360?l:0?l0
nP/0o`312P3o08l;0?l0H`/0o`0o2P3o02<;0?l03PX0o`032`3o000;0?l01@X0o`0C2`3o02T:0?l0
A`/0o`1]2`3o09/:0?l0c`/0m@3o2P2e0?l;0700o`/09`3o2P009?l;001co`X00<?o1`3jl>H00`00
0000n_3V0?[`iP0E0?[`iP030000001[o`00Jol00140Jol09P3`nOl00`000000@FWQ045Yh@06045Y
h@d0n_3V0@3oool003@0n_3V0P0000090?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;002_o`X0
05ko2`004?l:03X0o`/0PP3o2`360?l:0?l0nP/0o`312P3o08l;0?l0H`/0o`0o2P3o02<;0?l03PX0
o`032`3o000;0?l01@X0o`0C2`3o02T:0?l0A`/0o`1]2`3o09/:0?l0c`/0m@3o2P2e0?l;0700o`/0
9`3o2P009?l;001co`X00<?o1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000000Jo`006_l00140
6_l09P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H0
1@3jl>H:003oo`/00:Ko2P00COl;00P0o`X0F`3o2`2Y0?l;0?40o`X0o`3=2`3o09@:0?l0H`/0o`0k
2`3o01d:0?l02P/0o`002P3o004;0?l03@/0o`0S2P3o04@;0?l0K@X0o`2P2`3o0=`;0>40o`X0U`3o
2`180?l:000:o`/0067o2`00^_l:003oj`/00?nA2P00ocT70?[`iP030000003jl>H0n_3V01D0n_3V
00<0000001[o000Jo`004@0Jo`0V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3j
l>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00Y_l:001=o`/0203o2P1K0?l;0:T0o`/0l@3o2P3o
0<d;0?l0U0X0o`1S2`3o03/;0?l07@X0o`0:2`3o000:0?l00@/0o`0=2`3o02<:0?l0A0/0o`1]2P3o
0:0;0?l0g0/0h@3o2P2G0?l;04P0o`X000[o2`00HOl;002jo`X00?o[2`00oi4:003o>@L0n_3V00<0
00000?[`iP3jl>H05@3jl>H00`0000006_l001[o000A01[o02H0l?Wo00<00000045Yh@11JN401P11
JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;002Vo`X004go2`080?l:
05/0o`/0Z@3o2`3a0?l:0?l0c@/0o`2D2P3o06<;0?l0>`/0o`0M2P3o00X;0?l000X0o`012`3o00d;
0?l08`X0o`142`3o06d:0?l0X0/0o`3L2`3Q0?l:09L0o`/0B03o2P002_l;001Qo`/00;[o2P00on/;
003oT@X00?li1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000000Jo`006_l001406_l09P3`nOl0
0`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003o
o`/00:Ko2P00COl;00P0o`X0F`3o2`2Y0?l;0?40o`X0o`3=2`3o09@:0?l0H`/0o`0k2`3o01d:0?l0
2P/0o`002P3o004;0?l03@/0o`0S2P3o04@;0?l0K@X0o`2P2`3o0=`;0>40o`X0U`3o2`180?l:000:
o`/0067o2`00^_l:003oj`/00?nA2P00ocT70?[`iP030000003jl>H0n_3V01D0n_3V00<0000001[o
000Jo`004@0Jo`0V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H2000000H0
n_3V2P00ool;002Vo`X004go2`080?l:05/0o`/0Z@3o2`3a0?l:0?l0c@/0o`2D2P3o06<;0?l0>`/0
o`0M2P3o00X;0?l000X0o`012`3o00d;0?l08`X0o`142`3o06d:0?l0X0/0o`3L2`3Q0?l:09L0o`/0
B03o2P002_l;001Qo`/00;[o2P00on/;003oT@X00?li1P3jl>H2000001L0n_3V00<0000001[o000J
o`004@0Jo`0V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V
0?[`iP050?[`iPX00?oo2`00Y_l:001=o`/0203o2P1K0?l;0:T0o`/0l@3o2P3o0<d;0?l0U0X0o`1S
2`3o03/;0?l07@X0o`0:2`3o000:0?l00@/0o`0=2`3o02<:0?l0A0/0o`1]2P3o0:0;0?l0g0/0h@3o
2P2G0?l;04P0o`X000[o2`00HOl;002jo`X00?o[2`00oi4:003o>@L0n_3V00<000000?[`iP3jl>H0
5@3jl>H00`0000006_l001[o000A01[o02H0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo
000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;002Vo`X004go2`080?l:05/0o`/0Z@3o2`3a
0?l:0?l0c@/0o`2D2P3o06<;0?l0>`/0o`0M2P3o00X;0?l000X0o`012`3o00d;0?l08`X0o`142`3o
06d:0?l0X0/0o`3L2`3Q0?l:09L0o`/0B03o2P002_l;001Qo`/00;[o2P00on/;003oT@X00?li1`3j
l>H00`000000n_3V0?[`iP0E0?[`iP030000000Jo`006_l001406_l09P3`nOl00`000000@FWQ045Y
h@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/00:Ko2P00COl;
00P0o`X0F`3o2`2Y0?l;0?40o`X0o`3=2`3o09@:0?l0H`/0o`0k2`3o01d:0?l02P/0o`002P3o004;
0?l03@/0o`0S2P3o04@;0?l0K@X0o`2P2`3o0=`;0>40o`X0U`3o2`180?l:000:o`/0067o2`00^_l:
003oj`/00?nA2P00ocT70?[`iP030000003jl>H0n_3V01D0n_3V00<0000001[o000Jo`004@0Jo`0V
0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`
iPX00?oo2`00Y_l:001=o`/0203o2P1K0?l;0:T0o`/0l@3o2P3o0<d;0?l0U0X0o`1S2`3o03/;0?l0
7@X0o`0:2`3o000:0?l00@/0o`0=2`3o02<:0?l0A0/0o`1]2P3o0:0;0?l0g0/0h@3o2P2G0?l;04P0
o`X000[o2`00HOl;002jo`X00?o[2`00oi4:003o>@L0n_3V00<000000?[`iP3jl>H05@3jl>H00`00
00006_l001[o000A01[o02H0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP03
0000003jl>H0n_3V00D0n_3V2P00ool;002Vo`X004go2`080?l:05/0o`/0Z@3o2`3a0?l:0?l0c@/0
o`2D2P3o06<;0?l0>`/0o`0M2P3o00X;0?l000X0o`012`3o00d;0?l08`X0o`142`3o06d:0?l0X0/0
o`3L2`3Q0?l:09L0o`/0B03o2P002_l;001Qo`/00;[o2P00on/;003oT@X00?li1`3jl>H00`000000
n_3V0?[`iP0E0?[`iP030000000Jo`006_l001406_l09P3`nOl00`000000@FWQ045Yh@06045Yh@d0
n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/009go2P00>ol;0280o`X0N`3o
2`3>0?l;0?l0iPX0o`2T2`3o06`:0?l0?`/0o`0M2`3o00P:0?l000/0o`042P3o01D;0?l0<P/0o`1L
2P3o090;0?l0c`X0j03o2`2G0?l;0400o`X001_o2`00O?l:003No`/00?nn2`00oe`:00;o00/0GOl0
2P2co`070?[`iP030000003jl>H0n_3V01D0n_3V00<00000003o=P00ocH04@00ocHV0?3io`030000
0011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00
WOl:000ko`/08P3o2P1k0?l;0<h0o`/0o`3V2P3o0:@;0?l0K0X0o`0o2`3o01d;0?l020X0o`002`3o
00@:0?l05@/0o`0b2`3o05`:0?l0T0/0o`3?2P3X0?l;09L0o`/0@03o2P006ol;001lo`X00=ko2`00
okh;003oG0X00_l02`1Mo`0:0;?o00L0n_3V00<000000?[`iP3jl>H05@3jl>H00`0000000?lf003o
=P0A003o=RH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0
n_3V00D0n_3V2P00ool;002Mo`X003_o2`0R0?l:07/0o`/0cP3o2`3o0>H:0?l0Y0/0o`1/2P3o03l;
0?l07@/0o`082P3o000;0?l010X0o`0E2`3o038;0?l0G0X0o`2@2`3o0<l:0>P0o`/0U`3o2`100?l:
000Ko`/007co2P00g_l;003o_P/00?mL2P02o`0;05go00X0/ol01`3jl>H00`000000n_3V0?[`iP0E
0?[`iP0300000000ocH00?lf01400?lf9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool0
03l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/009go2P00>ol;0280o`X0N`3o2`3>0?l;0?l0
iPX0o`2T2`3o06`:0?l0?`/0o`0M2`3o00P:0?l000/0o`042P3o01D;0?l0<P/0o`1L2P3o090;0?l0
c`X0j03o2`2G0?l;0400o`X001_o2`00O?l:003No`/00?nn2`00oe`:00;o00/0GOl02P2co`070?[`
iP030000003jl>H0n_3V01D0n_3V00<00000003o=P00ocH04@00ocHV0?3io`0300000011JN40@FWQ
00H0@FWQ3@3jl>H10?ooo`00?`3jl>H2000000H0n_3V2P00ool;002Mo`X003_o2`0R0?l:07/0o`/0
cP3o2`3o0>H:0?l0Y0/0o`1/2P3o03l;0?l07@/0o`082P3o000;0?l010X0o`0E2`3o038;0?l0G0X0
o`2@2`3o0<l:0>P0o`/0U`3o2`100?l:000Ko`/007co2P00g_l;003o_P/00?mL2P02o`0;05go00X0
/ol01P3jl>H2000001L0n_3V00<00000003o=P00ocH04@00ocHV0?3io`0300000011JN40@FWQ00H0
@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00WOl:000ko`/08P3o
2P1k0?l;0<h0o`/0o`3V2P3o0:@;0?l0K0X0o`0o2`3o01d;0?l020X0o`002`3o00@:0?l05@/0o`0b
2`3o05`:0?l0T0/0o`3?2P3X0?l;09L0o`/0@03o2P006ol;001lo`X00=ko2`00okh;003oG0X00_l0
2`1Mo`0:0;?o00L0n_3V00<000000?[`iP3jl>H05@3jl>H00`0000000?lf003o=P0A003o=RH0l?Wo
00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00
ool;002Mo`X003_o2`0R0?l:07/0o`/0cP3o2`3o0>H:0?l0Y0/0o`1/2P3o03l;0?l07@/0o`082P3o
000;0?l010X0o`0E2`3o038;0?l0G0X0o`2@2`3o0<l:0>P0o`/0U`3o2`100?l:000Ko`/007co2P00
g_l;003o_P/00?mL2P02o`0;05go00X0/ol01`3jl>H00`000000n_3V0?[`iP0E0?[`iP0300000000
ocH00?lf01400?lf9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<00000
0?[`iP3jl>H01@3jl>H:003oo`/009go2P00>ol;0280o`X0N`3o2`3>0?l;0?l0iPX0o`2T2`3o06`:
0?l0?`/0o`0M2`3o00P:0?l000/0o`042P3o01D;0?l0<P/0o`1L2P3o090;0?l0c`X0j03o2`2G0?l;
0400o`X001_o2`00O?l:003No`/00?nn2`00oe`:00;o00/0GOl02P2co`070?[`iP030000003jl>H0
n_3V01D0n_3V00<00000003o=P00ocH04@00ocHV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H1
0?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00WOl:000ko`/08P3o2P1k0?l;0<h0
o`/0o`3V2P3o0:@;0?l0K0X0o`0o2`3o01d;0?l020X0o`002`3o00@:0?l05@/0o`0b2`3o05`:0?l0
T0/0o`3?2P3X0?l;09L0o`/0@03o2P006ol;001lo`X00=ko2`00okh;003oG0X00_l02`1Mo`0:0;?o
00L0n_3V00<000000?[`iP3jl>H05@3jl>H00`0000000?lf003o=P0A003o=RH0l?Wo00<00000045Y
h@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;002Mo`X0
03_o2`0R0?l:07/0o`/0cP3o2`3o0>H:0?l0Y0/0o`1/2P3o03l;0?l07@/0o`082P3o000;0?l010X0
o`0E2`3o038;0?l0G0X0o`2@2`3o0<l:0>P0o`/0U`3o2`100?l:000Ko`/007co2P00g_l;003o_P/0
0?mL2P02o`0;05go00X0/ol01`3jl>H00`000000n_3V0?[`iP0E0?[`iP0300000000ocH00?lf0140
0?lf9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H0
1@3jl>H:003oo`/009go2P00>ol;0280o`X0N`3o2`3>0?l;0?l0iPX0o`2T2`3o06`:0?l0?`/0o`0M
2`3o00P:0?l000/0o`042P3o01D;0?l0<P/0o`1L2P3o090;0?l0c`X0j03o2`2G0?l;0400o`X001_o
2`00O?l:003No`/00?nn2`00oe`:00;o00/0GOl02P2co`070?[`iP030000003jl>H0n_3V01D0n_3V
00<00000003o=P00ocH04@00ocHV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3j
l>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00U?l:000Zo`/0>P3o2P2J0?l;0?40o`/0o`312P3o
07l;0?l0BPX0o`0S2`3o00X;0?l000X0o`052`3o01T:0?l0?0/0o`1]2`3o0:/:0?l0m@/0]@3o2P1H
0?l;000:o`/007?o2P00g_l;003o]@X00?m:2`0Lo`0;07go00X0eol02`3of00:0?nB00L0n_3V00<0
00000?[`iP3jl>H05@3jl>H00`0000000?lf003o=P0A003o=RH0l?Wo00<00000045Yh@11JN401P11
JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;002Do`X002[o2`0j0?l:
09X0o`/0l@3o2`3o0<4:0?l0O`/0o`1:2P3o02<;0?l02P/0o`002P3o00D;0?l06@X0o`0l2`3o06d;
0?l0Z`X0o`3e2`2e0?l:05P0o`/000[o2`00Lol:003No`/00?ne2P00odX;01co00/0OOl02P3Go`0;
0?oH00X0oi801`3jl>H00`000000n_3V0?[`iP0E0?[`iP0300000000ohH00?n601400?n69P3`nOl0
0`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003o
o`/009Co2P00:_l;03X0o`X0VP3o2`3a0?l;0?l0`@X0o`1o2`3o04X:0?l08`/0o`0:2`3o000:0?l0
1@/0o`0I2P3o03`;0?l0K@/0o`2[2P3o0?D;0;D0o`X0F03o2`002_l;001co`X00=ko2`00okD:003o
BP/07?l02`1mo`0:0=Oo00/0omP02P3oTP070?[`iP030000003jl>H0n_3V01D0n_3V00<00000003o
QP00ohH04@00ohHV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H2000000H0
n_3V2P00ool;002Do`X002[o2`0j0?l:09X0o`/0l@3o2`3o0<4:0?l0O`/0o`1:2P3o02<;0?l02P/0
o`002P3o00D;0?l06@X0o`0l2`3o06d;0?l0Z`X0o`3e2`2e0?l:05P0o`/000[o2`00Lol:003No`/0
0?ne2P00odX;01co00/0OOl02P3Go`0;0?oH00X0oi801P3jl>H2000001L0n_3V00<00000003oQP00
ohH04@00ohHV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V
0?[`iP050?[`iPX00?oo2`00U?l:000Zo`/0>P3o2P2J0?l;0?40o`/0o`312P3o07l;0?l0BPX0o`0S
2`3o00X;0?l000X0o`052`3o01T:0?l0?0/0o`1]2`3o0:/:0?l0m@/0]@3o2P1H0?l;000:o`/007?o
2P00g_l;003o]@X00?m:2`0Lo`0;07go00X0eol02`3of00:0?nB00L0n_3V00<000000?[`iP3jl>H0
5@3jl>H00`0000000?n6003oQP0A003oQRH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo
000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;002Do`X002[o2`0j0?l:09X0o`/0l@3o2`3o
0<4:0?l0O`/0o`1:2P3o02<;0?l02P/0o`002P3o00D;0?l06@X0o`0l2`3o06d;0?l0Z`X0o`3e2`2e
0?l:05P0o`/000[o2`00Lol:003No`/00?ne2P00odX;01co00/0OOl02P3Go`0;0?oH00X0oi801`3j
l>H00`000000n_3V0?[`iP0E0?[`iP0300000000ohH00?n601400?n69P3`nOl00`000000@FWQ045Y
h@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/009Co2P00:_l;
03X0o`X0VP3o2`3a0?l;0?l0`@X0o`1o2`3o04X:0?l08`/0o`0:2`3o000:0?l01@/0o`0I2P3o03`;
0?l0K@/0o`2[2P3o0?D;0;D0o`X0F03o2`002_l;001co`X00=ko2`00okD:003oBP/07?l02`1mo`0:
0=Oo00/0omP02P3oTP070?[`iP030000003jl>H0n_3V01D0n_3V00<00000003oQP00ohH04@00ohHV
0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`
iPX00?oo2`00U?l:000Zo`/0>P3o2P2J0?l;0?40o`/0o`312P3o07l;0?l0BPX0o`0S2`3o00X;0?l0
00X0o`052`3o01T:0?l0?0/0o`1]2`3o0:/:0?l0m@/0]@3o2P1H0?l;000:o`/007?o2P00g_l;003o
]@X00?m:2`0Lo`0;07go00X0eol02`3of00:0?nB00L0n_3V00<000000?[`iP3jl>H05@3jl>H00`00
00000?n6003oQP0A003oQRH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP03
0000003jl>H0n_3V00D0n_3V2P00ool;002Do`X002[o2`0j0?l:09X0o`/0l@3o2`3o0<4:0?l0O`/0
o`1:2P3o02<;0?l02P/0o`002P3o00D;0?l06@X0o`0l2`3o06d;0?l0Z`X0o`3e2`2e0?l:05P0o`/0
00[o2`00Lol:003No`/00?ne2P00odX;01co00/0OOl02P3Go`0;0?oH00X0oi801`3jl>H00`000000
n_3V0?[`iP0E0?[`iP0300000000ohH00?n601400?n69P3`nOl00`000000@FWQ045Yh@06045Yh@d0
n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/009Co2P00:_l;03X0o`X0VP3o
2`3a0?l;0?l0`@X0o`1o2`3o04X:0?l08`/0o`0:2`3o000:0?l01@/0o`0I2P3o03`;0?l0K@/0o`2[
2P3o0?D;0;D0o`X0F03o2`002_l;001co`X00=ko2`00okD:003oBP/07?l02`1mo`0:0=Oo00/0omP0
2P3oTP070?[`iP030000003jl>H0n_3V01D0n_3V00<00000003oQP00ohH04@00ohHV0?3io`030000
0011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00
Rol:000Io`/0D`3o2P2h0?l;0?l0k@/0o`2O2P3o05l;0?l0;PX0o`0>2`3o000;0?l010X0o`0I2`3o
040:0?l0M`/0o`2m2`3_0?l:0900o`/09`3o2P00Aol;002jo`/00?o@2P00oe`;01?o00X0OOl02`3N
o`0;0?o;00X0oh<02`3oB@0:0?lO00L0n_3V00<000000?[`iP3jl>H05@3jl>H00`0000000?n6003o
QP0A003oQRH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0
n_3V00D0n_3V2P00ool;002;o`X001Wo2`1C0?l:0;P0o`/0o`3]2`3o09l:0?l0G`/0o`0^2P3o00h;
0?l000/0o`042P3o01T;0?l0@0X0o`1g2`3o0;d;0>l0o`X0T03o2`0W0?l:0017o`/00;[o2`00om0:
003oG0/04ol02P1mo`0;0=ko00/0ol/02P3oP`0;0?m900X0oal01`3jl>H00`000000n_3V0?[`iP0E
0?[`iP0300000000ohH00?n601400?n69P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool0
03l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/008_o2P006Ol;05<0o`X0^03o2`3o0>d;0?l0
W`X0o`1O2`3o02h:0?l03P/0o`002`3o00@:0?l06@/0o`102P3o07L;0?l0_@/0k`3o2P2@0?l;02L0
o`X004Oo2`00^_l;003od0X00?mL2`0Co`0:07go00/0g_l02`3ob`0:0?n300/0odT02P3o7`070?[`
iP030000003jl>H0n_3V01D0n_3V00<00000003oe`00omL04@00omLV0?3io`0300000011JN40@FWQ
00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00Rol:000Io`/0
D`3o2P2h0?l;0?l0k@/0o`2O2P3o05l;0?l0;PX0o`0>2`3o000;0?l010X0o`0I2`3o040:0?l0M`/0
o`2m2`3_0?l:0900o`/09`3o2P00Aol;002jo`/00?o@2P00oe`;01?o00X0OOl02`3No`0;0?o;00X0
oh<02`3oB@0:0?lO00L0n_3V00<000000?[`iP3jl>H05@3jl>H00`0000000?oG003oe`0A003oebH0
l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP8000001P3jl>H:003oo`/008_o
2P006Ol;05<0o`X0^03o2`3o0>d;0?l0W`X0o`1O2`3o02h:0?l03P/0o`002`3o00@:0?l06@/0o`10
2P3o07L;0?l0_@/0k`3o2P2@0?l;02L0o`X004Oo2`00^_l;003od0X00?mL2`0Co`0:07go00/0g_l0
2`3ob`0:0?n300/0odT02P3o7`060?[`iP8000005`3jl>H00`0000000?oG003oe`0A003oebH0l?Wo
00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00
ool;002;o`X001Wo2`1C0?l:0;P0o`/0o`3]2`3o09l:0?l0G`/0o`0^2P3o00h;0?l000/0o`042P3o
01T;0?l0@0X0o`1g2`3o0;d;0>l0o`X0T03o2`0W0?l:0017o`/00;[o2`00om0:003oG0/04ol02P1m
o`0;0=ko00/0ol/02P3oP`0;0?m900X0oal01`3jl>H00`000000n_3V0?[`iP0E0?[`iP0300000000
omL00?oG01400?oG9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<00000
0?[`iP3jl>H01@3jl>H:003oo`/008_o2P006Ol;05<0o`X0^03o2`3o0>d;0?l0W`X0o`1O2`3o02h:
0?l03P/0o`002`3o00@:0?l06@/0o`102P3o07L;0?l0_@/0k`3o2P2@0?l;02L0o`X004Oo2`00^_l;
003od0X00?mL2`0Co`0:07go00/0g_l02`3ob`0:0?n300/0odT02P3o7`070?[`iP030000003jl>H0
n_3V01D0n_3V00<00000003oe`00omL04@00omLV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H1
0?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00Rol:000Io`/0D`3o2P2h0?l;0?l0
k@/0o`2O2P3o05l;0?l0;PX0o`0>2`3o000;0?l010X0o`0I2`3o040:0?l0M`/0o`2m2`3_0?l:0900
o`/09`3o2P00Aol;002jo`/00?o@2P00oe`;01?o00X0OOl02`3No`0;0?o;00X0oh<02`3oB@0:0?lO
00L0n_3V00<000000?[`iP3jl>H05@3jl>H00`0000000?oG003oe`0A003oebH0l?Wo00<00000045Y
h@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;002;o`X0
01Wo2`1C0?l:0;P0o`/0o`3]2`3o09l:0?l0G`/0o`0^2P3o00h;0?l000/0o`042P3o01T;0?l0@0X0
o`1g2`3o0;d;0>l0o`X0T03o2`0W0?l:0017o`/00;[o2`00om0:003oG0/04ol02P1mo`0;0=ko00/0
ol/02P3oP`0;0?m900X0oal01`3jl>H00`000000n_3V0?[`iP0E0?[`iP0300000000omL00?oG0140
0?oG9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H0
1@3jl>H:003oo`/008_o2P006Ol;05<0o`X0^03o2`3o0>d;0?l0W`X0o`1O2`3o02h:0?l03P/0o`00
2`3o00@:0?l06@/0o`102P3o07L;0?l0_@/0k`3o2P2@0?l;02L0o`X004Oo2`00^_l;003od0X00?mL
2`0Co`0:07go00/0g_l02`3ob`0:0?n300/0odT02P3o7`070?[`iP030000003jl>H0n_3V01D0n_3V
00<00000003oe`00omL04@00omLV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3j
l>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00Rol:000Io`/0D`3o2P2h0?l;0?l0k@/0o`2O2P3o
05l;0?l0;PX0o`0>2`3o000;0?l010X0o`0I2`3o040:0?l0M`/0o`2m2`3_0?l:0900o`/09`3o2P00
Aol;002jo`/00?o@2P00oe`;01?o00X0OOl02`3No`0;0?o;00X0oh<02`3oB@0:0?lO00L0n_3V00<0
00000?[`iP3jl>H05@3jl>H00`0000000?oG003oe`0A003oebH0l?Wo00<00000045Yh@11JN401P11
JN4=0?[`iP40oooo000T0?[`iPH000000P3jl>H2000000D0n_3V0`0000090?[`iP030000003jl>H0
n_3V00D0n_3V2P00ool;0022o`X000So2`1[0?l:0=D0o`/0o`3=2`3o07l:0?l0@P/0o`0I2P3o00<;
0?l00@/0o`0E2P3o03`;0?l0M`X0o`332`3Q0?l;07P0o`X01P3o2`00Lol:003`o`/00?nA2`00oaH:
05go00/0bOl02P3of00;0?n800/0odT02P3o7@0;0?l400X0o`001`3jl>H00`000000n_3V0?[`iP0E
0?[`iP0300000000omL00?oG01400?oG9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool0
02H0n_3V0P0000040?[`iP800000103jl>H00`000000n_3V0?[`iP02000000P0n_3V00<000000?[`
iP3jl>H01@3jl>H:003oo`/008;o2P002?l;06/0o`X0e@3o2`3o0<d;0?l0O`X0o`122`3o01T:0?l0
0`/0o`012`3o01D:0?l0?0/0o`1g2P3o0<<;0>40o`/0N03o2P060?l;001co`X00?3o2`00oi4;003o
5PX0GOl02`39o`0:0?oH00/0ohP02`3oB@0:0?lM00/0o`@02P3o00070?[`iP030000003jl>H0n_3V
01D0n_3V00<00000003oe`00omL04@00omLV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?oo
o`009P3jl>H2000000d0n_3V0P0000080?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;0022o`X0
00So2`1[0?l:0=D0o`/0o`3=2`3o07l:0?l0@P/0o`0I2P3o00<;0?l00@/0o`0E2P3o03`;0?l0M`X0
o`332`3Q0?l;07P0o`X01P3o2`00Lol:003`o`/00?nA2`00oaH:05go00/0bOl02P3of00;0?n800/0
odT02P3o7@0;0?l400X0o`001`3jl>H00`000000n_3V0?[`iP0E0?[`iP0300000000omL00?oG0140
0?oG9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool002H0n_3V0P00000=0?[`iP800000
203jl>H3000000D0n_3V2P00ool;0022o`X000So2`1[0?l:0=D0o`/0o`3=2`3o07l:0?l0@P/0o`0I
2P3o00<;0?l00@/0o`0E2P3o03`;0?l0M`X0o`332`3Q0?l;07P0o`X01P3o2`00Lol:003`o`/00?nA
2`00oaH:05go00/0bOl02P3of00;0?n800/0odT02P3o7@0;0?l400X0o`001@3jl>H3000001L0n_3V
00<00000003Go`00eol04@00eolV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`009P3j
l>H2000000X0n_3V00<000000?[`iP3jl>H00P0000080?[`iP030000003jl>H0n_3V00D0n_3V2P00
ool;0022o`X000So2`1[0?l:0=D0o`/0o`3=2`3o07l:0?l0@P/0o`0I2P3o00<;0?l00@/0o`0E2P3o
03`;0?l0M`X0o`332`3Q0?l;07P0o`X01P3o2`00Lol:003`o`/00?nA2`00oaH:05go00/0bOl02P3o
f00;0?n800/0odT02P3o7@0;0?l400X0o`001`3jl>H00`000000n_3V0?[`iP0E0?[`iP0300000000
eol00=Oo01400=Oo9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool002H0n_3V0P00000:
0?[`iP@000002@3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00P_l:0008o`/0J`3o2P3E0?l;
0?l0c@/0o`1o2P3o048;0?l06@X0o`032`3o004;0?l05@X0o`0l2`3o07L:0?l0``/0h@3o2`1h0?l:
00H0o`/007?o2P00l?l;003oT@/00?lF2P1Mo`0;0<Wo00X0omP02`3oR00;0?m900X0oad02`3o100:
0?l000L0n_3V00<000000?[`iP3jl>H05@3jl>H00`0000000=Oo003Go`0A003GobH0l?Wo00<00000
045Yh@11JN401P11JN4=0?[`iP40oooo000T0?[`iP@000002P3jl>H2000000/0n_3V00<000000?[`
iP3jl>H01@3jl>H:003oo`/008;o2P002?l;06/0o`X0e@3o2`3o0<d;0?l0O`X0o`122`3o01T:0?l0
0`/0o`012`3o01D:0?l0?0/0o`1g2P3o0<<;0>40o`/0N03o2P060?l;001co`X00?3o2`00oi4;003o
5PX0GOl02`39o`0:0?oH00/0ohP02`3oB@0:0?lM00/0o`@02P3o00070?[`iP030000003jl>H0n_3V
01D0n_3V00<00000003Go`00eol04@00eolV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?oo
o`00503jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V00P0n_3V0P00000:0?[`iPD0
0000203jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00P_l:0008o`/0J`3o2P3E0?l;0?l0c@/0
o`1o2P3o048;0?l06@X0o`032`3o004;0?l05@X0o`0l2`3o07L:0?l0``/0h@3o2`1h0?l:00H0o`/0
07?o2P00l?l;003oT@/00?lF2P1Mo`0;0<Wo00X0omP02`3oR00;0?m900X0oad02`3o100:0?l000L0
n_3V00<000000?[`iP3jl>H05@3jl>H00`0000000=Oo003Go`0A003GobH0l?Wo00<00000045Yh@11
JN401P11JN4=0?[`iP40oooo000D0?[`iP<00000103jl>H00`000000n_3V0?[`iP0Q0?[`iP030000
003jl>H0n_3V00D0n_3V2P00ool;0022o`X000So2`1[0?l:0=D0o`/0o`3=2`3o07l:0?l0@P/0o`0I
2P3o00<;0?l00@/0o`0E2P3o03`;0?l0M`X0o`332`3Q0?l;07P0o`X01P3o2`00Lol:003`o`/00?nA
2`00oaH:05go00/0bOl02P3of00;0?n800/0odT02P3o7@0;0?l400X0o`001`3jl>H00`000000n_3V
0?[`iP0E0?[`iP0300000000eol00=Oo01400=Oo9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V
0@3oool001@0n_3V2000000S0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;0022o`X000So2`1[
0?l:0=D0o`/0o`3=2`3o07l:0?l0@P/0o`0I2P3o00<;0?l00@/0o`0E2P3o03`;0?l0M`X0o`332`3Q
0?l;07P0o`X01P3o2`00Lol:003`o`/00?nA2`00oaH:05go00/0bOl02P3of00;0?n800/0odT02P3o
7@0;0?l400X0o`001`3jl>H00`000000n_3V0?[`iP0E0?[`iP0300000000eol00=Oo01400=Oo9P3`
nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool001L0n_3V1@00000S0?[`iP030000003jl>H0
n_3V00D0n_3V2P00ool;001io`X0203o2`220?l:0?40o`/0o`2_2`3o06<:0?l0:`/0o`0:2P3o000;
0?l03@/0o`0b2P3o06d;0?l0_@X0h@3o2`1`0?l;000:o`X008ko2`00on/:003oI@/07?l02`2Do`0:
0?oo00/0oj802P3oF@0;0?lT00/0o`H02P3o000;0?lA00X0ocX01`3jl>H00`000000n_3V0?[`iP0E
0?[`iP0300000000eol00=Oo01400=Oo9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool0
01@0n_3V1@0000020?[`iP030000003jl>H0n_3V0240n_3V00<000000?[`iP3jl>H01@3jl>H:003o
o`/007Wo2P080?l;0880o`X0l@3o2`3o0:l;0?l0H`X0o`0[2`3o00X:0?l000/0o`0=2`3o038:0?l0
K@/0o`2m2P3Q0?l;0700o`/000[o2P00S_l;003oj`X00?mU2`0Lo`0;09Co00X0ool02`3oXP0:0?mI
00/0ob@02`3o1P0:0?l000/0oa402P3o>P070?[`iP030000003jl>H0n_3V01D0n_3V00<00000003G
o`00eol04@00eolV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00503jl>H3000002P0
n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/007Wo2P080?l;0880o`X0l@3o2`3o0:l;0?l0H`X0
o`0[2`3o00X:0?l000/0o`0=2`3o038:0?l0K@/0o`2m2P3Q0?l;0700o`/000[o2P00S_l;003oj`X0
0?mU2`0Lo`0;09Co00X0ool02`3oXP0:0?mI00/0ob@02`3o1P0:0?l000/0oa402P3o>P070?[`iP03
0000003jl>H0n_3V01D0n_3V00<00000003Go`00eol04@00eolV0?3io`0300000011JN40@FWQ00H0
@FWQ3@3jl>H10?ooo`00503jl>H00`000000n_3V0?[`iP0X0?[`iP8000001P3jl>H:003oo`/007Wo
2P080?l;0880o`X0l@3o2`3o0:l;0?l0H`X0o`0[2`3o00X:0?l000/0o`0=2`3o038:0?l0K@/0o`2m
2P3Q0?l;0700o`/000[o2P00S_l;003oj`X00?mU2`0Lo`0;09Co00X0ool02`3oXP0:0?mI00/0ob@0
2`3o1P0:0?l000/0oa402P3o>P060?[`iP8000005`3jl>H00`0000000=Oo003Go`0A003GobH0l?Wo
00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00
ool;001io`X0203o2`220?l:0?40o`/0o`2_2`3o06<:0?l0:`/0o`0:2P3o000;0?l03@/0o`0b2P3o
06d;0?l0_@X0h@3o2`1`0?l;000:o`X008ko2`00on/:003oI@/07?l02`2Do`0:0?oo00/0oj802P3o
F@0;0?lT00/0o`H02P3o000;0?lA00X0ocX01`3jl>H00`000000n_3V0?[`iP0E0?[`iP0300000000
Q_l008Ko014008Ko9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<00000
0?[`iP3jl>H01@3jl>H:003oo`/007Wo2P080?l;0880o`X0l@3o2`3o0:l;0?l0H`X0o`0[2`3o00X:
0?l000/0o`0=2`3o038:0?l0K@/0o`2m2P3Q0?l;0700o`/000[o2P00S_l;003oj`X00?mU2`0Lo`0;
09Co00X0ool02`3oXP0:0?mI00/0ob@02`3o1P0:0?l000/0oa402P3o>P070?[`iP030000003jl>H0
n_3V01D0n_3V00<000000026o`00Q_l04@00Q_lV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H1
0?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00NOl:00P0o`/0PP3o2P3a0?l;0?l0
[`/0o`1S2P3o02/;0?l02PX0o`002`3o00d;0?l0<PX0o`1]2`3o0;d:0>40o`/0L03o2`002_l:002>
o`/00?o[2P00ofD;01co00/0U?l02P3oo`0;0?nR00X0oeT02`3o900;0?l600X0o`002`3o4@0:0?lj
00L0n_3V00<000000?[`iP3jl>H05@3jl>H00`00000008Ko0026o`0A0026obH0l?Wo00<00000045Y
h@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;001io`X0
203o2`220?l:0?40o`/0o`2_2`3o06<:0?l0:`/0o`0:2P3o000;0?l03@/0o`0b2P3o06d;0?l0_@X0
h@3o2`1`0?l;000:o`X008ko2`00on/:003oI@/07?l02`2Do`0:0?oo00/0oj802P3oF@0;0?lT00/0
o`H02P3o000;0?lA00X0ocX01`3jl>H00`000000n_3V0?[`iP0E0?[`iP0300000000Q_l008Ko0140
08Ko9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H0
1@3jl>H:003oo`/007Wo2P080?l;0880o`X0l@3o2`3o0:l;0?l0H`X0o`0[2`3o00X:0?l000/0o`0=
2`3o038:0?l0K@/0o`2m2P3Q0?l;0700o`/000[o2P00S_l;003oj`X00?mU2`0Lo`0;09Co00X0ool0
2`3oXP0:0?mI00/0ob@02`3o1P0:0?l000/0oa402P3o>P070?[`iP030000003jl>H0n_3V01D0n_3V
00<000000026o`00Q_l04@00Q_lV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3j
l>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00NOl:00P0o`/0PP3o2P3a0?l;0?l0[`/0o`1S2P3o
02/;0?l02PX0o`002`3o00d;0?l0<PX0o`1]2`3o0;d:0>40o`/0L03o2`002_l:002>o`/00?o[2P00
ofD;01co00/0U?l02P3oo`0;0?nR00X0oeT02`3o900;0?l600X0o`002`3o4@0:0?lj00L0n_3V00<0
00000?[`iP3jl>H05@3jl>H00`00000008Ko0026o`0A0026obH0l?Wo00<00000045Yh@11JN401P11
JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;001io`X0203o2`220?l:
0?40o`/0o`2_2`3o06<:0?l0:`/0o`0:2P3o000;0?l03@/0o`0b2P3o06d;0?l0_@X0h@3o2`1`0?l;
000:o`X008ko2`00on/:003oI@/07?l02`2Do`0:0?oo00/0oj802P3oF@0;0?lT00/0o`H02P3o000;
0?lA00X0ocX01`3jl>H00`000000n_3V0?[`iP0E0?[`iP0300000000Q_l008Ko014008Ko9P3`nOl0
0`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003o
o`/0073o2P0I0?l;09X0o`X0o`3c2`3o09@;0?l0BPX0o`0I2`3o004:0?l01@/0o`0S2`3o05`:0?l0
Z`/0k`3o2P1h0?l;000:o`/009Ko2P00omT;003oBPX0?Ol02`2jo`0;0?oH00X0ogh02`3o>P0:0?l@
00/0o`002`3o2P0:0?l`00/0ofl02P3oa@070?[`iP030000003jl>H0n_3V01D0n_3V00<000000026
o`00Q_l04@00Q_lV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000
n_3V0?[`iP050?[`iPX00?oo2`00L?l:01T0o`/0VP3o2P3o0?<;0?l0U0/0o`1:2P3o01T;0?l00@X0
o`052`3o02<;0?l0G0X0o`2[2`3_0?l:07P0o`/000[o2`00U_l:003of@/00?m:2P0mo`0;0;[o00/0
omP02P3oOP0;0?lj00X0oa002`3o000;0?l:00X0oc002`3oK`0:0?o500L0n_3V00<000000?[`iP3j
l>H05@3jl>H00`00000008Ko0026o`0A0026obH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40
oooo000o0?[`iP8000001P3jl>H:003oo`/0073o2P0I0?l;09X0o`X0o`3c2`3o09@;0?l0BPX0o`0I
2`3o004:0?l01@/0o`0S2`3o05`:0?l0Z`/0k`3o2P1h0?l;000:o`/009Ko2P00omT;003oBPX0?Ol0
2`2jo`0;0?oH00X0ogh02`3o>P0:0?l@00/0o`002`3o2P0:0?l`00/0ofl02P3oa@060?[`iP800000
5`3jl>H00`00000008Ko0026o`0A0026obH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo
000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;001`o`X06@3o2`2J0?l:0?l0l`/0o`2D2`3o
04X:0?l06@/0o`012P3o00D;0?l08`/0o`1L2P3o0:/;0>l0o`X0N03o2`002_l;002Fo`X00?oI2`00
odX:03go00/0^_l02`3of00:0?mn00/0ocX02P3o400;0?l000/0o`X02P3o<00;0?m_00X0olD01`3j
l>H00`000000n_3V0?[`iP0E0?[`iP0300000000Q_l008Ko014008Ko9P3`nOl00`000000@FWQ045Y
h@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/0073o2P0I0?l;
09X0o`X0o`3c2`3o09@;0?l0BPX0o`0I2`3o004:0?l01@/0o`0S2`3o05`:0?l0Z`/0k`3o2P1h0?l;
000:o`/009Ko2P00omT;003oBPX0?Ol02`2jo`0;0?oH00X0ogh02`3o>P0:0?l@00/0o`002`3o2P0:
0?l`00/0ofl02P3oa@070?[`iP030000003jl>H0n_3V01D0n_3V00<000000026o`00Q_l04@00Q_lV
0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`
iPX00?oo2`00L?l:01T0o`/0VP3o2P3o0?<;0?l0U0/0o`1:2P3o01T;0?l00@X0o`052`3o02<;0?l0
G0X0o`2[2`3_0?l:07P0o`/000[o2`00U_l:003of@/00?m:2P0mo`0;0;[o00/0omP02P3oOP0;0?lj
00X0oa002`3o000;0?l:00X0oc002`3oK`0:0?o500L0n_3V00<000000?[`iP3jl>H05@3jl>H00`00
000003Ko000fo`0A000fobH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP03
0000003jl>H0n_3V00D0n_3V2P00ool;001`o`X06@3o2`2J0?l:0?l0l`/0o`2D2`3o04X:0?l06@/0
o`012P3o00D;0?l08`/0o`1L2P3o0:/;0>l0o`X0N03o2`002_l;002Fo`X00?oI2`00odX:03go00/0
^_l02`3of00:0?mn00/0ocX02P3o400;0?l000/0o`X02P3o<00;0?m_00X0olD01`3jl>H00`000000
n_3V0?[`iP0E0?[`iP0300000000=_l003Ko014003Ko9P3`nOl00`000000@FWQ045Yh@06045Yh@d0
n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/0073o2P0I0?l;09X0o`X0o`3c
2`3o09@;0?l0BPX0o`0I2`3o004:0?l01@/0o`0S2`3o05`:0?l0Z`/0k`3o2P1h0?l;000:o`/009Ko
2P00omT;003oBPX0?Ol02`2jo`0;0?oH00X0ogh02`3o>P0:0?l@00/0o`002`3o2P0:0?l`00/0ofl0
2P3oa@070?[`iP030000003jl>H0n_3V01D0n_3V00<00000000fo`00=_l04@00=_lV0?3io`030000
0011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00
L?l:01T0o`/0VP3o2P3o0?<;0?l0U0/0o`1:2P3o01T;0?l00@X0o`052`3o02<;0?l0G0X0o`2[2`3_
0?l:07P0o`/000[o2`00U_l:003of@/00?m:2P0mo`0;0;[o00/0omP02P3oOP0;0?lj00X0oa002`3o
000;0?l:00X0oc002`3oK`0:0?o500L0n_3V00<000000?[`iP3jl>H05@3jl>H00`00000003Ko000f
o`0A000fobH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0
n_3V00D0n_3V2P00ool;001`o`X06@3o2`2J0?l:0?l0l`/0o`2D2`3o04X:0?l06@/0o`012P3o00D;
0?l08`/0o`1L2P3o0:/;0>l0o`X0N03o2`002_l;002Fo`X00?oI2`00odX:03go00/0^_l02`3of00:
0?mn00/0ocX02P3o400;0?l000/0o`X02P3o<00;0?m_00X0olD01`3jl>H00`000000n_3V0?[`iP0E
0?[`iP0300000000=_l003Ko014003Ko9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool0
03l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/006Oo2P0Z0?l;0;00o`X0o`3J2`3o07X;0?l0
=0X0o`0;2`3o000:0?l04`/0o`142`3o090:0?l0m@/0T03o2P060?l;002>o`/00?oI2P00od4;04go
00X0d?l02`3o_`0;0?mV00X0obL02`3o1@0:0?l200/0oa`02`3oE00:0?nW00/0kOl02P1^o`070?[`
iP030000003jl>H0n_3V01D0n_3V00<00000000fo`00=_l04@00=_lV0?3io`0300000011JN40@FWQ
00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00Iol:02X0o`/0
/03o2P3o0=X;0?l0NP/0o`0d2P3o00/;0?l000X0o`0C2`3o04@;0?l0T0X0o`3e2`2@0?l:00H0o`/0
08ko2`00omT:003o@@/0COl02P3@o`0;0?no00/0ofH02P3o9`0;0?l500X0o`802`3o700;0?mD00X0
ojL02`3]o`0:06ko00L0n_3V00<000000?[`iP3jl>H05@3jl>H00`00000003Ko000fo`0A000fobH0
l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP8000001P3jl>H:003oo`/006Oo
2P0Z0?l;0;00o`X0o`3J2`3o07X;0?l0=0X0o`0;2`3o000:0?l04`/0o`142`3o090:0?l0m@/0T03o
2P060?l;002>o`/00?oI2P00od4;04go00X0d?l02`3o_`0;0?mV00X0obL02`3o1@0:0?l200/0oa`0
2`3oE00:0?nW00/0kOl02P1^o`060?[`iP8000005`3jl>H00`00000003Ko000fo`0A000fobH0l?Wo
00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00
ool;001Wo`X0:P3o2`2`0?l:0?l0fP/0o`1j2`3o03@:0?l02`/0o`002P3o01<;0?l0A0/0o`2@2P3o
0?D;0900o`X01P3o2`00S_l;003of@X00?m12`1=o`0:0=3o00/0okl02`3oIP0:0?lW00/0o`D02P3o
0P0;0?lL00/0oe@02P3oY`0;0>go00X0K_l01`3jl>H00`000000n_3V0?[`iP0E0?[`iP0300000000
=_l003Ko014003Ko9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<00000
0?[`iP3jl>H01@3jl>H:003oo`/006Oo2P0Z0?l;0;00o`X0o`3J2`3o07X;0?l0=0X0o`0;2`3o000:
0?l04`/0o`142`3o090:0?l0m@/0T03o2P060?l;002>o`/00?oI2P00od4;04go00X0d?l02`3o_`0;
0?mV00X0obL02`3o1@0:0?l200/0oa`02`3oE00:0?nW00/0kOl02P1^o`070?[`iP030000003jl>H0
n_3V01D0n_3V00<00000000fo`00=_l04@00=_lV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H1
0?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00Iol:02X0o`/0/03o2P3o0=X;0?l0
NP/0o`0d2P3o00/;0?l000X0o`0C2`3o04@;0?l0T0X0o`3e2`2@0?l:00H0o`/008ko2`00omT:003o
@@/0COl02P3@o`0;0?no00/0ofH02P3o9`0;0?l500X0o`802`3o700;0?mD00X0ojL02`3]o`0:06ko
00L0n_3V00<000000?[`iP3jl>H05@3jl>H00`00000003Ko000fo`0A000fobH0l?Wo00<00000045Y
h@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;001Wo`X0
:P3o2`2`0?l:0?l0fP/0o`1j2`3o03@:0?l02`/0o`002P3o01<;0?l0A0/0o`2@2P3o0?D;0900o`X0
1P3o2`00S_l;003of@X00?m12`1=o`0:0=3o00/0okl02`3oIP0:0?lW00/0o`D02P3o0P0;0?lL00/0
oe@02P3oY`0;0>go00X0K_l01`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000000J0?l06P3o0140
6P3o9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H0
1@3jl>H:003oo`/006Oo2P0Z0?l;0;00o`X0o`3J2`3o07X;0?l0=0X0o`0;2`3o000:0?l04`/0o`14
2`3o090:0?l0m@/0T03o2P060?l;002>o`/00?oI2P00od4;04go00X0d?l02`3o_`0;0?mV00X0obL0
2`3o1@0:0?l200/0oa`02`3oE00:0?nW00/0kOl02P1^o`070?[`iP030000003jl>H0n_3V01D0n_3V
00<0000001X0o`0J0?l04@0J0?lV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3j
l>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00Iol:02X0o`/0/03o2P3o0=X;0?l0NP/0o`0d2P3o
00/;0?l000X0o`0C2`3o04@;0?l0T0X0o`3e2`2@0?l:00H0o`/008ko2`00omT:003o@@/0COl02P3@
o`0;0?no00/0ofH02P3o9`0;0?l500X0o`802`3o700;0?mD00X0ojL02`3]o`0:06ko00L0n_3V00<0
00000?[`iP3jl>H05@3jl>H00`0000006P3o01X0o`0A01X0obH0l?Wo00<00000045Yh@11JN401P11
JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;001Wo`X0:P3o2`2`0?l:
0?l0fP/0o`1j2`3o03@:0?l02`/0o`002P3o01<;0?l0A0/0o`2@2P3o0?D;0900o`X01P3o2`00S_l;
003of@X00?m12`1=o`0:0=3o00/0okl02`3oIP0:0?lW00/0o`D02P3o0P0;0?lL00/0oe@02P3oY`0;
0>go00X0K_l01`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000000J0?l06P3o01406P3o9P3`nOl0
0`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003o
o`/006Oo2P0Z0?l;0;00o`X0o`3J2`3o07X;0?l0=0X0o`0;2`3o000:0?l04`/0o`142`3o090:0?l0
m@/0T03o2P060?l;002>o`/00?oI2P00od4;04go00X0d?l02`3o_`0;0?mV00X0obL02`3o1@0:0?l2
00/0oa`02`3oE00:0?nW00/0kOl02P1^o`070?[`iP030000003jl>H0n_3V01D0n_3V00<0000001X0
o`0J0?l04@0J0?lV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000
n_3V0?[`iP050?[`iPX00?oo2`00G_l:03X0o`/0aP3o2P3o0<4;0?l0H`/0o`0S2P3o00<;0?l01@X0
o`0Y2`3o06d;0?l0c`X0]@3o2`0W0?l:001co`/00?o[2`00odX:04go00/0eol02P3o/`0;0?mI00/0
oad02P3o0@0;0?l800X0oc002`3oN00;0?oM00X0Y?l02`0Do`0:003oQ`L0n_3V00<000000?[`iP3j
l>H05@3jl>H00`0000006P3o01X0o`0A01X0obH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40
oooo000o0?[`iP8000001P3jl>H:003oo`/005ko2P0j0?l;0<H0o`X0o`312`3o06<;0?l08`X0o`03
2`3o00D:0?l0:@/0o`1]2`3o0<l:0;D0o`/09`3o2P00Lol;003oj`/00?m:2P1=o`0;0=Oo00X0ok<0
2`3oF@0;0?lM00X0o`402`3o200:0?l`00/0ogP02`3og@0:0:Co00/05?l02P00ohL60?[`iP800000
5`3jl>H00`0000006P3o01X0o`0A01X0obH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo
000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;001No`X0>P3o2`360?l:0?l0`@/0o`1S2`3o
02<:0?l00`/0o`052P3o02T;0?l0K@/0o`3?2P2e0?l;02L0o`X007?o2`00on/;003oBPX0COl02`3G
o`0:0?nc00/0oeT02`3o7@0:0?l100/0o`P02P3o<00;0?mh00/0omd02P2To`0;01Co00X00?n71`3j
l>H00`000000n_3V0?[`iP0E0?[`iP030000000J0?l06P3o01406P3o9P3`nOl00`000000@FWQ045Y
h@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/005ko2P0j0?l;
0<H0o`X0o`312`3o06<;0?l08`X0o`032`3o00D:0?l0:@/0o`1]2`3o0<l:0;D0o`/09`3o2P00Lol;
003oj`/00?m:2P1=o`0;0=Oo00X0ok<02`3oF@0;0?lM00X0o`402`3o200:0?l`00/0ogP02`3og@0:
0:Co00/05?l02P00ohL70?[`iP030000003jl>H0n_3V01D0n_3V00<0000001X0o`0J0?l04@0J0?lV
0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`
iPX00?oo2`00G_l:03X0o`/0aP3o2P3o0<4;0?l0H`/0o`0S2P3o00<;0?l01@X0o`0Y2`3o06d;0?l0
c`X0]@3o2`0W0?l:001co`/00?o[2`00odX:04go00/0eol02P3o/`0;0?mI00/0oad02P3o0@0;0?l8
00X0oc002`3oN00;0?oM00X0Y?l02`0Do`0:003oQ`L0n_3V00<000000?[`iP3jl>H05@3jl>H00`00
00006P3o01X0o`0A01X0obH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP03
0000003jl>H0n_3V00D0n_3V2P00ool;001No`X0>P3o2`360?l:0?l0`@/0o`1S2`3o02<:0?l00`/0
o`052P3o02T;0?l0K@/0o`3?2P2e0?l;02L0o`X007?o2`00on/;003oBPX0COl02`3Go`0:0?nc00/0
oeT02`3o7@0:0?l100/0o`P02P3o<00;0?mh00/0omd02P2To`0;01Co00X00?n71`3jl>H00`000000
n_3V0?[`iP0E0?[`iP030000000J0?l06P3o01406P3o9P3`nOl00`000000@FWQ045Yh@06045Yh@d0
n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/005ko2P0j0?l;0<H0o`X0o`31
2`3o06<;0?l08`X0o`032`3o00D:0?l0:@/0o`1]2`3o0<l:0;D0o`/09`3o2P00Lol;003oj`/00?m:
2P1=o`0;0=Oo00X0ok<02`3oF@0;0?lM00X0o`402`3o200:0?l`00/0ogP02`3og@0:0:Co00/05?l0
2P00ohL70?[`iP030000003jl>H0n_3V01D0n_3V00<0000001X0o`0J0?l04@0J0?lV0?3io`030000
0011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00
G_l:03X0o`/0aP3o2P3o0<4;0?l0H`/0o`0S2P3o00<;0?l01@X0o`0Y2`3o06d;0?l0c`X0]@3o2`0W
0?l:001co`/00?o[2`00odX:04go00/0eol02P3o/`0;0?mI00/0oad02P3o0@0;0?l800X0oc002`3o
N00;0?oM00X0Y?l02`0Do`0:003oQ`L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000J`3o06/0
o`0A06/0obH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0
n_3V00D0n_3V2P00ool;001No`X0>P3o2`360?l:0?l0`@/0o`1S2`3o02<:0?l00`/0o`052P3o02T;
0?l0K@/0o`3?2P2e0?l;02L0o`X007?o2`00on/;003oBPX0COl02`3Go`0:0?nc00/0oeT02`3o7@0:
0?l100/0o`P02P3o<00;0?mh00/0omd02P2To`0;01Co00X00?n71`3jl>H00`000000n_3V0?[`iP0E
0?[`iP030000001[0?l0J`3o0140J`3o9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool0
0380n_3V1@0000080?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;001No`X0>P3o2`360?l:0?l0
`@/0o`1S2`3o02<:0?l00`/0o`052P3o02T;0?l0K@/0o`3?2P2e0?l;02L0o`X007?o2`00on/;003o
BPX0COl02`3Go`0:0?nc00/0oeT02`3o7@0:0?l100/0o`P02P3o<00;0?mh00/0omd02P2To`0;01Co
00X00?n71`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000001[0?l0J`3o0140J`3o9P3`nOl00`00
0000@FWQ045Yh@06045Yh@d0n_3V0@3oool00380n_3V0P00000;0?[`iP030000003jl>H0n_3V00D0
n_3V2P00ool;001Fo`X0B`3o2`3L0?l:0?l0ZP/0o`1>2`3o01@:0?l000/0o`0A2P3o04L;0?l0X0/0
j03o2P1H0?l;0017o`X00?3o2`00ofD;03go00X0d?l02`3o/`0:0?mE00/0oaP02`3o000:0?l>00/0
od402P3oU`0;0?Co00/0I_l02P00ocP;003oh@X007Co1`3jl>H00`000000n_3V0?[`iP0E0?[`iP03
0000001[0?l0J`3o0140J`3o9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003<0n_3V
0P00000:0?[`iP<000001@3jl>H:003oo`/005Ko2P1;0?l;0=`0o`X0o`2Z2`3o04h;0?l050X0o`00
2`3o014:0?l0A`/0o`2P2`3X0?l:05P0o`/004Oo2P00l?l;003oI@/0?Ol02P3@o`0;0?nc00X0oeD0
2`3o600;0?l000X0o`h02`3o@@0:0?nG00/0m?l02`1Vo`0:003o>0/00?oQ2P00M?l50?[`iP<00000
5`3jl>H00`000000J`3o06/0o`0A06/0obH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo
000d0?[`iP8000002@3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00E_l:04/0o`/0g03o2P3o
0:X;0?l0CP/0o`0D2P3o000;0?l04@X0o`172`3o0:0;0>P0o`X0F03o2`00Aol:003`o`/00?mU2`0m
o`0:0=3o00/0ok<02P3oE@0;0?lH00/0o`002P3o3P0;0?m100X0oiL02`3do`0;06Ko00X00?lh2`00
on4:001do`L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000J`3o06/0o`0A06/0obH0l?Wo00<0
0000045Yh@11JN401P11JN4=0?[`iP40oooo000e0?[`iP800000203jl>H00`000000n_3V0?[`iP05
0?[`iPX00?oo2`00E_l:04/0o`/0g03o2P3o0:X;0?l0CP/0o`0D2P3o000;0?l04@X0o`172`3o0:0;
0>P0o`X0F03o2`00Aol:003`o`/00?mU2`0mo`0:0=3o00/0ok<02P3oE@0;0?lH00/0o`002P3o3P0;
0?m100X0oiL02`3do`0;06Ko00X00?lh2`00on4:001do`L0n_3V00<000000?[`iP3jl>H05@3jl>H0
0`000000J`3o06/0o`0A06/0obH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000b0?[`
iP80000000<0n_3V000000000000203jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00E_l:04/0
o`/0g03o2P3o0:X;0?l0CP/0o`0D2P3o000;0?l04@X0o`172`3o0:0;0>P0o`X0F03o2`00Aol:003`
o`/00?mU2`0mo`0:0=3o00/0ok<02P3oE@0;0?lH00/0o`002P3o3P0;0?m100X0oiL02`3do`0;06Ko
00X00?lh2`00on4:001do`L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000J`3o06/0o`0A06/0
obH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000b0?[`iP80000000<0n_3V00000000
0000203jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00E_l:04/0o`/0g03o2P3o0:X;0?l0CP/0
o`0D2P3o000;0?l04@X0o`172`3o0:0;0>P0o`X0F03o2`00Aol:003`o`/00?mU2`0mo`0:0=3o00/0
ok<02P3oE@0;0?lH00/0o`002P3o3P0;0?m100X0oiL02`3do`0;06Ko00X00?lh2`00on4:001do`L0
n_3V00<000000?[`iP3jl>H05@3jl>H00`000000J`3o06/0o`0A06/0obH0l?Wo00<00000045Yh@11
JN401P11JN4=0?[`iP40oooo000c0?[`iP<000002@3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo
2`00E_l:04/0o`/0g03o2P3o0:X;0?l0CP/0o`0D2P3o000;0?l04@X0o`172`3o0:0;0>P0o`X0F03o
2`00Aol:003`o`/00?mU2`0mo`0:0=3o00/0ok<02P3oE@0;0?lH00/0o`002P3o3P0;0?m100X0oiL0
2`3do`0;06Ko00X00?lh2`00on4:001do`L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000J`3o
06/0o`0A06/0obH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003j
l>H0n_3V00D0n_3V2P00ool;001Fo`X0B`3o2`3L0?l:0?l0ZP/0o`1>2`3o01@:0?l000/0o`0A2P3o
04L;0?l0X0/0j03o2P1H0?l;0017o`X00?3o2`00ofD;03go00X0d?l02`3o/`0:0?mE00/0oaP02`3o
000:0?l>00/0od402P3oU`0;0?Co00/0I_l02P00ocP;003oh@X007Co1`3jl>H00`000000n_3V0?[`
iP0E0?[`iP030000001[0?l0J`3o0140J`3o9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3o
ool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/005Ko2P1;0?l;0=`0o`X0o`2Z2`3o04h;
0?l050X0o`002`3o014:0?l0A`/0o`2P2`3X0?l:05P0o`/004Oo2P00l?l;003oI@/0?Ol02P3@o`0;
0?nc00X0oeD02`3o600;0?l000X0o`h02`3o@@0:0?nG00/0m?l02`1Vo`0:003o>0/00?oQ2P00M?l7
0?[`iP030000003jl>H0n_3V01D0n_3V00<0000006/0o`1[0?l04@1[0?lV0?3io`0300000011JN40
@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00E_l:04/0
o`/0g03o2P3o0:X;0?l0CP/0o`0D2P3o000;0?l04@X0o`172`3o0:0;0>P0o`X0F03o2`00Aol:003`
o`/00?mU2`0mo`0:0=3o00/0ok<02P3oE@0;0?lH00/0o`002P3o3P0;0?m100X0oiL02`3do`0;06Ko
00X00?lh2`00on4:001do`L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000_03o0;`0o`0A0;`0
obH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0
n_3V2P00ool;001Fo`X0B`3o2`3L0?l:0?l0ZP/0o`1>2`3o01@:0?l000/0o`0A2P3o04L;0?l0X0/0
j03o2P1H0?l;0017o`X00?3o2`00ofD;03go00X0d?l02`3o/`0:0?mE00/0oaP02`3o000:0?l>00/0
od402P3oU`0;0?Co00/0I_l02P00ocP;003oh@X007Co1`3jl>H00`000000n_3V0?[`iP0E0?[`iP03
0000002l0?l0_03o0140_03o9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V
0P0000060?[`iPX00?oo2`00COl:05/0o`/0l@3o2P3o09@;0?l0>`/0o`0:2P3o004;0?l08`X0o`1]
2`3o0=`;09L0o`X000[o2`00^_l:003oT@/07?l02`2jo`0:0?no00/0oeT02P3o600;0?l000/0oa40
2P3oC00;0?n]00X0d?l02`0fo`0;003oM@X00=Ko2`009Ol:07l0o`H0n_3V0P00000G0?[`iP030000
002l0?l0_03o0140_03o9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<0
00000?[`iP3jl>H01@3jl>H:003oo`/004go2P1K0?l;0?40o`X0o`2D2`3o03/;0?l02PX0o`012`3o
02<:0?l0K@/0o`3L2`2G0?l:000:o`/00;[o2P00oi4;01co00/0^_l02P3o_`0;0?mI00X0oaP02`3o
000;0?lA00X0od`02`3o[@0:0=3o00/0=_l02`00ogD:003Fo`/002Go2P1o0?l70?[`iP030000003j
l>H0n_3V01D0n_3V00<000000;`0o`2l0?l04@2l0?lV0?3io`0300000011JN40@FWQ00H0@FWQ3@3j
l>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00COl:05/0o`/0l@3o2P3o09@;
0?l0>`/0o`0:2P3o004;0?l08`X0o`1]2`3o0=`;09L0o`X000[o2`00^_l:003oT@/07?l02`2jo`0:
0?no00/0oeT02P3o600;0?l000/0oa402P3oC00;0?n]00X0d?l02`0fo`0;003oM@X00=Ko2`009Ol:
07l0o`L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000_03o0;`0o`0A0;`0obH0l?Wo00<00000
045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;001=
o`X0F`3o2`3a0?l:0?l0U0/0o`0k2`3o00X:0?l00@/0o`0S2P3o06d;0?l0g0/0U`3o2P002_l;002j
o`X00?nA2`0Lo`0;0;[o00X0okl02`3oF@0:0?lH00/0o`002`3o4@0:0?m<00/0ojd02P3@o`0;03Ko
00/00?me2P00e_l;000Uo`X0O`3o1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000002l0?l0_03o
0140_03o9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3j
l>H01@3jl>H:003oo`/004go2P1K0?l;0?40o`X0o`2D2`3o03/;0?l02PX0o`012`3o02<:0?l0K@/0
o`3L2`2G0?l:000:o`/00;[o2P00oi4;01co00/0^_l02P3o_`0;0?mI00X0oaP02`3o000;0?lA00X0
od`02`3o[@0:0=3o00/0=_l02`00ogD:003Fo`/002Go2P1o0?l70?[`iP030000003jl>H0n_3V01D0
n_3V00<000000;`0o`2l0?l04@2l0?lV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00
?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00COl:05/0o`/0l@3o2P3o09@;0?l0>`/0o`0:
2P3o004;0?l08`X0o`1]2`3o0=`;09L0o`X000[o2`00^_l:003oT@/07?l02`2jo`0:0?no00/0oeT0
2P3o600;0?l000/0oa402P3oC00;0?n]00X0d?l02`0fo`0;003oM@X00=Ko2`009Ol:07l0o`L0n_3V
00<000000?[`iP3jl>H05@3jl>H00`000000_03o0;`0o`0A0;`0obH0l?Wo00<00000045Yh@11JN40
1P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;001=o`X0F`3o2`3a
0?l:0?l0U0/0o`0k2`3o00X:0?l00@/0o`0S2P3o06d;0?l0g0/0U`3o2P002_l;002jo`X00?nA2`0L
o`0;0;[o00X0okl02`3oF@0:0?lH00/0o`002`3o4@0:0?m<00/0ojd02P3@o`0;03Ko00/00?me2P00
e_l;000Uo`X0O`3o1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000002l0?l0_03o0140_03o9P3`
nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:
003oo`/004go2P1K0?l;0?40o`X0o`2D2`3o03/;0?l02PX0o`012`3o02<:0?l0K@/0o`3L2`2G0?l:
000:o`/00;[o2P00oi4;01co00/0^_l02P3o_`0;0?mI00X0oaP02`3o000;0?lA00X0od`02`3o[@0:
0=3o00/0=_l02`00ogD:003Fo`/002Go2P1o0?l70?[`iP030000003jl>H0n_3V01D0n_3V00<00000
0;`0o`2l0?l04@2l0?lV0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`00
0000n_3V0?[`iP050?[`iPX00?oo2`00COl:05/0o`/0l@3o2P3o09@;0?l0>`/0o`0:2P3o004;0?l0
8`X0o`1]2`3o0=`;09L0o`X000[o2`00^_l:003oT@/07?l02`2jo`0:0?no00/0oeT02P3o600;0?l0
00/0oa402P3oC00;0?n]00X0d?l02`0fo`0;003oM@X00=Ko2`009Ol:07l0o`L0n_3V00<000000?[`
iP3jl>H05@3jl>H00`000000_03o0;`0o`0A0;`0obH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`
iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;001=o`X0F`3o2`3a0?l:0?l0U0/0
o`0k2`3o00X:0?l00@/0o`0S2P3o06d;0?l0g0/0U`3o2P002_l;002jo`X00?nA2`0Lo`0;0;[o00X0
okl02`3oF@0:0?lH00/0o`002`3o4@0:0?m<00/0ojd02P3@o`0;03Ko00/00?me2P00e_l;000Uo`X0
O`3o1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003o0?80o`3b0140o`3b9P3`nOl00`000000
@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V0P0000060?[`iPX00?oo2`00A?l:06/0o`/0o`3j
2P3o07l;0?l0:`/0o`032P3o00T;0?l0?0X0o`2K2`3Q0?l;0400o`X007?o2`00om0:003o5P/0U?l0
2`3of00:0?mV00/0oad02P3o000;0?lA00/0oe002P3o^@0;0;_o00X05?l02`00oj8;002Po`X05P3o
2`2l0?l:0?l0^0H0n_3V0P00000G0?[`iP030000003o0?80o`3b0140o`3b9P3`nOl00`000000@FWQ
045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/004Co2P1[
0?l;0?l0nPX0o`1o2`3o02/;0?l00`X0o`092`3o03`:0?l0V`/0h@3o2`100?l:001co`/00?o@2P00
oaH;09Co00/0omP02P3oIP0;0?lM00X0o`002`3o4@0;0?m@00X0okT02`2ko`0:01Co00/00?nR2`00
X?l:01H0o`/0_03o2P3o0;P70?[`iP030000003jl>H0n_3V01D0n_3V00<000000?l0lP3o0?804@3o
0?8V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP05
0?[`iPX00?oo2`00A?l:06/0o`/0o`3j2P3o07l;0?l0:`/0o`032P3o00T;0?l0?0X0o`2K2`3Q0?l;
0400o`X007?o2`00om0:003o5P/0U?l02`3of00:0?mV00/0oad02P3o000;0?lA00/0oe002P3o^@0;
0;_o00X05?l02`00oj8;002Po`X05P3o2`2l0?l:0?l0^0L0n_3V00<000000?[`iP3jl>H05@3jl>H0
0`000000o`3b0?l0lP0A0?l0lRH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`
iP030000003jl>H0n_3V00D0n_3V2P00ool;0014o`X0J`3o2`3o0?X:0?l0O`/0o`0[2`3o00<:0?l0
2@/0o`0l2P3o09/;0>40o`/0@03o2P00Lol;003od0X00?lF2`2Do`0;0?oH00X0ofH02`3o7@0:0?l0
00/0oa402`3oD00:0?ni00/0^ol02P0Do`0;003oXP/00:3o2P0F0?l;0;`0o`X0o`2h1`3jl>H00`00
0000n_3V0?[`iP0E0?[`iP030000003o0?80o`3b0140o`3b9P3`nOl00`000000@FWQ045Yh@06045Y
h@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/004Co2P1[0?l;0?l0nPX0
o`1o2`3o02/;0?l00`X0o`092`3o03`:0?l0V`/0h@3o2`100?l:001co`/00?o@2P00oaH;09Co00/0
omP02P3oIP0;0?lM00X0o`002`3o4@0;0?m@00X0okT02`2ko`0:01Co00/00?nR2`00X?l:01H0o`/0
_03o2P3o0;P70?[`iP030000003jl>H0n_3V01D0n_3V00<000000?l0lP3o0?804@3o0?8V0?3io`03
00000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo
2`00A?l:06/0o`/0o`3j2P3o07l;0?l0:`/0o`032P3o00T;0?l0?0X0o`2K2`3Q0?l;0400o`X007?o
2`00om0:003o5P/0U?l02`3of00:0?mV00/0oad02P3o000;0?lA00/0oe002P3o^@0;0;_o00X05?l0
2`00oj8;002Po`X05P3o2`2l0?l:0?l0^0L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000o`3b
0?l0lP0A0?l0lRH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003j
l>H0n_3V00D0n_3V2P00ool;0014o`X0J`3o2`3o0?X:0?l0O`/0o`0[2`3o00<:0?l02@/0o`0l2P3o
09/;0>40o`/0@03o2P00Lol;003od0X00?lF2`2Do`0;0?oH00X0ofH02`3o7@0:0?l000/0oa402`3o
D00:0?ni00/0^ol02P0Do`0;003oXP/00:3o2P0F0?l;0;`0o`X0o`2h1`3jl>H00`000000n_3V0?[`
iP0E0?[`iP030000003o0?80o`3b0140o`3b9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3o
ool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/004Co2P1[0?l;0?l0nPX0o`1o2`3o02/;
0?l00`X0o`092`3o03`:0?l0V`/0h@3o2`100?l:001co`/00?o@2P00oaH;09Co00/0omP02P3oIP0;
0?lM00X0o`002`3o4@0;0?m@00X0okT02`2ko`0:01Co00/00?nR2`00X?l:01H0o`/0_03o2P3o0;P7
0?[`iP030000003jl>H0n_3V01D0n_3V00<000000?l0lP3o0?804@3o0?8V0?3io`0300000011JN40
@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00A?l:06/0
o`/0o`3j2P3o07l;0?l0:`/0o`032P3o00T;0?l0?0X0o`2K2`3Q0?l;0400o`X007?o2`00om0:003o
5P/0U?l02`3of00:0?mV00/0oad02P3o000;0?lA00/0oe002P3o^@0;0;_o00X05?l02`00oj8;002P
o`X05P3o2`2l0?l:0?l0^0L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000o`3b0?l0lP0A0?l0
lRH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0
n_3V2P00ool;0014o`X0J`3o2`3o0?X:0?l0O`/0o`0[2`3o00<:0?l02@/0o`0l2P3o09/;0>40o`/0
@03o2P00Lol;003od0X00?lF2`2Do`0;0?oH00X0ofH02`3o7@0:0?l000/0oa402`3oD00:0?ni00/0
^ol02P0Do`0;003oXP/00:3o2P0F0?l;0;`0o`X0o`2h1`3jl>H00`000000n_3V0?[`iP0E0?[`iP03
0000003o0?80o`3b0140o`3b9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V
0P0000060?[`iPX00?oo2`00A?l:06/0o`/0o`3j2P3o07l;0?l0:`/0o`032P3o00T;0?l0?0X0o`2K
2`3Q0?l;0400o`X007?o2`00om0:003o5P/0U?l02`3of00:0?mV00/0oad02P3o000;0?lA00/0oe00
2P3o^@0;0;_o00X05?l02`00oj8;002Po`X05P3o2`2l0?l:0?l0^0H0n_3V0P00000G0?[`iP030000
003o0?80o`3b0140o`3b9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<0
00000?[`iP3jl>H01@3jl>H:003oo`/003_o2P1k0?l;0?l0iPX0o`1/2`3o01d;0?l000X0o`0E2`3o
05`:0?l0c`/0U`3o2`006ol:003No`/00?mL2P1Mo`0;0?oo00/0ogh02P3o9`0;0?l100X0o`h02`3o
C00;0?ni00X0/ol02`03o`0:003o_@/007go2`0o0?l:0>L0o`/0o`2A2P3o03<70?[`iP030000003j
l>H0n_3V01D0n_3V00<000000?l0X@3o0:404@3o0:4V0?3io`0300000011JN40@FWQ00H0@FWQ3@3j
l>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00>ol:07/0o`/0o`3V2P3o06`;
0?l07@/0o`002P3o01D;0?l0G0X0o`3?2`2G0?l;000Ko`X00=ko2`00oe`:05go00/0ool02`3oOP0:
0?lW00/0o`402P3o3P0;0?m<00/0okT02P2co`0;00?o00X00?nm2`00OOl;03l0o`X0i`3o2`3o094:
0?l0<`L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000o`2Q0?l0X@0A0?l0XBH0l?Wo00<00000
045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;000k
o`X0N`3o2`3o0>H:0?l0K0/0o`0M2`3o000:0?l05@/0o`1L2P3o0<l;09L0o`/001_o2P00g_l;003o
G0X0GOl02`3oo`0;0?mn00X0obL02`3o0@0:0?l>00/0od`02`3o^@0:0;?o00/00ol02P00okd;001m
o`/0?`3o2P3W0?l;0?l0T@X0o`0c1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003o0:40o`2Q
0140o`2Q9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3j
l>H01@3jl>H:003oo`/003_o2P1k0?l;0?l0iPX0o`1/2`3o01d;0?l000X0o`0E2`3o05`:0?l0c`/0
U`3o2`006ol:003No`/00?mL2P1Mo`0;0?oo00/0ogh02P3o9`0;0?l100X0o`h02`3oC00;0?ni00X0
/ol02`03o`0:003o_@/007go2`0o0?l:0>L0o`/0o`2A2P3o03<70?[`iP030000003jl>H0n_3V01D0
n_3V00<000000?l0X@3o0:404@3o0:4V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00
?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00>ol:07/0o`/0o`3V2P3o06`;0?l07@/0o`00
2P3o01D;0?l0G0X0o`3?2`2G0?l;000Ko`X00=ko2`00oe`:05go00/0ool02`3oOP0:0?lW00/0o`40
2P3o3P0;0?m<00/0okT02P2co`0;00?o00X00?nm2`00OOl;03l0o`X0i`3o2`3o094:0?l0<`L0n_3V
00<000000?[`iP3jl>H05@3jl>H00`000000o`2Q0?l0X@0A0?l0XBH0l?Wo00<00000045Yh@11JN40
1P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;000ko`X0N`3o2`3o
0>H:0?l0K0/0o`0M2`3o000:0?l05@/0o`1L2P3o0<l;09L0o`/001_o2P00g_l;003oG0X0GOl02`3o
o`0;0?mn00X0obL02`3o0@0:0?l>00/0od`02`3o^@0:0;?o00/00ol02P00okd;001mo`/0?`3o2P3W
0?l;0?l0T@X0o`0c1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003o0:40o`2Q0140o`2Q9P3`
nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:
003oo`/003_o2P1k0?l;0?l0iPX0o`1/2`3o01d;0?l000X0o`0E2`3o05`:0?l0c`/0U`3o2`006ol:
003No`/00?mL2P1Mo`0;0?oo00/0ogh02P3o9`0;0?l100X0o`h02`3oC00;0?ni00X0/ol02`03o`0:
003o_@/007go2`0o0?l:0>L0o`/0o`2A2P3o03<70?[`iP030000003jl>H0n_3V01D0n_3V00<00000
0?l0X@3o0:404@3o0:4V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`00
0000n_3V0?[`iP050?[`iPX00?oo2`00>ol:07/0o`/0o`3V2P3o06`;0?l07@/0o`002P3o01D;0?l0
G0X0o`3?2`2G0?l;000Ko`X00=ko2`00oe`:05go00/0ool02`3oOP0:0?lW00/0o`402P3o3P0;0?m<
00/0okT02P2co`0;00?o00X00?nm2`00OOl;03l0o`X0i`3o2`3o094:0?l0<`L0n_3V00<000000?[`
iP3jl>H05@3jl>H00`000000o`2Q0?l0X@0A0?l0XBH0l?Wo00<00000045Yh@11JN401P11JN4=0?[`
iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;000ko`X0N`3o2`3o0>H:0?l0K0/0
o`0M2`3o000:0?l05@/0o`1L2P3o0<l;09L0o`/001_o2P00g_l;003oG0X0GOl02`3oo`0;0?mn00X0
obL02`3o0@0:0?l>00/0od`02`3o^@0:0;?o00/00ol02P00okd;001mo`/0?`3o2P3W0?l;0?l0T@X0
o`0c1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003o0:40o`2Q0140o`2Q9P3`nOl00`000000
@FWQ045Yh@06045Yh@d0n_3V0@3oool003l0n_3V0P0000060?[`iPX00?oo2`00>ol:07/0o`/0o`3V
2P3o06`;0?l07@/0o`002P3o01D;0?l0G0X0o`3?2`2G0?l;000Ko`X00=ko2`00oe`:05go00/0ool0
2`3oOP0:0?lW00/0o`402P3o3P0;0?m<00/0okT02P2co`0;00?o00X00?nm2`00OOl;03l0o`X0i`3o
2`3o094:0?l0<`H0n_3V0P00000G0?[`iP030000003o0:40o`2Q0140o`2Q9P3`nOl00`000000@FWQ
045Yh@06045Yh@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/003?o2P2:
0?l;0?l0d`X0o`1J2`3o018;0?l000X0o`0V2`3o084:0?D0o`/0B03o2`00O?l:003o]@/04ol02P39
o`0;0?nR00/0ocX02P3o1@0;0?l800X0od402`3o[@0;0;_o00X00ol02`00olH:001[o`/0F03o2`3o
0?d:0?l0M`/0o`0Q2P3o00070?[`iP030000003jl>H0n_3V01D0n_3V00<000000?l0X@3o0:404@3o
0:4V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP05
0?[`iPX00?oo2`00<ol:08X0o`/0o`3C2P3o05X;0?l04P/0o`002P3o02H;0?l0P@X0m@3o2`180?l;
001lo`X00?ne2`0Co`0:0<Wo00/0oj802`3o>P0:0?l500/0o`P02P3o@@0;0?n]00/0^ol02P03o`0;
003oaPX006_o2`1H0?l;0?l0o@X0o`1g2`3o024:0?l000L0n_3V00<000000?[`iP3jl>H05@3jl>H0
0`000000o`1@0?l0D00A0?l0D2H0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`
iP030000003jl>H0n_3V00D0n_3V2P00ool;000co`X0RP3o2`3o0=<:0?l0FP/0o`0B2`3o000:0?l0
9P/0o`212P3e0?l;04P0o`/007co2P00okD;01?o00X0bOl02`3oXP0;0?lj00X0o`D02`3o200:0?m1
00/0ojd02`2ko`0:00?o00/00?o62P00Jol;05P0o`/0o`3m2P3o07L;0?l08@X0o`001`3jl>H00`00
0000n_3V0?[`iP0E0?[`iP030000003o0500o`1@0140o`1@9P3`nOl00`000000@FWQ045Yh@06045Y
h@d0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/003?o2P2:0?l;0?l0d`X0
o`1J2`3o018;0?l000X0o`0V2`3o084:0?D0o`/0B03o2`00O?l:003o]@/04ol02P39o`0;0?nR00/0
ocX02P3o1@0;0?l800X0od402`3o[@0;0;_o00X00ol02`00olH:001[o`/0F03o2`3o0?d:0?l0M`/0
o`0Q2P3o00070?[`iP030000003jl>H0n_3V01D0n_3V00<000000?l0D03o05004@3o050V0?3io`03
00000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo
2`00<ol:08X0o`/0o`3C2P3o05X;0?l04P/0o`002P3o02H;0?l0P@X0m@3o2`180?l;001lo`X00?ne
2`0Co`0:0<Wo00/0oj802`3o>P0:0?l500/0o`P02P3o@@0;0?n]00/0^ol02P03o`0;003oaPX006_o
2`1H0?l;0?l0o@X0o`1g2`3o024:0?l000L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000o`1@
0?l0D00A0?l0D2H0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003j
l>H0n_3V00D0n_3V2P00ool;000co`X0RP3o2`3o0=<:0?l0FP/0o`0B2`3o000:0?l09P/0o`212P3e
0?l;04P0o`/007co2P00okD;01?o00X0bOl02`3oXP0;0?lj00X0o`D02`3o200:0?m100/0ojd02`2k
o`0:00?o00/00?o62P00Jol;05P0o`/0o`3m2P3o07L;0?l08@X0o`001`3jl>H00`000000n_3V0?[`
iP0E0?[`iP030000003o0500o`1@0140o`1@9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3o
ool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/003?o2P2:0?l;0?l0d`X0o`1J2`3o018;
0?l000X0o`0V2`3o084:0?D0o`/0B03o2`00O?l:003o]@/04ol02P39o`0;0?nR00/0ocX02P3o1@0;
0?l800X0od402`3o[@0;0;_o00X00ol02`00olH:001[o`/0F03o2`3o0?d:0?l0M`/0o`0Q2P3o0007
0?[`iP030000003jl>H0n_3V01D0n_3V00<000000?l0D03o05004@3o050V0?3io`0300000011JN40
@FWQ00H0@FWQ3@3jl>H10?ooo`00903jl>H5000000<0n_3V0P0000050?[`iP<000002@3jl>H00`00
0000n_3V0?[`iP050?[`iPX00?oo2`00<ol:08X0o`/0o`3C2P3o05X;0?l04P/0o`002P3o02H;0?l0
P@X0m@3o2`180?l;001lo`X00?ne2`0Co`0:0<Wo00/0oj802`3o>P0:0?l500/0o`P02P3o@@0;0?n]
00/0^ol02P03o`0;003oaPX006_o2`1H0?l;0?l0o@X0o`1g2`3o024:0?l000L0n_3V00<000000?[`
iP3jl>H05@3jl>H00`000000o`1@0?l0D00A0?l0D2H0l?Wo00<00000045Yh@11JN401P11JN4=0?[`
iP40oooo000T0?[`iP8000001P3jl>H2000000@0n_3V00<000000?[`iP3jl>H00P0000080?[`iP03
0000003jl>H0n_3V00D0n_3V2P00ool;000co`X0RP3o2`3o0=<:0?l0FP/0o`0B2`3o000:0?l09P/0
o`212P3e0?l;04P0o`/007co2P00okD;01?o00X0bOl02`3oXP0;0?lj00X0o`D02`3o200:0?m100/0
ojd02`2ko`0:00?o00/00?o62P00Jol;05P0o`/0o`3m2P3o07L;0?l08@X0o`001`3jl>H00`000000
n_3V0?[`iP0E0?[`iP030000003o0500o`1@0140o`1@9P3`nOl00`000000@FWQ045Yh@06045Yh@d0
n_3V0@3oool002D0n_3V0P00000>0?[`iP800000203jl>H3000000D0n_3V2P00ool;000co`X0RP3o
2`3o0=<:0?l0FP/0o`0B2`3o000:0?l09P/0o`212P3e0?l;04P0o`/007co2P00okD;01?o00X0bOl0
2`3oXP0;0?lj00X0o`D02`3o200:0?m100/0ojd02`2ko`0:00?o00/00?o62P00Jol;05P0o`/0o`3m
2P3o07L;0?l08@X0o`001@3jl>H3000001L0n_3V00<000000?l0D03o05004@3o050V0?3io`030000
0011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`009P3jl>H2000000d0n_3V0P0000080?[`iP030000003j
l>H0n_3V00D0n_3V2P00ool;000co`X0RP3o2`3o0=<:0?l0FP/0o`0B2`3o000:0?l09P/0o`212P3e
0?l;04P0o`/007co2P00okD;01?o00X0bOl02`3oXP0;0?lj00X0o`D02`3o200:0?m100/0ojd02`2k
o`0:00?o00/00?o62P00Jol;05P0o`/0o`3m2P3o07L;0?l08@X0o`001`3jl>H00`000000n_3V0?[`
iP0E0?[`iP030000003o0500o`1@0140o`1@9P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3o
ool002L0n_3V0P0000090?[`iP030000003jl>H0n_3V00800000203jl>H00`000000n_3V0?[`iP05
0?[`iPX00?oo2`00:_l:09X0o`/0o`312P3o04X;0?l02P/0o`052P3o03`;0?l0Z`X0]@3o2`002_l;
003No`X00?m:2`1mo`0:0?oH00/0oeT02`3o400:0?l200/0oc002P3oU`0;0=3o00/05?l02P00okd;
001[o`X0H03o2`3o0>l;0?l0J@X0o`0G2`3o000:0?l09@L0n_3V00<000000?[`iP3jl>H05@3jl>H0
0`000000o`1@0?l0D00A0?l0D2H0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000T0?[`
iP80000000<0n_3V0000000000002@3jl>H4000000T0n_3V00<000000?[`iP3jl>H01@3jl>H:003o
o`/002[o2P2J0?l;0?l0`@X0o`1:2`3o00X;0?l01@X0o`0l2`3o0:/:0;D0o`/000[o2`00g_l:003o
BP/0OOl02P3of00;0?mI00/0oa002P3o0P0;0?l`00X0oiL02`3@o`0;01Co00X00?nm2`00Jol:0600
o`/0o`3_2`3o06T:0?l05`/0o`002P3o02D70?[`iP030000003jl>H0n_3V01D0n_3V00<000000?l0
D03o05004@3o050V0?3io`0300000011JN40@FWQ00H0@FWQ3@3jl>H10?ooo`00903jl>H200000003
0?[`iP000000000000T0n_3V0P00000;0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;000Zo`X0
VP3o2`3o0<4:0?l0BP/0o`0:2`3o00D:0?l0?0/0o`2[2P2e0?l;000:o`/00=ko2P00odX;07go00X0
omP02`3oF@0;0?l@00X0o`802`3o<00:0?nG00/0d?l02`0Do`0:003o_@/006_o2P1P0?l;0?l0k`/0
o`1Y2P3o01L;0?l000X0o`0U1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003o0000o`000140
o`009P3`nOl00`000000@FWQ045Yh@06045Yh@d0n_3V0@3oool002D0n_3V0`00000:0?[`iPD00000
203jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00:_l:09X0o`/0o`312P3o04X;0?l02P/0o`05
2P3o03`;0?l0Z`X0]@3o2`002_l;003No`X00?m:2`1mo`0:0?oH00/0oeT02`3o400:0?l200/0oc00
2P3oU`0;0=3o00/05?l02P00okd;001[o`X0H03o2`3o0>l;0?l0J@X0o`0G2`3o000:0?l09@L0n_3V
00<000000?[`iP3jl>H05@3jl>H00`000000o`000?l0000A0?l002H0l?Wo00<00000045Yh@11JN40
1P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;000Zo`X0VP3o2`3o
0<4:0?l0BP/0o`0:2`3o00D:0?l0?0/0o`2[2P2e0?l;000:o`/00=ko2P00odX;07go00X0omP02`3o
F@0;0?l@00X0o`802`3o<00:0?nG00/0d?l02`0Do`0:003o_@/006_o2P1P0?l;0?l0k`/0o`1Y2P3o
01L;0?l000X0o`0U1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003o0000o`000140o`00103`
nOl6000001`0l?Wo00<00000045Yh@11JN401P11JN4=0?[`iP40oooo000o0?[`iP030000003jl>H0
n_3V00D0n_3V2P00ool;000Zo`X0VP3o2`3o0<4:0?l0BP/0o`0:2`3o00D:0?l0?0/0o`2[2P2e0?l;
000:o`/00=ko2P00odX;07go00X0omP02`3oF@0;0?l@00X0o`802`3o<00:0?nG00/0d?l02`0Do`0:
003o_@/006_o2P1P0?l;0?l0k`/0o`1Y2P3o01L;0?l000X0o`0U1`3jl>H00`000000n_3V0?[`iP0E
0?[`iP030000003o0000o`000140o`001P3`nOl2000001h0l?Wo00<000000?[`iP3jl>H04`3jl>H1
0?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`00:_l:09X0o`/0o`312P3o04X;0?l0
2P/0o`052P3o03`;0?l0Z`X0]@3o2`002_l;003No`X00?m:2`1mo`0:0?oH00/0oeT02`3o400:0?l2
00/0oc002P3oU`0;0=3o00/05?l02P00okd;001[o`X0H03o2`3o0>l;0?l0J@X0o`0G2`3o000:0?l0
9@L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000o`000?l0000A0?l000H0l?Wo0P00000N0?3i
o`030000003jl>H0n_3V01<0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/0
02[o2P2J0?l;0?l0`@X0o`1:2`3o00X;0?l01@X0o`0l2`3o0:/:0;D0o`/000[o2`00g_l:003oBP/0
OOl02P3of00;0?mI00/0oa002P3o0P0;0?l`00X0oiL02`3@o`0;01Co00X00?nm2`00Jol:0600o`/0
o`3_2`3o06T:0?l05`/0o`002P3o02D70?[`iP030000003jl>H0n_3V01D0n_3V00<000000?l0003o
00004@3o00060?3io`8000007P3`nOl00`000000n_3V0?[`iP0C0?[`iP40oooo000o0?[`iP030000
003jl>H0n_3V00D0n_3V2P00ool;000Zo`X0VP3o2`3o0<4:0?l0BP/0o`0:2`3o00D:0?l0?0/0o`2[
2P2e0?l;000:o`/00=ko2P00odX;07go00X0omP02`3oF@0;0?l@00X0o`802`3o<00:0?nG00/0d?l0
2`0Do`0:003o_@/006_o2P1P0?l;0?l0k`/0o`1Y2P3o01L;0?l000X0o`0U1`3jl>H00`000000n_3V
0?[`iP0E0?[`iP030000003o0000o`000140o`001P3`nOl2000001h0l?Wo00<000000?[`iP3jl>H0
4`3jl>H10?ooo`00?`3jl>H2000000H0n_3V2P00ool;000Zo`X0VP3o2`3o0<4:0?l0BP/0o`0:2`3o
00D:0?l0?0/0o`2[2P2e0?l;000:o`/00=ko2P00odX;07go00X0omP02`3oF@0;0?l@00X0o`802`3o
<00:0?nG00/0d?l02`0Do`0:003o_@/006_o2P1P0?l;0?l0k`/0o`1Y2P3o01L;0?l000X0o`0U1P3j
l>H2000001L0n_3V00<000000?l0003o00004@3o00060?3io`8000007P3`nOl00`000000n_3V0?[`
iP0C0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;000Zo`X0VP3o2`3o0<4:
0?l0BP/0o`0:2`3o00D:0?l0?0/0o`2[2P2e0?l;000:o`/00=ko2P00odX;07go00X0omP02`3oF@0;
0?l@00X0o`802`3o<00:0?nG00/0d?l02`0Do`0:003o_@/006_o2P1P0?l;0?l0k`/0o`1Y2P3o01L;
0?l000X0o`0U1`3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003o0000o`000140o`00103`nOl4
000001h0l?Wo00<000000?[`iP3jl>H04`3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`
iPX00?oo2`008Ol:0:T0o`/0o`2_2P3o03/;0?l010/0o`0=2P3o05L;0?l0g0X0L03o2`00HOl;003o
_PX07?l02`3No`0:0?n800/0ob@02`3o000:0?lL00/0ogP02P3do`0;03Ko00/00?nR2P00OOl;05P0
o`X0o`3_2`3o06D;0?l04`X0o`012`3o034:0?l0WPL0n_3V00<000000?[`iP3jl>H05@3jl>H00`00
0000o`000?l0000A0?l000H0l?Wo0P00000N0?3io`030000003jl>H0n_3V01<0n_3V0@3oool003l0
n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/0027o2P2Y0?l;0?l0[`X0o`0k2`3o00@;0?l03@X0
o`1G2`3o0=`:0700o`/0067o2`00okh:01co00/0g_l02P3oR00;0?lT00/0o`002P3o700;0?mh00X0
m?l02`0fo`0;003oXPX007go2`1H0?l:0?l0k`/0o`1U2`3o01<:0?l00@/0o`0a2P3o09h70?[`iP03
0000003jl>H0n_3V01D0n_3V00<000000?l0003o00004@3o000V0?3io`030000003jl>H0n_3V01<0
n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/0027o2P2Y0?l;0?l0[`X0o`0k
2`3o00@;0?l03@X0o`1G2`3o0=`:0700o`/0067o2`00okh:01co00/0g_l02P3oR00;0?lT00/0o`00
2P3o700;0?mh00X0m?l02`0fo`0;003oXPX007go2`1H0?l:0?l0k`/0o`1U2`3o01<:0?l00@/0o`0a
2P3o09h70?[`iP030000003jl>H0n_3V01D0n_3V>`00000E0?[`iP40oooo000o0?[`iP030000003j
l>H0n_3V00D0n_3V2P00ool;000Qo`X0Z@3o2`3o0:l:0?l0>`/0o`042`3o00d:0?l0E`/0o`3L2P1`
0?l;001Qo`/00?nn2P0Lo`0;0=ko00X0ohP02`3o900;0?l000X0oa`02`3oN00:0?Co00/0=_l02`00
oj8:001mo`/0F03o2P3o0>l;0?l0I@/0o`0C2P3o004;0?l0<@X0o`2N1`3jl>H00`000000n_3V0?[`
iP1U0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;000Qo`X0Z@3o2`3o0:l:
0?l0>`/0o`042`3o00d:0?l0E`/0o`3L2P1`0?l;001Qo`/00?nn2P0Lo`0;0=ko00X0ohP02`3o900;
0?l000X0oa`02`3oN00:0?Co00/0=_l02`00oj8:001mo`/0F03o2P3o0>l;0?l0I@/0o`0C2P3o004;
0?l0<@X0o`2N1`3jl>H00`000000n_3V0?[`iP1U0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V
00D0n_3V2P00ool;000Qo`X0Z@3o2`3o0:l:0?l0>`/0o`042`3o00d:0?l0E`/0o`3L2P1`0?l;001Q
o`/00?nn2P0Lo`0;0=ko00X0ohP02`3o900;0?l000X0oa`02`3oN00:0?Co00/0=_l02`00oj8:001m
o`/0F03o2P3o0>l;0?l0I@/0o`0C2P3o004;0?l0<@X0o`2N1`3jl>H00`000000n_3V0?[`iP1U0?[`
iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;000Qo`X0Z@3o2`3o0:l:0?l0>`/0
o`042`3o00d:0?l0E`/0o`3L2P1`0?l;001Qo`/00?nn2P0Lo`0;0=ko00X0ohP02`3o900;0?l000X0
oa`02`3oN00:0?Co00/0=_l02`00oj8:001mo`/0F03o2P3o0>l;0?l0I@/0o`0C2P3o004;0?l0<@X0
o`2N1`3jl>H00`000000n_3V0?[`iP1U0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V
2P00ool;000Qo`X0Z@3o2`3o0:l:0?l0>`/0o`042`3o00d:0?l0E`/0o`3L2P1`0?l;001Qo`/00?nn
2P0Lo`0;0=ko00X0ohP02`3o900;0?l000X0oa`02`3oN00:0?Co00/0=_l02`00oj8:001mo`/0F03o
2P3o0>l;0?l0I@/0o`0C2P3o004;0?l0<@X0o`2N1`3jl>H00`000000n_3V0?[`iP1U0?[`iP40oooo
000o0?[`iP8000001P3jl>H:003oo`/0027o2P2Y0?l;0?l0[`X0o`0k2`3o00@;0?l03@X0o`1G2`3o
0=`:0700o`/0067o2`00okh:01co00/0g_l02P3oR00;0?lT00/0o`002P3o700;0?mh00X0m?l02`0f
o`0;003oXPX007go2`1H0?l:0?l0k`/0o`1U2`3o01<:0?l00@/0o`0a2P3o09h60?[`iP800000I`3j
l>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`008Ol:0:T0o`/0o`2_2P3o03/;
0?l010/0o`0=2P3o05L;0?l0g0X0L03o2`00HOl;003o_PX07?l02`3No`0:0?n800/0ob@02`3o000:
0?lL00/0ogP02P3do`0;03Ko00/00?nR2P00OOl;05P0o`X0o`3_2`3o06D;0?l04`X0o`012`3o034:
0?l0WPL0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`
iPX00?oo2`006Ol:0;P0o`/0o`2O2P3o02h;0?l000/0o`0I2P3o07L;0>l0o`X09`3o2`00^_l;003o
G0X0OOl02`3ob`0:0?m900/0o`H02`3o2P0:0?mD00/0omd02P1Vo`0;003oM@/00:3o2P0o0?l;0?l0
o@X0o`1Y2`3o01<;0?l00PX0o`0h2`3o0:l:0:80o`L0n_3V00<000000?[`iP3jl>H0I@3jl>H10?oo
o`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`006Ol:0;P0o`/0o`2O2P3o02h;0?l000/0
o`0I2P3o07L;0>l0o`X09`3o2`00^_l;003oG0X0OOl02`3ob`0:0?m900/0o`H02`3o2P0:0?mD00/0
omd02P1Vo`0;003oM@/00:3o2P0o0?l;0?l0o@X0o`1Y2`3o01<;0?l00PX0o`0h2`3o0:l:0:80o`L0
n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo
2`006Ol:0;P0o`/0o`2O2P3o02h;0?l000/0o`0I2P3o07L;0>l0o`X09`3o2`00^_l;003oG0X0OOl0
2`3ob`0:0?m900/0o`H02`3o2P0:0?mD00/0omd02P1Vo`0;003oM@/00:3o2P0o0?l;0?l0o@X0o`1Y
2`3o01<;0?l00PX0o`0h2`3o0:l:0:80o`L0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3j
l>H00`000000n_3V0?[`iP050?[`iPX00?oo2`006Ol:0;P0o`/0o`2O2P3o02h;0?l000/0o`0I2P3o
07L;0>l0o`X09`3o2`00^_l;003oG0X0OOl02`3ob`0:0?m900/0o`H02`3o2P0:0?mD00/0omd02P1V
o`0;003oM@/00:3o2P0o0?l;0?l0o@X0o`1Y2`3o01<;0?l00PX0o`0h2`3o0:l:0:80o`L0n_3V00<0
00000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`006Ol:
0;P0o`/0o`2O2P3o02h;0?l000/0o`0I2P3o07L;0>l0o`X09`3o2`00^_l;003oG0X0OOl02`3ob`0:
0?m900/0o`H02`3o2P0:0?mD00/0omd02P1Vo`0;003oM@/00:3o2P0o0?l;0?l0o@X0o`1Y2`3o01<;
0?l00PX0o`0h2`3o0:l:0:80o`L0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`00
0000n_3V0?[`iP050?[`iPX00?oo2`006Ol:0;P0o`/0o`2O2P3o02h;0?l000/0o`0I2P3o07L;0>l0
o`X09`3o2`00^_l;003oG0X0OOl02`3ob`0:0?m900/0o`H02`3o2P0:0?mD00/0omd02P1Vo`0;003o
M@/00:3o2P0o0?l;0?l0o@X0o`1Y2`3o01<;0?l00PX0o`0h2`3o0:l:0:80o`L0n_3V00<000000?[`
iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`006Ol:0;P0o`/0
o`2O2P3o02h;0?l000/0o`0I2P3o07L;0>l0o`X09`3o2`00^_l;003oG0X0OOl02`3ob`0:0?m900/0
o`H02`3o2P0:0?mD00/0omd02P1Vo`0;003oM@/00:3o2P0o0?l;0?l0o@X0o`1Y2`3o01<;0?l00PX0
o`0h2`3o0:l:0:80o`L0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000n_3V
0?[`iP050?[`iPX00?oo2`006Ol:0;P0o`/0o`2O2P3o02h;0?l000/0o`0I2P3o07L;0>l0o`X09`3o
2`00^_l;003oG0X0OOl02`3ob`0:0?m900/0o`H02`3o2P0:0?mD00/0omd02P1Vo`0;003oM@/00:3o
2P0o0?l;0?l0o@X0o`1Y2`3o01<;0?l00PX0o`0h2`3o0:l:0:80o`L0n_3V00<000000?[`iP3jl>H0
I@3jl>H10?ooo`00?`3jl>H2000000H0n_3V2P00ool;000Io`X0^03o2`3o09l:0?l0;P/0o`002`3o
01T:0?l0M`/0k`3o2P0W0?l;002jo`/00?mL2P1mo`0;0?o;00X0odT02`3o1P0;0?l:00X0oe@02`3o
g@0:06Ko00/00?me2`00X?l:03l0o`/0o`3m2P3o06T;0?l04`/0o`022P3o03P;0?l0[`X0XP3o1P3j
l>H2000006L0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/001Wo2P2h0?l;
0?l0W`X0o`0^2`3o000;0?l06@X0o`1g2`3_0?l:02L0o`/00;[o2`00oe`:07go00/0ol/02P3oB@0;
0?l600/0o`X02P3oE00;0?oM00X0I_l02`00ogD;002Po`X0?`3o2`3o0?d:0?l0J@/0o`0C2`3o008:
0?l0>0/0o`2_2P2R0?l70?[`iP030000003jl>H0n_3V06D0n_3V0@3oool003l0n_3V00<000000?[`
iP3jl>H01@3jl>H:003oo`/001Wo2P2h0?l;0?l0W`X0o`0^2`3o000;0?l06@X0o`1g2`3_0?l:02L0
o`/00;[o2`00oe`:07go00/0ol/02P3oB@0;0?l600/0o`X02P3oE00;0?oM00X0I_l02`00ogD;002P
o`X0?`3o2`3o0?d:0?l0J@/0o`0C2`3o008:0?l0>0/0o`2_2P2R0?l70?[`iP030000003jl>H0n_3V
06D0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/0013o2P360?l;0?l0S`X0
o`0S2`3o000;0?l0:@X0o`2K2`2e0?l:000To`/00?o[2`02o`0:0=Oo00/0oh<02P3o7@0;0?l000/0
oc002P3oY`0;0:Co00X00?lh2`00e_l;01H0o`X0i`3o2`3o07L:0?l05`/0o`012`3o03P:0?l0]@/0
T`3o2P00C?l70?[`iP030000003jl>H0n_3V06D0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H0
1@3jl>H:003oo`/0013o2P360?l;0?l0S`X0o`0S2`3o000;0?l0:@X0o`2K2`2e0?l:000To`/00?o[
2`02o`0:0=Oo00/0oh<02P3o7@0;0?l000/0oc002P3oY`0;0:Co00X00?lh2`00e_l;01H0o`X0i`3o
2`3o07L:0?l05`/0o`012`3o03P:0?l0]@/0T`3o2P00C?l70?[`iP030000003jl>H0n_3V06D0n_3V
0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/0013o2P360?l;0?l0S`X0o`0S2`3o
000;0?l0:@X0o`2K2`2e0?l:000To`/00?o[2`02o`0:0=Oo00/0oh<02P3o7@0;0?l000/0oc002P3o
Y`0;0:Co00X00?lh2`00e_l;01H0o`X0i`3o2`3o07L:0?l05`/0o`012`3o03P:0?l0]@/0T`3o2P00
C?l70?[`iP030000003jl>H0n_3V06D0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:
003oo`/0013o2P360?l;0?l0S`X0o`0S2`3o000;0?l0:@X0o`2K2`2e0?l:000To`/00?o[2`02o`0:
0=Oo00/0oh<02P3o7@0;0?l000/0oc002P3oY`0;0:Co00X00?lh2`00e_l;01H0o`X0i`3o2`3o07L:
0?l05`/0o`012`3o03P:0?l0]@/0T`3o2P00C?l70?[`iP030000003jl>H0n_3V06D0n_3V0@3oool0
03l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/0013o2P360?l;0?l0S`X0o`0S2`3o000;0?l0
:@X0o`2K2`2e0?l:000To`/00?o[2`02o`0:0=Oo00/0oh<02P3o7@0;0?l000/0oc002P3oY`0;0:Co
00X00?lh2`00e_l;01H0o`X0i`3o2`3o07L:0?l05`/0o`012`3o03P:0?l0]@/0T`3o2P00C?l70?[`
iP030000003jl>H0n_3V06D0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H:003oo`/0
013o2P360?l;0?l0S`X0o`0S2`3o000;0?l0:@X0o`2K2`2e0?l:000To`/00?o[2`02o`0:0=Oo00/0
oh<02P3o7@0;0?l000/0oc002P3oY`0;0:Co00X00?lh2`00e_l;01H0o`X0i`3o2`3o07L:0?l05`/0
o`012`3o03P:0?l0]@/0T`3o2P00C?l70?[`iP030000003jl>H0n_3V06D0n_3V0@3oool003l0n_3V
00<000000?[`iP3jl>H01@3jl>H:003oo`/0013o2P360?l;0?l0S`X0o`0S2`3o000;0?l0:@X0o`2K
2`2e0?l:000To`/00?o[2`02o`0:0=Oo00/0oh<02P3o7@0;0?l000/0oc002P3oY`0;0:Co00X00?lh
2`00e_l;01H0o`X0i`3o2`3o07L:0?l05`/0o`012`3o03P:0?l0]@/0T`3o2P00C?l70?[`iP030000
003jl>H0n_3V06D0n_3V0@3oool003l0n_3V0P0000060?[`iPX00?oo2`004?l:0<H0o`/0o`2?2P3o
02<;0?l000/0o`0Y2P3o09/;0;D0o`X002Co2`00on/;00;o00X0eol02`3oP`0:0?lM00/0o`002`3o
<00:0?nW00/0Y?l02P00ocP;003Fo`/05P3o2P3W0?l;0?l0M`X0o`0G2`3o004;0?l0>0X0o`2e2`2C
0?l:001<o`H0n_3V0P00001W0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;
000@o`X0aP3o2`3o08l:0?l08`/0o`002`3o02T:0?l0V`/0]@3o2P009?l;003oj`/00_l02P3Go`0;
0?n300X0oad02`3o000;0?l`00X0ojL02`2To`0:003o>0/00=Ko2`0F0?l:0>L0o`/0o`1g2P3o01L;
0?l00@/0o`0h2P3o0;D;09<0o`X004co1`3jl>H00`000000n_3V0?[`iP1U0?[`iP40oooo000o0?[`
iP030000003jl>H0n_3V00D0n_3V2P00ool;000@o`X0aP3o2`3o08l:0?l08`/0o`002`3o02T:0?l0
V`/0]@3o2P009?l;003oj`/00_l02P3Go`0;0?n300X0oad02`3o000;0?l`00X0ojL02`2To`0:003o
>0/00=Ko2`0F0?l:0>L0o`/0o`1g2P3o01L;0?l00@/0o`0h2P3o0;D;09<0o`X004co1`3jl>H00`00
0000n_3V0?[`iP1U0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;0008o`X0
e@3o2`3o07l:0?l06@/0o`012`3o03`:0?l0``/0N03o2P00Lol;003oT@/0GOl02P3of00;0?m900X0
o`@02`3o4@0;0?m_00X0kOl02`0Do`0:003oh@/002Go2`2l0?l:0?l0T@/0o`0Q2P3o000;0?l0<@/0
o`2_2P2C0?l;001Eo`X00?n_1`3jl>H00`000000n_3V0?[`iP1U0?[`iP40oooo000o0?[`iP030000
003jl>H0n_3V00D0n_3V2P00ool;0008o`X0e@3o2`3o07l:0?l06@/0o`012`3o03`:0?l0``/0N03o
2P00Lol;003oT@/0GOl02P3of00;0?m900X0o`@02`3o4@0;0?m_00X0kOl02`0Do`0:003oh@/002Go
2`2l0?l:0?l0T@/0o`0Q2P3o000;0?l0<@/0o`2_2P2C0?l;001Eo`X00?n_1`3jl>H00`000000n_3V
0?[`iP1U0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;0008o`X0e@3o2`3o
07l:0?l06@/0o`012`3o03`:0?l0``/0N03o2P00Lol;003oT@/0GOl02P3of00;0?m900X0o`@02`3o
4@0;0?m_00X0kOl02`0Do`0:003oh@/002Go2`2l0?l:0?l0T@/0o`0Q2P3o000;0?l0<@/0o`2_2P2C
0?l;001Eo`X00?n_1`3jl>H00`000000n_3V0?[`iP1U0?[`iP40oooo000o0?[`iP030000003jl>H0
n_3V00D0n_3V2P00ool;0008o`X0e@3o2`3o07l:0?l06@/0o`012`3o03`:0?l0``/0N03o2P00Lol;
003oT@/0GOl02P3of00;0?m900X0o`@02`3o4@0;0?m_00X0kOl02`0Do`0:003oh@/002Go2`2l0?l:
0?l0T@/0o`0Q2P3o000;0?l0<@/0o`2_2P2C0?l;001Eo`X00?n_1`3jl>H00`000000n_3V0?[`iP1U
0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;0008o`X0e@3o2`3o07l:0?l0
6@/0o`012`3o03`:0?l0``/0N03o2P00Lol;003oT@/0GOl02P3of00;0?m900X0o`@02`3o4@0;0?m_
00X0kOl02`0Do`0:003oh@/002Go2`2l0?l:0?l0T@/0o`0Q2P3o000;0?l0<@/0o`2_2P2C0?l;001E
o`X00?n_1`3jl>H00`000000n_3V0?[`iP1U0?[`iP40oooo000c0?[`iP<000002@3jl>H00`000000
n_3V0?[`iP050?[`iPX00?oo2`002?l:0=D0o`/0o`1o2P3o01T;0?l00@/0o`0l2P3o0<<;07P0o`X0
07?o2`00oi4;05go00X0omP02`3oB@0:0?l400/0oa402`3oK`0:0>go00/05?l02P00on4;000Uo`/0
_03o2P3o094;0?l08@X0o`002`3o034;0?l0[`X0T`3o2`00EOl:003o[`L0n_3V00<000000?[`iP3j
l>H0I@3jl>H10?ooo`00<P3jl>H00`000000n_3V0?[`iP02000000P0n_3V00<000000?[`iP3jl>H0
1@3jl>H:003oo`/000So2P3E0?l;0?l0O`X0o`0I2`3o004;0?l0?0X0o`332`1h0?l:001co`/00?nA
2`1Mo`0:0?oH00/0odT02P3o100;0?lA00/0ofl02P3]o`0;01Co00X00?oQ2`009Ol;0;`0o`X0o`2A
2`3o024:0?l000/0o`0a2`3o0:l:09<0o`/005Go2P00ojl70?[`iP030000003jl>H0n_3V06D0n_3V
0@3oool003D0n_3V0P0000080?[`iP<000001@3jl>H:003oo`/000So2P3E0?l;0?l0O`X0o`0I2`3o
004;0?l0?0X0o`332`1h0?l:001co`/00?nA2`1Mo`0:0?oH00/0odT02P3o100;0?lA00/0ofl02P3]
o`0;01Co00X00?oQ2`009Ol;0;`0o`X0o`2A2`3o024:0?l000/0o`0a2`3o0:l:09<0o`/005Go2P00
ojl50?[`iP<00000I`3jl>H10?ooo`00=@3jl>H2000000P0n_3V00<000000?[`iP3jl>H01@3jl>H:
003oo`/000So2P3E0?l;0?l0O`X0o`0I2`3o004;0?l0?0X0o`332`1h0?l:001co`/00?nA2`1Mo`0:
0?oH00/0odT02P3o100;0?lA00/0ofl02P3]o`0;01Co00X00?oQ2`009Ol;0;`0o`X0o`2A2`3o024:
0?l000/0o`0a2`3o0:l:09<0o`/005Go2P00ojl70?[`iP030000003jl>H0n_3V06D0n_3V0@3oool0
03<0n_3V0`0000090?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;0008o`X0e@3o2`3o07l:0?l0
6@/0o`012`3o03`:0?l0``/0N03o2P00Lol;003oT@/0GOl02P3of00;0?m900X0o`@02`3o4@0;0?m_
00X0kOl02`0Do`0:003oh@/002Go2`2l0?l:0?l0T@/0o`0Q2P3o000;0?l0<@/0o`2_2P2C0?l;001E
o`X00?n_1`3jl>H00`000000n_3V0?[`iP1U0?[`iP40oooo000e0?[`iP800000203jl>H00`000000
n_3V0?[`iP050?[`iPX00?oo2`002?l:0=D0o`/0o`1o2P3o01T;0?l00@/0o`0l2P3o0<<;07P0o`X0
07?o2`00oi4;05go00X0omP02`3oB@0:0?l400/0oa402`3oK`0:0>go00/05?l02P00on4;000Uo`/0
_03o2P3o094;0?l08@X0o`002`3o034;0?l0[`X0T`3o2`00EOl:003o[`L0n_3V00<000000?[`iP3j
l>H0I@3jl>H10?ooo`00<P3jl>H00`000000n_3V0?[`iP02000000P0n_3V00<000000?[`iP3jl>H0
1@3jl>H:003oo`/0003o2P3S0?l;0?l0L@X0o`0@2`3o00H;0?l0D`X0o`3_2`0h0?l:0033o`/00?li
2`2co`0:0?nB00/0oal02P3o000;0?lj00/0olD02P1^o`0;003oQ`X007Co2`1o0?l;0?l0^0X0o`0c
2`3o000:0?l09@/0o`2N2`2R0?l:001<o`/00?n_2P1:o`070?[`iP030000003jl>H0n_3V06D0n_3V
0@3oool003<0n_3V0`0000090?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;0000o`X0h`3o2`3o
074:0?l040/0o`062`3o05<:0?l0k`/0>03o2P00`ol;003o>@/0/ol02P3oTP0;0?lO00X0o`002`3o
>P0;0?o500X0K_l02`00ohL:001do`/0O`3o2`3o0;P:0?l0<`/0o`002P3o02D;0?l0WP/0XP3o2P00
C?l;003o[`X0B_l01`3jl>H00`000000n_3V0?[`iP1U0?[`iP40oooo000o0?[`iP030000003jl>H0
n_3V00D0n_3V2P00ool;0000o`X0h`3o2`3o074:0?l040/0o`062`3o05<:0?l0k`/0>03o2P00`ol;
003o>@/0/ol02P3oTP0;0?lO00X0o`002`3o>P0;0?o500X0K_l02`00ohL:001do`/0O`3o2`3o0;P:
0?l0<`/0o`002P3o02D;0?l0WP/0XP3o2P00C?l;003o[`X0B_l01`3jl>H00`000000n_3V0?[`iP1U
0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;0000o`X0h`3o2`3o074:0?l0
40/0o`062`3o05<:0?l0k`/0>03o2P00`ol;003o>@/0/ol02P3oTP0;0?lO00X0o`002`3o>P0;0?o5
00X0K_l02`00ohL:001do`/0O`3o2`3o0;P:0?l0<`/0o`002P3o02D;0?l0WP/0XP3o2P00C?l;003o
[`X0B_l01`3jl>H00`000000n_3V0?[`iP1U0?[`iP40oooo000o0?[`iP030000003jl>H0n_3V00D0
n_3V2P00ool;0000o`X0h`3o2`3o074:0?l040/0o`062`3o05<:0?l0k`/0>03o2P00`ol;003o>@/0
/ol02P3oTP0;0?lO00X0o`002`3o>P0;0?o500X0K_l02`00ohL:001do`/0O`3o2`3o0;P:0?l0<`/0
o`002P3o02D;0?l0WP/0XP3o2P00C?l;003o[`X0B_l01`3jl>H00`000000n_3V0?[`iP1U0?[`iP40
oooo000o0?[`iP030000003jl>H0n_3V00D0n_3V2P00ool;0000o`X0h`3o2`3o074:0?l040/0o`06
2`3o05<:0?l0k`/0>03o2P00`ol;003o>@/0/ol02P3oTP0;0?lO00X0o`002`3o>P0;0?o500X0K_l0
2`00ohL:001do`/0O`3o2`3o0;P:0?l0<`/0o`002P3o02D;0?l0WP/0XP3o2P00C?l;003o[`X0B_l0
1`3jl>H00`000000n_3V0?[`iP1U0?[`iP40oooo000o0?[`iP8000001P3jl>H:003oo`/0003o2P3S
0?l;0?l0L@X0o`0@2`3o00H;0?l0D`X0o`3_2`0h0?l:0033o`/00?li2`2co`0:0?nB00/0oal02P3o
000;0?lj00/0olD02P1^o`0;003oQ`X007Co2`1o0?l;0?l0^0X0o`0c2`3o000:0?l09@/0o`2N2`2R
0?l:001<o`/00?n_2P1:o`060?[`iP800000I`3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP05
0?[`iPX00?oo2`000?l:0><0o`/0o`1a2P3o010;0?l01P/0o`1C2P3o0>l;03P0o`X00<?o2`00ocT;
0;?o00X0oi802`3o7`0:0?l000/0ocX02`3oa@0:06ko00/00?n72P00M?l;07l0o`/0o`2h2P3o03<;
0?l000X0o`0U2`3o09h;0:80o`X004co2`00ojl:04[o00L0n_3V00<000000?[`iP3jl>H0I@3jl>H1
0?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX00?oo2`000?l:0><0o`/0o`1a2P3o010;0?l0
1P/0o`1C2P3o0>l;03P0o`X00<?o2`00ocT;0;?o00X0oi802`3o7`0:0?l000/0ocX02`3oa@0:06ko
00/00?n72P00M?l;07l0o`/0o`2h2P3o03<;0?l000X0o`0U2`3o09h;0:80o`X004co2`00ojl:04[o
00L0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP050?[`iPX0
0?oo2`000?l:0><0o`/0o`1a2P3o010;0?l01P/0o`1C2P3o0>l;03P0o`X00<?o2`00ocT;0;?o00X0
oi802`3o7`0:0?l000/0ocX02`3oa@0:06ko00/00?n72P00M?l;07l0o`/0o`2h2P3o03<;0?l000X0
o`0U2`3o09h;0:80o`X004co2`00ojl:04[o00L0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00
?`3jl>H00`000000n_3V0?[`iP3o0?[`iTX0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3j
l>H00`000000n_3V0?[`iP3o0?[`iTX0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H0
0`000000n_3V0?[`iP3o0?[`iTX0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`00
0000n_3V0?[`iP3o0?[`iTX0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000
n_3V0?[`iP3o0?[`iTX0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H00`000000n_3V
0?[`iP3o0?[`iTX0n_3V00<000000?[`iP3jl>H0I@3jl>H10?ooo`00?`3jl>H2000000H0n_3V00<0
00000?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V0300n_3V00<0
00000?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V02l0n_3V00<0
00000?[`iP3jl>H04P3jl>H2000006L0n_3V0@3oool003l0n_3V00<000000?[`iP3jl>H01@3jl>H0
0`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0203jl>H0
0`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP000000I`3jl>H1
0?ooo`00?`3jl>Ko000004h00000I`3jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V
0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0
n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003R0?[`iP@000002`3jl>H5000000@0n_3V1000
003e0?[`iP40oooo003R0?[`iP8000003`3jl>H2000000L0n_3V0P00003e0?[`iP40oooo003:0?[`
iPD000000P3jl>H6000000050?[`iP00000000000000003jl>H00`0000030?[`iP8000000`3jl>H3
000000040?[`iP0000000000000000D0n_3V0P0000070?[`iP800000m@3jl>H10?ooo`00bP3jl>H0
10000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000040?[`iP80000000<0n_3V000000000000103j
l>H2000000@0n_3V0P0000000`3jl>H00000000000060?[`iP<000001P3jl>H200000?D0n_3V0@3o
ool00<h0n_3V0P0000030?[`iP800000103jl>H2000000030?[`iP000000000000@0n_3V0P000005
0?[`iP<000001`3jl>H3000000H0n_3V0P00003e0?[`iP40oooo003<0?[`iP<00000103jl>H20000
00@0n_3V0P0000000`3jl>H00000000000040?[`iP8000001@3jl>H3000000H0n_3V0P0000000`3j
l>H00000000000050?[`iP800000m@3jl>H10?ooo`00b`3jl>H3000000D0n_3V0P0000040?[`iP80
000000<0n_3V000000000000103jl>H2000000@0n_3V0P0000000`3jl>H00000000000050?[`iP80
000000<0n_3V0000000000001@3jl>H200000?D0n_3V0@3oool00<X0n_3V0P0000050?[`iP@00000
0`3jl>H5000000D0n_3V0P0000030?[`iP<0000000@0n_3V00000000000000000`3jl>H300000004
0?[`iP0000000000000000@0n_3V0P00003e0?[`iP40oooo003:0?[`iP8000000`3jl>H00`000000
n_3V0?[`iP0@0?[`iP800000603jl>H200000?D0n_3V0@3oool00</0n_3V1@0000030?[`iP800000
3@3jl>H4000001@0n_3V1000003e0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H1
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {407.125, 0}} -> {-1.06197, -1.05001, \
0.00515819, 0.00515819}, {{12, 399.688}, {397.375, 9.6875}} -> {-0.704432, \
-0.525085, 0.00991547, 0.00991547}, {{419.125, 477.25}, {319.875, 87.1875}} -> \
{-23.1747, -7.68874, 0.0550543, 0.0868825}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowSize->{683, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 30, 0, 67, "Title"],
Cell[1787, 53, 73, 1, 50, "Input"],
Cell[1863, 56, 188, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[2076, 64, 37, 0, 52, "Subsection"],
Cell[2116, 66, 486, 8, 86, "Text"],

Cell[CellGroupData[{
Cell[2627, 78, 1595, 27, 557, "Input"],
Cell[4225, 107, 123763, 2998, 317, 36275, 1914, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[128003, 3108, 117, 3, 29, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[128157, 3116, 38, 0, 52, "Subsection"],
Cell[128198, 3118, 162, 3, 48, "Text"],

Cell[CellGroupData[{
Cell[128385, 3125, 650, 12, 230, "Input"],
Cell[129038, 3139, 52891, 1552, 175, 22962, 1179, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[181944, 4694, 414, 7, 67, "Text"],

Cell[CellGroupData[{
Cell[182383, 4705, 1107, 18, 390, "Input"],
Cell[183493, 4725, 63630, 1824, 254, 27042, 1369, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[247138, 6552, 74, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[247237, 6556, 1392, 24, 450, "Input"],
Cell[248632, 6582, 64034, 1870, 247, 27904, 1421, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[312681, 8455, 298, 5, 67, "Text"],

Cell[CellGroupData[{
Cell[313004, 8464, 1536, 25, 470, "Input"],
Cell[314543, 8491, 63205, 1862, 247, 27870, 1423, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[377763, 10356, 95, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[377883, 10362, 1479, 26, 470, "Input"],
Cell[379365, 10390, 70733, 2172, 247, 32165, 1693, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[450113, 12565, 308, 8, 48, "Text"],

Cell[CellGroupData[{
Cell[450446, 12577, 1125, 18, 390, "Input"],
Cell[451574, 12597, 145642, 2890, 417, 33757, 1506, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

