(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    380826,      10911]*)
(*NotebookOutlinePosition[    381526,      10935]*)
(*  CellTagsIndexPosition[    381482,      10931]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Viviani's Temple", "Title"],

Cell[BoxData[{
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\), "\n", 
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell["Viviani's Temple", "Subsection"],

Cell[TextData[{
  "This example is taken from ",
  StyleBox["Elementary Differential Geometry",
    FontSlant->"Italic"],
  " by Barrett O'Neil, 1966, Chapter 1, Section 4. The curve and construction \
is known as Viviani's Temple. Viviani was a friend, biographer and promoter \
of Galileo."
}], "Text"],

Cell["\<\
The following parametric curve moves on the intersection of a cylinder and a \
sphere.\
\>", "Text"],

Cell[BoxData[
    \(\(\[Alpha][t_] = {2\ Cos[t]\^2, Sin[2  t], 2  Sin[t]};\)\)], "Input"],

Cell["\<\
These rules will help us examine the properties of the curve.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xyzrules = {x, y, z} \[Rule] \[Alpha][t] // Thread\)], "Input"],

Cell[BoxData[
    \({x \[Rule] 2\ Cos[t]\^2, y \[Rule] Sin[2\ t], 
      z \[Rule] 2\ Sin[t]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The projection on the xy-plane is a cylinder of radius 1 centered at ",
  Cell[BoxData[
      \({1, 0, 0}\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\((x - 1)\)\^2 + 
        y\^2 == \((\((x - 1)\)\^2 + y\^2 /. xyzrules)\)\ \), "\n", 
    \(% // Simplify\)}], "Input"],

Cell[BoxData[
    \(\((\(-1\) + x)\)\^2 + y\^2 \[Equal] \((\(-1\) + 2\ Cos[t]\^2)\)\^2 + 
        Sin[2\ t]\^2\)], "Output"],

Cell[BoxData[
    \(x\^2 + y\^2 \[Equal] 2\ x\)], "Output"]
}, Open  ]],

Cell["The curve moves on the surface of a sphere of radius 2.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(x\^2 + y\^2 + z\^2 == \((x\^2 + y\^2 + z\^2 /. xyzrules)\)\ \), "\n", 
    \(% // Simplify\)}], "Input"],

Cell[BoxData[
    \(x\^2 + y\^2 + z\^2 \[Equal] 
      4\ Cos[t]\^4 + 4\ Sin[t]\^2 + Sin[2\ t]\^2\)], "Output"],

Cell[BoxData[
    \(x\^2 + y\^2 + z\^2 \[Equal] 4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Solve[x\^2 + y\^2 + z\^2 == 4, z]\)\[LeftDoubleBracket]2, 
      1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \(z \[Rule] \@\(4 - x\^2 - y\^2\)\)], "Output"]
}, Open  ]],

Cell["This is the parametric representation of the cylinder:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cylinder = 
      CoordinatesToCartesian[{1, \[Theta], z}, 
          Cylindrical[r, \[Theta], z]] + {1, 0, 0}\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(cylinder\\)\\\" is similar to existing \
symbol \\\"\\!\\(Cylinder\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({1 + Cos[\[Theta]], Sin[\[Theta]], z}\)], "Output"]
}, Open  ]],

Cell["\<\
But the height of the cylinder varies with \[Theta]. Using our z solution \
above it is given by:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\@\(4 - \((1 + Cos[\[Theta]])\)\^2 - Sin[\[Theta]]\^2\) // 
      Simplify\)], "Input"],

Cell[BoxData[
    \(\@\(2 - 2\ Cos[\[Theta]]\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "So we want to reparametrize the cylinder to obtain a fixed limit iterator \
using ",
  ButtonBox["IteratorSubstitution",
    ButtonData:>{"IteratorSubstitution"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IteratorSubstitution[{1 + Cos[\[Theta]], Sin[\[Theta]], z}, {z, 
        0, \@\(2 - 2\ Cos[\[Theta]]\)}]\)], "Input"],

Cell[BoxData[
    \({{1 + Cos[\[Theta]], Sin[\[Theta]], w\ \@\(2 - 2\ Cos[\[Theta]]\)}, {w, 
        0, 1}}\)], "Output"]
}, Open  ]],

Cell["\<\
This will be used in the plot below. The parametrization of the sphere is:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sphere = 
      CoordinatesToCartesian[{2, \[Phi], \[Theta]}, 
        Spherical[\[Rho], \[Phi], \[Theta]]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(sphere\\)\\\" is similar to existing symbols \
\\!\\({gsphere, Sphere}\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({2\ Cos[\[Theta]]\ Sin[\[Phi]], 2\ Sin[\[Theta]]\ Sin[\[Phi]], 
      2\ Cos[\[Phi]]}\)], "Output"]
}, Open  ]],

Cell["\<\
We can now make our plot.
1) The cylinder was drawn up to its intersection with the sphere. \
SurfaceColor and NeutralLighting were used to obtain a colored, shaded \
surface.
2) UseWireFrame was used to obtain 1/8th of a see-through sphere.
3) The intersection was drawn with a thicker Peacock line.
4) ColorMix was used to obtain a lighter shade of SeaGreen for the \
Background.\
\>", "Text",
  ParagraphSpacing->{0, 0}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{EdgeForm[], 
          SurfaceColor[Sienna, Sienna, 3], 
          ParametricDraw3D[{1 + Cos[\[Theta]], Sin[\[Theta]], 
              w\ \@\(2 - 2\ Cos[\[Theta]]\)}, {w, 0, 1}, {\[Theta], 
              0, \[Pi]}, 
            PlotPoints \[Rule] {11, 31}], \[IndentingNewLine]ParametricDraw3D[
              Evaluate[sphere], {\[Phi], 0, \[Pi]\/2}, {\[Theta], 
                0, \[Pi]\/2}] // 
            UseWireFrame, \[IndentingNewLine]AbsoluteThickness[2], 
          Peacock, \[IndentingNewLine]ParametricDraw3D[
            Evaluate[\[Alpha][t]], {t, 
              0, \[Pi]\/2}]}, \[IndentingNewLine]\[IndentingNewLine]PlotRange \
\[Rule] {{0, 2}, {0, 2}, {0, 2}}, \[IndentingNewLine]Axes \[Rule] 
          False, \[IndentingNewLine]AxesLabel \[Rule] {x, y, 
            z}, \[IndentingNewLine]ViewPoint \[Rule] {2.616, 1.841, 
            1.104}, \[IndentingNewLine]NeutralLighting[0.3, 0.5, 
          0], \[IndentingNewLine]Background \[Rule] \(ColorMix[DarkSeaGreen, 
              White]\)[0.5], \[IndentingNewLine]ImageSize \[Rule] 
          400];\)\)], "Input",
  GeneratedCell->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .97597 
%%ImageSize: 400 390.387 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.78 .869 .78 r
MFill
% Scaling calculations
-0.0416488 1.11885 1.37992e-016 1.11885 [
[ 0 0 0 0 ]
[ 1 .97597 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.45128 .42473 m
.44568 .97597 L
s
.44568 .97597 m
1 .91394 L
s
1 .91394 m
.95704 .28633 L
s
.95704 .28633 m
.45128 .42473 L
s
.04921 .21495 m
.6146 0 L
s
.6146 0 m
.62692 .78051 L
s
.62692 .78051 m
0 .88134 L
s
0 .88134 m
.04921 .21495 L
s
.45128 .42473 m
.44568 .97597 L
s
.44568 .97597 m
0 .88134 L
s
0 .88134 m
.04921 .21495 L
s
.04921 .21495 m
.45128 .42473 L
s
.95704 .28633 m
.6146 0 L
s
.6146 0 m
.62692 .78051 L
s
.62692 .78051 m
1 .91394 L
s
1 .91394 m
.95704 .28633 L
s
0 0 m
1 0 L
1 .97597 L
0 .97597 L
closepath
clip
newpath
.446 .22 .13 r
.47355 .41791 m .45076 .47597 L .45128 .42473 L F
.47355 .41791 m .47321 .46941 L .45076 .47597 L F
.411 .203 .121 r
.49413 .4101 m .47321 .46941 L .47355 .41791 L F
.446 .22 .13 r
.47321 .46941 m .45023 .52803 L .45076 .47597 L F
.47321 .46941 m .47285 .52172 L .45023 .52803 L F
.411 .203 .121 r
.49394 .46176 m .47285 .52172 L .47321 .46941 L F
.49413 .4101 m .49394 .46176 L .47321 .46941 L F
.373 .185 .112 r
.51279 .40135 m .49394 .46176 L .49413 .4101 L F
.446 .22 .13 r
.47285 .52172 m .44969 .58091 L .45023 .52803 L F
.47285 .52172 m .47249 .57488 L .44969 .58091 L F
.411 .203 .121 r
.49375 .51423 m .47249 .57488 L .47285 .52172 L F
.49394 .46176 m .49375 .51423 L .47285 .52172 L F
.373 .185 .112 r
.51275 .45305 m .49375 .51423 L .49394 .46176 L F
.51279 .40135 m .51275 .45305 L .49394 .46176 L F
.446 .22 .13 r
.47249 .57488 m .44915 .63463 L .44969 .58091 L F
.331 .164 .1 r
.52931 .39169 m .51275 .45305 L .51279 .40135 L F
.446 .22 .13 r
.47249 .57488 m .47213 .62888 L .44915 .63463 L F
.411 .203 .121 r
.49356 .56755 m .47213 .62888 L .47249 .57488 L F
.49375 .51423 m .49356 .56755 L .47249 .57488 L F
.373 .185 .112 r
.51271 .50558 m .49356 .56755 L .49375 .51423 L F
.51275 .45305 m .51271 .50558 L .49375 .51423 L F
.446 .22 .13 r
.47213 .62888 m .44859 .68923 L .44915 .63463 L F
.331 .164 .1 r
.52941 .44334 m .51271 .50558 L .51275 .45305 L F
.52931 .39169 m .52941 .44334 L .51275 .45305 L F
.279 .138 .086 r
.5435 .38119 m .52941 .44334 L .52931 .39169 L F
.446 .22 .13 r
.47213 .62888 m .47176 .68377 L .44859 .68923 L F
.411 .203 .121 r
.49336 .62173 m .47176 .68377 L .47213 .62888 L F
.49356 .56755 m .49336 .62173 L .47213 .62888 L F
.373 .185 .112 r
.51267 .55896 m .49336 .62173 L .49356 .56755 L F
.51271 .50558 m .51267 .55896 L .49356 .56755 L F
.446 .22 .13 r
.47176 .68377 m .44803 .74471 L .44859 .68923 L F
.331 .164 .1 r
.5295 .49581 m .51267 .55896 L .51271 .50558 L F
.52941 .44334 m .5295 .49581 L .51271 .50558 L F
.279 .138 .086 r
.5437 .43266 m .5295 .49581 L .52941 .44334 L F
.5435 .38119 m .5437 .43266 L .52941 .44334 L F
.212 .105 .069 r
.55512 .36992 m .5437 .43266 L .5435 .38119 L F
.446 .22 .13 r
.47176 .68377 m .47138 .73955 L .44803 .74471 L F
.411 .203 .121 r
.49316 .6768 m .47138 .73955 L .47176 .68377 L F
.49336 .62173 m .49316 .6768 L .47176 .68377 L F
.373 .185 .112 r
.51263 .6132 m .49316 .6768 L .49336 .62173 L F
.51267 .55896 m .51263 .6132 L .49336 .62173 L F
.446 .22 .13 r
.47138 .73955 m .44746 .8011 L .44803 .74471 L F
.331 .164 .1 r
.52959 .54912 m .51263 .6132 L .51267 .55896 L F
.5295 .49581 m .52959 .54912 L .51267 .55896 L F
.279 .138 .086 r
.54391 .48496 m .52959 .54912 L .5295 .49581 L F
.5437 .43266 m .54391 .48496 L .5295 .49581 L F
.212 .105 .069 r
.55542 .42109 m .54391 .48496 L .5437 .43266 L F
.55512 .36992 m .55542 .42109 L .5437 .43266 L F
.446 .22 .13 r
.47138 .73955 m .471 .79625 L .44746 .8011 L F
.411 .203 .121 r
.49296 .73277 m .471 .79625 L .47138 .73955 L F
.49316 .6768 m .49296 .73277 L .47138 .73955 L F
.373 .185 .112 r
.51258 .66833 m .49296 .73277 L .49316 .6768 L F
.51263 .6132 m .51258 .66833 L .49316 .6768 L F
.446 .22 .13 r
.471 .79625 m .44688 .85843 L .44746 .8011 L F
.331 .164 .1 r
.52969 .6033 m .51258 .66833 L .51263 .6132 L F
.52959 .54912 m .52969 .6033 L .51263 .6132 L F
.121 .06 .045 r
.56399 .35796 m .55542 .42109 L .55512 .36992 L F
.279 .138 .086 r
.54411 .53809 m .52969 .6033 L .52959 .54912 L F
.54391 .48496 m .54411 .53809 L .52959 .54912 L F
.212 .105 .069 r
.55571 .47308 m .54411 .53809 L .54391 .48496 L F
.55542 .42109 m .55571 .47308 L .54391 .48496 L F
.446 .22 .13 r
.471 .79625 m .47061 .8539 L .44688 .85843 L F
.411 .203 .121 r
.49276 .78966 m .47061 .8539 L .471 .79625 L F
.49296 .73277 m .49276 .78966 L .471 .79625 L F
.373 .185 .112 r
.51254 .72436 m .49276 .78966 L .49296 .73277 L F
.51258 .66833 m .51254 .72436 L .49296 .73277 L F
.446 .22 .13 r
.47061 .8539 m .44628 .91671 L .44688 .85843 L F
.331 .164 .1 r
.52979 .65837 m .51254 .72436 L .51258 .66833 L F
.52969 .6033 m .52979 .65837 L .51258 .66833 L F
.121 .06 .045 r
.56435 .40871 m .55571 .47308 L .55542 .42109 L F
.56399 .35796 m .56435 .40871 L .55542 .42109 L F
.279 .138 .086 r
.54433 .59208 m .52979 .65837 L .52969 .6033 L F
.54411 .53809 m .54433 .59208 L .52969 .6033 L F
.082 .042 .033 r
.56991 .3454 m .56435 .40871 L .56399 .35796 L F
.212 .105 .069 r
.55602 .5259 m .54433 .59208 L .54411 .53809 L F
.55571 .47308 m .55602 .5259 L .54411 .53809 L F
.446 .22 .13 r
.47061 .8539 m .47021 .91252 L .44628 .91671 L F
.411 .203 .121 r
.49255 .84751 m .47021 .91252 L .47061 .8539 L F
.49276 .78966 m .49255 .84751 L .47061 .8539 L F
.373 .185 .112 r
.5125 .78133 m .49255 .84751 L .49276 .78966 L F
.51254 .72436 m .5125 .78133 L .49276 .78966 L F
.446 .22 .13 r
.47021 .91252 m .44568 .97597 L .44628 .91671 L F
.121 .06 .045 r
.56472 .46026 m .55602 .5259 L .55571 .47308 L F
.56435 .40871 m .56472 .46026 L .55571 .47308 L F
.331 .164 .1 r
.52988 .71435 m .5125 .78133 L .51254 .72436 L F
.52979 .65837 m .52988 .71435 L .51254 .72436 L F
.279 .138 .086 r
.54455 .64696 m .52988 .71435 L .52979 .65837 L F
.54433 .59208 m .54455 .64696 L .52979 .65837 L F
.082 .042 .033 r
.57032 .39559 m .56472 .46026 L .56435 .40871 L F
.56991 .3454 m .57032 .39559 L .56435 .40871 L F
.212 .105 .069 r
.55633 .57958 m .54455 .64696 L .54433 .59208 L F
.55602 .5259 m .55633 .57958 L .54433 .59208 L F
.446 .22 .13 r
.47021 .91252 m .46981 .97212 L .44568 .97597 L F
.411 .203 .121 r
.49233 .90634 m .46981 .97212 L .47021 .91252 L F
.49255 .84751 m .49233 .90634 L .47021 .91252 L F
.373 .185 .112 r
.51245 .83925 m .49233 .90634 L .49255 .84751 L F
.5125 .78133 m .51245 .83925 L .49255 .84751 L F
0 0 0 r
.5 Mabswid
.44568 .97597 m
.44568 .97597 L
s
.44568 .97597 m
.47169 .97218 L
s
.44568 .97597 m
.46946 .97174 L
s
.44568 .97597 m
.46823 .97154 L
s
.44568 .97597 m
.46694 .97135 L
s
.44568 .97597 m
.46559 .97116 L
s
.44568 .97597 m
.46417 .97099 L
s
.44568 .97597 m
.4627 .97084 L
s
.44568 .97597 m
.46117 .97069 L
s
.44568 .97597 m
.4596 .97056 L
s
.44568 .97597 m
.45799 .97044 L
s
.44568 .97597 m
.45634 .97033 L
s
.44568 .97597 m
.45465 .97024 L
s
.44568 .97597 m
.45294 .97016 L
s
.44568 .97597 m
.45121 .9701 L
s
.44568 .97597 m
.44946 .97005 L
s
.44568 .97597 m
.4477 .97002 L
s
.44568 .97597 m
.44593 .97 L
s
.44416 .97 m
.44568 .97597 L
s
.4424 .97001 m
.44568 .97597 L
s
.44064 .97004 m
.44568 .97597 L
s
.4389 .97008 m
.44568 .97597 L
s
.43719 .97014 m
.44568 .97597 L
s
.43549 .97021 m
.44568 .97597 L
s
.43383 .9703 m
.44568 .97597 L
s
.43221 .9704 m
.44568 .97597 L
s
.43062 .97051 m
.44568 .97597 L
s
.42909 .97064 m
.44568 .97597 L
s
.4276 .97078 m
.44568 .97597 L
s
.42616 .97094 m
.44568 .97597 L
s
.2 .63 .79 r
2 Mabswid
.44568 .97597 m
.45567 .97466 L
s
.121 .06 .045 r
.56509 .51262 m .55633 .57958 L .55602 .5259 L F
.56472 .46026 m .56509 .51262 L .55602 .5259 L F
.331 .164 .1 r
.52999 .77125 m .51245 .83925 L .5125 .78133 L F
.52988 .71435 m .52999 .77125 L .5125 .78133 L F
.045 .023 .018 r
.57271 .33236 m .57032 .39559 L .56991 .3454 L F
.279 .138 .086 r
.54477 .70274 m .52999 .77125 L .52988 .71435 L F
.54455 .64696 m .54477 .70274 L .52988 .71435 L F
.2 .63 .79 r
.45567 .97466 m
.46538 .97301 L
s
.082 .042 .033 r
.57073 .44655 m .56509 .51262 L .56472 .46026 L F
.57032 .39559 m .57073 .44655 L .56472 .46026 L F
.212 .105 .069 r
.55664 .63412 m .54477 .70274 L .54455 .64696 L F
.55633 .57958 m .55664 .63412 L .54455 .64696 L F
.2 .63 .79 r
.46538 .97301 m
.46884 .97228 L
s
.411 .203 .121 r
.49233 .90634 m .49212 .96616 L .46981 .97212 L F
0 0 0 r
.5 Mabswid
.47169 .97218 m
.49801 .96656 L
s
.47061 .97195 m
.47169 .97218 L
s
.2 .63 .79 r
2 Mabswid
.47074 .97188 m
.4748 .97102 L
s
.46884 .97228 m
.47074 .97188 L
s
0 0 0 r
.5 Mabswid
.4702 .97202 m
.47061 .97195 L
s
.44568 .97597 m
.4702 .97202 L
s
.373 .185 .112 r
.51241 .89815 m .49212 .96616 L .49233 .90634 L F
.51245 .83925 m .51241 .89815 L .49233 .90634 L F
0 0 0 r
.47061 .97195 m
.48235 .96924 L
s
.48235 .96924 m
.49588 .96611 L
s
.46946 .97174 m
.47057 .97195 L
s
.47057 .97195 m
.47061 .97195 L
s
.121 .06 .045 r
.56547 .56583 m .55664 .63412 L .55633 .57958 L F
.56509 .51262 m .56547 .56583 L .55633 .57958 L F
0 0 0 r
.46946 .97174 m
.46823 .97154 L
s
.045 .023 .018 r
.57313 .38184 m .57073 .44655 L .57032 .39559 L F
.57271 .33236 m .57313 .38184 L .57032 .39559 L F
.331 .164 .1 r
.53009 .82911 m .51241 .89815 L .51245 .83925 L F
.52999 .77125 m .53009 .82911 L .51245 .83925 L F
0 0 0 r
.46823 .97154 m
.49114 .96526 L
s
.46823 .97154 m
.46694 .97135 L
s
.2 .63 .79 r
2 Mabswid
.4748 .97102 m
.48391 .96867 L
s
0 0 0 r
.5 Mabswid
.46694 .97135 m
.48856 .96486 L
s
.46694 .97135 m
.46559 .97116 L
s
.46559 .97116 m
.48584 .96449 L
s
.46559 .97116 m
.46417 .97099 L
s
.46417 .97099 m
.483 .96414 L
s
.46417 .97099 m
.4627 .97084 L
s
.279 .138 .086 r
.54499 .75944 m .53009 .82911 L .52999 .77125 L F
.54477 .70274 m .54499 .75944 L .52999 .77125 L F
0 0 0 r
.4276 .97078 m
.42616 .97094 L
s
.42616 .97094 m
.40631 .96402 L
s
.4627 .97084 m
.48005 .96381 L
s
.4627 .97084 m
.46117 .97069 L
s
.42909 .97064 m
.4276 .97078 L
s
.4276 .97078 m
.40918 .9637 L
s
.46117 .97069 m
.47698 .96351 L
s
.46117 .97069 m
.4596 .97056 L
s
.43062 .97051 m
.42909 .97064 L
s
.42909 .97064 m
.41218 .96341 L
s
.4596 .97056 m
.47382 .96324 L
s
.4596 .97056 m
.45799 .97044 L
s
.43221 .9704 m
.43062 .97051 L
s
.43062 .97051 m
.41527 .96315 L
s
.45799 .97044 m
.47057 .96299 L
s
.45799 .97044 m
.45634 .97033 L
s
.082 .042 .033 r
.57114 .49832 m .56547 .56583 L .56509 .51262 L F
.57073 .44655 m .57114 .49832 L .56509 .51262 L F
0 0 0 r
.43383 .9703 m
.43221 .9704 L
s
.43221 .9704 m
.41847 .96291 L
s
.45634 .97033 m
.46724 .96278 L
s
.45634 .97033 m
.45465 .97024 L
s
.43549 .97021 m
.43383 .9703 L
s
.43383 .9703 m
.42174 .96271 L
s
.45465 .97024 m
.46384 .96259 L
s
.45465 .97024 m
.45294 .97016 L
s
.43719 .97014 m
.43549 .97021 L
s
.43549 .97021 m
.4251 .96253 L
s
.45294 .97016 m
.46038 .96243 L
s
.45294 .97016 m
.45121 .9701 L
s
.4389 .97008 m
.43719 .97014 L
s
.43719 .97014 m
.42852 .96238 L
s
.45121 .9701 m
.45688 .9623 L
s
.45121 .9701 m
.44946 .97005 L
s
.44064 .97004 m
.4389 .97008 L
s
.4389 .97008 m
.43199 .96226 L
s
.44946 .97005 m
.45334 .9622 L
s
.44946 .97005 m
.4477 .97002 L
s
.4424 .97001 m
.44064 .97004 L
s
.44064 .97004 m
.4355 .96217 L
s
.2 .63 .79 r
2 Mabswid
.48391 .96867 m
.49176 .96626 L
s
0 0 0 r
.5 Mabswid
.4477 .97002 m
.44978 .96213 L
s
.4477 .97002 m
.44593 .97 L
s
.44416 .97 m
.4424 .97001 L
s
.4424 .97001 m
.43905 .96212 L
s
.212 .105 .069 r
.55696 .68956 m .54499 .75944 L .54477 .70274 L F
.55664 .63412 m .55696 .68956 L .54477 .70274 L F
0 0 0 r
.44593 .97 m
.4462 .9621 L
s
.44593 .97 m
.44416 .97 L
s
.44416 .97 m
.44262 .96209 L
s
.365 .18 .084 r
.57224 .31896 m .57313 .38184 L .57271 .33236 L F
0 0 0 r
.49588 .96611 m
.49801 .96656 L
s
.121 .06 .045 r
.56586 .6199 m .55696 .68956 L .55664 .63412 L F
.56547 .56583 m .56586 .6199 L .55664 .63412 L F
.373 .185 .112 r
.51241 .89815 m .51236 .95806 L .49212 .96616 L F
0 0 0 r
.49358 .96567 m
.49588 .96611 L
s
.49588 .96611 m
.52139 .95841 L
s
.49801 .96656 m
.52457 .9591 L
s
.2 .63 .79 r
2 Mabswid
.49227 .9661 m
.49269 .96597 L
s
.49176 .96626 m
.49227 .9661 L
s
0 0 0 r
.5 Mabswid
.49306 .9658 m
.49358 .96567 L
s
.46946 .97174 m
.49306 .9658 L
s
.045 .023 .018 r
.57356 .43207 m .57114 .49832 L .57073 .44655 L F
.57313 .38184 m .57356 .43207 L .57073 .44655 L F
.2 .63 .79 r
2 Mabswid
.49269 .96597 m
.50114 .96292 L
s
0 0 0 r
.5 Mabswid
.49114 .96526 m
.49351 .96566 L
s
.49351 .96566 m
.49358 .96567 L
s
.331 .164 .1 r
.53019 .88795 m .51236 .95806 L .51241 .89815 L F
0 0 0 r
.49358 .96567 m
.50229 .96284 L
s
.50229 .96284 m
.51797 .95774 L
s
.331 .164 .1 r
.53009 .82911 m .53019 .88795 L .51241 .89815 L F
0 0 0 r
.49114 .96526 m
.48856 .96486 L
s
.279 .138 .086 r
.54522 .8171 m .53019 .88795 L .53009 .82911 L F
.54499 .75944 m .54522 .8171 L .53009 .82911 L F
0 0 0 r
.48856 .96486 m
.51046 .95649 L
s
.48856 .96486 m
.48584 .96449 L
s
.082 .042 .033 r
.57157 .55092 m .56586 .6199 L .56547 .56583 L F
.57114 .49832 m .57157 .55092 L .56547 .56583 L F
0 0 0 r
.48584 .96449 m
.50639 .95591 L
s
.48584 .96449 m
.483 .96414 L
s
.2 .63 .79 r
2 Mabswid
.50114 .96292 m
.50923 .95952 L
s
0 0 0 r
.5 Mabswid
.483 .96414 m
.50213 .95537 L
s
.483 .96414 m
.48005 .96381 L
s
.40918 .9637 m
.40631 .96402 L
s
.40631 .96402 m
.38618 .95519 L
s
.212 .105 .069 r
.55728 .74591 m .54522 .8171 L .54499 .75944 L F
.55696 .68956 m .55728 .74591 L .54499 .75944 L F
.365 .18 .084 r
.57265 .36757 m .57356 .43207 L .57313 .38184 L F
.57224 .31896 m .57265 .36757 L .57313 .38184 L F
0 0 0 r
.48005 .96381 m
.49768 .95487 L
s
.48005 .96381 m
.47698 .96351 L
s
.52457 .9591 m
.52139 .95841 L
s
.41218 .96341 m
.40918 .9637 L
s
.40918 .9637 m
.3905 .9547 L
s
.47698 .96351 m
.49306 .95441 L
s
.47698 .96351 m
.47382 .96324 L
s
.41527 .96315 m
.41218 .96341 L
s
.41218 .96341 m
.39501 .95425 L
s
.47382 .96324 m
.48829 .95398 L
s
.47382 .96324 m
.47057 .96299 L
s
.41847 .96291 m
.41527 .96315 L
s
.41527 .96315 m
.39968 .95384 L
s
.51797 .95774 m
.52139 .95841 L
s
.47057 .96299 m
.48338 .9536 L
s
.47057 .96299 m
.46724 .96278 L
s
.42174 .96271 m
.41847 .96291 L
s
.41847 .96291 m
.4045 .95348 L
s
.2 .63 .79 r
2 Mabswid
.50923 .95952 m
.51161 .95836 L
s
.045 .023 .018 r
.574 .48309 m .57157 .55092 L .57114 .49832 L F
.57356 .43207 m .574 .48309 L .57114 .49832 L F
.121 .06 .045 r
.56625 .67485 m .55728 .74591 L .55696 .68956 L F
.56586 .6199 m .56625 .67485 L .55696 .68956 L F
0 0 0 r
.5 Mabswid
.46724 .96278 m
.47835 .95326 L
s
.46724 .96278 m
.46384 .96259 L
s
.4251 .96253 m
.42174 .96271 L
s
.42174 .96271 m
.40945 .95315 L
s
.46384 .96259 m
.47321 .95297 L
s
.46384 .96259 m
.46038 .96243 L
s
.42852 .96238 m
.4251 .96253 L
s
.4251 .96253 m
.41453 .95288 L
s
.46038 .96243 m
.46798 .95272 L
s
.46038 .96243 m
.45688 .9623 L
s
.43199 .96226 m
.42852 .96238 L
s
.42852 .96238 m
.4197 .95265 L
s
.45688 .9623 m
.46267 .95252 L
s
.45688 .9623 m
.45334 .9622 L
s
.4355 .96217 m
.43199 .96226 L
s
.43199 .96226 m
.42496 .95246 L
s
.331 .164 .1 r
.53019 .88795 m .5303 .94779 L .51236 .95806 L F
0 0 0 r
.51433 .9571 m
.51797 .95774 L
s
.51797 .95774 m
.54254 .94792 L
s
.2 .63 .79 r
2 Mabswid
.51313 .95762 m
.51695 .95576 L
s
.51162 .95836 m
.51313 .95762 L
s
0 0 0 r
.5 Mabswid
.52139 .95841 m
.54706 .94884 L
s
.52457 .9591 m
.55125 .9498 L
s
.51378 .95729 m
.51433 .9571 L
s
.49114 .96526 m
.51378 .95729 L
s
.45334 .9622 m
.45731 .95237 L
s
.45334 .9622 m
.44978 .96213 L
s
.43905 .96212 m
.4355 .96217 L
s
.4355 .96217 m
.43028 .95233 L
s
.44978 .96213 m
.45191 .95226 L
s
.44978 .96213 m
.4462 .9621 L
s
.44262 .96209 m
.43905 .96212 L
s
.43905 .96212 m
.43566 .95224 L
s
.4462 .9621 m
.44649 .95221 L
s
.4462 .9621 m
.44262 .96209 L
s
.44262 .96209 m
.44107 .9522 L
s
.499 .246 .122 r
.56837 .30533 m .57265 .36757 L .57224 .31896 L F
0 0 0 r
.51046 .95649 m
.51421 .95708 L
s
.51421 .95708 m
.51433 .9571 L
s
.279 .138 .086 r
.54545 .87572 m .5303 .94779 L .53019 .88795 L F
0 0 0 r
.51433 .9571 m
.52102 .95422 L
s
.52102 .95422 m
.53771 .94705 L
s
.279 .138 .086 r
.54522 .8171 m .54545 .87572 L .53019 .88795 L F
.082 .042 .033 r
.572 .60435 m .56625 .67485 L .56586 .6199 L F
.57157 .55092 m .572 .60435 L .56586 .6199 L F
.2 .63 .79 r
2 Mabswid
.51695 .95576 m
.52427 .95165 L
s
0 0 0 r
.5 Mabswid
.51046 .95649 m
.50639 .95591 L
s
.55125 .9498 m
.54706 .94884 L
s
.57796 .93863 m
.55125 .9498 L
s
.365 .18 .084 r
.57307 .41692 m .574 .48309 L .57356 .43207 L F
.57265 .36757 m .57307 .41692 L .57356 .43207 L F
.212 .105 .069 r
.55761 .80321 m .54545 .87572 L .54522 .8171 L F
.55728 .74591 m .55761 .80321 L .54522 .8171 L F
0 0 0 r
.50639 .95591 m
.52716 .94542 L
s
.50639 .95591 m
.50213 .95537 L
s
.54706 .94884 m
.57279 .93741 L
s
.54706 .94884 m
.54254 .94792 L
s
.50213 .95537 m
.52147 .94467 L
s
.50213 .95537 m
.49768 .95487 L
s
.3905 .9547 m
.38618 .95519 L
s
.38618 .95519 m
.36585 .94442 L
s
.045 .023 .018 r
.57444 .5349 m .572 .60435 L .57157 .55092 L F
.574 .48309 m .57444 .5349 L .57157 .55092 L F
.2 .63 .79 r
2 Mabswid
.52427 .95165 m
.52981 .94808 L
s
0 0 0 r
.5 Mabswid
.49768 .95487 m
.51553 .94398 L
s
.49768 .95487 m
.49306 .95441 L
s
.121 .06 .045 r
.56665 .73069 m .55761 .80321 L .55728 .74591 L F
.56625 .67485 m .56665 .73069 L .55728 .74591 L F
0 0 0 r
.39501 .95425 m
.3905 .9547 L
s
.3905 .9547 m
.37162 .94374 L
s
.53771 .94705 m
.54254 .94792 L
s
.49306 .95441 m
.50936 .94334 L
s
.49306 .95441 m
.48829 .95398 L
s
.39968 .95384 m
.39501 .95425 L
s
.39501 .95425 m
.37765 .94312 L
s
.499 .246 .122 r
.56874 .35292 m .57307 .41692 L .57265 .36757 L F
.56837 .30533 m .56874 .35292 L .57265 .36757 L F
0 0 0 r
.48829 .95398 m
.50297 .94275 L
s
.48829 .95398 m
.48338 .9536 L
s
.4045 .95348 m
.39968 .95384 L
s
.39968 .95384 m
.3839 .94256 L
s
.57796 .93863 m
.57279 .93741 L
s
.60459 .92563 m
.57796 .93863 L
s
.48338 .9536 m
.49639 .94223 L
s
.48338 .9536 m
.47835 .95326 L
s
.40945 .95315 m
.4045 .95348 L
s
.4045 .95348 m
.39036 .94205 L
s
.279 .138 .086 r
.54545 .87572 m .54568 .93535 L .5303 .94779 L F
0 0 0 r
.53258 .94621 m
.53771 .94705 L
s
.54254 .94792 m
.56719 .93622 L
s
.2 .63 .79 r
2 Mabswid
.53052 .94761 m
.5312 .94718 L
s
.52981 .94807 m
.53052 .94761 L
s
0 0 0 r
.5 Mabswid
.53203 .94646 m
.53258 .94621 L
s
.51046 .95649 m
.53203 .94646 L
s
.082 .042 .033 r
.57244 .65864 m .56665 .73069 L .56625 .67485 L F
.572 .60435 m .57244 .65864 L .56625 .67485 L F
0 0 0 r
.47835 .95326 m
.48964 .94176 L
s
.47835 .95326 m
.47321 .95297 L
s
.2 .63 .79 r
2 Mabswid
.5312 .94718 m
.5377 .94235 L
s
0 0 0 r
.5 Mabswid
.41453 .95288 m
.40945 .95315 L
s
.40945 .95315 m
.39701 .94161 L
s
.365 .18 .084 r
.57349 .46702 m .57444 .5349 L .574 .48309 L F
.57307 .41692 m .57349 .46702 L .574 .48309 L F
0 0 0 r
.47321 .95297 m
.48274 .94135 L
s
.47321 .95297 m
.46798 .95272 L
s
.52716 .94542 m
.53242 .94619 L
s
.53242 .94619 m
.53258 .94621 L
s
.4197 .95265 m
.41453 .95288 L
s
.41453 .95288 m
.40382 .94122 L
s
.46798 .95272 m
.47571 .94101 L
s
.46798 .95272 m
.46267 .95252 L
s
.42496 .95246 m
.4197 .95265 L
s
.4197 .95265 m
.41077 .9409 L
s
.57279 .93741 m
.59847 .9241 L
s
.57279 .93741 m
.56719 .93622 L
s
.212 .105 .069 r
.55795 .86147 m .54568 .93535 L .54545 .87572 L F
0 0 0 r
.53258 .94621 m
.53783 .94333 L
s
.53783 .94333 m
.55481 .93401 L
s
.53771 .94705 m
.5612 .93509 L
s
.212 .105 .069 r
.55761 .80321 m .55795 .86147 L .54545 .87572 L F
0 0 0 r
.46267 .95252 m
.46858 .94073 L
s
.46267 .95252 m
.45731 .95237 L
s
.43028 .95233 m
.42496 .95246 L
s
.42496 .95246 m
.41784 .94065 L
s
.45731 .95237 m
.46137 .94052 L
s
.45731 .95237 m
.45191 .95226 L
s
.43566 .95224 m
.43028 .95233 L
s
.43028 .95233 m
.425 .94046 L
s
.45191 .95226 m
.4541 .94037 L
s
.45191 .95226 m
.44649 .95221 L
s
.44107 .9522 m
.43566 .95224 L
s
.43566 .95224 m
.43223 .94034 L
s
.44649 .95221 m
.44681 .94029 L
s
.44649 .95221 m
.44107 .9522 L
s
.44107 .9522 m
.43951 .94028 L
s
.52716 .94542 m
.52147 .94467 L
s
.614 .3 .153 r
.56101 .29163 m .56874 .35292 L .56837 .30533 L F
.045 .023 .018 r
.57488 .58754 m .57244 .65864 L .572 .60435 L F
.57444 .5349 m .57488 .58754 L .572 .60435 L F
.2 .63 .79 r
2 Mabswid
.5377 .94235 m
.54376 .93716 L
s
0 0 0 r
.5 Mabswid
.56719 .93622 m
.59183 .92264 L
s
.56719 .93622 m
.5612 .93509 L
s
.121 .06 .045 r
.56705 .78747 m .55795 .86147 L .55761 .80321 L F
.56665 .73069 m .56705 .78747 L .55761 .80321 L F
0 0 0 r
.52147 .94467 m
.54096 .93202 L
s
.52147 .94467 m
.51553 .94398 L
s
.60459 .92563 m
.59847 .9241 L
s
.63103 .91079 m
.60459 .92563 L
s
.37162 .94374 m
.36585 .94442 L
s
.36585 .94442 m
.34539 .93169 L
s
.499 .246 .122 r
.56912 .40121 m .57349 .46702 L .57307 .41692 L F
.56874 .35292 m .56912 .40121 L .57307 .41692 L F
0 0 0 r
.51553 .94398 m
.53354 .93112 L
s
.51553 .94398 m
.50936 .94334 L
s
.37765 .94312 m
.37162 .94374 L
s
.37162 .94374 m
.35262 .93081 L
s
.5612 .93509 m
.5847 .92123 L
s
.55481 .93401 m
.5612 .93509 L
s
.082 .042 .033 r
.57288 .71382 m .56705 .78747 L .56665 .73069 L F
.57244 .65864 m .57288 .71382 L .56665 .73069 L F
0 0 0 r
.50936 .94334 m
.52581 .93029 L
s
.50936 .94334 m
.50297 .94275 L
s
.365 .18 .084 r
.57392 .51789 m .57488 .58754 L .57444 .5349 L F
.57349 .46702 m .57392 .51789 L .57444 .5349 L F
0 0 0 r
.59847 .9241 m
.62399 .90896 L
s
.59847 .9241 m
.59183 .92264 L
s
.3839 .94256 m
.37765 .94312 L
s
.37765 .94312 m
.36016 .93001 L
s
.2 .63 .79 r
2 Mabswid
.54376 .93716 m
.54518 .93576 L
s
0 0 0 r
.5 Mabswid
.50297 .94275 m
.5178 .92953 L
s
.50297 .94275 m
.49639 .94223 L
s
.39036 .94205 m
.3839 .94256 L
s
.3839 .94256 m
.368 .92928 L
s
.212 .105 .069 r
.55795 .86147 m .55829 .92071 L .54568 .93535 L F
0 0 0 r
.54806 .93298 m
.55481 .93401 L
s
.2 .63 .79 r
2 Mabswid
.54621 .93474 m
.54937 .93161 L
s
.54518 .93575 m
.54621 .93474 L
s
0 0 0 r
.5 Mabswid
.54754 .93329 m
.54806 .93298 L
s
.52716 .94542 m
.54754 .93329 L
s
.63103 .91079 m
.62399 .90896 L
s
.65716 .89416 m
.63103 .91079 L
s
.49639 .94223 m
.50954 .92885 L
s
.49639 .94223 m
.48964 .94176 L
s
.614 .3 .153 r
.56132 .33803 m .56912 .40121 L .56874 .35292 L F
.56101 .29163 m .56132 .33803 L .56874 .35292 L F
0 0 0 r
.39701 .94161 m
.39036 .94205 L
s
.39036 .94205 m
.3761 .92862 L
s
.59183 .92264 m
.61635 .90718 L
s
.59183 .92264 m
.5847 .92123 L
s
.48964 .94176 m
.50106 .92824 L
s
.48964 .94176 m
.48274 .94135 L
s
.045 .023 .018 r
.57534 .64101 m .57288 .71382 L .57244 .65864 L F
.57488 .58754 m .57534 .64101 L .57244 .65864 L F
0 0 0 r
.54096 .93202 m
.54786 .93295 L
s
.54786 .93295 m
.54806 .93298 L
s
.40382 .94122 m
.39701 .94161 L
s
.39701 .94161 m
.38445 .92804 L
s
.48274 .94135 m
.49239 .92771 L
s
.48274 .94135 m
.47571 .94101 L
s
.121 .06 .045 r
.56746 .84519 m .55829 .92071 L .55795 .86147 L F
0 0 0 r
.54806 .93298 m
.55224 .93012 L
s
.55224 .93012 m
.56902 .91861 L
s
.55481 .93401 m
.57709 .91988 L
s
.121 .06 .045 r
.56705 .78747 m .56746 .84519 L .55795 .86147 L F
0 0 0 r
.41077 .9409 m
.40382 .94122 L
s
.40382 .94122 m
.39301 .92754 L
s
.499 .246 .122 r
.56951 .45023 m .57392 .51789 L .57349 .46702 L F
.56912 .40121 m .56951 .45023 L .57349 .46702 L F
.2 .63 .79 r
2 Mabswid
.54937 .93161 m
.55452 .9257 L
s
0 0 0 r
.5 Mabswid
.47571 .94101 m
.48354 .92726 L
s
.47571 .94101 m
.46858 .94073 L
s
.41784 .94065 m
.41077 .9409 L
s
.41077 .9409 m
.40175 .92713 L
s
.46858 .94073 m
.47457 .9269 L
s
.46858 .94073 m
.46137 .94052 L
s
.54096 .93202 m
.53354 .93112 L
s
.425 .94046 m
.41784 .94065 L
s
.41784 .94065 m
.41065 .92679 L
s
.62399 .90896 m
.64926 .89199 L
s
.62399 .90896 m
.61635 .90718 L
s
.46137 .94052 m
.46549 .92663 L
s
.46137 .94052 m
.4541 .94037 L
s
.43223 .94034 m
.425 .94046 L
s
.425 .94046 m
.41967 .92655 L
s
.5847 .92123 m
.60811 .90548 L
s
.5847 .92123 m
.57709 .91988 L
s
.4541 .94037 m
.45634 .92644 L
s
.4541 .94037 m
.44681 .94029 L
s
.35262 .93081 m
.34539 .93169 L
s
.34539 .93169 m
.3249 .917 L
s
.43951 .94028 m
.43223 .94034 L
s
.43223 .94034 m
.42878 .92639 L
s
.44681 .94029 m
.44715 .92633 L
s
.44681 .94029 m
.43951 .94028 L
s
.43951 .94028 m
.43795 .92632 L
s
.65716 .89416 m
.64926 .89199 L
s
.68288 .87578 m
.65716 .89416 L
s
.365 .18 .084 r
.57436 .56956 m .57534 .64101 L .57488 .58754 L F
.57392 .51789 m .57436 .56956 L .57488 .58754 L F
.082 .042 .033 r
.57333 .7699 m .56746 .84519 L .56705 .78747 L F
.57288 .71382 m .57333 .7699 L .56705 .78747 L F
.784 .376 .194 r
.55011 .27802 m .56132 .33803 L .56101 .29163 L F
0 0 0 r
.53354 .93112 m
.55162 .91629 L
s
.53354 .93112 m
.52581 .93029 L
s
.36016 .93001 m
.35262 .93081 L
s
.35262 .93081 m
.33355 .91591 L
s
.2 .63 .79 r
2 Mabswid
.55452 .9257 m
.55784 .92123 L
s
0 0 0 r
.5 Mabswid
.57709 .91988 m
.5993 .90385 L
s
.57709 .91988 m
.56902 .91861 L
s
.614 .3 .153 r
.56164 .38509 m .56951 .45023 L .56912 .40121 L F
.56132 .33803 m .56164 .38509 L .56912 .40121 L F
0 0 0 r
.52581 .93029 m
.54235 .91525 L
s
.52581 .93029 m
.5178 .92953 L
s
.61635 .90718 m
.64064 .88989 L
s
.61635 .90718 m
.60811 .90548 L
s
.368 .92928 m
.36016 .93001 L
s
.36016 .93001 m
.34261 .9149 L
s
.045 .023 .018 r
.5758 .69534 m .57333 .7699 L .57288 .71382 L F
.57534 .64101 m .5758 .69534 L .57288 .71382 L F
0 0 0 r
.5178 .92953 m
.53273 .9143 L
s
.5178 .92953 m
.50954 .92885 L
s
.64926 .89199 m
.67415 .87324 L
s
.64926 .89199 m
.64064 .88989 L
s
.499 .246 .122 r
.5699 .49999 m .57436 .56956 L .57392 .51789 L F
.56951 .45023 m .5699 .49999 L .57392 .51789 L F
0 0 0 r
.3761 .92862 m
.368 .92928 L
s
.368 .92928 m
.35202 .91399 L
s
.68288 .87578 m
.67415 .87324 L
s
.70807 .85569 m
.68288 .87578 L
s
.121 .06 .045 r
.56746 .84519 m .56788 .90388 L .55829 .92071 L F
0 0 0 r
.56052 .91741 m
.56902 .91861 L
s
.2 .63 .79 r
2 Mabswid
.55849 .92036 m
.55918 .91943 L
s
.55784 .92122 m
.55849 .92036 L
s
0 0 0 r
.5 Mabswid
.56003 .91778 m
.56052 .91741 L
s
.54096 .93202 m
.56003 .91778 L
s
.95704 .28633 m
.95831 .31766 L
s
.94138 .2742 m
.95704 .28633 L
s
.50954 .92885 m
.52279 .91345 L
s
.50954 .92885 m
.50106 .92824 L
s
.2 .63 .79 r
2 Mabswid
.55918 .91943 m
.56334 .9128 L
s
0 0 0 r
.5 Mabswid
.38445 .92804 m
.3761 .92862 L
s
.3761 .92862 m
.36178 .91317 L
s
.60811 .90548 m
.63133 .88786 L
s
.60811 .90548 m
.5993 .90385 L
s
.50106 .92824 m
.51258 .91269 L
s
.50106 .92824 m
.49239 .92771 L
s
.784 .376 .194 r
.55034 .32305 m .56164 .38509 L .56132 .33803 L F
.55011 .27802 m .55034 .32305 L .56132 .33803 L F
0 0 0 r
.39301 .92754 m
.38445 .92804 L
s
.38445 .92804 m
.37183 .91244 L
s
.55162 .91629 m
.56028 .91738 L
s
.56028 .91738 m
.56052 .91741 L
s
.365 .18 .084 r
.5748 .62203 m .5758 .69534 L .57534 .64101 L F
.57436 .56956 m .5748 .62203 L .57534 .64101 L F
0 0 0 r
.49239 .92771 m
.50212 .91203 L
s
.49239 .92771 m
.48354 .92726 L
s
.082 .042 .033 r
.57379 .82691 m .56788 .90388 L .56746 .84519 L F
0 0 0 r
.56052 .91741 m
.56387 .91458 L
s
.56387 .91458 m
.58008 .90085 L
s
.56902 .91861 m
.58995 .90231 L
s
.082 .042 .033 r
.57333 .7699 m .57379 .82691 L .56746 .84519 L F
0 0 0 r
.33355 .91591 m
.3249 .917 L
s
.3249 .917 m
.30445 .90035 L
s
.40175 .92713 m
.39301 .92754 L
s
.39301 .92754 m
.38215 .91182 L
s
.64064 .88989 m
.6646 .87079 L
s
.64064 .88989 m
.63133 .88786 L
s
.48354 .92726 m
.49146 .91147 L
s
.48354 .92726 m
.47457 .9269 L
s
.614 .3 .153 r
.56196 .43285 m .5699 .49999 L .56951 .45023 L F
.56164 .38509 m .56196 .43285 L .56951 .45023 L F
0 0 0 r
.70807 .85569 m
.69855 .85276 L
s
.7326 .83395 m
.70807 .85569 L
s
.41065 .92679 m
.40175 .92713 L
s
.40175 .92713 m
.39269 .9113 L
s
.95831 .31766 m
.94262 .30584 L
s
.95831 .31766 m
.95787 .34963 L
s
.5993 .90385 m
.62136 .88593 L
s
.5993 .90385 m
.58995 .90231 L
s
.55162 .91629 m
.54235 .91525 L
s
.47457 .9269 m
.48063 .91102 L
s
.47457 .9269 m
.46549 .92663 L
s
.67415 .87324 m
.69855 .85276 L
s
.67415 .87324 m
.6646 .87079 L
s
.41967 .92655 m
.41065 .92679 L
s
.41065 .92679 m
.40343 .91088 L
s
.2 .63 .79 r
2 Mabswid
.56334 .9128 m
.56699 .9058 L
s
0 0 0 r
.5 Mabswid
.46549 .92663 m
.46966 .91067 L
s
.46549 .92663 m
.45634 .92644 L
s
.34261 .9149 m
.33355 .91591 L
s
.33355 .91591 m
.31452 .89903 L
s
.42878 .92639 m
.41967 .92655 L
s
.41967 .92655 m
.41432 .91057 L
s
.45634 .92644 m
.45861 .91043 L
s
.45634 .92644 m
.44715 .92633 L
s
.43795 .92632 m
.42878 .92639 L
s
.42878 .92639 m
.42533 .91037 L
s
.44715 .92633 m
.44751 .9103 L
s
.44715 .92633 m
.43795 .92632 L
s
.43795 .92632 m
.4364 .91028 L
s
.045 .023 .018 r
.57627 .75055 m .57379 .82691 L .57333 .7699 L F
.5758 .69534 m .57627 .75055 L .57333 .7699 L F
.499 .246 .122 r
.5703 .5505 m .5748 .62203 L .57436 .56956 L F
.5699 .49999 m .5703 .5505 L .57436 .56956 L F
0 0 0 r
.54235 .91525 m
.55891 .89823 L
s
.54235 .91525 m
.53273 .9143 L
s
.904 .429 .222 r
.53568 .26468 m .55034 .32305 L .55011 .27802 L F
0 0 0 r
.35202 .91399 m
.34261 .9149 L
s
.34261 .9149 m
.32507 .89781 L
s
.58995 .90231 m
.61075 .88409 L
s
.58995 .90231 m
.58008 .90085 L
s
.63133 .88786 m
.65427 .86842 L
s
.63133 .88786 m
.62136 .88593 L
s
.7326 .83395 m
.72235 .83062 L
s
.75637 .81065 m
.7326 .83395 L
s
.95787 .34963 m
.94218 .33818 L
s
.95787 .34963 m
.9557 .38211 L
s
.53273 .9143 m
.54769 .89708 L
s
.53273 .9143 m
.52279 .91345 L
s
.784 .376 .194 r
.55057 .36872 m .56196 .43285 L .56164 .38509 L F
.55034 .32305 m .55057 .36872 L .56164 .38509 L F
0 0 0 r
.6646 .87079 m
.68812 .84993 L
s
.6646 .87079 m
.65427 .86842 L
s
.36178 .91317 m
.35202 .91399 L
s
.35202 .91399 m
.33606 .89669 L
s
.69855 .85276 m
.72235 .83062 L
s
.69855 .85276 m
.68812 .84993 L
s
.2 .63 .79 r
2 Mabswid
.56699 .9058 m
.56762 .90434 L
s
.365 .18 .084 r
.57525 .67533 m .57627 .75055 L .5758 .69534 L F
.5748 .62203 m .57525 .67533 L .5758 .69534 L F
0 0 0 r
.5 Mabswid
.94262 .30584 m
.94138 .2742 L
s
.92369 .26231 m
.94138 .2742 L
s
.58008 .90085 m
.59953 .88236 L
s
.52279 .91345 m
.53608 .89604 L
s
.52279 .91345 m
.51258 .91269 L
s
.082 .042 .033 r
.57379 .82691 m .57426 .88487 L .56788 .90388 L F
0 0 0 r
.56972 .89949 m
.58008 .90085 L
s
.2 .63 .79 r
2 Mabswid
.56813 .90313 m
.57012 .89845 L
s
.56762 .90434 m
.56813 .90313 L
s
0 0 0 r
.5 Mabswid
.56926 .89991 m
.56972 .89949 L
s
.55162 .91629 m
.56926 .89991 L
s
.614 .3 .153 r
.56229 .48132 m .5703 .5505 L .5699 .49999 L F
.56196 .43285 m .56229 .48132 L .5699 .49999 L F
0 0 0 r
.37183 .91244 m
.36178 .91317 L
s
.36178 .91317 m
.34745 .89569 L
s
.75637 .81065 m
.74544 .80687 L
s
.77927 .78586 m
.75637 .81065 L
s
.62136 .88593 m
.64317 .86616 L
s
.62136 .88593 m
.61075 .88409 L
s
.31452 .89903 m
.30445 .90035 L
s
.30445 .90035 m
.28414 .88177 L
s
.9557 .38211 m
.94004 .37107 L
s
.9557 .38211 m
.95179 .41496 L
s
.51258 .91269 m
.52414 .89511 L
s
.51258 .91269 m
.50212 .91203 L
s
.38215 .91182 m
.37183 .91244 L
s
.37183 .91244 m
.3592 .89481 L
s
.55891 .89823 m
.56943 .89945 L
s
.56943 .89945 m
.56972 .89949 L
s
.50212 .91203 m
.5119 .89431 L
s
.50212 .91203 m
.49146 .91147 L
s
.904 .429 .222 r
.53581 .30817 m .55057 .36872 L .55034 .32305 L F
.53568 .26468 m .53581 .30817 L .55034 .32305 L F
.045 .023 .018 r
.57675 .80666 m .57426 .88487 L .57379 .82691 L F
0 0 0 r
.56972 .89949 m
.57241 .8967 L
s
.045 .023 .018 r
.57627 .75055 m .57675 .80666 L .57379 .82691 L F
0 0 0 r
.65427 .86842 m
.6768 .8472 L
s
.65427 .86842 m
.64317 .86616 L
s
.499 .246 .122 r
.5707 .6018 m .57525 .67533 L .5748 .62203 L F
.5703 .5505 m .5707 .6018 L .5748 .62203 L F
0 0 0 r
.72235 .83062 m
.74544 .80687 L
s
.72235 .83062 m
.71109 .82738 L
s
.2 .63 .79 r
2 Mabswid
.57012 .89845 m
.57271 .89074 L
s
0 0 0 r
.5 Mabswid
.39269 .9113 m
.38215 .91182 L
s
.38215 .91182 m
.37127 .89405 L
s
.32507 .89781 m
.31452 .89903 L
s
.31452 .89903 m
.2956 .88019 L
s
.77927 .78586 m
.7677 .78162 L
s
.80118 .75968 m
.77927 .78586 L
s
.49146 .91147 m
.49942 .89363 L
s
.49146 .91147 m
.48063 .91102 L
s
.95179 .41496 m
.9362 .40437 L
s
.95179 .41496 m
.94613 .44805 L
s
.68812 .84993 m
.71109 .82738 L
s
.68812 .84993 m
.6768 .8472 L
s
.94218 .33818 m
.94262 .30584 L
s
.94262 .30584 m
.92488 .29427 L
s
.40343 .91088 m
.39269 .9113 L
s
.39269 .9113 m
.38362 .89341 L
s
.61075 .88409 m
.63134 .86401 L
s
.61075 .88409 m
.59953 .88236 L
s
.784 .376 .194 r
.55081 .41504 m .56229 .48132 L .56196 .43285 L F
.55057 .36872 m .55081 .41504 L .56196 .43285 L F
0 0 0 r
.48063 .91102 m
.48672 .89307 L
s
.48063 .91102 m
.46966 .91067 L
s
.55891 .89823 m
.54769 .89708 L
s
.41432 .91057 m
.40343 .91088 L
s
.40343 .91088 m
.3962 .89291 L
s
.46966 .91067 m
.47387 .89265 L
s
.46966 .91067 m
.45861 .91043 L
s
.42533 .91037 m
.41432 .91057 L
s
.41432 .91057 m
.40897 .89253 L
s
.33606 .89669 m
.32507 .89781 L
s
.32507 .89781 m
.30762 .87873 L
s
.45861 .91043 m
.46092 .89236 L
s
.45861 .91043 m
.44751 .9103 L
s
.4364 .91028 m
.42533 .91037 L
s
.42533 .91037 m
.42187 .89229 L
s
.44751 .9103 m
.4479 .8922 L
s
.44751 .9103 m
.4364 .91028 L
s
.4364 .91028 m
.43487 .89218 L
s
.80118 .75968 m
.78902 .75495 L
s
.822 .73221 m
.80118 .75968 L
s
.94613 .44805 m
.93065 .43794 L
s
.94613 .44805 m
.93875 .48122 L
s
.365 .18 .084 r
.57571 .72948 m .57675 .80666 L .57627 .75055 L F
.57525 .67533 m .57571 .72948 L .57627 .75055 L F
0 0 0 r
.74544 .80687 m
.7677 .78162 L
s
.74544 .80687 m
.73338 .80321 L
s
.614 .3 .153 r
.56262 .5305 m .5707 .6018 L .5703 .5505 L F
.56229 .48132 m .56262 .5305 L .5703 .5505 L F
0 0 0 r
.64317 .86616 m
.66462 .84458 L
s
.64317 .86616 m
.63134 .86401 L
s
.54769 .89708 m
.56261 .87786 L
s
.54769 .89708 m
.53608 .89604 L
s
.2 .63 .79 r
2 Mabswid
.57271 .89074 m
.574 .88563 L
s
0 0 0 r
.5 Mabswid
.59953 .88236 m
.6188 .86197 L
s
.59953 .88236 m
.58775 .88074 L
s
.953 .449 .234 r
.51778 .25179 m .53581 .30817 L .53568 .26468 L F
0 0 0 r
.94004 .37107 m
.94218 .33818 L
s
.94218 .33818 m
.92444 .32696 L
s
.34745 .89569 m
.33606 .89669 L
s
.33606 .89669 m
.32016 .8774 L
s
.822 .73221 m
.8093 .72698 L
s
.84163 .70357 m
.822 .73221 L
s
.93875 .48122 m
.9234 .47162 L
s
.93875 .48122 m
.92965 .51434 L
s
.71109 .82738 m
.73338 .80321 L
s
.71109 .82738 m
.69883 .82426 L
s
.2956 .88019 m
.28414 .88177 L
s
.28414 .88177 m
.26405 .86128 L
s
.6768 .8472 m
.69883 .82426 L
s
.6768 .8472 m
.66462 .84458 L
s
.904 .429 .222 r
.53593 .35226 m .55081 .41504 L .55057 .36872 L F
.53581 .30817 m .53593 .35226 L .55057 .36872 L F
0 0 0 r
.53608 .89604 m
.54935 .87662 L
s
.53608 .89604 m
.52414 .89511 L
s
.92488 .29427 m
.92369 .26231 L
s
.90397 .25073 m
.92369 .26231 L
s
.3592 .89481 m
.34745 .89569 L
s
.34745 .89569 m
.33318 .87621 L
s
.84163 .70357 m
.82844 .69781 L
s
.85998 .67387 m
.84163 .70357 L
s
.92965 .51434 m
.91449 .50527 L
s
.92965 .51434 m
.91888 .54725 L
s
.499 .246 .122 r
.57111 .65388 m .57571 .72948 L .57525 .67533 L F
.5707 .6018 m .57111 .65388 L .57525 .67533 L F
0 0 0 r
.7677 .78162 m
.78902 .75495 L
s
.7677 .78162 m
.75491 .7775 L
s
.045 .023 .018 r
.57675 .80666 m .57723 .86369 L .57426 .88487 L F
.2 .63 .79 r
2 Mabswid
.57434 .8843 m
.57475 .88268 L
s
.574 .88563 m
.57434 .8843 L
s
0 0 0 r
.5 Mabswid
.57501 .87972 m
.57542 .87924 L
s
.55891 .89823 m
.57501 .87972 L
s
.57241 .8967 m
.58775 .88074 L
s
.58775 .88074 m
.60561 .86007 L
s
.57542 .87924 m
.58775 .88074 L
s
.9362 .40437 m
.94004 .37107 L
s
.94004 .37107 m
.92235 .36025 L
s
.52414 .89511 m
.5357 .87552 L
s
.52414 .89511 m
.5119 .89431 L
s
.85998 .67387 m
.84635 .66758 L
s
.87695 .64326 m
.85998 .67387 L
s
.63134 .86401 m
.6516 .84209 L
s
.63134 .86401 m
.6188 .86197 L
s
.91888 .54725 m
.90393 .53873 L
s
.91888 .54725 m
.90646 .5798 L
s
.784 .376 .194 r
.55104 .46202 m .56262 .5305 L .56229 .48132 L F
.55081 .41504 m .55104 .46202 L .56229 .48132 L F
0 0 0 r
.30762 .87873 m
.2956 .88019 L
s
.2956 .88019 m
.27688 .85943 L
s
.2 .63 .79 r
2 Mabswid
.57475 .88268 m
.57622 .87426 L
s
0 0 0 r
.5 Mabswid
.37127 .89405 m
.3592 .89481 L
s
.3592 .89481 m
.34662 .87516 L
s
.87695 .64326 m
.86292 .63641 L
s
.89247 .61185 m
.87695 .64326 L
s
.90646 .5798 m
.89178 .57184 L
s
.90646 .5798 m
.89247 .61185 L
s
.89247 .61185 m
.87809 .60445 L
s
.5119 .89431 m
.52169 .87455 L
s
.5119 .89431 m
.49942 .89363 L
s
.73338 .80321 m
.75491 .7775 L
s
.73338 .80321 m
.72024 .79967 L
s
.38362 .89341 m
.37127 .89405 L
s
.37127 .89405 m
.36044 .87425 L
s
.66462 .84458 m
.68561 .82126 L
s
.66462 .84458 m
.6516 .84209 L
s
.78902 .75495 m
.8093 .72698 L
s
.78902 .75495 m
.77555 .75036 L
s
.56261 .87786 m
.57509 .8792 L
s
.57509 .8792 m
.57542 .87924 L
s
.953 .449 .234 r
.51778 .29357 m .53593 .35226 L .53581 .30817 L F
.51778 .25179 m .51778 .29357 L .53581 .30817 L F
.365 .18 .084 r
.57617 .7845 m .57723 .86369 L .57675 .80666 L F
0 0 0 r
.57758 .87649 m
.59181 .85831 L
s
.57542 .87924 m
.57758 .87649 L
s
.365 .18 .084 r
.57571 .72948 m .57617 .7845 L .57675 .80666 L F
0 0 0 r
.92444 .32696 m
.92488 .29427 L
s
.92488 .29427 m
.90511 .28299 L
s
.69883 .82426 m
.72024 .79967 L
s
.69883 .82426 m
.68561 .82126 L
s
.93065 .43794 m
.9362 .40437 L
s
.9362 .40437 m
.91859 .394 L
s
.49942 .89363 m
.50738 .87374 L
s
.49942 .89363 m
.48672 .89307 L
s
.614 .3 .153 r
.56295 .58042 m .57111 .65388 L .5707 .6018 L F
.56262 .5305 m .56295 .58042 L .5707 .6018 L F
0 0 0 r
.3962 .89291 m
.38362 .89341 L
s
.38362 .89341 m
.37459 .87349 L
s
.32016 .8774 m
.30762 .87873 L
s
.30762 .87873 m
.29035 .85772 L
s
.6188 .86197 m
.6378 .83974 L
s
.6188 .86197 m
.60561 .86007 L
s
.48672 .89307 m
.49284 .87308 L
s
.48672 .89307 m
.47387 .89265 L
s
.40897 .89253 m
.3962 .89291 L
s
.3962 .89291 m
.38901 .87288 L
s
.904 .429 .222 r
.53605 .39696 m .55104 .46202 L .55081 .41504 L F
.53593 .35226 m .53605 .39696 L .55081 .41504 L F
0 0 0 r
.8093 .72698 m
.82844 .69781 L
s
.8093 .72698 m
.7952 .72189 L
s
.47387 .89265 m
.4781 .87257 L
s
.47387 .89265 m
.46092 .89236 L
s
.2 .63 .79 r
2 Mabswid
.57622 .87426 m
.57712 .86549 L
s
0 0 0 r
.5 Mabswid
.56261 .87786 m
.54935 .87662 L
s
.42187 .89229 m
.40897 .89253 L
s
.40897 .89253 m
.40365 .87243 L
s
.27688 .85943 m
.26405 .86128 L
s
.26405 .86128 m
.2443 .83893 L
s
.9234 .47162 m
.93065 .43794 L
s
.93065 .43794 m
.91317 .42804 L
s
.46092 .89236 m
.46324 .87223 L
s
.46092 .89236 m
.4479 .8922 L
s
.43487 .89218 m
.42187 .89229 L
s
.42187 .89229 m
.41845 .87214 L
s
.4479 .8922 m
.4483 .87204 L
s
.4479 .8922 m
.43487 .89218 L
s
.75491 .7775 m
.77555 .75036 L
s
.75491 .7775 m
.74092 .77352 L
s
.43487 .89218 m
.43335 .87201 L
s
.33318 .87621 m
.32016 .8774 L
s
.32016 .8774 m
.30442 .85615 L
s
.499 .246 .122 r
.57153 .70678 m .57617 .7845 L .57571 .72948 L F
.57111 .65388 m .57153 .70678 L .57571 .72948 L F
0 0 0 r
.92235 .36025 m
.92444 .32696 L
s
.92444 .32696 m
.90467 .31604 L
s
.6516 .84209 m
.67146 .81841 L
s
.6516 .84209 m
.6378 .83974 L
s
.82844 .69781 m
.84635 .66758 L
s
.82844 .69781 m
.81376 .6922 L
s
.784 .376 .194 r
.55128 .50969 m .56295 .58042 L .56262 .5305 L F
.55104 .46202 m .55128 .50969 L .56262 .5305 L F
.956 .45 .236 r
.49651 .23954 m .51778 .29357 L .51778 .25179 L F
0 0 0 r
.91449 .50527 m
.9234 .47162 L
s
.9234 .47162 m
.90611 .46223 L
s
.60561 .86007 m
.62324 .83753 L
s
.60561 .86007 m
.59181 .85831 L
s
.54935 .87662 m
.56255 .85523 L
s
.54935 .87662 m
.5357 .87552 L
s
.72024 .79967 m
.74092 .77352 L
s
.72024 .79967 m
.70603 .79627 L
s
.68561 .82126 m
.70603 .79627 L
s
.68561 .82126 m
.67146 .81841 L
s
.90511 .28299 m
.90397 .25073 L
s
.88225 .23953 m
.90397 .25073 L
s
.34662 .87516 m
.33318 .87621 L
s
.33318 .87621 m
.31903 .85475 L
s
.84635 .66758 m
.86292 .63641 L
s
.84635 .66758 m
.83113 .66144 L
s
.29035 .85772 m
.27688 .85943 L
s
.27688 .85943 m
.25845 .83678 L
s
.90393 .53873 m
.91449 .50527 L
s
.91449 .50527 m
.89741 .4964 L
s
.953 .449 .234 r
.51778 .33589 m .53605 .39696 L .53593 .35226 L F
.51778 .29357 m .51778 .33589 L .53593 .35226 L F
0 0 0 r
.77555 .75036 m
.7952 .72189 L
s
.77555 .75036 m
.76078 .74591 L
s
.2 .63 .79 r
2 Mabswid
.57712 .86549 m
.57717 .86415 L
s
0 0 0 r
.5 Mabswid
.5357 .87552 m
.54719 .85393 L
s
.5357 .87552 m
.52169 .87455 L
s
.86292 .63641 m
.87809 .60445 L
s
.86292 .63641 m
.84723 .62972 L
s
.89178 .57184 m
.90393 .53873 L
s
.90393 .53873 m
.88713 .53039 L
s
.91859 .394 m
.92235 .36025 L
s
.92235 .36025 m
.90263 .34972 L
s
.614 .3 .153 r
.5633 .6311 m .57153 .70678 L .57111 .65388 L F
.56295 .58042 m .5633 .6311 L .57111 .65388 L F
0 0 0 r
.87809 .60445 m
.89178 .57184 L
s
.87809 .60445 m
.86198 .59721 L
s
.89178 .57184 m
.8753 .56405 L
s
.36044 .87425 m
.34662 .87516 L
s
.34662 .87516 m
.33414 .85351 L
s
.365 .18 .084 r
.57617 .7845 m .57664 .84041 L .57723 .86369 L F
.2 .63 .79 r
2 Mabswid
.57717 .86415 m
.57721 .86289 L
s
.57721 .86289 m
.57744 .85637 L
s
0 0 0 r
.5 Mabswid
.56261 .87786 m
.57706 .85722 L
s
.57706 .85722 m
.57744 .85669 L
s
.59181 .85831 m
.60799 .83548 L
s
.59181 .85831 m
.57744 .85669 L
s
.6378 .83974 m
.65642 .81571 L
s
.6378 .83974 m
.62324 .83753 L
s
.904 .429 .222 r
.53618 .44227 m .55128 .50969 L .55104 .46202 L F
.53605 .39696 m .53618 .44227 L .55104 .46202 L F
0 0 0 r
.52169 .87455 m
.53143 .8528 L
s
.52169 .87455 m
.50738 .87374 L
s
.30442 .85615 m
.29035 .85772 L
s
.29035 .85772 m
.27333 .83479 L
s
.37459 .87349 m
.36044 .87425 L
s
.36044 .87425 m
.34969 .85244 L
s
.74092 .77352 m
.76078 .74591 L
s
.74092 .77352 m
.72578 .76969 L
s
.7952 .72189 m
.81376 .6922 L
s
.7952 .72189 m
.7797 .71695 L
s
.25845 .83678 m
.2443 .83893 L
s
.2443 .83893 m
.22497 .81478 L
s
.90467 .31604 m
.90511 .28299 L
s
.90511 .28299 m
.88333 .27208 L
s
.91317 .42804 m
.91859 .394 L
s
.91859 .394 m
.89898 .3839 L
s
.67146 .81841 m
.69079 .79303 L
s
.67146 .81841 m
.65642 .81571 L
s
.50738 .87374 m
.51533 .85184 L
s
.50738 .87374 m
.49284 .87308 L
s
.956 .45 .236 r
.49637 .27942 m .51778 .33589 L .51778 .29357 L F
.49651 .23954 m .49637 .27942 L .51778 .29357 L F
0 0 0 r
.70603 .79627 m
.72578 .76969 L
s
.70603 .79627 m
.69079 .79303 L
s
.38901 .87288 m
.37459 .87349 L
s
.37459 .87349 m
.36562 .85154 L
s
.57744 .85669 m
.59209 .83361 L
s
.57705 .85665 m
.57744 .85669 L
s
.56255 .85523 m
.57705 .85665 L
s
.499 .246 .122 r
.57195 .76051 m .57664 .84041 L .57617 .7845 L F
.57153 .70678 m .57195 .76051 L .57617 .7845 L F
.2 .63 .79 r
2 Mabswid
.57716 .84691 m
.57744 .85637 L
s
.784 .376 .194 r
.55153 .55804 m .5633 .6311 L .56295 .58042 L F
.55128 .50969 m .55153 .55804 L .56295 .58042 L F
0 0 0 r
.5 Mabswid
.49284 .87308 m
.49894 .85106 L
s
.49284 .87308 m
.4781 .87257 L
s
.40365 .87243 m
.38901 .87288 L
s
.38901 .87288 m
.38187 .85083 L
s
.31903 .85475 m
.30442 .85615 L
s
.30442 .85615 m
.2889 .83298 L
s
.81376 .6922 m
.83113 .66144 L
s
.81376 .6922 m
.79759 .68676 L
s
.62324 .83753 m
.64054 .81317 L
s
.62324 .83753 m
.60799 .83548 L
s
.4781 .87257 m
.48233 .85047 L
s
.4781 .87257 m
.46324 .87223 L
s
.90611 .46223 m
.91317 .42804 L
s
.91317 .42804 m
.89372 .4184 L
s
.953 .449 .234 r
.51778 .37878 m .53618 .44227 L .53605 .39696 L F
.51778 .33589 m .51778 .37878 L .53605 .39696 L F
0 0 0 r
.41845 .87214 m
.40365 .87243 L
s
.40365 .87243 m
.39837 .8503 L
s
.46324 .87223 m
.46557 .85005 L
s
.46324 .87223 m
.4483 .87204 L
s
.43335 .87201 m
.41845 .87214 L
s
.41845 .87214 m
.41506 .84995 L
s
.76078 .74591 m
.7797 .71695 L
s
.76078 .74591 m
.74476 .74163 L
s
.27333 .83479 m
.25845 .83678 L
s
.25845 .83678 m
.24041 .81231 L
s
.4483 .87204 m
.44873 .84983 L
s
.4483 .87204 m
.43335 .87201 L
s
.43335 .87201 m
.43187 .8498 L
s
.56255 .85523 m
.54719 .85393 L
s
.90263 .34972 m
.90467 .31604 L
s
.90467 .31604 m
.88289 .30546 L
s
.83113 .66144 m
.84723 .62972 L
s
.83113 .66144 m
.81436 .65548 L
s
.89741 .4964 m
.90611 .46223 L
s
.90611 .46223 m
.88686 .45308 L
s
.33414 .85351 m
.31903 .85475 L
s
.31903 .85475 m
.30509 .83135 L
s
.614 .3 .153 r
.56364 .68254 m .57195 .76051 L .57153 .70678 L F
.5633 .6311 m .56364 .68254 L .57153 .70678 L F
.933 .439 .233 r
.47206 .22812 m .49637 .27942 L .49651 .23954 L F
0 0 0 r
.88333 .27208 m
.88225 .23953 L
s
.85856 .22875 m
.88225 .23953 L
s
.65642 .81571 m
.67457 .78996 L
s
.65642 .81571 m
.64054 .81317 L
s
.904 .429 .222 r
.53631 .48823 m .55153 .55804 L .55128 .50969 L F
.53618 .44227 m .53631 .48823 L .55128 .50969 L F
0 0 0 r
.84723 .62972 m
.86198 .59721 L
s
.84723 .62972 m
.82991 .62323 L
s
.72578 .76969 m
.74476 .74163 L
s
.72578 .76969 m
.70951 .76604 L
s
.2 .63 .79 r
2 Mabswid
.57667 .84141 m
.57716 .84691 L
s
0 0 0 r
.5 Mabswid
.88713 .53039 m
.89741 .4964 L
s
.89741 .4964 m
.87844 .48777 L
s
.60799 .83548 m
.62388 .81082 L
s
.60799 .83548 m
.59209 .83361 L
s
.69079 .79303 m
.70951 .76604 L
s
.69079 .79303 m
.67457 .78996 L
s
.54719 .85393 m
.55857 .8304 L
s
.54719 .85393 m
.53143 .8528 L
s
.86198 .59721 m
.8753 .56405 L
s
.86198 .59721 m
.84416 .59018 L
s
.8753 .56405 m
.88713 .53039 L
s
.88713 .53039 m
.86848 .52229 L
s
.24041 .81231 m
.22497 .81478 L
s
.22497 .81478 m
.20617 .78891 L
s
.8753 .56405 m
.85704 .55648 L
s
.956 .45 .236 r
.49624 .31981 m .51778 .37878 L .51778 .33589 L F
.49637 .27942 m .49624 .31981 L .51778 .33589 L F
0 0 0 r
.7797 .71695 m
.79759 .68676 L
s
.7797 .71695 m
.76286 .7122 L
s
.34969 .85244 m
.33414 .85351 L
s
.33414 .85351 m
.32184 .8299 L
s
.89898 .3839 m
.90263 .34972 L
s
.90263 .34972 m
.88091 .33953 L
s
.2889 .83298 m
.27333 .83479 L
s
.27333 .83479 m
.25666 .81003 L
s
.53143 .8528 m
.54108 .82908 L
s
.53143 .8528 m
.51533 .85184 L
s
.784 .376 .194 r
.55178 .60711 m .56364 .68254 L .5633 .6311 L F
.55153 .55804 m .55178 .60711 L .5633 .6311 L F
.499 .246 .122 r
.57195 .76051 m .57238 .81509 L .57664 .84041 L F
.2 .63 .79 r
2 Mabswid
.57651 .83961 m
.57667 .84141 L
s
.57629 .83711 m
.57651 .83961 L
s
0 0 0 r
.5 Mabswid
.56255 .85523 m
.57527 .83249 L
s
.57527 .83249 m
.57559 .83191 L
s
.36562 .85154 m
.34969 .85244 L
s
.34969 .85244 m
.33909 .82866 L
s
.953 .449 .234 r
.51778 .42225 m .53631 .48823 L .53618 .44227 L F
.51778 .37878 m .51778 .42225 L .53618 .44227 L F
0 0 0 r
.59209 .83361 m
.60649 .80867 L
s
.57559 .83191 m
.59209 .83361 L
s
.88289 .30546 m
.88333 .27208 L
s
.88333 .27208 m
.85958 .26158 L
s
.64054 .81317 m
.65743 .78708 L
s
.64054 .81317 m
.62388 .81082 L
s
.79759 .68676 m
.81436 .65548 L
s
.79759 .68676 m
.77999 .68152 L
s
.74476 .74163 m
.76286 .7122 L
s
.74476 .74163 m
.72751 .73755 L
s
.89372 .4184 m
.89898 .3839 L
s
.89898 .3839 m
.87738 .37412 L
s
.2 .63 .79 r
2 Mabswid
.5748 .82697 m
.57629 .83711 L
s
0 0 0 r
.5 Mabswid
.51533 .85184 m
.5232 .82796 L
s
.51533 .85184 m
.49894 .85106 L
s
.30509 .83135 m
.2889 .83298 L
s
.2889 .83298 m
.27368 .80794 L
s
.38187 .85083 m
.36562 .85154 L
s
.36562 .85154 m
.35678 .82762 L
s
.933 .439 .233 r
.47179 .26594 m .49624 .31981 L .49637 .27942 L F
.47206 .22812 m .47179 .26594 L .49637 .27942 L F
0 0 0 r
.25666 .81003 m
.24041 .81231 L
s
.24041 .81231 m
.22284 .7861 L
s
.67457 .78996 m
.69217 .76258 L
s
.67457 .78996 m
.65743 .78708 L
s
.70951 .76604 m
.72751 .73755 L
s
.70951 .76604 m
.69217 .76258 L
s
.49894 .85106 m
.50499 .82706 L
s
.49894 .85106 m
.48233 .85047 L
s
.39837 .8503 m
.38187 .85083 L
s
.38187 .85083 m
.37483 .82678 L
s
.614 .3 .153 r
.56399 .73478 m .57238 .81509 L .57195 .76051 L F
.56364 .68254 m .56399 .73478 L .57195 .76051 L F
.904 .429 .222 r
.53644 .53482 m .55178 .60711 L .55153 .55804 L F
.53631 .48823 m .53644 .53482 L .55153 .55804 L F
0 0 0 r
.81436 .65548 m
.82991 .62323 L
s
.81436 .65548 m
.79605 .64973 L
s
.88686 .45308 m
.89372 .4184 L
s
.89372 .4184 m
.87231 .40908 L
s
.57559 .83191 m
.58843 .80671 L
s
.57516 .83187 m
.57559 .83191 L
s
.55857 .8304 m
.57516 .83187 L
s
.48233 .85047 m
.48653 .82636 L
s
.48233 .85047 m
.46557 .85005 L
s
.41506 .84995 m
.39837 .8503 L
s
.39837 .8503 m
.39317 .82617 L
s
.22284 .7861 m
.20617 .78891 L
s
.20617 .78891 m
.188 .76139 L
s
.956 .45 .236 r
.4961 .36071 m .51778 .42225 L .51778 .37878 L F
.49624 .31981 m .4961 .36071 L .51778 .37878 L F
0 0 0 r
.88091 .33953 m
.88289 .30546 L
s
.88289 .30546 m
.85914 .29529 L
s
.32184 .8299 m
.30509 .83135 L
s
.30509 .83135 m
.29141 .80607 L
s
.46557 .85005 m
.4679 .82588 L
s
.46557 .85005 m
.44873 .84983 L
s
.62388 .81082 m
.6394 .7844 L
s
.62388 .81082 m
.60649 .80867 L
s
.43187 .8498 m
.41506 .84995 L
s
.41506 .84995 m
.41173 .82577 L
s
.44873 .84983 m
.44917 .82562 L
s
.44873 .84983 m
.43187 .8498 L
s
.76286 .7122 m
.77999 .68152 L
s
.76286 .7122 m
.7447 .70766 L
s
.43187 .8498 m
.43042 .82559 L
s
.82991 .62323 m
.84416 .59018 L
s
.82991 .62323 m
.81096 .61697 L
s
.85958 .26158 m
.85856 .22875 L
s
.83297 .21848 m
.85856 .22875 L
s
.87844 .48777 m
.88686 .45308 L
s
.88686 .45308 m
.86571 .44424 L
s
.899 .423 .226 r
.44469 .21773 m .47179 .26594 L .47206 .22812 L F
.2 .63 .79 r
2 Mabswid
.5727 .81651 m
.5748 .82697 L
s
0 0 0 r
.5 Mabswid
.27368 .80794 m
.25666 .81003 L
s
.25666 .81003 m
.24043 .7835 L
s
.55857 .8304 m
.54108 .82908 L
s
.84416 .59018 m
.85704 .55648 L
s
.84416 .59018 m
.82464 .5834 L
s
.86848 .52229 m
.87844 .48777 L
s
.87844 .48777 m
.8576 .47942 L
s
.784 .376 .194 r
.55203 .6569 m .56399 .73478 L .56364 .68254 L F
.55178 .60711 m .55203 .6569 L .56364 .68254 L F
0 0 0 r
.85704 .55648 m
.86848 .52229 L
s
.85704 .55648 m
.83702 .54917 L
s
.86848 .52229 m
.84802 .51445 L
s
.953 .449 .234 r
.51778 .46629 m .53644 .53482 L .53631 .48823 L F
.51778 .42225 m .51778 .46629 L .53631 .48823 L F
0 0 0 r
.33909 .82866 m
.32184 .8299 L
s
.32184 .8299 m
.30977 .8044 L
s
.65743 .78708 m
.6738 .75933 L
s
.65743 .78708 m
.6394 .7844 L
s
.72751 .73755 m
.7447 .70766 L
s
.72751 .73755 m
.7091 .73367 L
s
.87738 .37412 m
.88091 .33953 L
s
.88091 .33953 m
.85723 .32972 L
s
.933 .439 .233 r
.47151 .3042 m .4961 .36071 L .49624 .31981 L F
.47179 .26594 m .47151 .3042 L .49624 .31981 L F
0 0 0 r
.69217 .76258 m
.7091 .73367 L
s
.69217 .76258 m
.6738 .75933 L
s
.77999 .68152 m
.79605 .64973 L
s
.77999 .68152 m
.76098 .67651 L
s
.60649 .80867 m
.62057 .78194 L
s
.60649 .80867 m
.58843 .80671 L
s
.54108 .82908 m
.5506 .80345 L
s
.54108 .82908 m
.5232 .82796 L
s
.24043 .7835 m
.22284 .7861 L
s
.22284 .7861 m
.20586 .75822 L
s
.35678 .82762 m
.33909 .82866 L
s
.33909 .82866 m
.3287 .80297 L
s
.29141 .80607 m
.27368 .80794 L
s
.27368 .80794 m
.25886 .78112 L
s
.85914 .29529 m
.85958 .26158 L
s
.85958 .26158 m
.83391 .25157 L
s
.20586 .75822 m
.188 .76139 L
s
.188 .76139 m
.17056 .73234 L
s
.2 .63 .79 r
2 Mabswid
.57244 .81547 m
.5727 .81651 L
s
.904 .429 .222 r
.53657 .58208 m .55203 .6569 L .55178 .60711 L F
.53644 .53482 m .53657 .58208 L .55178 .60711 L F
.956 .45 .236 r
.49596 .40213 m .51778 .46629 L .51778 .42225 L F
.4961 .36071 m .49596 .40213 L .51778 .42225 L F
0 0 0 r
.5 Mabswid
.87231 .40908 m
.87738 .37412 L
s
.87738 .37412 m
.85384 .36472 L
s
.5232 .82796 m
.53097 .80217 L
s
.5232 .82796 m
.50499 .82706 L
s
.614 .3 .153 r
.56399 .73478 m .56435 .78782 L .57238 .81509 L F
.2 .63 .79 r
2 Mabswid
.57216 .81436 m
.57244 .81547 L
s
.56999 .80573 m
.57216 .81436 L
s
0 0 0 r
.5 Mabswid
.55857 .8304 m
.5695 .80561 L
s
.5695 .80561 m
.56978 .80497 L
s
.79605 .64973 m
.81096 .61697 L
s
.79605 .64973 m
.77626 .64423 L
s
.899 .423 .226 r
.44428 .2533 m .47151 .3042 L .47179 .26594 L F
.44469 .21773 m .44428 .2533 L .47179 .26594 L F
0 0 0 r
.37483 .82678 m
.35678 .82762 L
s
.35678 .82762 m
.34811 .80177 L
s
.6394 .7844 m
.65447 .7563 L
s
.6394 .7844 m
.62057 .78194 L
s
.7447 .70766 m
.76098 .67651 L
s
.7447 .70766 m
.72528 .70335 L
s
.58843 .80671 m
.60099 .77971 L
s
.56978 .80497 m
.58843 .80671 L
s
.50499 .82706 m
.51098 .80112 L
s
.50499 .82706 m
.48653 .82636 L
s
.39317 .82617 m
.37483 .82678 L
s
.37483 .82678 m
.36793 .80081 L
s
.30977 .8044 m
.29141 .80607 L
s
.29141 .80607 m
.27808 .77898 L
s
.86571 .44424 m
.87231 .40908 L
s
.87231 .40908 m
.84899 .40012 L
s
.81096 .61697 m
.82464 .5834 L
s
.81096 .61697 m
.79045 .61097 L
s
.25886 .78112 m
.24043 .7835 L
s
.24043 .7835 m
.22472 .75528 L
s
.6738 .75933 m
.68957 .73003 L
s
.6738 .75933 m
.65447 .7563 L
s
.7091 .73367 m
.72528 .70335 L
s
.7091 .73367 m
.68957 .73003 L
s
.48653 .82636 m
.4907 .80032 L
s
.48653 .82636 m
.4679 .82588 L
s
.85723 .32972 m
.85914 .29529 L
s
.85914 .29529 m
.83347 .28559 L
s
.953 .449 .234 r
.51778 .51093 m .53657 .58208 L .53644 .53482 L F
.51778 .46629 m .51778 .51093 L .53644 .53482 L F
0 0 0 r
.83391 .25157 m
.83297 .21848 L
s
.80555 .20877 m
.83297 .21848 L
s
.933 .439 .233 r
.47123 .34293 m .49596 .40213 L .4961 .36071 L F
.47151 .3042 m .47123 .34293 L .4961 .36071 L F
0 0 0 r
.41173 .82577 m
.39317 .82617 L
s
.39317 .82617 m
.38808 .8001 L
s
.784 .376 .194 r
.55228 .70744 m .56435 .78782 L .56399 .73478 L F
.55203 .6569 m .55228 .70744 L .56399 .73478 L F
.859 .405 .219 r
.4147 .20853 m .44428 .2533 L .44469 .21773 L F
0 0 0 r
.4679 .82588 m
.47022 .79977 L
s
.4679 .82588 m
.44917 .82562 L
s
.2 .63 .79 r
2 Mabswid
.56665 .79463 m
.56999 .80573 L
s
0 0 0 r
.5 Mabswid
.8576 .47942 m
.86571 .44424 L
s
.86571 .44424 m
.84267 .43574 L
s
.43042 .82559 m
.41173 .82577 L
s
.41173 .82577 m
.40847 .79964 L
s
.82464 .5834 m
.83702 .54917 L
s
.82464 .5834 m
.80349 .57689 L
s
.56978 .80497 m
.58075 .77773 L
s
.56929 .80493 m
.56978 .80497 L
s
.5506 .80345 m
.56929 .80493 L
s
.44917 .82562 m
.44963 .79947 L
s
.44917 .82562 m
.43042 .82559 L
s
.43042 .82559 m
.42902 .79943 L
s
.22472 .75528 m
.20586 .75822 L
s
.20586 .75822 m
.18954 .72879 L
s
.76098 .67651 m
.77626 .64423 L
s
.76098 .67651 m
.74062 .67175 L
s
.18954 .72879 m
.17056 .73234 L
s
.17056 .73234 m
.15395 .70187 L
s
.84802 .51445 m
.8576 .47942 L
s
.8576 .47942 m
.83492 .4714 L
s
.83702 .54917 m
.84802 .51445 L
s
.83702 .54917 m
.81528 .54215 L
s
.3287 .80297 m
.30977 .8044 L
s
.30977 .8044 m
.298 .77708 L
s
.62057 .78194 m
.63425 .75352 L
s
.62057 .78194 m
.60099 .77971 L
s
.84802 .51445 m
.82578 .50693 L
s
.402 .197 .117 r
.04921 .21495 m .0734 .23805 L .07362 .23484 L F
.04921 .21495 m .07362 .23484 L .07385 .23164 L F
.04921 .21495 m .07385 .23164 L .07407 .22844 L F
.04921 .21495 m .07407 .22844 L .07429 .22524 L F
.04921 .21495 m .07429 .22524 L .07452 .22205 L F
.04921 .21495 m .07452 .22205 L .07474 .21886 L F
.04921 .21495 m .07474 .21886 L .07496 .21567 L F
.04921 .21495 m .07496 .21567 L .07518 .21249 L F
.04921 .21495 m .07518 .21249 L .07541 .20931 L F
.04921 .21495 m .07541 .20931 L .07563 .20613 L F
.2 .63 .79 r
2 Mabswid
.04921 .21495 m
.05863 .22407 L
s
0 0 0 r
.5 Mabswid
.04751 .24813 m
.04921 .21495 L
s
.956 .45 .236 r
.49582 .44408 m .51778 .51093 L .51778 .46629 L F
.49596 .40213 m .49582 .44408 L .51778 .46629 L F
.899 .423 .226 r
.44386 .28927 m .47123 .34293 L .47151 .3042 L F
.44428 .2533 m .44386 .28927 L .47151 .3042 L F
0 0 0 r
.85384 .36472 m
.85723 .32972 L
s
.85723 .32972 m
.83165 .32038 L
s
.27808 .77898 m
.25886 .78112 L
s
.25886 .78112 m
.24451 .75259 L
s
.904 .429 .222 r
.53671 .63001 m .55228 .70744 L .55203 .6569 L F
.53657 .58208 m .53671 .63001 L .55203 .6569 L F
0 0 0 r
.5506 .80345 m
.53097 .80217 L
s
.72528 .70335 m
.74062 .67175 L
s
.72528 .70335 m
.70466 .6993 L
s
.65447 .7563 m
.669 .72664 L
s
.65447 .7563 m
.63425 .75352 L
s
.34811 .80177 m
.3287 .80297 L
s
.3287 .80297 m
.31855 .77544 L
s
.83347 .28559 m
.83391 .25157 L
s
.83391 .25157 m
.8064 .24211 L
s
.77626 .64423 m
.79045 .61097 L
s
.77626 .64423 m
.75503 .639 L
s
.2 .63 .79 r
2 Mabswid
.5647 .789 m
.56665 .79463 L
s
0 0 0 r
.5 Mabswid
.68957 .73003 m
.70466 .6993 L
s
.68957 .73003 m
.669 .72664 L
s
.60099 .77971 m
.61321 .751 L
s
.60099 .77971 m
.58075 .77773 L
s
.53097 .80217 m
.53859 .77453 L
s
.53097 .80217 m
.51098 .80112 L
s
.859 .405 .219 r
.41416 .2417 m .44386 .28927 L .44428 .2533 L F
.4147 .20853 m .41416 .2417 L .44428 .2533 L F
0 0 0 r
.84899 .40012 m
.85384 .36472 L
s
.85384 .36472 m
.82842 .35576 L
s
.24451 .75259 m
.22472 .75528 L
s
.22472 .75528 m
.20962 .72549 L
s
.933 .439 .233 r
.47095 .38213 m .49582 .44408 L .49596 .40213 L F
.47123 .34293 m .47095 .38213 L .49596 .40213 L F
0 0 0 r
.17399 .69791 m
.15395 .70187 L
s
.15395 .70187 m
.13825 .67011 L
s
.36793 .80081 m
.34811 .80177 L
s
.34811 .80177 m
.33965 .77407 L
s
.953 .449 .234 r
.51778 .55619 m .53671 .63001 L .53657 .58208 L F
.51778 .51093 m .51778 .55619 L .53657 .58208 L F
0 0 0 r
.298 .77708 m
.27808 .77898 L
s
.27808 .77898 m
.26516 .75017 L
s
.20962 .72549 m
.18954 .72879 L
s
.18954 .72879 m
.17399 .69791 L
s
.79045 .61097 m
.80349 .57689 L
s
.79045 .61097 m
.76843 .60526 L
s
.04727 .28226 m
.04751 .24813 L
s
.784 .376 .194 r
.55228 .70744 m .55254 .75873 L .56435 .78782 L F
.2 .63 .79 r
2 Mabswid
.56392 .78677 m
.5647 .789 L
s
.56269 .78322 m
.56392 .78677 L
s
0 0 0 r
.5 Mabswid
.5506 .80345 m
.55969 .77668 L
s
.55969 .77668 m
.55992 .776 L
s
.51098 .80112 m
.51685 .77333 L
s
.51098 .80112 m
.4907 .80032 L
s
.2 .63 .79 r
2 Mabswid
.05863 .22407 m
.06858 .23353 L
s
0 0 0 r
.5 Mabswid
.8064 .24211 m
.80555 .20877 L
s
.77638 .19969 m
.80555 .20877 L
s
.84267 .43574 m
.84899 .40012 L
s
.84899 .40012 m
.82381 .39158 L
s
.38808 .8001 m
.36793 .80081 L
s
.36793 .80081 m
.36121 .77298 L
s
.818 .386 .21 r
.38249 .2007 m .41416 .2417 L .4147 .20853 L F
0 0 0 r
.74062 .67175 m
.75503 .639 L
s
.74062 .67175 m
.71897 .66726 L
s
.83165 .32038 m
.83347 .28559 L
s
.83347 .28559 m
.80597 .27643 L
s
.63425 .75352 m
.64745 .72352 L
s
.63425 .75352 m
.61321 .751 L
s
.899 .423 .226 r
.44344 .32566 m .47095 .38213 L .47123 .34293 L F
.44386 .28927 m .44344 .32566 L .47123 .34293 L F
0 0 0 r
.80349 .57689 m
.81528 .54215 L
s
.80349 .57689 m
.78074 .5707 L
s
.58075 .77773 m
.59143 .74876 L
s
.55992 .776 m
.58075 .77773 L
s
.4907 .80032 m
.49479 .77242 L
s
.4907 .80032 m
.47022 .79977 L
s
.2 .63 .79 r
2 Mabswid
.55811 .77152 m
.56269 .78322 L
s
0 0 0 r
.5 Mabswid
.40847 .79964 m
.38808 .8001 L
s
.38808 .8001 m
.38312 .77216 L
s
.83492 .4714 m
.84267 .43574 L
s
.84267 .43574 m
.81782 .42764 L
s
.956 .45 .236 r
.49568 .48658 m .51778 .55619 L .51778 .51093 L F
.49582 .44408 m .49568 .48658 L .51778 .51093 L F
0 0 0 r
.47022 .79977 m
.47251 .77179 L
s
.47022 .79977 m
.44963 .79947 L
s
.31855 .77544 m
.298 .77708 L
s
.298 .77708 m
.2866 .74802 L
s
.81528 .54215 m
.82578 .50693 L
s
.81528 .54215 m
.79189 .53548 L
s
.70466 .6993 m
.71897 .66726 L
s
.70466 .6993 m
.68291 .69552 L
s
.42902 .79943 m
.40847 .79964 L
s
.40847 .79964 m
.40531 .77163 L
s
.445 .217 .128 r
.07563 .20613 m .10442 .20511 L .10483 .19872 L F
0 0 0 r
.04921 .21495 m
.06998 .20756 L
s
.445 .217 .128 r
.07563 .20613 m .07541 .20931 L .10442 .20511 L F
0 0 0 r
.26516 .75017 m
.24451 .75259 L
s
.24451 .75259 m
.23071 .72247 L
s
.669 .72664 m
.68291 .69552 L
s
.669 .72664 m
.64745 .72352 L
s
.82578 .50693 m
.83492 .4714 L
s
.83492 .4714 m
.81048 .46376 L
s
.44963 .79947 m
.4501 .77145 L
s
.44963 .79947 m
.42902 .79943 L
s
.15929 .66574 m
.13825 .67011 L
s
.13825 .67011 m
.12357 .63721 L
s
.904 .429 .222 r
.53684 .67864 m .55254 .75873 L .55228 .70744 L F
.53671 .63001 m .53684 .67864 L .55228 .70744 L F
0 0 0 r
.42902 .79943 m
.42767 .77139 L
s
.82578 .50693 m
.80182 .49977 L
s
.445 .217 .128 r
.07541 .20931 m .104 .2115 L .10442 .20511 L F
0 0 0 r
.06998 .20756 m
.07591 .20545 L
s
.445 .217 .128 r
.07541 .20931 m .07518 .21249 L .104 .2115 L F
.07518 .21249 m .10358 .21791 L .104 .2115 L F
.07518 .21249 m .07496 .21567 L .10358 .21791 L F
.859 .405 .219 r
.41362 .27522 m .44344 .32566 L .44386 .28927 L F
.41416 .2417 m .41362 .27522 L .44386 .28927 L F
0 0 0 r
.07403 .2733 m
.04727 .28226 L
s
.04849 .31716 m
.04727 .28226 L
s
.75503 .639 m
.76843 .60526 L
s
.75503 .639 m
.73243 .63407 L
s
.445 .217 .128 r
.07496 .21567 m .10316 .22433 L .10358 .21791 L F
.07496 .21567 m .07474 .21886 L .10316 .22433 L F
0 0 0 r
.55992 .776 m
.569 .7468 L
s
.55939 .77596 m
.55992 .776 L
s
.53859 .77453 m
.55939 .77596 L
s
.82842 .35576 m
.83165 .32038 L
s
.83165 .32038 m
.80423 .31154 L
s
.23071 .72247 m
.20962 .72549 L
s
.20962 .72549 m
.19521 .69424 L
s
.19521 .69424 m
.17399 .69791 L
s
.17399 .69791 m
.15929 .66574 L
s
.445 .217 .128 r
.07474 .21886 m .10274 .23077 L .10316 .22433 L F
.07474 .21886 m .07452 .22205 L .10274 .23077 L F
.933 .439 .233 r
.47067 .4218 m .49568 .48658 L .49582 .44408 L F
.47095 .38213 m .47067 .4218 L .49582 .44408 L F
.445 .217 .128 r
.07452 .22205 m .10232 .23722 L .10274 .23077 L F
.07452 .22205 m .07429 .22524 L .10232 .23722 L F
0 0 0 r
.80597 .27643 m
.8064 .24211 L
s
.8064 .24211 m
.77714 .23326 L
s
.33965 .77407 m
.31855 .77544 L
s
.31855 .77544 m
.30873 .74617 L
s
.61321 .751 m
.625 .72069 L
s
.61321 .751 m
.59143 .74876 L
s
.2 .63 .79 r
2 Mabswid
.06858 .23353 m
.07242 .23712 L
s
.07242 .23712 m
.07252 .23721 L
s
.445 .217 .128 r
.07429 .22524 m .1019 .24368 L .10232 .23722 L F
.07429 .22524 m .07407 .22844 L .1019 .24368 L F
.818 .386 .21 r
.38184 .23131 m .41362 .27522 L .41416 .2417 L F
.38249 .2007 m .38184 .23131 L .41416 .2417 L F
.2 .63 .79 r
.55291 .75954 m
.55811 .77152 L
s
.953 .449 .234 r
.51778 .60206 m .53684 .67864 L .53671 .63001 L F
.51778 .55619 m .51778 .60206 L .53671 .63001 L F
.445 .217 .128 r
.07407 .22844 m .10148 .25015 L .1019 .24368 L F
.07407 .22844 m .07385 .23164 L .10148 .25015 L F
0 0 0 r
.5 Mabswid
.14554 .6324 m
.12357 .63721 L
s
.12357 .63721 m
.10998 .6033 L
s
.445 .217 .128 r
.07385 .23164 m .10105 .25664 L .10148 .25015 L F
.07385 .23164 m .07362 .23484 L .10105 .25664 L F
0 0 0 r
.2866 .74802 m
.26516 .75017 L
s
.26516 .75017 m
.25274 .71975 L
s
.53859 .77453 m
.51685 .77333 L
s
.76843 .60526 m
.78074 .5707 L
s
.76843 .60526 m
.74495 .59989 L
s
.71897 .66726 m
.73243 .63407 L
s
.71897 .66726 m
.69611 .66309 L
s
.82381 .39158 m
.82842 .35576 L
s
.82842 .35576 m
.80119 .3473 L
s
.445 .217 .128 r
.07362 .23484 m .10063 .26314 L .10105 .25664 L F
.07362 .23484 m .0734 .23805 L .10063 .26314 L F
0 0 0 r
.0744 .23664 m
.07591 .20545 L
s
.07429 .23888 m
.0744 .23664 L
s
.2 .63 .79 r
2 Mabswid
.07453 .23909 m
.07904 .24331 L
s
0 0 0 r
.5 Mabswid
.07394 .239 m
.07429 .23888 L
s
.04751 .24813 m
.07394 .239 L
s
.899 .423 .226 r
.44302 .36246 m .47067 .4218 L .47095 .38213 L F
.44344 .32566 m .44302 .36246 L .47095 .38213 L F
.776 .368 .202 r
.34849 .19439 m .38184 .23131 L .38249 .2007 L F
0 0 0 r
.07516 .30853 m
.04849 .31716 L
s
.05118 .35268 m
.04849 .31716 L
s
.36121 .77298 m
.33965 .77407 L
s
.33965 .77407 m
.33146 .74461 L
s
.64745 .72352 m
.66009 .69204 L
s
.64745 .72352 m
.625 .72069 L
s
.07429 .2396 m
.07429 .23888 L
s
.07403 .2733 m
.07429 .2396 L
s
.77714 .23326 m
.77638 .19969 L
s
.74558 .19129 m
.77638 .19969 L
s
.68291 .69552 m
.69611 .66309 L
s
.68291 .69552 m
.66009 .69204 L
s
.956 .45 .236 r
.49554 .52963 m .51778 .60206 L .51778 .55619 L F
.49568 .48658 m .49554 .52963 L .51778 .55619 L F
0 0 0 r
.51685 .77333 m
.52259 .74378 L
s
.51685 .77333 m
.49479 .77242 L
s
.59143 .74876 m
.60175 .71816 L
s
.59143 .74876 m
.569 .7468 L
s
.488 .237 .138 r
.10483 .19872 m .13585 .20247 L .13643 .19287 L F
.10483 .19872 m .10442 .20511 L .13585 .20247 L F
0 0 0 r
.78074 .5707 m
.79189 .53548 L
s
.78074 .5707 m
.75647 .56486 L
s
.81782 .42764 m
.82381 .39158 L
s
.82381 .39158 m
.79685 .38351 L
s
.1816 .66167 m
.15929 .66574 L
s
.15929 .66574 m
.14554 .6324 L
s
.25274 .71975 m
.23071 .72247 L
s
.23071 .72247 m
.21754 .69088 L
s
.80423 .31154 m
.80597 .27643 L
s
.80597 .27643 m
.77671 .26785 L
s
.859 .405 .219 r
.41307 .30909 m .44302 .36246 L .44344 .32566 L F
.41362 .27522 m .41307 .30909 L .44344 .32566 L F
0 0 0 r
.38312 .77216 m
.36121 .77298 L
s
.36121 .77298 m
.35469 .74337 L
s
.1328 .59805 m
.10998 .6033 L
s
.10998 .6033 m
.09758 .56857 L
s
.488 .237 .138 r
.10442 .20511 m .13527 .21209 L .13585 .20247 L F
.10442 .20511 m .104 .2115 L .13527 .21209 L F
0 0 0 r
.08687 .20205 m
.10441 .19661 L
s
.07591 .20545 m
.08687 .20205 L
s
.2 .63 .79 r
2 Mabswid
.55263 .75895 m
.55291 .75954 L
s
0 0 0 r
.5 Mabswid
.21754 .69088 m
.19521 .69424 L
s
.19521 .69424 m
.1816 .66167 L
s
.30873 .74617 m
.2866 .74802 L
s
.2866 .74802 m
.27563 .71734 L
s
.07768 .34441 m
.05118 .35268 L
s
.05536 .38864 m
.05118 .35268 L
s
.2 .63 .79 r
2 Mabswid
.07904 .24331 m
.08999 .25342 L
s
.904 .429 .222 r
.53684 .67864 m .53698 .72796 L .55254 .75873 L F
.2 .63 .79 r
.5523 .75825 m
.55263 .75895 L
s
.54709 .74728 m
.5523 .75825 L
s
0 0 0 r
.5 Mabswid
.53859 .77453 m
.54584 .74586 L
s
.54584 .74586 m
.54602 .74513 L
s
.49479 .77242 m
.4988 .74274 L
s
.49479 .77242 m
.47251 .77179 L
s
.79189 .53548 m
.80182 .49977 L
s
.79189 .53548 m
.76691 .52918 L
s
.81048 .46376 m
.81782 .42764 L
s
.81782 .42764 m
.79122 .41999 L
s
.40531 .77163 m
.38312 .77216 L
s
.38312 .77216 m
.37833 .74245 L
s
.10441 .19661 m
.13461 .18847 L
s
.73243 .63407 m
.74495 .59989 L
s
.73243 .63407 m
.70854 .62948 L
s
.818 .386 .21 r
.38118 .26222 m .41307 .30909 L .41362 .27522 L F
.38184 .23131 m .38118 .26222 L .41362 .27522 L F
.488 .237 .138 r
.104 .2115 m .13469 .22175 L .13527 .21209 L F
.104 .2115 m .10358 .21791 L .13469 .22175 L F
.933 .439 .233 r
.47038 .46196 m .49554 .52963 L .49568 .48658 L F
.47067 .4218 m .47038 .46196 L .49568 .48658 L F
0 0 0 r
.80182 .49977 m
.81048 .46376 L
s
.80182 .49977 m
.77621 .49301 L
s
.81048 .46376 m
.78433 .45655 L
s
.47251 .77179 m
.47477 .74203 L
s
.47251 .77179 m
.4501 .77145 L
s
.42767 .77139 m
.40531 .77163 L
s
.40531 .77163 m
.40226 .74185 L
s
.12117 .56287 m
.09758 .56857 L
s
.09758 .56857 m
.08641 .53318 L
s
.488 .237 .138 r
.10358 .21791 m .13411 .23143 L .13469 .22175 L F
.10358 .21791 m .10316 .22433 L .13411 .23143 L F
0 0 0 r
.4501 .77145 m
.45059 .74164 L
s
.4501 .77145 m
.42767 .77139 L
s
.625 .72069 m
.63631 .68889 L
s
.625 .72069 m
.60175 .71816 L
s
.776 .368 .202 r
.34775 .22229 m .38118 .26222 L .38184 .23131 L F
.34849 .19439 m .34775 .22229 L .38184 .23131 L F
0 0 0 r
.42767 .77139 m
.42639 .74158 L
s
.569 .7468 m
.57779 .71596 L
s
.54602 .74513 m
.569 .7468 L
s
.07516 .30853 m
.07403 .2733 L
s
.08158 .38075 m
.05536 .38864 L
s
.061 .42485 m
.05536 .38864 L
s
.734 .349 .193 r
.3132 .18971 m .34775 .22229 L .34849 .19439 L F
0 0 0 r
.80119 .3473 m
.80423 .31154 L
s
.80423 .31154 m
.77508 .30328 L
s
.488 .237 .138 r
.10316 .22433 m .13352 .24115 L .13411 .23143 L F
.10316 .22433 m .10274 .23077 L .13352 .24115 L F
0 0 0 r
.10288 .23026 m
.10441 .19661 L
s
.07429 .23888 m
.08952 .23429 L
s
.77671 .26785 m
.77714 .23326 L
s
.77714 .23326 m
.74624 .22508 L
s
.953 .449 .234 r
.51778 .64856 m .53698 .72796 L .53684 .67864 L F
.51778 .60206 m .51778 .64856 L .53684 .67864 L F
0 0 0 r
.69611 .66309 m
.70854 .62948 L
s
.69611 .66309 m
.67211 .65924 L
s
.33146 .74461 m
.30873 .74617 L
s
.30873 .74617 m
.29927 .71525 L
s
.16885 .62793 m
.14554 .6324 L
s
.14554 .6324 m
.1328 .59805 L
s
.899 .423 .226 r
.44259 .39967 m .47038 .46196 L .47067 .4218 L F
.44302 .36246 m .44259 .39967 L .47067 .4218 L F
0 0 0 r
.1107 .52702 m
.08641 .53318 L
s
.08641 .53318 m
.07656 .49731 L
s
.66009 .69204 m
.67211 .65924 L
s
.66009 .69204 m
.63631 .68889 L
s
.27563 .71734 m
.25274 .71975 L
s
.25274 .71975 m
.24089 .68784 L
s
.08686 .41737 m
.061 .42485 L
s
.06808 .46114 m
.061 .42485 L
s
.53 .256 .148 r
.13643 .19287 m .16928 .20148 L .16998 .18868 L F
.13643 .19287 m .13585 .20247 L .16928 .20148 L F
.488 .237 .138 r
.10274 .23077 m .13293 .25089 L .13352 .24115 L F
.10274 .23077 m .10232 .23722 L .13293 .25089 L F
0 0 0 r
.08952 .23429 m
.10288 .23026 L
s
.74495 .59989 m
.75647 .56486 L
s
.74495 .59989 m
.72011 .59487 L
s
.10146 .4907 m
.07656 .49731 L
s
.07656 .49731 m
.06808 .46114 L
s
.2 .63 .79 r
2 Mabswid
.54066 .73475 m
.54709 .74728 L
s
0 0 0 r
.5 Mabswid
.0935 .45409 m
.06808 .46114 L
s
.54602 .74513 m
.55322 .71409 L
s
.54544 .7451 m
.54602 .74513 L
s
.52259 .74378 m
.54544 .7451 L
s
.2 .63 .79 r
2 Mabswid
.08999 .25342 m
.10019 .26274 L
s
.10019 .26274 m
.10026 .2628 L
s
.859 .405 .219 r
.41251 .34332 m .44259 .39967 L .44302 .36246 L F
.41307 .30909 m .41251 .34332 L .44302 .36246 L F
.488 .237 .138 r
.10232 .23722 m .13234 .26067 L .13293 .25089 L F
.10232 .23722 m .1019 .24368 L .13234 .26067 L F
0 0 0 r
.5 Mabswid
.20509 .65795 m
.1816 .66167 L
s
.1816 .66167 m
.16885 .62793 L
s
.24089 .68784 m
.21754 .69088 L
s
.21754 .69088 m
.20509 .65795 L
s
.74624 .22508 m
.74558 .19129 L
s
.71326 .18364 m
.74558 .19129 L
s
.956 .45 .236 r
.49539 .57324 m .51778 .64856 L .51778 .60206 L F
.49554 .52963 m .49539 .57324 L .51778 .60206 L F
0 0 0 r
.79685 .38351 m
.80119 .3473 L
s
.80119 .3473 m
.77224 .33938 L
s
.53 .256 .148 r
.13585 .20247 m .16857 .21433 L .16928 .20148 L F
.13585 .20247 m .13527 .21209 L .16857 .21433 L F
0 0 0 r
.10363 .30048 m
.07516 .30853 L
s
.07768 .34441 m
.07516 .30853 L
s
.10288 .23026 m
.13317 .22234 L
s
.35469 .74337 m
.33146 .74461 L
s
.33146 .74461 m
.32358 .71351 L
s
.60175 .71816 m
.61166 .68607 L
s
.60175 .71816 m
.57779 .71596 L
s
.488 .237 .138 r
.1019 .24368 m .13175 .27047 L .13234 .26067 L F
.1019 .24368 m .10148 .25015 L .13175 .27047 L F
.818 .386 .21 r
.38051 .29342 m .41251 .34332 L .41307 .30909 L F
.38118 .26222 m .38051 .29342 L .41307 .30909 L F
0 0 0 r
.15705 .59317 m
.1328 .59805 L
s
.1328 .59805 m
.12117 .56287 L
s
.75647 .56486 m
.76691 .52918 L
s
.75647 .56486 m
.73076 .55941 L
s
.734 .349 .193 r
.3132 .18971 m .31239 .21478 L .34775 .22229 L F
.693 .33 .184 r
.27715 .18676 m .31239 .21478 L .3132 .18971 L F
.776 .368 .202 r
.34699 .25044 m .38051 .29342 L .38118 .26222 L F
.34775 .22229 m .34699 .25044 L .38118 .26222 L F
.53 .256 .148 r
.13527 .21209 m .16786 .22724 L .16857 .21433 L F
.13527 .21209 m .13469 .22175 L .16786 .22724 L F
.488 .237 .138 r
.10148 .25015 m .13116 .28031 L .13175 .27047 L F
.10148 .25015 m .10105 .25664 L .13116 .28031 L F
0 0 0 r
.52259 .74378 m
.4988 .74274 L
s
.734 .349 .193 r
.31239 .21478 m .34699 .25044 L .34775 .22229 L F
0 0 0 r
.77508 .30328 m
.77671 .26785 L
s
.77671 .26785 m
.74581 .25992 L
s
.70854 .62948 m
.72011 .59487 L
s
.70854 .62948 m
.68343 .62525 L
s
.29927 .71525 m
.27563 .71734 L
s
.27563 .71734 m
.26516 .68515 L
s
.79122 .41999 m
.79685 .38351 L
s
.79685 .38351 m
.76819 .37596 L
s
.933 .439 .233 r
.47009 .50262 m .49539 .57324 L .49554 .52963 L F
.47038 .46196 m .47009 .50262 L .49554 .52963 L F
.571 .275 .157 r
.16998 .18868 m .20418 .20221 L .20498 .18624 L F
.16998 .18868 m .16928 .20148 L .20418 .20221 L F
0 0 0 r
.37833 .74245 m
.35469 .74337 L
s
.35469 .74337 m
.34843 .71211 L
s
.13461 .18847 m
.16638 .1811 L
s
.488 .237 .138 r
.10105 .25664 m .13056 .29017 L .13116 .28031 L F
.10105 .25664 m .10063 .26314 L .13056 .29017 L F
0 0 0 r
.07403 .2733 m
.10209 .2651 L
s
.10209 .2651 m
.10261 .26494 L
s
.10261 .26494 m
.10288 .23026 L
s
.2 .63 .79 r
2 Mabswid
.10085 .26334 m
.1014 .26385 L
s
0 0 0 r
.5 Mabswid
.63631 .68889 m
.64707 .65574 L
s
.63631 .68889 m
.61166 .68607 L
s
.76691 .52918 m
.77621 .49301 L
s
.76691 .52918 m
.74042 .52329 L
s
.2 .63 .79 r
2 Mabswid
.53764 .72927 m
.54066 .73475 L
s
0 0 0 r
.5 Mabswid
.10595 .33669 m
.07768 .34441 L
s
.08158 .38075 m
.07768 .34441 L
s
.53 .256 .148 r
.13469 .22175 m .16714 .24019 L .16786 .22724 L F
.13469 .22175 m .13411 .23143 L .16714 .24019 L F
0 0 0 r
.13317 .22234 m
.13461 .18847 L
s
.67211 .65924 m
.68343 .62525 L
s
.67211 .65924 m
.64707 .65574 L
s
.4988 .74274 m
.5027 .7114 L
s
.4988 .74274 m
.47477 .74203 L
s
.78433 .45655 m
.79122 .41999 L
s
.79122 .41999 m
.76296 .41283 L
s
.14626 .55757 m
.12117 .56287 L
s
.12117 .56287 m
.1107 .52702 L
s
.77621 .49301 m
.78433 .45655 L
s
.77621 .49301 m
.74904 .48669 L
s
.693 .33 .184 r
.27715 .18676 m .27631 .20888 L .31239 .21478 L F
.653 .312 .175 r
.24088 .18559 m .27631 .20888 L .27715 .18676 L F
0 0 0 r
.40226 .74185 m
.37833 .74245 L
s
.37833 .74245 m
.37373 .71107 L
s
.78433 .45655 m
.75657 .44981 L
s
.19343 .62383 m
.16885 .62793 L
s
.16885 .62793 m
.15705 .59317 L
s
.899 .423 .226 r
.44216 .43732 m .47009 .50262 L .47038 .46196 L F
.44259 .39967 m .44216 .43732 L .47038 .46196 L F
.2 .63 .79 r
2 Mabswid
.1014 .26385 m
.11326 .2746 L
s
0 0 0 r
.5 Mabswid
.57779 .71596 m
.58623 .68361 L
s
.57779 .71596 m
.55322 .71409 L
s
.571 .275 .157 r
.16928 .20148 m .20339 .21826 L .20418 .20221 L F
.16928 .20148 m .16857 .21433 L .20339 .21826 L F
.612 .293 .166 r
.20498 .18624 m .24005 .20468 L .24088 .18559 L F
.20498 .18624 m .20418 .20221 L .24005 .20468 L F
0 0 0 r
.26516 .68515 m
.24089 .68784 L
s
.24089 .68784 m
.22967 .65458 L
s
.10261 .26494 m
.10264 .26581 L
s
.10264 .26581 m
.10363 .30048 L
s
.47477 .74203 m
.47697 .7106 L
s
.47477 .74203 m
.45059 .74164 L
s
.53 .256 .148 r
.13411 .23143 m .16643 .2532 L .16714 .24019 L F
.13411 .23143 m .13352 .24115 L .16643 .2532 L F
0 0 0 r
.42639 .74158 m
.40226 .74185 L
s
.40226 .74185 m
.39935 .7104 L
s
.953 .449 .234 r
.51778 .64856 m .51778 .69572 L .53698 .72796 L F
.2 .63 .79 r
2 Mabswid
.53622 .72669 m
.53763 .72926 L
s
.53362 .72197 m
.53622 .72669 L
s
0 0 0 r
.5 Mabswid
.52259 .74378 m
.52802 .71334 L
s
.52802 .71334 m
.52816 .71257 L
s
.653 .312 .175 r
.24088 .18559 m .24005 .20468 L .27631 .20888 L F
0 0 0 r
.74581 .25992 m
.74624 .22508 L
s
.74624 .22508 m
.71381 .21763 L
s
.10956 .3734 m
.08158 .38075 L
s
.08686 .41737 m
.08158 .38075 L
s
.22967 .65458 m
.20509 .65795 L
s
.20509 .65795 m
.19343 .62383 L
s
.32358 .71351 m
.29927 .71525 L
s
.29927 .71525 m
.29025 .68283 L
s
.45059 .74164 m
.45109 .71016 L
s
.45059 .74164 m
.42639 .74158 L
s
.77224 .33938 m
.77508 .30328 L
s
.77508 .30328 m
.74429 .29564 L
s
.72011 .59487 m
.73076 .55941 L
s
.72011 .59487 m
.69398 .59024 L
s
.42639 .74158 m
.42518 .71009 L
s
.859 .405 .219 r
.41195 .37792 m .44216 .43732 L .44259 .39967 L F
.41251 .34332 m .41195 .37792 L .44259 .39967 L F
.734 .349 .193 r
.31239 .21478 m .31157 .24005 L .34699 .25044 L F
.693 .33 .184 r
.27631 .20888 m .31157 .24005 L .31239 .21478 L F
0 0 0 r
.13655 .5213 m
.1107 .52702 L
s
.1107 .52702 m
.10146 .4907 L
s
.818 .386 .21 r
.37984 .32494 m .41195 .37792 L .41251 .34332 L F
.38051 .29342 m .37984 .32494 L .41251 .34332 L F
.776 .368 .202 r
.34699 .25044 m .34623 .27885 L .38051 .29342 L F
.734 .349 .193 r
.31157 .24005 m .34623 .27885 L .34699 .25044 L F
0 0 0 r
.11445 .41041 m
.08686 .41737 L
s
.0935 .45409 m
.08686 .41737 L
s
.53 .256 .148 r
.13352 .24115 m .16571 .26626 L .16643 .2532 L F
.13352 .24115 m .13293 .25089 L .16571 .26626 L F
.571 .275 .157 r
.16857 .21433 m .20259 .23439 L .20339 .21826 L F
.16857 .21433 m .16786 .22724 L .20259 .23439 L F
0 0 0 r
.12798 .48455 m
.10146 .4907 L
s
.10146 .4907 m
.0935 .45409 L
s
.776 .368 .202 r
.34623 .27885 m .37984 .32494 L .38051 .29342 L F
0 0 0 r
.71381 .21763 m
.71326 .18364 L
s
.67957 .17678 m
.71326 .18364 L
s
.2 .63 .79 r
2 Mabswid
.52599 .70896 m
.53362 .72197 L
s
0 0 0 r
.5 Mabswid
.1206 .44753 m
.0935 .45409 L
s
.612 .293 .166 r
.20418 .20221 m .23921 .22388 L .24005 .20468 L F
.20418 .20221 m .20339 .21826 L .23921 .22388 L F
.956 .45 .236 r
.49525 .61742 m .51778 .69572 L .51778 .64856 L F
.49539 .57324 m .49525 .61742 L .51778 .64856 L F
0 0 0 r
.55322 .71409 m
.56015 .68153 L
s
.52816 .71257 m
.55322 .71409 L
s
.61166 .68607 m
.62109 .65262 L
s
.61166 .68607 m
.58623 .68361 L
s
.13317 .22234 m
.16504 .21515 L
s
.693 .33 .184 r
.27631 .20888 m .27546 .23116 L .31157 .24005 L F
.653 .312 .175 r
.24005 .20468 m .27546 .23116 L .27631 .20888 L F
0 0 0 r
.18262 .58869 m
.15705 .59317 L
s
.15705 .59317 m
.14626 .55757 L
s
.68343 .62525 m
.69398 .59024 L
s
.68343 .62525 m
.65721 .6214 L
s
.53 .256 .148 r
.13293 .25089 m .16499 .27938 L .16571 .26626 L F
.13293 .25089 m .13234 .26067 L .16499 .27938 L F
0 0 0 r
.13289 .25726 m
.13317 .22234 L
s
.10261 .26494 m
.11464 .26189 L
s
.34843 .71211 m
.32358 .71351 L
s
.32358 .71351 m
.31605 .68087 L
s
.653 .312 .175 r
.24005 .20468 m .23921 .22388 L .27546 .23116 L F
0 0 0 r
.10595 .33669 m
.10363 .30048 L
s
.76819 .37596 m
.77224 .33938 L
s
.77224 .33938 m
.74167 .33206 L
s
.73076 .55941 m
.74042 .52329 L
s
.73076 .55941 m
.7037 .55438 L
s
.64707 .65574 m
.65721 .6214 L
s
.64707 .65574 m
.62109 .65262 L
s
.2 .63 .79 r
2 Mabswid
.11326 .2746 m
.12554 .28566 L
s
.571 .275 .157 r
.16786 .22724 m .20179 .2506 L .20259 .23439 L F
.16786 .22724 m .16714 .24019 L .20179 .2506 L F
0 0 0 r
.5 Mabswid
.29025 .68283 m
.26516 .68515 L
s
.26516 .68515 m
.25525 .6516 L
s
.16638 .1811 m
.19959 .17454 L
s
.16504 .21515 m
.16638 .1811 L
s
.933 .439 .233 r
.46979 .54378 m .49525 .61742 L .49539 .57324 L F
.47009 .50262 m .46979 .54378 L .49539 .57324 L F
0 0 0 r
.74429 .29564 m
.74581 .25992 L
s
.74581 .25992 m
.71339 .2527 L
s
.734 .349 .193 r
.31157 .24005 m .31075 .26552 L .34623 .27885 L F
.693 .33 .184 r
.27546 .23116 m .31075 .26552 L .31157 .24005 L F
.53 .256 .148 r
.13234 .26067 m .16426 .29255 L .16499 .27938 L F
.13234 .26067 m .13175 .27047 L .16426 .29255 L F
0 0 0 r
.11464 .26189 m
.13289 .25726 L
s
.52816 .71257 m
.53352 .67983 L
s
.52753 .71254 m
.52816 .71257 L
s
.5027 .7114 m
.52753 .71254 L
s
.612 .293 .166 r
.20339 .21826 m .23836 .24319 L .23921 .22388 L F
.20339 .21826 m .20259 .23439 L .23836 .24319 L F
0 0 0 r
.21917 .62013 m
.19343 .62383 L
s
.19343 .62383 m
.18262 .58869 L
s
.25525 .6516 m
.22967 .65458 L
s
.22967 .65458 m
.21917 .62013 L
s
.76296 .41283 m
.76819 .37596 L
s
.76819 .37596 m
.73795 .36898 L
s
.74042 .52329 m
.74904 .48669 L
s
.74042 .52329 m
.71252 .51786 L
s
.37373 .71107 m
.34843 .71211 L
s
.34843 .71211 m
.34246 .67931 L
s
.899 .423 .226 r
.44172 .47541 m .46979 .54378 L .47009 .50262 L F
.44216 .43732 m .44172 .47541 L .47009 .50262 L F
0 0 0 r
.17275 .5527 m
.14626 .55757 L
s
.14626 .55757 m
.13655 .5213 L
s
.571 .275 .157 r
.16714 .24019 m .20098 .2669 L .20179 .2506 L F
.16714 .24019 m .16643 .2532 L .20098 .2669 L F
0 0 0 r
.1359 .3296 m
.10595 .33669 L
s
.10956 .3734 m
.10595 .33669 L
s
.776 .368 .202 r
.34623 .27885 m .34547 .3075 L .37984 .32494 L F
.734 .349 .193 r
.31075 .26552 m .34547 .3075 L .34623 .27885 L F
0 0 0 r
.58623 .68361 m
.59428 .6499 L
s
.58623 .68361 m
.56015 .68153 L
s
.53 .256 .148 r
.13175 .27047 m .16353 .30577 L .16426 .29255 L F
.13175 .27047 m .13116 .28031 L .16353 .30577 L F
.693 .33 .184 r
.27546 .23116 m .2746 .2536 L .31075 .26552 L F
.653 .312 .175 r
.23921 .22388 m .2746 .2536 L .27546 .23116 L F
.23921 .22388 m .23836 .24319 L .2746 .2536 L F
0 0 0 r
.75657 .44981 m
.76296 .41283 L
s
.76296 .41283 m
.73315 .40622 L
s
.74904 .48669 m
.75657 .44981 L
s
.74904 .48669 m
.7204 .48086 L
s
.859 .405 .219 r
.41138 .41289 m .44172 .47541 L .44216 .43732 L F
.41195 .37792 m .41138 .41289 L .44216 .43732 L F
0 0 0 r
.5027 .7114 m
.47697 .7106 L
s
.818 .386 .21 r
.37984 .32494 m .37916 .35676 L .41195 .37792 L F
.776 .368 .202 r
.34547 .3075 m .37916 .35676 L .37984 .32494 L F
0 0 0 r
.69398 .59024 m
.7037 .55438 L
s
.69398 .59024 m
.66667 .58603 L
s
.75657 .44981 m
.72729 .44358 L
s
.818 .386 .21 r
.37916 .35676 m .41138 .41289 L .41195 .37792 L F
0 0 0 r
.71339 .2527 m
.71381 .21763 L
s
.71381 .21763 m
.68001 .21095 L
s
.13289 .25726 m
.16475 .2503 L
s
.39935 .7104 m
.37373 .71107 L
s
.37373 .71107 m
.36934 .67815 L
s
.31605 .68087 m
.29025 .68283 L
s
.29025 .68283 m
.28171 .64902 L
s
.612 .293 .166 r
.20259 .23439 m .23751 .26263 L .23836 .24319 L F
.20259 .23439 m .20179 .2506 L .23751 .26263 L F
0 0 0 r
.16387 .51604 m
.13655 .5213 L
s
.13655 .5213 m
.12798 .48455 L
s
.2 .63 .79 r
2 Mabswid
.12554 .28566 m
.12946 .28918 L
s
.12946 .28918 m
.12979 .28947 L
s
0 0 0 r
.5 Mabswid
.68001 .21095 m
.67957 .17678 L
s
.64465 .17078 m
.67957 .17678 L
s
.53 .256 .148 r
.13116 .28031 m .1628 .31905 L .16353 .30577 L F
.13116 .28031 m .13056 .29017 L .1628 .31905 L F
0 0 0 r
.10363 .30048 m
.13317 .29323 L
s
.13317 .29323 m
.1338 .29308 L
s
.13289 .25726 m
.1338 .29308 L
s
.2 .63 .79 r
2 Mabswid
.13194 .2914 m
.13821 .29703 L
s
.571 .275 .157 r
.16643 .2532 m .20017 .28328 L .20098 .2669 L F
.16643 .2532 m .16571 .26626 L .20017 .28328 L F
0 0 0 r
.5 Mabswid
.47697 .7106 m
.47911 .67762 L
s
.47697 .7106 m
.45109 .71016 L
s
.74167 .33206 m
.74429 .29564 L
s
.74429 .29564 m
.71199 .28868 L
s
.13919 .36664 m
.10956 .3734 L
s
.11445 .41041 m
.10956 .3734 L
s
.62109 .65262 m
.62999 .61797 L
s
.62109 .65262 m
.59428 .6499 L
s
.42518 .71009 m
.39935 .7104 L
s
.39935 .7104 m
.39658 .6774 L
s
.65721 .6214 m
.66667 .58603 L
s
.65721 .6214 m
.62999 .61797 L
s
.45109 .71016 m
.4516 .67713 L
s
.45109 .71016 m
.42518 .71009 L
s
.42518 .71009 m
.42404 .67706 L
s
.734 .349 .193 r
.31075 .26552 m .30992 .2912 L .34547 .3075 L F
.693 .33 .184 r
.2746 .2536 m .30992 .2912 L .31075 .26552 L F
0 0 0 r
.20944 .58464 m
.18262 .58869 L
s
.18262 .58869 m
.17275 .5527 L
s
.15603 .4789 m
.12798 .48455 L
s
.12798 .48455 m
.1206 .44753 L
s
.14365 .40401 m
.11445 .41041 L
s
.1206 .44753 m
.11445 .41041 L
s
.19836 .20877 m
.16504 .21515 L
s
.16475 .2503 m
.16504 .21515 L
s
.56015 .68153 m
.56675 .64758 L
s
.53352 .67983 m
.56015 .68153 L
s
.956 .45 .236 r
.49525 .61742 m .4951 .6622 L .51778 .69572 L F
.2 .63 .79 r
2 Mabswid
.50899 .68227 m
.51778 .69572 L
s
0 0 0 r
.5 Mabswid
.5027 .7114 m
.50637 .67934 L
s
.50637 .67934 m
.50646 .67852 L
s
.2 .63 .79 r
2 Mabswid
.51778 .69572 m
.52599 .70896 L
s
0 0 0 r
.5 Mabswid
.14928 .44149 m
.1206 .44753 L
s
.653 .312 .175 r
.23836 .24319 m .27374 .2762 L .2746 .2536 L F
.23836 .24319 m .23751 .26263 L .27374 .2762 L F
0 0 0 r
.28171 .64902 m
.25525 .6516 L
s
.25525 .6516 m
.24597 .61684 L
s
.7037 .55438 m
.71252 .51786 L
s
.7037 .55438 m
.67539 .54981 L
s
.19959 .17454 m
.23409 .16886 L
s
.19836 .20877 m
.19959 .17454 L
s
.693 .33 .184 r
.2746 .2536 m .27374 .2762 L .30992 .2912 L F
.571 .275 .157 r
.16571 .26626 m .19935 .29974 L .20017 .28328 L F
.16571 .26626 m .16499 .27938 L .19935 .29974 L F
.612 .293 .166 r
.20179 .2506 m .23665 .28218 L .23751 .26263 L F
.20179 .2506 m .20098 .2669 L .23665 .28218 L F
0 0 0 r
.24597 .61684 m
.21917 .62013 L
s
.21917 .62013 m
.20944 .58464 L
s
.34246 .67931 m
.31605 .68087 L
s
.31605 .68087 m
.30894 .64686 L
s
.1338 .29308 m
.1437 .29099 L
s
.1338 .29308 m
.13385 .294 L
s
.13385 .294 m
.1359 .3296 L
s
.776 .368 .202 r
.34547 .3075 m .34469 .33641 L .37916 .35676 L F
.734 .349 .193 r
.30992 .2912 m .34469 .33641 L .34547 .3075 L F
0 0 0 r
.73795 .36898 m
.74167 .33206 L
s
.74167 .33206 m
.7096 .32539 L
s
.933 .439 .233 r
.46949 .58546 m .4951 .6622 L .49525 .61742 L F
.46979 .54378 m .46949 .58546 L .49525 .61742 L F
0 0 0 r
.71199 .28868 m
.71339 .2527 L
s
.71339 .2527 m
.67959 .24623 L
s
.2 .63 .79 r
2 Mabswid
.13821 .29703 m
.15124 .3087 L
s
.818 .386 .21 r
.37916 .35676 m .37847 .3889 L .41138 .41289 L F
.776 .368 .202 r
.34469 .33641 m .37847 .3889 L .37916 .35676 L F
0 0 0 r
.5 Mabswid
.53352 .67983 m
.53864 .64569 L
s
.50646 .67852 m
.53352 .67983 L
s
.899 .423 .226 r
.44127 .51394 m .46949 .58546 L .46979 .54378 L F
.44172 .47541 m .44127 .51394 L .46979 .54378 L F
0 0 0 r
.20054 .54829 m
.17275 .5527 L
s
.17275 .5527 m
.16387 .51604 L
s
.71252 .51786 m
.7204 .48086 L
s
.71252 .51786 m
.68332 .51292 L
s
.571 .275 .157 r
.16499 .27938 m .19854 .31629 L .19935 .29974 L F
.16499 .27938 m .16426 .29255 L .19854 .31629 L F
0 0 0 r
.1437 .29099 m
.16554 .28637 L
s
.59428 .6499 m
.60188 .61496 L
s
.59428 .6499 m
.56675 .64758 L
s
.66667 .58603 m
.67539 .54981 L
s
.66667 .58603 m
.6383 .58227 L
s
.859 .405 .219 r
.41138 .41289 m .4108 .44824 L .44172 .47541 L F
.818 .386 .21 r
.37847 .3889 m .4108 .44824 L .41138 .41289 L F
.859 .405 .219 r
.4108 .44824 m .44127 .51394 L .44172 .47541 L F
0 0 0 r
.73315 .40622 m
.73795 .36898 L
s
.73795 .36898 m
.70623 .36263 L
s
.653 .312 .175 r
.23751 .26263 m .27287 .29895 L .27374 .2762 L F
.23751 .26263 m .23665 .28218 L .27287 .29895 L F
.612 .293 .166 r
.20098 .2669 m .23579 .30185 L .23665 .28218 L F
.20098 .2669 m .20017 .28328 L .23579 .30185 L F
0 0 0 r
.36934 .67815 m
.34246 .67931 L
s
.34246 .67931 m
.33682 .64513 L
s
.734 .349 .193 r
.30992 .2912 m .30908 .31708 L .34469 .33641 L F
.693 .33 .184 r
.27374 .2762 m .30908 .31708 L .30992 .2912 L F
.2 .63 .79 r
2 Mabswid
.49964 .66862 m
.50899 .68227 L
s
0 0 0 r
.5 Mabswid
.67959 .24623 m
.68001 .21095 L
s
.68001 .21095 m
.64497 .2051 L
s
.64497 .2051 m
.64465 .17078 L
s
.60869 .16568 m
.64465 .17078 L
s
.13919 .36664 m
.1359 .3296 L
s
.62999 .61797 m
.6383 .58227 L
s
.62999 .61797 m
.60188 .61496 L
s
.7204 .48086 m
.72729 .44358 L
s
.7204 .48086 m
.69041 .47555 L
s
.30894 .64686 m
.28171 .64902 L
s
.28171 .64902 m
.27372 .614 L
s
.19806 .24411 m
.16475 .2503 L
s
.16475 .2503 m
.16554 .28637 L
s
.693 .33 .184 r
.27374 .2762 m .27287 .29895 L .30908 .31708 L F
0 0 0 r
.72729 .44358 m
.73315 .40622 L
s
.73315 .40622 m
.70189 .4002 L
s
.50646 .67852 m
.51007 .64425 L
s
.50579 .6785 m
.50646 .67852 L
s
.47911 .67762 m
.50579 .6785 L
s
.72729 .44358 m
.69661 .43791 L
s
.571 .275 .157 r
.16426 .29255 m .19771 .33292 L .19854 .31629 L F
.16426 .29255 m .16353 .30577 L .19771 .33292 L F
0 0 0 r
.19254 .51128 m
.16387 .51604 L
s
.16387 .51604 m
.15603 .4789 L
s
.23737 .58104 m
.20944 .58464 L
s
.20944 .58464 m
.20054 .54829 L
s
.39658 .6774 m
.36934 .67815 L
s
.36934 .67815 m
.36521 .64384 L
s
.7096 .32539 m
.71199 .28868 L
s
.71199 .28868 m
.67832 .28245 L
s
.27372 .614 m
.24597 .61684 L
s
.24597 .61684 m
.23737 .58104 L
s
.23409 .16886 m
.26971 .16408 L
s
.23297 .20323 m
.23409 .16886 L
s
.23297 .20323 m
.19836 .20877 L
s
.19806 .24411 m
.19836 .20877 L
s
.17035 .36052 m
.13919 .36664 L
s
.14365 .40401 m
.13919 .36664 L
s
.47911 .67762 m
.4516 .67713 L
s
.776 .368 .202 r
.34469 .33641 m .34391 .36559 L .37847 .3889 L F
.734 .349 .193 r
.30908 .31708 m .34391 .36559 L .34469 .33641 L F
.612 .293 .166 r
.20017 .28328 m .23492 .32165 L .23579 .30185 L F
.20017 .28328 m .19935 .29974 L .23492 .32165 L F
.2 .63 .79 r
2 Mabswid
.15124 .3087 m
.16192 .31827 L
s
0 0 0 r
.5 Mabswid
.56675 .64758 m
.573 .61241 L
s
.56675 .64758 m
.53864 .64569 L
s
.42404 .67706 m
.39658 .6774 L
s
.39658 .6774 m
.39398 .643 L
s
.67539 .54981 m
.68332 .51292 L
s
.67539 .54981 m
.64596 .54572 L
s
.18548 .47379 m
.15603 .4789 L
s
.15603 .4789 m
.14928 .44149 L
s
.653 .312 .175 r
.23665 .28218 m .272 .32187 L .27287 .29895 L F
.23665 .28218 m .23579 .30185 L .272 .32187 L F
0 0 0 r
.4516 .67713 m
.45211 .64271 L
s
.4516 .67713 m
.42404 .67706 L
s
.17435 .39821 m
.14365 .40401 L
s
.14928 .44149 m
.14365 .40401 L
s
.42404 .67706 m
.423 .64263 L
s
.2 .63 .79 r
2 Mabswid
.49601 .66354 m
.49964 .66862 L
s
0 0 0 r
.5 Mabswid
.17941 .43603 m
.14928 .44149 L
s
.571 .275 .157 r
.16353 .30577 m .19688 .34964 L .19771 .33292 L F
.16353 .30577 m .1628 .31905 L .19688 .34964 L F
0 0 0 r
.1359 .3296 m
.1667 .32332 L
s
.1667 .32332 m
.16741 .32317 L
s
.2 .63 .79 r
2 Mabswid
.1633 .3195 m
.1646 .32066 L
s
.16192 .31827 m
.16294 .31918 L
s
0 0 0 r
.5 Mabswid
.33682 .64513 m
.30894 .64686 L
s
.30894 .64686 m
.30229 .61162 L
s
.16554 .28637 m
.19872 .28041 L
s
.16554 .28637 m
.16741 .32317 L
s
.818 .386 .21 r
.37847 .3889 m .37777 .42136 L .4108 .44824 L F
.776 .368 .202 r
.34391 .36559 m .37777 .42136 L .37847 .3889 L F
.734 .349 .193 r
.30908 .31708 m .30824 .34318 L .34391 .36559 L F
.693 .33 .184 r
.27287 .29895 m .30824 .34318 L .30908 .31708 L F
0 0 0 r
.67832 .28245 m
.67959 .24623 L
s
.67959 .24623 m
.64457 .24056 L
s
.693 .33 .184 r
.27287 .29895 m .272 .32187 L .30824 .34318 L F
0 0 0 r
.70623 .36263 m
.7096 .32539 L
s
.7096 .32539 m
.67618 .31942 L
s
.60188 .61496 m
.60898 .57899 L
s
.60188 .61496 m
.573 .61241 L
s
.6383 .58227 m
.64596 .54572 L
s
.6383 .58227 m
.60898 .57899 L
s
.60888 .20013 m
.60869 .16568 L
s
.57184 .16151 m
.60869 .16568 L
s
.22952 .54438 m
.20054 .54829 L
s
.20054 .54829 m
.19254 .51128 L
s
.933 .439 .233 r
.46949 .58546 m .46919 .62766 L .4951 .6622 L F
.2 .63 .79 r
2 Mabswid
.49401 .66075 m
.49599 .66352 L
s
.48976 .65481 m
.49401 .66075 L
s
0 0 0 r
.5 Mabswid
.47911 .67762 m
.48113 .6441 L
s
.48113 .6441 m
.48118 .64325 L
s
.612 .293 .166 r
.19935 .29974 m .23405 .34156 L .23492 .32165 L F
.19935 .29974 m .19854 .31629 L .23405 .34156 L F
.859 .405 .219 r
.4108 .44824 m .41022 .48397 L .44127 .51394 L F
.818 .386 .21 r
.37777 .42136 m .41022 .48397 L .4108 .44824 L F
0 0 0 r
.68332 .51292 m
.69041 .47555 L
s
.68332 .51292 m
.65294 .5085 L
s
.64457 .24056 m
.64497 .2051 L
s
.64497 .2051 m
.60888 .20013 L
s
.53864 .64569 m
.5435 .61033 L
s
.53864 .64569 m
.51007 .64425 L
s
.899 .423 .226 r
.44083 .55292 m .46919 .62766 L .46949 .58546 L F
.44127 .51394 m .44083 .55292 L .46949 .58546 L F
.859 .405 .219 r
.41022 .48397 m .44083 .55292 L .44127 .51394 L F
0 0 0 r
.30229 .61162 m
.27372 .614 L
s
.27372 .614 m
.26631 .57793 L
s
.26971 .16408 m
.30627 .16025 L
s
.26871 .19857 m
.26971 .16408 L
s
.2 .63 .79 r
2 Mabswid
.1646 .32066 m
.17826 .33291 L
s
.653 .312 .175 r
.23579 .30185 m .27112 .34495 L .272 .32187 L F
.23579 .30185 m .23492 .32165 L .27112 .34495 L F
0 0 0 r
.5 Mabswid
.36521 .64384 m
.33682 .64513 L
s
.33682 .64513 m
.33155 .60971 L
s
.26631 .57793 m
.23737 .58104 L
s
.23737 .58104 m
.22952 .54438 L
s
.70189 .4002 m
.70623 .36263 L
s
.70623 .36263 m
.67318 .35694 L
s
.23267 .23875 m
.19806 .24411 L
s
.19806 .24411 m
.19872 .28041 L
s
.2 .63 .79 r
2 Mabswid
.47935 .64083 m
.48976 .65481 L
s
0 0 0 r
.5 Mabswid
.16741 .32317 m
.17576 .32173 L
s
.16741 .32317 m
.16748 .32413 L
s
.16748 .32413 m
.17035 .36052 L
s
.69041 .47555 m
.69661 .43791 L
s
.69041 .47555 m
.65919 .4708 L
s
.26871 .19857 m
.23297 .20323 L
s
.23267 .23875 m
.23297 .20323 L
s
.776 .368 .202 r
.34391 .36559 m .34312 .39503 L .37777 .42136 L F
.734 .349 .193 r
.30824 .34318 m .34312 .39503 L .34391 .36559 L F
0 0 0 r
.22246 .50705 m
.19254 .51128 L
s
.19254 .51128 m
.18548 .47379 L
s
.69661 .43791 m
.70189 .4002 L
s
.70189 .4002 m
.66933 .39482 L
s
.69661 .43791 m
.66466 .43284 L
s
.51007 .64425 m
.5135 .60874 L
s
.48118 .64325 m
.51007 .64425 L
s
.612 .293 .166 r
.19854 .31629 m .23317 .3616 L .23405 .34156 L F
.19854 .31629 m .19771 .33292 L .23317 .3616 L F
0 0 0 r
.17576 .32173 m
.20034 .31746 L
s
.67618 .31942 m
.67832 .28245 L
s
.67832 .28245 m
.64342 .27699 L
s
.64596 .54572 m
.65294 .5085 L
s
.64596 .54572 m
.61554 .54214 L
s
.693 .33 .184 r
.272 .32187 m .30738 .36948 L .30824 .34318 L F
.272 .32187 m .27112 .34495 L .30738 .36948 L F
0 0 0 r
.573 .61241 m
.57885 .57619 L
s
.573 .61241 m
.5435 .61033 L
s
.39398 .643 m
.36521 .64384 L
s
.36521 .64384 m
.36135 .60829 L
s
.57191 .19606 m
.57184 .16151 L
s
.53432 .1583 m
.57184 .16151 L
s
.734 .349 .193 r
.30824 .34318 m .30738 .36948 L .34312 .39503 L F
0 0 0 r
.17435 .39821 m
.17035 .36052 L
s
.21623 .46925 m
.18548 .47379 L
s
.18548 .47379 m
.17941 .43603 L
s
.48118 .64325 m
.48316 .60764 L
s
.48047 .64324 m
.48118 .64325 L
s
.45211 .64271 m
.48047 .64324 L
s
.60898 .57899 m
.61554 .54214 L
s
.60898 .57899 m
.57885 .57619 L
s
.33155 .60971 m
.30229 .61162 L
s
.30229 .61162 m
.29613 .57532 L
s
.818 .386 .21 r
.37777 .42136 m .37707 .45414 L .41022 .48397 L F
.776 .368 .202 r
.34312 .39503 m .37707 .45414 L .37777 .42136 L F
.2 .63 .79 r
2 Mabswid
.17826 .33291 m
.19219 .34542 L
s
.653 .312 .175 r
.23492 .32165 m .27024 .3682 L .27112 .34495 L F
.23492 .32165 m .23405 .34156 L .27024 .3682 L F
0 0 0 r
.5 Mabswid
.423 .64263 m
.39398 .643 L
s
.39398 .643 m
.39157 .60737 L
s
.30627 .16025 m
.34358 .1574 L
s
.3054 .19484 m
.30627 .16025 L
s
.2 .63 .79 r
2 Mabswid
.4696 .6282 m
.47935 .64083 L
s
0 0 0 r
.5 Mabswid
.20643 .39305 m
.17435 .39821 L
s
.17941 .43603 m
.17435 .39821 L
s
.21087 .43118 m
.17941 .43603 L
s
.64342 .27699 m
.64457 .24056 L
s
.64457 .24056 m
.60848 .23574 L
s
.25955 .541 m
.22952 .54438 L
s
.22952 .54438 m
.22246 .50705 L
s
.45211 .64271 m
.423 .64263 L
s
.60848 .23574 m
.60888 .20013 L
s
.60888 .20013 m
.57191 .19606 L
s
.23319 .27524 m
.19872 .28041 L
s
.19872 .28041 m
.20034 .31746 L
s
.423 .64263 m
.42204 .60695 L
s
.29613 .57532 m
.26631 .57793 L
s
.26631 .57793 m
.25955 .541 L
s
.612 .293 .166 r
.19771 .33292 m .23228 .38177 L .23317 .3616 L F
.19771 .33292 m .19688 .34964 L .23228 .38177 L F
0 0 0 r
.20216 .3552 m
.20291 .35508 L
s
.17035 .36052 m
.20216 .3552 L
s
.67318 .35694 m
.67618 .31942 L
s
.67618 .31942 m
.64155 .31419 L
s
.65294 .5085 m
.65919 .4708 L
s
.65294 .5085 m
.62152 .50463 L
s
.859 .405 .219 r
.41022 .48397 m .40963 .52009 L .44083 .55292 L F
.818 .386 .21 r
.37707 .45414 m .40963 .52009 L .41022 .48397 L F
0 0 0 r
.5435 .61033 m
.54805 .57391 L
s
.5435 .61033 m
.5135 .60874 L
s
.53425 .19294 m
.53432 .1583 L
s
.49631 .15609 m
.53432 .1583 L
s
.3054 .19484 m
.26871 .19857 L
s
.2684 .23424 m
.26871 .19857 L
s
.2684 .23424 m
.23267 .23875 L
s
.23319 .27524 m
.23267 .23875 L
s
.899 .423 .226 r
.44083 .55292 m .44037 .59236 L .46919 .62766 L F
0 0 0 r
.45211 .64271 m
.45261 .60793 L
s
.45261 .60793 m
.45262 .60704 L
s
.2 .63 .79 r
2 Mabswid
.46897 .62739 m
.46959 .62819 L
s
.46844 .62671 m
.46897 .62739 L
s
.859 .405 .219 r
.40963 .52009 m .44037 .59236 L .44083 .55292 L F
.776 .368 .202 r
.34312 .39503 m .34233 .42473 L .37707 .45414 L F
.734 .349 .193 r
.30738 .36948 m .34233 .42473 L .34312 .39503 L F
.693 .33 .184 r
.27112 .34495 m .30653 .396 L .30738 .36948 L F
.27112 .34495 m .27024 .3682 L .30653 .396 L F
0 0 0 r
.5 Mabswid
.36135 .60829 m
.33155 .60971 L
s
.33155 .60971 m
.32667 .57323 L
s
.34358 .1574 m
.38145 .15555 L
s
.34284 .19206 m
.34358 .1574 L
s
.2 .63 .79 r
2 Mabswid
.45706 .61247 m
.46844 .62671 L
s
.19219 .34542 m
.19578 .34865 L
s
.19837 .35099 m
.20634 .35818 L
s
.19578 .34865 m
.19807 .35072 L
s
0 0 0 r
.5 Mabswid
.66933 .39482 m
.67318 .35694 L
s
.67318 .35694 m
.63894 .35196 L
s
.65919 .4708 m
.66466 .43284 L
s
.65919 .4708 m
.62688 .46665 L
s
.25348 .50339 m
.22246 .50705 L
s
.22246 .50705 m
.21623 .46925 L
s
.20034 .31746 m
.23454 .31251 L
s
.20034 .31746 m
.20291 .35508 L
s
.653 .312 .175 r
.23405 .34156 m .26934 .39162 L .27024 .3682 L F
.23405 .34156 m .23317 .3616 L .26934 .39162 L F
0 0 0 r
.61554 .54214 m
.62152 .50463 L
s
.61554 .54214 m
.58426 .5391 L
s
.734 .349 .193 r
.30738 .36948 m .30653 .396 L .34233 .42473 L F
0 0 0 r
.57885 .57619 m
.58426 .5391 L
s
.57885 .57619 m
.54805 .57391 L
s
.49611 .19079 m
.49631 .15609 L
s
.45802 .15489 m
.49631 .15609 L
s
.64155 .31419 m
.64342 .27699 L
s
.64342 .27699 m
.60748 .27234 L
s
.66466 .43284 m
.66933 .39482 L
s
.66933 .39482 m
.63562 .3901 L
s
.5135 .60874 m
.51673 .57217 L
s
.5135 .60874 m
.48316 .60764 L
s
.66466 .43284 m
.63159 .4284 L
s
.38145 .15555 m
.41967 .15471 L
s
.38084 .19025 m
.38145 .15555 L
s
.57152 .23181 m
.57191 .19606 L
s
.57191 .19606 m
.53425 .19294 L
s
.39157 .60737 m
.36135 .60829 L
s
.36135 .60829 m
.3578 .57167 L
s
.32667 .57323 m
.29613 .57532 L
s
.29613 .57532 m
.29051 .53815 L
s
.45769 .18961 m
.45802 .15489 L
s
.41967 .15471 m
.45802 .15489 L
s
.29051 .53815 m
.25955 .541 L
s
.25955 .541 m
.25348 .50339 L
s
.60748 .27234 m
.60848 .23574 L
s
.60848 .23574 m
.57152 .23181 L
s
.24813 .46531 m
.21623 .46925 L
s
.21623 .46925 m
.21087 .43118 L
s
.41919 .18944 m
.41967 .15471 L
s
.21006 .35408 m
.23672 .35036 L
s
.20291 .35508 m
.21006 .35408 L
s
.20291 .35508 m
.203 .35606 L
s
.203 .35606 m
.20643 .39305 L
s
.818 .386 .21 r
.37707 .45414 m .37637 .48726 L .40963 .52009 L F
.776 .368 .202 r
.34233 .42473 m .37637 .48726 L .37707 .45414 L F
0 0 0 r
.34284 .19206 m
.3054 .19484 L
s
.30507 .23062 m
.3054 .19484 L
s
.2 .63 .79 r
2 Mabswid
.44523 .59812 m
.45706 .61247 L
s
0 0 0 r
.5 Mabswid
.48316 .60764 m
.48504 .57096 L
s
.45262 .60704 m
.48316 .60764 L
s
.26877 .27089 m
.23319 .27524 L
s
.23454 .31251 m
.23319 .27524 L
s
.2 .63 .79 r
2 Mabswid
.20634 .35818 m
.22069 .37119 L
s
0 0 0 r
.5 Mabswid
.24353 .42697 m
.21087 .43118 L
s
.21087 .43118 m
.20643 .39305 L
s
.42204 .60695 m
.39157 .60737 L
s
.39157 .60737 m
.38936 .57066 L
s
.62152 .50463 m
.62688 .46665 L
s
.62152 .50463 m
.5892 .50134 L
s
.693 .33 .184 r
.27024 .3682 m .30566 .42274 L .30653 .396 L F
.27024 .3682 m .26934 .39162 L .30566 .42274 L F
0 0 0 r
.30507 .23062 m
.2684 .23424 L
s
.26877 .27089 m
.2684 .23424 L
s
.45262 .60704 m
.45314 .57031 L
s
.45188 .60704 m
.45262 .60704 L
s
.42204 .60695 m
.45188 .60704 L
s
.653 .312 .175 r
.23317 .3616 m .26845 .4152 L .26934 .39162 L F
.23317 .3616 m .23228 .38177 L .26845 .4152 L F
0 0 0 r
.23894 .38869 m
.23972 .38859 L
s
.20643 .39305 m
.23894 .38869 L
s
.63894 .35196 m
.64155 .31419 L
s
.64155 .31419 m
.60588 .30974 L
s
.54805 .57391 m
.55227 .53662 L
s
.54805 .57391 m
.51673 .57217 L
s
.53387 .22878 m
.53425 .19294 L
s
.53425 .19294 m
.49611 .19079 L
s
.859 .405 .219 r
.40963 .52009 m .40904 .55661 L .44037 .59236 L F
0 0 0 r
.42121 .57112 m
.42204 .60695 L
s
.42119 .57021 m
.42121 .57112 L
s
.818 .386 .21 r
.37637 .48726 m .40904 .55661 L .40963 .52009 L F
.776 .368 .202 r
.34233 .42473 m .34153 .45471 L .37637 .48726 L F
.734 .349 .193 r
.30653 .396 m .34153 .45471 L .34233 .42473 L F
0 0 0 r
.58426 .5391 m
.5892 .50134 L
s
.58426 .5391 m
.55227 .53662 L
s
.3578 .57167 m
.32667 .57323 L
s
.32667 .57323 m
.32223 .53588 L
s
.734 .349 .193 r
.30653 .396 m .30566 .42274 L .34153 .45471 L F
0 0 0 r
.28546 .50032 m
.25348 .50339 L
s
.25348 .50339 m
.24813 .46531 L
s
.2 .63 .79 r
2 Mabswid
.44143 .59366 m
.44523 .59812 L
s
.43297 .5837 m
.43903 .59083 L
s
.43903 .59083 m
.4414 .59362 L
s
0 0 0 r
.5 Mabswid
.38084 .19025 m
.34284 .19206 L
s
.34251 .22793 m
.34284 .19206 L
s
.2 .63 .79 r
2 Mabswid
.22069 .37119 m
.23105 .38065 L
s
.23305 .38247 m
.2352 .38443 L
s
.23105 .38065 m
.23295 .38238 L
s
0 0 0 r
.5 Mabswid
.62688 .46665 m
.63159 .4284 L
s
.62688 .46665 m
.59364 .46311 L
s
.26985 .30835 m
.23454 .31251 L
s
.23454 .31251 m
.23672 .35036 L
s
.63562 .3901 m
.63894 .35196 L
s
.63894 .35196 m
.60368 .34772 L
s
.60588 .30974 m
.60748 .27234 L
s
.60748 .27234 m
.57066 .26855 L
s
.32223 .53588 m
.29051 .53815 L
s
.29051 .53815 m
.28546 .50032 L
s
.57066 .26855 m
.57152 .23181 L
s
.57152 .23181 m
.53387 .22878 L
s
.51673 .57217 m
.51973 .53472 L
s
.51673 .57217 m
.48504 .57096 L
s
.49573 .22669 m
.49611 .19079 L
s
.49611 .19079 m
.45769 .18961 L
s
.63159 .4284 m
.63562 .3901 L
s
.63159 .4284 m
.59754 .42462 L
s
.63562 .3901 m
.6009 .38609 L
s
.41919 .18944 m
.38084 .19025 L
s
.3805 .22618 m
.38084 .19025 L
s
.38936 .57066 m
.3578 .57167 L
s
.3578 .57167 m
.35457 .53418 L
s
.28102 .46201 m
.24813 .46531 L
s
.24813 .46531 m
.24353 .42697 L
s
.34251 .22793 m
.30507 .23062 L
s
.3053 .26741 m
.30507 .23062 L
s
.2 .63 .79 r
2 Mabswid
.42031 .5692 m
.43297 .5837 L
s
0 0 0 r
.5 Mabswid
.3053 .26741 m
.26877 .27089 L
s
.26985 .30835 m
.26877 .27089 L
s
.23672 .35036 m
.27162 .3464 L
s
.23672 .35036 m
.23972 .38859 L
s
.45732 .22556 m
.45769 .18961 L
s
.45769 .18961 m
.41919 .18944 L
s
.693 .33 .184 r
.26934 .39162 m .30479 .44969 L .30566 .42274 L F
.26934 .39162 m .26845 .4152 L .30479 .44969 L F
.2 .63 .79 r
2 Mabswid
.2352 .38443 m
.24982 .39788 L
s
0 0 0 r
.5 Mabswid
.5892 .50134 m
.59364 .46311 L
s
.5892 .50134 m
.55614 .49866 L
s
.41884 .22538 m
.41919 .18944 L
s
.55227 .53662 m
.55614 .49866 L
s
.55227 .53662 m
.51973 .53472 L
s
.818 .386 .21 r
.37637 .48726 m .37565 .52071 L .40904 .55661 L F
.776 .368 .202 r
.34153 .45471 m .37565 .52071 L .37637 .48726 L F
0 0 0 r
.48504 .57096 m
.4868 .53341 L
s
.48504 .57096 m
.45314 .57031 L
s
.27642 .42353 m
.27722 .42344 L
s
.24353 .42697 m
.27642 .42353 L
s
.23972 .38859 m
.23982 .38957 L
s
.23982 .38957 m
.24353 .42697 L
s
.24591 .38791 m
.27408 .38483 L
s
.23972 .38859 m
.24591 .38791 L
s
.42042 .57022 m
.42119 .57021 L
s
.38936 .57066 m
.42042 .57022 L
s
.38737 .53308 m
.38742 .53403 L
s
.38742 .53403 m
.38936 .57066 L
s
.60368 .34772 m
.60588 .30974 L
s
.60588 .30974 m
.56935 .3061 L
s
.45314 .57031 m
.45365 .53269 L
s
.42119 .57021 m
.45314 .57031 L
s
.35457 .53418 m
.32223 .53588 L
s
.32223 .53588 m
.31825 .49785 L
s
.53317 .26564 m
.53387 .22878 L
s
.53387 .22878 m
.49573 .22669 L
s
.31825 .49785 m
.28546 .50032 L
s
.28546 .50032 m
.28102 .46201 L
s
.42045 .53259 m
.42119 .57021 L
s
.2 .63 .79 r
2 Mabswid
.40989 .55758 m
.42031 .5692 L
s
.40728 .55467 m
.40855 .55609 L
s
.40855 .55609 m
.40986 .55755 L
s
.734 .349 .193 r
.30566 .42274 m .34072 .48496 L .34153 .45471 L F
.30566 .42274 m .30479 .44969 L .34072 .48496 L F
.2 .63 .79 r
.24982 .39788 m
.26452 .41153 L
s
.776 .368 .202 r
.34153 .45471 m .34072 .48496 L .37565 .52071 L F
0 0 0 r
.5 Mabswid
.56935 .3061 m
.57066 .26855 L
s
.57066 .26855 m
.53317 .26564 L
s
.59364 .46311 m
.59754 .42462 L
s
.59364 .46311 m
.55962 .46023 L
s
.3805 .22618 m
.34251 .22793 L
s
.34258 .26481 m
.34251 .22793 L
s
.30609 .30501 m
.26985 .30835 L
s
.27162 .3464 m
.26985 .30835 L
s
.6009 .38609 m
.60368 .34772 L
s
.60368 .34772 m
.56758 .34426 L
s
.51973 .53472 m
.52249 .4966 L
s
.51973 .53472 m
.4868 .53341 L
s
.2 .63 .79 r
2 Mabswid
.39393 .54011 m
.40728 .55467 L
s
0 0 0 r
.5 Mabswid
.34258 .26481 m
.3053 .26741 L
s
.30609 .30501 m
.3053 .26741 L
s
.59754 .42462 m
.6009 .38609 L
s
.59754 .42462 m
.5627 .42154 L
s
.49519 .26362 m
.49573 .22669 L
s
.49573 .22669 m
.45732 .22556 L
s
.6009 .38609 m
.56536 .38281 L
s
.55614 .49866 m
.55962 .46023 L
s
.55614 .49866 m
.52249 .4966 L
s
.31395 .45942 m
.31477 .45936 L
s
.28102 .46201 m
.31395 .45942 L
s
.27722 .42344 m
.27732 .42443 L
s
.27732 .42443 m
.28102 .46201 L
s
.2 .63 .79 r
2 Mabswid
.26452 .41153 m
.26746 .4143 L
s
.26989 .41657 m
.27926 .42536 L
s
.26746 .4143 m
.26976 .41645 L
s
0 0 0 r
.5 Mabswid
.38657 .53311 m
.38737 .53308 L
s
.35457 .53418 m
.38657 .53311 L
s
.35169 .49602 m
.35176 .49698 L
s
.35176 .49698 m
.35457 .53418 L
s
.41884 .22538 m
.3805 .22618 L
s
.38042 .26313 m
.3805 .22618 L
s
.30744 .34322 m
.27162 .3464 L
s
.27408 .38483 m
.27162 .3464 L
s
.45693 .26253 m
.45732 .22556 L
s
.45732 .22556 m
.41884 .22538 L
s
.2 .63 .79 r
2 Mabswid
.38027 .52556 m
.39393 .54011 L
s
0 0 0 r
.5 Mabswid
.35088 .49606 m
.35169 .49602 L
s
.31825 .49785 m
.35088 .49606 L
s
.31477 .45936 m
.31485 .46034 L
s
.31485 .46034 m
.31825 .49785 L
s
.4868 .53341 m
.48844 .49518 L
s
.4868 .53341 m
.45365 .53269 L
s
.4186 .26236 m
.41884 .22538 L
s
.2826 .423 m
.31179 .42061 L
s
.27722 .42344 m
.2826 .423 L
s
.27408 .38483 m
.27722 .42344 L
s
.56758 .34426 m
.56935 .3061 L
s
.56935 .3061 m
.53215 .30331 L
s
.2 .63 .79 r
2 Mabswid
.27926 .42536 m
.294 .43935 L
s
0 0 0 r
.5 Mabswid
.30934 .38182 m
.27408 .38483 L
s
.53215 .30331 m
.53317 .26564 L
s
.53317 .26564 m
.49519 .26362 L
s
.38737 .53308 m
.42045 .53259 L
s
.38561 .49483 m
.38737 .53308 L
s
.2 .63 .79 r
2 Mabswid
.37673 .52186 m
.38027 .52556 L
s
.36634 .51102 m
.37418 .5192 L
s
.37418 .5192 m
.37668 .52181 L
s
0 0 0 r
.5 Mabswid
.45365 .53269 m
.45416 .49441 L
s
.45365 .53269 m
.42045 .53259 L
s
.55962 .46023 m
.5627 .42154 L
s
.55962 .46023 m
.525 .45801 L
s
.42045 .53259 m
.41982 .49429 L
s
.38042 .26313 m
.34258 .26481 L
s
.34308 .30252 m
.34258 .26481 L
s
.2 .63 .79 r
2 Mabswid
.294 .43935 m
.30334 .44832 L
s
.30576 .45065 m
.3087 .45348 L
s
.30334 .44832 m
.30569 .45058 L
s
0 0 0 r
.5 Mabswid
.34308 .30252 m
.30609 .30501 L
s
.30744 .34322 m
.30609 .30501 L
s
.52249 .4966 m
.525 .45801 L
s
.52249 .4966 m
.48844 .49518 L
s
.2 .63 .79 r
2 Mabswid
.35218 .49652 m
.36634 .51102 L
s
0 0 0 r
.5 Mabswid
.56536 .38281 m
.56758 .34426 L
s
.56758 .34426 m
.53081 .3416 L
s
.2 .63 .79 r
2 Mabswid
.3087 .45348 m
.32333 .46773 L
s
0 0 0 r
.5 Mabswid
.31945 .45909 m
.34918 .45739 L
s
.31477 .45936 m
.31945 .45909 L
s
.31179 .42061 m
.31477 .45936 L
s
.2 .63 .79 r
2 Mabswid
.33783 .48208 m
.33996 .48422 L
s
.34193 .48621 m
.35218 .49652 L
s
.33996 .48422 m
.34187 .48614 L
s
0 0 0 r
.5 Mabswid
.35169 .49602 m
.38561 .49483 L
s
.34918 .45739 m
.35169 .49602 L
s
.5627 .42154 m
.56536 .38281 L
s
.5627 .42154 m
.52723 .41917 L
s
.2 .63 .79 r
2 Mabswid
.32333 .46773 m
.33783 .48208 L
s
0 0 0 r
.5 Mabswid
.49447 .30138 m
.49519 .26362 L
s
.49519 .26362 m
.45693 .26253 L
s
.56536 .38281 m
.52917 .38029 L
s
.4186 .26236 m
.38042 .26313 L
s
.38061 .30091 m
.38042 .26313 L
s
.34399 .34085 m
.30744 .34322 L
s
.30934 .38182 m
.30744 .34322 L
s
.53081 .3416 m
.53215 .30331 L
s
.53215 .30331 m
.49447 .30138 L
s
.48844 .49518 m
.48995 .45648 L
s
.48844 .49518 m
.45416 .49441 L
s
.34705 .4185 m
.31179 .42061 L
s
.31179 .42061 m
.30934 .38182 L
s
.45651 .30034 m
.45693 .26253 L
s
.45693 .26253 m
.4186 .26236 L
s
.41849 .30018 m
.4186 .26236 L
s
.34532 .37958 m
.30934 .38182 L
s
.41982 .49429 m
.38561 .49483 L
s
.38561 .49483 m
.38409 .45611 L
s
.525 .45801 m
.52723 .41917 L
s
.525 .45801 m
.48995 .45648 L
s
.38061 .30091 m
.34308 .30252 L
s
.34399 .34085 m
.34308 .30252 L
s
.45416 .49441 m
.45466 .45565 L
s
.45416 .49441 m
.41982 .49429 L
s
.41982 .49429 m
.41931 .45553 L
s
.38409 .45611 m
.34918 .45739 L
s
.34918 .45739 m
.34705 .4185 L
s
.52917 .38029 m
.53081 .3416 L
s
.53081 .3416 m
.49358 .33977 L
s
.49358 .33977 m
.49447 .30138 L
s
.49447 .30138 m
.45651 .30034 L
s
.52723 .41917 m
.52917 .38029 L
s
.52723 .41917 m
.49131 .41754 L
s
.52917 .38029 m
.49253 .37856 L
s
.38108 .33932 m
.34399 .34085 L
s
.34532 .37958 m
.34399 .34085 L
s
.41849 .30018 m
.38061 .30091 L
s
.38108 .33932 m
.38061 .30091 L
s
.48995 .45648 m
.49131 .41754 L
s
.48995 .45648 m
.45466 .45565 L
s
.38282 .41713 m
.34705 .4185 L
s
.34705 .4185 m
.34532 .37958 L
s
.45608 .33877 m
.45651 .30034 L
s
.45651 .30034 m
.41849 .30018 L
s
.41931 .45553 m
.38409 .45611 L
s
.38409 .45611 m
.38282 .41713 L
s
.38182 .37813 m
.34532 .37958 L
s
.41851 .33862 m
.41849 .30018 L
s
.45466 .45565 m
.45515 .41665 L
s
.45466 .45565 m
.41931 .45553 L
s
.49253 .37856 m
.49358 .33977 L
s
.49358 .33977 m
.45608 .33877 L
s
.41931 .45553 m
.41892 .41651 L
s
.49131 .41754 m
.49253 .37856 L
s
.49131 .41754 m
.45515 .41665 L
s
.41851 .33862 m
.38108 .33932 L
s
.38182 .37813 m
.38108 .33932 L
s
.49253 .37856 m
.45562 .37761 L
s
.41892 .41651 m
.38282 .41713 L
s
.38282 .41713 m
.38182 .37813 L
s
.45562 .37761 m
.45608 .33877 L
s
.45608 .33877 m
.41851 .33862 L
s
.41865 .37747 m
.38182 .37813 L
s
.41865 .37747 m
.41851 .33862 L
s
.45515 .41665 m
.45562 .37761 L
s
.45515 .41665 m
.41892 .41651 L
s
.41892 .41651 m
.41865 .37747 L
s
.45562 .37761 m
.41865 .37747 L
s
.25 Mabswid
.04921 .21495 m
.6146 0 L
s
.6146 0 m
.62692 .78051 L
s
.62692 .78051 m
0 .88134 L
s
0 .88134 m
.04921 .21495 L
s
.95704 .28633 m
.6146 0 L
s
.6146 0 m
.62692 .78051 L
s
.62692 .78051 m
1 .91394 L
s
1 .91394 m
.95704 .28633 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 390.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001QR000`400?l00000o`00003om03oool2
000009X0oooo003b0<ONa`80000000<0amk7000000000000V037g/L10?ooo`00k`37g/L3000000<0
amk700<000000<ONa`000000U`37g/L10?ooo`00k037g/L3000000H0amk700<000000<ONa`37g/L0
0P00002E0<ONa`40oooo003Z0<ONa`8000002@37g/L00`000000amk70<ONa`020<ONa`0300000037
g/L0amk70980amk70@3oool00>L0amk70`00000;0<ONa`0300000037g/L0amk700<0amk700<00000
0<ONa`37g/L0T@37g/L10?ooo`00i037g/L3000000h0amk700<000000<ONa`37g/L01037g/L00`00
0000amk70<ONa`2@0<ONa`40oooo003R0<ONa`8000004@37g/L00`000000amk70<ONa`050<ONa`03
00000037g/L0amk708l0amk70@3oool00=l0amk70`00000C0<ONa`0300000037g/L0amk700H0amk7
0P00002?0<ONa`40oooo003M0<ONa`8000005P37g/L00`000000amk70<ONa`080<ONa`0300000037
g/L0amk708`0amk70@3oool00=X0amk70`00000H0<ONa`0300000037g/L0amk700T0amk700<00000
0<ONa`37g/L0R`37g/L10?ooo`00e`37g/L3000001/0amk700<000000<ONa`37g/L02P37g/L00`00
0000amk70<ONa`2:0<ONa`40oooo003E0<ONa`8000007P37g/L00`000000amk70<ONa`0;0<ONa`03
00000037g/L0amk708T0amk70@3oool00=80amk70`00000P0<ONa`0300000037g/L0amk700`0amk7
0P0000290<ONa`40oooo003?0<ONa`<000008`37g/L00`000000amk70<ONa`0>0<ONa`0300000037
g/L0amk708H0amk70@3oool00<d0amk70P00000V0<ONa`0300000037g/L0amk700l0amk700<00000
0<ONa`37g/L0Q@37g/L10?ooo`00bP37g/L3000002P0amk700<000000<ONa`37g/L04037g/L00`00
0000amk70<ONa`240<ONa`40oooo00380<ONa`800000:`37g/L00`000000amk70<ONa`0A0<ONa`03
00000037g/L0amk708<0amk70@3oool00<D0amk70`00000]0<ONa`0300000037g/L0amk70180amk7
0P0000230<ONa`40oooo00320<ONa`<00000<037g/L00`000000amk70<ONa`0D0<ONa`0300000037
g/L0amk70800amk70@3oool00<00amk70P00000c0<ONa`0300000037g/L0amk701D0amk700<00000
0<ONa`37g/L0O`37g/L10?ooo`00_@37g/L3000003D0amk700<000000<ONa`37g/L05P37g/L00`00
0000amk70<ONa`1n0<ONa`40oooo002j0<ONa`<00000>037g/L00`000000amk70<ONa`0G0<ONa`03
00000037g/L0amk707d0amk70@3oool00;P0amk70P00000k0<ONa`0300000037g/L0amk701P0amk7
0P00001m0<ONa`40oooo002e0<ONa`<00000?@37g/L00`000000amk70<ONa`0J0<ONa`0300000037
g/L0amk707X0amk70@3oool00;80amk70`0000100<ONa`0300000037g/L0amk701/0amk700<00000
0<ONa`37g/L0N@37g/L10?ooo`00/037g/L2000004<0amk700<000000<ONa`37g/L07037g/L00`00
0000amk70<ONa`1h0<ONa`40oooo002]0<ONa`<00000A@37g/L00`000000amk70<ONa`0M0<ONa`03
00000037g/L0amk707L0amk70@3oool00:/0amk70P0000180<ONa`0300000037g/L0amk701h0amk7
00<000000<ONa`37g/L0MP37g/L10?ooo`00Z037g/L3000004X0amk700<000000<ONa`37g/L07`37
g/L2000007H0amk70@3oool00:D0amk70`00001=0<ONa`0300000037g/L0amk70240amk700<00000
0<ONa`37g/L0L`37g/L10?ooo`00X`37g/L200000500amk700<000000<ONa`37g/L08P37g/L00`00
0000amk70<ONa`1b0<ONa`40oooo002P0<ONa`<00000D`37g/L00`000000amk70<ONa`0R0<ONa`03
00000037g/L0amk70740amk70@3oool009d0amk70`00001F0<ONa`0300000037g/L0amk702<0amk7
00<000000<ONa`37g/L0L037g/L10?ooo`00V`37g/L2000005T0amk700<000000<ONa`37g/L09037
g/L200000700amk70@3oool009P0amk70`00001K0<ONa`0300000037g/L0amk702H0amk700<00000
0<ONa`37g/L0K@37g/L10?ooo`00UP37g/L2000005h0amk700<000000<ONa`37g/L09`37g/L00`00
0000amk70<ONa`1/0<ONa`40oooo002C0<ONa`<00000H037g/L00`000000amk70<ONa`0X0<ONa`03
00000037g/L0amk706/0amk70@3oool00900amk70`00001S0<ONa`0300000037g/L0amk702T0amk7
00<000000<ONa`37g/L0JP37g/L10?ooo`00SP37g/L2000006H0amk700<000000<ONa`37g/L0:P37
g/L2000006X0amk70@3oool008/0amk70`00001X0<ONa`0300000037g/L0amk702`0amk700<00000
0<ONa`37g/L0I`37g/L10?ooo`00R037g/L3000006/0amk700<000000<ONa`37g/L0;@37g/L00`00
0000amk70<ONa`1V0<ONa`40oooo00260<ONa`800000KP37g/L00`000000amk70<ONa`0^0<ONa`03
00000037g/L0amk706D0amk70@3oool008<0amk70`00001`0<ONa`0300000037g/L0amk702l0amk7
00<000000<ONa`37g/L0I037g/L10?ooo`00P@37g/L2000007<0amk700<000000<ONa`37g/L0<037
g/L2000006@0amk70@3oool007h0amk70`00001e0<ONa`0300000037g/L0amk70380amk700<00000
0<ONa`37g/L0H@37g/L10?ooo`00N`37g/L3000007P0amk700<000000<ONa`37g/L0<`37g/L00`00
0000amk70<ONa`1P0<ONa`40oooo001i0<ONa`800000N`37g/L00`000000amk70<ONa`0d0<ONa`03
00000037g/L0amk705l0amk70@3oool007H0amk70`00001m0<ONa`0300000037g/L0amk703D0amk7
00<000000<ONa`37g/L0GP37g/L10?ooo`00L`37g/L300000800amk700<000000<ONa`37g/L0=P37
g/L2000005h0amk70@3oool00740amk70P0000230<ONa`0300000037g/L0amk703P0amk700<00000
0<ONa`37g/L0F`37g/L10?ooo`00KP37g/L3000008D0amk700<000000<ONa`37g/L0>@37g/L00`00
0000amk70<ONa`1J0<ONa`40oooo001/0<ONa`800000R037g/L00`000000amk70<ONa`0j0<ONa`03
00000037g/L0amk705T0amk70@3oool006T0amk70`00002:0<ONa`0300000037g/L0amk703/0amk7
00<000000<ONa`37g/L0F037g/L10?ooo`00IP37g/L3000008d0amk700<000000<ONa`37g/L0?037
g/L2000005P0amk70@3oool006@0amk70P00002@0<ONa`0300000037g/L0amk703h0amk700<00000
0<ONa`37g/L0E@37g/L10?ooo`00H@37g/L300000980amk700<000000<ONa`37g/L0?`37g/L00`00
0000amk70<ONa`1D0<ONa`40oooo001N0<ONa`<00000U@37g/L00`000000amk70<ONa`100<ONa`03
00000037g/L0amk705<0amk70@3oool005`0amk70P00002H0<ONa`0300000037g/L0amk70440amk7
00<000000<ONa`37g/L0DP37g/L10?ooo`00F@37g/L3000009X0amk700<000000<ONa`37g/L0@P37
g/L00`000000amk70<ONa`1A0<ONa`40oooo001G0<ONa`800000W@37g/L00`000000amk70<ONa`13
0<ONa`800000D@37g/L10?ooo`00E037g/L3000009l0amk700<000000<ONa`37g/L0A@37g/L00`00
0000amk70<ONa`1>0<ONa`40oooo001A0<ONa`<00000?@37g/Lm000002P0amk700<000000<ONa`37
g/L0AP37g/L00`000000amk70<ONa`1=0<ONa`40oooo001?0<ONa`800000<@37g/L?000000L0amk7
00<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700d0amk7
00<000000<ONa`37g/L01@37g/L;000001d0amk700<000000<ONa`37g/L0A`37g/L00`000000amk7
0<ONa`1<0<ONa`40oooo001<0<ONa`<00000:037g/L;000000L0amk700<000000<ONa`37g/L03037
g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03@37
g/L00`000000amk70<ONa`0<0<ONa`0400000037g/L0amk70<ONa`P000005@37g/L00`000000amk7
0<ONa`180<ONa`0300000037g/L0amk704/0amk70@3oool004T0amk70`00000S0<ONa`P000000`37
g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03037
g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700d0amk700<000000<ONa`37g/L03037
g/L00`000000amk70<ONa`090<ONa`X000002`37g/L00`000000amk70<ONa`190<ONa`800000B`37
g/L10?ooo`00A`37g/L2000001`0amk72P00000;0<ONa`0300000037g/L0amk700`0amk700<00000
0<ONa`37g/L03037g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700`0amk700<00000
0<ONa`37g/L03@37g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700`0amk700<00000
0<ONa`37g/L01037g/L<000004d0amk700<000000<ONa`37g/L0B037g/L10?ooo`00A037g/L30000
01@0amk72P0000060<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03037g/L00`00
0000amk70<ONa`0<0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03037g/L00`00
0000amk70<ONa`0=0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03037g/L00`00
0000amk70<ONa`0;0<ONa`0400000037g/L0amk70<ONa`P00000A`37g/L00`000000amk70<ONa`17
0<ONa`40oooo00110<ONa`<000004`37g/L400000080amk700<000000<ONa`37g/L02`37g/L00`00
0000amk70<ONa`0<0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03037g/L00`00
0000amk70<ONa`0<0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03@37g/L00`00
0000amk70<ONa`0<0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L02`37g/L01@00
0000amk70<ONa`37g/L0000000L0amk71P0000120<ONa`0300000037g/L0amk704H0amk70@3oool0
03l0amk70P00000A0<ONa`D000001P37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk7
00`0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk7
00d0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk7
00d0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0;0<ONa`0500000037g/L0amk7
0<ONa`0000002P37g/L00`000000amk70<ONa`04000003l0amk700<000000<ONa`37g/L0A@37g/L1
0?ooo`00?037g/L3000000d0amk71P00000;0<ONa`0300000037g/L0amk700/0amk700<000000<ON
a`37g/L03037g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700`0amk700<000000<ON
a`37g/L03@37g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700`0amk700<000000<ON
a`37g/L03@37g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700/0amk700D000000<ON
a`37g/L0amk70000000:0<ONa`0300000037g/L0amk700@0amk71@00000k0<ONa`800000A@37g/L1
0?ooo`00>P37g/L2000000X0amk71P0000030<ONa`0300000037g/L0amk700/0amk700<000000<ON
a`37g/L02`37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700`0amk700<000000<ON
a`37g/L03037g/L00`000000amk70<ONa`0=0<ONa`0300000037g/L0amk700`0amk700<000000<ON
a`37g/L03037g/L00`000000amk70<ONa`0=0<ONa`0300000037g/L0amk700`0amk700<000000<ON
a`37g/L02`37g/L01@000000amk70<ONa`37g/L0000000X0amk700<000000<ONa`37g/L02@37g/L6
000003L0amk700<000000<ONa`37g/L0@P37g/L10?ooo`00=`37g/L3000000H0amk71P0000090<ON
a`0300000037g/L0amk700/0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`0;0<ON
a`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0=0<ON
a`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0=0<ON
a`0300000037g/L0amk700`0amk700<000000<ONa`37g/L02`37g/L01@000000amk70<ONa`37g/L0
000000X0amk700<000000<ONa`37g/L02`37g/L010000000amk70<ONa`37g/L600000380amk700<0
00000<ONa`37g/L0@@37g/L10?ooo`00=037g/L3000000D0amk7100000020<ONa`0300000037g/L0
amk700X0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0
amk700/0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0
amk700d0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0
amk700d0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0;0<ONa`0500000037g/L0
amk70<ONa`0000002P37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700L0amk71P00
000]0<ONa`0300000037g/L0amk70400amk70@3oool00380amk70P0000040<ONa`@000001P37g/L0
0`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L03037g/L0
0`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03037g/L0
0`000000amk70<ONa`0=0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03037g/L0
0`000000amk70<ONa`0=0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L02`37g/L0
1@000000amk70<ONa`37g/L0000000X0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ON
a`0:0<ONa`0300000037g/L0amk700@00000:P37g/L00`000000amk70<ONa`0o0<ONa`40oooo000_
0<ONa`<000000P37g/L4000000X0amk700<000000996:02BARP02P2BARP00`000000TTHX09a;:P0:
09a;:P040000002LBbX0W4/Z09a;:P/0Ydl/00<000000:M?;02WCb`02`37g/L00`000000amk70<ON
a`0<0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03@37g/L00`000000amk70<ON
a`0<0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03@37g/L00`000000amk70<ON
a`0<0<ONa`0300000037g/L0amk700/0amk700D000000<ONa`37g/L0amk70000000:0<ONa`030000
0037g/L0amk700/0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`040<ONa`@00000
9`37g/L2000003l0amk70@3oool002`0amk70`0000020<ONa`<0000000<0amk700000037g/L01P37
g/L508M19@030000002BARP0TTHX00X0TTHX00<000000996:02LBbX02P2LBbX010000000W4/Z09a;
:P2LBbX;0:M?;0030000002WCb`0Ydl/00/0/E@_00<000000;5D;`2aE2l03037g/L00`000000amk7
0<ONa`050<ONacd000002037g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700/0amk7
00D000000<ONa`37g/L0amk70000000:0<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37
g/L02P37g/L00`000000amk70<ONa`080<ONa`@000009@37g/L00`000000amk70<ONa`0l0<ONa`40
oooo000Z0<ONa`8000000P37g/L3000000@0amk700<0000008M19@27@BD02P27@BD00`000000TTHX
0996:00:0996:0030000002BARP0W4/Z00X0W4/Z00@0000009a;:P2LBbX0W4/Z2`2WCb`00`000000
Ydl/0:M?;00;0;5D;`030000002aE2l0/E@_00D0^eTa3`0000070<ONa`0300000037g/L0amk700d0
amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700D0
amk7400000070<ONa`0300000037g/L0amk700/0amk700D000000<ONa`37g/L0amk70000000:0<ON
a`0300000037g/L0amk700/0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ON
a`0300000037g/L00000008000008`37g/L00`000000amk70<ONa`0k0<ONa`40oooo000W0<ONa`<0
000000@0amk700000000000000000P37g/L507`l8`0300000027@BD0Qd4U00X0Qd4U00<000000996
:02BARP02P2BARP00`000000TTHX09a;:P0:09a;:P040000002LBbX0W4/Z09a;:P/0Ydl/00<00000
0:M?;02WCb`01@2aE2l>000000L0^eTa00<000000;]I<@2kFC403037g/L00`000000amk70<ONa`0=
0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0=
0<ONa`0300000037g/L0amk700D0amk72`00000:0<ONa`0500000037g/L0amk70<ONa`0000002P37
g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37
g/L00`000000amk70<ONa`020<ONa`<000008@37g/L00`000000amk70<ONa`0j0<ONa`40oooo000U
0<ONa`80000000@0amk700000000000000002P1l?2<00`000000Qd4U08M19@0908M19@0300000027
@BD0TTHX00/0TTHX00<000000996:02LBbX02P2LBbX010000000W4/Z09a;:P2LBbX80:M?;0/00000
1P2aE2l00`000000/E@_0;5D;`0<0;]I<@030000002kFC40^eTa00L0aUhc1@37g/L00`000000amk7
0<ONa`0=0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03037g/L00`000000amk7
0<ONa`0=0<ONa`0300000037g/L0amk700`0amk700@000000<ONa`37g/L0amk71`0000030<ONa`05
00000037g/L0amk70<ONa`0000002P37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk7
00X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`050<ONa`<000007`37g/L00`00
0000amk70<ONa`0i0<ONa`40oooo000R0<ONa`H0000000<0LCLP0000001l?2<02P1l?2<00`000000
Qd4U08M19@0908M19@0300000027@BD0TTHX00/0TTHX00<000000996:02LBbX02P2LBbX010000000
W4/Z09a;:P2LBbX8000000<0Ydl/00<000000:M?;02WCb`02`2aE2l00`000000/E@_0;5D;`0<0;]I
<@030000002kFC40^eTa00`0aUhc00<000000<ONa`37g/L03@37g/L00`000000amk70<ONa`0<0<ON
a`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03@37g/L00`000000amk70<ONa`0<0<ON
a`0300000037g/L0amk700P0amk72000000:0<ONa`0300000037g/L0amk700/0amk700<000000<ON
a`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700P0amk70`00000M0<ON
a`800000>@37g/L10?ooo`007`37g/L5000000D0LCLP00<0000007`l8`1l?2<02@1l?2<00`000000
Qd4U08M19@0908M19@0300000027@BD0TTHX00/0TTHX00<000000996:02LBbX01`2LBbX7000000/0
Ydl/00<000000:M?;02WCb`02`2aE2l00`000000/E@_0;5D;`0<0;]I<@030000002kFC40^eTa00`0
aUhc00<000000=5R=@3AHSD00`3AHSD:0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37
g/L03037g/L00`000000amk70<ONa`0=0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37
g/L02`37g/L010000000amk70<ONa`37g/L8000000<0amk700<000000<ONa`37g/L02`37g/L00`00
0000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`00
0000amk700000003000001/0amk700<000000<ONa`37g/L0=P37g/L10?ooo`007@37g/L4000000P0
LCLP00<0000007`l8`1l?2<02@1l?2<00`000000Qd4U08M19@0908M19@0300000027@BD0TTHX00/0
TTHX00@000000996:02LBbX0W4/Z1P00000309a;:P030000002LBbX0W4/Z00`0Ydl/00<000000:M?
;02WCb`02`2aE2l00`000000/E@_0;5D;`0<0;]I<@030000002kFC40^eTa00`0aUhc00<000000=5R
=@3AHSD01`3AHSD60<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03037g/L00`00
0000amk70<ONa`0=0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L02`37g/L01@00
0000amk70<ONa`37g/L0000000L0amk71`00000:0<ONa`0300000037g/L0amk700X0amk700<00000
0<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700<0amk71000000H
0<ONa`0300000037g/L0amk703D0amk70@3oool001X0amk70`0000000`1V<Qd00000074g8009074g
80030000001l?2<0O3`S00T0O3`S00<0000008M19@27@BD02@27@BD00`000000Qd4U0996:0090996
:0H000002@2LBbX00`000000W4/Z09a;:P0<0:M?;0030000002WCb`0Ydl/00/0/E@_00<000000;5D
;`2aE2l0302kFC400`000000^eTa0;]I<@0<0<IN<`030000003AHSD0dF8e00/0dF8e0P37g/L00`00
0000amk70<ONa`0<0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03@37g/L00`00
0000amk70<ONa`0<0<ONa`0300000037g/L0amk700/0amk700D000000<ONa`37g/L0amk70000000:
0<ONa`0400000037g/L0amk70<ONa`L000000`37g/L00`000000amk70<ONa`0:0<ONa`0300000037
g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`070<ONa`@000005@37
g/L00`000000amk70<ONa`0d0<ONa`40oooo000G0<ONa`<00000101V<Qd00`000000LCLP074g8008
074g80030000001l?2<0O3`S00T0O3`S00<0000008M19@27@BD02@27@BD00`000000Qd4U0996:005
0996:0@000000P2BARP00`000000TTHX09a;:P0:09a;:P030000002LBbX0W4/Z00`0Ydl/00<00000
0:M?;02WCb`02`2aE2l00`000000/E@_0;5D;`0<0;]I<@030000002kFC40^eTa00`0aUhc00<00000
0=5R=@3AHSD02`3AHSD20=]W>00300000037g/L0amk700`0amk700<000000<ONa`37g/L03037g/L0
0`000000amk70<ONa`0=0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L02`37g/L0
1@000000amk70<ONa`37g/L0000000X0amk700<000000<ONa`37g/L02037g/L6000000X0amk700<0
00000<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<0
00000<ONa`0000000P00000C0<ONa`0300000037g/L0amk703<0amk70@3oool001<0amk700<0<j7:
0<ONa`0000000P00000606Hb7@030000001a=b00LCLP00P0LCLP00<0000007`l8`1l?2<02@1l?2<0
0`000000Qd4U08M19@0908M19@0300000027@BD0TTHX00D000001P2BARP00`000000TTHX09a;:P0:
09a;:P030000002LBbX0W4/Z00`0Ydl/00<000000:M?;02WCb`02`2aE2l00`000000/E@_0;5D;`0<
0;]I<@030000002kFC40^eTa00`0aUhc00<000000=5R=@3AHSD02`3AHSD20=]W>0040000003KIcP0
ffLh0=]W>0/0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0=0<ONa`0300000037
g/L0amk700`0amk700<000000<ONa`37g/L02`37g/L01@000000amk70<ONa`37g/L0000000X0amk7
00<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`04000000H0amk700<000000<ONa`37g/L0
2P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L0
0P37g/L200000180amk700<000000<ONa`37g/L0<P37g/L10?ooo`004P37g/L00`0cXLX000000000
000806Hb7@03074g80000000LCLP00T0LCLP00<0000007`l8`1l?2<02@1l?2<00`000000Qd4U08M1
9@0808M19@@000002`2BARP00`000000TTHX09a;:P0:09a;:P030000002LBbX0W4/Z00`0Ydl/00<0
00000:M?;02WCb`02`2aE2l00`000000/E@_0;5D;`0<0;]I<@030000002kFC40^eTa00`0aUhc00<0
00000=5R=@3AHSD02`3AHSD20=]W>0030000003KIcP0ffLh00@0ffLh2037g/L00`000000amk70<ON
a`0<0<ONa`0300000037g/L0amk700d0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ON
a`0;0<ONa`0500000037g/L0amk70<ONa`0000002P37g/L00`000000amk70<ONa`0;0<ONa`030000
0037g/L0amk700@0amk7100000020<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L0
2@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700@0amk70`00000@0<ONa`800000
<P37g/L10?ooo`004`37g/L00`000000<j7:03>QbP0706Hb7@03074g80000000LCLP00T0LCLP00<0
000007`l8`1l?2<02@1l?2<00`000000Qd4U08M19@0408M19@@0000000<0Qd4U00000027@BD0302B
ARP00`000000TTHX09a;:P0:09a;:P030000002LBbX0W4/Z00`0Ydl/00<000000:M?;02WCb`02`2a
E2l00`000000/E@_0;5D;`0<0;]I<@030000002kFC40^eTa00`0aUhc00<000000=5R=@3AHSD02`3A
HSD20=]W>0030000003KIcP0ffLh00L0ffLh1@37g/L00`000000amk70<ONa`0<0<ONa`0300000037
g/L0amk700d0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0;0<ONa`0500000037
g/L0amk70<ONa`0000002P37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700P0amk7
1@00000:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02037g/L00`000000amk7
0<ONa`070<ONa`<000003`37g/L00`000000amk70<ONa`0_0<ONa`40oooo000C0<ONa`040000000c
XLX0<j7:03>QbPH0IS8M00<0LCLP0000001a=b002@1a=b000`000000O3`S07`l8`0907`l8`030000
0027@BD0Qd4U00@000001@27@BD00`000000Qd4U0996:00;0996:0030000002BARP0W4/Z00X0W4/Z
00<0000009a;:P2LBbX0302WCb`00`000000Ydl/0:M?;00;0;5D;`030000002aE2l0/E@_00`0^eTa
00<000000;]I<@2kFC403036GS<00`000000dF8e0=5R=@0;0=5R=@80ffLh00<000000=]W>03KIcP0
1`3KIcP30>I/>@80amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0=0<ONa`030000
0037g/L0amk700`0amk700<000000<ONa`37g/L02`37g/L01@000000amk70<ONa`37g/L0000000X0
amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700@0
00001P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37
g/L02037g/L010000000amk700000000000>0<ONa`0300000037g/L0amk702h0amk70@3oool001<0
amk700<000000<ONa`0cXLX00P0cXLX506Hb7@030000001a=b00LCLP00T0LCLP00<0000007`l8`1l
?2<0201l?2<4000000T0Qd4U00<0000008M19@2BARP02`2BARP00`000000TTHX09a;:P0:09a;:P03
0000002LBbX0W4/Z00`0Ydl/00<000000:M?;02WCb`02`2aE2l00`000000/E@_0;5D;`0<0;]I<@03
0000002kFC40aUhc00`0aUhc00<000000=5R=@3AHSD02`3AHSD20=]W>0030000003KIcP0ffLh00L0
ffLh1@3VK3T00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700d0amk700<000000<ONa`37
g/L03037g/L00`000000amk70<ONa`0;0<ONa`0500000037g/L0amk70<ONa`0000002P37g/L00`00
0000amk70<ONa`0;0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L01037g/L40000
0080amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk7
00P0amk700@000000<ONa`37g/L0amk70`00000<0<ONa`0300000037g/L0amk702d0amk70@3oool0
01<0amk700<000000<ONa`37g/L00`0cXLX406Hb7@030000001a=b00LCLP00T0LCLP00<0000007`l
8`1l?2<0101l?2<40000000307`l8`000000Qd4U00X0Qd4U00<0000008M19@2BARP02`2BARP00`00
0000TTHX09a;:P0:09a;:P030000002LBbX0W4/Z00`0Ydl/00<000000:M?;02WCb`02`2aE2l00`00
0000/E@_0;5D;`0<0;]I<@030000002kFC40aUhc00D0aUhc;P0000070<ONa`0300000037g/L0amk7
00d0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0;0<ONa`0500000037g/L0amk7
0<ONa`0000002P37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700X0amk700<00000
0<ONa`37g/L02037g/L5000000X0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`08
0<ONa`0300000037g/L0amk700@0amk70P00000;0<ONa`0300000037g/L0amk702`0amk70@3oool0
01<0amk700@000000<ONa`37g/L0amk7100cXLX206Hb7@030000001a=b00LCLP00T0LCLP00<00000
07`l8`1l?2<01000000507`l8`0300000027@BD0Qd4U00T0Qd4U00<000000996:02BARP02`2BARP0
0`000000TTHX09a;:P0:09a;:P030000002LBbX0W4/Z00`0Ydl/00<000000:M?;02WCb`02`2aE2l0
0`000000/E@_0;5D;`050;]I<@l000001`36GS<00`000000dF8e0=5R=@0;0=5R=@80ffLh00<00000
0=]W>03KIcP01`3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i0P37g/LK000000/0amk700<00000
0<ONa`37g/L02`37g/L01@000000amk70<ONa`37g/L0000000X0amk700<000000<ONa`37g/L02`37
g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L01000
00060<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`060<ONa`8000002P37g/L2000002`0amk70@3oool001<0amk700<000000<ONa`37g/L00P37g/L4
03>QbP0306Hb7@000000LCLP00T0LCLP1000000907`l8`0300000027@BD0Qd4U00T0Qd4U00<00000
0996:02BARP02`2BARP00`000000TTHX09a;:P0:09a;:P030000002LBbX0W4/Z00`0Ydl/00<00000
0:M?;02aE2l0202aE2l;000000L0^eTa00<000000;]I<@36GS<03036GS<00`000000dF8e0=5R=@0;
0=5R=@80ffLh00<000000=]W>03KIcP01`3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i0P3^L3/7
0<ONa`0300000037g/L0amk700d0amk700@000000<ONa`37g/L0amk7200000030<ONa`0300000037
g/L0amk700/0amk700D000000<ONa`37g/L0amk70000000:0<ONa`0300000037g/L0amk700/0amk7
00<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700@0amk7
100000020<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk7
0<ONa`070<ONa`<000002P37g/L00`000000amk70<ONa`0Y0<ONa`40oooo000B0<ONa`0300000037
g/L0amk700D0amk70`0cXLX00`000000LCLP074g8005074g80<0000000<0LCLP0000001l?2<02P1l
?2<00`000000Qd4U08M19@0908M19@030000002BARP0TTHX00/0TTHX00<000000996:02LBbX02P2L
BbX00`000000W4/Z09a;:P0<0:M?;0040000002WCb`0/E@_0;5D;`L000000`2aE2l00`000000/E@_
0;5D;`0<0;]I<@030000002kFC40aUhc00`0aUhc00<000000=5R=@3AHSD02`3AHSD20=]W>0030000
003KIcP0ffLh00L0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@@0kW0k1@37g/L00`000000amk7
0<ONa`0=0<ONa`0300000037g/L0amk700T0amk72P0000070<ONa`0500000037g/L0amk70<ONa`00
00002P37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37
g/L02P37g/L00`000000amk70<ONa`080<ONa`@000002@37g/L00`000000amk70<ONa`080<ONa`03
00000037g/L0amk700L0amk700<000000<ONa`37g/L00P0000090<ONa`0300000037g/L0amk702P0
amk70@3oool00180amk700<000000<ONa`37g/L01P37g/L203>QbP040000001a=b00LCLP074g80@0
0000101a=b000`000000O3`S07`l8`0907`l8`0300000027@BD0Qd4U00T0Qd4U00<000000996:02B
ARP02`2BARP00`000000W4/Z09a;:P0:09a;:P030000002LBbX0W4/Z00D0Ydl/2`00000:0;5D;`03
0000002aE2l0/E@_00`0^eTa00<000000;]I<@36GS<03036GS<00`000000dF8e0=5R=@0;0=5R=@80
ffLh00<000000=]W>03KIcP01`3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i1P3^L3/30<ONa`03
00000037g/L0amk700d0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`040<ONa`/0
000000<0amk700000037g/L02037g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700X0
amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L000000080
00001P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37
g/L00P37g/L2000000P0amk700<000000<ONa`37g/L09`37g/L10?ooo`004P37g/L00`000000amk7
0<ONa`050<ONa`80<j7:1@000007074g800307`l8`000000O3`S00X0O3`S00<0000008M19@27@BD0
2@27@BD00`000000TTHX0996:00;0996:0030000002LBbX0W4/Z00P0W4/Z2P0000070:M?;0030000
002WCb`0/E@_00/0/E@_00<000000;5D;`2aE2l0302kFC400`000000^eTa0<IN<`0<0<IN<`030000
003AHSD0dF8e00/0dF8e0P3KIcP00`000000ffLh0=]W>0070=]W>0D0iV`i00<000000>I/>@3VK3T0
0`3VK3T80>i`>`030<ONa`000000amk700h0amk700<000000<ONa`37g/L03037g/L00`000000amk7
0<ONa`0;0<ONa`0400000037g/L0amk70<ONa`P000000`37g/L00`000000amk70<ONa`0;0<ONa`03
00000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`03
00000037g/L0amk70080amk70P0000040<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37
g/L01`37g/L00`000000amk70<ONa`040<ONa`8000001`37g/L00`000000amk70<ONa`0V0<ONa`40
oooo000B0<ONa`0300000037g/L0amk700@0amk70`000000100cXLX0000003>QbP0cXLX8074g8003
07`l8`000000O3`S00X0O3`S00<0000008M19@27@BD02@27@BD00`000000TTHX0996:00;0996:003
0000002LBbX0W4/Z00@0W4/Z1000000209a;:P030000002LBbX0W4/Z00`0Ydl/00<000000:M?;02a
E2l02`2aE2l00`000000/E@_0;5D;`0<0;]I<@030000002kFC40aUhc00`0aUhc00<000000=5R=@3A
HSD02`3AHSD20=]W>0030000003KIcP0ffLh00L0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@T0
kW0k00<000000<ONa`37g/L03@37g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700/0
amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`040<ONa`L000002P37g/L00`000000
amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000
amk70<ONa`040<ONa`<0000000<0amk700000037g/L02@37g/L00`000000amk70<ONa`070<ONa`03
00000037g/L0amk700H0amk70P0000060<ONa`8000009P37g/L10?ooo`004P37g/L00`000000amk7
0<ONa`020<ONa`8000001037g/L010000000<j7:03>QbP0cXLX7074g800307`l8`000000O3`S00X0
O3`S00<0000008M19@27@BD02@27@BD00`000000TTHX0996:00;0996:0030000002LBbX0W4/Z00@0
00001P2LBbX00`000000W4/Z09a;:P0<0:M?;0030000002WCb`0/E@_00/0/E@_00<000000;5D;`2a
E2l0302kFC400`000000^eTa0<IN<`0<0<IN<`030000003AHSD0dF8e00/0dF8e0P3KIcP00`000000
ffLh0=]W>0070=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T90>i`>`030000003dLc`0m7<l00d0
amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk70080
amk700<000000<ONa`37g/L01`37g/L010000000amk70<ONa`37g/L7000000<0amk700<000000<ON
a`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ON
a`37g/L01`37g/L3000000T0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ON
a`<000001P37g/L00`000000amk70<ONa`0S0<ONa`40oooo000B0<ONa`0300000037g/L000000080
00001P37g/L00`000000amk703>QbP0203>QbPH0LCLP00<0O3`S0000001l?2<02P1l?2<00`000000
Qd4U08M19@0908M19@030000002BARP0TTHX00P0TTHX1P00000:09a;:P030000002LBbX0W4/Z00`0
Ydl/00<000000:M?;02aE2l02`2aE2l00`000000/E@_0;5D;`0<0;]I<@030000002kFC40aUhc00`0
aUhc00<000000=5R=@3AHSD02`3AHSD20=]W>0030000003KIcP0ffLh00L0ffLh1@3VK3T00`000000
iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac?03dLc`00P3dLc`;0<ONa`0300000037g/L0amk700`0
amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk700L0
amk700<000000<ONa`37g/L02037g/L6000000X0amk700<000000<ONa`37g/L02P37g/L00`000000
amk70<ONa`0:0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`0000000`0000050<ONa`03
00000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`02000000D0
amk700<000000<ONa`37g/L08P37g/L10?ooo`004P37g/L2000000T0amk700<000000<ONa`37g/L0
0`0cXLX5074g80030000001l?2<0O3`S00X0O3`S00<0000008M19@27@BD02@27@BD010000000TTHX
0996:02BARP7000000<0TTHX00<0000009a;:P2LBbX02P2LBbX00`000000W4/Z09a;:P0<0:M?;003
0000002WCb`0/E@_00/0/E@_00<000000;5D;`2aE2l0302kFC400`000000^eTa0<IN<`0<0<IN<`03
0000003AHSD0dF8e00/0dF8e0P3KIcP00`000000ffLh0=]W>0070=]W>0D0iV`i00<000000>I/>@3V
K3T00`3VK3T90>i`>`030000003dLc`0m7<l00<0m7<l2@37g/L00`000000amk70<ONa`0=0<ONa`03
00000037g/L0amk700/0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`070<ONa`03
00000037g/L0amk700/0amk700<000000<ONa`37g/L0100000060<ONa`0300000037g/L0amk700X0
amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700<0
amk7100000000`37g/L000000<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37
g/L00P37g/L2000000@0amk700<000000<ONa`37g/L08@37g/L10?ooo`004P37g/L00`000000amk7
0<ONa`080<ONa`0400000037g/L0amk70<ONa`<0<j7:101a=b000`000000O3`S07`l8`0:07`l8`03
00000027@BD0Qd4U00P0Qd4U1@00000:0996:0030000002LBbX0W4/Z00X0W4/Z00<0000009a;:P2L
BbX0302WCb`00`000000Ydl/0;5D;`0;0;5D;`030000002aE2l0/E@_00`0^eTa00<000000;]I<@36
GS<03036GS<00`000000dF8e0=5R=@0;0=5R=@80ffLh00<000000=]W>03KIcP01`3KIcP50>I/>@03
0000003VK3T0iV`i00<0iV`i2@3^L3/00`000000m7<l0?Ac?0050?Ac?0L0amk700<000000<ONa`37
g/L03037g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk70080amk700<000000<ONa`37
g/L01`37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700@0amk7100000020<ONa`03
00000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700L0amk70`0000080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37
g/L01037g/L2000000<0amk700<000000<ONa`37g/L08037g/L10?ooo`004P37g/L00`000000amk7
0<ONa`080<ONa`0300000037g/L0amk70080amk70`0cXLX3074g80030000001l?2<0O3`S00X0O3`S
00<0000008M19@27@BD01027@BD40000000308M19@000000TTHX00`0TTHX00<0000009a;:P2LBbX0
2P2LBbX00`000000W4/Z09a;:P0<0:M?;0030000002WCb`0/E@_00/0/E@_00<000000;5D;`2aE2l0
302kFC400`000000^eTa0<IN<`0<0<IN<`030000003AHSD0dF8e00/0dF8e0P3KIcP00`000000ffLh
0=]W>0070=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T90>i`>`030000003dLc`0m7<l00H0m7<l
1P37g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L0
0P37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37g/L0
2037g/L5000000X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`030000
0037g/L0amk700P0amk700@000000<ONa`00000000001P37g/L00`000000amk70<ONa`070<ONa`03
00000037g/L0amk700D0amk70`0000020<ONa`8000008037g/L10?ooo`004P37g/L00`000000amk7
0<ONa`080<ONa`0300000037g/L0amk700<0amk70`0cXLX2074g80030000001l?2<0O3`S00X0O3`S
00<0000008M19@27@BD01000000508M19@030000002BARP0TTHX00/0TTHX00<0000009a;:P2LBbX0
2P2LBbX00`000000W4/Z09a;:P0<0:M?;0030000002WCb`0/E@_00/0/E@_00<000000;5D;`2aE2l0
302kFC400`000000^eTa0<IN<`0<0<IN<`030000003AHSD0dF8e00/0dF8e0P3KIcP00`000000ffLh
0=]W>0070=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T90>i`>`030000003dLc`0m7<l00H0m7<l
0P3cLS/40<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L03037g/L00`000000amk7
0<ONa`020<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02`37g/L00`000000amk7
0<ONa`0:0<ONa`0300000037g/L0amk700@000001P37g/L00`000000amk70<ONa`090<ONa`030000
0037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L010000000amk70<ONa`37g/L3000000<0
amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`050<ONa`0400000037g/L0amk70000
00<0amk700<000000<ONa`37g/L07@37g/L10?ooo`004P37g/L00`000000amk70<ONa`080<ONa`03
00000037g/L0amk700@0amk70`0cXLX00`1a=b00000007`l8`0:07`l8`@000002@27@BD00`000000
TTHX0996:00;0996:0030000002LBbX0W4/Z00/0W4/Z00<0000009a;:P2WCb`02`2WCb`00`000000
Ydl/0;5D;`0;0;5D;`030000002aE2l0/E@_00`0^eTa00<000000;]I<@36GS<03036GS<00`000000
dF8e0=5R=@0;0=5R=@80ffLh00<000000=]W>03KIcP01`3KIcP50>I/>@030000003VK3T0iV`i00<0
iV`i2@3^L3/00`000000m7<l0?Ac?0060?Ac?0<0lg8k0`37g/L00`000000amk70<ONa`0<0<ONa`03
00000037g/L0amk700`0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`070<ONa`03
00000037g/L0amk700/0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`040<ONa`@0
00000P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37
g/L02037g/L00`000000amk70<ONa`040<ONa`80000000<0amk700000037g/L02037g/L00`000000
amk70<ONa`050<ONa`0400000037g/L0amk70<ONa`8000000P37g/L00`000000amk70<ONa`0L0<ON
a`40oooo000B0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01@37g/L403>QbPL0
O3`S100000000`27@BD0000008M19@0:08M19@030000002BARP0TTHX00/0TTHX00<0000009a;:P2L
BbX02`2LBbX00`000000W4/Z0:M?;00;0:M?;0030000002WCb`0/E@_00/0/E@_00<000000;5D;`2a
E2l0302kFC400`000000^eTa0<IN<`0<0<IN<`030000003AHSD0dF8e00/0dF8e0P3KIcP00`000000
ffLh0=]W>0070=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T90>i`>`030000003dLc`0m7<l00H0
m7<l1@3cLS/00`37g/L000000<ONa`0=0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37
g/L00P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37
g/L02P37g/L00`000000amk70<ONa`080<ONa`@000002P37g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700P0amk700<000000<ONa`37g/L01P37g/L2000000T0amk700<000000<ONa`37
g/L01@37g/L00`000000amk70<ONa`030<ONa`80000000<0amk700000037g/L07037g/L10?ooo`00
4P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700H0amk7100cXLX00`1l?2<00000
00000003000000@0O3`S00<0Qd4U00000027@BD02P27@BD00`000000TTHX0996:00;0996:0030000
002LBbX0W4/Z00/0W4/Z00<000000:M?;02WCb`02`2WCb`00`000000Ydl/0;5D;`0;0;5D;`030000
002aE2l0/E@_00`0^eTa00<000000;]I<@36GS<01@36GS<m000000030?Ac?03cLS/0lg8k00@0lg8k
00<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk70080amk7
00<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700X0amk7
00<000000<ONa`37g/L02P37g/L00`000000amk700000003000000H0amk700<000000<ONa`37g/L0
2@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk70`0000070<ONa`030000
0037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70000000L0<ONa`40oooo
000B0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01P37g/L203>QbP<000002@1l
?2<00`27@BD0000008M19@0:08M19@030000002BARP0TTHX00/0TTHX00<0000009a;:P2LBbX02`2L
BbX00`000000Ydl/0:M?;00;0:M?;0030000002WCb`0/E@_00/0/E@_00<000000;5D;`2kFC401@2k
FC4?000000L0aUhc00<000000=5R=@3AHSD02`3AHSD20=]W>0030000003KIcP0ffLh00L0ffLh1@3V
K3T00`000000iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac?03dLc`01@3dLc`?000000L0amk700<0
00000<ONa`37g/L03037g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk700H0amk700<0
00000<ONa`37g/L02`37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700X0amk700<0
00000<ONa`37g/L00`37g/L400000080amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L00P0000050<ONa`0300000037
g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L5000001X0amk70@3oool00140amk70P00000:
0<ONa`0300000037g/L0amk700<0amk7100000000`37g/L0000003>QbP0203>QbPP0O3`S00<0Qd4U
00000027@BD02P27@BD00`000000TTHX0996:00;0996:0030000002LBbX0W4/Z00/0W4/Z00<00000
0:M?;02WCb`02`2WCb`00`000000Ydl/0;5D;`050;5D;`h000001`2kFC400`000000^eTa0<IN<`0<
0<IN<`030000003AHSD0dF8e00/0dF8e0P3KIcP00`000000ffLh0=]W>0070=]W>0D0iV`i00<00000
0>I/>@3VK3T00`3VK3T90>i`>`030000003dLc`0m7<l00H0m7<l1P3cLS/00`000000ifdh0>M]>005
0<ONa`/000002`37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk700H0amk700<00000
0<ONa`37g/L02`37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700X0amk700<00000
0<ONa`37g/L01`37g/L4000000X0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`07
0<ONa`0300000037g/L0amk70080amk70P0000030<ONa`0300000037g/L0amk700H0amk700<00000
0<ONa`37g/L01037g/L01P000000amk70<ONa`000000amk7000001T0amk70@3oool00140amk70P00
000:0<ONa`0300000037g/L0000000<000001@37g/L00`000000amk703>QbP0203>QbPL0O3`S00<0
Qd4U00000027@BD02`27@BD00`000000TTHX0996:00:0996:0030000002LBbX0W4/Z00/0W4/Z00<0
00000:M?;02WCb`0202WCb`;000000H0/E@_00<000000;5D;`2kFC40302kFC400`000000^eTa0<IN
<`0<0<IN<`030000003AHSD0dF8e00/0dF8e0P3KIcP00`000000ffLh0=]W>0070=]W>0D0iV`i00<0
00000>I/>@3VK3T00`3VK3T90>i`>`030000003dLc`0m7<l00H0m7<l1P3cLS/010000000ifdh0>M]
>03WKCP;0<ONa`0400000037g/L0amk70<ONa`P000000`37g/L00`000000amk70<ONa`020<ONa`03
00000037g/L0amk700H0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`0;0<ONa`03
00000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk700000003000000H0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700@0
amk70P0000000`37g/L000000<ONa`070<ONa`0300000037g/L0amk700@0amk700L000000<ONa`37
g/L0amk700000037g/L0000001P0amk70@3oool00140amk70P0000090<ONa`<000002@37g/L00`00
0000amk70<ONa`0303>QbPH0O3`S00<0Qd4U00000027@BD02`27@BD00`000000TTHX0996:00:0996
:0030000002LBbX0W4/Z00/0W4/Z00@000000:M?;02WCb`0Ydl/1`0000030:M?;0030000002WCb`0
/E@_00/0/E@_00<000000;5D;`2kFC40302kFC400`000000^eTa0<IN<`0<0<IN<`030000003AHSD0
dF8e00/0dF8e0P3KIcP00`000000ffLh0=]W>0070=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T9
0>i`>`030000003dLc`0m7<l00H0m7<l1P3cLS/00`000000ifdh0>M]>0020>M]>0X0amk700<00000
0<ONa`37g/L02@37g/L7000000030<ONa`000000amk700L0amk700<000000<ONa`37g/L02`37g/L0
0`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L0
0`000000amk70<ONa`030<ONa`@000000P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L01P37g/L3000000L0amk700<000000<ONa`37g/L01037g/L0
0`000000amk70<ONa`020<ONa`<000005`37g/L10?ooo`004@37g/L2000000H0amk70`0000000`37
g/L000000<ONa`090<ONa`0400000037g/L0amk70<ONa`<0<j7:1@1l?2<00`27@BD0000008M19@0;
08M19@030000002BARP0TTHX00X0TTHX00<0000009a;:P2LBbX0202LBbX7000000X0Ydl/00<00000
0:M?;02aE2l02`2aE2l00`000000/E@_0;]I<@0<0;]I<@030000002kFC40aUhc00`0aUhc00<00000
0=5R=@3AHSD02`3AHSD20=]W>0030000003KIcP0ffLh00L0ffLh1@3VK3T00`000000iV`i0>I/>@03
0>I/>@T0kW0k00<000000?Ac?03dLc`01P3dLc`60?=b>`030000003WKCP0ifdh00<0ifdh2@37g/L0
0`000000amk70<ONa`0<0<ONa`0400000037g/L0amk70<ONa`L000000`37g/L00`000000amk70<ON
a`0;0<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ON
a`090<ONa`0300000037g/L0amk700L0amk7100000090<ONa`0300000037g/L0amk700L0amk700<0
00000<ONa`37g/L01`37g/L010000000amk70000000000050<ONa`0300000037g/L0amk700@0amk7
00<000000<ONa`37g/L01037g/L2000001H0amk70@3oool00140amk70P0000040<ONa`8000001037
g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk70080amk70`0cXLX407`l8`0308M19@00
0000Qd4U00/0Qd4U00<000000996:02BARP02P2BARP010000000W4/Z09a;:P2LBbX7000000<0W4/Z
00<000000:M?;02WCb`02`2WCb`00`000000Ydl/0;5D;`0;0;5D;`030000002aE2l0^eTa00`0^eTa
00<000000;]I<@36GS<03036GS<00`000000dF8e0=5R=@0;0=5R=@80ffLh00<000000=]W>03KIcP0
1`3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i2@3^L3/00`000000m7<l0?Ac?0060?Ac?0H0lg8k
00<000000>M]>03WKCP0103WKCP80<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L0
0P37g/L00`000000amk70<ONa`030<ONa`L000002P37g/L00`000000amk70<ONa`0;0<ONa`030000
0037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ONa`030000
0037g/L00000008000001P37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk7
00@000000<ONa`37g/L0amk70P0000030<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37
g/L01037g/L4000001@0amk70@3oool00140amk70P0000001037g/L000000000000000060<ONa`03
00000037g/L0amk700P0amk700<000000<ONa`37g/L00`37g/L403>QbP80O3`S00<0Qd4U00000027
@BD02P27@BD00`2BARP000000996:0080996:0L000002P2LBbX00`000000Ydl/0:M?;00;0:M?;003
0000002WCb`0/E@_00/0/E@_00<000000;5D;`2kFC40302kFC400`000000^eTa0<IN<`0<0<IN<`03
0000003AHSD0dF8e00/0dF8e0P3KIcP00`000000ffLh0=]W>0070=]W>0D0iV`i00<000000>I/>@3V
K3T00`3VK3T90>i`>`030000003dLc`0m7<l00H0m7<l1P3cLS/00`000000ifdh0>M]>0040>M]>003
0<QP<@37g/L0amk700D0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`020<ONa`03
00000037g/L0amk700H0amk700@000000<ONa`37g/L0amk71`0000030<ONa`0300000037g/L0amk7
00/0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk7
00T0amk700<000000<ONa`37g/L00P37g/L2000000@0amk700<000000<ONa`37g/L01`37g/L00`00
0000amk70<ONa`070<ONa`0300000037g/L0amk700<0amk70P0000000`37g/L000000<ONa`060<ON
a`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00P00000C0<ONa`40oooo000A0<ONa`<0
00002@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700@0amk7100cXLX00`1l?2<0
Qd4U0000000;08M19@030996:0000000TTHX0080TTHX1P0000030996:0030000002LBbX0W4/Z00/0
W4/Z00<000000:M?;02WCb`02`2WCb`00`000000Ydl/0;5D;`0;0;5D;`030000002aE2l0^eTa00`0
^eTa00<000000;]I<@36GS<03036GS<00`000000dF8e0=5R=@0;0=5R=@030=]W>0000000ffLh00T0
ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac?03dLc`01P3dLc`60?=b>`03
0000003WKCP0ifdh00@0ifdh0P38H3460<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37
g/L00P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700P0amk71`00000:0<ONa`03
00000037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700@0amk70`0000000`37g/L000000<ONa`080<ONa`0300000037g/L0amk700L0
amk700<000000<ONa`37g/L01@37g/L2000000L0amk700<000000<ONa`37g/L00`37g/L010000000
amk70<ONa`37g/L200000180amk70@3oool00140amk70P00000:0<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L01@37g/L303>QbP0308M19@000000Qd4U00T0Qd4U1P0000090996:003
0000002LBbX0W4/Z00/0W4/Z00<000000:M?;02WCb`02`2WCb`00`000000Ydl/0;5D;`0;0;5D;`03
0000002aE2l0^eTa00`0^eTa00<000000;]I<@36GS<03036GS<00`000000dF8e0=5R=@0;0=5R=@03
0=]W>0000000ffLh00T0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac?03d
Lc`01P3dLc`60?=b>`030000003WKCP0ifdh00@0ifdh0`38H3450<ONa`0300000037g/L0amk700`0
amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700/0
amk700@000000<ONa`37g/L0amk71`0000030<ONa`0300000037g/L0amk700T0amk700<000000<ON
a`37g/L02P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700L0amk70`0000080<ON
a`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L3000000D0amk700<000000<ON
a`37g/L00`37g/L00`000000amk70<ONa`020<ONa`8000004@37g/L10?ooo`004@37g/L2000000X0
amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`060<ONa`<0<j7:00<0000008M19@27
@BD01027@BD40000000308M19@2BARP0000000`0TTHX00<0000009a;:P2LBbX02`2LBbX00`000000
Ydl/0:M?;00;0:M?;0030000002WCb`0/E@_00`0/E@_00<000000;]I<@2kFC402`2kFC400`000000
^eTa0<IN<`0<0<IN<`030000003AHSD0dF8e00/0dF8e00<0ffLh0000003KIcP02@3KIcP50>I/>@03
0000003VK3T0iV`i00<0iV`i2@3^L3/00`000000m7<l0?Ac?0060?Ac?0H0lg8k00<000000>M]>03W
KCP0103WKCP40<QP<@@0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`020<ONa`03
00000037g/L0amk700H0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`080<ONa`D0
00002P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37
g/L02037g/L010000000amk70000000000060<ONa`0300000037g/L0amk700L0amk700<000000<ON
a`37g/L01P37g/L010000000amk70<ONa`0000040<ONa`0300000037g/L0amk700<0amk71@000000
0`37g/L000000<ONa`0@0<ONa`40oooo000A0<ONa`8000002P37g/L00`000000amk70<ONa`090<ON
a`0300000037g/L0amk700H0amk7100cXLX208M19@@000001@27@BD00`2BARP000000996:00;0996
:0030000002LBbX0W4/Z00/0W4/Z00<000000:M?;02WCb`02`2WCb`00`000000Ydl/0;5D;`0<0;5D
;`030000002kFC40^eTa00/0^eTa00<000000;]I<@36GS<03036GS<00`000000dF8e0=5R=@0;0=5R
=@030=]W>0000000ffLh00T0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac
?03dLc`01P3dLc`60?=b>`030000003WKCP0ifdh00@0ifdh1038H3440<ONa`0300000037g/L0amk7
00`0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk7
00/0amk700<000000<ONa`37g/L02`37g/L00`000000amk700000003000000H0amk700<000000<ON
a`37g/L02P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700@000000<ON
a`37g/L0amk70`0000030<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L0
10000000amk70<ONa`37g/L200000080amk700@000000<ONa`37g/L0amk70`0000050<ONa`030000
0037g/L0amk700l0amk70@3oool00140amk70P00000;0<ONa`0300000037g/L0amk700P0amk700<0
00000<ONa`37g/L01P37g/L303>QbP<000002@27@BD00`2BARP000000996:00;0996:0030000002L
BbX0W4/Z00/0W4/Z00<000000:M?;02WCb`02`2WCb`00`000000Ydl/0;5D;`0<0;5D;`030000002k
FC40^eTa00/0^eTa00<000000;]I<@36GS<03036GS<00`000000dF8e0=5R=@0;0=5R=@030=]W>000
0000ffLh00T0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac?03dLc`01P3d
Lc`60?=b>`030000003WKCP0ifdh00@0ifdh1038H3401@2MC2L0amk70<ONa`37g/L0000000d0amk7
00<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700/0amk7
00<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`030<ONa`@000000P37g/L00`000000amk7
0<ONa`0:0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`040<ONa`80000000<0amk700000037g/L02037g/L00`000000amk70<ONa`060<ONa`030000
0037g/L0amk700<0amk71P0000030<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L0
3`37g/L10?ooo`004@37g/L2000000/0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`040<ONa`@0000000@0amk70000000cXLX0<j7:2@27@BD00`2BARP000000996:00;0996:0030000
002LBbX0W4/Z00/0W4/Z00<000000:M?;02WCb`02`2WCb`00`000000Ydl/0;5D;`0<0;5D;`030000
002kFC40^eTa00/0^eTa00<000000;]I<@36GS<03036GS<00`000000dF8e0=5R=@0;0=5R=@030=]W
>0000000ffLh00T0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac?03dLc`0
1P3dLc`60?=b>`030000003WKCP0ifdh00@0ifdh1038H3401@2MC2L0amk70<ONa`37g/L0000000d0
amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700`0
amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`070<ONa`D000002P37g/L00`000000
amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L01P37g/L3000000P0
amk700<000000<ONa`37g/L01P37g/L010000000amk70<ONa`37g/L5000000H0amk700<000000<ON
a`37g/L00P37g/L00`000000amk70<ONa`0?0<ONa`40oooo000A0<ONa`8000002`37g/L00`000000
amk70<ONa`080<ONa`0300000037g/L0amk700@000001@37g/L010000000<j7:03>QbP0cXLX808M1
9@030996:0000000TTHX00/0TTHX00<0000009a;:P2LBbX02`2LBbX00`000000Ydl/0:M?;00;0:M?
;0030000002aE2l0/E@_00`0/E@_00<000000;]I<@2kFC402`2kFC400`000000^eTa0<IN<`0<0<IN
<`030000003AHSD0dF8e00/0dF8e00<0ffLh0000003KIcP02@3KIcP50>I/>@030000003VK3T0iV`i
00<0iV`i2@3^L3/00`000000m7<l0?Ac?0060?Ac?0H0lg8k00<000000>M]>03WKCP0103WKCP40<QP
<@80WD`W0P37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700<0amk700<000000<ON
a`37g/L01@37g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700/0amk700<000000<ON
a`37g/L02@37g/L00`000000amk70<ONa`04000000H0amk700<000000<ONa`37g/L02037g/L00`00
0000amk70<ONa`090<ONa`0300000037g/L0amk700L0amk700@000000<ONa`00000000001P37g/L0
0`000000amk70<ONa`060<ONa`@000001037g/L3000000@0amk700<000000<ONa`37g/L00P37g/L0
0`000000amk70<ONa`0?0<ONa`40oooo000A0<ONa`8000002`37g/L00`000000amk70<ONa`070<ON
a`@000002@37g/L00`000000amk703>QbP0203>QbPL0Qd4U00<0TTHX0000002BARP02`2BARP00`00
0000W4/Z09a;:P0;09a;:P030000002WCb`0Ydl/00/0Ydl/00<000000;5D;`2aE2l0302aE2l00`00
0000^eTa0;]I<@0;0;]I<@030000002kFC40aUhc00D0aUhc?@0000000`3dLc`0lg8k0?=b>`040?=b
>`030000003WKCP0ifdh00@0ifdh1038H34209e<9`80amk700<000000<ONa`37g/L02`37g/L00`00
0000amk70<ONa`030<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L03037g/L00`00
0000amk70<ONa`0;0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L01037g/L40000
0080amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk7
00L0amk700@000000<ONa`37g/L0amk70`0000030<ONa`0300000037g/L0amk700<0amk710000007
0<ONa`0300000037g/L0amk7008000000P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0
amk700l0amk70@3oool00100amk700@000000<ONa`37g/L000002P37g/L00`000000amk70<ONa`03
0<ONa`@0000000<0amk700000037g/L02P37g/L00`000000amk70<ONa`0403>QbPD0Qd4U00<0TTHX
0000002BARP02`2BARP00`000000W4/Z09a;:P0;09a;:P030000002WCb`0Ydl/00/0Ydl/00<00000
0;5D;`2aE2l0302aE2l00`000000^eTa0;]I<@050;]I<@h000001`36GS<00`000000dF8e0=5R=@0;
0=5R=@030=]W>0000000ffLh00T0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@T0kW0k00<00000
0?Ac?03dLc`01@3dLc`?000000<0b60a0`2MC2L00`37g/L000000<ONa`0<0<ONa`0300000037g/L0
amk700<0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0
amk700`0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`@000002@37g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01037g/L2
000000040<ONa`000000amk70<ONa`<000000P37g/L00`000000amk70<ONa`060<ONa`0300000037
g/L0amk70080amk70`0000040<ONa`8000004037g/L10?ooo`004037g/L010000000amk70<ONa`00
000:0<ONa`0300000037g/L0000000<000001@37g/L00`000000amk70<ONa`090<ONa`0400000037
g/L0amk70<ONa`@0<j7:1027@BD00`2BARP000000996:00;0996:0030000002LBbX0W4/Z00/0W4/Z
00<000000:M?;02WCb`02`2WCb`00`000000/E@_0;5D;`050;5D;`l000001P2kFC400`000000^eTa
0<IN<`0<0<IN<`030000003AHSD0dF8e00/0dF8e00<0ffLh0000003KIcP02@3KIcP50>I/>@030000
003VK3T0iV`i00<0iV`i2@3^L3/00`000000m7<l0?Ac?0060?Ac?0H0lg8k00<000000>M]>03WKCP0
103WKCP00`38H340000000000009000000X0amk700<000000<ONa`37g/L00`37g/L00`000000amk7
0<ONa`050<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37g/L03037g/L00`000000amk7
0<ONa`090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`0000000`0000050<ONa`030000
0037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`060<ONa`@00000
1@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0
0`37g/L00`000000amk70<ONa`0>0<ONa`40oooo000@0<ONa`0400000037g/L0amk7000000T0amk7
0`0000090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L00`37g/L303>QbP<0Qd4U
00<0TTHX0000002BARP02`2BARP00`000000W4/Z09a;:P0;09a;:P030000002WCb`0Ydl/00P0Ydl/
2`0000070;5D;`030000002kFC40^eTa00/0^eTa00<000000<IN<`36GS<03036GS<00`000000dF8e
0=5R=@0:0=5R=@80ffLh00<000000=]W>03KIcP0203KIcP50>I/>@030000003VK3T0iV`i00<0iV`i
2@3^L3/00`000000m7<l0?Ac?0060?Ac?0H0lg8k00<000000>M]>03WKCP0103WKCP40<QP<@<0WD`W
00<0OchO00000037g/L00P37g/L7000000<0amk700<000000<ONa`37g/L00`37g/L00`000000amk7
0<ONa`050<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37g/L02`37g/L00`000000amk7
0<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L00`37g/L4000000030<ON
a`000000amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`020<ONa`@00000
00@0amk700000000000000001@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700@0
amk70P0000040<ONa`0300000037g/L0amk700h0amk70@3oool00100amk700@000000<ONa`37g/L0
00001P37g/L3000000030<ONa`000000amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000
amk70<ONa`040<ONa`<0<j7:0P27@BD00`2BARP000000996:00;0996:0030000002LBbX0W4/Z00/0
W4/Z00@000000:M?;02WCb`0Ydl/1`0000030:M?;0030000002aE2l0/E@_00`0/E@_00<000000;]I
<@2kFC402`2kFC400`000000aUhc0<IN<`0<0<IN<`030000003AHSD0dF8e00X0dF8e0P3KIcP00`00
0000ffLh0=]W>0080=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T90>i`>`030000003dLc`0m7<l
00H0m7<l1P3cLS/00`000000ifdh0>M]>0040>M]>0@0b60a0`2MC2L00`1o?Ql000000<ONa`090<ON
a`X000001`37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700/0amk700<000000<ON
a`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700L0amk70`0000090<ON
a`0300000037g/L0amk700P0amk700<000000<ONa`0000000P0000050<ONa`0300000037g/L0amk7
008000000`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700@0amk700<000000<ON
a`0000000`37g/L00`000000amk70<ONa`0>0<ONa`40oooo000@0<ONa`0400000037g/L0amk70000
00@0amk70P0000040<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02P37g/L00`00
0000amk70<ONa`040<ONa`<0<j7:00<0Qd4U0996:0000000302BARP00`000000W4/Z09a;:P0809a;
:PL000002P2WCb`00`000000/E@_0;5D;`0<0;5D;`030000002kFC40^eTa00/0^eTa00<000000<IN
<`36GS<03036GS<00`000000dF8e0=5R=@0:0=5R=@80ffLh00<000000=]W>03KIcP0203KIcP50>I/
>@030000003VK3T0iV`i00<0iV`i2@3^L3/00`000000m7<l0?Ac?0060?Ac?0H0lg8k00<000000>M]
>03WKCP0103WKCP40<QP<@<0WD`W00<0OchO00000037g/L03037g/L00`000000amk70<ONa`030<ON
a`/000002`37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700X0amk700<000000<ON
a`37g/L02P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L00000008000001P37g/L00`00
0000amk70<ONa`060<ONa`@000002037g/L00`000000amk70<ONa`020<ONa`80000000<0amk70000
0037g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk70080000000<0amk70000
0037g/L03`37g/L10?ooo`004037g/L01@000000amk70<ONa`000000amk700<000001P37g/L00`00
0000amk70<ONa`080<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L01@37g/L303>Q
bP030996:0000000TTHX00/0TTHX00@0000009a;:P2LBbX0W4/Z1`00000309a;:P030000002WCb`0
Ydl/00/0Ydl/00<000000;5D;`2aE2l0302aE2l00`000000^eTa0;]I<@0;0;]I<@0300000036GS<0
aUhc00`0aUhc00<000000=5R=@3AHSD02P3AHSD20=]W>0030000003KIcP0ffLh00P0ffLh1@3VK3T0
0`000000iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac?03dLc`01P3dLc`60?=b>`030000003WKCP0
ifdh00@0ifdh1038H34309e<9`0307ln7`000000amk700`0amk700<000000<ONa`37g/L00`37g/L0
0`000000amk70<ONa`050<ONa`0300000037g/L0amk700@000001`37g/L00`000000amk70<ONa`0;
0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`08
0<ONa`0300000037g/L0amk70080amk70P0000040<ONa`0300000037g/L0amk700<0amk70`000002
0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01037g/L2000000L0amk700<00000
0<ONa`37g/L01@37g/L00`000000amk70<ONa`020<ONa`8000004037g/L10?ooo`004037g/L00`00
0000amk70<ONa`02000000T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`0:0<ON
a`0300000037g/L0amk700H0amk70`0cXLX00`000000TTHX0996:0060996:0P000002P2LBbX00`00
0000Ydl/0:M?;00;0:M?;0030000002aE2l0/E@_00`0/E@_00<000000;]I<@2kFC402`2kFC400`00
0000aUhc0<IN<`0<0<IN<`030000003AHSD0dF8e00X0dF8e0P3KIcP00`000000ffLh0=]W>0080=]W
>0D0iV`i00<000000>I/>@3VK3T00`3VK3T90>i`>`030000003dLc`0m7<l00H0m7<l1P3cLS/00`00
0000ifdh0>M]>0040>M]>0@0b60a0`2MC2L00`1o?Ql0000005d^5@0<0<ONa`0300000037g/L0amk7
00<0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`D000000P37g/L00`00
0000amk70<ONa`0;0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02`37g/L00`00
0000amk70<ONa`080<ONa`0300000037g/L0amk700@0amk70`0000000`37g/L000000<ONa`040000
00D0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`050<ONa`<000001@37g/L00`00
0000amk70<ONa`050<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L03P37g/L10?oo
o`004037g/L010000000amk70<ONa`00000:0<ONa`0300000037g/L0amk700T0amk700<000000<ON
a`37g/L02@37g/L00`000000amk70<ONa`060<ONa`@0<j7:0P2BARP6000000@0TTHX00<0000009a;
:P2LBbX02`2LBbX00`000000Ydl/0:M?;00;0:M?;0030000002aE2l0/E@_00`0/E@_00<000000;]I
<@2kFC402`2kFC400`000000aUhc0<IN<`0<0<IN<`030=5R=@000000dF8e00X0dF8e0P3KIcP00`00
0000ffLh0=]W>0080=]W>0@0iV`i00<000000>I/>@3VK3T0103VK3T80>i`>`030000003^L3/0m7<l
00L0m7<l1P3cLS/00`000000ifdh0>M]>0040>M]>0@0b60a0`2MC2L00`1o?Ql0000005d^5@0<0<ON
a`0300000037g/L0amk700<0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`090<ON
a`H000002P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700/0amk700<000000<ON
a`37g/L02037g/L00`000000amk70<ONa`060<ONa`@000002@37g/L00`000000amk70<ONa`070<ON
a`0300000037g/L0amk700D0amk700@000000<ONa`37g/L000001037g/L00`000000amk70<ONa`05
0<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L03P37g/L10?ooo`004037g/L01000
0000amk70<ONa`00000:0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L0
0`000000amk70<ONa`060<ONa`<0<j7:0`00000:0996:0030000002LBbX0W4/Z00/0W4/Z00<00000
0:M?;02WCb`02`2WCb`00`000000/E@_0;5D;`0<0;5D;`030000002kFC40^eTa00`0^eTa00<00000
0<IN<`36GS<02`36GS<00`3AHSD000000=5R=@0:0=5R=@80ffLh00<000000=]W>03KIcP0203KIcP4
0>I/>@030000003VK3T0iV`i00@0iV`i203^L3/00`000000kW0k0?Ac?0070?Ac?0D0lg8k00<00000
0?=b>`3WKCP01@3WKCP40<QP<@<0WD`W00<0OchO0000001M;QD03037g/L00`000000amk70<ONa`03
0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L02`37g/L010000000amk70<ONa`37
g/L7000000<0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ONa`0300000037
g/L0amk700T0amk700<000000<ONa`37g/L00`37g/L300000080amk700<000000<ONa`0000000P00
00060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L010000000amk70<ON
a`37g/L200000080amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`030000
0037g/L0amk700h0amk70@3oool00100amk700@000000<ONa`37g/L000002P37g/L00`000000amk7
0<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L01037g/L4000000030<ON
a`000000<j7:0080<j7:2@2BARP00`000000W4/Z09a;:P0;09a;:P030000002WCb`0Ydl/00/0Ydl/
00<000000;5D;`2aE2l0302aE2l00`000000^eTa0;]I<@0<0;]I<@0300000036GS<0aUhc00/0aUhc
00<0dF8e0000003AHSD02P3AHSD20=]W>0030000003KIcP0ffLh00L0ffLh1@3VK3T00`000000iV`i
0>I/>@040>I/>@P0kW0k00<000000>i`>`3dLc`01`3dLc`50?=b>`030000003cLS/0ifdh00D0ifdh
1038H34309e<9`030000001o?Ql0GBhE00`0amk700<000000<ONa`37g/L00`37g/L00`000000amk7
0<ONa`050<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37g/L02037g/L5000000X0amk7
00<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0000000<00000
1@37g/L00`000000amk70<ONa`020<ONa`8000001037g/L00`000000amk70<ONa`060<ONa`030000
0037g/L0amk700H0amk700<000000<ONa`37g/L00`37g/L3000000H0amk700<000000<ONa`37g/L0
1037g/L00`000000amk70<ONa`0>0<ONa`40oooo000@0<ONa`0400000037g/L0amk7000000/0amk7
00<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700@00000
1@37g/L00`000000<j7:03>QbP0203>QbPP0TTHX00<0000009a;:P2LBbX02`2LBbX00`000000Ydl/
0:M?;00<0:M?;0030000002aE2l0/E@_00/0/E@_00<000000;]I<@2kFC40302kFC400`000000aUhc
0<IN<`0;0<IN<`030=5R=@000000dF8e00X0dF8e0P3KIcP00`000000ffLh0=]W>0070=]W>0D0iV`i
00<000000>I/>@3VK3T0103VK3T80>i`>`030000003^L3/0m7<l00L0m7<l1@3cLS/00`000000lg8k
0>M]>0050>M]>0@0b60a0`2MC2L00`000000OchO05d^5@0<0<ONa`0300000037g/L0amk700<0amk7
00<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700/0amk7
00<000000<ONa`0000000`0000060<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L0
2037g/L3000000T0amk700<000000<ONa`37g/L01037g/L3000000030<ONa`000000amk700L0amk7
00<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk7
00<000000<ONa`37g/L01037g/L00`000000amk70<ONa`0>0<ONa`40oooo000@0<ONa`0400000037
g/L0amk7000000/0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`D00000
2@37g/L00`000000amk70<ONa`0303>QbPL0TTHX00<0000009a;:P2LBbX02`2LBbX00`000000Ydl/
0:M?;00<0:M?;0030000002aE2l0/E@_00/0/E@_00<000000;]I<@2kFC40302kFC400`000000aUhc
0<IN<`0;0<IN<`030=5R=@000000dF8e00X0dF8e0P3KIcP00`000000ffLh0=]W>0070=]W>0D0iV`i
00<000000>I/>@3VK3T0103VK3T80>i`>`030000003^L3/0m7<l00L0m7<l1@3cLS/00`000000lg8k
0>M]>0050>M]>0@0b60a0`2MC2L00`000000OchO05d^5@0;0<ONa`0300000037g/L0amk700@0amk7
00<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700/0amk7
00<000000<ONa`37g/L00`37g/L400000080amk700<000000<ONa`37g/L02P37g/L00`000000amk7
0<ONa`040<ONa`D000002`37g/L00`000000amk70<ONa`070<ONa`<000001`37g/L00`000000amk7
0<ONa`060<ONa`0300000037g/L0amk700D0amk70`0000040<ONa`0300000037g/L0amk700@0amk7
00<000000<ONa`37g/L03P37g/L10?ooo`004037g/L010000000amk70<ONa`00000;0<ONa`030000
0037g/L0amk700P0amk700@000000<ONa`37g/L0amk71P0000020<ONa`0300000037g/L0amk700T0
amk700@000000<ONa`37g/L0amk70`0cXLX50996:00309a;:P000000W4/Z00`0W4/Z00<0Ydl/0000
002WCb`0302WCb`00`000000/E@_0;5D;`0;0;5D;`030000002kFC40^eTa00`0^eTa00<000000<IN
<`36GS<02`36GS<00`3AHSD000000=5R=@0:0=5R=@80ffLh00<000000=]W>03KIcP01`3KIcP50>I/
>@030000003VK3T0iV`i00@0iV`i203^L3/00`000000kW0k0?Ac?0070?Ac?0D0lg8k00<000000?=b
>`3WKCP01@3WKCP40<QP<@<0WD`W00<0000007ln7`1M;QD02`37g/L00`000000amk70<ONa`040<ON
a`0300000037g/L0amk700@0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`0;0<ON
a`0300000037g/L0amk700L0amk71@00000:0<ONa`0400000037g/L0amk70<ONa`<000001037g/L0
0`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700@000000<ONa`00000000001@37
g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L00P00
00020<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L03P37g/L10?ooo`004037g/L0
10000000amk70<ONa`00000;0<ONa`0300000037g/L0amk700L0amk71@0000080<ONa`0300000037
g/L0amk700T0amk700<000000<ONa`37g/L00P37g/L303>QbP@0TTHX00<0W4/Z0000002LBbX0302L
BbX00`2WCb`000000:M?;00<0:M?;0030000002aE2l0/E@_00/0/E@_00<000000;]I<@2kFC40302k
FC400`000000aUhc0<IN<`0;0<IN<`030=5R=@000000dF8e00X0dF8e0P3KIcP00`000000ffLh0=]W
>0070=]W>0D0iV`i00<000000>I/>@3VK3T0103VK3T80>i`>`030000003^L3/0m7<l00L0m7<l1@3c
LS/00`000000lg8k0>M]>0050>M]>0@0b60a0`2MC2L00`000000OchO05d^5@0;0<ONa`0300000037
g/L0amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`0<0<ONa`0300000037
g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`04000000H0amk71000
00070<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L010000000amk70<ON
a`37g/L2000000<0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`030000
0037g/L0amk70080amk70`0000060<ONa`0300000037g/L0amk700h0amk70@3oool000l0amk700<0
00000<ONa`37g/L00P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700@0amk70`00
00000`37g/L000000<ONa`0:0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L00`37
g/L303>QbP<0TTHX0P2LBbX00`000000W4/Z09a;:P0:09a;:P030:M?;0000000Ydl/00`0Ydl/00<0
00000;5D;`2aE2l02`2aE2l00`000000^eTa0;]I<@0<0;]I<@0300000036GS<0aUhc00D0aUhc;000
00070>i`>`030000003^L3/0m7<l00L0m7<l1@3cLS/00`000000lg8k0>M]>0050>M]>0@0b60a0`2M
C2L00`000000OchO05d^5@0;0<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01037
g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37
g/L00`000000amk70<ONa`040<ONa`L000002P37g/L00`000000amk70<ONa`080<ONa`0300000037
g/L0amk700T0amk700<000000<ONa`37g/L00`37g/L2000000030<ONa`000000amk700L0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L03P37g/L10?ooo`003`37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0
amk700P0amk700<000000<ONa`37g/L00P37g/L2000000@0amk700<000000<ONa`37g/L02@37g/L0
0`000000amk70<ONa`090<ONa`0300000037g/L0amk700@0amk70`0cXLX20996:080W4/Z00<00000
09a;:P2LBbX02P2LBbX00`2WCb`000000:M?;00<0:M?;0030000002aE2l0/E@_00/0/E@_00<00000
0;]I<@2kFC401@2kFC4?000000H0aUhc00<0dF8e0000003AHSD02P3AHSD20=]W>0030000003KIcP0
ffLh00L0ffLh1@3VK3T00`000000iV`i0>I/>@040>I/>@030>i`>`000000000001`000001@38H342
09e<9`030000001o?Ql0GBhE00/0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`04
0<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`0:
0<ONa`0300000037g/L0amk700<0amk70`0000020<ONa`@000002@37g/L00`000000amk70<ONa`08
0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01P37g/L3000000L0amk700<00000
0<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`<000001037g/L00`000000amk70<ONa`0>
0<ONa`40oooo000?0<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L02037g/L00`00
0000amk700000002000000H0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ON
a`0300000037g/L0amk700@0amk70`0cXLX0102BARP0W4/Z09a;:P00000<09a;:P030:M?;0000000
Ydl/00`0Ydl/00<000000;5D;`2aE2l01@2aE2l>000000L0^eTa00<000000<IN<`36GS<02`36GS<0
0`3AHSD000000=5R=@0:0=5R=@80ffLh00<000000=]W>03KIcP01`3KIcP50>I/>@030000003VK3T0
iV`i00@0iV`i203^L3/00`000000kW0k0?Ac?0070?Ac?0D0lg8k00<000000?=b>`3WKCP01@3WKCP;
000000X0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0
amk700/0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0
000000<000001`37g/L00`000000amk700000003000000D0amk700<000000<ONa`37g/L02037g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700@000000<ONa`00000000001@37
g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700@000000<ONa`37g/L00000
0`37g/L2000000l0amk70@3oool000l0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ON
a`070<ONa`<000002@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700X0amk700<0
00000<ONa`37g/L01@37g/L403>QbP0309a;:P000000W4/Z00/0W4/Z00<0Ydl/0000002WCb`02@2W
Cb`;000000H0/E@_00<000000;]I<@2kFC40302kFC400`000000aUhc0<IN<`0;0<IN<`030=5R=@00
0000dF8e00X0dF8e0P3KIcP00`000000ffLh0=]W>0070=]W>0D0iV`i00<000000>I/>@3VK3T0103V
K3T80>i`>`030000003^L3/0m7<l00L0m7<l1@3cLS/00`000000lg8k0>M]>0050>M]>0D0b60a0P2M
C2L010000000OchO05d^5@37g/L7000000<0amk700<000000<ONa`37g/L01037g/L00`000000amk7
0<ONa`040<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37g/L02`37g/L00`000000amk7
0<ONa`090<ONa`<000002`37g/L00`000000amk70<ONa`030<ONa`@0000000<0amk700000037g/L0
2@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700@000000<ONa`37g/L0
amk70P0000030<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L01@000000
amk70<ONa`37g/L000000080amk70P00000?0<ONa`40oooo000?0<ONa`0300000037g/L0amk70080
amk700<000000<ONa`37g/L00`37g/L4000000030<ONa`000000amk700T0amk700<000000<ONa`37
g/L02@37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700H0amk7100cXLX00`000000
W4/Z09a;:P0:09a;:P030:M?;0000000Ydl/0080Ydl/1`0000030:M?;0030000002aE2l0/E@_00/0
/E@_00<000000;]I<@2kFC40302kFC400`000000aUhc0<IN<`0;0<IN<`030=5R=@000000dF8e00X0
dF8e0P3KIcP00`000000ffLh0=]W>0070=]W>0D0iV`i00<000000>I/>@3VK3T0103VK3T80>i`>`03
0000003^L3/0m7<l00L0m7<l1@3cLS/00`000000lg8k0>M]>0050>M]>0D0b60a0P2MC2L00`000000
OchO05d^5@080<ONa`L000000`37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700/0
amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`050<ONa`@0000000<0amk700000037
g/L02`37g/L00`000000amk70<ONa`070<ONa`<000002@37g/L00`000000amk70<ONa`080<ONa`03
00000037g/L0amk700L0amk700<000000<ONa`37g/L00`37g/L2000000030<ONa`000000amk700H0
amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`020<ONa`@000003`37g/L10?ooo`00
3`37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0000000<000001@37g/L00`000000amk7
0<ONa`080<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`080<ONa`80<j7:00<0000009a;:P2LBbX01P2LBbX9000000X0Ydl/00<000000;5D;`2aE2l0
2`2aE2l00`000000^eTa0;]I<@0<0;]I<@0300000036GS<0aUhc00/0aUhc00<0dF8e0000003AHSD0
2P3AHSD20=]W>0030000003KIcP0ffLh00L0ffLh1@3VK3T00`000000iV`i0>I/>@040>I/>@P0kW0k
00<000000>i`>`3dLc`01`3dLc`50?=b>`030000003cLS/0ifdh00D0ifdh1@38H34209e<9`030000
001o?Ql0GBhE00/0amk700@000000<ONa`37g/L0amk71`0000030<ONa`0300000037g/L0amk700/0
amk700<000000<ONa`37g/L02`37g/L010000000amk70<ONa`37g/L4000000@0amk700<000000<ON
a`37g/L02P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0000000<000001@37g/L00`00
0000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01@37g/L20000
00L0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`8000003`37g/L10?oo
o`003`37g/L00`000000amk70<ONa`020<ONa`8000002@37g/L00`000000amk70<ONa`080<ONa`03
00000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`03
03>QbP000000<j7:00L00000102LBbX00`2WCb`000000:M?;00<0:M?;0030000002aE2l0/E@_00/0
/E@_00<000000;]I<@2kFC40302kFC400`000000aUhc0<IN<`0;0<IN<`030=5R=@000000dF8e00X0
dF8e0P3KIcP00`000000ffLh0=]W>0070=]W>0D0iV`i00<000000>I/>@3VK3T0103VK3T80>i`>`03
0000003^L3/0m7<l00L0m7<l1@3cLS/00`000000lg8k0>M]>0050>M]>0D0b60a0P2MC2L00`000000
OchO05d^5@0;0<ONa`0300000037g/L0amk700@0amk700@000000<ONa`37g/L0amk71`00000:0<ON
a`0300000037g/L0amk700/0amk7100000080<ONa`0300000037g/L0amk700X0amk700<000000<ON
a`37g/L02@37g/L00`000000amk70<ONa`030<ONa`@0000000<0amk700000037g/L02@37g/L00`00
0000amk70<ONa`070<ONa`0300000037g/L0amk700H0amk70`0000050<ONa`0300000037g/L0amk7
00@0amk700<000000<ONa`37g/L01037g/L2000000l0amk70@3oool000l0amk700<000000<ONa`37
g/L00P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37
g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700L0amk71@0000000`0cXLX0
W4/Z09a;:P0809a;:P030:M?;0000000Ydl/00`0Ydl/00<000000;5D;`2aE2l02`2aE2l00`000000
^eTa0;]I<@0<0;]I<@0300000036GS<0aUhc00/0aUhc00<0dF8e0000003AHSD02P3AHSD20=]W>003
0000003KIcP0ffLh00L0ffLh1@3VK3T00`000000iV`i0>I/>@040>I/>@P0kW0k00<000000>i`>`3d
Lc`01`3dLc`50?=b>`030000003cLS/0ifdh00D0ifdh1@38H34209e<9`030000001o?Ql0GBhE00/0
amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0400000037g/L0amk70<ON
a`L000000`37g/L00`000000amk70<ONa`080<ONa`@000002`37g/L00`000000amk70<ONa`0:0<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L01`37g/L3000000T0amk700<000000<ON
a`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk7008000000`37g/L00`00
0000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk70P00000?0<ONa`40oooo000?0<ONa`03
00000037g/L0amk70080amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L010000000amk70<ONa`37g/L60000
00@0amk70`0cXLX909a;:P030:M?;0000000Ydl/00`0Ydl/00<000000;5D;`2aE2l02`2aE2l00`00
0000^eTa0;]I<@0<0;]I<@0300000036GS<0aUhc00/0aUhc00<0dF8e0000003AHSD02P3AHSD20=]W
>0030000003KIcP0ffLh00L0ffLh1@3VK3T00`000000iV`i0>I/>@040>I/>@P0kW0k00<000000>i`
>`3dLc`01`3dLc`50?=b>`030000003cLS/0ifdh00D0ifdh1@38H34209e<9`030000001o?Ql0GBhE
00/0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk7
00P0amk71`0000040<ONa`<000000P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk7
00X0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0400000037g/L00000
000000H0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0
amk70080amk70P0000000`37g/L000000<ONa`050<ONa`0300000037g/L0amk700@0amk70P00000?
0<ONa`40oooo000?0<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L02037g/L00`00
0000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L01`37g/L60000
00X0amk700@0000003>QbP0cXLX0<j7:202LBbX00`2WCb`000000:M?;00<0:M?;0030000002aE2l0
/E@_00/0/E@_00<000000;]I<@2kFC40302kFC400`000000aUhc0<IN<`0;0<IN<`030=5R=@000000
dF8e00X0dF8e0`3KIcP00`000000ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T0103VK3T8
0>i`>`030000003dLc`0m7<l00L0m7<l1@3cLS/00`000000lg8k0>M]>0050>M]>0D0b60a0P2MC2L0
0`000000OchO05d^5@0;0<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01037g/L0
0`000000amk70<ONa`0;0<ONa`0400000037g/L0amk70<ONa`H000000`37g/L00`000000amk70<ON
a`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`090<ONa`0400000037g/L0amk70<ONa`<000000`37g/L00`000000amk70<ONa`070<ONa`030000
0037g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L2000000H0amk700<000000<ONa`37g/L0
1037g/L2000000l0amk70@3oool000l0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ON
a`070<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L010000000amk70<ON
a`37g/L600000080amk700<000000<ONa`37g/L02`37g/L00`000000amk703>QbP0303>QbPH0W4/Z
00<0Ydl/0000002WCb`0302WCb`00`000000/E@_0;5D;`0;0;5D;`030;]I<@000000^eTa00`0^eTa
00<000000<IN<`36GS<02`36GS<00`3AHSD000000=5R=@0:0=5R=@<0ffLh00<000000=]W>03KIcP0
1P3KIcP50>I/>@030000003VK3T0iV`i00@0iV`i203^L3/00`000000m7<l0?Ac?0070?Ac?0D0lg8k
00<000000?=b>`3WKCP01@3WKCP50<QP<@0509e<9`000000WD`W07ln7`1M;QD02`37g/L00`000000
amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L02`37g/L4000000H0
amk71`0000090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02037g/L00`000000
amk70<ONa`090<ONa`0300000037g/L0amk700@0amk70P0000000`37g/L000000<ONa`080<ONa`03
00000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L3000000@0amk700<000000<ONa`37
g/L01037g/L2000000l0amk70@3oool000l0amk700<000000<ONa`37g/L00`37g/L00`000000amk7
0<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L5000000P0amk7
00<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`0403>QbPD0W4/Z00<0Ydl/0000002WCb`0
302WCb`00`000000/E@_0;5D;`0;0;5D;`030;]I<@000000^eTa00`0^eTa00<000000<IN<`36GS<0
2`36GS<00`3AHSD000000=5R=@0:0=5R=@<0ffLh00<000000=]W>03KIcP01P3KIcP50>I/>@030000
003VK3T0iV`i00@0iV`i203^L3/00`000000m7<l0?Ac?0070?Ac?0D0lg8k00<000000?=b>`3WKCP0
1@3WKCP50<QP<@0509e<9`000000WD`W07ln7`1M;QD02`37g/L00`000000amk70<ONa`040<ONa`03
00000037g/L0amk700@0amk700<000000<ONa`37g/L02037g/L4000000`0amk700@000000<ONa`37
g/L0amk71P0000030<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02037g/L00`00
0000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk70`0000080<ONa`0300000037g/L0amk7
00H0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`0200000080amk700<000000<ON
a`37g/L01037g/L2000000l0amk70@3oool000l0amk700<000000<ONa`37g/L00`37g/L00`000000
amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01037g/L400000003
0<ONa`000000amk700X0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`020<ONa`<0
<j7:102LBbX00`2WCb`000000:M?;00;0:M?;080/E@_00<000000;5D;`2aE2l02P2aE2l00`2kFC40
00000;]I<@0<0;]I<@0300000036GS<0aUhc00/0aUhc00<0dF8e0000003AHSD02P3AHSD30=]W>003
0000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@040>I/>@P0kW0k00<000000?Ac?03d
Lc`01`3dLc`50?=b>`030000003cLS/0ifdh00D0ifdh1@38H3401@2MC2L0000009e<9`1o?Ql0GBhE
00X0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk7
00@0amk7100000030<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L01`37g/L50000
00X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk7
00P0amk700<000000<ONa`0000000P0000050<ONa`0300000037g/L0amk700H0amk700<000000<ON
a`37g/L01P37g/L00`000000amk70<ONa`020<ONa`<000001@37g/L00`000000amk70000000?0<ON
a`40oooo000?0<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L02037g/L00`000000
amk70<ONa`080<ONa`0300000037g/L0amk700@000001@37g/L00`000000amk70<ONa`0:0<ONa`03
00000037g/L0amk700X0amk700<000000<ONa`37g/L00`37g/L303>QbP<0W4/Z0P2WCb`00`000000
Ydl/0:M?;0090:M?;080/E@_00<000000;5D;`2aE2l02P2aE2l00`2kFC4000000;]I<@0<0;]I<@03
00000036GS<0aUhc00/0aUhc00<0dF8e0000003AHSD02P3AHSD30=]W>0030000003KIcP0ffLh00H0
ffLh1@3VK3T00`000000iV`i0>I/>@040>I/>@P0kW0k00<000000?Ac?03dLc`01`3dLc`50?=b>`03
0000003cLS/0ifdh00D0ifdh1@38H3401@2MC2L0000009e<9`1o?Ql0GBhE00X0amk700<000000<ON
a`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0400000037g/L0amk70<ONa`<000001`37g/L0
0`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`0000000`000006
0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`08
0<ONa`0300000037g/L0amk70080amk7100000000`37g/L000000<ONa`070<ONa`0300000037g/L0
amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0
000000l0amk70@3oool000h0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`080<ON
a`0300000037g/L0amk700L0amk7100000090<ONa`0300000037g/L0amk700X0amk700<000000<ON
a`37g/L02P37g/L00`000000amk70<ONa`040<ONa`<0<j7:0P2LBbX20:M?;0030000002WCb`0Ydl/
00T0Ydl/0P2aE2l00`000000/E@_0;5D;`0:0;5D;`030;]I<@000000^eTa00`0^eTa00<000000<IN
<`36GS<02`36GS<00`3AHSD000000=5R=@0:0=5R=@<0ffLh00<000000=]W>03KIcP01P3KIcP50>I/
>@030000003VK3T0iV`i00@0iV`i203^L3/00`000000m7<l0?Ac?0070?Ac?0D0lg8k00<000000?=b
>`3WKCP01@3WKCP50<QP<@0509e<9`000000WD`W07ln7`1M;QD02P37g/L00`000000amk70<ONa`05
0<ONa`0300000037g/L0amk700<0amk71@00000:0<ONa`0300000037g/L0amk700X0amk700<00000
0<ONa`37g/L02P37g/L00`000000amk70<ONa`030<ONa`@000000P37g/L00`000000amk70<ONa`09
0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`06
0<ONa`8000002037g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk70P000004
0<ONa`0300000037g/L0000000l0amk70@3oool000h0amk700<000000<ONa`37g/L01037g/L00`00
0000amk70<ONa`080<ONa`0300000037g/L0amk700<0amk7100000000`37g/L000000<ONa`0;0<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`040<ON
a`<0<j7:00@0W4/Z0:M?;02WCb`000002`2WCb`20;5D;`030000002aE2l0/E@_00X0/E@_00<0^eTa
0000002kFC40302kFC400`000000aUhc0<IN<`0;0<IN<`030=5R=@000000dF8e00X0dF8e0`3KIcP0
0`000000ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T0103VK3T80>i`>`030000003dLc`0
m7<l00L0m7<l1@3cLS/00`000000lg8k0>M]>0050>M]>0D0b60a00D0WD`W0000002MC2L0OchO05d^
5@0:0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01000000>0<ONa`0300000037
g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`070<ONa`@000002@37
g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02037
g/L3000000D0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037
g/L0000000<0amk700<000000<ONa`0000003`37g/L10?ooo`003P37g/L00`000000amk70<ONa`04
0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`0000000`0000050<ONa`0300000037g/L0
amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0
amk700D0amk70`0cXLX20:M?;0030000002WCb`0Ydl/00T0Ydl/0P2aE2l00`000000/E@_0;5D;`0:
0;5D;`030;]I<@000000^eTa00`0^eTa00<000000<IN<`36GS<01@36GS<k00000080m7<l1@3cLS/0
0`000000lg8k0>M]>0050>M]>0D0b60a00D0WD`W0000002MC2L0OchO05d^5@0:0<ONa`0300000037
g/L0amk700D0amk70`0000030<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37g/L02`37
g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`0000000`00
00050<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk7008000000`37g/L00`000000amk70<ONa`060<ONa`0300000037
g/L0amk700D0amk700<000000<ONa`37g/L00P0000001@37g/L000000<ONa`37g/L0000000h0amk7
0@3oool000h0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`<000002@37
g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02`37
g/L00`000000amk70<ONa`060<ONa`<0<j7:00<0Ydl/0000002WCb`02P2WCb`20;5D;`030000002a
E2l0/E@_00P0/E@_6@0000060<IN<`030=5R=@000000dF8e00X0dF8e0`3KIcP00`000000ffLh0=]W
>0060=]W>0D0iV`i00<000000>I/>@3VK3T0103VK3T80>i`>`030000003dLc`0m7<l00D0m7<l3P00
00000`3WKCP0b60a0<QP<@030<QP<@0509e<9`000000WD`W07ln7`1M;QD02P37g/L010000000amk7
0<ONa`37g/L5000000D0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`0;0<ONa`03
00000037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`030<ONa`@0
000000<0amk700000037g/L02P37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700P0
amk700<000000<ONa`37g/L00P37g/L2000000030<ONa`000000amk700L0amk700<000000<ONa`37
g/L01037g/L00`000000amk70<ONa`030<ONa`8000000P37g/L00`000000amk70<ONa`0<0<ONa`40
oooo000>0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L00`37g/L3000000030<ON
a`000000amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`030000
0037g/L0amk700/0amk700<000000<ONa`37g/L01P37g/L403>QbP030000002WCb`0Ydl/00T0Ydl/
0P2aE2l010000000/E@_0;5D;`2aE2l700000080/E@_00<0^eTa0000002kFC40302kFC400`000000
aUhc0<IN<`0;0<IN<`030=5R=@000000dF8e00X0dF8e0`3KIcP00`000000ffLh0=]W>0060=]W>0D0
iV`i00<000000>I/>@3VK3T00`3VK3T90>i`>`030000003dLc`0m7<l00L0m7<l1@3cLS/00`000000
lg8k0>M]>0040>M]>0h000001`37g/L4000000@0amk700<000000<ONa`37g/L00`37g/L00`000000
amk70<ONa`0;0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000
amk70<ONa`0:0<ONa`0300000037g/L0amk700L0amk70`0000090<ONa`0300000037g/L0amk700P0
amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`050<ONa`8000002037g/L00`000000
amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700@000000<ONa`37g/L000003P37g/L10?oo
o`003P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0000000<000001037g/L00`000000
amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000
amk70<ONa`0;0<ONa`0300000037g/L0amk700H0amk71@0cXLX80:M?;0T000002@2aE2l00`2kFC40
00000;]I<@0<0;]I<@0300000036GS<0aUhc00/0aUhc00<0dF8e0000003AHSD02P3AHSD30=]W>003
0000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac?03d
Lc`01`3dLc`50?=b>`030000003cLS/0ifdh00D0ifdh1@38H3401@2MC2L0000009e<9`1o?Ql0GBhE
00<0amk72`0000040<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L02`37g/L00`00
0000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`00
0000amk70<ONa`090<ONa`0300000037g/L0000000<000001@37g/L00`000000amk70<ONa`080<ON
a`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L3000000D0amk700<000000<ON
a`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0400000037g/L0amk7000000h0amk70@3oool0
00h0amk700<000000<ONa`37g/L01@37g/L2000000P0amk700<000000<ONa`37g/L02@37g/L00`00
0000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02`37g/L00`00
0000amk70<ONa`070<ONa`80000000<0<j7:0000000000001`0000030:M?;080/E@_00<000000;5D
;`2aE2l02P2aE2l00`2kFC4000000;]I<@0<0;]I<@0300000036GS<0aUhc00/0aUhc00<0dF8e0000
003AHSD02P3AHSD30=]W>0030000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/
>@T0kW0k00<000000?Ac?03dLc`01`3dLc`50?=b>`030000003cLS/0ifdh00D0ifdh1@38H3401@2M
C2L0000009e<9`1o?Ql0GBhE00@0amk70`0000030<ONa`0400000037g/L0amk70<ONa`L000000`37
g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37
g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L00`37
g/L4000000030<ONa`000000amk700T0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ON
a`060<ONa`0300000037g/L0amk7008000000`37g/L00`000000amk70<ONa`050<ONa`0300000037
g/L0amk700@0amk700@000000<ONa`37g/L000003P37g/L10?ooo`003P37g/L00`000000amk70<ON
a`050<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L010000000amk70<ON
a`37g/L6000000<0amk700<0000003>QbP0cXLX02@2WCb`20;5D;`030000002aE2l0/E@_00X0/E@_
00<0^eTa0000002kFC40302kFC400`000000aUhc0<IN<`0;0<IN<`030=5R=@000000dF8e00X0dF8e
0`3KIcP00`000000ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T90>i`>`030000
003dLc`0m7<l00L0m7<l1@3cLS/00`000000lg8k0>M]>0050>M]>0D0b60a00D0WD`W0000002MC2L0
OchO05d^5@04000000H0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`07000000X0
amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`070<ONa`<000002@37g/L00`000000
amk70<ONa`070<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L00P37g/L200000003
0<ONa`000000amk700H0amk700<000000<ONa`37g/L01037g/L010000000amk70<ONa`00000>0<ON
a`40oooo000>0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L02037g/L00`000000
amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000
amk70<ONa`070<ONa`L000002@37g/L010000000<j7:03>QbP0cXLX80:M?;080/E@_00<000000;5D
;`2aE2l02P2aE2l00`2kFC4000000;]I<@0<0;]I<@0300000036GS<0aUhc00/0aUhc00<0dF8e0000
003AHSD02P3AHSD30=]W>0030000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/
>@T0kW0k00<000000?Ac?03dLc`01`3dLc`50?=b>`030000003cLS/0ifdh00D0ifdh1@38H3401@2M
C2L0000009e<9`1o?Ql0GBhE00X0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`02
0<ONa`0400000037g/L0amk70<ONa`L000000`37g/L00`000000amk70<ONa`0:0<ONa`0300000037
g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037
g/L0amk700T0amk700@000000<ONa`00000000001P37g/L00`000000amk70<ONa`080<ONa`030000
0037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L2000000L0amk700<000000<ONa`37g/L0
0`37g/L01@000000amk70<ONa`37g/L0000000h0amk70@3oool000h0amk700<000000<ONa`37g/L0
1@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L0
2P37g/L00`000000amk70<ONa`090<ONa`0400000037g/L0amk70<ONa`H000000`37g/L00`000000
amk70<ONa`0:0<ONa`0300000037g/L0<j7:0080<j7:1`2WCb`20;5D;`030000002aE2l0/E@_00X0
/E@_00<0^eTa0000002kFC402`2kFC400`36GS<000000<IN<`0<0<IN<`030=5R=@000000dF8e00X0
dF8e0`3KIcP00`000000ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T90>i`>`03
0000003dLc`0m7<l00L0m7<l1@3cLS/00`000000lg8k0>M]>0050>M]>0D0b60a00D0WD`W0000002M
C2L0OchO05d^5@0:0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L00P37g/L00`00
0000amk70<ONa`080<ONa`L000002@37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk7
00T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0400000037g/L0amk7
0<ONa`<000000`37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700D0amk700<00000
0<ONa`37g/L01P37g/L3000000@0amk700<000000<ONa`37g/L01037g/L01@000000amk70<ONa`37
g/L0000000h0amk70@3oool000h0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`07
0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`07
0<ONa`H000002@37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700<0<j7:1P2WCb`2
0;5D;`030000002aE2l0/E@_00X0/E@_00<0^eTa0000002kFC402`2kFC400`36GS<000000<IN<`0<
0<IN<`030=5R=@000000dF8e00X0dF8e0`3KIcP00`000000ffLh0=]W>0060=]W>0D0iV`i00<00000
0>I/>@3VK3T00`3VK3T90>i`>`030000003dLc`0m7<l00L0m7<l1@3cLS/00`000000lg8k0>M]>005
0>M]>0D0b60a00D0WD`W0000002MC2L0OchO05d^5@0:0<ONa`0300000037g/L0amk700H0amk700<0
00000<ONa`37g/L00P37g/L00`000000amk70<ONa`0;0<ONa`0400000037g/L0amk70<ONa`H00000
0`37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L0
2037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700@0amk70P0000000`37g/L00000
0<ONa`090<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01P37g/L00`000000amk7
0<ONa`0200000080amk700<000000<ONa`37g/L01037g/L01@000000amk70<ONa`37g/L0000000h0
amk70@3oool000h0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`070<ONa`030000
0037g/L0amk700P0amk700<000000<ONa`37g/L02P37g/L010000000amk70<ONa`37g/L600000080
amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700<0
<j7:1@2WCb`20;5D;`030000002aE2l0/E@_00X0/E@_00<0^eTa0000002kFC402`2kFC420<IN<`03
00000036GS<0aUhc00X0aUhc00<0dF8e0000003AHSD02P3AHSD30=]W>0030000003KIcP0ffLh00H0
ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac?03dLc`01`3dLc`40?=b>`03
0000003cLS/0lg8k00H0ifdh1@38H3401@2MC2L0000009e<9`1o?Ql0GBhE00X0amk700<000000<ON
a`37g/L01P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk700/0amk700<000000<ON
a`37g/L01`37g/L6000000T0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`080<ON
a`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L3000000P0amk700<000000<ON
a`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk70080amk70`0000060<ON
a`0500000037g/L0amk70<ONa`0000003P37g/L10?ooo`003P37g/L00`000000amk70<ONa`060<ON
a`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ON
a`D000002037g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700X0amk700@000000<ON
a`37g/L0amk7100cXLX30:M?;080/E@_00<000000;5D;`2aE2l02P2aE2l20;]I<@030000002kFC40
^eTa00T0^eTa0P36GS<00`000000aUhc0<IN<`0:0<IN<`030=5R=@000000dF8e00X0dF8e0`3KIcP0
0`000000ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T90>i`>`030000003dLc`0
m7<l00L0m7<l103cLS/00`000000lg8k0?=b>`060>M]>0D0b60a00D0000009e<9`2MC2L0OchO05d^
5@0:0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ON
a`0;0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L01P0000030<ONa`0300000037
g/L0amk700X0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037
g/L0amk700P0amk700<000000<ONa`0000000P0000050<ONa`0300000037g/L0amk700H0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700D0
00000<ONa`37g/L0amk70000000>0<ONa`40oooo000>0<ONa`0300000037g/L0amk700H0amk700<0
00000<ONa`37g/L01`37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700@0amk71000
00000`37g/L000000<ONa`0:0<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37g/L02P37
g/L00`000000amk70<ONa`020<ONa`@0<j7:0P2WCb`30;5D;`030000002aE2l0/E@_00T0/E@_0P2k
FC400`000000^eTa0;]I<@090;]I<@80aUhc00<000000<IN<`36GS<02P36GS<00`3AHSD000000=5R
=@0:0=5R=@<0ffLh00<000000=]W>03KIcP01P3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i2@3^
L3/00`000000m7<l0?Ac?0070?Ac?0@0lg8k00<000000?=b>`3cLS/01P3WKCP50<QP<@050000002M
C2L0WD`W07ln7`1M;QD02@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk70080amk7
00<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700H0amk7
1@00000:0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk7
0<ONa`080<ONa`0300000037g/L0amk70080amk7100000000`37g/L000000<ONa`070<ONa`030000
0037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L2000000D0amk700D000000<ONa`37g/L0
amk70000000>0<ONa`40oooo000=0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L0
1`37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700@000001@37g/L00`000000amk7
0<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000amk7
0<ONa`040<ONa`<0<j7:00D0Ydl/0;5D;`2aE2l0/E@_0000000;0;5D;`80^eTa00<000000;]I<@2k
FC402@2kFC420<IN<`0300000036GS<0aUhc00X0aUhc00<0dF8e0000003AHSD02P3AHSD30=]W>003
0000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac?03d
Lc`01`3dLc`40?=b>`030000003cLS/0lg8k00H0ifdh1@38H3401@000000WD`W09e<9`1o?Ql0GBhE
00T0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk7
00X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L00000
00<000001P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700<000000<ON
a`37g/L02037g/L00`000000amk70<ONa`060<ONa`8000002037g/L00`000000amk70<ONa`050<ON
a`0300000037g/L0amk700D0amk700<000000<ONa`0000000`37g/L00`000000amk70<ONa`020<ON
a`0300000037g/L0amk700`0amk70@3oool000d0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`080<ONa`0300000037g/L0amk700L0amk7100000090<ONa`0300000037g/L0amk700X0
amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700D0
amk70`0cXLX30;5D;`030000002aE2l0/E@_00T0/E@_0P2kFC400`000000^eTa0;]I<@090;]I<@80
aUhc00<000000<IN<`36GS<02P36GS<00`3AHSD000000=5R=@0:0=5R=@<0ffLh00<000000=]W>03K
IcP01P3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i2@3^L3/00`000000m7<l0?Ac?0070?Ac?0@0
lg8k00<000000?=b>`3cLS/01P3WKCP50<QP<@050000002MC2L0WD`W07ln7`1M;QD02@37g/L00`00
0000amk70<ONa`070<ONa`0500000037g/L0amk70<ONa`0000003@37g/L00`000000amk70<ONa`0:
0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L00`37g/L400000080amk700<00000
0<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<00000
0<ONa`37g/L02037g/L3000000D0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`05
0<ONa`0300000037g/L0amk70080000000<0amk700000037g/L00`37g/L00`000000amk70<ONa`0<
0<ONa`40oooo000=0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`00
0000amk70<ONa`030<ONa`@0000000<0amk700000037g/L02`37g/L00`000000amk70<ONa`090<ON
a`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`060<ON
a`<0<j7:0P2aE2l00`000000/E@_0;5D;`090;5D;`80^eTa00<000000;]I<@2kFC402@2kFC420<IN
<`0300000036GS<0aUhc00X0aUhc00<0dF8e0000003AHSD02P3AHSD30=]W>0030000003KIcP0ffLh
00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac?03dLc`01`3dLc`40?=b
>`030000003cLS/0lg8k00H0ifdh1@38H3401@000000WD`W09e<9`1o?Ql0GBhE00T0amk700<00000
0<ONa`37g/L01`37g/L01@000000amk70<ONa`37g/L0000000d0amk700<000000<ONa`37g/L02P37
g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700L0amk7100000090<ONa`0300000037
g/L0amk700T0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`080<ONa`0300000037
g/L0amk7008000000`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L00`37g/L2000000@0amk700<000000<ONa`37g/L03037g/L10?ooo`003@37g/L0
0`000000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk700<000000<ONa`0000000`000005
0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:
0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L01`37g/L303>QbP030;5D;`000000
/E@_00X0/E@_0P2kFC400`000000^eTa0;]I<@090;]I<@80aUhc00<000000<IN<`36GS<02P36GS<0
0`3AHSD000000=5R=@060=5R=Ad000001`3^L3/00`000000m7<l0?Ac?0070?Ac?0@0lg8k00<00000
0?=b>`3cLS/01P3WKCP50<QP<@050000002MC2L0WD`W07ln7`1M;QD02@37g/L00`000000amk70<ON
a`070<ONa`0500000037g/L0amk70<ONa`0000003@37g/L00`000000amk70<ONa`0:0<ONa`030000
0037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000amk700000003000000D0amk7
00<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk7
00<000000<ONa`37g/L00`37g/L2000000030<ONa`000000amk700L0amk700<000000<ONa`37g/L0
1037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L0
2`37g/L10?ooo`003@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700H0amk70`00
000:0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`0:0<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37g/L01`37g/L303>QbP030000002a
E2l0/E@_00T0/E@_0P2kFC400`000000^eTa0;]I<@050;]I<A`00000103AHSD30=]W>0030000003K
IcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@80kW0k700000020>M]>0D0b60a00D0
000009e<9`2MC2L0OchO05d^5@090<ONa`0300000037g/L0amk700L0amk700D000000<ONa`37g/L0
amk70000000=0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000
amk70<ONa`0:0<ONa`0300000037g/L0amk700<0amk7100000000`37g/L000000<ONa`0:0<ONa`03
00000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`050<ONa`80
00002037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37
g/L00`37g/L00`000000amk70<ONa`0;0<ONa`40oooo000=0<ONa`0300000037g/L0amk700P0amk7
00<000000<ONa`37g/L00`37g/L3000000030<ONa`000000amk700X0amk700<000000<ONa`37g/L0
2@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L0
2`37g/L00`000000amk70<ONa`080<ONa`80<j7:00<000000;5D;`2aE2l01P2aE2l=000000@0^eTa
0P36GS<00`000000aUhc0<IN<`090<IN<`80dF8e00<000000=5R=@3AHSD02@3AHSD30=]W>0030000
003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac?03dLc`0
1`3dLc`40?=b>`030000003cLS/0lg8k00@0ifdh2`0000000`1M;QD0amk70<ONa`070<ONa`030000
0037g/L0amk700L0amk700D000000<ONa`37g/L0amk70000000=0<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0
amk70`0000090<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`060<ONa`<000001@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0
amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`0;0<ONa`40oooo000=0<ONa`030000
0037g/L0amk700P0amk700<000000<ONa`0000000`0000040<ONa`0300000037g/L0amk700T0amk7
00<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700/0amk7
00<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`040<ONa`D0000000<0<j7:0000000cXLX0
1`0000020;5D;`<0^eTa00<000000;]I<@2kFC402@2kFC420<IN<`0300000036GS<0aUhc00T0aUhc
0P3AHSD00`000000dF8e0=5R=@090=5R=@<0ffLh00<000000=]W>03KIcP01P3KIcP50>I/>@030000
003VK3T0iV`i00<0iV`i2@3^L3/00`000000m7<l0?Ac?0070?Ac?0@0lg8k00<000000?=b>`3cLS/0
1P3WKCP50<QP<@040000002MC2L0WD`W07ln7`L000000`37g/L00`000000amk70<ONa`070<ONa`05
00000037g/L0amk70<ONa`0000003@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk7
00X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L00000
00<000001@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ON
a`37g/L01P37g/L00`000000amk70<ONa`02000000<0amk700<000000<ONa`37g/L01@37g/L00`00
0000amk70<ONa`040<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L02`37g/L10?oo
o`003@37g/L00`000000amk70<ONa`080<ONa`8000002@37g/L00`000000amk70<ONa`080<ONa`03
00000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0;0<ONa`03
00000037g/L0amk700L0amk72P0000060<ONa`<0<j7:202aE2l30;]I<@030000002kFC40^eTa00T0
^eTa0P36GS<00`000000aUhc0<IN<`090<IN<`80dF8e00<000000=5R=@3AHSD02@3AHSD30=]W>003
0000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@T0kW0k00<000000?Ac?03d
Lc`01`3dLc`40?=b>`030000003cLS/0lg8k00H0ifdh1@38H3401@000000WD`W09e<9`1o?Ql0GBhE
00H0amk72P0000030<ONa`0500000037g/L0amk70<ONa`0000003037g/L00`000000amk70<ONa`0:
0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`09
0<ONa`0300000037g/L0amk700<0amk7100000000`37g/L000000<ONa`090<ONa`0300000037g/L0
amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`030<ONa`80000000<0amk7
00000037g/L01P37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700@0amk700<00000
0<ONa`37g/L02`37g/L10?ooo`003@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk7
00P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk7
00X0amk700<000000<ONa`37g/L02P37g/L010000000amk70<ONa`37g/L6000000<0amk700<00000
0<ONa`37g/L02P37g/L010000000<j7:03>QbP0cXLX70;5D;`<0^eTa00<000000;]I<@2kFC402@2k
FC420<IN<`0300000036GS<0aUhc00T0aUhc0P3AHSD00`000000dF8e0=5R=@090=5R=@<0ffLh00<0
00000=]W>03KIcP01P3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i2@3^L3/00`000000m7<l0?Ac
?0070?Ac?0@0lg8k00<000000?=b>`3cLS/01P3WKCP50<QP<@050000002MC2L0WD`W07ln7`1M;QD0
2@37g/L00`000000amk70<ONa`040<ONa`/000002@37g/L00`000000amk70<ONa`0:0<ONa`030000
0037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`030000
0037g/L0amk700P0amk70`0000080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L0
1P37g/L00`000000amk70<ONa`050<ONa`8000001`37g/L00`000000amk70<ONa`030<ONa`030000
0037g/L0amk700@0amk700<000000<ONa`37g/L02`37g/L10?ooo`003@37g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L01`37g/L7000000T0amk700<0
00000<ONa`37g/L02P37g/L00`000000amk703>QbP0303>QbPD0/E@_0`2kFC400`000000^eTa0;]I
<@090;]I<@80aUhc00<000000<IN<`36GS<02@36GS<20=5R=@030000003AHSD0dF8e00T0dF8e0`3K
IcP00`000000ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T90>i`>`030000003d
Lc`0m7<l00L0m7<l103cLS/00`000000lg8k0?=b>`060>M]>0D0b60a00D0000009e<9`2MC2L0OchO
05d^5@090<ONa`0300000037g/L0amk700L0amk700D000000<ONa`37g/L0amk7000000030<ONa`H0
00000`37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37
g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`00
00000P0000050<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L00`000000
amk70<ONa`060<ONa`<000001037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0
amk700<000000<ONa`37g/L02`37g/L10?ooo`003@37g/L00`000000amk70<ONa`090<ONa`030000
0037g/L0amk700L0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`030000
0037g/L0amk700T0amk700@000000<ONa`37g/L0amk71P0000030<ONa`0300000037g/L0amk700X0
amk700<000000<ONa`37g/L02`37g/L00`000000amk703>QbP0303>QbP@0/E@_0`2kFC400`000000
^eTa0;]I<@090;]I<@80aUhc00<000000<IN<`36GS<02@36GS<20=5R=@030000003AHSD0dF8e00T0
dF8e0`3KIcP00`000000ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T90>i`>`03
0000003dLc`0m7<l00L0m7<l103cLS/00`000000lg8k0?=b>`060>M]>0D0b60a00D0000009e<9`2M
C2L0OchO05d^5@090<ONa`0300000037g/L0amk700L0amk700D000000<ONa`37g/L0amk700000009
0<ONa`H000002@37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700P0amk700<00000
0<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk70080amk710000000
0`37g/L000000<ONa`080<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L0
0`000000amk70<ONa`0200000080amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`04
0<ONa`0300000037g/L0amk700/0amk70@3oool000d0amk700<000000<ONa`37g/L02@37g/L00`00
0000amk70<ONa`070<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`00
0000amk70<ONa`070<ONa`H000002@37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk7
00/0amk700@000000<ONa`37g/L0amk70`0cXLX30;5D;`<0^eTa00<000000;]I<@2kFC402@2kFC42
0<IN<`0300000036GS<0aUhc00T0aUhc0P3AHSD00`000000dF8e0=5R=@090=5R=@<0ffLh00<00000
0=]W>03KIcP01P3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i2@3^L3/00`000000m7<l0?Ac?007
0?Ac?0@0lg8k00<000000?=b>`3cLS/01P3WKCP50<QP<@050000002MC2L0WD`W07ln7`1M;QD02037
g/L00`000000amk70<ONa`080<ONa`0500000037g/L0amk70<ONa`0000003037g/L00`000000amk7
0<ONa`06000000<0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ONa`030000
0037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`<00000
2037g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L0
0`37g/L3000000H0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`0;0<ONa`40oooo
000=0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700T0amk700@000000<ONa`37g/L0amk71P0000020<ONa`030000
0037g/L0amk700X0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`0:0<ONa`030000
0037g/L0amk70080amk70`0cXLX20;5D;`<0^eTa00<000000;]I<@2kFC402@2kFC420<IN<`030000
0036GS<0aUhc00T0aUhc0`3AHSD00`000000dF8e0=5R=@080=5R=@<0ffLh00<000000=]W>03KIcP0
1P3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i203^L3/00`000000kW0k0?Ac?0080?Ac?0<0lg8k
00@000000?=b>`3cLS/0lg8k1P3WKCP50<QP<@050000002MC2L0WD`W07ln7`1M;QD02037g/L00`00
0000amk70<ONa`080<ONa`0400000037g/L0amk7000000d0amk700<000000<ONa`37g/L01P37g/L7
000000T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0
amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk700000002000000@0amk700<00000
0<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<00000
0<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700/0amk70@3oool0
00d0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk7
00P0amk700<000000<ONa`37g/L02037g/L5000000P0amk700<000000<ONa`37g/L02`37g/L00`00
0000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L00`37g/L303>Q
bP030;5D;`2kFC40^eTa0080^eTa00<000000;]I<@2kFC40202kFC430<IN<`0300000036GS<0aUhc
00P0aUhc0`3AHSD00`000000dF8e0=5R=@080=5R=@<0ffLh00<000000=]W>03KIcP01P3KIcP50>I/
>@030000003VK3T0iV`i00<0iV`i203^L3/00`000000kW0k0?Ac?0080?Ac?0<0lg8k00@000000?=b
>`3cLS/0lg8k1P3WKCP40<QP<@060000002MC2L0WD`W09e<9`1o?Ql0GBhE2037g/L00`000000amk7
0<ONa`080<ONa`0400000037g/L0amk7000000d0amk700<000000<ONa`37g/L02@37g/L010000000
amk70<ONa`37g/L6000000<0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`020<ON
a`<0000000<0amk700000037g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk7
00D0amk70`0000030<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L02`37g/L10?oo
o`003037g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37
g/L02@37g/L00`000000amk70<ONa`030<ONa`@0000000<0amk700000037g/L02`37g/L00`000000
amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000
amk70<ONa`040<ONa`<0<j7:102kFC400`000000^eTa0;]I<@080;]I<@<0aUhc00<000000<IN<`36
GS<02036GS<30=5R=@030000003AHSD0dF8e00P0dF8e0`3KIcP00`000000ffLh0=]W>0060=]W>0D0
iV`i00<000000>I/>@3VK3T00`3VK3T80>i`>`030000003^L3/0m7<l00P0m7<l0`3cLS/010000000
lg8k0?=b>`3cLS/60>M]>0@0b60a00H0000009e<9`2MC2L0WD`W07ln7`1M;QD80<ONa`0300000037
g/L0amk700P0amk700@000000<ONa`37g/L000003037g/L00`000000amk70<ONa`0:0<ONa`030000
0037g/L0amk700L0amk71@00000:0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L0
2@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700H0amk70P0000080<ONa`030000
0037g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L010000000amk70<ONa`0000020<ONa`03
00000037g/L0amk700D0amk700<000000<ONa`37g/L02`37g/L10?ooo`003037g/L00`000000amk7
0<ONa`0;0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
00000003000000D0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`030000
0037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`050<ONa`<0<j7:
0`2kFC400`000000^eTa0;]I<@080;]I<@<0aUhc00<000000<IN<`36GS<02036GS<30=5R=@030000
003AHSD0dF8e00P0dF8e0`3KIcP00`000000ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T0
0`3VK3T80>i`>`030000003^L3/0m7<l00P0m7<l0`3cLS/010000000lg8k0?=b>`3cLS/60>M]>0@0
b60a00H0000009e<9`2MC2L0WD`W07ln7`1M;QD80<ONa`0300000037g/L0amk700P0amk700@00000
0<ONa`37g/L000003037g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<0
00000<ONa`0000000`0000050<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037
g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk70`0000060<ONa`0300000037
g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`020<ONa`<000001`37
g/L00`000000amk70<ONa`0;0<ONa`40oooo000<0<ONa`0300000037g/L0amk700/0amk700<00000
0<ONa`37g/L02037g/L00`000000amk70<ONa`060<ONa`@000002P37g/L00`000000amk70<ONa`09
0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:
0<ONa`0300000037g/L0amk700H0amk70`0cXLX20;]I<@030000002kFC40^eTa00P0^eTa0`36GS<0
0`000000aUhc0<IN<`080<IN<`<0dF8e00<000000=5R=@3AHSD01`3AHSD40=]W>0030000003KIcP0
ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@P0kW0k00<000000>i`>`3dLc`0203dLc`3
0?=b>`040000003cLS/0lg8k0?=b>`H0ifdh1038H3401P000000WD`W09e<9`2MC2L0OchO05d^5@P0
amk700<000000<ONa`37g/L02037g/L010000000amk70<ONa`00000<0<ONa`0300000037g/L0amk7
00T0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`030<ONa`@0000000<0amk70000
0037g/L02P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ON
a`37g/L01`37g/L00`000000amk70<ONa`02000000<0amk700<000000<ONa`37g/L01P37g/L00`00
0000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01@37g/L00`00
0000amk70<ONa`0;0<ONa`40oooo000<0<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37
g/L02037g/L00`000000amk70<ONa`0600000080amk700<000000<ONa`37g/L02@37g/L00`000000
amk70<ONa`090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000
amk70<ONa`0:0<ONa`0300000037g/L0amk700H0amk7100cXLX00`2kFC4000000;]I<@090;]I<@<0
aUhc00<000000<IN<`36GS<02036GS<30=5R=@030000003AHSD0dF8e00L0dF8e103KIcP00`000000
ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T80>i`>`030000003^L3/0m7<l00P0
m7<l0`3cLS/010000000lg8k0?=b>`3cLS/60>M]>0@0b60a00H0000009e<9`2MC2L0WD`W07ln7`1M
;QD80<ONa`0300000037g/L0amk700P0amk700@000000<ONa`37g/L000003037g/L00`000000amk7
0<ONa`090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02037g/L4000000P0amk7
00<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700H0amk7
00<000000<ONa`37g/L00`37g/L2000000030<ONa`000000amk700L0amk700<000000<ONa`37g/L0
1@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L0
2`37g/L10?ooo`003037g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700L0amk71000
00080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ON
a`050<ONa`D0<j7:00<000000;]I<@2kFC40202kFC430<IN<`0300000036GS<0aUhc00P0aUhc0`3A
HSD00`000000dF8e0=5R=@070=5R=@@0ffLh00<000000=]W>03KIcP01P3KIcP50>I/>@030000003V
K3T0iV`i00<0iV`i203^L3/00`000000kW0k0?Ac?0080?Ac?0<0lg8k00@000000?=b>`3cLS/0lg8k
1P3WKCP40<QP<@060000002MC2L0WD`W09e<9`1o?Ql0GBhE2037g/L00`000000amk70<ONa`080<ON
a`0400000037g/L0amk7000000`0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:
0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L01P0000020<ONa`0300000037g/L0
amk700T0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0
amk700D0amk70P0000080<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L0
0`000000amk70<ONa`060<ONa`0300000037g/L0amk700X0amk70@3oool000`0amk700<000000<ON
a`37g/L03037g/L00`000000amk70<ONa`030<ONa`<0000000<0amk700000037g/L02P37g/L00`00
0000amk70<ONa`080<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`00
0000amk70<ONa`0:0<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37g/L02037g/L203>Q
bP030000002kFC40^eTa00P0^eTa0`36GS<00`000000aUhc0<IN<`050<IN<cL00000103dLc`30?=b
>`040000003cLS/0lg8k0?=b>`H0ifdh1038H3401P000000WD`W09e<9`2MC2L0OchO05d^5@L0amk7
00<000000<ONa`37g/L02@37g/L010000000amk70<ONa`00000<0<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700H0
amk71000000:0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`060<ONa`<000001P37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0
amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`0:0<ONa`40oooo000<0<ONa`030000
0037g/L0amk700`0amk700<000000<ONa`0000000`0000040<ONa`0300000037g/L0amk700T0amk7
00<000000<ONa`37g/L02037g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700T0amk7
00<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700@0amk7
1@0000000`0cXLX000000000000D000000<0aUhc0`3AHSD00`000000dF8e0=5R=@070=5R=@@0ffLh
00<000000=]W>03KIcP01P3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i203^L3/00`000000kW0k
0?Ac?0040?Ac?0h000000`3WKCP40<QP<@060000002MC2L0WD`W09e<9`1o?Ql0GBhE1`37g/L00`00
0000amk70<ONa`090<ONa`0300000037g/L0000000d0amk700<000000<ONa`37g/L02@37g/L00`00
0000amk70<ONa`0:0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`00
0000amk700000003000000D0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ON
a`0300000037g/L0amk700H0amk700<000000<ONa`37g/L00P0000030<ONa`0300000037g/L0amk7
00D0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk7
00X0amk70@3oool000`0amk700<000000<ONa`37g/L03037g/L2000000T0amk700<000000<ONa`37
g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37
g/L02P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700L0amk72P0000060<ONa`<0
<j7:202kFC430<IN<`0300000036GS<0aUhc00P0aUhc0`3AHSD00`000000dF8e0=5R=@070=5R=@@0
ffLh00<000000=]W>03KIcP01P3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i203^L3/00`000000
kW0k0?Ac?0080?Ac?0<0lg8k00@000000?=b>`3cLS/0lg8k0`3WKCP>000000H0amk700<000000<ON
a`37g/L02@37g/L00`000000amk70000000=0<ONa`0300000037g/L0amk700T0amk700<000000<ON
a`37g/L02P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ON
a`37g/L00`37g/L4000000030<ONa`000000amk700T0amk700<000000<ONa`37g/L01P37g/L00`00
0000amk70<ONa`060<ONa`0300000037g/L0amk700<0amk70P0000000`37g/L000000<ONa`060<ON
a`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`0:0<ON
a`40oooo000<0<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L02037g/L00`000000
amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000
amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700@000000<ONa`37g/L0amk71P0000030<ON
a`0300000037g/L0amk700X0amk700@0000003>QbP0cXLX0<j7:1`2kFC430<IN<`0300000036GS<0
aUhc00P0aUhc0`3AHSD00`000000dF8e0=5R=@070=5R=@@0ffLh00<000000=]W>03KIcP01P3KIcP5
0>I/>@030000003VK3T0iV`i00<0iV`i203^L3/00`000000kW0k0?Ac?0080?Ac?0<0lg8k00@00000
0?=b>`3cLS/0lg8k1P3WKCP40<QP<@070000002MC2L0WD`W09e<9`1o?Ql0GBhE0<ONa`0=000000D0
amk700<000000<ONa`0000003037g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0
amk70`0000090<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000
amk70<ONa`050<ONa`<000001P37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700L0
amk700<000000<ONa`37g/L02P37g/L10?ooo`003037g/L00`000000amk70<ONa`0<0<ONa`030000
0037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`030000
0037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`040<ONa`X00000
2@37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0<j7:0080<j7:1P2kFC430<IN<`030000
0036GS<0aUhc00P0aUhc0`3AHSD00`000000dF8e0=5R=@070=5R=@@0ffLh00<000000=]W>03KIcP0
1P3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i203^L3/00`000000kW0k0?Ac?0080?Ac?0<0lg8k
00@000000?=b>`3cLS/0lg8k1P3WKCP40<QP<@060000002MC2L0WD`W09e<9`1o?Ql0GBhE1`37g/L0
0`000000amk70<ONa`040<ONa`/000002@37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0
amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0
amk700T0amk700<000000<ONa`0000000P0000050<ONa`0300000037g/L0amk700L0amk700<00000
0<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0400000037g/L00000000000<0amk700<0
00000<ONa`37g/L01037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700X0amk70@3o
ool000`0amk700<000000<ONa`37g/L03@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0
amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0
amk700L0amk72@0000060<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L0
0`000000amk70<ONa`0303>QbPD0^eTa0`36GS<00`000000aUhc0<IN<`080<IN<`<0dF8e00<00000
0=5R=@3AHSD01`3AHSD40=]W>0030000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@03
0>I/>@P0kW0k00<000000>i`>`3dLc`0203dLc`30?=b>`040000003cLS/0lg8k0?=b>`H0ifdh1038
H3401P000000WD`W09e<9`2MC2L0OchO05d^5@L0amk700<000000<ONa`37g/L02@37g/L00`000000
amk7000000030<ONa`H000000`37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700X0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0
amk700<000000<ONa`37g/L00`37g/L4000000030<ONa`000000amk700P0amk700<000000<ONa`37
g/L01P37g/L00`000000amk70<ONa`060<ONa`0400000037g/L0amk70<ONa`80000000<0amk70000
0037g/L01@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700X0amk70@3oool000`0
amk700<000000<ONa`37g/L03@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`0:0<ONa`0400000037g/L0amk70<ON
a`H000000P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ON
a`37g/L02P37g/L010000000amk70<ONa`37g/L303>QbP@0^eTa0`36GS<00`000000aUhc0<IN<`08
0<IN<`<0dF8e00<000000=5R=@3AHSD01`3AHSD40=]W>0030000003KIcP0ffLh00H0ffLh1@3VK3T0
0`000000iV`i0>I/>@030>I/>@P0kW0k00<000000>i`>`3dLc`0203dLc`30?=b>`040000003cLS/0
lg8k0?=b>`H0ifdh0`38H3400`000000b60a09e<9`0209e<9`0307ln7`1M;QD0amk700H0amk700<0
00000<ONa`37g/L02@37g/L00`000000amk7000000090<ONa`H000002@37g/L00`000000amk70<ON
a`0:0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700L0amk70`0000080<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`040<ONa`8000001P37g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700X0amk70@3oool000`0amk700<000000<ONa`37g/L03@37g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L0
0`000000amk70<ONa`070<ONa`H000002037g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0
amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`020<ONa`<0<j7:0`2kFC43
0<IN<`0300000036GS<0aUhc00P0aUhc0`3AHSD00`000000dF8e0=5R=@070=5R=@@0ffLh00<00000
0=]W>03KIcP01P3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i203^L3/00`000000kW0k0?Ac?008
0?Ac?0<0lg8k00@000000?=b>`3cLS/0lg8k1P3WKCP30<QP<@0300000038H340WD`W0080WD`W00<0
OchO05d^5@37g/L01P37g/L00`000000amk70<ONa`090<ONa`8000003@37g/L00`000000amk70<ON
a`06000000<0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`080<ONa`0300000037
g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037
g/L00000008000001037g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<0
00000<ONa`37g/L01@37g/L3000000@0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`0:0<ONa`40oooo000<0<ONa`0300000037g/L0amk700d0amk700<000000<ONa`37g/L02037g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700@000000<ONa`37g/L0amk71P00
00020<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ON
a`090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L00`37g/L303>QbP80^eTa0`36
GS<00`000000aUhc0<IN<`080<IN<`<0dF8e00<000000=5R=@3AHSD01`3AHSD40=]W>0030000003K
IcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@L0kW0k00<000000>i`>`3^L3/02@3d
Lc`30?=b>`040000003cLS/0lg8k0?=b>`H0ifdh0`38H3400`000000b60a09e<9`0209e<9`0307ln
7`1M;QD0amk700H0amk700<000000<ONa`37g/L02@37g/L2000000d0amk700<000000<ONa`37g/L0
1P37g/L6000000T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`030000
0037g/L0amk700T0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`030<ONa`<00000
00<0amk700000037g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700@0amk7
00D000000<ONa`37g/L0amk7000000020<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37
g/L02P37g/L10?ooo`002`37g/L00`000000amk70<ONa`0>0<ONa`0300000037g/L0amk700P0amk7
00<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`060<ONa`H000002037g/L00`000000amk7
0<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`0:0<ONa`0300000037g/L0amk700@0amk70`0cXLX00`2kFC40aUhc0<IN<`020<IN<`030000
0036GS<0aUhc00L0aUhc0`3AHSD00`000000dF8e0=5R=@070=5R=@@0ffLh00<000000=]W>03KIcP0
1P3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i1`3^L3/00`000000kW0k0>i`>`090?Ac?080lg8k
00<000000?=b>`3cLS/00P3cLS/60>M]>0<0b60a00<000000<QP<@2MC2L00P2MC2L00`1o?Ql0GBhE
0<ONa`060<ONa`0300000037g/L0amk700T0amk70P00000<0<ONa`0300000037g/L0amk700X0amk7
00<000000<ONa`37g/L01P0000030<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L0
2037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L0
1P37g/L2000000P0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`040<ONa`030000
0037g/L0amk70080amk70`00000;0<ONa`0300000037g/L0amk700X0amk70@3oool000/0amk700<0
00000<ONa`37g/L03`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700T0amk700<0
00000<ONa`37g/L01P0000020<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02P37
g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02`37
g/L00`000000amk70<ONa`040<ONa`<0<j7:1036GS<00`000000aUhc0<IN<`070<IN<`<0dF8e00<0
00000=5R=@3AHSD01`3AHSD40=]W>0030000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/
>@030>I/>@L0kW0k00<000000>i`>`3^L3/02@3dLc`20?=b>`030000003cLS/0lg8k0080lg8k1P3W
KCP30<QP<@0300000038H340WD`W0080WD`W00<0OchO05d^5@37g/L01P37g/L00`000000amk70<ON
a`090<ONa`8000003037g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700H0amk71P00
00080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700L0amk70`0000060<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700T0amk700<0
00000<ONa`37g/L02P37g/L10?ooo`002`37g/L00`000000amk70<ONa`0?0<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L02037g/L4000000P0amk700<000000<ONa`37g/L02P37g/L0
0`000000amk70<ONa`090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L0
0`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700D0amk70`0cXLX30<IN<`0300000036GS<0
aUhc00L0aUhc0`3AHSD00`000000dF8e0=5R=@070=5R=@@0ffLh00<000000=]W>03KIcP01P3KIcP5
0>I/>@030000003VK3T0iV`i00<0iV`i1`3^L3/00`000000kW0k0>i`>`090?Ac?080lg8k00<00000
0?=b>`3cLS/00P3cLS/60>M]>0<0b60a00<000000<QP<@2MC2L00P2MC2L00`1o?Ql0GBhE0<ONa`05
0<ONa`0300000037g/L0amk700X0amk70P00000<0<ONa`0300000037g/L0amk700T0amk700<00000
0<ONa`37g/L02P37g/L00`000000amk70<ONa`0600000080amk700<000000<ONa`37g/L02@37g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01P37g/L0
10000000amk70<ONa`37g/L2000000<0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ON
a`050<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`0:0<ONa`40oooo000;0<ONa`0300000037g/L0amk700l0amk700<000000<ONa`37g/L02037g/L0
0`000000amk70<ONa`030<ONa`@0000000<0amk700000037g/L02P37g/L00`000000amk70<ONa`09
0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:
0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L01P37g/L303>QbP80aUhc00<00000
0<IN<`36GS<01`36GS<30=5R=@030000003AHSD0dF8e00L0dF8e103KIcP00`000000ffLh0=]W>006
0=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T70>i`>`030000003^L3/0kW0k00T0m7<l0P3cLS/0
0`000000lg8k0?=b>`020?=b>`H0ifdh0`38H3400`000000b60a09e<9`0209e<9`0307ln7`1M;QD0
amk700D0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0
amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`060<ONa`@000002P37g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L0
0`000000amk70<ONa`030<ONa`80000000<0amk700000037g/L01`37g/L00`000000amk70<ONa`04
0<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:
0<ONa`40oooo000;0<ONa`0300000037g/L0amk700l0amk700<000000<ONa`37g/L02037g/L00`00
0000amk700000003000000D0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ON
a`0300000037g/L0amk700X0amk700<000000<ONa`37g/L01`37g/L303>QbP030<IN<`000000aUhc
00P0aUhc0`3AHSD00`000000dF8e0=5R=@070=5R=@@0ffLh00<000000=]W>03KIcP01P3KIcP50>I/
>@030000003VK3T0iV`i00<0iV`i1`3^L3/00`000000kW0k0>i`>`090?Ac?080lg8k00<000000?=b
>`3cLS/00P3cLS/60>M]>0<0b60a00<000000<QP<@2MC2L00P2MC2L00`1o?Ql0GBhE0<ONa`050<ON
a`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`090<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk7000000030000
00D0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk7
00L0amk700<000000<ONa`37g/L01@37g/L3000000L0amk700<000000<ONa`37g/L01037g/L00`00
0000amk70<ONa`040<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L10?oo
o`002`37g/L00`000000amk70<ONa`0?0<ONa`0300000037g/L0amk700L0amk70`00000:0<ONa`03
00000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`03
00000037g/L0amk700P0amk70`0cXLX00`000000aUhc0<IN<`070<IN<`<0dF8e00<000000=5R=@3A
HSD01`3AHSD40=]W>0030000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@L0
kW0k00<000000>i`>`3^L3/02@3dLc`20?=b>`030000003cLS/0lg8k00<0lg8k1@3WKCP20<QP<@03
00000038H340b60a00<0WD`W00<0OchO05d^5@37g/L01@37g/L00`000000amk70<ONa`0:0<ONa`03
00000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700T0amk700<000000<ONa`37g/L00`37g/L4000000030<ONa`000000amk700T0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700H0
amk700@000000<ONa`00000000001037g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk7
00@0amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`090<ONa`40oooo000;0<ONa`03
00000037g/L0amk70100amk700<000000<ONa`37g/L00`37g/L3000000030<ONa`000000amk700X0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0
amk700<000000<ONa`37g/L02@37g/L203>QbP0300000036GS<0aUhc00L0aUhc0`3AHSD00`000000
dF8e0=5R=@050=5R=A/000001P3^L3/00`000000kW0k0>i`>`090?Ac?080lg8k00<000000?=b>`3c
LS/00`3cLS/50>M]>080b60a00<000000<QP<@38H3400`2MC2L00`1o?Ql0GBhE0<ONa`050<ONa`03
00000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`03
00000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`<0
00002@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37
g/L01P37g/L00`000000amk70<ONa`020<ONa`<0000000<0amk700000037g/L01@37g/L00`000000
amk70<ONa`040<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L02@37g/L10?ooo`00
2`37g/L00`000000amk70<ONa`0@0<ONa`0300000037g/L0000000<000001@37g/L00`000000amk7
0<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`090<ONa`0300000037g/L0amk700/0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`0:0<ONa`0300000037g/L0amk700D0amk71@0000000`0cXLX000000000000C00000080dF8e
103KIcP00`000000ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T00`3^L3/00000
0000000I000000@0ifdh0P38H3400`000000b60a0<QP<@0309e<9`0307ln7`1M;QD0amk700D0amk7
00<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700T0amk7
00<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0amk7
00<000000<ONa`0000000P0000060<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L0
1`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk70P0000060<ONa`030000
0037g/L0amk700@0amk700<000000<ONa`37g/L03037g/L00`000000amk70<ONa`090<ONa`40oooo
000;0<ONa`0300000037g/L0amk70100amk70P0000090<ONa`0300000037g/L0amk700P0amk700<0
00000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700X0amk700<0
00000<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700@0amk73P00
00060<ONa`<0<j7:1`36GS<30=5R=@030000003AHSD0dF8e00L0dF8e103KIcP00`000000ffLh0=]W
>0060=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T70>i`>`030000003^L3/0kW0k00T0m7<l0P3c
LS/00`000000lg8k0?=b>`030?=b>`030>M]>0000000000000/0000000<0GBhE0<ONa`37g/L01037
g/L00`000000amk70<ONa`090<ONa`8000003037g/L00`000000amk70<ONa`090<ONa`0300000037
g/L0amk700X0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037
g/L0amk700<0amk7100000000`37g/L000000<ONa`090<ONa`0300000037g/L0amk700L0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`<000001037g/L00`000000amk70<ON
a`040<ONa`0300000037g/L0amk700`0amk700<000000<ONa`37g/L02@37g/L10?ooo`002`37g/L0
0`000000amk70<ONa`0@0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L0
0`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02P37g/L0
0`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700@0amk7300000060<ONa`0300000037g/L0
amk700/0amk700@0000003>QbP0cXLX0<j7:1P36GS<30=5R=@030000003AHSD0dF8e00L0dF8e103K
IcP00`000000ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T70>i`>`030000003^
L3/0kW0k00T0m7<l0P3cLS/00`000000lg8k0?=b>`030?=b>`D0ifdh0P38H3400`000000b60a0<QP
<@0309e<9`0307ln7`000000000000/000001P37g/L2000000`0amk700<000000<ONa`37g/L02@37
g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037
g/L00`000000amk70<ONa`070<ONa`@000002037g/L00`000000amk70<ONa`060<ONa`0300000037
g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L01@000000amk70<ONa`37g/L0000000<0amk7
00<000000<ONa`37g/L01037g/L00`000000amk70<ONa`0<0<ONa`0300000037g/L0amk700T0amk7
0@3oool000/0amk700<000000<ONa`37g/L04@37g/L00`000000amk70<ONa`070<ONa`0300000037
g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037
g/L0amk700T0amk700<000000<ONa`37g/L01037g/L=000000D0amk700<000000<ONa`37g/L02P37
g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0<j7:0080<j7:1@36GS<30=5R=@030000003A
HSD0dF8e00L0dF8e103KIcP00`000000ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T00`3V
K3T70>i`>`030000003^L3/0kW0k00T0m7<l0P3cLS/00`000000lg8k0?=b>`030?=b>`D0ifdh0P38
H3400`000000b60a0<QP<@0309e<9`0307ln7`1M;QD0amk700D0amk700<000000<ONa`37g/L00`37
g/L:000000T0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ONa`0300000037
g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037
g/L0amk700D000000P37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700H0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`020<ONa`<000001P37g/L00`000000amk70<ON
a`0=0<ONa`0300000037g/L0amk700T0amk70@3oool000/0amk700<000000<ONa`37g/L04@37g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L0
0`000000amk70<ONa`090<ONa`0300000037g/L0amk700L0amk72@0000060<ONa`0300000037g/L0
amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0
amk700<0<j7:1036GS<30=5R=@030000003AHSD0dF8e00L0dF8e103KIcP00`000000ffLh0=]W>006
0=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T70>i`>`030000003^L3/0kW0k00T0m7<l0P3cLS/0
0`000000lg8k0?=b>`030?=b>`D0ifdh0P38H3400`000000b60a0<QP<@0309e<9`0307ln7`1M;QD0
amk700D0amk700<000000<ONa`37g/L02@37g/L200000080amk71P0000030<ONa`0300000037g/L0
amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0
amk700T0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`@000002037g/L0
0`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01037g/L0
0`000000amk70<ONa`040<ONa`0300000037g/L0amk700d0amk700<000000<ONa`37g/L02@37g/L1
0?ooo`002`37g/L00`000000amk70<ONa`0A0<ONa`0300000037g/L0amk700P0amk700<000000<ON
a`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700@000000<ON
a`37g/L0amk71P0000020<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L0
0`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700X0amk700@000000<ONa`37g/L0amk70`0c
XLX30<IN<`<0dF8e00<000000=5R=@3AHSD01`3AHSD40=]W>0030000003KIcP0ffLh00H0ffLh1@3V
K3T00`000000iV`i0>I/>@030>I/>@L0kW0k00<000000>i`>`3^L3/02@3dLc`20?=b>`030000003c
LS/0lg8k00<0lg8k1@3WKCP20<QP<@0300000038H340b60a00<0WD`W00<0OchO05d^5@37g/L01@37
g/L00`000000amk70<ONa`090<ONa`8000002037g/L6000000T0amk700<000000<ONa`37g/L02P37
g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037
g/L00`000000amk70<ONa`080<ONa`0300000037g/L00000008000001@37g/L00`000000amk70<ON
a`060<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L3000000@0amk700<0
00000<ONa`37g/L03@37g/L00`000000amk70<ONa`090<ONa`40oooo000;0<ONa`0300000037g/L0
amk70140amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0
amk700T0amk700<000000<ONa`37g/L01P37g/L6000000P0amk700<000000<ONa`37g/L02P37g/L0
0`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L0
0`000000amk70<ONa`020<ONa`<0<j7:0P36GS<30=5R=@030000003AHSD0dF8e00L0dF8e103KIcP0
0`000000ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T70>i`>`030000003^L3/0
kW0k00T0m7<l0P3cLS/00`000000lg8k0?=b>`030?=b>`H0ifdh00@0b60a00000038H340b60a0`2M
C2L00`1o?Ql0GBhE0<ONa`040<ONa`0300000037g/L0amk700X0amk70P00000;0<ONa`0300000037
g/L0amk700H000000`37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700P0amk700<0
00000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<0
00000<ONa`37g/L00`37g/L3000000030<ONa`000000amk700L0amk700<000000<ONa`37g/L01P37
g/L00`000000amk70<ONa`040<ONa`0400000037g/L0amk70<ONa`80000000<0amk700000037g/L0
3`37g/L00`000000amk70<ONa`090<ONa`40oooo000:0<ONa`0300000037g/L0amk701<0amk700<0
00000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700T0amk700<0
00000<ONa`37g/L01P0000020<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37
g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37
g/L00`000000amk70<ONa`030<ONa`<0<j7:00D0aUhc0=5R=@3AHSD0dF8e000000090=5R=@@0ffLh
00<000000=]W>03KIcP01P3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i1`3^L3/00`000000kW0k
0>i`>`090?Ac?080lg8k00<000000?=b>`3cLS/00`3cLS/60>M]>0040<QP<@000000b60a0<QP<@<0
WD`W00<0OchO05d^5@37g/L01037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0000000/0
amk700<000000<ONa`37g/L01P37g/L6000000T0amk700<000000<ONa`37g/L02@37g/L00`000000
amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`060<ONa`<000001`37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0
amk700<000000<ONa`37g/L00`37g/L200000100amk700<000000<ONa`37g/L02@37g/L10?ooo`00
2P37g/L00`000000amk70<ONa`0C0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L0
2037g/L00`000000amk70<ONa`060<ONa`D000002@37g/L00`000000amk70<ONa`090<ONa`030000
0037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ONa`030000
0037g/L0amk700/0amk700<000000<ONa`37g/L00`37g/L303>QbP@0dF8e00<000000=5R=@3AHSD0
1P3AHSD40=]W>0030000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@L0kW0k
00<000000>i`>`3^L3/02@3dLc`00`3cLS/000000?=b>`050?=b>`H0ifdh00@0b60a00000038H340
b60a0`2MC2L00`1o?Ql0GBhE0<ONa`040<ONa`0300000037g/L0amk700T0amk700<000000<ONa`00
00002P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700H000000`37g/L00`000000
amk70<ONa`090<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000
amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700@000000<ONa`00000000001@37g/L00`00
0000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L00`00
0000amk70<ONa`0>0<ONa`0300000037g/L0amk700T0amk70@3oool000X0amk700<000000<ONa`37
g/L04`37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37
g/L01P0000020<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000
amk70<ONa`0:0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000
amk70<ONa`0;0<ONa`0300000037g/L0amk700@0amk70`0cXLX30=5R=@030000003AHSD0dF8e00H0
dF8e103KIcP00`000000ffLh0=]W>0060=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T70>i`>`03
0000003^L3/0kW0k00T0m7<l00<0lg8k0000003cLS/01@3cLS/60>M]>00400000038H340b60a0<QP
<@<0WD`W00<0OchO05d^5@37g/L01037g/L00`000000amk70<ONa`090<ONa`0300000037g/L00000
00X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`060<ONa`H000002037g/L00`00
0000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`00
0000amk70<ONa`060<ONa`0300000037g/L0amk70080amk70`0000000`37g/L000000<ONa`070<ON
a`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`0?0<ON
a`0300000037g/L0amk700T0amk70@3oool000X0amk700<000000<ONa`37g/L05037g/L00`000000
amk70<ONa`070<ONa`0300000037g/L0amk700H0amk71@0000080<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0;0<ONa`0300000037g/L0amk700D0
amk70`0cXLX20=5R=@030000003AHSD0dF8e00H0dF8e103KIcP00`000000ffLh0=]W>0060=]W>0D0
iV`i00<000000>I/>@3VK3T00`3VK3T70>i`>`030000003^L3/0kW0k00T0m7<l00<0lg8k0000003c
LS/01@3cLS/60>M]>00400000038H340b60a0<QP<@<0WD`W0P1o?Ql50<ONa`0300000037g/L0amk7
00T0amk700<000000<ONa`0000002P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk7
00X0amk700<000000<ONa`37g/L01P0000020<ONa`0300000037g/L0amk700P0amk700<000000<ON
a`37g/L02037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ON
a`37g/L01@37g/L2000000L0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ON
a`0300000037g/L0amk700l0amk700<000000<ONa`37g/L02@37g/L10?ooo`002P37g/L00`000000
amk70<ONa`0D0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01@0000020<ONa`03
00000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ONa`03
00000037g/L0amk700/0amk700<000000<ONa`37g/L01P37g/L203>QbP80dF8e00<000000=5R=@3A
HSD01P3AHSD40=]W>0030000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@L0
kW0k00<000000>i`>`3^L3/02@3dLc`00`3cLS/000000?=b>`050?=b>`H0ifdh00@000000<QP<@38
H340b60a0`2MC2L207ln7`D0amk700<000000<ONa`37g/L02@37g/L00`000000amk70000000:0<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`070<ON
a`D000002037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk700<000000<ON
a`37g/L01`37g/L00`000000amk70<ONa`060<ONa`<000001@37g/L00`000000amk70<ONa`050<ON
a`0300000037g/L0amk700@0amk700<000000<ONa`37g/L03`37g/L00`000000amk70<ONa`090<ON
a`40oooo000:0<ONa`0300000037g/L0amk701@0amk700<000000<ONa`37g/L01`37g/L4000000P0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700X0
amk700<000000<ONa`37g/L02`37g/L00`000000amk70<ONa`060<ONa`<0<j7:00<0dF8e0000003A
HSD01`3AHSD40=]W>0030000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@L0
kW0k00<000000>i`>`3^L3/02@3dLc`00`3cLS/000000?=b>`050?=b>`H0ifdh00@000000<QP<@38
H340b60a0`2MC2L207ln7`D0amk700<000000<ONa`37g/L02@37g/L00`000000amk70000000:0<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ON
a`0300000037g/L0amk700D000000P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk7
00P0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0400000037g/L0amk7
0<ONa`8000000`37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700<0amk700<00000
0<ONa`37g/L04@37g/L00`000000amk70<ONa`080<ONa`40oooo000:0<ONa`0300000037g/L0amk7
01@0amk700<000000<ONa`37g/L01037g/L3000000030<ONa`000000amk700T0amk700<000000<ON
a`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ON
a`37g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700/0amk700<000000<ON
a`37g/L02P37g/L00`000000amk70<ONa`070<ONa`<0<j7:00<000000=5R=@3AHSD01P3AHSD40=]W
>0030000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@L0kW0k00<000000>i`
>`3^L3/02@3dLc`00`3cLS/000000?=b>`050?=b>`H0ifdh00@000000<QP<@38H340b60a0`2MC2L2
07ln7`D0amk700<000000<ONa`37g/L02@37g/L00`000000amk7000000090<ONa`0300000037g/L0
amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0
amk700H0amk7100000090<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L0
0`000000amk70<ONa`060<ONa`0300000037g/L0amk700<0amk70`0000070<ONa`0300000037g/L0
amk700@0amk700<000000<ONa`37g/L04@37g/L00`000000amk70<ONa`080<ONa`40oooo000:0<ON
a`0300000037g/L0amk701D0amk700<000000<ONa`0000000`0000050<ONa`0300000037g/L0amk7
00L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk7
00T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk7
00X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`080<ONa`80<j7:00<000000=5R
=@3AHSD01P3AHSD40=]W>0030000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/
>@L0kW0k00<000000>i`>`3^L3/02@3dLc`00`3cLS/000000?=b>`050?=b>`H0ifdh00@000000<QP
<@38H340b60a0`2MC2L207ln7`@0amk700<000000<ONa`37g/L02P37g/L00`000000amk700000009
0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`08
0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`0000000P0000060<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0
amk700D0amk70P0000060<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L04@37g/L0
0`000000amk70<ONa`080<ONa`40oooo000:0<ONa`0300000037g/L0amk701D0amk70P0000090<ON
a`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ON
a`0300000037g/L0amk700X0amk700<000000<ONa`37g/L01037g/LB0000000303>QbP0000000000
03X000001P3WKCP010000000b60a0<QP<@38H34309e<9`80OchO1037g/L00`000000amk70<ONa`09
0<ONa`0400000037g/L0amk7000000T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ON
a`030<ONa`@0000000<0amk700000037g/L02@37g/L00`000000amk70<ONa`060<ONa`0300000037
g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L010000000amk70000000000040<ONa`030000
0037g/L0amk700@0amk700<000000<ONa`37g/L04@37g/L00`000000amk70<ONa`080<ONa`40oooo
000:0<ONa`0300000037g/L0amk701D0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`040<ONa`d000001P37g/L00`000000amk70<ONa`0:0<ONa`<0<j7:1P3AHSD40=]W>0030000003K
IcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@L0kW0k00<000000>i`>`3^L3/02@3d
Lc`00`3cLS/000000?=b>`050?=b>`d000000P1o?Ql40<ONa`0300000037g/L0amk700T0amk700@0
00000<ONa`37g/L000002@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk7
00<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk7
100000080<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk7
0<ONa`050<ONa`0300000037g/L0amk70080amk70P0000000`37g/L000000<ONa`050<ONa`030000
0037g/L0amk70180amk700<000000<ONa`37g/L02037g/L10?ooo`002P37g/L00`000000amk70<ON
a`0F0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`090<ONa`0300000037g/L0amk700@0amk7300000060<ONa`0300000037g/L0amk700X0amk700<0
00000<ONa`37g/L02P37g/L010000000<j7:03>QbP0cXLX50=5R=@@0ffLh00<000000=]W>03KIcP0
1P3KIcP50>I/>@030000003VK3T0iV`i00<0iV`i1`3^L3/00`000000kW0k0>i`>`090?Ac?0030?=b
>`000000lg8k00D0lg8k1P3WKCP010000000b60a0<QP<@38H34309e<9``000001P37g/L010000000
amk70<ONa`0000090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`00
0000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`00
0000amk70<ONa`0500000080amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ON
a`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01037g/L2000000H0amk700<000000<ON
a`37g/L04P37g/L00`000000amk70<ONa`080<ONa`40oooo000:0<ONa`0300000037g/L0amk701H0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700P0
amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700@0
amk7300000050<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000
amk70<ONa`0:0<ONa`0300000037g/L0<j7:0080<j7:103AHSD40=]W>0030000003KIcP0ffLh00H0
ffLh1@3VK3T00`000000iV`i0>I/>@030>I/>@L0kW0k00<000000>i`>`3^L3/02@3dLc`00`3cLS/0
00000?=b>`050?=b>`H0ifdh00@000000<QP<@38H340b60a0`2MC2L207ln7`@0amk700<000000<ON
a`37g/L00`37g/L:000000P0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`080<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ON
a`0300000037g/L0amk700H0amk7100000070<ONa`0300000037g/L0amk700H0amk700<000000<ON
a`37g/L01P37g/L00`000000amk70<ONa`050<ONa`<000001037g/L00`000000amk70<ONa`0B0<ON
a`0300000037g/L0amk700P0amk70@3oool000X0amk700<000000<ONa`37g/L05P37g/L00`000000
amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000
amk70<ONa`090<ONa`0300000037g/L0amk700L0amk72@0000050<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0
amk700<000000<ONa`37g/L00`0cXLX30=5R=@@0ffLh00<000000=]W>03KIcP01P3KIcP50>I/>@03
0000003VK3T0iV`i00<0iV`i1`3^L3/00`000000kW0k0>i`>`090?Ac?0030?=b>`000000lg8k00D0
lg8k1P3WKCP010000000b60a0<QP<@38H34309e<9`80OchO1037g/L00`000000amk70<ONa`090<ON
a`0300000037g/L0amk700H000000`37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk7
00T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk7
00P0amk700<000000<ONa`37g/L02037g/L010000000amk70000000000050<ONa`0300000037g/L0
amk700H0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0400000037g/L0
amk70<ONa`80000000<0amk700000037g/L05037g/L00`000000amk70<ONa`080<ONa`40oooo000:
0<ONa`0300000037g/L0amk701H0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`08
0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`06
00000080amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0
amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ONa`0400000037g/L0
amk70<ONa`<0<j7:0P3AHSD40=]W>0030000003KIcP0ffLh00H0ffLh1@3VK3T00`000000iV`i0>I/
>@030>I/>@L0kW0k00<000000>i`>`3^L3/02@3dLc`00`3cLS/000000?=b>`050?=b>`D0ifdh00<0
00000<QP<@38H3400P38H34309e<9`80OchO0`37g/L00`000000amk70<ONa`0:0<ONa`0400000037
g/L0amk7000000D0amk72@0000060<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L0
2037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L0
1`37g/L00`000000amk70<ONa`020<ONa`<0000000<0amk700000037g/L01`37g/L00`000000amk7
0<ONa`060<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L00`37g/L2000001D0amk7
00<000000<ONa`37g/L02037g/L10?ooo`002@37g/L00`000000amk70<ONa`0H0<ONa`0300000037
g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037
g/L0amk700L0amk71@0000080<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02@37
g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02P37
g/L00`000000amk70<ONa`020<ONa`<0<j7:00<0dF8e0=]W>03KIcP00P3KIcP00`000000ffLh0=]W
>0060=]W>0D0iV`i00<000000>I/>@3VK3T00`3VK3T70>i`>`030000003^L3/0kW0k00T0m7<l00<0
lg8k0000003cLS/01@3cLS/50>M]>00300000038H340b60a0080b60a0`2MC2L207ln7`<0amk700<0
00000<ONa`37g/L02@37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L00`37g/L9000000T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ON
a`050<ONa`<000001`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`0C0<ONa`0300000037g/L0amk700P0amk70@3o
ool000T0amk700<000000<ONa`37g/L06037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L02037g/L010000000amk70<ONa`37g/L600000080amk700<0
00000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<0
00000<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700X0amk700<0
00000<ONa`37g/L00`37g/L303>QbP@0ffLh00<000000=]W>03KIcP01P3KIcP50>I/>@030000003V
K3T0iV`i00<0iV`i1`3^L3/00`000000kW0k0>i`>`090?Ac?0030?=b>`000000lg8k00D0lg8k1@3W
KCP00`000000b60a0<QP<@020<QP<@<0WD`W0P1o?Ql30<ONa`0300000037g/L0amk700T0amk700<0
00000<ONa`37g/L00P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700T0amk700<0
00000<ONa`37g/L01P0000020<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L01`37
g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01P37
g/L010000000amk70000000000050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L0
1037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk701@0amk700<000000<ONa`37g/L0
2037g/L10?ooo`002@37g/L00`000000amk70<ONa`0H0<ONa`0300000037g/L0amk700P0amk700<0
00000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`H000002037g/L00`000000amk70<ON
a`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ON
a`030<ONa`<0<j7:103KIcP00`000000ffLh0=]W>0040=]W>0D0iV`i00<000000>I/>@3VK3T0103V
K3T60>i`>`040000003^L3/0kW0k0>i`>`T0m7<l00<000000?=b>`3cLS/01@3cLS/50>M]>0030000
0038H340b60a0080b60a0`2MC2L207ln7`<0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`020<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`070<ONa`D000002@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk7
00<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk70080amk7
0`0000000`37g/L000000<ONa`070<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L0
1037g/L00`000000amk70<ONa`0D0<ONa`0300000037g/L0amk700P0amk70@3oool000T0amk700<0
00000<ONa`37g/L06@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk700<0
00000<ONa`37g/L01@0000020<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02037
g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02P37
g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L01037
g/L303>QbP<0ffLh00<000000=]W>03KIcP0103KIcP50>I/>@030000003VK3T0iV`i00@0iV`i1P3^
L3/010000000kW0k0>i`>`3^L3/90?Ac?0030000003cLS/0lg8k00D0lg8k1@3WKCP00`000000b60a
0<QP<@020<QP<@<0WD`W0P1o?Ql30<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L0
0P37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L0
2@37g/L00`000000amk70<ONa`0600000080amk700<000000<ONa`37g/L02037g/L00`000000amk7
0<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L00`000000amk7
0<ONa`050<ONa`<000001`37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk7
00<000000<ONa`37g/L05@37g/L00`000000amk70<ONa`080<ONa`40oooo00090<ONa`0300000037
g/L0amk701T0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`D000002037
g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37
g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02P37
g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700@0amk70`0cXLX30=]W>0030000003K
IcP0ffLh00@0ffLh1@3VK3T00`000000iV`i0>I/>@040>I/>@H0kW0k00@000000>i`>`3^L3/0kW0k
2@3dLc`00`000000lg8k0?=b>`050?=b>`D0ifdh00<000000<QP<@38H3400P38H34309e<9`80OchO
0P37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L0
1037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L0
1`37g/L5000000P0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`030000
0037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L010000000amk70000000000050<ONa`03
00000037g/L0amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`0E0<ONa`03
00000037g/L0amk700P0amk70@3oool000T0amk700<000000<ONa`37g/L06@37g/L00`000000amk7
0<ONa`080<ONa`0300000037g/L0amk700D000000P37g/L00`000000amk70<ONa`080<ONa`030000
0037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`0:0<ONa`030000
0037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ONa`030000
0037g/L0amk700X0amk700<000000<ONa`37g/L01037g/L403>QbP80ffLh00<000000=]W>03KIcP0
103KIcP50>I/>@030000003VK3T0iV`i00@0iV`i1P3^L3/010000000kW0k0>i`>`3^L3/90?Ac?003
0000003cLS/0lg8k00D0lg8k1@3WKCP00`000000b60a0<QP<@020<QP<@<0WD`W0P1o?Ql20<ONa`03
00000037g/L0amk700T0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`040<ONa`03
00000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700D000000P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0
amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk70080
amk70`0000000`37g/L000000<ONa`060<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37
g/L05@37g/L00`000000amk70<ONa`080<ONa`40oooo00090<ONa`0300000037g/L0amk701T0amk7
00<000000<ONa`37g/L01P37g/L5000000P0amk700<000000<ONa`37g/L01`37g/L00`000000amk7
0<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000amk7
0<ONa`0:0<ONa`0300000037g/L0amk700H0amk70`0cXLX00`3KIcP000000=]W>0050=]W>0D0iV`i
00<000000>I/>@3VK3T0103VK3T60>i`>`040000003^L3/0kW0k0>i`>`T0m7<l00<000000?=b>`3c
LS/01@3cLS/50>M]>00300000038H340b60a0080b60a0`2MC2L207ln7`80amk700<000000<ONa`37
g/L02@37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37
g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37
g/L01P37g/L4000000T0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`03
00000037g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L2000000H0amk700<000000<ONa`37
g/L01037g/L00`000000amk70<ONa`0G0<ONa`0300000037g/L0amk700L0amk70@3oool000T0amk7
00<000000<ONa`37g/L06P37g/L00`000000amk70<ONa`0500000080amk700<000000<ONa`37g/L0
2037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L0
2@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L0
2P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L0
1`37g/L303>QbP030000003KIcP0ffLh00@0ffLh1@3VK3T00`000000iV`i0>I/>@040>I/>@H0kW0k
00@000000>i`>`3^L3/0kW0k2@3dLc`00`000000lg8k0?=b>`050?=b>`@0ifdh00<000000>M]>038
H3400`38H34309e<9`80OchO0P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700<0
amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L000000080
00001P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37
g/L01P37g/L00`000000amk70<ONa`060<ONa`<000001037g/L00`000000amk70<ONa`040<ONa`03
00000037g/L0amk701L0amk700<000000<ONa`37g/L01`37g/L10?ooo`002@37g/L00`000000amk7
0<ONa`0J0<ONa`<000002037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk7
00<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0amk7
00<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700T0amk7
00<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`080<ONa`<0<j7:1P3KIcP50>I/>@030000
003VK3T0iV`i00@0iV`i1P3^L3/010000000kW0k0>i`>`3^L3/90?Ac?0030000003cLS/0lg8k00D0
lg8k103WKCP00`000000ifdh0<QP<@030<QP<@<0WD`W0P1o?Ql00`1M;QD0amk70000000;0<ONa`03
00000037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`070<ONa`03
00000037g/L0amk700<0amk7100000000`37g/L000000<ONa`080<ONa`0300000037g/L0amk700L0
amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0400000037g/L0amk70<ON
a`80000000<0amk700000037g/L01P37g/L00`000000amk70<ONa`0G0<ONa`0300000037g/L0amk7
00L0amk70@3oool000T0amk700<000000<ONa`37g/L06P37g/L00`000000amk70<ONa`080<ONa`03
00000037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ONa`03
00000037g/L0amk700T0amk700<000000<ONa`37g/L01037g/LN0000000303>QbP000000000002X0
00000P3cLS/40>M]>0030000003WKCP0b60a00<0b60a0`2MC2L207ln7`0305d^5@000000amk700/0
amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700L0
amk700<000000<ONa`37g/L01`37g/L4000000L0amk700<000000<ONa`37g/L01P37g/L00`000000
amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L00`37g/L2000000H0
amk700<000000<ONa`37g/L06037g/L00`000000amk70<ONa`070<ONa`40oooo00090<ONa`030000
0037g/L0amk701/0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`080<ONa`030000
0037g/L0amk700L0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`030000
0037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`040<ONa``00000
1@37g/L00`000000amk70<ONa`0:0<ONa`0300000037g/L0amk700X0amk70P0cXLX50=]W>0D0iV`i
00<000000>I/>@3VK3T0103VK3T60>i`>`040000003^L3/0kW0k0>i`>`T0m7<l00<000000?=b>`3c
LS/00`3cLS/<000000<0WD`W0P1o?Ql00`1M;QD000000<ONa`0:0<ONa`0300000037g/L0amk700@0
amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0
amk700<000000<ONa`37g/L0100000020<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37
g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk70`0000040<ONa`03
00000037g/L0amk701P0amk700<000000<ONa`37g/L01`37g/L10?ooo`002@37g/L00`000000amk7
0<ONa`0K0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`000000amk7
0<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`090<ONa`0300000037g/L0amk700@0amk7300000050<ONa`0300000037g/L0amk700T0amk7
00<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`030000000cXLX0<j7:00@0ffLh
1@3VK3T00`000000iV`i0>I/>@040>I/>@H0kW0k00@000000>i`>`3^L3/0kW0k2@3dLc`00`000000
lg8k0?=b>`050?=b>`@0ifdh00<000000>M]>038H3400`38H34<000000H0amk700<000000<ONa`37
g/L01037g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37
g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37
g/L01`37g/L00`000000amk70<ONa`050<ONa`@000002037g/L00`000000amk70<ONa`050<ONa`03
00000037g/L0amk700H0amk700<000000<ONa`37g/L01037g/L010000000amk70<ONa`37g/L20000
00030<ONa`000000amk701X0amk700<000000<ONa`37g/L01`37g/L10?ooo`002@37g/L00`000000
amk70<ONa`0K0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000
amk70<ONa`040<ONa``000001@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`0:0<ONa`040000000cXLX0<j7:03>Q
bP<0ffLh1@3VK3T00`000000iV`i0>I/>@040>I/>@H0kW0k00@000000>i`>`3^L3/0kW0k2@3dLc`0
0`000000lg8k0?=b>`050?=b>`@0ifdh00<000000>M]>038H3400`38H34309e<9`80OchO00<0GBhE
00000037g/L01037g/L<000000030<ONa`000000amk700<0amk700<000000<ONa`37g/L02@37g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L01`37g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`0000000P000005
0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`05
0<ONa`0300000037g/L0amk700<0amk70P00000K0<ONa`0300000037g/L0amk700L0amk70@3oool0
00T0amk700<000000<ONa`37g/L07037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk7
00P0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk7
00<0amk7300000050<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`00
0000amk70<ONa`0:0<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`00
0000amk703>QbP0203>QbP80ffLh1@3VK3T00`000000iV`i0>I/>@040>I/>@H0kW0k00@000000>i`
>`3^L3/0kW0k203dLc`00`000000lg8k0?=b>`060?=b>`@0ifdh00<000000>M]>038H3400`38H343
09e<9`80OchO00<0GBhE00000037g/L02P37g/L00`000000amk70<ONa`030<ONa`T000002@37g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L00`37g/L3
000000030<ONa`000000amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`04
0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L06@37g/L00`000000amk70<ONa`07
0<ONa`40oooo00080<ONa`0300000037g/L0amk701d0amk700<000000<ONa`37g/L02037g/L00`00
0000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L80000
00D0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk7
00X0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk7
00X0amk700<000000<ONa`37g/L00`0cXLX00`3KIcP0iV`i0>I/>@030>I/>@030000003VK3T0iV`i
00@0iV`i1P3^L3/010000000kW0k0>i`>`3^L3/80?Ac?0030000003cLS/0lg8k00H0lg8k0`3WKCP0
0`000000ifdh0>M]>0040<QP<@<0WD`W0P1o?Ql00`1M;QD000000<ONa`0:0<ONa`0300000037g/L0
amk700@0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`0600000080amk700<00000
0<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<00000
0<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700H0amk70`000006
0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`04
0<ONa`0300000037g/L0amk701X0amk700<000000<ONa`37g/L01`37g/L10?ooo`002037g/L00`00
0000amk70<ONa`0M0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`00
0000amk70<ONa`080<ONa`0300000037g/L0amk700H000000P37g/L00`000000amk70<ONa`090<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ON
a`0400000037g/L0amk70<ONa`<0<j7:1@3VK3T00`000000iV`i0>I/>@040>I/>@H0kW0k00@00000
0>i`>`3^L3/0kW0k203dLc`00`000000lg8k0?=b>`060?=b>`<0ifdh00<000000>M]>03WKCP01038
H34309e<9`80OchO00<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`040<ONa`0300000037
g/L0amk70080amk700<000000<ONa`37g/L01P37g/L5000000T0amk700<000000<ONa`37g/L02037
g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37
g/L00`000000amk70<ONa`070<ONa`0400000037g/L00000000000@0amk700<000000<ONa`37g/L0
1@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0
6P37g/L00`000000amk70<ONa`070<ONa`40oooo00080<ONa`0300000037g/L0amk701h0amk700<0
00000<ONa`37g/L02037g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk71@00
00090<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L00P37g/L303>QbP@0iV`i00<0
00000>I/>@3VK3T0103VK3T60>i`>`040000003^L3/0kW0k0>i`>`P0m7<l00<000000?=b>`3cLS/0
1P3cLS/30>M]>0030000003WKCP0ifdh00@0b60a0`2MC2L207ln7`0300000037g/L0amk700T0amk7
00<000000<ONa`37g/L01@37g/L01@000000amk70<ONa`37g/L0000000/0amk700<000000<ONa`37
g/L01P0000020<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`020<ONa`80000000<0amk700000037g/L01P37g/L00`000000amk70<ONa`050<ONa`03
00000037g/L0amk700@0amk700<000000<ONa`37g/L06`37g/L00`000000amk70<ONa`070<ONa`40
oooo00080<ONa`0300000037g/L0amk701h0amk700<000000<ONa`37g/L02037g/L00`000000amk7
0<ONa`070<ONa`0300000037g/L0amk700D000000P37g/L00`000000amk70<ONa`090<ONa`030000
0037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`030000
0037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`0:0<ONa`030000
0037g/L0amk700T0amk700<000000<ONa`37g/L00`37g/L303>QbP<0iV`i00<000000>I/>@3VK3T0
103VK3T50>i`>`030000003^L3/0kW0k0080kW0k203dLc`00`000000lg8k0?=b>`060?=b>`<0ifdh
00<000000>M]>03WKCP01038H34309e<9`80OchO00<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`050<ONa`0500000037g/L0amk70<ONa`0000002`37g/L00`000000amk70<ONa`060<ONa`P0
00001@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37
g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700@0amk70`0000060<ONa`03
00000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`0K0<ONa`03
00000037g/L0amk700L0amk70@3oool000P0amk700<000000<ONa`37g/L07`37g/L00`000000amk7
0<ONa`070<ONa`0300000037g/L0amk700D0amk71@0000080<ONa`0300000037g/L0amk700P0amk7
00<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk7
00<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700X0amk7
00<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`040<ONa`<0<j7:0P3VK3T00`000000iV`i
0>I/>@040>I/>@D0kW0k00<000000>i`>`3^L3/00P3^L3/80?Ac?0030000003cLS/0lg8k00H0lg8k
0`3WKCP00`000000ifdh0>M]>0040<QP<@<0WD`W0P1o?Ql00`000000amk70<ONa`090<ONa`030000
0037g/L0amk700D0amk700D000000<ONa`37g/L0amk70000000:0<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L00`37g/L8000000P0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`060<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L00`000000
amk700000003000000030<ONa`000000amk700L0amk700<000000<ONa`37g/L01037g/L00`000000
amk70<ONa`0K0<ONa`0300000037g/L0amk700L0amk70@3oool000P0amk700<000000<ONa`37g/L0
7`37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700@000000P37g/L00`000000amk7
0<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`090<ONa`0300000037g/L0amk700X0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`050<ONa`80<j7:0P3VK3T00`000000iV`i0>I/>@040>I/>@D0kW0k00<000000>i`>`3^L3/0
0P3^L3/80?Ac?0030000003cLS/0lg8k00H0lg8k0`3WKCP00`000000ifdh0>M]>0040<QP<@<0WD`W
0P1o?Ql00`000000amk70<ONa`090<ONa`0300000037g/L0amk700D0amk700D000000<ONa`37g/L0
amk70000000:0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000
amk70<ONa`0500000080amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`03
00000037g/L0amk700L0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`<0
00001P37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk701`0amk700<000000<ONa`37
g/L01`37g/L10?ooo`002037g/L00`000000amk70<ONa`0O0<ONa`0300000037g/L0amk700H0amk7
1@0000070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02@37g/L00`000000amk7
0<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk7
0<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02P37g/L00`000000amk7
0<ONa`090<ONa`0300000037g/L0amk700D0amk70`0cXLX00`3VK3T000000>I/>@050>I/>@D0kW0k
00<000000>i`>`3^L3/00P3^L3/80?Ac?0030000003cLS/0lg8k00H0lg8k0`3WKCP00`000000ifdh
0>M]>0040<QP<@<0WD`W0P1o?Ql00`000000amk70<ONa`090<ONa`0300000037g/L0amk700D0amk7
00D000000<ONa`37g/L0amk70000000:0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37
g/L02037g/L00`000000amk70<ONa`060<ONa`@000002037g/L00`000000amk70<ONa`070<ONa`03
00000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`04
00000037g/L00000000000@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`0L0<ON
a`0300000037g/L0amk700L0amk70@3oool000P0amk700<000000<ONa`37g/L08037g/L00`000000
amk70<ONa`0500000080amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`080<ONa`03
00000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700P0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`060<ONa`<0
<j7:00<000000>I/>@3VK3T0103VK3T50>i`>`030000003^L3/0kW0k0080kW0k1`3dLc`00`000000
m7<l0?=b>`070?=b>`<0ifdh00<000000>M]>03WKCP01038H34309e<9`80OchO00<000000<ONa`37
g/L02@37g/L00`000000amk70<ONa`050<ONa`0400000037g/L0amk7000000/0amk700<000000<ON
a`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ON
a`0000000P0000050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01`37g/L00`00
0000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L00P37g/L20000
00030<ONa`000000amk700H0amk700<000000<ONa`37g/L07@37g/L00`000000amk70<ONa`060<ON
a`40oooo00080<ONa`0300000037g/L0amk70200amk70`0000080<ONa`0300000037g/L0amk700H0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L01`37g/L203>QbP030000003VK3T0iV`i00@0iV`i1@3^L3/00`000000
kW0k0>i`>`020>i`>`L0m7<l00<000000?Ac?03cLS/01`3cLS/20>M]>0040000003WKCP0ifdh0>M]
>0@0b60a0`2MC2L00`1o?Ql0000005d^5@0;0<ONa`0300000037g/L0amk700D0amk700@000000<ON
a`37g/L000002P37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700<00000
0<ONa`37g/L01`37g/L00`000000amk70<ONa`030<ONa`<0000000<0amk700000037g/L02037g/L0
0`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L0
0`000000amk70<ONa`040<ONa`8000001P37g/L00`000000amk70<ONa`0N0<ONa`0300000037g/L0
amk700H0amk70@3oool000P0amk700<000000<ONa`37g/L08037g/L00`000000amk70<ONa`080<ON
a`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`080<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`040<ON
ab<0000000<0iV`i0>i`>`3^L3/00`3^L3/00`000000kW0k0>i`>`020>i`>`L0m7<l00<000000?Ac
?03cLS/01`3cLS/20>M]>0040000003WKCP0ifdh0>M]>0@0b60a0`2MC2L00`1o?Ql0000005d^5@0:
0<ONa`0300000037g/L0amk700H0amk700@000000<ONa`37g/L000002P37g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`060<ONa`@000001`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<0
00000<ONa`37g/L01037g/L00`000000amk70<ONa`060<ONa`<000001037g/L00`000000amk70<ON
a`0N0<ONa`0300000037g/L0amk700H0amk70@3oool000P0amk700<000000<ONa`37g/L08@37g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L02037g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700@0amk7600000050<ONa`0300000037g/L0
amk700T0amk700<000000<ONa`37g/L02037g/L0101b>240<j7:03>QbP0cXLX30>I/>AP00000103c
LS/20>M]>0040000003WKCP0ifdh0>M]>0@0b60a0`2MC2L00`1o?Ql0000005d^5@0:0<ONa`030000
0037g/L0amk700H0amk700@000000<ONa`37g/L000002P37g/L00`000000amk70<ONa`080<ONa`03
00000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`03
00000037g/L0amk700@000000P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0
amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0400000037g/L0amk70<ON
a`80000000<0amk700000037g/L08037g/L00`000000amk70<ONa`060<ONa`40oooo00080<ONa`03
00000037g/L0amk70240amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`060<ONa`03
00000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`03
00000037g/L0amk700T0amk700<000000<ONa`37g/L00`37g/L<000000D0amk700<000000<ONa`37
g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37
g/L02037g/L00`1b>240000003>QbP0203>QbP<0iV`i1@3^L3/00`000000kW0k0>i`>`020>i`>`L0
m7<l00<000000?Ac?03cLS/00`3cLS/H000000H0amk700<000000<ONa`37g/L01P37g/L010000000
amk70<ONa`00000:0<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`00
0000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01@37g/L40000
00L0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk7
00D0amk700<000000<ONa`37g/L00`37g/L200000240amk700<000000<ONa`37g/L01P37g/L10?oo
o`002037g/L00`000000amk70<ONa`0R0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37
g/L01`37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37
g/L02@37g/L00`000000amk70<ONa`030<ONa`/000001@37g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700T0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700P0amk700<0LSPQ0000001b>2400P0cXLX30>I/>@D0kW0k00<000000>i`>`3^
L3/00P3^L3/70?Ac?0030000003dLc`0lg8k00L0lg8k0P3WKCP010000000ifdh0>M]>03WKCP40<QP
<@<0WD`W00<0OchO0000001M;QD01037g/L9000000H0amk700<000000<ONa`0000002`37g/L00`00
0000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`00
0000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`0000000`0000020<ON
a`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`050<ON
a`0300000037g/L0amk700@0amk700<000000<ONa`37g/L08037g/L00`000000amk70<ONa`060<ON
a`40oooo00080<ONa`0300000037g/L0amk70280amk700<000000<ONa`37g/L02037g/L00`000000
amk70<ONa`060<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`070<ONa`P000001@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0
amk700<000000<ONa`37g/L02037g/L0101b>2400000078h8@1b>24203>QbP80iV`i1@3^L3/00`00
0000kW0k0>i`>`020>i`>`L0m7<l00<000000?Ac?03cLS/01`3cLS/20>M]>0040000003WKCP0ifdh
0>M]>0@0b60a0`2MC2L00`1o?Ql0000005d^5@0:0<ONa`0300000037g/L0amk700L0000000<0amk7
00000037g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<00000
0<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<00000
0<ONa`37g/L01037g/L4000000L0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`05
0<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L08037g/L00`000000amk70<ONa`06
0<ONa`40oooo00070<ONa`0300000037g/L0amk702@0amk700<000000<ONa`37g/L01`37g/L00`00
0000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`00
0000amk70<ONa`0600000080amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`1b>2400000078h8@02078h
8@0303>QbP3VK3T0iV`i00D0kW0k00<000000>i`>`3^L3/00P3^L3/70?Ac?0030000003dLc`0lg8k
00L0lg8k0P3WKCP010000000ifdh0>M]>03WKCP40<QP<@<0WD`W00<0OchO0000001M;QD02P37g/L0
0`000000amk70<ONa`060<ONa`P000001@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L01P37g/L010000000amk70000000000050<ONa`0300000037
g/L0amk700D0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037
g/L0amk70240amk700<000000<ONa`37g/L01P37g/L10?ooo`001`37g/L00`000000amk70<ONa`0T
0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`08
0<ONa`0300000037g/L0amk700<0amk71`0000080<ONa`0300000037g/L0amk700T0amk700<00000
0<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700<00000
0<ONa`37g/L02@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700<0LSPQ
0000001b>2400P1b>24203>QbP030>I/>@3^L3/0kW0k00<0kW0k00<000000>i`>`3^L3/00P3^L3/7
0?Ac?0030000003dLc`0lg8k00L0lg8k00<0ifdh0000003WKCP00`3WKCP40<QP<@<0WD`W00<00000
07ln7`1M;QD02@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0000000D0amk720000008
0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`07
0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`02
0<ONa`<0000000<0amk700000037g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0
amk700@0amk700<000000<ONa`37g/L08@37g/L00`000000amk70<ONa`060<ONa`40oooo00070<ON
a`0300000037g/L0amk702D0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ON
a`0300000037g/L0amk700H0amk7200000040<ONa`0300000037g/L0amk700T0amk700<000000<ON
a`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ON
a`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700T0amk700<000000<ON
a`37g/L02037g/L00`1b>2400000078h8@03078h8@80<j7:1@3^L3/00`000000kW0k0>i`>`020>i`
>`L0m7<l00<000000?Ac?03cLS/01`3cLS/00`3WKCP000000>M]>0030>M]>0@0b60a0`2MC2L00`00
0000OchO05d^5@090<ONa`0300000037g/L0amk700L0amk70P00000;0<ONa`0300000037g/L0amk7
00D000000P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ON
a`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700H0amk700<000000<ON
a`37g/L01@37g/L3000000H0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ON
a`0300000037g/L0amk70280amk700<000000<ONa`37g/L01P37g/L10?ooo`001`37g/L00`000000
amk70<ONa`0U0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`0500000080amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`03
00000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`03
00000037g/L0amk700P0amk700<000000<ONa`37g/L02P37g/L00`000000amk70<ONa`080<ONa`03
00000037g/L0amk700P0amk700<0LSPQ0000001b>2400`1b>24303>QbP<0kW0k00<000000>i`>`3^
L3/00`3^L3/60?Ac?0030000003dLc`0m7<l00P0lg8k00<0ifdh0000003WKCP00`3WKCP40<QP<@<0
WD`W00<0000007ln7`1M;QD02@37g/L00`000000amk70<ONa`070<ONa`8000002P37g/L00`000000
amk70<ONa`060<ONa`L000001@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0
amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0
amk700<000000<ONa`37g/L0100000000`37g/L000000<ONa`060<ONa`0300000037g/L0amk700@0
amk700<000000<ONa`37g/L08P37g/L00`000000amk70<ONa`060<ONa`40oooo00070<ONa`030000
0037g/L0amk702H0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`020<ONa`L00000
2037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L0
2037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L0
2@37g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L0
2037g/L00`1b>2400000078h8@03078h8@@0<j7:0P3^L3/00`000000kW0k0>i`>`030>i`>`H0m7<l
00<000000?Ac?03dLc`0203cLS/00`3WKCP000000>M]>0030>M]>0@0b60a0`2MC2L00`000000OchO
05d^5@090<ONa`0300000037g/L0amk700L0amk70P00000:0<ONa`0300000037g/L0amk700P0amk7
00<000000<ONa`37g/L00P37g/L8000000P0amk700<000000<ONa`37g/L01`37g/L00`000000amk7
0<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk7
0<ONa`040<ONa`8000001P37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk702<0amk7
00<000000<ONa`37g/L01P37g/L10?ooo`001`37g/L00`000000amk70<ONa`0V0<ONa`0300000037
g/L0amk700D0amk71`0000040<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37
g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37
g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02@37
g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<0LSPQ0000001b>240101b
>24403>QbP030>i`>`000000kW0k00@0kW0k1P3dLc`00`000000m7<l0?Ac?0080?=b>`030>M]>000
0000ifdh00<0ifdh1038H34309e<9`030000001o?Ql0GBhE00P0amk700<000000<ONa`37g/L02037
g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02037
g/L00`000000amk70<ONa`0500000080amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ON
a`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ON
a`050<ONa`0400000037g/L00000000000@0amk700<000000<ONa`37g/L01037g/L00`000000amk7
0<ONa`0S0<ONa`0300000037g/L0amk700H0amk70@3oool000L0amk700<000000<ONa`37g/L09`37
g/L00`000000amk70<ONa`0400000080amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ON
a`070<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ON
a`090<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`090<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`080<ONa`03078h8@000000LSPQ00H0LSPQ0P0cXLX00`3^L3/000000>i`>`040>i`>`H0m7<l00<0
00000?Ac?03dLc`0203cLS/00`3WKCP000000>M]>0030>M]>0@0b60a0`2MC2L00`000000OchO05d^
5@080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L5000000L0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<0
00000<ONa`37g/L01@37g/L010000000amk70<ONa`37g/L2000000030<ONa`000000amk700D0amk7
00<000000<ONa`37g/L09037g/L00`000000amk70<ONa`060<ONa`40oooo00070<ONa`0300000037
g/L0amk702L0amk70`0000070<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01`37
g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037
g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37
g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037
g/L00`1b>2400000078h8@06078h8@0406Tc7P0cXLX0<j7:000000D0kW0k1P3dLc`00`000000m7<l
0?Ac?0080?=b>`030>M]>0000000ifdh00<0ifdh1038H34309e<9`030000001o?Ql0GBhE00P0amk7
00<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk7
00<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700@00000
0P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L0
1P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk70P0000060<ONa`030000
0037g/L0amk702@0amk700<000000<ONa`37g/L01P37g/L10?ooo`001`37g/L00`000000amk70<ON
a`0W0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ON
a`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`080<ONa`03078h8@000000LSPQ00H0LSPQ00@0JC<N03>QbP0cXLX0<j7:1@3^L3/60?Ac?0030000
003dLc`0m7<l00P0lg8k00<000000>M]>03WKCP00`3WKCP40<QP<@80WD`W00@0000007ln7`1o?Ql0
GBhE2037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37
g/L01`37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37
g/L01@37g/L4000000L0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`03
00000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L010000000amk70000000000030<ON
a`0300000037g/L0amk702H0amk700<000000<ONa`37g/L01@37g/L10?ooo`001`37g/L00`000000
amk70<ONa`0X0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000
amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000
amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000
amk70<ONa`080<ONa`03078h8@000000LSPQ00H0LSPQ0P1Y<ah303>QbP@0kW0k1P3dLc`00`000000
m7<l0?Ac?0080?=b>`030000003WKCP0ifdh00<0ifdh1038H34209e<9`040000001o?Ql0OchO05d^
5@P0amk700<000000<ONa`37g/L01`37g/L2000000X0amk700<000000<ONa`37g/L01`37g/L00`00
0000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`00
0000amk70000000300000080amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ON
a`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L010000000amk70<ONa`37g/L2
000000030<ONa`000000amk702L0amk700<000000<ONa`37g/L01@37g/L10?ooo`001`37g/L00`00
0000amk70<ONa`0X0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L00`00
0000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`00
0000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`00
0000amk70<ONa`030<ONac<0000000<0<j7:0000000000003`0000050?=b>`030000003WKCP0ifdh
00<0ifdh1038H34209e<9`040000001o?Ql0OchO05d^5@L0amk700<000000<ONa`37g/L02037g/L2
000000T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`040<ONa`@000001`37g/L0
0`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L0
0`000000amk70<ONa`040<ONa`0300000037g/L0amk702L0amk700<000000<ONa`37g/L01@37g/L1
0?ooo`001`37g/L00`000000amk70<ONa`0Y0<ONa`0300000037g/L0amk700H0amk700<000000<ON
a`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ON
a`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700<0amk75P0000050<ON
a`0300000037g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ON
a`03078h8@000000LSPQ00H0LSPQ0`1Y<ah00`000000<j7:03>QbP030>i`>`H0m7<l00<000000?Ac
?03dLc`00`3cLS/G000000D0amk700<000000<ONa`37g/L02037g/L2000000T0amk700<000000<ON
a`37g/L02037g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700P0amk700<000000<ON
a`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0000000<000000P37g/L00`00
0000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`00
0000amk70<ONa`030<ONa`0300000037g/L0amk702P0amk700<000000<ONa`37g/L01@37g/L10?oo
o`001`37g/L00`000000amk70<ONa`0Y0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37
g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37
g/L02037g/L00`000000amk70<ONa`030<ONa`/000001@37g/L00`000000amk70<ONa`080<ONa`03
00000037g/L0amk700P0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`03
00000037g/L0amk700P0amk700<0LSPQ0000001b>2401P1b>24306Tc7P040000001Y<ah0<j7:03>Q
bP80kW0k1P3dLc`00`000000m7<l0?Ac?0080?=b>`030000003WKCP0ifdh00<0ifdh1038H34209e<
9`040000001o?Ql0OchO05d^5@80amk72P0000050<ONa`0300000037g/L0000000T0amk700<00000
0<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<00000
0<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700@0amk710000007
0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`04
0<ONa`0300000037g/L0amk702P0amk700<000000<ONa`37g/L01@37g/L10?ooo`001`37g/L00`00
0000amk70<ONa`0Z0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`00
0000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L00`37g/L:0000
00D0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk7
00P0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk7
00P0amk700<0LSPQ0000001b>2401P1b>24306Tc7P030000001Y<ah0<j7:0080<j7:00<0kW0k0?Ac
?03dLc`0103dLc`00`000000m7<l0?Ac?0080?=b>`030000003WKCP0ifdh00<0ifdh1038H34209e<
9`040000001o?Ql0OchO05d^5@L0amk700<000000<ONa`37g/L00P37g/L8000000T0amk700<00000
0<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<00000
0<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700@00000
0<ONa`00000000001037g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L01037g/L00`000000amk70<ONa`0Y0<ONa`0300000037g/L0amk700D0amk70@3o
ool000H0amk700<000000<ONa`37g/L0:`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`P000001037g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700T0amk700<000000<ONa`37g/L01`37g/L0
0`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L0
0`000000amk70<ONa`080<ONa`03078h8@000000LSPQ00H0LSPQ0`1Y<ah00`000000JC<N06Tc7P02
03>QbP030>i`>`3dLc`0m7<l00@0m7<l00<000000?Ac?03dLc`0203cLS/00`000000ifdh0>M]>003
0>M]>0@0b60a00<0WD`W0000002MC2L00P1o?Ql00`1M;QD0amk70<ONa`040<ONa`0300000037g/L0
amk700P0amk700<000000<ONa`0000001P0000020<ONa`0300000037g/L0amk700P0amk700<00000
0<ONa`37g/L01P37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<00000
0<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk70080amk70P000002
0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`04
0<ONa`0300000037g/L0amk702T0amk700<000000<ONa`37g/L01@37g/L10?ooo`001P37g/L00`00
0000amk70<ONa`0/0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`00
0000amk70<ONa`070<ONa`0300000037g/L0amk700D000000P37g/L00`000000amk70<ONa`080<ON
a`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ON
a`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ON
a`0300000037g/L0amk700P0amk700<0LSPQ0000001b>2401P1b>24306Tc7P040000001Y<ah0JC<N
06Tc7P80<j7:1P3dLc`00`000000m7<l0?Ac?0070?=b>`030000003WKCP0ifdh00@0ifdh1038H340
1P2MC2L0000009e<9`2MC2L0OchO05d^5@H0amk700<000000<ONa`37g/L02037g/L00`000000amk7
000000060<ONa`L000001@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk7
00<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk7
00<000000<ONa`37g/L01037g/L3000000H0amk700<000000<ONa`37g/L01037g/L00`000000amk7
0<ONa`040<ONa`0300000037g/L0amk702X0amk700<000000<ONa`37g/L01@37g/L10?ooo`001P37
g/L00`000000amk70<ONa`0/0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01`37
g/L00`000000amk70<ONa`020<ONa`L000002037g/L00`000000amk70<ONa`070<ONa`0300000037
g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037
g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037
g/L0amk700P0amk700<0LSPQ0000001b>2401P1b>24306Tc7P030000001Y<ah0JC<N0080JC<N0P0c
XLX50?Ac?0030000003dLc`0m7<l00L0lg8k00<000000>M]>03WKCP0103WKCP40<QP<@0609e<9`00
0000WD`W09e<9`1o?Ql0GBhE1P37g/L00`000000amk70<ONa`070<ONa`0400000037g/L0amk70000
00P0amk700<000000<ONa`37g/L00P37g/L8000000L0amk700<000000<ONa`37g/L01P37g/L00`00
0000amk70<ONa`070<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`00
0000amk70<ONa`050<ONa`0300000037g/L0amk700@000000P37g/L00`000000amk70<ONa`040<ON
a`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0:P37g/L00`000000amk70<ONa`050<ON
a`40oooo00060<ONa`0300000037g/L0amk702d0amk700<000000<ONa`37g/L01@37g/L00`000000
amk70<ONa`050<ONa`L000001037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0
amk700<000000<ONa`37g/L01`37g/L00`1b>2400000078h8@06078h8@<0JC<N00<0000006Tc7P1Y
<ah00P1Y<ah203>QbP@0m7<l00@000000?Ac?03dLc`0m7<l1`3cLS/00`000000ifdh0>M]>0040>M]
>0@0b60a00H0WD`W0000002MC2L0WD`W07ln7`1M;QD60<ONa`0300000037g/L0amk700L0amk700@0
00000<ONa`37g/L000001`37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700@00000
0P37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L0
1P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L0
1037g/L3000000D0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`0[0<ONa`030000
0037g/L0amk700D0amk70@3oool000H0amk700<000000<ONa`37g/L0;@37g/L00`000000amk70<ON
a`060<ONa`0300000037g/L0amk700@000000P37g/L00`000000amk70<ONa`070<ONa`0300000037
g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`0300000037
g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037
g/L0amk700T0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`03078h8@00
0000LSPQ00H0LSPQ0`1Y<ah00`000000JC<N06Tc7P0206Tc7P<0<j7:0`3dLc`010000000m7<l0?Ac
?03dLc`70?=b>`030000003WKCP0ifdh00@0ifdh1038H3401P000000WD`W09e<9`2MC2L0OchO05d^
5@D0amk700<000000<ONa`37g/L02037g/L010000000amk70<ONa`0000070<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L01@37g/L7000000@0amk700<000000<ONa`37g/L01`37g/L0
0`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L0
0`000000amk70<ONa`050<ONa`0300000037g/L0amk700<000000P37g/L00`000000amk70<ONa`04
0<ONa`0300000037g/L0amk702/0amk700<000000<ONa`37g/L01@37g/L10?ooo`001P37g/L00`00
0000amk70<ONa`0^0<ONa`0300000037g/L0amk70080amk71P0000070<ONa`0300000037g/L0amk7
00H0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk7
00L0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk7
00P0amk700<000000<ONa`37g/L02@37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk7
00L0amk700<0LSPQ0000001b>2401P1b>24306Tc7P030000001Y<ah0JC<N0080JC<N100cXLX20?Ac
?0040000003dLc`0m7<l0?Ac?0L0lg8k00<000000>M]>03WKCP0103WKCP40<QP<@060000002MC2L0
WD`W09e<9`1o?Ql0GBhE1@37g/L00`000000amk70<ONa`080<ONa`0400000037g/L0amk7000000H0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk70080
amk71`0000070<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000
amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L00`37g/L2000000H0
amk700<000000<ONa`37g/L0;037g/L00`000000amk70<ONa`050<ONa`40oooo00060<ONa`030000
0037g/L0amk702h0amk71@0000030<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L0
1`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L0
2037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L0
2037g/L00`000000amk70<ONa`090<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L0
1`37g/L00`1b>2400000078h8@06078h8@<0JC<N00<0000006Tc7P1Y<ah00P1Y<ah205l_70<0<j7:
00<0m7<l0000003dLc`00P3dLc`70?=b>`030000003WKCP0ifdh00@0ifdh1038H3401P000000WD`W
09e<9`2MC2L0OchO05d^5@D0amk700<000000<ONa`37g/L01`37g/L01@000000amk70<ONa`37g/L0
000000H0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L0100000020<ONa`0300000037g/L0amk700H0amk700<00000
0<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<00000
0<ONa`37g/L01037g/L010000000amk70000000000040<ONa`0300000037g/L0amk702`0amk700<0
00000<ONa`37g/L01@37g/L10?ooo`001P37g/L00`000000amk70<ONa`0^0<ONa`0300000037g/L0
amk700H0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0
amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0
amk700P0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`03078h8@000000
LSPQ00H0LSPQ0`1Y<ah00`000000JC<N06Tc7P0206Tc7P<0GblL0`0cXLX010000000m7<l0?Ac?03d
Lc`60?=b>`030000003cLS/0ifdh00D0ifdh1038H3401P000000WD`W09e<9`2MC2L0OchO05d^5@@0
amk700<000000<ONa`37g/L02037g/L01@000000amk70<ONa`37g/L0000000H0amk700<000000<ON
a`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700H0amk700<000000<ON
a`37g/L01@37g/L4000000L0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ON
a`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L010000000amk70<ONa`37g/L2
000000030<ONa`000000amk702h0amk700<000000<ONa`37g/L01@37g/L10?ooo`001P37g/L00`00
0000amk70<ONa`0_0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01`37g/L00`00
0000amk70<ONa`060<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`00
0000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`00
0000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037g/L00`00
0000amk70<ONa`070<ONa`03078h8@000000LSPQ00H0LSPQ0`1Y<ah00`000000JC<N06Tc7P0206Tc
7P@0GblL0P0cXLX010000000m7<l0?Ac?03dLc`60?=b>`030000003cLS/0ifdh00D0ifdh1038H340
1P000000WD`W09e<9`2MC2L0OchO05d^5@@0amk700<000000<ONa`37g/L02037g/L01@000000amk7
0<ONa`37g/L0000000D0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`060<ONa`03
00000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70000000300000080
amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0
amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`800000;`37g/L00`000000
amk70<ONa`050<ONa`40oooo00060<ONa`0300000037g/L0amk702l0amk700<000000<ONa`37g/L0
1P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L0
1`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L0
2@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L0
0`37g/L[000000D0GblL00<0<j7:0000003dLc`00P3dLc`60?=b>`030000003cLS/0ifdh00D0ifdh
0`38H3400`000000WD`W09e<9`0209e<9`0307ln7`1M;QD0amk700<0amk700<000000<ONa`37g/L0
2037g/L01@000000amk70<ONa`37g/L0000000D0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`070<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`040<ONa`@000001`37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0
amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk702l0
amk700<000000<ONa`37g/L01037g/L10?ooo`001P37g/L00`000000amk70<ONa`0`0<ONa`030000
0037g/L0amk700D0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`030000
0037g/L0amk700P0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`080<ONa`030000
0037g/L0amk700P0amk700<000000<ONa`37g/L00`37g/LE000000D0amk700<000000<ONa`37g/L0
2037g/L00`000000amk70<ONa`070<ONa`03078h8@000000LSPQ00H0LSPQ0`1Y<ah00`000000JC<N
06Tc7P0206Tc7PL0000000<0<j7:000000000000300000020>M]>0<0b60a00<0000009e<9`2MC2L0
0P2MC2L00`1o?Ql0GBhE0<ONa`030<ONa`0300000037g/L0amk700P0amk700D000000<ONa`37g/L0
amk7000000050<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`060<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01@37g/L00`000000
amk70<ONa`0400000080amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`03
00000037g/L0amk700@0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`0_0<ONa`03
00000037g/L0amk700@0amk70@3oool000H0amk700<000000<ONa`37g/L0<037g/L00`000000amk7
0<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk7
0<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk7
0<ONa`030<ONa`/000001037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk7
00<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`03078h8@000000LSPQ00H0LSPQ
0`1Y<ah00`000000JC<N06Tc7P0206Tc7PH0GblL0P0cXLX20?Ac?0H0lg8k00<000000?=b>`3WKCP0
0`3WKCP:0000000307ln7`1M;QD0amk70080amk700<000000<ONa`37g/L02037g/L00`000000amk7
0<ONa`020<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L02037g/L00`000000amk7
0<ONa`060<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L00`000000amk7
0<ONa`060<ONa`0300000037g/L0amk700@0amk7100000060<ONa`0300000037g/L0amk700@0amk7
00<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk70300amk7
00<000000<ONa`37g/L01037g/L10?ooo`001P37g/L00`000000amk70<ONa`0a0<ONa`0300000037
g/L0amk700D0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`070<ONa`0300000037
g/L0amk700L0amk700<000000<ONa`37g/L01@37g/LB000000D0amk700<000000<ONa`37g/L01`37
g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L02037
g/L00`000000amk70<ONa`070<ONa`03078h8@000000LSPQ00H0LSPQ0`1Y<ah00`000000JC<N06Tc
7P0206Tc7PH0GblL00@0000003>QbP0cXLX0m7<l1P3cLS/00`000000lg8k0>M]>0050>M]>0<0b60a
00<000000<QP<@2MC2L00P2MC2L;000000D0amk700<000000<ONa`37g/L00P37g/L00`000000amk7
0<ONa`020<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk7
0<ONa`060<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01@37g/L00`000000amk7
0<ONa`060<ONa`0300000037g/L0amk700@0000000<0amk700000037g/L01P37g/L00`000000amk7
0<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0<@37g/L00`000000amk7
0<ONa`040<ONa`40oooo00060<ONa`0300000037g/L0amk70340amk700<000000<ONa`37g/L01P37
g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L02037
g/L00`000000amk70<ONa`0400000080amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`1b>2400000078h
8@06078h8@<0JC<N00<0000006Tc7P1Y<ah00P1Y<ah605l_70040000001O;a`0<j7:0?Ac?0H0lg8k
00<000000?=b>`3WKCP01@3WKCP30<QP<@0300000038H340WD`W0080WD`W00<0OchO05d^5@37g/L0
0P37g/L00`000000amk70<ONa`030<ONa`/000000`37g/L00`000000amk70<ONa`080<ONa`030000
0037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`030000
0037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`040<ONa`<00000
1@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0
<@37g/L00`000000amk70<ONa`040<ONa`40oooo00050<ONa`0300000037g/L0amk703<0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700L0amk700<0
00000<ONa`37g/L00`37g/L7000000L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ON
a`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ON
a`070<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01P37g/L2078h8@030000001b
>240LSPQ00D0LSPQ0`1Y<ah00`000000JC<N06Tc7P0206Tc7PD0GblL00<0000005l_701O;a`00P0c
XLX50?=b>`030000003cLS/0lg8k00H0ifdh0P38H3400`000000b60a0<QP<@0309e<9`0307ln7`1M
;QD0amk70080amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`020<ONa`T000001@37
g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37
g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01@37
g/L00`000000amk70<ONa`0300000080amk700<000000<ONa`37g/L01037g/L00`000000amk70<ON
a`040<ONa`0300000037g/L0amk70380amk700<000000<ONa`37g/L01037g/L10?ooo`001@37g/L0
0`000000amk70<ONa`0c0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L0
0`000000amk70<ONa`020<ONa`X000001037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0
amk700P0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0
amk700H0amk70P1b>2400`000000LSPQ078h8@05078h8@<0JC<N00<0000006Tc7P1Y<ah00P1Y<ah5
05l_70050000001O;a`0GblL05@Y6@0cXLX01@3cLS/00`000000lg8k0?=b>`060>M]>080b60a00<0
00000<QP<@38H3400`2MC2L01@1o?Ql0GBhE0<ONa`37g/L0000000X0amk700<000000<ONa`37g/L0
0`37g/L01@000000amk70<ONa`37g/L0000000@0amk7200000070<ONa`0300000037g/L0amk700H0
amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0
amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`030<ONa`8000001`37g/L00`000000
amk70<ONa`030<ONa`0300000037g/L0amk703<0amk700<000000<ONa`37g/L01037g/L10?ooo`00
1@37g/L00`000000amk70<ONa`0d0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L0
1@37g/L6000000@0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`060<ONa`030000
0037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`030000
0037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`080<ONa`030000
0037g/L0amk700H0amk700<0LSPQ0000001b>2401`1b>24206Tc7P030000001Y<ah0JC<N00<0JC<N
1@1O;a`010000000GblL05l_701D:AT203>QbP@0lg8k00<000000?=b>`3cLS/01P3WKCP20<QP<@03
00000038H340b60a00<0WD`W00D0OchO05d^5@37g/L0amk70000000:0<ONa`0300000037g/L0amk7
00<0amk700@000000<ONa`37g/L000002P37g/L00`000000amk70<ONa`0400000080amk700<00000
0<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<00000
0<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700@00000
0<ONa`00000000001037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk703<0amk700<0
00000<ONa`37g/L01037g/L10?ooo`001@37g/L00`000000amk70<ONa`0d0<ONa`0300000037g/L0
amk700H0amk700<000000<ONa`37g/L0100000000`37g/L000000<ONa`080<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0
amk700P0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`03078h8@000000
LSPQ00L0LSPQ0P1Y<ah00`000000JC<N06Tc7P0306Tc7PD0GblL00<0000005l_701O;a`00P1D:AT0
0`0cXLX0lg8k0?=b>`020?=b>`030000003cLS/0lg8k00H0ifdh0P38H3400`000000b60a0<QP<@03
09e<9`0507ln7`1M;QD0amk70<ONa`0000002P37g/L00`000000amk70<ONa`030<ONa`0400000037
g/L0amk7000000T0amk700<000000<ONa`37g/L01@37g/L7000000@0amk700<000000<ONa`37g/L0
1P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L0
1P37g/L00`000000amk70<ONa`040<ONa`0400000037g/L0amk70<ONa`8000000P37g/L00`000000
amk70<ONa`030<ONa`0300000037g/L0amk703@0amk700<000000<ONa`37g/L01037g/L10?ooo`00
1@37g/L00`000000amk70<ONa`0e0<ONa`0300000037g/L0amk70080amk71P0000060<ONa`030000
0037g/L0amk700H0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`030000
0037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`030000
0037g/L0amk700L0amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`030000
0037g/L0amk700H0amk700<0LSPQ0000001b>2401`1b>24206Tc7P030000001Y<ah0JC<N00<0JC<N
1@1O;a`00`000000GblL05l_700205@Y6@80<j7:0`3cLS/00`000000lg8k0?=b>`060>M]>0030<QP
<@000000b60a0080b60a0`2MC2L01@1o?Ql0GBhE0<ONa`37g/L0000000T0amk700<000000<ONa`37
g/L01037g/L010000000amk70<ONa`0000090<ONa`0300000037g/L0amk700H0amk700<000000<ON
a`37g/L00`37g/L6000000L0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ON
a`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ON
a`<000001037g/L00`000000amk70<ONa`0e0<ONa`0300000037g/L0amk700@0amk70@3oool000D0
amk700<000000<ONa`37g/L0=@37g/L5000000<0amk700<000000<ONa`37g/L01P37g/L00`000000
amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L00`000000
amk70<ONa`070<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`070<ONa`0300000037g/L0amk700P0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`060<ONa`03078h8@000000LSPQ00L0LSPQ0P1Y<ah00`000000JC<N06Tc7P0306Tc7PD0
GblL00<0000005l_701O;a`00`1D:AT01@0cXLX0lg8k0?=b>`3cLS/000000080lg8k1P3WKCP00`38
H34000000<QP<@020<QP<@<0WD`W00@0OchO05d^5@37g/L000002P37g/L00`000000amk70<ONa`04
0<ONa`0300000037g/L0000000T0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`06
0<ONa`0300000037g/L0amk700@000000P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0
amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0
amk700@0amk700<000000<ONa`37g/L00P0000020<ONa`0300000037g/L0amk703D0amk700<00000
0<ONa`37g/L01037g/L10?ooo`001@37g/L00`000000amk70<ONa`0f0<ONa`0300000037g/L0amk7
00D0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk7
00L0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk7
00L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk7
00L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`03078h8@000000LSPQ
00L0LSPQ0P1Y<ah00`000000JC<N06Tc7P0306Tc7P@0GblL00@0000005l_701O;a`0GblL0`1D:AT2
03>QbP030?=b>`000000lg8k0080lg8k1P3WKCP00`38H34000000<QP<@020<QP<@<0WD`W00@0OchO
05d^5@37g/L000002P37g/L00`000000amk70<ONa`050<ONa`8000002@37g/L00`000000amk70<ON
a`060<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01037g/L6000000@0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`020<ONa`800000>037g/L00`000000amk70<ON
a`040<ONa`40oooo00050<ONa`0300000037g/L0amk703H0amk700<000000<ONa`37g/L01@37g/L0
0`000000amk70<ONa`060<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L0
0`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L0
0`000000amk70<ONa`080<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L0
0`000000amk70<ONa`070<ONa`0300000037g/L0amk700H0amk700<0LSPQ0000001b>2401`1b>242
06Tc7P030000001Y<ah0JC<N00<0JC<N101O;a`010000000GblL05l_701O;a`405@Y6@80<j7:00@0
00000?=b>`3cLS/0lg8k1P3WKCP00`38H34000000<QP<@020<QP<@<0WD`W00@0OchO05d^5@37g/L0
00002P37g/L00`000000amk70<ONa`050<ONa`8000002@37g/L00`000000amk70<ONa`060<ONa`03
00000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`020<ONa`H0
00001P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37
g/L01@37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk703L0amk700<000000<ONa`37
g/L01037g/L10?ooo`001@37g/L00`000000amk70<ONa`0g0<ONa`0300000037g/L0amk700D0amk7
00<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700L0amk7
00<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700P0amk7
00<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk7
00<000000<ONa`37g/L00`37g/LD000000<0LSPQ0P1Y<ah00`000000JC<N06Tc7P0306Tc7P@0GblL
00@0000005l_701O;a`0GblL1@1D:AT00`0cXLX000000?=b>`020?=b>`H0ifdh00<000000<QP<@38
H3400P38H34309e<9`0407ln7`1M;QD0amk7000000T0amk700<000000<ONa`37g/L01P37g/L20000
00P0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk7
00H0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`0400000080amk700<000000<ON
a`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ON
a`37g/L01037g/L00`000000amk70<ONa`0g0<ONa`0300000037g/L0amk700@0amk70@3oool000D0
amk700<000000<ONa`37g/L0=`37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700H0
amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0
amk700<000000<ONa`37g/L02037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700<0
amk77P0000040<ONa`0300000037g/L0amk700H0amk700<0LSPQ0000001b>240101b>24H00000003
03>QbP000000000000<000001@3WKCP00`000000b60a0<QP<@020<QP<@<0WD`W00<0OchO05d^5@00
00002P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37
g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37
g/L01P37g/L00`000000amk70<ONa`040<ONa`<000001P37g/L00`000000amk70<ONa`040<ONa`03
00000037g/L0amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`0i0<ONa`03
00000037g/L0amk700<0amk70@3oool000D0amk700<000000<ONa`37g/L0>037g/L00`000000amk7
0<ONa`050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk7
0<ONa`060<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L00`37g/LD000000@0amk7
00<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk7
00<000000<ONa`37g/L01P37g/L00`1b>2400000078h8@07078h8@80JC<N00<0000006Tc7P1Y<ah0
0`1Y<ah405l_70040000001O;a`0GblL05l_70H0E2TI00D0<j7:0?=b>`3cLS/0lg8k0>M]>00:0000
00<0WD`W00<0OchO05d^5@0000002P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk7
00L0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk7
00H0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk7
00@000000P37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ON
a`37g/L00`37g/L00`000000amk70<ONa`0j0<ONa`0300000037g/L0amk700<0amk70@3oool000D0
amk700<000000<ONa`37g/L0>037g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700H0
amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk70080
amk72P0000040<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000
amk70<ONa`060<ONa`03078h8@000000LSPQ00L0LSPQ0P1Y<ah00`000000JC<N06Tc7P0306Tc7P@0
GblL00@0000005l_701O;a`0GblL1P1D:AT203>QbP80lg8k1P3WKCP00`000000b60a0<QP<@020<QP
<@X000001@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700H0amk700<000000<ON
a`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ON
a`37g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk70`0000050<ON
a`0300000037g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`0k0<ON
a`0300000037g/L0amk700<0amk70@3oool000D0amk700<000000<ONa`37g/L0>@37g/L00`000000
amk70<ONa`050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000
amk70<ONa`030<ONa`P000001037g/L00`000000amk70<ONa`080<ONa`0300000037g/L0amk700H0
amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0
amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`03078h8@000000LSPQ00L0
LSPQ0P1Y<ah00`000000JC<N06Tc7P0306Tc7P@0GblL00@0000005l_701O;a`0GblL1P1D:AT01000
0000<j7:03>QbP3cLS/50>M]>00300000038H340b60a00<0b60a0`2MC2L00`1o?Ql0GBhE00000004
0<ONa`X000001037g/L2000000P0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`07
0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`05
0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L00`0000020<ONa`0300000037g/L0
amk700<0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`0k0<ONa`0300000037g/L0
amk700<0amk70@3oool000D0amk700<000000<ONa`37g/L0>P37g/L00`000000amk70<ONa`040<ON
a`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L7000000<0amk700<000000<ON
a`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ON
a`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700L0amk700<000000<ON
a`37g/L01`37g/L00`000000amk70<ONa`060<ONa`03078h8@000000LSPQ00L0LSPQ0P1Y<ah00`00
0000JC<N06Tc7P0306Tc7P@0GblL00@0000005l_701O;a`0GblL1@1D:AT01@000000E2TI04LS5P0c
XLX0lg8k00D0ifdh00<000000<QP<@38H3400`38H34309e<9`0307ln7`000000amk700T0amk700<0
00000<ONa`37g/L00P37g/L9000000@0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ON
a`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ON
a`060<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L00`37g/L3000000@0amk700<0
00000<ONa`37g/L01037g/L00`000000amk70<ONa`0l0<ONa`0300000037g/L0amk700<0amk70@3o
ool000@0amk700<000000<ONa`37g/L0>`37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0
amk700H0amk700<000000<ONa`37g/L0100000020<ONa`0300000037g/L0amk700H0amk700<00000
0<ONa`37g/L01P37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<00000
0<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700L0amk700<00000
0<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`03078h8@000000LSPQ00L0LSPQ0P1Y<ah0
0`000000JC<N06Tc7P0306Tc7P@0GblL00@0000005l_701O;a`0GblL1@1D:AT00`000000E2TI04LS
5P0203>QbPD0ifdh00<000000<QP<@38H3400`38H34309e<9`0307ln7`000000amk700P0amk700<0
00000<ONa`37g/L01`37g/L2000000<0amk7200000040<ONa`0300000037g/L0amk700L0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk7008000000P37
g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk703d0amk700<000000<ONa`37g/L00`37
g/L10?ooo`001037g/L00`000000amk70<ONa`0l0<ONa`0300000037g/L0amk700@0amk700<00000
0<ONa`37g/L00`37g/L6000000L0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`07
0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`07
0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`08
0<ONa`0300000037g/L0amk700D0amk700<0LSPQ0000001b>2401`1b>2400`1Y<ah0000006Tc7P05
06Tc7P<0GblL00<0000005l_701O;a`00P1O;a`505@Y6@030000001D:AT0Ab<F00<0<j7:103WKCP0
0`000000b60a0<QP<@030<QP<@<0WD`W00<0OchO00000037g/L02037g/L00`000000amk70<ONa`06
0<ONa`0300000037g/L0000000L0amk700@000000<ONa`37g/L0amk72@0000040<ONa`0300000037
g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037
g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`020<ONa`<000001037
g/L00`000000amk70<ONa`0n0<ONa`0300000037g/L0amk700<0amk70@3oool000@0amk700<00000
0<ONa`37g/L0?037g/L00`000000amk70<ONa`020<ONa`P000001037g/L00`000000amk70<ONa`06
0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`07
0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`07
0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`05
0<ONa`03078h8@000000LSPQ00L0LSPQ00<0JC<N0000001Y<ah01@1Y<ah305l_70030000001O;a`0
GblL0080GblL1@1D:AT010000000E2TI04LS5P178aH303>QbP80ifdh00<000000>M]>038H3401038
H34309e<9`0307ln7`000000amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70000
00060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L00P37g/L6000000H0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01037g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk7008000000P37
g/L00`000000amk70<ONa`0n0<ONa`0300000037g/L0amk700<0amk70@3oool000@0amk700<00000
0<ONa`37g/L0?@37g/L4000000@0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`07
0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`07
0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`07
0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`05
0<ONa`03078h8@000000LSPQ00L0LSPQ00<0JC<N0000001Y<ah01@1Y<ah305l_70030000001O;a`0
GblL0080GblL1@1D:AT00`000000E2TI04LS5P0204LS5P80<j7:0P3WKCP00`000000ifdh0<QP<@04
0<QP<@<0WD`W00<0000005d^5@37g/L01`37g/L00`000000amk70<ONa`060<ONa`0400000037g/L0
amk7000000H0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037
g/L0amk700@000000P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L00P37g/L200000440amk700<000000<ONa`37g/L00`37g/L10?ooo`001037g/L0
0`000000amk70<ONa`0n0<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01P37g/L0
0`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01`37g/L0
0`000000amk70<ONa`060<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L0
0`000000amk70<ONa`070<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01`37g/L0
0`000000amk70<ONa`050<ONa`03078h8@000000LSPQ00L0LSPQ00<0JC<N0000001Y<ah01@1Y<ah3
05l_70030000001O;a`0GblL0080GblL1@1D:AT00`000000E2TI04LS5P0304LS5P0503>QbP3WKCP0
ifdh0000003WKCP01@38H34309e<9`030000001M;QD0amk700H0amk700<000000<ONa`37g/L01`37
g/L010000000amk70<ONa`0000050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L0
1P37g/L00`000000amk70<ONa`040<ONa`D000001@37g/L00`000000amk70<ONa`050<ONa`030000
0037g/L0amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`030000
0037g/L0amk700<0amk700<000000<ONa`37g/L0@037g/L00`000000amk70<ONa`030<ONa`40oooo
00040<ONa`0300000037g/L0amk703h0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ON
a`050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ON
a`060<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ON
a`070<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ON
a`070<ONa`0300000037g/L0amk700D0amk700<0LSPQ0000001b>2401`1b>2400`1Y<ah0000006Tc
7P0506Tc7P<0GblL00<0000005l_701O;a`00P1O;a`405@Y6@030000001D:AT0E2TI00@0Ab<F0P0c
XLX00`3WKCP000000>M]>0050<QP<@<0WD`W00<0000005d^5@37g/L01P37g/L00`000000amk70<ON
a`060<ONa`0500000037g/L0amk70<ONa`0000001@37g/L00`000000amk70<ONa`050<ONa`030000
0037g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`020<ONa`H00000
1P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0
0`37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk70400amk700<000000<ONa`37g/L0
0`37g/L10?ooo`001037g/L00`000000amk70<ONa`0o0<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700H0amk700<0
00000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700L0amk700<0
00000<ONa`37g/L01`37g/L00`000000amk70<ONa`050<ONa`03078h8@000000LSPQ00L0LSPQ00<0
JC<N0000001Y<ah01@1Y<ah305l_70030000001O;a`0GblL0080GblL101D:AT00`000000E2TI05@Y
6@0504LS5P0403>QbP000000ifdh0>M]>0D0b60a0`2MC2L00`000000GBhE0<ONa`060<ONa`030000
0037g/L0amk700H0amk700D000000<ONa`37g/L0amk7000000040<ONa`0300000037g/L0amk700H0
amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0
amk700<000000<ONa`37g/L0100000020<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37
g/L01037g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37
g/L0@@37g/L00`000000amk70<ONa`030<ONa`40oooo00040<ONa`0300000037g/L0amk703l0amk7
00<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700H0amk7
00<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk7
00<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk70080amk7
>P00000405@Y6@030000001D:AT0E2TI00D0Ab<F00@0<j7:0000003WKCP0ifdh1@38H34209e<9`03
0000001o?Ql0GBhE00H0amk700<000000<ONa`37g/L01`37g/L01@000000amk70<ONa`37g/L00000
00@0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk7
00D0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`040<ONa`<000001@37g/L00`00
0000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`00
0000amk70<ONa`120<ONa`0300000037g/L0amk700<0amk70@3oool000@0amk700<000000<ONa`37
g/L0@037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37
g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37
g/L01`37g/L00`000000amk70<ONa`020<ONaa8000001037g/L00`000000amk70<ONa`070<ONa`03
00000037g/L0amk700L0amk700<000000<ONa`37g/L01@37g/L00`1b>2400000078h8@07078h8@03
06Tc7P000000JC<N00D0JC<N0`1O;a`00`000000GblL05l_700205l_70h0000000@0<j7:00000000
000000000`38H34209e<9`030000001o?Ql0GBhE00H0amk700<000000<ONa`37g/L01P37g/L00`00
0000amk70<ONa`020<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L01@37g/L00`00
0000amk70<ONa`050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L00`00
0000amk70<ONa`050<ONa`0300000037g/L0amk700<000000P37g/L00`000000amk70<ONa`030<ON
a`0300000037g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`130<ON
a`0300000037g/L0amk700<0amk70@3oool000@0amk700<000000<ONa`37g/L0@037g/L00`000000
amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01P37g/L00`000000
amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L00P37g/L9000000@0
amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700L0
amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`050<ONa`03078h8@000000LSPQ00L0
LSPQ00<0JC<N0000001Y<ah01@1Y<ah305l_70030000001O;a`0GblL0080GblL101D:AT00`000000
E2TI05@Y6@0604LS5P030000000cXLX0<j7:0080b60a2@0000040<ONa`0300000037g/L0amk700L0
amk700<000000<ONa`37g/L00P37g/L01@000000amk70<ONa`37g/L0000000P0amk700<000000<ON
a`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700H0amk700<000000<ON
a`37g/L01@37g/L00`000000amk70<ONa`030<ONa`@000001037g/L00`000000amk70<ONa`030<ON
a`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0@`37g/L00`000000amk70<ONa`030<ON
a`40oooo00040<ONa`0300000037g/L0amk70440amk700<000000<ONa`37g/L01@37g/L00`000000
amk70<ONa`050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L00P37g/LA000000@0
amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0
amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700D0
amk700<0LSPQ0000001b>2401`1b>2400`1Y<ah0000006Tc7P0506Tc7P80GblL00<0000005l_701O
;a`00`1O;a`405@Y6@030000001D:AT0E2TI00H0Ab<F00<0000003>QbP0cXLX01@38H34209e<9`04
0000001o?Ql0GBhE0<ONa`T000001037g/L00`000000amk70<ONa`030<ONa`0500000037g/L0amk7
0<ONa`0000001`37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700H0amk700<00000
0<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700@00000
0<ONa`37g/L0amk71@0000040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0A@37
g/L00`000000amk70<ONa`020<ONa`40oooo00040<ONa`0300000037g/L0amk70480amk700<00000
0<ONa`37g/L01037g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700<0amk720000003
0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`06
0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`06
0<ONa`0300000037g/L0amk700L0amk700<000000<ONa`37g/L01@37g/L00`1b>2400000078h8@07
078h8@0306Tc7P000000JC<N00D0JC<N0P1O;a`00`000000GblL05l_700305l_70<0E2TI00@00000
05@Y6@1D:AT0E2TI1@178aH010000000=QXA03>QbP0cXLX50<QP<@0509e<9`000000WD`W07ln7`1M
;QD01@37g/L00`000000amk70<ONa`020<ONa`T0000000D0amk700000037g/L0amk7000000080<ON
a`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ON
a`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`030<ON
a`0300000037g/L0amk7008000000P37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk7
04H0amk700<000000<ONa`37g/L00P37g/L10?ooo`001037g/L00`000000amk70<ONa`120<ONa`03
00000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L6000000<0amk700<000000<ONa`37
g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37
g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37
g/L01P37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700D0amk700<0LSPQ0000001b
>2401`1b>2400`1Y<ah0000006Tc7P0506Tc7P80GblL00<0000005l_701O;a`00`1O;a`305@Y6@04
0000001D:AT0E2TI05@Y6@D0Ab<F00<0000003HJ4@0cXLX00P0cXLX40<QP<@0509e<9`000000WD`W
07ln7`1M;QD01037g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk70080amk720000004
0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`05
0<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`04
0<ONa`0300000037g/L0amk70080amk70`0000040<ONa`0300000037g/L0amk704L0amk700<00000
0<ONa`37g/L00P37g/L10?ooo`001037g/L00`000000amk70<ONa`130<ONa`0300000037g/L0amk7
00@0amk700<000000<ONa`37g/L0100000000`37g/L000000<ONa`070<ONa`0300000037g/L0amk7
00D0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk7
00H0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk7
00H0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`050<ONa`03078h8@000000LSPQ
00L0LSPQ00<0000006Tc7P1Y<ah01@1Y<ah205l_70030000001O;a`0GblL00<0GblL0`1D:AT01000
0000E2TI05@Y6@1D:AT504LS5P030000000f6Q40=QXA0080<j7:1038H3401@2MC2L0000009e<9`1o
?Ql0GBhE00@0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`040<ONa`0300000037
g/L0000000@0amk7200000040<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01@37
g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01037
g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk7008000000P37g/L00`000000amk70<ON
a`170<ONa`0300000037g/L0amk70080amk70@3oool000<0amk700<000000<ONa`37g/L0A037g/L0
0`000000amk70<ONa`020<ONa`D000001P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0
amk700H0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0
amk700D0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0
amk700L0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`03078h8@000000
LSPQ00L0LSPQ00<0000006Tc7P1Y<ah01@1Y<ah205l_70030000001O;a`0GblL00<0GblL0`1D:AT0
10000000E2TI05@Y6@1D:AT504LS5P030000000f6Q40<j7:00<0<j7:0`38H3401@000000WD`W09e<
9`1o?Ql0GBhE00@0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`040<ONa`030000
0037g/L0000000L0amk700<000000<ONa`37g/L00P37g/L7000000D0amk700<000000<ONa`37g/L0
1@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0
1037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk70080amk70P00001:0<ONa`030000
0037g/L0amk70080amk70@3oool000<0amk700<000000<ONa`37g/L0A@37g/L4000000@0amk700<0
00000<ONa`37g/L01037g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700L0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`03078h8@000000LSPQ00L0LSPQ00<0
000006Tc7P1Y<ah01@1Y<ah205l_70030000001O;a`0GblL00<0GblL0`1D:AT010000000E2TI05@Y
6@1D:AT404LS5P03000000178aH0=QXA00@0<j7:0`38H3401@000000WD`W09e<9`1o?Ql0GBhE00<0
amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`8000002037g/L00`000000
amk70<ONa`040<ONa`0300000037g/L0amk70080amk71P0000060<ONa`0300000037g/L0amk700@0
amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700@0
amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`190<ONa`0300000037g/L0amk70080
amk70@3oool000<0amk700<000000<ONa`37g/L0AP37g/L00`000000amk70<ONa`040<ONa`030000
0037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`030000
0037g/L0amk700H0amk700<000000<ONa`37g/L01`37g/L00`000000amk70<ONa`050<ONa`030000
0037g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`070<ONa`030000
0037g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L00`1b>2400000078h8@07078h8@030000
001Y<ah0JC<N00D0JC<N00<0GblL0000001O;a`01@1O;a`305@Y6@040000001D:AT0E2TI05@Y6@@0
Ab<F00<0000004LS5P0f6Q400P0f6Q4203>QbP<0b60a00D0000009e<9`2MC2L0OchO05d^5@030<ON
a`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L2000000L0amk700<000000<ON
a`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@000000P37g/L00`00
0000amk70<ONa`030<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L00`00
0000amk70<ONa`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L0BP37g/L00`00
0000amk70<ONa`020<ONa`40oooo00030<ONa`0300000037g/L0amk704H0amk700<000000<ONa`37
g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37
g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37
g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37
g/L01P37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<0LSPQ0000001b
>2401`1b>2400`000000JC<N06Tc7P0506Tc7P0305l_70000000GblL00D0GblL0P1D:AT00`000000
E2TI05@Y6@0205@Y6@@0Ab<F00<0000004LS5P0f6Q400P0f6Q4303>QbP030<QP<@000000WD`W0080
WD`W00D0OchO05d^5@37g/L0amk7000000080<ONa`0300000037g/L0amk700H0amk700<000000<ON
a`37g/L01P37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700H0amk700<000000<ON
a`37g/L01037g/L4000000@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ON
a`0300000037g/L0amk700<0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`1:0<ON
a`0300000037g/L0amk70080amk70@3oool000<0amk700<000000<ONa`37g/L0A`37g/L00`000000
amk70<ONa`040<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000
amk70<ONa`050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000
amk70<ONa`050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37g/L00`000000
amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L00`1b>240
0000078h8@07078h8@030000001Y<ah0JC<N00D0JC<N00<0GblL0000001O;a`01@1O;a`205@Y6@03
0000001D:AT0E2TI0080E2TI10178aH00`000000Ab<F03HJ4@0303HJ4@80<j7:00<0b60a0000002M
C2L00P2MC2L01@1o?Ql0GBhE0<ONa`37g/L0000000P0amk700<000000<ONa`37g/L01P37g/L00`00
0000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`00
0000amk70<ONa`050<ONa`0400000037g/L0amk70<ONa`D000001@37g/L00`000000amk70<ONa`04
0<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`1;
0<ONa`0300000037g/L0amk70080amk70@3oool000<0amk700<000000<ONa`37g/L0B037g/L00`00
0000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01P37g/L00`00
0000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01`37g/L00`00
0000amk70<ONa`050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L00P37g/Le0000
0080GblL0P1D:AT00`000000E2TI05@Y6@0205@Y6@<0Ab<F00<0000004LS5P178aH0100f6Q4303>Q
bP060000002MC2L0WD`W09e<9`1o?Ql0GBhE0P37g/L00`000000amk70<ONa`050<ONa`0300000037
g/L0amk700H0amk70P0000070<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01@37
g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`00
00020<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ON
a`030<ONa`0300000037g/L0amk704`0amk700<000000<ONa`37g/L00P37g/L10?ooo`000`37g/L0
0`000000amk70<ONa`180<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01@37g/L0
0`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01P37g/L0
0`000000amk70<ONa`020<ONaaX000000`37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0
amk700H0amk700<000000<ONa`37g/L01@37g/L00`1b>2400000078h8@07078h8@030000001Y<ah0
JC<N00D0JC<N00<0GblL0000001O;a`00`1O;a`A000000<0=QXA00<0<j7:00000038H3400`2MC2L0
101o?Ql0GBhE0<ONa`0000080<ONa`0300000037g/L0amk700H0amk70P0000060<ONa`0300000037
g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037
g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L4000000@0amk700<000000<ONa`37g/L00`37
g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk704d0amk700<000000<ONa`37g/L00P37
g/L10?ooo`000`37g/L00`000000amk70<ONa`190<ONa`0300000037g/L0amk700@0amk700<00000
0<ONa`37g/L01037g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<00000
0<ONa`37g/L00P37g/L8000000@0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`06
0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`06
0<ONa`0300000037g/L0amk700D0amk700<0LSPQ0000001b>2401`1b>2400`000000JC<N06Tc7P05
06Tc7P0305l_70000000GblL00D0GblL0P1D:AT00`000000E2TI05@Y6@0205@Y6@<0Ab<F00<00000
04LS5P178aH00P0f6Q4@000000@0amk700<000000<ONa`37g/L01P37g/L00`000000amk700000006
0<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`05
0<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01037g/L010000000amk70<ONa`37
g/L5000000@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`1>0<ONa`0300000037
g/L0amk70080amk70@3oool000<0amk700<000000<ONa`37g/L0B@37g/L00`000000amk70<ONa`04
0<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`02
0<ONa`P000000`37g/L00`000000amk70<ONa`070<ONa`0300000037g/L0amk700D0amk700<00000
0<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<00000
0<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`03078h8@000000LSPQ00L0LSPQ00<00000
06Tc7P1Y<ah01@1Y<ah00`000000GblL05l_700505l_700305@Y6@000000E2TI00@0E2TI0P178aH0
10000000Ab<F04LS5P178aH503HJ4@<0<j7:0`2MC2L0101o?Ql0GBhE0<ONa`0000030<ONa`P00000
1@37g/L00`000000amk7000000050<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L0
1@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0
1037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk7008000000P37g/L00`000000amk7
0<ONa`020<ONa`0300000037g/L0amk704l0amk700<000000<ONa`37g/L00P37g/L10?ooo`000`37
g/L00`000000amk70<ONa`1:0<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01037
g/L00`000000amk70<ONa`030<ONa`L000001037g/L00`000000amk70<ONa`050<ONa`0300000037
g/L0amk700H0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037
g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037
g/L0amk700D0amk700<0LSPQ0000001b>2401`1b>2400`000000JC<N06Tc7P0506Tc7P030000001O
;a`0GblL00D0GblL00<0E2TI0000001D:AT0101D:AT204LS5P04000000178aH0Ab<F04LS5PD0=QXA
00<0000003>QbP0cXLX00`2MC2L00`1o?Ql0GBhE000000080<ONa`0400000037g/L0amk70<ONa`T0
00001037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37
g/L01@37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37
g/L00`37g/L00`000000amk70<ONa`030<ONa`8000001@37g/L00`000000amk70<ONa`1?0<ONa`03
00000037g/L0amk70080amk70@3oool000<0amk700<000000<ONa`37g/L0B`37g/L00`000000amk7
0<ONa`030<ONa`0300000037g/L0amk70080amk7200000040<ONa`0300000037g/L0amk700@0amk7
00<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk7
00<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk7
00<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`050<ONa`03078h8@000000LSPQ00L0LSPQ
00<0000006Tc7P1Y<ah01@1Y<ah00`000000GblL05l_700505l_700305@Y6@000000E2TI00@0E2TI
0P178aH010000000Ab<F04LS5P178aH503HJ4@040000000cXLX0<j7:03>QbP80WD`W00<0OchO05d^
5@0000001`37g/L00`000000amk70<ONa`06000000@0amk7200000040<ONa`0300000037g/L0amk7
00@0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk7
00@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`030<ONa`0400000037g/L00000
00000080amk700<000000<ONa`37g/L0D037g/L00`000000amk70<ONa`020<ONa`40oooo00030<ON
a`0300000037g/L0amk704/0amk700<000000<ONa`37g/L00P37g/L6000000@0amk700<000000<ON
a`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<000000<ON
a`37g/L01P37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700H0amk700<000000<ON
a`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<000000<ON
a`37g/L01037g/L00`1b>2400000078h8@06078h8@030000001Y<ah0JC<N00H0JC<N00<0000005l_
701O;a`01@1O;a`00`1D:AT0000005@Y6@0405@Y6@80Ab<F00@0000004LS5P178aH0Ab<F1@0f6Q40
0`0000007Pl;03>QbP0203>QbP0409e<9`1o?Ql0OchO000000@0amk71P0000050<ONa`0300000037
g/L0amk700D0amk70`0000020<ONa`L000001037g/L00`000000amk70<ONa`040<ONa`0300000037
g/L0amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037
g/L0amk700<0amk700<000000<ONa`37g/L00P37g/L2000005@0amk700@000000<ONa`37g/L0amk7
0@3oool000<0amk700<000000<ONa`37g/L0C037g/L4000000<0amk700<000000<ONa`37g/L01037
g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01@37
g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01@37
g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01P37
g/L00`000000amk70<ONa`040<ONa`03078h8@000000LSPQ00H0LSPQ00<0000006Tc7P1Y<ah01P1Y
<ah00`000000GblL05l_700505l_70030000001D:AT0E2TI00@0E2TI00<0Ab<F000000178aH00`17
8aH403HJ4@030000000N3`/07Pl;0080<j7:0P2MC2L00`1o?Ql000000000000400000080amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700<0000000<0
amk700000037g/L00`37g/L5000000D0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ON
a`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ON
a`030<ONa`0300000037g/L0amk705<0amk700@000000<ONa`37g/L0amk70@3oool000<0amk700<0
00000<ONa`37g/L0C@37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700H0amk700<0
00000<ONa`37g/L01037g/L00`1b>2400000078h8@06078h8@030000001Y<ah0JC<N00H0JC<N00<0
000005l_701O;a`01@1O;a`00`000000E2TI05@Y6@0405@Y6@0304LS5P000000Ab<F00<0Ab<F100f
6Q49000000L0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037
g/L0amk700@0amk70`0000050<ONa`0300000037g/L0amk700<000000P37g/L00`000000amk70<ON
a`030<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ON
a`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L0E037g/L010000000amk70<ON
a`37g/L10?ooo`000P37g/L00`000000amk70<ONa`1>0<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`040<ONa`03078h8@000000LSPQ00H0LSPQ00<0
000006Tc7P1Y<ah01@1Y<ah00`000000GblL05l_700605l_70030000001D:AT0E2TI00@0E2TI00<0
Ab<F000000178aH00P178aH6000000@07Pl;0P0cXLX00`000000OchO0<ONa`050<ONa`0300000037
g/L0amk700D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037
g/L0amk700<000000P37g/L00`000000amk70<ONa`030<ONa`@000001037g/L00`000000amk70<ON
a`040<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ON
a`030<ONa`0300000037g/L0amk705D0amk700@000000<ONa`37g/L0amk70@3oool00080amk700<0
00000<ONa`37g/L0C`37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L01P37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700H0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700H0amk700<0
00000<ONa`37g/L01037g/L00`1b>2400000078h8@06078h8@030000001Y<ah0JC<N00D0JC<N00<0
000005l_701O;a`01P1O;a`00`000000E2TI05@Y6@0305@Y6@H0000000H0Ab<F03HJ4@0f6Q40=QXA
0000000f6Q4401h?2`80<j7:00<0000007ln7`37g/L01@37g/L00`000000amk70<ONa`050<ONa`03
00000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`<0
00001@37g/L010000000amk70<ONa`37g/L6000000@0amk700<000000<ONa`37g/L00`37g/L00`00
0000amk70<ONa`040<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L0EP37g/L01000
0000amk70<ONa`37g/L10?ooo`000P37g/L00`000000amk70<ONa`1@0<ONa`0300000037g/L0amk7
00<0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk7
00@0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`060<ONa`0300000037g/L0amk7
00@0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`020<ONac000000101O;a`70000
000305@Y6@000000Ab<F00@0Ab<F0`0f6Q400`000000=QXA01h?2`0301h?2`80<j7:00<0000007ln
7`37g/L01037g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<000000<ON
a`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk7008000000P37g/L00`00
0000amk70<ONa`040<ONa`0400000037g/L0amk70<ONa`D000001@37g/L00`000000amk70<ONa`03
0<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L0E`37g/L010000000amk70<ONa`37
g/L10?ooo`000P37g/L00`000000amk70<ONa`1@0<ONa`0300000037g/L0amk700@0amk700<00000
0<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<00000
0<ONa`37g/L01@37g/L00`000000amk70<ONa`020<ONaaL000000`37g/L00`000000amk70<ONa`05
0<ONa`0300000037g/L0amk700H0amk700<000000<ONa`37g/L01037g/L00`1b>2400000078h8@06
078h8@030000001Y<ah0JC<N00D0JC<N00<0000005l_700000004@00000204LS5P80=QXA00<00000
03HJ4@0f6Q40100N3`/0100cXLX0000007ln7`1o?Ql50<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L00`37g/L3000000D0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ON
a`0200000080amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`030<ONa`0300000037
g/L0amk705L0amk700@000000<ONa`37g/L0amk70@3oool00080amk700<000000<ONa`37g/L0D@37
g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01037
g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk70080amk7200000030<ONa`0300000037
g/L0amk700@0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037
g/L0amk700D0amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`040<ONa`03078h8@00
0000LSPQ00H0LSPQ00@0000006Tc7P1Y<ah0JC<N1P00000605l_70030000001D:AT0E2TI00D0E2TI
00@0000004LS5P178aH0Ab<F400000030<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37
g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37
g/L01037g/L00`000000amk70000000200000080amk700<000000<ONa`37g/L00`37g/L00`000000
amk70<ONa`030<ONa`@000000`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk705P0
amk700@000000<ONa`37g/L0amk70@3oool00080amk700<000000<ONa`37g/L0DP37g/L00`000000
amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L00P37g/L>000000<0
amk700<000000<ONa`37g/L01P37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700D0
amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0
amk700<000000<ONa`37g/L01037g/L00`1b>2400000078h8@04078h8@H00000101Y<ah00`000000
GblL05l_700505l_70030000001D:AT0E2TI00@0E2TI00<0000004LS5P178aH010178aH203HJ4@03
0000000f6Q40=QXA00@07Pl;0`0cXLX00`1o?Ql0amk700000006000000@0amk700<000000<ONa`37
g/L01037g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37
g/L01037g/L00`000000amk70<ONa`030<ONa`<000001037g/L00`000000amk70<ONa`040<ONa`04
00000037g/L0amk70<ONa`<000001@37g/L00`000000amk70<ONa`1I0<ONa`0400000037g/L0amk7
0<ONa`40oooo00020<ONa`0300000037g/L0amk705<0amk700<000000<ONa`37g/L00`37g/L00`00
0000amk70<ONa`020<ONa`L000001037g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk7
00D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk7
00D0amk700<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk7
00D0amk700<000000<ONa`37g/L01037g/L00`1b>24000000000000400000080LSPQ00<0000006Tc
7P1Y<ah01@1Y<ah00`000000GblL05l_700405l_70030000001O;a`0E2TI00D0E2TI00<0000004LS
5P178aH010178aH00`0f6Q40000003HJ4@0203HJ4@@07Pl;00@0000003>QbP0cXLX0OchO0`37g/L0
0`000000amk70<ONa`020<ONa`L000001037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0
amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0
amk700@000001P37g/L00`000000amk70<ONa`030<ONa`0400000037g/L0000000000080amk700<0
00000<ONa`37g/L0FP37g/L010000000amk70<ONa`37g/L10?ooo`000P37g/L00`000000amk70<ON
a`1C0<ONa`0300000037g/L0amk70080amk71P0000040<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01@37g/L00`000000amk70<ONa`050<ONa`T000001`1b>2400`000000JC<N06Tc
7P0506Tc7P030000001O;a`0GblL00@0GblL00<0000005l_701D:AT01@1D:AT00`000000Ab<F04LS
5P0404LS5P0303HJ4@000000=QXA0080=QXA100N3`/010000000<j7:03>QbP1o?Ql30<ONa`030000
0037g/L0amk700@0amk700<000000<ONa`37g/L00P37g/L7000000@0amk700<000000<ONa`37g/L0
0`37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0
0`37g/L3000000@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`020<ONa`800000
G@37g/L010000000amk70<ONa`37g/L10?ooo`000P37g/L00`000000amk70<ONa`1D0<ONa`@00000
0`37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L0
0`37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L0
1037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L0
1@37g/L00`000000amk70<ONa`06000000H0amk700<0LSPQ0000001b>2401@1b>2400`000000JC<N
06Tc7P0506Tc7P030000001Y<ah0GblL00D0GblL00<0000005l_701D:AT0101D:AT00`000000E2TI
04LS5P0504LS5P030000000f6Q40=QXA0080=QXA0`0N3`/00`000000<j7:03>QbP0203>QbP80amk7
00<000000<ONa`37g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk70080amk7
1P0000040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000amk7
0<ONa`040<ONa`0300000037g/L0amk700@000001@37g/L00`000000amk70<ONa`030<ONa`030000
0037g/L0amk705`0amk700@000000<ONa`37g/L0amk70@3oool00080amk700<000000<ONa`37g/L0
E@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0
1037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0
1@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L0
1037g/L00`000000amk70<ONa`020<ONa`H000001@37g/L00`000000amk70<ONa`040<ONa`03078h
8@000000LSPQ00D0LSPQ00<0000006Tc7P1Y<ah01@1Y<ah00`000000JC<N05l_700505l_70030000
001O;a`0E2TI00@0E2TI00<0000005@Y6@178aH01@178aH00`000000=QXA03HJ4@0203HJ4@<07Pl;
00<0000003>QbP0cXLX00P0cXLX20<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L0
1@37g/L00`000000amk70<ONa`040<ONa`0400000037g/L0amk70<ONa`H000001037g/L00`000000
amk70<ONa`040<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L400000080
amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`1M0<ONa`0400000037g/L0amk70<ON
a`40oooo00020<ONa`0300000037g/L0amk705H0amk700<000000<ONa`37g/L00`37g/L00`000000
amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000
amk70<ONa`050<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L00`000000
amk70<ONa`040<ONa`0300000037g/L0amk700<0amk71P0000030<ONa`0300000037g/L0amk700D0
amk700<000000<ONa`37g/L01037g/L00`1b>2400000078h8@05078h8@030000001Y<ah0JC<N00D0
JC<N00<0000006Tc7P1O;a`01@1O;a`00`000000GblL05@Y6@0405@Y6@030000001D:AT0Ab<F00D0
Ab<F00<0000003HJ4@0f6Q400P0f6Q4201h?2`030000000N3`/050X800<0<j7:00<0amk700000037
g/L01P37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37
g/L01037g/L010000000amk70<ONa`37g/L6000000@0amk700<000000<ONa`37g/L00`37g/L00`00
0000amk70<ONa`030<ONa`0300000037g/L0amk70080amk70`0000040<ONa`0300000037g/L0amk7
05h0amk700@000000<ONa`37g/L0amk70@3oool00080amk700<000000<ONa`37g/L0EP37g/L00`00
0000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01@37g/L00`00
0000amk70<ONa`030<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01@37g/L00`00
0000amk70<ONa`040<ONa`0300000037g/L0amk700<0amk71`0000020<ONa`0300000037g/L0amk7
00D0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`03078h8@000000LSPQ
00D0LSPQ00<0000006Tc7P1Y<ah01@1Y<ah00`000000JC<N05l_700405l_70030000001O;a`0GblL
00D0E2TI00<0000005@Y6@178aH010178aH00`000000=QXA03HJ4@0303HJ4@807Pl;00@0000001h?
2`0D2PP050X80P0cXLX00`37g/L000000<ONa`050<ONa`0300000037g/L0amk700@0amk700<00000
0<ONa`37g/L01@37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700@0amk700@00000
0<ONa`37g/L0amk71P0000030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L01037
g/L00`000000amk70000000300000640amk700@000000<ONa`37g/L0amk70@3oool00080amk700<0
00000<ONa`37g/L0E`37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L01037g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700D0amk700<0
00000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`H000000P37g/L00`000000amk70<ON
a`040<ONa`0300000037g/L0amk700D0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ON
a`040<ONa`03078h8@000000LSPQ00D0LSPQ00<0000006Tc7P1Y<ah01@1Y<ah00`000000JC<N05l_
700405l_70030000001O;a`0GblL00@0E2TI00<0000005@Y6@1D:AT01@178aH00`000000=QXA03HJ
4@0303HJ4@0401h?2`0000007Pl;01h?2`8050X80P0cXLX00`000000amk70<ONa`050<ONa`030000
0037g/L0amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`030000
0037g/L0amk700<0amk700<000000<ONa`37g/L01037g/L010000000amk70<ONa`37g/L5000000<0
amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`020<ONa`<00000H@37g/L00`000000
amk70<ONa`010?ooo`000P37g/L00`000000amk70<ONa`1H0<ONa`0300000037g/L0amk700@0amk7
00<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700<0amk7
00<000000<ONa`37g/L01037g/L00`000000amk70<ONa`050<ONadd000000`178aH00`000000Ab<F
03HJ4@0403HJ4@0401h?2`0000007Pl;01h?2`8050X80`0cXLX60<ONa`0300000037g/L0amk700@0
amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700<0
amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`030<ONa`0400000037g/L0amk70<ON
a`@000001@37g/L00`000000amk70<ONa`020<ONa`0400000037g/L0amk70<ONa`<00000GP37g/L0
0`000000amk70<ONa`010?ooo`0000<0amk700000037g/L0F`37g/L00`000000amk70<ONa`040<ON
a`0300000037g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`030<ON
a`0300000037g/L0amk70080amk73P0000030<ONa`0300000037g/L0amk700@0amk700<000000<ON
a`37g/L01037g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk700@0amk700<000000<ON
a`37g/L01037g/L00`1b>2400000078h8@05078h8@030000001Y<ah0JC<N00D0JC<N00<0000006Tc
7P1O;a`0101O;a`00`000000GblL05l_700405@Y6@040000001D:AT0E2TI04LS5Ph000000P0D2PP2
03>QbPL0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0
amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0
amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`0200000080amk700<00000
0<ONa`37g/L00P37g/L00`000000amk70<ONa`050<ONa`<00000F`37g/L00`000000amk70<ONa`01
0?ooo`0000<0amk700000037g/L0G037g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk7
00@0amk700<000000<ONa`37g/L00P37g/L@000000H0amk700<000000<ONa`37g/L01@37g/L00`00
0000amk70<ONa`040<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L01@37g/L00`00
0000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<0LSPQ0000001b>2401@1b>2400`00
0000JC<N06Tc7P0506Tc7P030000001Y<ah0GblL00@0GblL00<0000005l_701O;a`00`1D:AT01000
0000E2TI05@Y6@1D:AT404LS5P03000000178aH0=QXA00@0=QXA00@0000001h?2`0N3`/07Pl;1`00
00030<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ON
a`030<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ON
a`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L3000000<0amk700<0
00000<ONa`37g/L02@37g/L3000005P0amk700<000000<ONa`37g/L00@3oool000030<ONa`000000
amk705`0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`020<ONa`H000000`37g/L7
000000H0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0
amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0
amk700@0amk700<000000<ONa`37g/L01037g/L00`1b>2400000078h8@05078h8@030000001Y<ah0
JC<N00@0JC<N00<0000006Tc7P1Y<ah0101O;a`010000000GblL05l_701O;a`305@Y6@040000001D
:AT0E2TI05@Y6@<0Ab<F00<0000004LS5P178aH0100f6Q400`0000007Pl;01h?2`0201h?2`8050X8
0P0cXLX30<ONa``000001037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700<0amk7
00<000000<ONa`37g/L01037g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk700<0amk7
00<000000<ONa`37g/L01037g/L00`000000amk70<ONa`03000000l0amk70`00001E0<ONa`030000
0037g/L0amk70040oooo00000`37g/L000000<ONa`1M0<ONa`0300000037g/L0amk70080amk71P00
00030<ONa`L000001@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<0
00000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<0
LSPQ0000001b>2401@1b>2400`000000JC<N06Tc7P0406Tc7P030000001Y<ah0JC<N00@0GblL00@0
000005l_701O;a`0GblL0`1D:AT010000000E2TI05@Y6@1D:AT304LS5P03000000178aH0Ab<F00@0
=QXA00<0000001h?2`0N3`/00P0N3`/201@:20<0<j7:1037g/L00`000000amk70<ONa`030<ONa`04
00000037g/L0amk70<ONa`H000001037g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk7
00@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk7
00<0amk70P0000040<ONa`0300000037g/L0amk70140amk70P00001C0<ONa`0300000037g/L0amk7
0040oooo00000`37g/L000000<ONa`1N0<ONa`@000000`37g/L7000000H0amk700<000000<ONa`37
g/L00`37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37
g/L00`37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37
g/L01@37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700<0amk700<0LSPQ0000001b
>240101b>2400`000000LSPQ06Tc7P0506Tc7P030000001Y<ah0JC<N00@0GblL00@0000005l_701O
;a`0GblL0P1D:AT00`000000E2TI05@Y6@0205@Y6@<0Ab<F00<0000004LS5P178aH00`0f6Q400`00
0000=QXA01h?2`0301h?2`0301@:20000000<j7:00<0<j7:0`37g/L00`000000amk70<ONa`030<ON
a`0300000037g/L0amk700<0amk700@000000<ONa`37g/L0amk71P0000030<ONa`0300000037g/L0
amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0
amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`0D0<ONa`<00000D037g/L0
0`000000amk70<ONa`010?ooo`0000<0amk700000037g/L0GP37g/L7000000030<ONa`000000amk7
00@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk7
00<0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk7
00@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`050<ONa`0300000037g/L0amk7
00@0amk700<000000<ONa`37g/L00`37g/L00`1b>2400000078h8@04078h8@030000001b>240JC<N
00D0JC<N00<0000006Tc7P1Y<ah0101O;a`010000000GblL05l_701O;a`205@Y6@030000001D:AT0
E2TI0080E2TI0P178aH010000000Ab<F04LS5P178aH303HJ4@030000000f6Q407Pl;00<07Pl;00<0
50X80000000D2PP00P0cXLX30<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`37
g/L00`000000amk70<ONa`040<ONa`0400000037g/L0amk70<ONa`D000001037g/L00`000000amk7
0<ONa`030<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L00`37g/L00`000000amk7
0<ONa`030<ONa`0300000037g/L0amk701P0amk70`00001=0<ONa`0300000037g/L0amk70040oooo
00000`37g/L000000<ONa`1H0<ONa`H000000P37g/L00`000000amk70<ONa`030<ONa`0300000037
g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`030<ONa`0300000037
g/L0amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`030<ONa`0300000037
g/L0amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ONa`0300000037
g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`1b>2400000078h8@04078h8@030000001b
>240JC<N00@0JC<N00@0000006Tc7P1Y<ah0JC<N101O;a`010000000GblL05l_701O;a`205@Y6@03
0000001D:AT0E2TI0080E2TI0P178aH010000000Ab<F04LS5P178aH303HJ4@030000000f6Q407Pl;
00<07Pl;00<0000001@:200D2PP00P0cXLX20<ONa`0300000037g/L0amk700@0amk700<000000<ON
a`37g/L00`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700<0amk700@000000<ON
a`37g/L0amk71P0000030<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L00`37g/L0
0`000000amk70<ONa`030<ONa`0300000037g/L0amk701`0amk70`00001:0<ONa`0300000037g/L0
amk70040oooo00000`37g/L000000<ONa`1B0<ONa`H000002@37g/L00`000000amk70<ONa`030<ON
a`0300000037g/L0amk700<0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`030<ON
a`0300000037g/L0amk700<0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`030<ON
a`0300000037g/L0amk700@0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`040<ON
a`0300000037g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`1b>2400000078h8@04078h
8@030000001b>240JC<N00@0JC<N00@0000006Tc7P1Y<ah0JC<N0`1O;a`00`000000GblL05l_7002
05l_7080E2TI00<0000005@Y6@1D:AT00P1D:AT204LS5P04000000178aH0Ab<F04LS5P80=QXA00<0
000003HJ4@0f6Q40100N3`/00`00000050X801@:200203>QbP80amk700<000000<ONa`37g/L00`37
g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`37
g/L00`000000amk70<ONa`040<ONa`0400000037g/L0amk70<ONa`@000000`37g/L00`000000amk7
0<ONa`020<ONa`8000001037g/L200000280amk70P0000180<ONa`0300000037g/L0amk70040oooo
00000`37g/L000000<ONa`1<0<ONa`H000004037g/L00`000000amk70<ONa`030<ONa`0300000037
g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`040<ONa`0300000037
g/L0amk700<0amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`030<ONa`0300000037
g/L0amk700@0amk700@000000<ONa`37g/L0amk7:000000305l_70030000001O;a`0GblL0080GblL
00<0E2TI0000001D:AT0101D:AT00`178aH0000004LS5P0304LS5P80=QXA00<0000003HJ4@0f6Q40
0`0N3`/01000000050X801@:200D2PP203>QbP030<ONa`000000amk700@0amk700<000000<ONa`37
g/L00`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37
g/L01037g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700@000000`37g/L00`000000
amk70<ONa`030<ONa`0300000037g/L0amk702@0amk70`0000150<ONa`0300000037g/L0amk70040
oooo00000`37g/L000000<ONa`150<ONa`L000005P37g/L00`000000amk70<ONa`040<ONa`030000
0037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`030<ONa`030000
0037g/L0amk700<0amk700<000000<ONa`37g/L00P37g/LC00000080amk700<000000<ONa`37g/L0
1037g/L00`000000amk70<ONa`040<ONa`0300000037g/L0amk700<0amk700<0LSPQ0000001b>240
101b>2400`000000LSPQ06Tc7P0406Tc7P040000001Y<ah0JC<N06Tc7Q<000000P178aH00`0f6Q40
000003HJ4@0203HJ4@<07Pl;00@0000001@:200D2PP050X80P0cXLX00`000000amk70<ONa`040<ON
a`0300000037g/L0amk70080amk700<000000<ONa`37g/L01037g/L00`000000amk70<ONa`020<ON
a`0300000037g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`020<ON
a`0300000037g/L0amk700<000001@37g/L00`000000amk70<ONa`0X0<ONa`<00000@P37g/L00`00
0000amk70<ONa`010?ooo`0000<0amk700000037g/L0?`37g/L6000001h0amk700<000000<ONa`37
g/L00`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37
g/L00P37g/L<00000080amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`040<ONa`03
00000037g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`040<ONa`03
00000037g/L0amk700<0amk700<0LSPQ0000001b>240101b>2400`000000LSPQ06Tc7P0406Tc7P04
0000001Y<ah0JC<N06Tc7P<0GblL00<0000005l_701O;a`00P1O;a`00`1D:AT0000005@Y6@0405@Y
6@0404LS5P000000Ab<F04LS5P`000000P0D2PP203>QbP0300000037g/L0amk700<0amk700<00000
0<ONa`37g/L00`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700<0amk700<00000
0<ONa`37g/L00`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk70080amk700<00000
0<ONa`37g/L00P37g/L010000000amk70000000000020<ONa`0300000037g/L0amk702`0amk70`00
000o0<ONa`0300000037g/L0amk70040oooo00000`37g/L000000<ONa`0i0<ONa`H000009@37g/L0
0`000000amk70<ONa`030<ONa`0400000037g/L0amk70<ONa``000000`37g/L00`000000amk70<ON
a`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ON
a`040<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ON
a`040<ONa`0300000037g/L0amk700<0amk700<0LSPQ0000001b>240101b>2400`000000LSPQ06Tc
7P0306Tc7P030000001Y<ah0JC<N0080JC<N0P1O;a`00`000000GblL05l_700305l_70030000001D
:AT0E2TI00@0E2TI00<0000004LS5P178aH00`178aH00`000000=QXA03HJ4@0203HJ4@0501h?2`00
00007Pl;01h?2`0D2PP00P00000203>QbP8000001037g/L00`000000amk70<ONa`020<ONa`030000
0037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`030<ONa`030000
0037g/L0amk700<0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`020<ONa`030000
0037g/L0amk70080amk70P00000b0<ONa`<00000?037g/L00`000000amk70<ONa`010?ooo`0000<0
amk700000037g/L0<`37g/L6000002`0amk700@000000<ONa`37g/L0amk71@0000030<ONa`030000
0037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`030<ONa`030000
0037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`040<ONa`030000
0037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`040<ONa`030000
0037g/L0amk700<0amk700<0LSPQ0000001b>240101b>2400`000000LSPQ06Tc7P0306Tc7P030000
001Y<ah0JC<N0080JC<N0P1O;a`00`000000GblL05l_700305l_70030000001D:AT0E2TI00@0E2TI
00<0000004LS5P178aH00`178aH00`000000=QXA03HJ4@0203HJ4@0401h?2`0000007Pl;01h?2`<0
50X80P0cXLX20<ONa`/000000`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700<0
amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk70080
amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`0d0<ONa`800000>`37g/L100000040
amk70@3oool000030<ONa`000000amk702`0amk71`00000c0<ONa`<000000`37g/L00`000000amk7
0<ONa`030<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L01037g/L00`000000amk7
0<ONa`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk7
0<ONa`030<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37g/L00`37g/L00`000000amk7
0<ONa`030<ONa`0300000037g/L0amk700<0amk700<00000078h8@1b>2400`1b>2400`000000LSPQ
078h8@0406Tc7P030000001Y<ah0JC<N0080JC<N00<0GblL0000001O;a`01@1O;a`00`000000E2TI
05@Y6@0305@Y6@03000000178aH0Ab<F00<0Ab<F00<0000003HJ4@0f6Q400`0f6Q40100000007Pl;
01h?2`0N3`/201@:20030000000cXLX0<j7:00@0amk700<000000<ONa`37g/L00P37g/L010000000
amk70<ONa`37g/L5000000<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`030<ON
a`0300000037g/L0amk70080amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`020<ON
a`800000>@37g/L3000003P0amk70@0000010<ONa`40oooo00000`000000amk70<ONa`0V0<ONa`H0
0000>`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk70080amk700<000000<ONa`37
g/L00`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37
g/L00`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700@0amk700<000000<ONa`37
g/L00`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37
g/L00`37g/L00`000000LSPQ078h8@03078h8@030000001b>240LSPQ00@0JC<N00<0000006Tc7P1Y
<ah00P1Y<ah00`1O;a`0000005l_700405l_70030000001D:AT0E2TI00@0E2TI00<0000004LS5P17
8aH00P178aH00`000000Ab<F03HJ4@0403HJ4@040000000N3`/07Pl;01h?2`8050X800@0000003>Q
bP0cXLX0<j7:0P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk700<0amk700@00000
0<ONa`37g/L0amk71@0000030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00P37
g/L010000000amk70<ONa`37g/L2000000@0amk700<000000<ONa`37g/L0?037g/L3000003D0amk7
0@0000010<ONa`40oooo00000`000000amk70<ONa`0P0<ONa`H00000@P37g/L00`000000amk70<ON
a`030<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ON
a`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ON
a`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ON
a`030<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000LSPQ078h
8@03078h8@030000001b>240LSPQ00<0JC<N00<0000006Tc7P1Y<ah00`1Y<ah00`1O;a`0000005l_
700405l_70030000001D:AT0E2TI00<0E2TI00<0000005@Y6@178aH00`178aH00`000000Ab<F03HJ
4@0303HJ4@030000000N3`/07Pl;00807Pl;00<050X80000000cXLX00P0cXLX20<ONa`0300000037
g/L0amk700<0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`030<ONa`0400000037
g/L0amk70<ONa`D000000`37g/L00`000000amk70<ONa`020<ONa`0500000037g/L0amk70<ONa`00
00001@37g/L00`000000amk70<ONa`100<ONa`<00000<P37g/L100000040amk70@3oool000030000
0037g/L0amk701X0amk71P0000190<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L0
0`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L0
1037g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L0
1037g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L0
0`37g/L00`000000amk70<ONa`030<ONa`030000001b>240LSPQ00<0LSPQ00<00000078h8@1b>240
0`1Y<ah00`000000JC<N06Tc7P0306Tc7P030000001O;a`0GblL00@0GblL00<0000005@Y6@1D:AT0
0`1D:AT00`000000E2TI04LS5P0204LS5P03000000178aH0Ab<F00@0=QXA00<0000001h?2`0N3`/0
0P0N3`/00`00000050X801@:200203>QbP80amk700<000000<ONa`37g/L00P37g/L00`000000amk7
0<ONa`020<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L010000000amk7
0<ONa`37g/L4000000<0amk700D000000<ONa`37g/L0amk7000000050<ONa`0300000037g/L0amk7
04@0amk70`00000_0<ONa`4000000@37g/L10?ooo`0000<000000<ONa`37g/L04`37g/L700000500
amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk70080
amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700<0
amk700<000000<ONa`37g/L00`37g/L010000000amk70<ONa`37g/L^000000<0GblL00<0000005l_
701D:AT00`1D:AT00`000000E2TI05@Y6@0304LS5P03000000178aH0Ab<F00<0=QXA00<0000003HJ
4@0N3`/00P0N3`/01000000050X801@:200D2PP203>QbP030<ONa`000000amk700<0amk700<00000
0<ONa`37g/L00P37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk700<0amk700<00000
0<ONa`37g/L00P37g/L200000080amk7100000020<ONa`0300000037g/L0amk70080amk70P00001:
0<ONa`800000;@37g/L100000040amk70@3oool0000300000037g/L0amk700d0amk71P00001H0<ON
a`0300000037g/L0amk70080amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`030<ON
a`0300000037g/L0amk70080amk700<000000<ONa`37g/L00P37g/LA00000080amk700<000000<ON
a`37g/L00`37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk700<0amk700<000000<ON
a`37g/L00`37g/L00`000000LSPQ078h8@03078h8@030000001b>240LSPQ00<0JC<N00<0000006Tc
7P1Y<ah00`1Y<ah00`000000GblL05l_700A0000000604LS5P0f6Q40=QXA03HJ4@000000=QXA0`0N
3`/00`00000050X801@:200303>QbP0300000037g/L0amk70080amk700<000000<ONa`37g/L00`37
g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00P37
g/L00`000000amk70<ONa`020<ONa`8000000P37g/L3000000<0amk700<000000<ONa`37g/L0C037
g/L3000002X0amk70@0000010<ONa`40oooo00000`000000amk70<ONa`070<ONa`H00000G`37g/L0
0`000000amk70<ONa`020<ONa`0300000037g/L0amk70080amk700@000000<ONa`37g/L0amk72`00
00030<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ON
a`040<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ON
a`030<ONa`0300000037g/L0amk700<0amk700<00000078h8@1b>2400`1b>2400`000000LSPQ078h
8@0306Tc7P030000001Y<ah0JC<N0080JC<N00<0000005l_701O;a`0101O;a`00`000000GblL05@Y
6@0205@Y6@060000001D:AT0E2TI05@Y6@178aH000000`178aH;0000000401@:200cXLX0<j7:0000
00D0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk7
0080amk70P0000040<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L00P37g/L00`00
0000amk70<ONa`0300000580amk70`00000W0<ONa`4000000@37g/L10?ooo`0000@000000<ONa`37
g/L0amk71P00001V0<ONa`0400000037g/L0amk70<ONa`T000000`37g/L00`000000amk70<ONa`02
0<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`03
0<ONa`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`02
0<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L00`37g/L00`000000LSPQ078h8@03
078h8@030000001b>240LSPQ00<0JC<N00<0000006Tc7P1Y<ah00P1Y<ah00`000000GblL05l_7003
05l_70030000001O;a`0GblL00<0E2TI00H0000005@Y6@1D:AT0E2TI04LS5P00000404LS5P0303HJ
4@000000=QXA0080=QXA00D07Pl;0000000N3`/07Pl;01@:2005000000<0amk700<000000<ONa`37
g/L00P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk70080amk700<000000<ONa`37
g/L00P37g/L2000000@0amk700@000000<ONa`37g/L0amk70P0000030<ONa`800000EP37g/L30000
02@0amk70@0000010<ONa`40oooo0004000006d0amk70`0000020<ONa`0300000037g/L0amk70080
amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk700<0
amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk700<0
amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk70080
amk700<000000<ONa`37g/L00`37g/L00`000000LSPQ078h8@02078h8@040000001b>240LSPQ078h
8@80JC<N00<0000006Tc7P1Y<ah00`1Y<ah00`000000GblL05l_700305l_70030000001O;a`0GblL
0080E2TI00<0000005@Y6@1D:AT00P1D:AT00`000000Ab<F04LS5P0304LS5P030000000f6Q40=QXA
0080=QXA00@0000001h?2`0N3`/07Pl;0P0D2PP203>QbP80amk72@0000030<ONa`0300000037g/L0
amk70080amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`020<ONa`8000000`37g/L0
0`000000amk70<ONa`020<ONa`0300000037g/L0amk705T0amk70`00000Q0<ONa`4000000@37g/L1
0?ooo`000`37g/L5000006X0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`020<ON
a`0300000037g/L0amk700<0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`020<ON
a`0300000037g/L0amk70080amk700<000000<ONa`37g/L00`37g/L00`000000amk70<ONa`030<ON
a`0300000037g/L0amk70080amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`030<ON
a`0400000037g/L0amk70<ONa`800000101b>24010000000LSPQ078h8@1b>24206Tc7P030000001Y
<ah0JC<N00<0JC<N00<0000005l_701O;a`00P1O;a`010000000GblL05l_701O;a`205@Y6@030000
001D:AT0E2TI0080E2TI00<0000004LS5P178aH00`178aH00`000000=QXA03HJ4@0203HJ4@060000
000N3`/07Pl;01h?2`0D2PP000000P0cXLX30<ONa`0300000037g/L0amk70080amk700<000000<ON
a`37g/L0100000030<ONa`0400000037g/L0amk70<ONa`8000001037g/L00`000000amk70<ONa`02
0<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L0G@37g/L2000001l0amk70@000001
0<ONa`40oooo00080<ONa`@00000I`37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk7
0080amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk7
00<0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk7
00<0amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk7
00<0amk700@000000<ONa`37g/L0amk70P000004078h8@040000001b>240LSPQ078h8@80JC<N00<0
000006Tc7P1Y<ah00P1Y<ah00`000000JC<N05l_700305l_70060000001O;a`0GblL05l_701D:AT0
0000101D:AT00`000000Ab<F04LS5P0304LS5P030000000f6Q40=QXA0080=QXA00<0000001h?2`0N
3`/00P0N3`/010000000<j7:03>QbP0cXLX20<ONa`0300000037g/L0amk70080amk700<000000<ON
a`37g/L00P37g/L00`000000amk70<ONa`08000000<0amk70P0000030<ONa`8000000`37g/L20000
0680amk70`00000L0<ONa`4000000@37g/L10?ooo`003037g/L5000006<0amk700<000000<ONa`37
g/L00P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk70080amk700<000000<ONa`37
g/L00P37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk70080amk700<000000<ONa`37
g/L00P37g/L00`000000amk70<ONa`030<ONa`0300000037g/L0amk70080amk700<000000<ONa`37
g/L00P37g/L00`000000amk70<ONa`020<ONa`0400000037g/L0amk70<ONa`800000101b>2401000
0000LSPQ078h8@1b>24206Tc7P030000001Y<ah0JC<N0080JC<N00<0000006Tc7P1O;a`00`1O;a`0
1P000000GblL05l_701O;a`0E2TI000000@0E2TI00<0000004LS5P178aH00P178aH00`000000Ab<F
03HJ4@0203HJ4@030000000f6Q407Pl;00<07Pl;00H0000003>QbP0cXLX0<j7:0<ONa`0000040<ON
a`0300000037g/L0amk70080amk700<000000<ONa`37g/L00P37g/L01@000000amk70<ONa`37g/L0
00000080amk7100000030<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L0I@37g/L3
000001T0amk70@0000010<ONa`40oooo000A0<ONa`D00000G`37g/L2000000<0amk700<000000<ON
a`37g/L00P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk70080amk700<000000<ON
a`37g/L00P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk70080amk700@000000<ON
a`37g/L0amk7:@00000205l_70030000001O;a`0GblL0080GblL00<0000005@Y6@1D:AT00P1D:AT0
0`000000E2TI04LS5P0204LS5P03000000178aH0Ab<F0080=QXA00<0000003HJ4@0f6Q400`0N3`/0
1P00000050X803>QbP0cXLX0amk7000000@0amk700<000000<ONa`37g/L00P37g/L00`000000amk7
0<ONa`020<ONa`0300000037g/L0amk7008000000`37g/L200000080amk7100000020<ONa`800000
J`37g/L3000001H0amk70@0000010<ONa`40oooo000F0<ONa`D00000G037g/L01@000000amk70<ON
a`37g/L0000000@0amk700<000000<ONa`37g/L00P37g/L010000000amk70<ONa`37g/LC00000080
amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk70080
amk700@000000<ONa`37g/L0amk70P000004078h8@040000001b>240LSPQ078h8@80JC<N00<00000
06Tc7P1Y<ah00P1Y<ah00`000000JC<N05l_700>000000<0Ab<F00<0000004LS5P178aH00P0f6Q40
0`000000=QXA03HJ4@0201h?2`030000000N3`/050X80080<j7:00<000000<ONa`37g/L00P37g/L0
10000000amk70<ONa`37g/L2000000@0amk700@000000<ONa`37g/L000001037g/L00`000000amk7
0<ONa`020<ONa`8000000P37g/L200000700amk70`00000C0<ONa`4000000@37g/L10?ooo`006`37
g/L5000005P0amk700D000000<ONa`37g/L0amk7000000030<ONa`T000000P37g/L00`000000amk7
0<ONa`020<ONa`0300000037g/L0amk70080amk700D000000<ONa`37g/L0amk7000000040<ONa`03
00000037g/L0amk700<0amk700D000000<ONa`37g/L0amk7000000040<ONa`0400000037g/L0amk7
0<ONa`800000101b>2401P000000LSPQ078h8@1b>240JC<N000000@0JC<N00<0000006Tc7P1Y<ah0
0`1O;a`01@000000GblL05l_701O;a`0000000@0E2TI00<0000005@Y6@1D:AT03P000000100N3`/0
50X803>QbP0000040<ONa`0500000037g/L0amk70<ONa`0000001037g/L200000080amk700<00000
0<ONa`37g/L00P37g/L00`000000amk70<ONa`020<ONa`0400000037g/L0amk70<ONa`800000M037
g/L200000180amk70@0000010?ooo`008037g/L4000005D0amk71`0000020<ONa`0300000037g/L0
amk70080amk700<000000<ONa`37g/L00P37g/L01@000000amk70<ONa`37g/L0000000@0amk700<0
00000<ONa`37g/L00P37g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk70080amk700D0
00000<ONa`37g/L0amk7000000040<ONa`0400000037g/L0amk70<ONa`800000101b>2401P000000
LSPQ078h8@1b>240JC<N000000@0JC<N00<0000006Tc7P1Y<ah00P1O;a`00`000000GblL05l_7002
05l_70030000001D:AT0E2TI0080E2TI00D0000005@Y6@1D:AT0Ab<F0000000404LS5P030000000f
6Q40=QXA0080=QXA00@0000001h?2`0N3`/000000`0cXLX30<ONa`0500000037g/L0amk70<ONa`00
00001037g/L00`000000amk70<ONa`02000000<0amk70P0000030<ONa`8000000P37g/L2000007P0
amk70`00000?0<ONa`4000000@3oool002@0amk71@00001A0<ONa`0500000037g/L0amk70<ONa`00
00001037g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk70080amk700D000000<ONa`37
g/L0amk7000000040<ONa`0500000037g/L0amk70<ONa`0000001037g/L00`000000amk70<ONa`02
0<ONa`0300000037g/L0amk70080amk700<000000<ONa`37g/L00P37g/L00`000000amk70<ONa`02
000000<0LSPQ00<00000078h8@1b>2400P1b>2400`1Y<ah0000006Tc7P0206Tc7P040000001Y<ah0
JC<N06Tc7P80GblL00H0000005l_701O;a`0GblL0000001O;a`305@Y6@060000001D:AT0E2TI05@Y
6@178aH000000`178aH00`000000=QXA03HJ4@0203HJ4@080000000N3`/07Pl;01h?2`0cXLX00000
03>QbP37g/L8000000<0amk700@000000<ONa`37g/L000001037g/L010000000amk70<ONa`37g/L2
00000080amk70P00001m0<ONa`<000003037g/L100000040oooo000Y0<ONa`D00000C@37g/L01@00
0000amk70<ONa`37g/L0000000@0amk700<000000<ONa`37g/L00P37g/L01@000000amk70<ONa`37
g/L0000000@0amk700D000000<ONa`37g/L0amk7000000040<ONa`0500000037g/L0amk70<ONa`00
00001037g/L00`000000amk70<ONa`020<ONa`0300000037g/L0amk70080amk700<000000<ONa`37
g/L00P000003078h8@030000001b>240LSPQ0080LSPQ00<0JC<N0000001Y<ah00P1Y<ah01P000000
JC<N06Tc7P1Y<ah0GblL000000@0GblL00D0000005l_701D:AT0E2TI0000000405@Y6@0600000017
8aH0Ab<F04LS5P000000Ab<F0`0f6Q400`000000=QXA01h?2`0201h?2`040000000cXLX0amk70<ON
a`8000000`37g/L00`000000amk70<ONa`0700000080amk70P0000030<ONa`0300000037g/L0amk7
00800000PP37g/L3000000T0amk70@0000010?ooo`00;P37g/L5000004T0amk700D000000<ONa`37
g/L0amk7000000040<ONa`0500000037g/L0amk70<ONa`0000001037g/L00`000000amk70<ONa`02
0<ONa`0500000037g/L0amk70<ONa`0000000`37g/L01@000000amk70<ONa`37g/L0000000D0amk7
00D000000<ONa`37g/L0amk7000000040<ONa`0300000037g/L0amk7008000000`1b>2400`000000
LSPQ078h8@02078h8@030000001Y<ah0JC<N0080JC<N00H0000006Tc7P1Y<ah0JC<N05l_70000003
05l_70050000001O;a`0GblL05@Y6@000000101D:AT00`000000Ab<F04LS5P0204LS5P0500000017
8aH0=QXA03HJ4@0000000P0f6Q4201h?2`050000000cXLX0<j7:03>QbP0000001037g/L010000000
amk70<ONa`37g/L200000080amk700<000000<ONa`37g/L00`0000020<ONa`80000000<0amk70000
00000000Q`37g/L3000000H0amk70@0000010?ooo`00<`37g/L5000004D0amk70P0000020<ONa`80
00000`37g/L01@000000amk70<ONa`37g/L0000000@0amk700D000000<ONa`37g/L0amk700000003
0<ONa`0300000037g/L0amk70080amk700D000000<ONa`37g/L0amk7000000020<ONaaX000000P1Y
<ah00`000000JC<N06Tc7P0206Tc7P030000001O;a`0GblL0080GblL00D0000005l_701O;a`0E2TI
0000000305@Y6@030000001D:AT0Ab<F0080Ab<F00D0000004LS5P178aH0=QXA0000000303HJ4@03
01h?2`000000<j7:0080<j7:00<000000<ONa`37g/L00P37g/L01@000000amk70<ONa`37g/L00000
0080amk70P0000020<ONa`8000000P37g/L5000008`0amk70P0000040<ONa`4000000@3oool003P0
amk7100000130<ONa`0500000037g/L0amk70<ONa`0000000`37g/L01@000000amk70<ONa`37g/L0
000000<0amk7500000020<ONa`0500000037g/L0amk70<ONa`0000001037g/L00`000000amk70<ON
a`02000000<0LSPQ00<00000078h8@1b>2400P1b>2400`000000JC<N0000000@000000<0E2TI00D0
000005@Y6@178aH0Ab<F0000000304LS5P030000000f6Q40=QXA0080=QXA00D0000003>QbP0cXLX0
<j7:000000030<ONa`8000000P37g/L200000080amk700D000000<ONa`37g/L0amk7000000030<ON
a`80000000<0amk7000000000000S`37g/L300000040amk70@0000010?ooo`00?037g/L5000003l0
amk700D000000<ONa`37g/L0amk7000000020<ONa`P000000P37g/L01@000000amk70<ONa`37g/L0
000000<0amk700D000000<ONa`37g/L0amk7000000020<ONa`0300000037g/L0amk700<0amk700D0
00000<ONa`37g/L0amk7000000030<ONa`0300000037g/L0amk7008000000`1b>2401@000000LSPQ
078h8@1b>240000000@0JC<N00D0000006Tc7P1Y<ah0JC<N0000000305l_70050000001O;a`0GblL
05l_700000000P1D:AT<000000<0=QXA00@0000001h?2`0cXLX0<j7:1037g/L01@000000amk70<ON
a`37g/L0000000<0amk700<000000<ONa`37g/L00P0000020<ONa`80000000<0amk7000000000000
T@37g/L500000040oooo00110<ONa`D00000>`37g/L600000080amk700D000000<ONa`37g/L0amk7
000000040<ONa`0500000037g/L0amk70<ONa`0000000P37g/L01@000000amk70<ONa`37g/L00000
00<0amk700<000000<ONa`37g/L00P37g/L01@000000amk70<ONa`37g/L0000000<0amk700<00000
0<ONa`37g/L00P000003078h8@050000001b>240LSPQ078h8@0000000`1Y<ah00`000000JC<N06Tc
7P0206Tc7P050000001O;a`0GblL05l_700000000P1O;a`00`000000GblL05@Y6@0205@Y6@050000
001D:AT0E2TI05@Y6@0000000`178aH00`000000Ab<F03HJ4@060000000503>QbP37g/L0amk70<ON
a`0000000P37g/L200000080amk70P0000020<ONa`0500000037g/L0amk70<ONa`0000000P37g/L0
0`000000amk70<ONa`280<ONa`T000001@37g/L10?ooo`00AP37g/L5000003L0amk700@000000<ON
a`37g/L0amk70P0000020<ONa`0500000037g/L0amk70<ONa`0000001037g/L010000000amk70<ON
a`0000030<ONa`0500000037g/L0amk70<ONa`0000000P37g/L00`000000amk70<ONa`020<ONa`05
00000037g/L0amk70<ONa`0000000`37g/L00`000000amk70<ONa`02000000<0LSPQ00D00000078h
8@1b>240LSPQ0000000306Tc7P060000001Y<ah0JC<N06Tc7P000000JC<N0P1O;a`010000000GblL
05l_7000000205l_7080E2TI00D0000005@Y6@1D:AT0E2TI0000000304LS5P03000000178aH0Ab<F
0080=QXA00<0000003HJ4@0cXLX00`0cXLX700000080amk700<000000<ONa`37g/L00P0000020<ON
a`80000000<0amk7000000000000P@37g/L:000000h0amk70@3oool004/0amk71000000d0<ONa`80
00000`37g/L00`000000amk70<ONa`0200000080amk700D000000<ONa`37g/L0amk7000000030<ON
a`0500000037g/L0amk70<ONa`0000000`37g/L010000000amk70<ONa`0000030<ONa`0500000037
g/L0amk70<ONa`0000000`37g/L00`000000amk70<ONa`02000000<0LSPQ00D00000078h8@1b>240
LSPQ0000000306Tc7P040000001Y<ah0JC<N00000080JC<N00<0GblL0000001O;a`00P1O;a`01@00
0000GblL05l_701D:AT0000000<0E2TI00<0000005@Y6@178aH00P00000304LS5P80000000<0=QXA
0000000000000P0cXLX01037g/L0000000000037g/L200000080amk71@0000020<ONa`80000000<0
amk7000000000000NP37g/L9000001P0amk70@3oool004l0amk71@00000a0<ONa`0500000037g/L0
amk70<ONa`0000000`37g/L010000000amk70<ONa`0000030<ONa`0500000037g/L0amk70<ONa`00
00000P37g/L01@000000amk70<ONa`37g/L000000080amk700<000000<ONa`37g/L00P37g/L01@00
0000amk70<ONa`37g/L000000080amk700<000000<ONa`37g/L00P000003078h8@050000001b>240
LSPQ0000001b>2400P1Y<ah01@000000JC<N06Tc7P1Y<ah000000080JC<N00D0GblL0000001O;a`0
GblL0000000305l_700505@Y6@000000E2TI05@Y6@0000000P1D:AT00`000000Ab<F04LS5P0204LS
5P040000000f6Q40=QXA000000<0<j7:0P0000020<ONa`0400000037g/L0amk70<ONa`80000000@0
amk7000000000000amk71@00001c0<ONa`T000008@37g/L10?ooo`00E037g/L5000002d0amk700@0
00000<ONa`37g/L0amk70P0000020<ONa`0400000037g/L0amk7000000<0amk700<000000<ONa`37
g/L0<@00000305l_70040000001D:AT0E2TI00000080E2TI00<0000004LS5P178aH00P178aH01@00
0000Ab<F03HJ4@000000=QXA0080<j7:00<000000<ONa`37g/L00P0000020<ONa`80000000<0amk7
0000000000000P37g/L2000000030<ONa`000000000006/0amk72@00000Z0<ONa`40oooo001I0<ON
a`D00000:@37g/L200000080amk73@0000020<ONa`0400000037g/L0amk700000080amk700D00000
0<ONa`37g/L0amk7000000020<ONa`0500000037g/L0amk70<ONa`0000000P37g/L00`000000amk7
0<ONa`02000000<0LSPQ00L00000078h8@1b>2400000078h8@1Y<ah000000080JC<N00D0000006Tc
7P1Y<ah0JC<N0000000205l_70030000001O;a`0GblL00X000000P178aH20000000404LS5P000000
000003HJ4@80<j7:0`37g/L00`000000amk70<ONa`0200000080amk700<000000<ONa`37g/L00P00
00000`37g/L000000000001T0<ONa`T00000<`37g/L10?ooo`00GP37g/L5000002H0amk70P000002
0<ONa`0300000037g/L0amk70080000000<0amk70000000000000P37g/L01@000000amk70<ONa`37
g/L000000080amk700@000000<ONa`37g/L000000P37g/L01@000000amk70<ONa`37g/L000000080
amk700@000000<ONa`37g/L000000P37g/L2000000<0LSPQ00L00000078h8@1b>2400000078h8@1Y
<ah000000080JC<N00D0000006Tc7P1Y<ah0JC<N0000000205l_70080000001O;a`0GblL05l_7000
0000GblL05@Y6@00000205@Y6@030000001D:AT0E2TI00P000000P0cXLX01037g/L0000000000037
g/L200000080amk70P0000001037g/L0000000000037g/L2000005`0amk72P00000l0<ONa`40oooo
001S0<ONa`@000008`37g/L200000080amk70P0000020<ONa`0400000037g/L0amk700000080amk7
00@000000<ONa`37g/L000000P37g/L010000000amk70<ONa`0000030<ONa`0400000037g/L0amk7
000000<0amk700D000000<ONa`37g/L000000<ONa`0200000080LSPQ00@00000078h8@1b>2400000
0P1b>24010000000JC<N06Tc7P00000306Tc7P040000001Y<ah0GblL000000<0GblL00@0000005l_
701O;a`000000P1D:AT00`000000E2TI05@Y6@020000000404LS5P000000000003>QbP8000000P0c
XLX500000080amk70P0000001037g/L0000000000037g/L2000005D0amk72@0000160<ONa`40oooo
001W0<ONa`D000008037g/L01@000000amk70<ONa`37g/L000000080amk700@000000<ONa`37g/L0
00000P37g/L010000000amk70<ONa`0000020<ONa`0400000037g/L0amk700000080amk700D00000
0<ONa`37g/L0amk7000000020<ONa`0500000037g/L0amk700000037g/L00P000002078h8@040000
001b>240LSPQ00000080LSPQ00@0000006Tc7P1Y<ah000000P1Y<ah010000000JC<N06Tc7P000003
05l_70050000001O;a`000000000001D:AT00P00000205@Y6@040000001D:AT0Ab<F00000080Ab<F
00<0000003>QbP0cXLX00P0000000`37g/L00000000000020<ONa`D0000000<0amk7000000000000
CP37g/L9000004l0amk70@3oool006`0amk71@00000L0<ONa`8000000P37g/L00`000000amk70<ON
a`02000000050<ONa`00000000000<ONa`0000000P37g/L01P000000amk70<ONa`000000amk70000
0080amk75`0000000`1Y<ah0000006Tc7P0206Tc7P040000001Y<ah0JC<N00000080GblL00<00000
05l_700000000P1O;a`01@000000E2TI05@Y6@1D:AT000000080E2TI00@0000004LS5P0000000000
0P0cXLX010000000amk70000000000020<ONa`80000000@0amk7000000000000amk70P0000170<ON
a`T00000F037g/L10?ooo`00L@37g/L5000001T0amk70P0000000`37g/L00000000000020<ONa`l0
00000P37g/L00`000000amk7000000020<ONa`0500000037g/L0amk700000037g/L00P000002078h
8@070000001b>240LSPQ0000001b>240000006Tc7P0@00000080E2TI0P0000000`1D:AT000000000
0002000000<0<j7:00@0amk7000000000000amk70`0000000`37g/L000000000000300000400amk7
2@00001Q0<ONa`40oooo001f0<ONa`@000005`37g/L5000000070<ONa`00000000000<ONa`000000
amk7000000020<ONa`0600000037g/L0amk700000037g/L000000P37g/L01P000000amk70<ONa`00
0000amk700000080amk700@000000<ONa`00000000000P1b>24020000000LSPQ0000001b>2400000
078h8@1Y<ah000000P1Y<ah02P000000JC<N06Tc7P000000JC<N05l_70000000GblL0000001O;a`2
0000000305l_70000000000000D000000P0cXLX01@000000<j7:000000000000amk7008000000P37
g/L4000003T0amk72P00001Z0<ONa`40oooo001j0<ONa`D000005037g/L400000080amk700D00000
0<ONa`000000amk7000000020<ONa`80000000@0amk700000037g/L000000P37g/L00`000000amk7
000000020<ONa`0400000037g/L000000<ONa`80000000T0LSPQ0000001b>240LSPQ0000001b>240
0000078h8@0000000P1Y<ah010000000JC<N00000000000206Tc7P050000001O;a`0000005l_7000
00000P1O;a`20000000405@Y6@000000000000000080<j7:1`0000020<ONa`@00000<P37g/L90000
07@0amk70@3oool007l0amk71@00000A0<ONa`@0000000<0amk700000037g/L0100000020<ONa`07
00000037g/L000000<ONa`000000amk7000000020<ONa`0600000037g/L000000<ONa`000000amk7
0P0000001P1b>2400000078h8@000000LSPQ00000080LSPQ00D0000006Tc7P000000JC<N00000002
06Tc7P@0000000<0GblL0000001O;a`00P0000000`1O;a`00000000000020000000405@Y6@000000
000003>QbP<000000P37g/L4000002`0amk72@00001m0<ONa`40oooo00240<ONa`D000003P37g/L6
000000040<ONa`000000amk700000080amk77000000206Tc7P040000001Y<ah0000005l_70@00000
00<0GblL0000000000000P0000000`0cXLX000000000000203>QbP80000000<0amk7000000000000
0P00000V0<ONa`T00000QP37g/L10?ooo`00R@37g/L5000000/0amk72P0000001`37g/L000000<ON
a`000000amk700000037g/L00P0000001@37g/L000000<ONa`000000amk70080000000`0LSPQ0000
00000000LSPQ0000001b>2400000078h8@000000JC<N0000001Y<ah=0000000303>QbP0000000000
00<0<j7:1P00000O0<ONa`T00000S`37g/L10?ooo`00SP37g/L4000000T0amk70`0000000`37g/L0
000000000003000000030<ONa`00000000000080000000D0amk700000037g/L000000<ONa`020000
00070<ONa`00000000000000001b>2400000078h8@0200000005078h8@000000JC<N0000001Y<ah0
2`0000000`1O;a`0<j7:000000020000000503>QbP000000000000000037g/L00P00000H0<ONa`X0
0000V037g/L10?ooo`00TP37g/L5000000H0amk70`0000000`37g/L0000000000003000000050<ON
a`000000000000000037g/L00P0000000`37g/L000000<ONa`0500000005078h8@000000LSPQ0000
001b>2401P0000000`1Y<ah00000000000040000000403>QbP000000000000000080<j7:0P000000
1037g/L0000000000000000A0<ONa`T00000XP37g/L10?ooo`00U`37g/L5000000<0amk70`000000
0`37g/L000000000000I0000000306Tc7P000000000000L00000100cXLX4000000/0amk72@00002[
0<ONa`40oooo002L0<ONa`T0000000<0amk7000000000000100000000`37g/L00000000000080000
0003078h8@000000000000`000000P0cXLX4000000H0amk72@00002d0<ONa`40oooo002Q0<ONa`h0
000000<0amk70000000000000P0000000`1b>24000000000000<000000<0<j7:0P0000000`37g/L0
00000000000700000;d0amk70@3oool00:H0amk7500000000`1b>240000000000003000000D0<j7:
100000360<ONa`40oooo002Z0<ONa`/000000P0cXLX6000000D0<j7:c@37g/L10?ooo`00[`37g/L0
0`000000<j7:00000005000000L0<j7:d@37g/L10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {389.375, 0}} -> {0.0371777, -4.36153*^-06, \
0.00224027, 0.00224027}}]
}, Open  ]],

Cell[BoxData[
    \(Clear[\[Alpha], xyzrules, cylinder, sphere]\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowSize->{683, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 33, 0, 67, "Title"],
Cell[1790, 53, 129, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[1944, 59, 38, 0, 52, "Subsection"],
Cell[1985, 61, 304, 7, 48, "Text"],
Cell[2292, 70, 110, 3, 29, "Text"],
Cell[2405, 75, 89, 1, 51, "Input"],
Cell[2497, 78, 85, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[2607, 84, 83, 1, 50, "Input"],
Cell[2693, 87, 107, 2, 49, "Output"]
}, Open  ]],
Cell[2815, 92, 147, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[2987, 101, 140, 3, 71, "Input"],
Cell[3130, 106, 124, 2, 50, "Output"],
Cell[3257, 110, 59, 1, 49, "Output"]
}, Open  ]],
Cell[3331, 114, 71, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[3427, 118, 125, 2, 71, "Input"],
Cell[3555, 122, 111, 2, 49, "Output"],
Cell[3669, 126, 63, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3769, 132, 122, 2, 51, "Input"],
Cell[3894, 136, 65, 1, 55, "Output"]
}, Open  ]],
Cell[3974, 140, 70, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[4069, 144, 143, 3, 50, "Input"],
Cell[4215, 149, 364, 5, 44, "Message"],
Cell[4582, 156, 71, 1, 49, "Output"]
}, Open  ]],
Cell[4668, 160, 121, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[4814, 167, 107, 2, 53, "Input"],
Cell[4924, 171, 60, 1, 50, "Output"]
}, Open  ]],
Cell[4999, 175, 231, 7, 29, "Text"],

Cell[CellGroupData[{
Cell[5255, 186, 137, 2, 53, "Input"],
Cell[5395, 190, 121, 2, 52, "Output"]
}, Open  ]],
Cell[5531, 195, 98, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[5654, 201, 140, 3, 50, "Input"],
Cell[5797, 206, 362, 5, 44, "Message"],
Cell[6162, 213, 119, 2, 49, "Output"]
}, Open  ]],
Cell[6296, 218, 433, 10, 124, "Text"],

Cell[CellGroupData[{
Cell[6754, 232, 1156, 20, 361, "Input"],
Cell[7913, 254, 372806, 10650, 399, 105924, 7352, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[380734, 10907, 76, 1, 50, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

