(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    274361,       5916]*)
(*NotebookOutlinePosition[    275061,       5940]*)
(*  CellTagsIndexPosition[    275017,       5936]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Log Plots", "Title"],

Cell[BoxData[{
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<Graphics`Graphics`\>"]\)}], "Input"],

Cell["\<\
The Graphics`Graphics` package contains routines for making log plots, namely \
LogPlot, LogLinearPlot and LogLogPlot. However, these routines do not always \
work well. Especially troublesome is that LogLinearPlot and LogLogPlot do not \
sample points correctly and thus often make incorrect plots. The Ticks \
specification, LogScale, from the Graphics`Graphics` package is often useful.\
\
\>", "Text"],

Cell["\<\
It will usually be far easier to construct your own log plots. Below, two \
functions are given, which aid in this. You can either use LogScale to label \
the axes and frames, or you can use the CustomTicks routine for more precise \
control.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Routines for log plot conversions", "Subsection"],

Cell[BoxData[{
    \(\(logstep[f_]\)[z_] := f[10\^z]\), "\[IndentingNewLine]", 
    \(logvalue[expr_] := Log[10, expr]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Making your own LogPlot", "Subsection",
  ShowGroupOpenCloseIcon->True],

Cell[BoxData[
    \(f[x_] := \(x!\)\)], "Input"],

Cell["\<\
This draws the function on a log scale. We can obtain a log scale grid by \
using a construction put forward by Tom Burton on MathGroup.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Draw[
            logvalue[f[x]], {x, 0, 8}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameTicks \[Rule] {Automatic, LogScale, 
            Automatic, 
            None}, \[IndentingNewLine]GridLines \[Rule] {Automatic, 
            First /@ 
                LogScale[##] &}, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            f}, \[IndentingNewLine]PlotLabel \[Rule] 
          SequenceForm[HoldForm[f[x]], "\< \[Equal] \>", 
            f[x]], \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 500];\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(logvalue[\\(\\(f[x]\
\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(3.333333333333333`*^-7\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(logvalue[\\(\\(f[x]\
\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(0.3245359325833263`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(logvalue[\\(\\(f[x]\
\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(0.6784703988749894`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Plot :: \\\"plnr\\\"\\) will be suppressed during this calculation. \\!\
\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21.75 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .01472 -10 -6.375 ]
[-0.0125 .01472 0 6.375 ]
[-0.0125 .11836 -22 -6.375 ]
[-0.0125 .11836 0 6.375 ]
[-0.0125 .1919 -10 -6.375 ]
[-0.0125 .1919 0 6.375 ]
[-0.0125 .29555 -10 -6.375 ]
[-0.0125 .29555 0 6.375 ]
[-0.0125 .42613 -10 -6.375 ]
[-0.0125 .42613 0 6.375 ]
[-0.0125 .51214 -10 -6.375 ]
[-0.0125 .51214 0 6.375 ]
[-0.0125 .60332 -16 -6.375 ]
[-0.0125 .60332 0 6.375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.75 -5 ]
[-0.01875 .30902 -22 5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -36 0 ]
[.5 .63053 36 12.75 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.78571 0 m
.78571 .61803 L
s
0 .01472 m
1 .01472 L
s
0 .11836 m
1 .11836 L
s
0 .1919 m
1 .1919 L
s
0 .29555 m
1 .29555 L
s
0 .42613 m
1 .42613 L
s
0 .51214 m
1 .51214 L
s
0 .60332 m
1 .60332 L
s
0 .03908 m
1 .03908 L
s
0 .06132 m
1 .06132 L
s
0 .08178 m
1 .08178 L
s
0 .10073 m
1 .10073 L
s
0 .13486 m
1 .13486 L
s
0 .15036 m
1 .15036 L
s
0 .16497 m
1 .16497 L
s
0 .17879 m
1 .17879 L
s
0 .36909 m
1 .36909 L
s
0 .47274 m
1 .47274 L
s
0 .54628 m
1 .54628 L
s
0 .57639 m
1 .57639 L
s
0 0 0 r
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11836 m
.00625 .11836 L
s
gsave
-0.0125 .11836 -83 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .1919 m
.00625 .1919 L
s
gsave
-0.0125 .1919 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .29555 m
.00625 .29555 L
s
gsave
-0.0125 .29555 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .42613 m
.00625 .42613 L
s
gsave
-0.0125 .42613 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .51214 m
.00625 .51214 L
s
gsave
-0.0125 .51214 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -77 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .03908 m
.00375 .03908 L
s
0 .06132 m
.00375 .06132 L
s
0 .08178 m
.00375 .08178 L
s
0 .10073 m
.00375 .10073 L
s
0 .13486 m
.00375 .13486 L
s
0 .15036 m
.00375 .15036 L
s
0 .16497 m
.00375 .16497 L
s
0 .17879 m
.00375 .17879 L
s
0 .36909 m
.00375 .36909 L
s
0 .47274 m
.00375 .47274 L
s
0 .54628 m
.00375 .54628 L
s
0 .57639 m
.00375 .57639 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -94.375 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.375 translate
90 rotate
-66 -10.375 translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -97 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(D) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
87.000 13.000 moveto
0.000 0.000 rmoveto
93.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\212) show
107.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.000 13.000 moveto
0.000 0.000 rmoveto
107.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
113.000 13.000 moveto
(@) show
119.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.000 13.000 moveto
(D) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`iP`0n_3V0P0000000`3jl>H000000000003S0?[`iP40oooo003o0?[`
iPd0n_3V00<000000?[`iP000000i03jl>H10?ooo`00o`3jl>H>0?[`iP030000003jl>H0n_3V0><0
n_3V0@3oool00?l0n_3V303jl>H2000000030?[`iP00000000000><0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo00130?[`iP800000B@3jl>H2000000@0n_3V0P0000030?[`iP@00000@P3j
l>H2000000@0n_3V0P0000050?[`iP<00000@@3jl>H2000000@0n_3V0P0000030?[`iP<00000@`3j
l>H2000000@0n_3V0P0000040?[`iP800000B03jl>H5000001L0n_3V0@3oool00480n_3V00@00000
0?[`iP3jl>H00000A`3jl>H010000000n_3V0?[`iP0000080?[`iP030000003jl>H0n_3V0480n_3V
00@000000?[`iP3jl>H000002`3jl>H00`000000n_3V0?[`iP0o0?[`iP040000003jl>H0n_3V0000
00P0n_3V00@000000?[`iP3jl>H00000@@3jl>H010000000n_3V0?[`iP0000080?[`iP040000003j
l>H0n_3V000004T0n_3V00<000000?[`iP3jl>H05`3jl>H10?ooo`00@P3jl>H010000000n_3V0?[`
iP0000170?[`iP040000003jl>H0n_3V000000T0n_3V00<000000?[`iP3jl>H0@@3jl>H010000000
n_3V0?[`iP0000080?[`iPD00000@03jl>H010000000n_3V0?[`iP0000080?[`iP040000003jl>H0
n_3V00000440n_3V00@000000?[`iP3jl>H00000203jl>H010000000n_3V0?[`iP0000190?[`iP03
0000003jl>H0n_3V01L0n_3V0@3oool00480n_3V00@000000?[`iP3jl>H00000A`3jl>H010000000
n_3V0?[`iP00000:0?[`iP030000003jl>H0n_3V0400n_3V00@000000?[`iP3jl>H00000203jl>H0
10000000n_3V0?[`iP0000110?[`iP040000003jl>H0n_3V000000P0n_3V0`0000120?[`iP040000
003jl>H0n_3V000000T0n_3V0P00001:0?[`iP030000003jl>H0n_3V01L0n_3V0@3oool00480n_3V
00@000000?[`iP3jl>H00000A`3jl>H010000000n_3V0?[`iP0000080?[`iP040000003jl>H0n_3V
00000440n_3V00@000000?[`iP3jl>H000002@3jl>H00`000000n_3V000000110?[`iP040000003j
l>H0n_3V000000T0n_3V00<000000?[`iP3jl>H0@@3jl>H010000000n_3V0?[`iP0000080?[`iP04
0000003jl>H0n_3V000004T0n_3V00<000000?[`iP3jl>H05`3jl>H10?ooo`00@`3jl>H2000004T0
n_3V0P00000:0?[`iP800000@`3jl>H2000000/0n_3V0P0000120?[`iP8000002P3jl>H300000480
n_3V0P00000:0?[`iP800000B@3jl>H2000001T0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo000j0?[`
i_l00000Z`00000?0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H04P3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H04P3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V04h0n_3V
00<000000?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04h0n_3V
00<000000?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V
0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003j
l>H0n_3V00d0n_3V0@3oool002d0n_3V1@0000080?[`iP030000003jl>H0n_3V05P0n_3V00<0001o
0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o
0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000_0?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V
04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V
00d0n_3V0@3oool002l0n_3V00<000000?[`iP3jl>H0203jl>H300000?l0001oY`0007l00`000000
n_3V0?[`iP0=0?[`iP40oooo000_0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0
F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool002l0n_3V00<0
00000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<0
00000?[`iP3jl>H03@3jl>H10?ooo`00;P3jl>H2000000X0n_3V00<000000?[`iP3jl>H0F03jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`
iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0
n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0
n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000
003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`
iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0
n_3V0P00003o0000OjP0001o00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V
0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V
0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3j
l>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3j
l>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3j
l>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o
0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<00000
0?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V
04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V
05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP03
0000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP03
0000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V
0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V
0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3j
l>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3j
l>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3j
l>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o
0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<00000
0?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V
04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V
05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H200000?l0001oZ00007l00`000000
n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0
n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0
n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`
iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`
iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`
iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0
n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000
n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP800000o`0007nX
0000O`030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`00
07l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`00
07l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3j
l>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3j
l>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V
00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V
00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V
0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003j
l>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>
0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H
0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`00
07l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`00
07l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3j
l>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3j
l>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V
0P00003o0000OjP0001o00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`008@3jl>H500000080n_3V0P00
00040?[`iP8000002P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<0
00000?[`iP3jl>H03@3jl>H10?ooo`008`3jl>H00`000000n_3V0?[`iP070?[`iP040000003jl>H0
n_3V000000T0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003j
l>H0n_3V00d0n_3V0@3oool002<0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP07
0?[`iP<00000o`0007nW0000O`030000003jl>H0n_3V00d0n_3V0@3oool002<0n_3V00<000000?[`
iP3jl>H0203jl>H2000000X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`
iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`
iP030000003jl>H0n_3V00d0n_3V0@3oool002<0n_3V00<000000?[`iP3jl>H0203jl>H00`000000
n_3V0?[`iP090?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0
n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000
n_3V0?[`iP0=0?[`iP40oooo000R0?[`iP8000002P3jl>H3000000T0n_3V00<000000?[`iP3jl>H0
F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<0
00000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3o
ool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0
n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0
n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`
iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`
iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V0P00003o0000OjP0001o00<000000?[`iP3j
l>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V
00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V
00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H
0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>
0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`00
0000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`00
07l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?oo
o`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3j
l>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3j
l>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V
00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V
00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H200000?l0001oZ00007l00`000000n_3V0?[`
iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H0
0`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000
003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo
000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`
iP0=0?[`iP40oooo000j0?[`iP800000o`0007nX0000O`030000003jl>H0n_3V00d0n_3V0@3oool0
03X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V
04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V
00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP03
0000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP03
0000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V
0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V
0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03j
l>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3j
l>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<00000
0?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o
0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool0
03X0n_3V0P00003o0000OjP0001o00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000
n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0
n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00
>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H0
3@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<0
00000?[`iP3jl>H03@3jl>H10?ooo`00;@3jl>H4000000T0n_3V00<000000?[`iP3jl>H0F03jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool002d0n_3V00<000000?[`
iP3jl>H02P3jl>H300000?l0001oY`0007l00`000000n_3V0?[`iP0=0?[`iP40oooo000^0?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP03
0000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP03
0000003jl>H0n_3V00d0n_3V0@3oool002l0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V
0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V
0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00;@3j
l>H010000000n_3V0?[`iP0000090?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000^0?[`iP8000002P3jl>H00`000000n_3V0?[`
iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00;P3jl>H2000000X0n_3V00<000000?[`iP3jl>H0
F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool002d0n_3V00@0
00000?[`iP3jl>H000002@3jl>H300000?l0001oY`0007l00`000000n_3V0?[`iP0=0?[`iP40oooo
000_0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool00300n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00;@3jl>H010000000n_3V0?[`iP0000090?[`iP030000003jl>H0n_3V05P0n_3V00<0001o
0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o
0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000^0?[`iP8000002P3jl>H00`00
0000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`00
07l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?oo
o`00503jl>H010000000n_3V0?[`iP00000R0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000C0?[`iPD000008P3jl>H00`000000
n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0
n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00
4P3jl>H00`000000n_3V000000020?[`iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0
F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool00180n_3V00<0
00000?[`iP0000000P3jl>H00`000000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V05P0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0
n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0
n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`
iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`
iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`
iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0
n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000
n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0
n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0
n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`
iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`
iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`
iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0
n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000
n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0
n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0
n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`
iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`
iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`
iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0
n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000
n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0
n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0
n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`
iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`
iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`
iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0
n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000
n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0
n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0
n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`
iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`
iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`
iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0
n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000
n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP800000o`0007nX0000O`030000003jl>H0n_3V00d0n_3V
0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003j
l>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>
0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H
0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`00
07l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`00
07l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3j
l>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3j
l>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V
00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V
00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V
0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003j
l>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>
0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H
0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`00
07l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`00
07l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3j
l>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3j
l>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V
00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V
00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V
0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003j
l>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>
0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H
0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`00
07l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`00
07l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3j
l>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3j
l>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V
00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V
00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V
0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003j
l>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>
0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H
0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`00
07l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`00
07l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3j
l>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3j
l>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V
00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V
00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V
0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003j
l>H0n_3V00d0n_3V0@3oool002h0n_3V0P00000:0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o
0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o
0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000]0?[`iP040000003jl>H0n_3V
000000T0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0
n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0
n_3V00d0n_3V0@3oool00300n_3V00<000000?[`iP3jl>H01`3jl>H300000?l0001oY`0007l00`00
0000n_3V0?[`iP0=0?[`iP40oooo000^0?[`iP8000002P3jl>H00`000000n_3V0?[`iP1H0?[`iP03
0000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP03
0000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00;P3jl>H00`000000n_3V
0?[`iP090?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V
0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V
0?[`iP0=0?[`iP40oooo000^0?[`iP<000002@3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H
0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>
0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`00
0000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`00
07l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?oo
o`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3j
l>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3j
l>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V
00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V
00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H
0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>
0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`00
0000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`00
07l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?oo
o`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3j
l>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3j
l>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V
00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V
00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H
0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>
0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`00
0000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`00
07l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?oo
o`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3j
l>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3j
l>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V
00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V
00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H
0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>
0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H20000
0?l0001oZ00007l00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000
003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo
000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`
iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H0
0`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000
003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo
000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`
iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H0
0`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000
003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo
000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`
iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H0
0`000000n_3V0?[`iP0=0?[`iP40oooo000_0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`
iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool002l0
n_3V00<000000?[`iP3jl>H0203jl>H300000?l0001oY`0007l00`000000n_3V0?[`iP0=0?[`iP40
oooo000_0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V
0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V
0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool00300n_3V00<000000?[`iP3jl>H01`3j
l>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3j
l>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3j
l>H10?ooo`00;@3jl>H010000000n_3V0?[`iP0000090?[`iP030000003jl>H0n_3V05P0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000]0?[`iP@000002@3jl>H0
0`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`
iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0
n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000
O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000
O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`
iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H0
0`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H200000?l0001oZ00007l00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP03
0000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP03
0000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40
oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V
0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V
0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3j
l>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03j
l>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o
0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o
0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V
05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V
04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP03
0000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP03
0000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40
oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V
0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V
0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3j
l>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03j
l>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o
0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o
0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V
05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V
04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP03
0000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP03
0000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40
oooo000j0?[`iP030000003jl>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V
0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V
0?[`iP0=0?[`iP40oooo000j0?[`iP800000o`0007nX0000O`030000003jl>H0n_3V00d0n_3V0@3o
ool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0
n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0
n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`
iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`
iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0
n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0
n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0
F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<0
00000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3o
ool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0
n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0
n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0n_3V0?[`iP1>0?[`
iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1H0?[`
iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0F03jl>H00`0007l0
n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0
n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0
F03jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0
CP3jl>H00`0007l0n_3V0?[`iP1H0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool002L0n_3V1@00
00020?[`iP8000002P3jl>H00`000000n_3V0?[`iP1H0?[`iP030000O`3jl>H0n_3V04h0n_3V00<0
001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3jl>H0n_3V05P0n_3V00<0
00000?[`iP3jl>H03@3jl>H10?ooo`00:@3jl>H01@000000n_3V0?[`iP3jl>H000000080n_3V00<0
00000?[`iP3jl>H01`3jl>H300000?l0001oY`0007l00`000000n_3V0?[`iP0=0?[`iP40oooo000Y
0?[`iP050000003jl>H0n_3V0?[`iP0000000P3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000Y
0?[`iP050000003jl>H0n_3V0?[`iP0000000P3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000Y
0?[`iP050000003jl>H0n_3V0?[`iP0000000P3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0n_3V05P0n_3V00<0001o0?[`iP3jl>H0CP3jl>H00`0007l0n_3V0?[`iP1>0?[`iP030000O`3j
l>H0n_3V04h0n_3V00<0001o0?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000X
0?[`iP800000103jl>H2000000X0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP1>
0?[`iP030000003jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>
0?[`iP030000003jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=
0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04@3jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H04@3jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04P3jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04@3jl>H00`00
0000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04@3jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H04@3jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04P3jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?oo
o`00>P3jl>Ko00000:/000003`3jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3V
m03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003e0?[`iP800000203jl>H200000200n_3V0P000008
0?[`iP800000aP3jl>H10?ooo`00m@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
01h0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP340?[`iP40oooo003]0?[`iP@0
0000103jl>H00`000000n_3V0?[`iP02000000030?[`iP000000000000<0n_3V00<000000?[`iP3j
l>H0203jl>H6000000P0n_3V100000040?[`iP030000003jl>H0n_3V0080000000<0n_3V00000000
00000`3jl>H00`000000n_3V0?[`iP340?[`iP40oooo003^0?[`iP030000003jl>H0n_3V00@0n_3V
00L000000?[`iP3jl>H0n_3V0000003jl>H0000000@0n_3V00<000000?[`iP3jl>H05`3jl>H00`00
0000n_3V0?[`iP040?[`iP070000003jl>H0n_3V0?[`iP000000n_3V000000040?[`iP030000003j
l>H0n_3V0<@0n_3V0@3oool00>h0n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP02
0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0203jl>H6000000T0n_3V00<00000
0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00<0n_3V00<00000
0?[`iP3jl>H0a03jl>H10?ooo`00k@3jl>H4000000@0n_3V00<000000?[`iP3jl>H00P0000000`3j
l>H00000000000030?[`iP030000003jl>H0n_3V01H0n_3V100000040?[`iP030000003jl>H0n_3V
0080000000<0n_3V0000000000000`3jl>H00`000000n_3V0?[`iP340?[`iP40oooo003^0?[`iP03
0000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0G0?[`iP03
0000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP340?[`iP40
oooo003_0?[`iP800000103jl>H2000000P0n_3V0P00000J0?[`iP800000103jl>H2000000P0n_3V
0P0000360?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-0.168523, -0.133121, 0.0024687, \
0.00399443}}]
}, Open  ]],

Cell["\<\
We can control the grid line style by this further construction.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Draw[
            logvalue[f[x]], {x, 0, 8}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameTicks \[Rule] {Automatic, LogScale, 
            Automatic, 
            None}, \[IndentingNewLine]GridLines \[Rule] {\({First[#], \
{LightBlue}} &\) /@ LinearScale[##] &, \({First[#], {LightBlue}} &\) /@ 
                LogScale[##] &}, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            f}, \[IndentingNewLine]PlotLabel \[Rule] 
          SequenceForm[HoldForm[f[x]], "\< \[Equal] \>", 
            f[x]], \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 500];\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(logvalue[\\(\\(f[x]\
\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(3.333333333333333`*^-7\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(logvalue[\\(\\(f[x]\
\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(0.3245359325833263`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(logvalue[\\(\\(f[x]\
\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(0.6784703988749894`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Plot :: \\\"plnr\\\"\\) will be suppressed during this calculation. \\!\
\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21.75 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .01472 -10 -6.375 ]
[-0.0125 .01472 0 6.375 ]
[-0.0125 .11836 -22 -6.375 ]
[-0.0125 .11836 0 6.375 ]
[-0.0125 .1919 -10 -6.375 ]
[-0.0125 .1919 0 6.375 ]
[-0.0125 .29555 -10 -6.375 ]
[-0.0125 .29555 0 6.375 ]
[-0.0125 .42613 -10 -6.375 ]
[-0.0125 .42613 0 6.375 ]
[-0.0125 .51214 -10 -6.375 ]
[-0.0125 .51214 0 6.375 ]
[-0.0125 .60332 -16 -6.375 ]
[-0.0125 .60332 0 6.375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.75 -5 ]
[-0.01875 .30902 -22 5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -36 0 ]
[.5 .63053 36 12.75 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.678 .847 .902 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.21429 0 m
.21429 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.78571 0 m
.78571 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 .01472 m
1 .01472 L
s
0 .11836 m
1 .11836 L
s
0 .1919 m
1 .1919 L
s
0 .29555 m
1 .29555 L
s
0 .42613 m
1 .42613 L
s
0 .51214 m
1 .51214 L
s
0 .60332 m
1 .60332 L
s
0 .03908 m
1 .03908 L
s
0 .06132 m
1 .06132 L
s
0 .08178 m
1 .08178 L
s
0 .10073 m
1 .10073 L
s
0 .13486 m
1 .13486 L
s
0 .15036 m
1 .15036 L
s
0 .16497 m
1 .16497 L
s
0 .17879 m
1 .17879 L
s
0 .36909 m
1 .36909 L
s
0 .47274 m
1 .47274 L
s
0 .54628 m
1 .54628 L
s
0 .57639 m
1 .57639 L
s
0 0 0 r
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11836 m
.00625 .11836 L
s
gsave
-0.0125 .11836 -83 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .1919 m
.00625 .1919 L
s
gsave
-0.0125 .1919 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .29555 m
.00625 .29555 L
s
gsave
-0.0125 .29555 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .42613 m
.00625 .42613 L
s
gsave
-0.0125 .42613 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .51214 m
.00625 .51214 L
s
gsave
-0.0125 .51214 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -77 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .03908 m
.00375 .03908 L
s
0 .06132 m
.00375 .06132 L
s
0 .08178 m
.00375 .08178 L
s
0 .10073 m
.00375 .10073 L
s
0 .13486 m
.00375 .13486 L
s
0 .15036 m
.00375 .15036 L
s
0 .16497 m
.00375 .16497 L
s
0 .17879 m
.00375 .17879 L
s
0 .36909 m
.00375 .36909 L
s
0 .47274 m
.00375 .47274 L
s
0 .54628 m
.00375 .54628 L
s
0 .57639 m
.00375 .57639 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -94.375 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.375 translate
90 rotate
-66 -10.375 translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -97 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(D) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
87.000 13.000 moveto
0.000 0.000 rmoveto
93.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\212) show
107.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.000 13.000 moveto
0.000 0.000 rmoveto
107.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
113.000 13.000 moveto
(@) show
119.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.000 13.000 moveto
(D) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`iP`0n_3V0P0000000`3jl>H000000000003S0?[`iP40oooo003o0?[`
iPd0n_3V00<000000?[`iP000000i03jl>H10?ooo`00o`3jl>H>0?[`iP030000003jl>H0n_3V0><0
n_3V0@3oool00?l0n_3V303jl>H2000000030?[`iP00000000000><0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo00130?[`iP800000B@3jl>H2000000@0n_3V0P0000030?[`iP@00000@P3j
l>H2000000@0n_3V0P0000050?[`iP<00000@@3jl>H2000000@0n_3V0P0000030?[`iP<00000@`3j
l>H2000000@0n_3V0P0000040?[`iP800000B03jl>H5000001L0n_3V0@3oool00480n_3V00@00000
0?[`iP3jl>H00000A`3jl>H010000000n_3V0?[`iP0000080?[`iP030000003jl>H0n_3V0480n_3V
00@000000?[`iP3jl>H000002`3jl>H00`000000n_3V0?[`iP0o0?[`iP040000003jl>H0n_3V0000
00P0n_3V00@000000?[`iP3jl>H00000@@3jl>H010000000n_3V0?[`iP0000080?[`iP040000003j
l>H0n_3V000004T0n_3V00<000000?[`iP3jl>H05`3jl>H10?ooo`00@P3jl>H010000000n_3V0?[`
iP0000170?[`iP040000003jl>H0n_3V000000T0n_3V00<000000?[`iP3jl>H0@@3jl>H010000000
n_3V0?[`iP0000080?[`iPD00000@03jl>H010000000n_3V0?[`iP0000080?[`iP040000003jl>H0
n_3V00000440n_3V00@000000?[`iP3jl>H00000203jl>H010000000n_3V0?[`iP0000190?[`iP03
0000003jl>H0n_3V01L0n_3V0@3oool00480n_3V00@000000?[`iP3jl>H00000A`3jl>H010000000
n_3V0?[`iP00000:0?[`iP030000003jl>H0n_3V0400n_3V00@000000?[`iP3jl>H00000203jl>H0
10000000n_3V0?[`iP0000110?[`iP040000003jl>H0n_3V000000P0n_3V0`0000120?[`iP040000
003jl>H0n_3V000000T0n_3V0P00001:0?[`iP030000003jl>H0n_3V01L0n_3V0@3oool00480n_3V
00@000000?[`iP3jl>H00000A`3jl>H010000000n_3V0?[`iP0000080?[`iP040000003jl>H0n_3V
00000440n_3V00@000000?[`iP3jl>H000002@3jl>H00`000000n_3V000000110?[`iP040000003j
l>H0n_3V000000T0n_3V00<000000?[`iP3jl>H0@@3jl>H010000000n_3V0?[`iP0000080?[`iP04
0000003jl>H0n_3V000004T0n_3V00<000000?[`iP3jl>H05`3jl>H10?ooo`00@`3jl>H2000004T0
n_3V0P00000:0?[`iP800000@`3jl>H2000000/0n_3V0P0000120?[`iP8000002P3jl>H300000480
n_3V0P00000:0?[`iP800000B@3jl>H2000001T0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo000j0?[`
i_l00000Z`00000?0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H04P3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H04P3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V04h0n_3V
00<000000?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04h0n_3V
00<000000?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V
0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000]
0?[`iPD00000203jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool0
02l0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V
04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V
04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V
00d0n_3V0@3oool002l0n_3V00<000000?[`iP3jl>H0203jl>H300000?l0[MSVY`2]f>H00`000000
n_3V0?[`iP0=0?[`iP40oooo000_0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
1`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000_0?[`iP030000003jl>H0n_3V00P0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000^0?[`iP8000002P3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000
003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0
n_3V0P00003o0:gHiZP0[MSV00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3j
l>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3j
l>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3j
l>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV
0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<00000
0?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V
04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V
04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V
00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP03
0:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP03
0:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40
oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3j
l>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3j
l>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3j
l>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V
00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V
04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V
00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H200000?l0[MSVZ02]f>H00`000000
n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0
3@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3o
ool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`
iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000
n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
1`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H200000?l0[MSVZ02]f>H00`000000n_3V0?[`iP0=
0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?oo
o`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V
00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP07
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`00
0000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H03@3jl>H10?ooo`00>P3jl>H200000?l0[MSVZ02]f>H00`000000n_3V0?[`iP0=0?[`iP40oooo
000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000
003jl>H0n_3V00d0n_3V0@3oool00240n_3V1@0000020?[`iP800000103jl>H2000000X0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000S0?[`iP030000003jl>H0
n_3V00L0n_3V00@000000?[`iP3jl>H000002@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00d0n_3V0@3oool002<0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP07
0?[`iP<00000o`2]f>JW0:gHiP030000003jl>H0n_3V00d0n_3V0@3oool002<0n_3V00<000000?[`
iP3jl>H0203jl>H2000000X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`
iP40oooo000S0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000
n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool00280n_3V0P00000:0?[`iP<00000
2@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0
n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`
iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V0P00003o0:gHiZP0[MSV00<000000?[`iP3j
l>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V
0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j
0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`00
0000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3j
l>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H200000?l0[MSVZ02]f>H00`000000n_3V0?[`
iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000
003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V0P00003o0:gHiZP0[MSV00<00000
0?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V
04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V
04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V
00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP03
0:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP03
0:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40
oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3j
l>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3j
l>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3j
l>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP800000o`2]f>JX0:gH
iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000
n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0
3@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3o
ool002d0n_3V100000090?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00;@3jl>H00`000000n_3V0?[`iP0:0?[`iP<00000o`2]f>JW0:gHiP030000003jl>H0n_3V
00d0n_3V0@3oool002h0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP070?[`iP03
0:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP03
0:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP03
0000003jl>H0n_3V00d0n_3V0@3oool002l0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool002d0n_3V00@000000?[`iP3jl>H00000
2@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool002h0n_3V0P00
000:0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000
003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000
003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0
n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo
000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000
003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000
003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0
n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo
000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000
003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000^0?[`iP800000
2P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool002d0n_3V00@0
00000?[`iP3jl>H000002@3jl>H300000?l0[MSVY`2]f>H00`000000n_3V0?[`iP0=0?[`iP40oooo
000_0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP0=0?[`iP40oooo000`0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP0=0?[`iP40oooo000]0?[`iP040000003jl>H0n_3V000000T0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000^0?[`iP8000002P3jl>H00`00
0000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool001@0n_3V00@000000?[`iP3j
l>H000008P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool001<0
n_3V1@00000R0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00
4P3jl>H00`000000n_3V000000020?[`iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
1`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000B0?[`iP030000003jl>H000000080n_3V00<0
00000?[`iP3jl>H0803jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3o
ool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`
iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000
n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
1`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0
n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`
iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00
>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0
n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`
iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000
n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0
3@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3o
ool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`
iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000
n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
1`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0
n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`
iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00
>P3jl>H200000?l0[MSVZ02]f>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP07
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`00
0000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V
0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j
0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`00
0000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3j
l>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=
0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?oo
o`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V
00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP07
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`00
0000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V
0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000^
0?[`iP8000002P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool0
02d0n_3V00@000000?[`iP3jl>H000002@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0
n_3V00d0n_3V0@3oool00300n_3V00<000000?[`iP3jl>H01`3jl>H300000?l0[MSVY`2]f>H00`00
0000n_3V0?[`iP0=0?[`iP40oooo000^0?[`iP8000002P3jl>H00`000000n_3V0?[`iP070?[`iP03
0:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP03
0:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP03
0000003jl>H0n_3V00d0n_3V0@3oool002h0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool002h0n_3V0`0000090?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP07
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`00
0000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V
0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j
0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`00
0000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3j
l>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=
0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]
f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?oo
o`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3j
l>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V
00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V
00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP07
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>
0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V0P00003o0:gHiZP0[MSV00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0
n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo
000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000
003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000
003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP0=0?[`iP40oooo000_0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000_0?[`iP030000003jl>H0n_3V00P0
n_3V0`00003o0:gHiZL0[MSV00<000000?[`iP3jl>H03@3jl>H10?ooo`00;`3jl>H00`000000n_3V
0?[`iP080?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00<03j
l>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3j
l>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3j
l>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3j
l>H10?ooo`00;@3jl>H010000000n_3V0?[`iP0000090?[`iP030000003jl>H0n_3V00L0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H03@3jl>H10?ooo`00;@3jl>H4000000T0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`
iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0
n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo
000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`
iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0
n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0
n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gH
iP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000
003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`
iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H0
0`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H1
0?ooo`00>P3jl>H200000?l0[MSVZ02]f>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP03
0000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP03
0:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP03
0:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3j
l>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3j
l>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3j
l>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV
0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<00000
0?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V
04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V
04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V
00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP03
0:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP03
0:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40
oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3j
l>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3j
l>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3j
l>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV
0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V
00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V
04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V
00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP03
0:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP03
0:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP03
0000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V
0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V
0?[`iP0=0?[`iP40oooo000j0?[`iP800000o`2]f>JX0:gHiP030000003jl>H0n_3V00d0n_3V0@3o
ool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`
iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000
n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
1`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0
n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0
n_3V00d0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`
iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`
iP40oooo000j0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0
n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00
>P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0
CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool002L0n_3V1@00
00020?[`iP8000002P3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3jl>H0n_3V04h0n_3V00<0
[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3o
ool002T0n_3V00D000000?[`iP3jl>H0n_3V000000020?[`iP030000003jl>H0n_3V00L0n_3V0`00
003o0:gHiZL0[MSV00<000000?[`iP3jl>H03@3jl>H10?ooo`00:@3jl>H01@000000n_3V0?[`iP3j
l>H000000080n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00d0n_3V0@3oool002T0n_3V00D000000?[`iP3jl>H0n_3V000000020?[`iP030000003j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000Y
0?[`iP050000003jl>H0n_3V0?[`iP0000000P3jl>H00`000000n_3V0?[`iP070?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V04h0n_3V00<0[MSV0?[`iP3jl>H0CP3jl>H00`2]f>H0n_3V0?[`iP1>0?[`iP030:gHiP3j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00:03jl>H2000000@0n_3V0P00000:
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>
0?[`iP030000003jl>H0n_3V04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>
0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00>P3jl>H00`00
0000n_3V0?[`iP070?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04@3jl>H00`00
0000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04@3jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H04@3jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04P3jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04@3jl>H00`00
0000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04@3jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H04@3jl>H00`00
0000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00d0n_3V0@3oool003X0n_3Vo`00002[000000l0
n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00m@3jl>H2000000P0n_3V0P00000P0?[`iP800000203jl>H200000<H0n_3V0@3oool0
0?D0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V
00P0n_3V00<000000?[`iP3jl>H0a03jl>H10?ooo`00k@3jl>H4000000@0n_3V00<000000?[`iP3j
l>H00P0000000`3jl>H00000000000030?[`iP030000003jl>H0n_3V00P0n_3V1P0000080?[`iP@0
0000103jl>H00`000000n_3V0?[`iP02000000030?[`iP000000000000<0n_3V00<000000?[`iP3j
l>H0a03jl>H10?ooo`00kP3jl>H00`000000n_3V0?[`iP040?[`iP070000003jl>H0n_3V0?[`iP00
0000n_3V000000040?[`iP030000003jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H0103jl>H01`00
0000n_3V0?[`iP3jl>H000000?[`iP000000103jl>H00`000000n_3V0?[`iP340?[`iP40oooo003^
0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP03
0?[`iP030000003jl>H0n_3V00P0n_3V1P0000090?[`iP030000003jl>H0n_3V00@0n_3V00<00000
0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0<@0n_3V0@3oool0
0>d0n_3V100000040?[`iP030000003jl>H0n_3V0080000000<0n_3V0000000000000`3jl>H00`00
0000n_3V0?[`iP0F0?[`iP@00000103jl>H00`000000n_3V0?[`iP02000000030?[`iP0000000000
00<0n_3V00<000000?[`iP3jl>H0a03jl>H10?ooo`00kP3jl>H00`000000n_3V0?[`iP040?[`iP03
0000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP040?[`iP03
0000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0a03jl>H10?ooo`00k`3jl>H2000000@0n_3V
0P0000080?[`iP8000006P3jl>H2000000@0n_3V0P0000080?[`iP800000aP3jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-0.168523, -0.133121, 0.0024687, \
0.00399443}}]
}, Open  ]],

Cell["\<\
The only disadvantages in the above plot is that we can't obtain the proper \
tick marks on the right hand side frame. The following plot uses CustomTicks \
and CustomGridLines to make a nicer plot. We even obtain the promised \
LightBlue grid lines.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(yticks[format_] := 
        CustomTicks[logvalue, \ {0, 5, {1}, Range[2, 9]}, 
          CTNumberFunction \[RuleDelayed] 
            format];\)\), "\[IndentingNewLine]", 
    \(\(ygrids := 
        CustomGridLines[
          logvalue, {0, 5, Range[10]}];\)\), "\[IndentingNewLine]", 
    \(\(xgrids := 
        CustomGridLines[Identity, {0, 8, 1}];\)\), "\[IndentingNewLine]", 
    \(\(Draw2D[\[IndentingNewLine]{Draw[
            logvalue[f[x]], {x, 0, 8}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameTicks \[Rule] {Automatic, 
            yticks[Identity], Automatic, 
            yticks["\<\>" &]}, \[IndentingNewLine]GridLines \[Rule] {xgrids, 
            ygrids}, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            f}, \[IndentingNewLine]PlotLabel \[Rule] 
          SequenceForm[HoldForm[f[x]], "\< \[Equal] \>", 
            f[x]], \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 500];\)\)}], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(ygrids\\)\\\" is similar to existing symbol \
\\\"\\!\\(xgrids\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(logvalue[\\(\\(f[x]\
\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(3.333333333333333`*^-7\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(logvalue[\\(\\(f[x]\
\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(0.3245359325833263`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(logvalue[\\(\\(f[x]\
\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(0.6784703988749894`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Plot :: \\\"plnr\\\"\\) will be suppressed during this calculation. \\!\
\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21.75 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24.75 -5 ]
[-0.01875 .30902 -12 5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -36 0 ]
[.5 .63053 36 12.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.678 .847 .902 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 .01472 m
1 .01472 L
s
0 .1919 m
1 .1919 L
s
0 .29555 m
1 .29555 L
s
0 .36909 m
1 .36909 L
s
0 .42613 m
1 .42613 L
s
0 .47274 m
1 .47274 L
s
0 .51214 m
1 .51214 L
s
0 .54628 m
1 .54628 L
s
0 .57639 m
1 .57639 L
s
0 .60332 m
1 .60332 L
s
0 .60332 m
1 .60332 L
s
0 0 0 r
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
[(1)] -0.0125 .01472 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(10)] -0.0125 .60332 1 0 Mshowa
0 .1919 m
.00375 .1919 L
s
0 .29555 m
.00375 .29555 L
s
0 .36909 m
.00375 .36909 L
s
0 .42613 m
.00375 .42613 L
s
0 .47274 m
.00375 .47274 L
s
0 .51214 m
.00375 .51214 L
s
0 .54628 m
.00375 .54628 L
s
0 .57639 m
.00375 .57639 L
s
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -84.375 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.375 translate
90 rotate
-66 -10.375 translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .60332 m
1 .60332 L
s
.99625 .1919 m
1 .1919 L
s
.99625 .29555 m
1 .29555 L
s
.99625 .36909 m
1 .36909 L
s
.99625 .42613 m
1 .42613 L
s
.99625 .47274 m
1 .47274 L
s
.99625 .51214 m
1 .51214 L
s
.99625 .54628 m
1 .54628 L
s
.99625 .57639 m
1 .57639 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -97 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(D) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
87.000 13.000 moveto
0.000 0.000 rmoveto
93.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\212) show
107.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.000 13.000 moveto
0.000 0.000 rmoveto
107.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
113.000 13.000 moveto
(@) show
119.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.000 13.000 moveto
(D) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`iPL0n_3V0P0000000`3jl>H000000000003X0?[`iP40oooo003o0?[`
iPP0n_3V00<000000?[`iP000000j@3jl>H10?ooo`00o`3jl>H90?[`iP030000003jl>H0n_3V0>P0
n_3V0@3oool00?l0n_3V1`3jl>H2000000030?[`iP00000000000>P0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo000n0?[`iP800000B@3jl>H2000000@0n_3V0P0000030?[`iP@00000@P3j
l>H2000000@0n_3V0P0000050?[`iP<00000@@3jl>H2000000@0n_3V0P0000030?[`iP<00000@`3j
l>H2000000@0n_3V0P0000040?[`iP800000B03jl>H5000001`0n_3V0@3oool003d0n_3V00@00000
0?[`iP3jl>H00000A`3jl>H010000000n_3V0?[`iP0000080?[`iP030000003jl>H0n_3V0480n_3V
00@000000?[`iP3jl>H000002`3jl>H00`000000n_3V0?[`iP0o0?[`iP040000003jl>H0n_3V0000
00P0n_3V00@000000?[`iP3jl>H00000@@3jl>H010000000n_3V0?[`iP0000080?[`iP040000003j
l>H0n_3V000004T0n_3V00<000000?[`iP3jl>H0703jl>H10?ooo`00?@3jl>H010000000n_3V0?[`
iP0000170?[`iP040000003jl>H0n_3V000000T0n_3V00<000000?[`iP3jl>H0@@3jl>H010000000
n_3V0?[`iP0000080?[`iPD00000@03jl>H010000000n_3V0?[`iP0000080?[`iP040000003jl>H0
n_3V00000440n_3V00@000000?[`iP3jl>H00000203jl>H010000000n_3V0?[`iP0000190?[`iP03
0000003jl>H0n_3V01`0n_3V0@3oool003d0n_3V00@000000?[`iP3jl>H00000A`3jl>H010000000
n_3V0?[`iP00000:0?[`iP030000003jl>H0n_3V0400n_3V00@000000?[`iP3jl>H00000203jl>H0
10000000n_3V0?[`iP0000110?[`iP040000003jl>H0n_3V000000P0n_3V0`0000120?[`iP040000
003jl>H0n_3V000000T0n_3V0P00001:0?[`iP030000003jl>H0n_3V01`0n_3V0@3oool003d0n_3V
00@000000?[`iP3jl>H00000A`3jl>H010000000n_3V0?[`iP0000080?[`iP040000003jl>H0n_3V
00000440n_3V00@000000?[`iP3jl>H000002@3jl>H00`000000n_3V000000110?[`iP040000003j
l>H0n_3V000000T0n_3V00<000000?[`iP3jl>H0@@3jl>H010000000n_3V0?[`iP0000080?[`iP04
0000003jl>H0n_3V000004T0n_3V00<000000?[`iP3jl>H0703jl>H10?ooo`00?P3jl>H2000004T0
n_3V0P00000:0?[`iP800000@`3jl>H2000000/0n_3V0P0000120?[`iP8000002P3jl>H300000480
n_3V0P00000:0?[`iP800000B@3jl>H2000001h0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo000e0?[`
i_l00000Z`00000D0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H04P3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H04P3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V04h0n_3V
00<000000?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V04h0n_3V
00<000000?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V
0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0
[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000Z0?[`iPD000001P3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V0180n_3V0@3oool002`0n_3V00<000000?[`iP3jl>H01P3jl>H00`00
0000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`
iP030000003jl>H0n_3V0180n_3V0@3oool002`0n_3V00<000000?[`iP3jl>H01P3jl>H300000?l0
[MSVY02]f>H4000001@0n_3V0@3oool002`0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000
003jl>H0n_3V0180n_3V0@3oool002`0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003j
l>H0n_3V0180n_3V0@3oool002/0n_3V0P0000080?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV
0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H1
0?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]
f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3j
l>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000
n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0
o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3j
l>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`
iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B
0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`
iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000
n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP03
0000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V
0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo
000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP07
0?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0
n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`
iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP03
0000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0
n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V
0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0
[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0
n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<00000
0?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V
0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V
00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0
4P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3j
l>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`
iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?oo
o`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0
n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V
0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3j
l>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]
f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`
iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP03
0:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000
003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e
0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0
n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`
iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V
0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0
n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000
003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3j
l>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3o
ool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV
0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V
00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`
iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0
n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V
00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H0
1`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0
[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3j
l>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H0
0`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`00
0000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00
=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V
0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3j
l>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC
0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`00
0000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`
iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0
n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40
oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gH
iP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003j
l>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o
0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`
iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V
00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP03
0:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180
n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V
00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool0
03D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`
iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0
n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3V
T`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3j
l>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV
0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H1
0?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]
f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3j
l>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000
n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0
o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3j
l>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`
iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B
0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`
iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000
n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP03
0000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V
0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo
000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP07
0?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0
n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`
iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP80
0000o`2]f>JV0:gHiP<00000503jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V
0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0
[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0
n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<00000
0?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V
0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V
00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0
4P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3j
l>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`
iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?oo
o`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0
n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V
0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3j
l>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]
f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`
iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP03
0:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000
003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e
0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0
n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`
iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V
0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0
n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000
003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3j
l>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3o
ool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV
0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V
00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`
iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0
n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V
00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H0
1`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0
[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3j
l>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H0
0`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`00
0000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00
=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V
0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3j
l>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC
0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`00
0000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`
iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0
n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40
oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gH
iP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003j
l>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o
0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`
iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V
00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP03
0:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180
n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V
00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool0
03D0n_3V0P00003o0:gHiZH0[MSV0`00000D0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0
n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3j
l>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3V
T`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3j
l>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV
0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H1
0?ooo`006@3jl>H010000000n_3V0?[`iP00000H0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV
0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H1
0?ooo`00603jl>H5000001P0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`
iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000G0?[`iP03
0000003jl>H000000080n_3V00<000000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP070?[`iP03
0:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180
n_3V0@3oool001L0n_3V00<000000?[`iP0000000P3jl>H00`000000n_3V0?[`iP0F0?[`iP030000
003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3j
l>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3o
ool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV
0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V
00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`
iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0
n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V
00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H0
1`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0
[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3j
l>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H0
0`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`00
0000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00
=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V
0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3j
l>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC
0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`00
0000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`
iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0
n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40
oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gH
iP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003j
l>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o
0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`
iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V
00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP03
0:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180
n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V
00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool0
03D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`
iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP800000o`2]f>JV0:gHiP<0
0000503jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3V
T`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3j
l>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV
0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H1
0?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]
f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3j
l>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000
n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0
o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3j
l>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`
iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B
0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`
iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000
n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP03
0000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V
0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo
000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP07
0?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0
n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`
iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP03
0000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0
n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V
0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0
[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0
n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<00000
0?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V
0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V
00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0
4P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3j
l>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP800000o`2]f>JV0:gHiP<00000503jl>H10?oo
o`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0
n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V
0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3j
l>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP07
0?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]
f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`
iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP03
0:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000
003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e
0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0
n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`
iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V
0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0
n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000
003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3j
l>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3o
ool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV
0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V
00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`
iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0
n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V
00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H0
1`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0
[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3j
l>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H0
0`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V0P00003o0:gH
iZH0[MSV0`00000D0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00
=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V
0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3j
l>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC
0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`00
0000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`
iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0
n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40
oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gH
iP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003j
l>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o
0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`
iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V
00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP03
0:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180
n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V
00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool0
03D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`
iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP800000o`2]f>JV0:gHiP<0
0000503jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3V
T`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3j
l>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV
0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H1
0?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]
f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3j
l>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000
n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0
o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3j
l>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`
iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B
0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`
iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000
n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP03
0000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V
0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo
000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP07
0?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0
n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`
iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP80
0000o`2]f>JV0:gHiP<00000503jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V
0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0
[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0
n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<00000
0?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V
0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V
00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0
4P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3j
l>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`
iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?oo
o`00=@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0
n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V
0?[`iP0B0?[`iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3j
l>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H2
00000?l0[MSVYP2]f>H3000001@0n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]
f>H0n_3V0?[`iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`
iP40oooo000e0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP03
0:gHiP3jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000
003jl>H0n_3V0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP3o0?[`iY<0n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e
0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0
n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`iP070?[`
iP030:gHiP3jl>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V
0180n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iY<0
n_3V00<0[MSV0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP030000
003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H04P3jl>H10?ooo`00903jl>H500000080n_3V0P0000080?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H04P3jl>H10?ooo`009P3jl>H01@000000n_3V0?[`iP3jl>H000000080n_3V00<0
00000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VT`3j
l>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool002H0n_3V00D00000
0?[`iP3jl>H0n_3V000000020?[`iP030000003jl>H0n_3V00D0n_3V0`00003o0:gHiZ@0[MSV1000
000D0?[`iP40oooo000V0?[`iP050000003jl>H0n_3V0?[`iP0000000P3jl>H00`000000n_3V0?[`
iP050?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>JC0?[`iP030:gHiP3j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`009P3jl>H01@000000n_3V0?[`iP3j
l>H000000080n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3j
l>H0n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3o
ool002D0n_3V0P0000040?[`iP800000203jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V0?l0n_3VT`3jl>H00`2]f>H0n_3V0?[`iP070?[`iP030000003jl>H0n_3V0180n_3V0@3oool0
03D0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V
04h0n_3V00<000000?[`iP3jl>H0CP3jl>H00`000000n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V
04h0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0B0?[`iP40oooo000e0?[`iP03
0000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP03
0000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP03
0000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0A0?[`iP03
0000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0B0?[`iP03
0000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP03
0000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0A0?[`iP03
0000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0A0?[`iP03
0000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H04P3jl>H10?ooo`00=@3jl>Ko00000:/00000
503jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?oo
o`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd
0?[`iP40oooo003`0?[`iP800000203jl>H200000200n_3V0P0000080?[`iP800000b`3jl>H10?oo
o`00l03jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3j
l>H0203jl>H00`000000n_3V0?[`iP390?[`iP40oooo003X0?[`iP@00000103jl>H00`000000n_3V
0?[`iP02000000030?[`iP000000000000<0n_3V00<000000?[`iP3jl>H0203jl>H6000000P0n_3V
100000040?[`iP030000003jl>H0n_3V0080000000<0n_3V0000000000000`3jl>H00`000000n_3V
0?[`iP390?[`iP40oooo003Y0?[`iP030000003jl>H0n_3V00@0n_3V00L000000?[`iP3jl>H0n_3V
0000003jl>H0000000@0n_3V00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP040?[`iP07
0000003jl>H0n_3V0?[`iP000000n_3V000000040?[`iP030000003jl>H0n_3V0<T0n_3V0@3oool0
0>T0n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V
00<0n_3V00<000000?[`iP3jl>H0203jl>H6000000T0n_3V00<000000?[`iP3jl>H0103jl>H00`00
0000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0b@3jl>H10?oo
o`00j03jl>H4000000@0n_3V00<000000?[`iP3jl>H00P0000000`3jl>H00000000000030?[`iP03
0000003jl>H0n_3V01H0n_3V100000040?[`iP030000003jl>H0n_3V0080000000<0n_3V00000000
00000`3jl>H00`000000n_3V0?[`iP390?[`iP40oooo003Y0?[`iP030000003jl>H0n_3V00@0n_3V
00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V00@0n_3V
00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP390?[`iP40oooo003Z0?[`iP800000103j
l>H2000000P0n_3V0P00000J0?[`iP800000103jl>H2000000P0n_3V0P00003;0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-0.156179, -0.133121, 0.0024687, \
0.00399443}}]
}, Open  ]],

Cell["\<\
If you would prefer to have the exponent form of labels on the y axis, you \
can use a number formatting function to obtain that.\
\>", "Text"],

Cell[BoxData[
    \(\(nformat = DisplayForm[SuperscriptBox[10, Log[10, #]]] &;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(yticks[format_] := 
        CustomTicks[logvalue, \ {0, 5, {1}, Range[2, 9]}, 
          CTNumberFunction \[RuleDelayed] 
            format];\)\), "\[IndentingNewLine]", 
    \(\(ygrids := 
        CustomGridLines[
          logvalue, {0, 5, Range[10]}];\)\), "\[IndentingNewLine]", 
    \(\(xgrids := 
        CustomGridLines[Identity, {0, 8, 1}];\)\), "\[IndentingNewLine]", 
    \(\(Draw2D[\[IndentingNewLine]{Draw[
            logvalue[f[x]], {x, 0, 8}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameTicks \[Rule] {Automatic, 
            yticks[nformat], Automatic, 
            yticks["\<\>" &]}, \[IndentingNewLine]GridLines \[Rule] {xgrids, 
            ygrids}, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            f}, \[IndentingNewLine]PlotLabel \[Rule] 
          SequenceForm[HoldForm[f[x]], "\< \[Equal] \>", 
            f[x]], \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 500];\)\)}], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(nformat\\)\\\" is similar to existing symbol \
\\\"\\!\\(format\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(logvalue[\\(\\(f[x]\
\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(3.333333333333333`*^-7\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(logvalue[\\(\\(f[x]\
\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(0.3245359325833263`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Plot::"plnr"\), \(\(:\)\(\ \)\), "\<\"\\!\\(logvalue[\\(\\(f[x]\
\\)\\)]\\) is not a machine-size real number at \\!\\(x\\) = \
\\!\\(0.6784703988749894`\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Plot::plnr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Plot :: \\\"plnr\\\"\\) will be suppressed during this calculation. \\!\
\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21.75 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .01472 -64 -6.375 ]
[-0.0125 .01472 0 6.375 ]
[-0.0125 .60332 -70 -6.375 ]
[-0.0125 .60332 0 6.375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -82.75 -5 ]
[-0.01875 .30902 -70 5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -36 0 ]
[.5 .63053 36 12.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.678 .847 .902 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 .01472 m
1 .01472 L
s
0 .1919 m
1 .1919 L
s
0 .29555 m
1 .29555 L
s
0 .36909 m
1 .36909 L
s
0 .42613 m
1 .42613 L
s
0 .47274 m
1 .47274 L
s
0 .51214 m
1 .51214 L
s
0 .54628 m
1 .54628 L
s
0 .57639 m
1 .57639 L
s
0 .60332 m
1 .60332 L
s
0 .60332 m
1 .60332 L
s
0 0 0 r
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -125 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(nformat) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(@) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(D) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -131 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(nformat) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(@) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.000 13.000 moveto
(D) show
1.000 setlinewidth
grestore
0 .1919 m
.00375 .1919 L
s
0 .29555 m
.00375 .29555 L
s
0 .36909 m
.00375 .36909 L
s
0 .42613 m
.00375 .42613 L
s
0 .47274 m
.00375 .47274 L
s
0 .51214 m
.00375 .51214 L
s
0 .54628 m
.00375 .54628 L
s
0 .57639 m
.00375 .57639 L
s
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -142.375 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.375 translate
90 rotate
-66 -10.375 translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .60332 m
1 .60332 L
s
.99625 .1919 m
1 .1919 L
s
.99625 .29555 m
1 .29555 L
s
.99625 .36909 m
1 .36909 L
s
.99625 .42613 m
1 .42613 L
s
.99625 .47274 m
1 .47274 L
s
.99625 .51214 m
1 .51214 L
s
.99625 .54628 m
1 .54628 L
s
.99625 .57639 m
1 .57639 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -97 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(D) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
87.000 13.000 moveto
0.000 0.000 rmoveto
93.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\212) show
107.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.000 13.000 moveto
0.000 0.000 rmoveto
107.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
113.000 13.000 moveto
(@) show
119.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.000 13.000 moveto
(D) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3j
l>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40
oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
iR@0n_3V0P0000000`3jl>H000000000003;0?[`iP40oooo003o0?[`iRD0n_3V00<000000?[`iP00
0000c03jl>H10?ooo`00o`3jl>HV0?[`iP030000003jl>H0n_3V0</0n_3V0@3oool00?l0n_3V903j
l>H2000000030?[`iP00000000000</0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo001S
0?[`iP800000A@3jl>H2000000@0n_3V0P0000030?[`iP@00000?`3jl>H2000000@0n_3V0P000005
0?[`iP<00000?P3jl>H2000000@0n_3V0P0000030?[`iP<00000@03jl>H2000000@0n_3V0P000004
0?[`iP800000A@3jl>H5000000L0n_3V0@3oool00680n_3V00@000000?[`iP3jl>H00000@`3jl>H0
10000000n_3V0?[`iP0000080?[`iP030000003jl>H0n_3V03l0n_3V00@000000?[`iP3jl>H00000
2`3jl>H00`000000n_3V0?[`iP0l0?[`iP040000003jl>H0n_3V000000P0n_3V00@000000?[`iP3j
l>H00000?P3jl>H010000000n_3V0?[`iP0000080?[`iP040000003jl>H0n_3V000004H0n_3V00<0
00000?[`iP3jl>H01`3jl>H10?ooo`00HP3jl>H010000000n_3V0?[`iP0000130?[`iP040000003j
l>H0n_3V000000T0n_3V00<000000?[`iP3jl>H0?P3jl>H010000000n_3V0?[`iP0000080?[`iPD0
0000?@3jl>H010000000n_3V0?[`iP0000080?[`iP040000003jl>H0n_3V000003h0n_3V00@00000
0?[`iP3jl>H00000203jl>H010000000n_3V0?[`iP0000160?[`iP030000003jl>H0n_3V00L0n_3V
0@3oool00680n_3V00@000000?[`iP3jl>H00000@`3jl>H010000000n_3V0?[`iP00000:0?[`iP03
0000003jl>H0n_3V03d0n_3V00@000000?[`iP3jl>H00000203jl>H010000000n_3V0?[`iP00000n
0?[`iP040000003jl>H0n_3V000000P0n_3V0`00000o0?[`iP040000003jl>H0n_3V000000T0n_3V
0P0000170?[`iP030000003jl>H0n_3V00L0n_3V0@3oool00680n_3V00@000000?[`iP3jl>H00000
@`3jl>H010000000n_3V0?[`iP0000080?[`iP040000003jl>H0n_3V000003h0n_3V00@000000?[`
iP3jl>H000002@3jl>H00`000000n_3V0000000n0?[`iP040000003jl>H0n_3V000000T0n_3V00<0
00000?[`iP3jl>H0?P3jl>H010000000n_3V0?[`iP0000080?[`iP040000003jl>H0n_3V000004H0
n_3V00<000000?[`iP3jl>H01`3jl>H10?ooo`00H`3jl>H2000004D0n_3V0P00000:0?[`iP800000
@03jl>H2000000/0n_3V0P00000o0?[`iP8000002P3jl>H3000003l0n_3V0P00000:0?[`iP800000
AP3jl>H2000000T0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`
i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3o
ool00?l0n_3Vm03jl>H10?ooo`00FP3jl>Ko000009X000000@3oool005X0n_3V00<000000?[`iP3j
l>H01`3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H0403jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H0403jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H0403jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H0403jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3j
l>H01P3jl>H100000040oooo00140?[`iP800000203jl>H2000000X0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`000000n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V04/0n_3V00<000000?[`iP3jl>H0
B`3jl>H00`000000n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V04/0n_3V00<000000?[`iP3jl>H0
1P3jl>H100000040oooo00140?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203j
l>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`
iP060?[`iP4000000@3oool001L0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P000003
0?[`iP8000000`3jl>H4000000080?[`iP00000000000?[`iP000000n_3V0000003jl>H500000080
n_3V0P0000050?[`iP040000003jl>H0n_3V0?[`iPD000000P3jl>H00`000000n_3V0?[`iP080?[`
iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V
00H0n_3V0@0000010?ooo`00603jl>H010000000n_3V0?[`iP0000030?[`iP030000003jl>H0n_3V
0080n_3V00@000000?[`iP3jl>H000000`3jl>H00`000000n_3V0?[`iP020?[`iP060000003jl>H0
00000?[`iP000000n_3V100000020?[`iP040000003jl>H0n_3V000000@0n_3V00<000000?[`iP3j
l>H00`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3j
l>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040
oooo000H0?[`iP040000003jl>H0n_3V000000<0n_3V00<000000?[`iP3jl>H00P3jl>H010000000
n_3V0?[`iP0000030?[`iP030000003jl>H0n_3V0080n_3V00D000000?[`iP000000n_3V00000004
0?[`iP040000003jl>H0n_3V000000L0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`
iP020?[`iP030000003jl>H0n_3V00P0n_3V0`00003o0:gHiY@0[MSV0`0000010?ooo`005`3jl>H4
000000<0n_3V100000030?[`iP8000000`3jl>H4000000060?[`iP00000000000000003jl>H00000
0`3jl>H3000000030?[`iP000000000000<00000103jl>H00`000000n_3V0?[`iP030?[`iP030000
003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool001l0n_3V00<0
00000?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V00<0n_3V00<0
00000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00L0n_3V00<0
[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00803jl>H2
00000280n_3V0P0000030?[`iP8000000`3jl>H2000000X0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`
iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V
00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0
n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo
001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3j
l>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H10000
0040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP03
0:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3j
l>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J3
0?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`
iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3j
l>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0
o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3o
ool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV
0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`
iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000
n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP40
00000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V
00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0
[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP06
0?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`
iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0
n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00
FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V
0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0
n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@000001
0?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]
f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0
n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000
003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V
0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3j
l>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`
iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V
00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0
n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo
001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3j
l>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H10000
0040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP03
0:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3j
l>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J3
0?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`
iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3j
l>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0
o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3o
ool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV
0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`
iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000
n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP40
00000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V
00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0
[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP06
0?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`
iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0
n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00
FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V
0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0
n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@000001
0?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]
f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0
n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000
003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V
0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3j
l>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`
iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V
00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0
n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo
001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3j
l>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H10000
0040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP03
0:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V0P00
003o0:gHiYH0[MSV0P0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H10000
0040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP03
0:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3j
l>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J3
0?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`
iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3j
l>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0
o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3o
ool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV
0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`
iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000
n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP40
00000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V
00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0
[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H0
0`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP06
0?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`
iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0
n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00
FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V
0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`
iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0
n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@000001
0?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]
f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0
n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000
003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V
0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3j
l>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`
iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V
00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0
n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H0
1`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo
001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3j
l>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0
n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H10000
0040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP03
0:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gH
iP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3j
l>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J3
0?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`
iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3j
l>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0
o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3o
ool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV
0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP800000o`2]f>JF0:gHiP8000000@3oool005X0
n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3j
l>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0
o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`
iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3o
ool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV
0?[`iP3jl>H01P3jl>H100000040oooo00050?[`iP040000003jl>H0n_3V00000540n_3V00<00000
0?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H1
00000040oooo00040?[`iPD00000D@3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V
0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool000<0n_3V00<000000?[`iP00
00000P3jl>H00`000000n_3V0?[`iP1?0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`000`3jl>H00`000000n_3V
000000020?[`iP030000003jl>H0n_3V04l0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V
0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@00
00010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H0
0`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]
f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP03
0000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0
n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3V
P`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3j
l>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J
0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0
n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V
0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3j
l>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040
oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gH
iP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3j
l>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H1
00000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`
iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP03
0:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V
00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H0
1P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3j
l>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP07
0?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool0
05X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`
iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP400000
0@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0
[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV
0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H20000
0?l0[MSVUP2]f>H200000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP400000
0@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0
[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV
0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`00
0000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`
iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0
n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V
00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3j
l>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`
iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o
0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V
00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?oo
o`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0
n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V
0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@00
00010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H0
0`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]
f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP03
0000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0
n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3V
P`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3j
l>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J
0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0
n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V
0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3j
l>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040
oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gH
iP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H200000?l0[MSVUP2]f>H200000040oooo001J
0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0
n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V
0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3j
l>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040
oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gH
iP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3j
l>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H1
00000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`
iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP03
0:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V
00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H0
1P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3j
l>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP07
0?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool0
05X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`
iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP400000
0@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0
[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV
0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`00
0000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`
iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0
n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP800000o`2]f>JF0:gHiP800000
0@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0
[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV
0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`00
0000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`
iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0
n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V
00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3j
l>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`
iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o
0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V
00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?oo
o`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0
n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V
0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003j
l>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@00
00010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H0
0`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]
f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP03
0000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0
n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3V
P`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V0P00003o0:gHiYH0[MSV0P00
00010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H0
0`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]
f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP03
0000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0
n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3V
P`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3j
l>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J
0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0
n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V
0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<000000?[`iP3j
l>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040
oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`iP030:gH
iP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3j
l>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H1
00000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`
iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP03
0:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V
0P00003o0:gHiYH0[MSV0P0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3j
l>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H1
00000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J30?[`
iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP070?[`iP03
0:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool005X0n_3V
00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H0
1P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3j
l>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V0?[`iP07
0?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP4000000@3oool0
05X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`
iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP400000
0@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0
[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP800000o`2]f>JF0:gHiP8000000@3oool0
05X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`
iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3j
l>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`000000n_3V
0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`iP400000
0@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0
[MSV0?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV
0?[`iP3jl>H0o`3jl>J30?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`00FP3jl>H00`00
0000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`iP060?[`
iP4000000@3oool005X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0
n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo000n0?[`iP8000003P3jl>H2000000X0n_3V
00<000000?[`iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H0
1P3jl>H100000040oooo000n0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0203j
l>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]f>H0n_3V0?[`
iP060?[`iP4000000@3oool00140n_3V0P0000020?[`iP80000000<0n_3V0000000000000P000003
0?[`iP8000000`3jl>H4000000080?[`iP00000000000?[`iP000000n_3V0000003jl>H500000080
n_3V0P0000050?[`iP040000003jl>H0n_3V0?[`iPD000000P3jl>H2000000@0n_3V00<000000?[`
iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP030:gHiP3jl>H0n_3V0?l0n_3VP`3jl>H00`2]
f>H0n_3V0?[`iP060?[`iP4000000@3oool00180n_3V00@000000?[`iP3jl>H000000`3jl>H00`00
0000n_3V0?[`iP020?[`iP040000003jl>H0n_3V000000<0n_3V00<000000?[`iP3jl>H00P3jl>H0
1P000000n_3V0000003jl>H000000?[`iP@000000P3jl>H010000000n_3V0?[`iP0000040?[`iP03
0000003jl>H0n_3V00<0n_3V00D000000?[`iP3jl>H0n_3V000000020?[`iP050000003jl>H0n_3V
0?[`iP0000002P3jl>H300000?l0[MSVU02]f>H300000040oooo000B0?[`iP040000003jl>H0n_3V
000000<0n_3V00<000000?[`iP3jl>H00P3jl>H010000000n_3V0?[`iP0000030?[`iP030000003j
l>H0n_3V0080n_3V00D000000?[`iP000000n_3V000000040?[`iP040000003jl>H0n_3V000000L0
n_3V00<000000?[`iP3jl>H00`3jl>H01@000000n_3V0?[`iP3jl>H000000080n_3V00D000000?[`
iP3jl>H0n_3V0000000:0?[`iP030000003jl>H0n_3V00L0n_3V00<0[MSV0?[`iP3jl>H0o`3jl>J3
0?[`iP030:gHiP3jl>H0n_3V00H0n_3V0@0000010?ooo`004@3jl>H4000000<0n_3V100000030?[`
iP8000000`3jl>H4000000060?[`iP00000000000000003jl>H000000`3jl>H3000000030?[`iP00
0000000000<00000103jl>H00`000000n_3V0?[`iP030?[`iP050000003jl>H0n_3V0?[`iP000000
0P3jl>H01@000000n_3V0?[`iP3jl>H0000000X0n_3V00<000000?[`iP3jl>H01`3jl>H00`2]f>H0
n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H100000040oooo000I0?[`iP030000
003jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP030?[`iP050000
003jl>H0n_3V0?[`iP0000000P3jl>H01@000000n_3V0?[`iP3jl>H0000000X0n_3V00<000000?[`
iP3jl>H01`3jl>H00`2]f>H0n_3V0?[`iP3o0?[`iX<0n_3V00<0[MSV0?[`iP3jl>H01P3jl>H10000
0040oooo000J0?[`iP8000008P3jl>H2000000<0n_3V0P0000040?[`iP8000000`3jl>H2000000X0
n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V04/0
n_3V00<000000?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP1;0?[`iP030000003jl>H0n_3V04/0
n_3V00<000000?[`iP3jl>H01P3jl>H100000040oooo001J0?[`iP030000003jl>H0n_3V00L0n_3V
00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0100n_3V
00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0100n_3V
00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V0140n_3V
00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0100n_3V
00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0100n_3V
00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V0140n_3V
00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00H0n_3V
0@0000010?ooo`00FP3jl>Ko000009X000000@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`
iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o
0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00o`3jl>H>0?[`iP800000203jl>H200000200
n_3V0P0000080?[`iP800000[P3jl>H10?ooo`00o`3jl>H>0?[`iP030000003jl>H0n_3V00P0n_3V
00<000000?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V0:`0n_3V
0@3oool00?l0n_3V1P3jl>H4000000@0n_3V00<000000?[`iP3jl>H00P0000000`3jl>H000000000
00030?[`iP030000003jl>H0n_3V00P0n_3V1P0000080?[`iP@00000103jl>H00`000000n_3V0?[`
iP02000000030?[`iP000000000000<0n_3V00<000000?[`iP3jl>H0[03jl>H10?ooo`00o`3jl>H7
0?[`iP030000003jl>H0n_3V00@0n_3V00L000000?[`iP3jl>H0n_3V0000003jl>H0000000@0n_3V
00<000000?[`iP3jl>H05`3jl>H00`000000n_3V0?[`iP040?[`iP070000003jl>H0n_3V0?[`iP00
0000n_3V000000040?[`iP030000003jl>H0n_3V0:`0n_3V0@3oool00?l0n_3V1`3jl>H00`000000
n_3V0?[`iP040?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H00`000000
n_3V0?[`iP080?[`iPH000002@3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V0080
n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP2/0?[`iP40oooo003o0?[`iPH0n_3V
100000040?[`iP030000003jl>H0n_3V0080000000<0n_3V0000000000000`3jl>H00`000000n_3V
0?[`iP0F0?[`iP@00000103jl>H00`000000n_3V0?[`iP02000000030?[`iP000000000000<0n_3V
00<000000?[`iP3jl>H0[03jl>H10?ooo`00o`3jl>H70?[`iP030000003jl>H0n_3V00@0n_3V00<0
00000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V00@0n_3V00<0
00000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP2/0?[`iP40oooo003o0?[`iPP0n_3V0P000004
0?[`iP800000203jl>H2000001X0n_3V0P0000040?[`iP800000203jl>H200000:h0n_3V0@3oool0
0?l0n_3Vm03jl>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03j
l>H10?ooo`00o`3jl>Kd0?[`iP40oooo003o0?[`i_@0n_3V0@3oool00?l0n_3Vm03jl>H10?ooo`00
o`3jl>Kd0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-0.257411, -0.15926, 0.00257062, \
0.00415934}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Making your own LogLinearPlot", "Subsection",
  ShowGroupOpenCloseIcon->True],

Cell[BoxData[
    \(f[x_] := Sin[Log[10, x + 3  x\^2]]\)], "Input"],

Cell[TextData[{
  "In the following, ",
  Cell[BoxData[
      \(f[x]\)]],
  " is plotted using the standard package LogLinearPlot. The points that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " used in LogLinearPlot are extracted from the graphics and also plotted. \
Clearly, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has used a poor choice of plot points, neglecting the smaller values of \
x."
}], "Text"],

Cell[BoxData[
    \(\(Module[\[IndentingNewLine]{g}, \[IndentingNewLine]Draw2D[\
\[IndentingNewLine]{g = 
              LogLinearPlot[f[x], {x, 0.01, 100}] // 
                DrawGraphics, \[IndentingNewLine]AbsolutePointSize[
              4], \[IndentingNewLine]g /. 
              Line[pts_] \[RuleDelayed] 
                Point /@ pts}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]FrameTicks \[Rule] {LogScale, Automatic, 
              None, Automatic}, \[IndentingNewLine]GridLines \[Rule] \
{Automatic, Automatic}, \[IndentingNewLine]FrameLabel \[Rule] {x, 
              f}, \[IndentingNewLine]PlotLabel \[Rule] 
            SequenceForm[
              HoldForm[
                f[x]], "\< \[Equal] \>", \
\*"\"\<Sin[Log[10,x+3\!\(x\^2\)]]\>\""], \[IndentingNewLine]Background \
\[Rule] Linen, \[IndentingNewLine]ImageSize \[Rule] 500]];\)\)], "Input"],

Cell["\<\
Here we make our own plot using the logstep function. The points are much \
better adapted to the function.\
\>", "Text"],

Cell[BoxData[
    \(\(Module[\[IndentingNewLine]{g}, \[IndentingNewLine]Draw2D[\
\[IndentingNewLine]{g = 
              Draw[\(logstep[f]\)[z], {z, \(-2\), 
                  2}], \[IndentingNewLine]AbsolutePointSize[
              4], \[IndentingNewLine]g /. 
              Line[pts_] \[RuleDelayed] 
                Point /@ pts}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]FrameTicks \[Rule] {LogScale, Automatic, 
              None, Automatic}, \[IndentingNewLine]GridLines \[Rule] {First /@ 
                  LogScale[##] &, 
              Automatic}, \[IndentingNewLine]FrameLabel \[Rule] {x, 
              f}, \[IndentingNewLine]PlotLabel \[Rule] 
            SequenceForm[
              HoldForm[
                f[x]], "\< \[Equal] \>", \
\*"\"\<Sin[Log[10,x+3\!\(x\^2\)]]\>\""], \[IndentingNewLine]Background \
\[Rule] Linen, \[IndentingNewLine]ImageSize \[Rule] 500]];\)\)], "Input"],

Cell["\<\
Again, we can't obtain the proper tick marks on the top of the frame. (If we \
didn't draw the grid we might be more interested in having them.) The \
following plot uses CustomTicks and CustomGridLines to make a nicer plot.\
\>", "Text"],

Cell[BoxData[{
    \(\(xticks[format_] := 
        CustomTicks[logvalue, \ {\(-2\), 2, {1}, Range[2, 9]}, 
          CTNumberFunction \[RuleDelayed] 
            format];\)\), "\[IndentingNewLine]", 
    \(\(xgrids := 
        CustomGridLines[
          logvalue, {\(-2\), 2, Range[10]}];\)\), "\[IndentingNewLine]", 
    \(\(ygrids := 
        CustomGridLines[
          Identity, {\(-1\), 1, 0.5}];\)\), "\[IndentingNewLine]", 
    \(\(Draw2D[\[IndentingNewLine]{Draw[\(logstep[f]\)[z], {z, \(-2\), 
              2}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameTicks \[Rule] {xticks[Identity], 
            Automatic, xticks["\<\>" &], 
            Automatic}, \[IndentingNewLine]GridLines \[Rule] {xgrids, 
            ygrids}, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            f}, \[IndentingNewLine]PlotLabel \[Rule] 
          SequenceForm[
            HoldForm[
              f[x]], "\< \[Equal] \>", \
\*"\"\<Sin[Log[10,x+3\!\(x\^2\)]]\>\""], \[IndentingNewLine]Background \
\[Rule] Linen, \[IndentingNewLine]ImageSize \[Rule] 500];\)\)}], "Input"],

Cell["\<\
If you would prefer to have the exponent form of labels on the y axis, you \
can use a format function to obtain that. Here are a number of functions that \
provide various formats. Try out each of them.\
\>", "Text"],

Cell[BoxData[
    \(\(nformat = DisplayForm[SuperscriptBox[10, Log[10, #]]] &;\)\)], "Input"],

Cell[BoxData[
    \(\(nformat := \[IndentingNewLine]Switch[#, \[IndentingNewLine]1, 
            1, \[IndentingNewLine]_, 
            DisplayForm[SuperscriptBox[10, Log[10, #]]]] &;\)\)], "Input"],

Cell[BoxData[
    \(\(nformat := \[IndentingNewLine]Switch[#, \[IndentingNewLine]1, 
            1, \[IndentingNewLine]10, 10, \[IndentingNewLine]1/10, 
            0.1, \[IndentingNewLine]_, 
            DisplayForm[SuperscriptBox[10, Log[10, #]]]] &;\)\)], "Input"],

Cell[BoxData[{
    \(\(xticks[format_] := 
        CustomTicks[logvalue, \ {\(-2\), 2, {1}, Range[2, 9]}, 
          CTNumberFunction \[RuleDelayed] 
            format];\)\), "\[IndentingNewLine]", 
    \(\(xgrids := 
        CustomGridLines[
          logvalue, {\(-2\), 2, Range[10]}];\)\), "\[IndentingNewLine]", 
    \(\(ygrids := 
        CustomGridLines[
          Identity, {\(-1\), 1, 0.5}];\)\), "\[IndentingNewLine]", 
    \(\(Draw2D[\[IndentingNewLine]{Draw[\(logstep[f]\)[z], {z, \(-2\), 
              2}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameTicks \[Rule] {xticks[nformat], 
            Automatic, xticks["\<\>" &], 
            Automatic}, \[IndentingNewLine]GridLines \[Rule] {xgrids, 
            ygrids}, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            f}, \[IndentingNewLine]PlotLabel \[Rule] 
          SequenceForm[
            HoldForm[
              f[x]], "\< \[Equal] \>", \
\*"\"\<Sin[Log[10,x+3\!\(x\^2\)]]\>\""], \[IndentingNewLine]Background \
\[Rule] Linen, \[IndentingNewLine]ImageSize \[Rule] 500];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Making your own LogLogPlot", "Subsection",
  ShowGroupOpenCloseIcon->True],

Cell[BoxData[
    \(f[x_] := \(Log[10, x + 3  x\^2]!\)\)], "Input"],

Cell[TextData[{
  "In the following, ",
  Cell[BoxData[
      \(f[x]\)]],
  " is plotted using the standard package LogLogPlot. The points that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " used in LogLogPlot are extracted from the graphics and also plotted. \
Clearly, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has used a poor choice of plot points, neglecting the smaller values of \
x."
}], "Text"],

Cell[BoxData[
    \(\(Module[\[IndentingNewLine]{g}, \[IndentingNewLine]Draw2D[\
\[IndentingNewLine]{g = 
              LogLogPlot[f[x], {x, 0.1, 1000}] // 
                DrawGraphics, \[IndentingNewLine]AbsolutePointSize[
              4], \[IndentingNewLine]g /. 
              Line[pts_] \[RuleDelayed] 
                Point /@ pts}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]FrameTicks \[Rule] {LogScale, LogScale, 
              None, None}, \[IndentingNewLine]GridLines \[Rule] {Automatic, 
              Automatic}, \[IndentingNewLine]FrameLabel \[Rule] {x, 
              f}, \[IndentingNewLine]PlotLabel \[Rule] 
            SequenceForm[
              HoldForm[
                f[x]], "\< \[Equal] \>", \
\*"\"\<Sin[Log[10,x+3\!\(x\^2\)]]\>\""], \[IndentingNewLine]Background \
\[Rule] Linen, \[IndentingNewLine]ImageSize \[Rule] 500]];\)\)], "Input"],

Cell["\<\
Here we make our own plot using the logstep function. The points are much \
better adapted to the function.\
\>", "Text"],

Cell[BoxData[
    \(\(Module[\[IndentingNewLine]{g}, \[IndentingNewLine]Draw2D[\
\[IndentingNewLine]{g = 
              Draw[logvalue[\(logstep[f]\)[z]], {z, \(-1\), 
                  3}], \[IndentingNewLine]AbsolutePointSize[
              4], \[IndentingNewLine]g /. 
              Line[pts_] \[RuleDelayed] 
                Point /@ pts}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]FrameTicks \[Rule] {LogScale, LogScale, 
              None, None}, \[IndentingNewLine]GridLines \[Rule] {First /@ 
                  LogScale[##] &, 
              First /@ 
                  LogScale[##] &}, \[IndentingNewLine]FrameLabel \[Rule] {x, 
              f}, \[IndentingNewLine]PlotLabel \[Rule] 
            SequenceForm[
              HoldForm[
                f[x]], "\< \[Equal] \>", \
\*"\"\<Sin[Log[10,x+3\!\(x\^2\)]]\>\""], \[IndentingNewLine]Background \
\[Rule] Linen, \[IndentingNewLine]ImageSize \[Rule] 500]];\)\)], "Input"],

Cell["\<\
We can make a more controlled plot, with matching tick marks , by using \
CustomTicks and CustomGridLines.\
\>", "Text"],

Cell[BoxData[{
    \(\(xticks[format_] := 
        CustomTicks[logvalue, \ {\(-1\), 3, {1}, Range[2, 9]}, 
          CTNumberFunction \[RuleDelayed] 
            format];\)\), "\[IndentingNewLine]", 
    \(\(yticks[format_] := 
        CustomTicks[logvalue, \ {0, 4, {1}, Range[2, 9]}, 
          CTNumberFunction \[RuleDelayed] 
            format];\)\), "\[IndentingNewLine]", 
    \(\(xgrids := 
        CustomGridLines[
          logvalue, {\(-1\), 3, Range[10]}];\)\), "\[IndentingNewLine]", 
    \(\(ygrids := 
        CustomGridLines[
          logvalue, {0, 4, Range[10]}];\)\), "\[IndentingNewLine]", 
    \(\(Draw2D[\[IndentingNewLine]{Draw[
            logvalue[\(logstep[f]\)[z]], {z, \(-1\), 
              3}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameTicks \[Rule] {xticks[N], 
            yticks[Identity], xticks["\<\>" &], 
            yticks["\<\>" &]}, \[IndentingNewLine]GridLines \[Rule] {xgrids, 
            ygrids}, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            f}, \[IndentingNewLine]PlotLabel \[Rule] 
          SequenceForm[
            HoldForm[
              f[x]], "\< \[Equal] \>", \
\*"\"\<Sin[Log[10,x+3\!\(x\^2\)]]\>\""], \[IndentingNewLine]Background \
\[Rule] Linen, \[IndentingNewLine]ImageSize \[Rule] 500];\)\)}], "Input"],

Cell["\<\
If you would prefer to have the exponent form of labels on the axes, you can \
use a format function to obtain that. I have again provided several number \
formatting functions.\
\>", "Text"],

Cell[BoxData[
    \(\(nformat = DisplayForm[SuperscriptBox[10, Log[10, #]]] &;\)\)], "Input"],

Cell[BoxData[
    \(\(nformat := \[IndentingNewLine]Switch[#, \[IndentingNewLine]1, 
            1, \[IndentingNewLine]_, 
            DisplayForm[SuperscriptBox[10, Log[10, #]]]] &;\)\)], "Input"],

Cell[BoxData[
    \(\(nformat := \[IndentingNewLine]Switch[#, \[IndentingNewLine]1, 
            1, \[IndentingNewLine]10, 10, \[IndentingNewLine]1/10, 
            0.1, \[IndentingNewLine]_, 
            DisplayForm[SuperscriptBox[10, Log[10, #]]]] &;\)\)], "Input"],

Cell[BoxData[{
    \(\(xticks[format_] := 
        CustomTicks[logvalue, \ {\(-1\), 3, {1}, Range[2, 9]}, 
          CTNumberFunction \[RuleDelayed] 
            format];\)\), "\[IndentingNewLine]", 
    \(\(yticks[format_] := 
        CustomTicks[logvalue, \ {0, 4, {1}, Range[2, 9]}, 
          CTNumberFunction \[RuleDelayed] 
            format];\)\), "\[IndentingNewLine]", 
    \(\(xgrids := 
        CustomGridLines[
          logvalue, {\(-1\), 3, Range[10]}];\)\), "\[IndentingNewLine]", 
    \(\(ygrids := 
        CustomGridLines[
          logvalue, {0, 4, Range[10]}];\)\), "\[IndentingNewLine]", 
    \(\(Draw2D[\[IndentingNewLine]{Draw[
            logvalue[\(logstep[f]\)[z]], {z, \(-1\), 
              3}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameTicks \[Rule] {xticks[nformat], 
            yticks[nformat], xticks["\<\>" &], 
            yticks["\<\>" &]}, \[IndentingNewLine]GridLines \[Rule] {xgrids, 
            ygrids}, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            f}, \[IndentingNewLine]PlotLabel \[Rule] 
          SequenceForm[
            HoldForm[
              f[x]], "\< \[Equal] \>", \
\*"\"\<Sin[Log[10,x+3\!\(x\^2\)]]\>\""], \[IndentingNewLine]Background \
\[Rule] Linen, \[IndentingNewLine]ImageSize \[Rule] 500];\)\)}], "Input"],

Cell[BoxData[
    \(Clear[f, xticks, yticks, xgrids, ygrids, nformat]\)], "Input"],

Cell[BoxData[
    \(Clear[logstep, logvalue]\)], "Input"]
}, Closed]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowSize->{683, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 26, 0, 67, "Title"],
Cell[1783, 53, 140, 2, 70, "Input"],
Cell[1926, 57, 415, 7, 86, "Text"],
Cell[2344, 66, 266, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[2635, 75, 55, 0, 52, "Subsection"],
Cell[2693, 77, 132, 2, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2862, 84, 77, 1, 52, "Subsection"],
Cell[2942, 87, 48, 1, 50, "Input"],
Cell[2993, 90, 160, 3, 48, "Text"],

Cell[CellGroupData[{
Cell[3178, 97, 642, 11, 210, "Input"],
Cell[3823, 110, 349, 5, 44, "Message"],
Cell[4175, 117, 346, 5, 44, "Message"],
Cell[4524, 124, 346, 5, 44, "Message"],
Cell[4873, 131, 328, 5, 44, "Message"],
Cell[5204, 138, 69743, 1525, 317, 18856, 893, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[74962, 1666, 88, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[75075, 1672, 696, 11, 230, "Input"],
Cell[75774, 1685, 349, 5, 44, "Message"],
Cell[76126, 1692, 346, 5, 44, "Message"],
Cell[76475, 1699, 346, 5, 44, "Message"],
Cell[76824, 1706, 328, 5, 44, "Message"],
Cell[77155, 1713, 82659, 1689, 317, 18922, 899, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[159829, 3405, 274, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[160128, 3414, 1014, 19, 290, "Input"],
Cell[161145, 3435, 360, 5, 44, "Message"],
Cell[161508, 3442, 349, 5, 44, "Message"],
Cell[161860, 3449, 346, 5, 44, "Message"],
Cell[162209, 3456, 346, 5, 44, "Message"],
Cell[162558, 3463, 328, 5, 44, "Message"],
Cell[162889, 3470, 48569, 1008, 317, 9290, 520, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[211473, 4481, 153, 3, 29, "Text"],
Cell[211629, 4486, 93, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[211747, 4491, 1013, 19, 290, "Input"],
Cell[212763, 4512, 361, 5, 44, "Message"],
Cell[213127, 4519, 349, 5, 44, "Message"],
Cell[213479, 4526, 346, 5, 44, "Message"],
Cell[213828, 4533, 346, 5, 44, "Message"],
Cell[214177, 4540, 328, 5, 44, "Message"],
Cell[214508, 4547, 47716, 1069, 317, 12288, 628, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[262273, 5622, 83, 1, 52, "Subsection"],
Cell[262359, 5625, 67, 1, 51, "Input"],
Cell[262429, 5628, 437, 13, 67, "Text"],
Cell[262869, 5643, 889, 16, 294, "Input"],
Cell[263761, 5661, 131, 3, 29, "Text"],
Cell[263895, 5666, 925, 17, 294, "Input"],
Cell[264823, 5685, 248, 4, 48, "Text"],
Cell[265074, 5691, 1094, 22, 293, "Input"],
Cell[266171, 5715, 227, 4, 48, "Text"],
Cell[266401, 5721, 93, 1, 50, "Input"],
Cell[266497, 5724, 197, 3, 110, "Input"],
Cell[266697, 5729, 267, 4, 150, "Input"],
Cell[266967, 5735, 1093, 22, 293, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[268097, 5762, 80, 1, 36, "Subsection"],
Cell[268180, 5765, 67, 1, 51, "Input"],
Cell[268250, 5768, 431, 13, 67, "Text"],
Cell[268684, 5783, 893, 16, 294, "Input"],
Cell[269580, 5801, 131, 3, 29, "Text"],
Cell[269714, 5806, 962, 18, 294, "Input"],
Cell[270679, 5826, 130, 3, 29, "Text"],
Cell[270812, 5831, 1305, 27, 333, "Input"],
Cell[272120, 5860, 201, 4, 48, "Text"],
Cell[272324, 5866, 93, 1, 50, "Input"],
Cell[272420, 5869, 197, 3, 110, "Input"],
Cell[272620, 5874, 267, 4, 150, "Input"],
Cell[272890, 5880, 1310, 27, 333, "Input"],
Cell[274203, 5909, 82, 1, 50, "Input"],
Cell[274288, 5912, 57, 1, 50, "Input"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

