(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     57685,       1614]*)
(*NotebookOutlinePosition[     58658,       1648]*)
(*  CellTagsIndexPosition[     58582,       1642]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["FilledDraw", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          RowBox[{"Filled", 
            StyleBox["Draw",
              "MR"]}]], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(f, {x, xmin, xmax}, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " extracts the graphics primitives from the corresponding FilledPlot \
statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as FilledPlot. Regular FilledPlot options may be used. \
Basic Graphics options, such as PlotRange have no effect.\
\>", "MathCaption"],

Cell["\<\
FilledPlot has an error which sometimes causes the filled area to overrun the \
frame when a Frame is used.\
\>", "MathCaption"],

Cell[TextData[{
  "See ",
  ButtonBox["DrawingTransform",
    ButtonData:>{"DrawingTransform"},
    ButtonStyle->"AddOnsLink"],
  " for an example of filling the area between two polar curves."
}], "MathCaption"],

Cell[TextData[{
  "The FilledPlot package also has the very useful option ",
  Cell[BoxData[
      \(AxesFront \[Rule] True\)]],
  ". DrawingMaster will automatically load FilledPlot when AxesFront is \
used."
}], "MathCaption"],

Cell[TextData[{
  "See also:  ",
  ButtonBox["FilledPlot",
    ButtonData:>{"Graphics`FilledPlot`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example ", "ExampleSection"],

Cell[BoxData[{
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<Statistics`ContinuousDistributions`\>"]\)}], "Input",
  CellLabel->"In[219]:="],

Cell["\<\
This is the probability distribution function for the normal distribution \
centered at 5 with a standard deviation of 2.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[x_] = PDF[NormalDistribution[5, 2], x]\)], "Input",
  CellLabel->"In[222]:="],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\(1\/8\)\)\ \((\(-5\) + x)\)\^2\)\/\(2\ \@\(2\ \
\[Pi]\)\)\)], "Output",
  CellLabel->"Out[222]="]
}, Open  ]],

Cell[TextData[{
  "The following plots the distribution from ",
  Cell[BoxData[
      \(x \[Equal] 0\)]],
  " to ",
  Cell[BoxData[
      \(x \[Equal] 10\)]],
  " and fills it one standard deviation on each side of the mean. The drawing \
of the curve was suppressed in FilledDraw so it wouldn't be doubly drawn."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{FilledDraw[f[x], {x, 3, 7}, 
            Fills \[Rule] CadetBlue, 
            Curves \[Rule] None], \[IndentingNewLine]Draw[
            f[x], {x, 0, 10}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]Axes \[Rule] True, AxesFront \[Rule] True, 
        AxesOrigin \[Rule] {5, 0}, \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]PlotLabel \[Rule] "\<Normal \
Distribution\>", \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 
          400\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[223]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.0238095 0.0952381 0.0147151 2.95082 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16226 -24 -4.5 ]
[-0.0125 .16226 0 4.5 ]
[-0.0125 .3098 -18 -4.5 ]
[-0.0125 .3098 0 4.5 ]
[-0.0125 .45734 -24 -4.5 ]
[-0.0125 .45734 0 4.5 ]
[-0.0125 .60488 -18 -4.5 ]
[-0.0125 .60488 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -59 0 ]
[.5 .63053 59 12.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16226 m
.00625 .16226 L
s
[(0.05)] -0.0125 .16226 1 0 Mshowa
0 .3098 m
.00625 .3098 L
s
[(0.1)] -0.0125 .3098 1 0 Mshowa
0 .45734 m
.00625 .45734 L
s
[(0.15)] -0.0125 .45734 1 0 Mshowa
0 .60488 m
.00625 .60488 L
s
[(0.2)] -0.0125 .60488 1 0 Mshowa
.125 Mabswid
0 .04422 m
.00375 .04422 L
s
0 .07373 m
.00375 .07373 L
s
0 .10324 m
.00375 .10324 L
s
0 .13275 m
.00375 .13275 L
s
0 .19176 m
.00375 .19176 L
s
0 .22127 m
.00375 .22127 L
s
0 .25078 m
.00375 .25078 L
s
0 .28029 m
.00375 .28029 L
s
0 .33931 m
.00375 .33931 L
s
0 .36881 m
.00375 .36881 L
s
0 .39832 m
.00375 .39832 L
s
0 .42783 m
.00375 .42783 L
s
0 .48685 m
.00375 .48685 L
s
0 .51635 m
.00375 .51635 L
s
0 .54586 m
.00375 .54586 L
s
0 .57537 m
.00375 .57537 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16226 m
1 .16226 L
s
.99375 .3098 m
1 .3098 L
s
.99375 .45734 m
1 .45734 L
s
.99375 .60488 m
1 .60488 L
s
.125 Mabswid
.99625 .04422 m
1 .04422 L
s
.99625 .07373 m
1 .07373 L
s
.99625 .10324 m
1 .10324 L
s
.99625 .13275 m
1 .13275 L
s
.99625 .19176 m
1 .19176 L
s
.99625 .22127 m
1 .22127 L
s
.99625 .25078 m
1 .25078 L
s
.99625 .28029 m
1 .28029 L
s
.99625 .33931 m
1 .33931 L
s
.99625 .36881 m
1 .36881 L
s
.99625 .39832 m
1 .39832 L
s
.99625 .42783 m
1 .42783 L
s
.99625 .48685 m
1 .48685 L
s
.99625 .51635 m
1 .51635 L
s
.99625 .54586 m
1 .54586 L
s
.99625 .57537 m
1 .57537 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Normal) show
105.000 13.000 moveto
(Distribution) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.372 .62 .628 r
.30952 .37172 m
.32498 .40062 L
.34183 .43167 L
.35766 .45992 L
.37288 .48581 L
.38909 .51153 L
.40468 .53405 L
.42126 .55512 L
.43723 .57221 L
.4526 .58537 L
.46038 .59072 L
.46895 .59555 L
.47707 .59907 L
.48071 .60031 L
.48469 .60142 L
.48684 .60192 L
.48884 .60231 L
.49091 .60265 L
.49279 .6029 L
.49463 .60309 L
.49548 .60315 L
.49637 .60321 L
.49733 .60326 L
.49775 .60328 L
.49821 .60329 L
.4987 .60331 L
.49916 .60331 L
.49943 .60332 L
.4997 .60332 L
.5002 .60332 L
.50065 .60332 L
.50114 .60331 L
.50161 .6033 L
.50203 .60329 L
.50302 .60325 L
.50406 .60319 L
.50507 .60311 L
.50602 .60303 L
.50816 .60278 L
.51172 .60221 L
.51553 .60137 L
.51962 .6002 L
.52407 .59864 L
.53213 .59501 L
.54849 .58455 L
.56425 .57076 L
.57941 .55433 L
.59555 .53374 L
.61108 .51128 L
.62759 .48504 L
.64349 .45791 L
.65879 .43054 L
.67507 .40054 L
.69048 .37172 L
.69048 .01472 L
.30952 .01472 L
F
0 0 0 r
.5 Mabswid
.02381 .04058 m
.04262 .04766 L
.06244 .05678 L
.10458 .08295 L
.14264 .11598 L
.18314 .16226 L
.22214 .21782 L
.26358 .28717 L
.30351 .36046 L
.34193 .43185 L
.38279 .5018 L
.40311 .53189 L
.42214 .55615 L
.44154 .57624 L
.45998 .59047 L
.46966 .5959 L
.47477 .59818 L
.48023 .60016 L
.48526 .60156 L
.48983 .60248 L
.49204 .60281 L
.4932 .60294 L
.49443 .60307 L
.4955 .60315 L
.49668 .60323 L
.49775 .60328 L
.49875 .60331 L
.50001 .60332 L
.50065 .60332 L
.50135 .6033 L
.50259 .60326 L
.50376 .6032 L
.50512 .60311 L
.50638 .60299 L
.5092 .60263 L
.51151 .60225 L
.51403 .60173 L
.5191 .60037 L
.52375 .59876 L
.52872 .59667 L
.53766 .59193 L
.5479 .585 L
.55901 .57574 L
.57916 .55462 L
.62008 .49725 L
.65948 .42929 L
.69737 .35881 L
.73771 .28489 L
.77653 .2199 L
.81781 .16104 L
Mistroke
.85757 .11578 L
.89581 .08266 L
.91717 .0682 L
.93651 .05731 L
.97569 .04075 L
.97619 .04058 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 2.95082 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16226 -24 -4.5 ]
[-0.0125 .16226 0 4.5 ]
[-0.0125 .3098 -18 -4.5 ]
[-0.0125 .3098 0 4.5 ]
[-0.0125 .45734 -24 -4.5 ]
[-0.0125 .45734 0 4.5 ]
[-0.0125 .60488 -18 -4.5 ]
[-0.0125 .60488 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -59 0 ]
[.5 .63053 59 12.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16226 m
.00625 .16226 L
s
[(0.05)] -0.0125 .16226 1 0 Mshowa
0 .3098 m
.00625 .3098 L
s
[(0.1)] -0.0125 .3098 1 0 Mshowa
0 .45734 m
.00625 .45734 L
s
[(0.15)] -0.0125 .45734 1 0 Mshowa
0 .60488 m
.00625 .60488 L
s
[(0.2)] -0.0125 .60488 1 0 Mshowa
.125 Mabswid
0 .04422 m
.00375 .04422 L
s
0 .07373 m
.00375 .07373 L
s
0 .10324 m
.00375 .10324 L
s
0 .13275 m
.00375 .13275 L
s
0 .19176 m
.00375 .19176 L
s
0 .22127 m
.00375 .22127 L
s
0 .25078 m
.00375 .25078 L
s
0 .28029 m
.00375 .28029 L
s
0 .33931 m
.00375 .33931 L
s
0 .36881 m
.00375 .36881 L
s
0 .39832 m
.00375 .39832 L
s
0 .42783 m
.00375 .42783 L
s
0 .48685 m
.00375 .48685 L
s
0 .51635 m
.00375 .51635 L
s
0 .54586 m
.00375 .54586 L
s
0 .57537 m
.00375 .57537 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16226 m
1 .16226 L
s
.99375 .3098 m
1 .3098 L
s
.99375 .45734 m
1 .45734 L
s
.99375 .60488 m
1 .60488 L
s
.125 Mabswid
.99625 .04422 m
1 .04422 L
s
.99625 .07373 m
1 .07373 L
s
.99625 .10324 m
1 .10324 L
s
.99625 .13275 m
1 .13275 L
s
.99625 .19176 m
1 .19176 L
s
.99625 .22127 m
1 .22127 L
s
.99625 .25078 m
1 .25078 L
s
.99625 .28029 m
1 .28029 L
s
.99625 .33931 m
1 .33931 L
s
.99625 .36881 m
1 .36881 L
s
.99625 .39832 m
1 .39832 L
s
.99625 .42783 m
1 .42783 L
s
.99625 .48685 m
1 .48685 L
s
.99625 .51635 m
1 .51635 L
s
.99625 .54586 m
1 .54586 L
s
.99625 .57537 m
1 .57537 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Normal) show
105.000 13.000 moveto
(Distribution) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[223]:=",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003oo`3ooonA
0?ooo`00;P3jl>H2000003l0n_3V100000110?[`iP<00000?@3jl>H300000440n_3V0P00000l0?[`
iPD000000P3jl>H200000100n_3V0@3oool002d0n_3V00@000000?[`iP3jl>H00000?P3jl>H00`00
0000n_3V0?[`iP130?[`iP030000003jl>H0n_3V03`0n_3V00@000000?[`iP3jl>H00000?`3jl>H0
10000000n_3V0?[`iP00000m0?[`iP050000003jl>H0n_3V0?[`iP0000000P3jl>H00`000000n_3V
0?[`iP0=0?[`iP40oooo000]0?[`iP040000003jl>H0n_3V000003l0n_3V00<000000?[`iP3jl>H0
?`3jl>H5000003d0n_3V00@000000?[`iP3jl>H00000?`3jl>H010000000n_3V0?[`iP00000m0?[`
iP050000003jl>H0n_3V0?[`iP0000000P3jl>H00`000000n_3V0?[`iP0=0?[`iP40oooo000]0?[`
iP040000003jl>H0n_3V00000400n_3V00<000000?[`iP3jl>H0?P3jl>H010000000n_3V0?[`iP00
000n0?[`iP<00000@@3jl>H2000003h0n_3V00D000000?[`iP3jl>H0n_3V000000020?[`iP030000
003jl>H0n_3V00d0n_3V0@3oool002d0n_3V00@000000?[`iP3jl>H00000?P3jl>H010000000n_3V
0?[`iP0000100?[`iP030000003jl>H0000003l0n_3V00<000000?[`iP3jl>H0?`3jl>H010000000
n_3V0?[`iP00000m0?[`iP050000003jl>H0n_3V0?[`iP0000000P3jl>H00`000000n_3V0?[`iP0=
0?[`iP40oooo000^0?[`iP800000@03jl>H200000480n_3V0P00000o0?[`iP<00000@03jl>H20000
03d0n_3V0P0000040?[`iP800000403jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V
0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0
n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo000W0?[`i_l00000G`00000:0?[`iP40oooo000W
0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0=
0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0>
0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0>
0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0>
0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0>
0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0=
0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0=
0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`00
0000n_3V0?[`iP050?[`iP030000003jl>H0n_3V03l0n_3V00<000000?[`iP3jl>H0@03jl>H00`00
0000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`iP3jl>H0@03jl>H00`00
0000n_3V0?[`iP0o0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0203jl>H10?oo
o`007P3jl>H2000000L0n_3V00<000000?[`iP3jl>H0Z`3jl>H00`000000n_3V0?[`iP2/0?[`iP03
0000003jl>H0n_3V00P0n_3V0@3oool001d0n_3V00@000000?[`iP3jl>H000001P3jl>H00`000000
n_3V0?[`iP2[0?[`iP030000003jl>H0n_3V0:`0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`00
7@3jl>H010000000n_3V0?[`iP0000060?[`i_l00000G`00000:0?[`iP40oooo000M0?[`iP040000
003jl>H0n_3V000000H0n_3V00<000000?[`iP3jl>H0J@3jl>I205nNX0030000001OWZ00GijP0400
GijPK03jl>H00`000000n_3V0?[`iP080?[`iP40oooo000M0?[`iP040000003jl>H0n_3V000000H0
n_3V00<000000?[`iP3jl>H0J@3jl>I205nNX0030000001OWZ00GijP0400GijPK03jl>H00`000000
n_3V0?[`iP080?[`iP40oooo000N0?[`iP8000001`3jl>H00`000000n_3V0?[`iP1Y0?[`iT80GijP
00<0000005nNX01OWZ00@01OWZ1/0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<0
00000?[`iP3jl>H0J@3jl>I205nNX0030000001OWZ00GijP0400GijPK03jl>H00`000000n_3V0?[`
iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V06T0n_3V@P1OWZ000`000000GijP05nNX010
05nNX6`0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1Y0?[`
iT80GijP00<0000005nNX01OWZ00@01OWZ1/0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0
n_3V00<000000?[`iP3jl>H0J@3jl>I205nNX0030000001OWZ00GijP0400GijPK03jl>H00`000000
n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V06T0n_3V@P1OWZ000`000000GijP
05nNX01005nNX6`0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`
iP050?[`iP800000HP3jl>I205nNX0030000001OWZ00GijP0400GijPHP3jl>H2000000P0n_3V00<0
00000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H2000000P0n_3V0`00001O0?[`iT80GijP00<00000
05nNX01OWZ00@01OWZ1P0?[`iP800000203jl>H3000000X0n_3V0@3oool002L0n_3V00<000000?[`
iP3jl>H02P3jl>H3000005`0n_3V@P1OWZ000`000000GijP05nNX01005nNX5h0n_3V0P00000<0?[`
iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H03@3jl>H2000005X0
n_3V@P1OWZ000`000000GijP05nNX01005nNX5/0n_3V0`00000>0?[`iP030000003jl>H0n_3V00P0
n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H03`3jl>H2000005P0n_3V@P1OWZ000`000000GijP
05nNX01005nNX5T0n_3V0P00000A0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<0
00000?[`iP3jl>H04@3jl>H2000005H0n_3V@P1OWZ000`000000GijP05nNX01005nNX5L0n_3V0P00
000C0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H04`3jl>H2
000005@0n_3V@P1OWZ000`000000GijP05nNX01005nNX5D0n_3V0P00000E0?[`iP030000003jl>H0
n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP1A0?[`
iT80GijP00<0000005nNX01OWZ00@01OWZ1C0?[`iP8000005`3jl>H00`000000n_3V0?[`iP080?[`
iP40oooo000W0?[`iP030000003jl>H0n_3V01H0n_3V0P00001A0?[`iT80GijP00<0000005nNX01O
WZ00@01OWZ1A0?[`iP8000006@3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000
003jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H0CP3jl>I205nNX0030000001OWZ00GijP0400GijP
C`3jl>H2000001/0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`
iP0I0?[`iP800000CP3jl>I205nNX0030000001OWZ00GijP0400GijPCP3jl>H00`000000n_3V0?[`
iP0K0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V0P00000L0?[`iP030000003jl>H0
n_3V04/0n_3V@P1OWZ000`000000GijP05nNX01005nNX4`0n_3V0P00000L0?[`iP<000002P3jl>H1
0?ooo`009`3jl>H00`000000n_3V0?[`iP0L0?[`iP800000B`3jl>I205nNX0030000001OWZ00GijP
0400GijPB`3jl>H00`000000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0
n_3V00<000000?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP180?[`iT80GijP00<0000005nNX01O
WZ00@01OWZ1:0?[`iP030000003jl>H0n_3V01l0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`00
9`3jl>H00`000000n_3V0?[`iP0O0?[`iP800000B03jl>I205nNX0030000001OWZ00GijP0400GijP
B03jl>H200000280n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`
iP0Q0?[`iP030000003jl>H0n_3V04D0n_3V@P1OWZ000`000000GijP05nNX01005nNX4L0n_3V00<0
00000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0
n_3V0280n_3V00<000000?[`iP3jl>H0A03jl>I205nNX0030000001OWZ00GijP0400GijPAP3jl>H0
0`000000n_3V0?[`iP0S0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`
iP3jl>H08`3jl>H00`000000n_3V0?[`iP130?[`iT80GijP00<0000005nNX01OWZ00@01OWZ150?[`
iP030000003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000
n_3V0?[`iP0T0?[`iP800000@`3jl>I205nNX0030000001OWZ00GijP0400GijP@`3jl>H2000002L0
n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP0V0?[`iP030000
003jl>H0n_3V0400n_3V@P1OWZ000`000000GijP05nNX01005nNX480n_3V00<000000?[`iP3jl>H0
9`3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V02L0n_3V00<0
00000?[`iP3jl>H0?`3jl>I205nNX0030000001OWZ00GijP0400GijP@@3jl>H00`000000n_3V0?[`
iP0X0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0:03jl>H0
0`000000n_3V0?[`iP0n0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ100?[`iP030000003jl>H0
n_3V02T0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H2000002X0n_3V00<000000?[`
iP3jl>H0?@3jl>I205nNX0030000001OWZ00GijP0400GijP?`3jl>H00`000000n_3V0?[`iP0X0?[`
iP<000002P3jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP0Z0?[`iP800000?@3jl>I205nNX003
0000001OWZ00GijP0400GijP?@3jl>H2000002d0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`00
9`3jl>H00`000000n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V03X0n_3V@P1OWZ000`000000GijP
05nNX01005nNX3`0n_3V00<000000?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP080?[`iP40oooo
000W0?[`iP030000003jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H0>@3jl>I205nNX0030000001O
WZ00GijP0400GijP>`3jl>H00`000000n_3V0?[`iP0^0?[`iP030000003jl>H0n_3V00P0n_3V0@3o
ool002L0n_3V00<000000?[`iP3jl>H0;P3jl>H00`000000n_3V0?[`iP0h0?[`iT80GijP00<00000
05nNX01OWZ00@01OWZ0j0?[`iP030000003jl>H0n_3V02l0n_3V00<000000?[`iP3jl>H0203jl>H1
0?ooo`009`3jl>H00`000000n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V03L0n_3V@P1OWZ000`00
0000GijP05nNX01005nNX3T0n_3V00<000000?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP080?[`
iP40oooo000W0?[`iP030000003jl>H0n_3V0300n_3V00<000000?[`iP3jl>H0=P3jl>I205nNX003
0000001OWZ00GijP0400GijP>03jl>H00`000000n_3V0?[`iP0a0?[`iP030000003jl>H0n_3V00P0
n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP0e0?[`iT80GijP
00<0000005nNX01OWZ00@01OWZ0g0?[`iP030000003jl>H0n_3V0380n_3V00<000000?[`iP3jl>H0
203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP0a0?[`iP030000003jl>H0n_3V03D0n_3V@P1O
WZ000`000000GijP05nNX01005nNX3H0n_3V00<000000?[`iP3jl>H0<`3jl>H00`000000n_3V0?[`
iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V0380n_3V00<000000?[`iP3jl>H0=03jl>I2
05nNX0030000001OWZ00GijP0400GijP=P3jl>H00`000000n_3V0?[`iP0c0?[`iP030000003jl>H0
n_3V00P0n_3V0@3oool002L0n_3V0P00000d0?[`iP030000003jl>H0n_3V03<0n_3V@P1OWZ000`00
0000GijP05nNX01005nNX3D0n_3V00<000000?[`iP3jl>H0<P3jl>H3000000X0n_3V0@3oool002L0
n_3V00<000000?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP0b0?[`iT80GijP00<0000005nNX01O
WZ00@01OWZ0d0?[`iP030000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`00
9`3jl>H00`000000n_3V0?[`iP0e0?[`iP030000003jl>H0n_3V0340n_3V@P1OWZ000`000000GijP
05nNX01005nNX3<0n_3V00<000000?[`iP3jl>H0=P3jl>H00`000000n_3V0?[`iP080?[`iP40oooo
000W0?[`iP030000003jl>H0n_3V03H0n_3V00<000000?[`iP3jl>H0<03jl>I205nNX0030000001O
WZ00GijP0400GijP<P3jl>H00`000000n_3V0?[`iP0g0?[`iP030000003jl>H0n_3V00P0n_3V0@3o
ool002L0n_3V00<000000?[`iP3jl>H0=`3jl>H00`000000n_3V0?[`iP0_0?[`iT80GijP00<00000
05nNX01OWZ00@01OWZ0a0?[`iP030000003jl>H0n_3V03P0n_3V00<000000?[`iP3jl>H0203jl>H1
0?ooo`009`3jl>H00`000000n_3V0?[`iP0h0?[`iP030000003jl>H0n_3V02h0n_3V@P1OWZ000`00
0000GijP05nNX01005nNX300n_3V00<000000?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP080?[`
iP40oooo000W0?[`iP030000003jl>H0n_3V03P0n_3V00<000000?[`iP3jl>H0;P3jl>I205nNX003
0000001OWZ00GijP0400GijP;`3jl>H00`000000n_3V0?[`iP0j0?[`iP030000003jl>H0n_3V00P0
n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0>@3jl>H00`000000n_3V0?[`iP0]0?[`iT80GijP
00<0000005nNX01OWZ00@01OWZ0_0?[`iP030000003jl>H0n_3V03X0n_3V00<000000?[`iP3jl>H0
203jl>H10?ooo`00303jl>H2000000@0n_3V0P0000040?[`iP800000103jl>H2000000L0n_3V00<0
00000?[`iP3jl>H0>P3jl>H00`000000n_3V0?[`iP0/0?[`iT80GijP00<0000005nNX01OWZ00@01O
WZ0^0?[`iP030000003jl>H0n_3V03/0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`002`3jl>H0
10000000n_3V0?[`iP0000080?[`iP040000003jl>H0n_3V00000080n_3V00@000000?[`iP3jl>H0
00001P3jl>H00`000000n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V02/0n_3V@P1OWZ000`000000
GijP05nNX01005nNX2d0n_3V00<000000?[`iP3jl>H0?03jl>H00`000000n_3V0?[`iP080?[`iP40
oooo000;0?[`iP040000003jl>H0n_3V000000P0n_3V00@000000?[`iP3jl>H000001@3jl>H00`00
0000n_3V0?[`iP040?[`iP<00000?03jl>H00`000000n_3V0?[`iP0Z0?[`iT80GijP00<0000005nN
X01OWZ00@01OWZ0/0?[`iP030000003jl>H0n_3V03X0n_3V1000000:0?[`iP40oooo000;0?[`iP04
0000003jl>H0n_3V000000P0n_3V00@000000?[`iP3jl>H000000`3jl>H2000000L0n_3V00<00000
0?[`iP3jl>H0?@3jl>H00`000000n_3V0?[`iP0Y0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0[
0?[`iP030000003jl>H0n_3V03h0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`002`3jl>H01000
0000n_3V0?[`iP0000080?[`iP040000003jl>H0n_3V000000<0n_3V00<000000?[`iP3jl>H01P3j
l>H00`000000n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V02T0n_3V@P1OWZ000`000000GijP05nN
X01005nNX2/0n_3V00<000000?[`iP3jl>H0?P3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000<
0?[`iP8000002P3jl>H2000000@0n_3V0`0000060?[`iP030000003jl>H0n_3V03h0n_3V00<00000
0?[`iP3jl>H0:03jl>I205nNX0030000001OWZ00GijP0400GijP:P3jl>H00`000000n_3V0?[`iP0o
0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0?`3jl>H00`00
0000n_3V0?[`iP0W0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0Y0?[`iP030000003jl>H0n_3V
0400n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP0o0?[`iP03
0000003jl>H0n_3V02L0n_3V@P1OWZ000`000000GijP05nNX01005nNX2P0n_3V00<000000?[`iP3j
l>H0@@3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V0400n_3V
00<000000?[`iP3jl>H09P3jl>I205nNX0030000001OWZ00GijP0400GijP:03jl>H00`000000n_3V
0?[`iP110?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0@@3j
l>H00`000000n_3V0?[`iP0U0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0W0?[`iP030000003j
l>H0n_3V0480n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP12
0?[`iP030000003jl>H0n_3V02@0n_3V@P1OWZ000`000000GijP05nNX01005nNX2H0n_3V00<00000
0?[`iP3jl>H0@`3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V
0480n_3V00<000000?[`iP3jl>H0903jl>I205nNX0030000001OWZ00GijP0400GijP9P3jl>H00`00
0000n_3V0?[`iP130?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3j
l>H0@`3jl>H00`000000n_3V0?[`iP0S0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0U0?[`iP03
0000003jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H2000004D0n_3V
00<000000?[`iP3jl>H08P3jl>I205nNX0030000001OWZ00GijP0400GijP903jl>H00`000000n_3V
0?[`iP130?[`iP<000002P3jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP140?[`iP030000003j
l>H0n_3V0280n_3V@P1OWZ000`000000GijP05nNX01005nNX2@0n_3V00<000000?[`iP3jl>H0A@3j
l>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V04D0n_3V00<00000
0?[`iP3jl>H08@3jl>I205nNX0030000001OWZ00GijP0400GijP8`3jl>H00`000000n_3V0?[`iP16
0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0AP3jl>H00`00
0000n_3V0?[`iP0P0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0R0?[`iP030000003jl>H0n_3V
04L0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP160?[`iP03
0000003jl>H0n_3V0200n_3V@P1OWZ000`000000GijP05nNX01005nNX240n_3V00<000000?[`iP3j
l>H0B03jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V04L0n_3V
00<000000?[`iP3jl>H07`3jl>I205nNX0030000001OWZ00GijP0400GijP8@3jl>H00`000000n_3V
0?[`iP180?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0B03j
l>H00`000000n_3V0?[`iP0N0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0P0?[`iP030000003j
l>H0n_3V04T0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP19
0?[`iP030000003jl>H0n_3V01d0n_3V@P1OWZ000`000000GijP05nNX01005nNX1l0n_3V00<00000
0?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V
04T0n_3V00<000000?[`iP3jl>H07@3jl>I205nNX0030000001OWZ00GijP0400GijP7`3jl>H00`00
0000n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3j
l>H0BP3jl>H00`000000n_3V0?[`iP0L0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0N0?[`iP03
0000003jl>H0n_3V04/0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H2000004`0n_3V
00<000000?[`iP3jl>H06`3jl>I205nNX0030000001OWZ00GijP0400GijP7@3jl>H00`000000n_3V
0?[`iP1:0?[`iP<000002P3jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1;0?[`iP030000003j
l>H0n_3V01/0n_3V@P1OWZ000`000000GijP05nNX01005nNX1d0n_3V00<000000?[`iP3jl>H0C03j
l>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V04`0n_3V00<00000
0?[`iP3jl>H06P3jl>I205nNX0030000001OWZ00GijP0400GijP703jl>H00`000000n_3V0?[`iP1=
0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0C03jl>H00`00
0000n_3V0?[`iP0J0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0L0?[`iP030000003jl>H0n_3V
04d0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1=0?[`iP03
0000003jl>H0n_3V01T0n_3V@P1OWZ000`000000GijP05nNX01005nNX1/0n_3V00<000000?[`iP3j
l>H0CP3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V04h0n_3V
00<000000?[`iP3jl>H0603jl>I205nNX0030000001OWZ00GijP0400GijP6P3jl>H00`000000n_3V
0?[`iP1?0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0CP3j
l>H00`000000n_3V0?[`iP0H0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0J0?[`iP030000003j
l>H0n_3V04l0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1?
0?[`iP030000003jl>H0n_3V01L0n_3V@P1OWZ000`000000GijP05nNX01005nNX1T0n_3V00<00000
0?[`iP3jl>H0D03jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V
0500n_3V00<000000?[`iP3jl>H05P3jl>I205nNX0030000001OWZ00GijP0400GijP6@3jl>H00`00
0000n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3j
l>H0D03jl>H00`000000n_3V0?[`iP0F0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0H0?[`iP03
0000003jl>H0n_3V0540n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H200000580n_3V
00<000000?[`iP3jl>H05@3jl>I205nNX0030000001OWZ00GijP0400GijP5`3jl>H00`000000n_3V
0?[`iP1@0?[`iP<000002P3jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1A0?[`iP030000003j
l>H0n_3V01D0n_3V@P1OWZ000`000000GijP05nNX01005nNX1L0n_3V00<000000?[`iP3jl>H0DP3j
l>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V0580n_3V00<00000
0?[`iP3jl>H0503jl>I205nNX0030000001OWZ00GijP0400GijP5P3jl>H00`000000n_3V0?[`iP1C
0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0D`3jl>H00`00
0000n_3V0?[`iP0C0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0E0?[`iP030000003jl>H0n_3V
05@0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1C0?[`iP03
0000003jl>H0n_3V01<0n_3V@P1OWZ000`000000GijP05nNX01005nNX1D0n_3V00<000000?[`iP3j
l>H0E03jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V05@0n_3V
00<000000?[`iP3jl>H04P3jl>I205nNX0030000001OWZ00GijP0400GijP503jl>H00`000000n_3V
0?[`iP1E0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0E@3j
l>H00`000000n_3V0?[`iP0A0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0D0?[`iP030000003j
l>H0n_3V05D0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1E
0?[`iP030000003jl>H0n_3V0140n_3V@P1OWZ000`000000GijP05nNX01005nNX1<0n_3V00<00000
0?[`iP3jl>H0EP3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V
05H0n_3V00<000000?[`iP3jl>H0403jl>I205nNX0030000001OWZ00GijP0400GijP4P3jl>H00`00
0000n_3V0?[`iP1G0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3j
l>H0EP3jl>H00`000000n_3V0?[`iP0@0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0B0?[`iP03
0000003jl>H0n_3V05L0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V
0?[`iP1G0?[`iP030000003jl>H0n_3V00l0n_3V@P1OWZ000`000000GijP05nNX01005nNX140n_3V
00<000000?[`iP3jl>H0F03jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP800000F@3j
l>H00`000000n_3V0?[`iP0>0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0A0?[`iP030000003j
l>H0n_3V05H0n_3V0`00000:0?[`iP40oooo000W0?[`iP030000003jl>H0n_3V05P0n_3V00<00000
0?[`iP3jl>H03P3jl>I205nNX0030000001OWZ00GijP0400GijP403jl>H00`000000n_3V0?[`iP1I
0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0F@3jl>H00`00
0000n_3V0?[`iP0=0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0?0?[`iP030000003jl>H0n_3V
05X0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1J0?[`iP03
0000003jl>H0n_3V00`0n_3V@P1OWZ000`000000GijP05nNX01005nNX0l0n_3V00<000000?[`iP3j
l>H0FP3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V05X0n_3V
00<000000?[`iP3jl>H0303jl>I205nNX0030000001OWZ00GijP0400GijP3P3jl>H00`000000n_3V
0?[`iP1K0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0F`3j
l>H00`000000n_3V0?[`iP0;0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ0>0?[`iP030000003j
l>H0n_3V05/0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1K
0?[`iP030000003jl>H0n_3V00/0n_3V@P1OWZ000`000000GijP05nNX01005nNX0d0n_3V00<00000
0?[`iP3jl>H0G03jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V
05`0n_3V00<000000?[`iP3jl>H02P3jl>I205nNX0030000001OWZ00GijP0400GijP3@3jl>H00`00
0000n_3V0?[`iP1L0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool00180n_3V0P0000040?[`iP80
00000`3jl>H5000000D0n_3V00<000000?[`iP3jl>H0G03jl>H00`000000n_3V0?[`iP0:0?[`iT80
GijP00<0000005nNX01OWZ00@01OWZ0<0?[`iP030000003jl>H0n_3V05d0n_3V00<000000?[`iP3j
l>H0203jl>H10?ooo`004@3jl>H010000000n_3V0?[`iP00000:0?[`iP030000003jl>H0n_3V00D0
n_3V00<000000?[`iP3jl>H0G@3jl>H00`000000n_3V0?[`iP090?[`iT80GijP00<0000005nNX01O
WZ00@01OWZ0<0?[`iP030000003jl>H0n_3V05d0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`00
4@3jl>H010000000n_3V0?[`iP00000:0?[`iP030000003jl>H0n_3V00D0n_3V0`00001M0?[`iP03
0000003jl>H0n_3V00T0n_3V@P1OWZ000`000000GijP05nNX01005nNX0/0n_3V00<000000?[`iP3j
l>H0F`3jl>H4000000X0n_3V0@3oool00140n_3V00@000000?[`iP3jl>H000002P3jl>H00`000000
n_3V0?[`iP050?[`iP030000003jl>H0n_3V05h0n_3V00<000000?[`iP3jl>H0203jl>I205nNX003
0000001OWZ00GijP0400GijP2`3jl>H00`000000n_3V0?[`iP1N0?[`iP030000003jl>H0n_3V00P0
n_3V0@3oool00140n_3V00@000000?[`iP3jl>H000002P3jl>H00`000000n_3V0?[`iP050?[`iP03
0000003jl>H0n_3V05l0n_3V00<000000?[`iP3jl>H01`3jl>I205nNX0030000001OWZ00GijP0400
GijP2P3jl>H00`000000n_3V0?[`iP1O0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool00180n_3V
0P00000:0?[`iP8000001`3jl>H00`000000n_3V0?[`iP1O0?[`iP030000003jl>H0n_3V00L0n_3V
@P1OWZ000`000000GijP05nNX01005nNX0X0n_3V00<000000?[`iP3jl>H0G`3jl>H00`000000n_3V
0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V0600n_3V00<000000?[`iP3jl>H01P3j
l>I205nNX0030000001OWZ00GijP0400GijP2@3jl>H00`000000n_3V0?[`iP1P0?[`iP030000003j
l>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0H03jl>H00`000000n_3V0?[`iP06
0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ080?[`iP030000003jl>H0n_3V0640n_3V00<00000
0?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1Q0?[`iP030000003jl>H0n_3V
00D0n_3V@P1OWZ000`000000GijP05nNX01005nNX0P0n_3V00<000000?[`iP3jl>H0H@3jl>H00`00
0000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V0640n_3V00<000000?[`iP3j
l>H01@3jl>I205nNX0030000001OWZ00GijP0400GijP1`3jl>H00`000000n_3V0?[`iP1R0?[`iP03
0000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0HP3jl>H00`000000n_3V
0?[`iP040?[`iT80GijP00<0000005nNX01OWZ00@01OWZ070?[`iP030000003jl>H0n_3V0680n_3V
00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1S0?[`iP030000003j
l>H0n_3V00<0n_3V@P1OWZ000`000000GijP05nNX01005nNX0H0n_3V00<000000?[`iP3jl>H0H`3j
l>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP800000I03jl>H00`000000n_3V0?[`iP03
0?[`iT80GijP00<0000005nNX01OWZ00@01OWZ060?[`iP030000003jl>H0n_3V0640n_3V0`00000:
0?[`iP40oooo000W0?[`iP030000003jl>H0n_3V06@0n_3V00<000000?[`iP3jl>H00P3jl>I205nN
X0030000001OWZ00GijP0400GijP1@3jl>H00`000000n_3V0?[`iP1T0?[`iP030000003jl>H0n_3V
00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0I03jl>H00`000000n_3V0?[`iP020?[`iT80
GijP00<0000005nNX01OWZ00@01OWZ050?[`iP030000003jl>H0n_3V06@0n_3V00<000000?[`iP3j
l>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1U0?[`iP040000003jl>H0n_3V0?[`iT80
GijP00<0000005nNX01OWZ00@01OWZ040?[`iP030000003jl>H0n_3V06D0n_3V00<000000?[`iP3j
l>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1U0?[`iP040000003jl>H0n_3V0?[`iT80
GijP00<0000005nNX01OWZ00@01OWZ040?[`iP030000003jl>H0n_3V06D0n_3V00<000000?[`iP3j
l>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1V0?[`iP030000003jl>H0n_3V0480GijP
00<0000005nNX01OWZ00@01OWZ030?[`iP030000003jl>H0n_3V06H0n_3V00<000000?[`iP3jl>H0
203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1V0?[`iP030000003jl>H0n_3V0480GijP00<0
000005nNX01OWZ00@01OWZ030?[`iP030000003jl>H0n_3V06H0n_3V00<000000?[`iP3jl>H0203j
l>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1W0?[`iP030000003jl>H0GijP0440GijP00<00000
05nNX01OWZ00@01OWZ020?[`iP030000003jl>H0n_3V06L0n_3V00<000000?[`iP3jl>H0203jl>H1
0?ooo`009`3jl>H00`000000n_3V0?[`iP1X0?[`iP030000001OWZ00GijP0400GijP00<0000005nN
X01OWZ00@01OWZ000`3jl>H000000?[`iP1Y0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0
n_3V00<000000?[`iP3jl>H0J03jl>H00`000000GijP05nNX01005nNX0030000001OWZ00GijP0400
GijP00<0n_3V0000003jl>H0J@3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP800000
JP3jl>H00`000000GijP05nNX00o05nNX0030000001OWZ00GijP0400GijP00<000000?[`iP3jl>H0
I`3jl>H3000000X0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0J@3jl>H00`000000GijP05nN
X00o05nNX0030000001OWZ00GijP0400GijP00<000000?[`iP3jl>H0J@3jl>H00`000000n_3V0?[`
iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V06X0n_3V00<0000005nNX01OWZ00?P1OWZ00
0`000000GijP05nNX00o05nNX0030000003jl>H0n_3V06X0n_3V00<000000?[`iP3jl>H0203jl>H1
0?ooo`009`3jl>H00`000000n_3V0?[`iP1Z0?[`iP030000001OWZ00GijP03h0GijP00<0000005nN
X01OWZ00?`1OWZ000`000000n_3V0?[`iP1Z0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0
n_3V00<000000?[`iP3jl>H0J`3jl>H00`000000GijP05nNX00m05nNX0030000001OWZ00GijP03h0
GijP00<000000?[`iP3jl>H0J`3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000
003jl>H0n_3V06/0n_3V00<0000005nNX01OWZ00?@1OWZ000`000000GijP05nNX00n05nNX0030000
003jl>H0n_3V06/0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`
iP1/0?[`iP030000001OWZ00GijP03`0GijP00<0000005nNX01OWZ00?@1OWZ000`000000n_3V0?[`
iP1/0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0K03jl>H0
0`000000GijP05nNX00l05nNX0030000001OWZ00GijP03d0GijP00<000000?[`iP3jl>H0K03jl>H0
0`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V06d0n_3V00<0000005nN
X01OWZ00>`1OWZ000`000000GijP05nNX00l05nNX0030000003jl>H0n_3V06d0n_3V00<000000?[`
iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1]0?[`iP030000001OWZ00GijP03/0
GijP00<0000005nNX01OWZ00?01OWZ000`000000n_3V0?[`iP1]0?[`iP030000003jl>H0n_3V00P0
n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0KP3jl>H00`000000GijP05nNX00j05nNX0030000
001OWZ00GijP03/0GijP00<000000?[`iP3jl>H0KP3jl>H00`000000n_3V0?[`iP080?[`iP40oooo
000W0?[`iP800000K`3jl>H00`000000GijP05nNX00j05nNX0030000001OWZ00GijP03X0GijP00<0
n_3V0000003jl>H0K@3jl>H3000000X0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0KP3jl>H0
0`1OWZ00000005nNX00j05nNX0030000001OWZ00GijP03X0GijP00<000000?[`iP3jl>H0K`3jl>H0
0`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V06l0n_3V00<0000005nN
X01OWZ00>@1OWZ000`000000GijP05nNX00j05nNX0030000003jl>H0n_3V06l0n_3V00<000000?[`
iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1`0?[`iP030000001OWZ00GijP03P0
GijP00<0000005nNX01OWZ00>@1OWZ000`000000n_3V0?[`iP1`0?[`iP030000003jl>H0n_3V00P0
n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0L03jl>H00`000000GijP05nNX00h05nNX0030000
001OWZ00GijP03T0GijP00<000000?[`iP3jl>H0L03jl>H00`000000n_3V0?[`iP080?[`iP40oooo
000W0?[`iP030000003jl>H0n_3V0740n_3V00<0000005nNX01OWZ00=`1OWZ000`000000GijP05nN
X00h05nNX0030000003jl>H0n_3V0740n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H0
0`000000n_3V0?[`iP1a0?[`iP030000001OWZ00GijP03L0GijP00<0000005nNX01OWZ00>01OWZ00
0`000000n_3V0?[`iP1a0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`
iP3jl>H0LP3jl>H00`000000GijP05nNX00f05nNX0030000001OWZ00GijP03L0GijP00<000000?[`
iP3jl>H0LP3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V0780
n_3V00<0000005nNX01OWZ00=P1OWZ000`000000GijP05nNX00g05nNX0030000003jl>H0n_3V0780
n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1c0?[`iP030000
001OWZ00GijP03D0GijP00<0000005nNX01OWZ00=P1OWZ000`000000n_3V0?[`iP1c0?[`iP030000
003jl>H0n_3V00P0n_3V0@3oool002L0n_3V0P00001d0?[`iP030000001OWZ00GijP03D0GijP00<0
000005nNX01OWZ00=P1OWZ000`000000n_3V0?[`iP1a0?[`iP<000002P3jl>H10?ooo`009`3jl>H0
0`000000n_3V0?[`iP1d0?[`iP030000001OWZ00GijP03@0GijP00<0000005nNX01OWZ00=@1OWZ00
0`000000n_3V0?[`iP1d0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`
iP3jl>H0M@3jl>H00`000000GijP05nNX00c05nNX0030000001OWZ00GijP03@0GijP00<000000?[`
iP3jl>H0M@3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V07D0
n_3V00<0000005nNX01OWZ00<`1OWZ000`000000GijP05nNX00d05nNX0030000003jl>H0n_3V07D0
n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1f0?[`iP030000
001OWZ00GijP0380GijP00<0000005nNX01OWZ00<`1OWZ000`000000n_3V0?[`iP1f0?[`iP030000
003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0MP3jl>H00`000000GijP05nN
X00b05nNX0030000001OWZ00GijP03<0GijP00<000000?[`iP3jl>H0MP3jl>H00`000000n_3V0?[`
iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V07L0n_3V00<0000005nNX01OWZ00<@1OWZ00
0`000000GijP05nNX00b05nNX0030000003jl>H0n_3V07L0n_3V00<000000?[`iP3jl>H0203jl>H1
0?ooo`009`3jl>H00`000000n_3V0?[`iP1g0?[`iP030000001OWZ00GijP0340GijP00<0000005nN
X01OWZ00<@1OWZ000`000000n_3V0?[`iP1h0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool000`0
n_3V0P0000040?[`iP8000000`3jl>H500000080n_3V0P0000070?[`iP030000003jl>H0n_3V07P0
n_3V00<0000005nNX01OWZ00<01OWZ000`000000GijP05nNX00a05nNX0030000003jl>H0n_3V07P0
n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`002`3jl>H010000000n_3V0?[`iP00000:0?[`iP05
0000003jl>H0n_3V0?[`iP0000000P3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V
07P0n_3V00<0000005nNX01OWZ00<01OWZ000`000000GijP05nNX00`05nNX0030000003jl>H0n_3V
07T0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`002`3jl>H010000000n_3V0?[`iP00000:0?[`
iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0103jl>H3000007T0n_3V00<0000005nN
X01OWZ00;`1OWZ000`000000GijP05nNX00_05nNX0030?[`iP000000n_3V07L0n_3V1000000:0?[`
iP40oooo000;0?[`iP040000003jl>H0n_3V000000X0n_3V00<000000?[`iP3jl>H00P3jl>H20000
00L0n_3V00<000000?[`iP3jl>H0N@3jl>H00`1OWZ00000005nNX00_05nNX0030000001OWZ00GijP
02l0GijP00<000000?[`iP3jl>H0NP3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000;0?[`iP04
0000003jl>H0n_3V000000X0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP060?[`
iP030000003jl>H0n_3V07X0n_3V00<0000005nNX01OWZ00;P1OWZ000`000000GijP05nNX00^05nN
X0030000003jl>H0n_3V07/0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`00303jl>H2000000X0
n_3V0P0000040?[`iP<000001P3jl>H00`000000n_3V0?[`iP1k0?[`iP030000001OWZ00GijP02d0
GijP00<0000005nNX01OWZ00;P1OWZ000`000000n_3V0?[`iP1k0?[`iP030000003jl>H0n_3V00P0
n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0N`3jl>H00`000000GijP05nNX00]05nNX0030000
001OWZ00GijP02d0GijP00<000000?[`iP3jl>H0O03jl>H00`000000n_3V0?[`iP080?[`iP40oooo
000W0?[`iP030000003jl>H0n_3V07`0n_3V00<0000005nNX01OWZ00;01OWZ000`000000GijP05nN
X00/05nNX0030000003jl>H0n_3V07d0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H0
0`000000n_3V0?[`iP1l0?[`iP030000001OWZ00GijP02`0GijP00<0000005nNX01OWZ00;01OWZ00
0`000000n_3V0?[`iP1m0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`
iP3jl>H0O@3jl>H00`000000GijP05nNX00[05nNX0030000001OWZ00GijP02/0GijP00<000000?[`
iP3jl>H0OP3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V07h0
n_3V00<0000005nNX01OWZ00:P1OWZ000`000000GijP05nNX00[05nNX0030000003jl>H0n_3V07h0
n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP1n0?[`iP030000
001OWZ00GijP02X0GijP00<0000005nNX01OWZ00:P1OWZ000`000000n_3V0?[`iP1o0?[`iP030000
003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0O`3jl>H00`000000GijP05nN
X00Y05nNX0030000001OWZ00GijP02T0GijP00<000000?[`iP3jl>H0P03jl>H00`000000n_3V0?[`
iP080?[`iP40oooo000W0?[`iP800000P03jl>H00`000000GijP05nNX00Y05nNX0030000001OWZ00
GijP02T0GijP00<000000?[`iP3jl>H0OP3jl>H3000000X0n_3V0@3oool002L0n_3V00<000000?[`
iP3jl>H0P03jl>H00`000000GijP05nNX00X05nNX0030000001OWZ00GijP02P0GijP00<000000?[`
iP3jl>H0P@3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V0800
n_3V00<0000005nNX01OWZ00:01OWZ000`000000GijP05nNX00X05nNX0030000003jl>H0n_3V0840
n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP210?[`iP030000
001OWZ00GijP02L0GijP00<0000005nNX01OWZ009`1OWZ000`000000n_3V0?[`iP220?[`iP030000
003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0P@3jl>H00`000000GijP05nN
X00W05nNX0030000001OWZ00GijP02H0GijP00<000000?[`iP3jl>H0P`3jl>H00`000000n_3V0?[`
iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V0880n_3V00<0000005nNX01OWZ009P1OWZ00
0`000000GijP05nNX00V05nNX0030000003jl>H0n_3V08<0n_3V00<000000?[`iP3jl>H0203jl>H1
0?ooo`009`3jl>H00`000000n_3V0?[`iP230?[`iP030000001OWZ00GijP02D0GijP00<0000005nN
X01OWZ009@1OWZ000`000000n_3V0?[`iP240?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0
n_3V00<000000?[`iP3jl>H0P`3jl>H00`000000GijP05nNX00U05nNX0030000001OWZ00GijP02@0
GijP00<000000?[`iP3jl>H0Q@3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000
003jl>H0n_3V08@0n_3V00<0000005nNX01OWZ00901OWZ000`000000GijP05nNX00S05nNX0030000
003jl>H0n_3V08H0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`
iP250?[`iP030000001OWZ00GijP02<0GijP00<0000005nNX01OWZ008`1OWZ000`000000n_3V0?[`
iP260?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V0P0000260?[`iP030000001OWZ00
GijP02<0GijP00<0000005nNX01OWZ008P1OWZ000`000000n_3V0?[`iP250?[`iP<000002P3jl>H1
0?ooo`009`3jl>H00`000000n_3V0?[`iP260?[`iP030000001OWZ00GijP0280GijP00<0000005nN
X01OWZ008@1OWZ000`000000n_3V0?[`iP280?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0
n_3V00<000000?[`iP3jl>H0Q`3jl>H00`000000GijP05nNX00Q05nNX0030000001OWZ00GijP0240
GijP00<000000?[`iP3jl>H0R03jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000
003jl>H0n_3V08P0n_3V00<0000005nNX01OWZ00801OWZ000`000000GijP05nNX00P05nNX0030000
003jl>H0n_3V08T0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`
iP280?[`iP030000001OWZ00GijP0200GijP00<0000005nNX01OWZ007`1OWZ000`000000n_3V0?[`
iP2:0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0R@3jl>H0
0`000000GijP05nNX00O05nNX0030000001OWZ00GijP01l0GijP00<000000?[`iP3jl>H0RP3jl>H0
0`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V08X0n_3V00<0000005nN
X01OWZ007P1OWZ000`000000GijP05nNX00N05nNX0030000003jl>H0n_3V08/0n_3V00<000000?[`
iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP2;0?[`iP030000001OWZ00GijP01d0
GijP00<0000005nNX01OWZ007@1OWZ000`000000n_3V0?[`iP2<0?[`iP030000003jl>H0n_3V00P0
n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0R`3jl>H00`000000GijP05nNX00M05nNX0030000
001OWZ00GijP01`0GijP00<000000?[`iP3jl>H0S@3jl>H00`000000n_3V0?[`iP080?[`iP40oooo
000W0?[`iP030000003jl>H0n_3V08`0n_3V00<0000005nNX01OWZ00701OWZ000`000000GijP05nN
X00L05nNX0030000003jl>H0n_3V08d0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H2
000008h0n_3V00<0000005nNX01OWZ006`1OWZ000`000000GijP05nNX00K05nNX0030000003jl>H0
n_3V08`0n_3V0`00000:0?[`iP40oooo000W0?[`iP030000003jl>H0n_3V08h0n_3V00<0000005nN
X01OWZ006P1OWZ000`000000GijP05nNX00J05nNX0030000003jl>H0n_3V08l0n_3V00<000000?[`
iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP2>0?[`iP030000003jl>H0GijP01X0
GijP00<0000005nNX01OWZ006P1OWZ000`000000n_3V0?[`iP2?0?[`iP030000003jl>H0n_3V00P0
n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0S`3jl>H00`000000GijP05nNX00I05nNX0030000
001OWZ00GijP01T0GijP00<000000?[`iP3jl>H0T03jl>H00`000000n_3V0?[`iP080?[`iP40oooo
000W0?[`iP030000003jl>H0n_3V0900n_3V00<0000005nNX01OWZ00601OWZ000`000000GijP05nN
X00H05nNX0030000003jl>H0n_3V0940n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H0
0`000000n_3V0?[`iP2A0?[`iP030000001OWZ00GijP01L0GijP00<0000005nNX01OWZ005`1OWZ00
0`000000n_3V0?[`iP2B0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`
iP3jl>H0TP3jl>H00`000000GijP05nNX00F05nNX0030000001OWZ00GijP01H0GijP00<000000?[`
iP3jl>H0T`3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V09<0
n_3V00<0000005nNX01OWZ005@1OWZ000`000000GijP05nNX00E05nNX0030000003jl>H0n_3V09@0
n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP2D0?[`iP030000
001OWZ00GijP01@0GijP00<0000005nNX01OWZ005@1OWZ000`000000n_3V0?[`iP2D0?[`iP030000
003jl>H0n_3V00P0n_3V0@3oool002L0n_3V00<000000?[`iP3jl>H0U@3jl>H00`000000GijP05nN
X00C05nNX0030000001OWZ00GijP01@0GijP00<000000?[`iP3jl>H0U@3jl>H00`000000n_3V0?[`
iP080?[`iP40oooo000W0?[`iP800000U`3jl>H00`000000GijP05nNX00B05nNX0030000001OWZ00
GijP01<0GijP00<000000?[`iP3jl>H0U03jl>H3000000X0n_3V0@3oool002L0n_3V00<000000?[`
iP3jl>H0U`3jl>H00`000000GijP05nNX00A05nNX0030000001OWZ00GijP0180GijP00<000000?[`
iP3jl>H0U`3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000003jl>H0n_3V09P0
n_3V00<0000005nNX01OWZ00401OWZ000`000000GijP05nNX00A05nNX0030000003jl>H0n_3V09P0
n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP2I0?[`iP030000
001OWZ00GijP00l0GijP00<0000005nNX01OWZ003`1OWZ02000009/0n_3V00<000000?[`iP3jl>H0
203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP2J0?[`iP8000003`1OWZ000`000000GijP05nN
X00>05nNX0030000003jl>H0n_3V09/0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H0
0`000000n_3V0?[`iP2L0?[`iP030000001OWZ00GijP00`0GijP00<0000005nNX01OWZ00301OWZ02
000009h0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP2M0?[`
iP030000001OWZ00GijP00/0GijP00<0000005nNX01OWZ002P1OWZ0200000:00n_3V00<000000?[`
iP3jl>H0203jl>H10?ooo`009`3jl>H00`000000n_3V0?[`iP2N0?[`iP8000002`1OWZ000`000000
GijP05nNX00805nNX0800000XP3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W0?[`iP030000
003jl>H0n_3V0:00n_3V0`00000805nNX0030000001OWZ00GijP00L0GijP00<000000?[`iP3jl>H0
XP3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000B0?[`iP800000103jl>H2000000<0n_3V1000
00060?[`iP030000003jl>H0n_3V0:<0n_3V0P00000605nNX0030000001OWZ00GijP00@0GijP0`00
002U0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool00140n_3V00@000000?[`iP3jl>H00000203j
l>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V0:D0n_3V3@00002X0?[`iP030000003j
l>H0n_3V00P0n_3V0@3oool00140n_3V00@000000?[`iP3jl>H000002@3jl>H00`000000n_3V0?[`
iP060?[`iP<00000Z`3jl>H00`000000n_3V0?[`iP2Y0?[`iP@000002P3jl>H10?ooo`004@3jl>H0
10000000n_3V0?[`iP00000:0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0Z`3j
l>H00`000000n_3V0?[`iP2/0?[`iP030000003jl>H0n_3V00P0n_3V0@3oool00140n_3V00@00000
0?[`iP3jl>H00000203jl>H010000000n_3V0?[`iP0000060?[`iP030000003jl>H0n_3V00D0n_3V
00<000000?[`iP3jl>H0?`3jl>H00`000000n_3V0?[`iP100?[`iP030000003jl>H0n_3V01h0n_3V
00<000000?[`iP3jl>H07P3jl>H00`000000n_3V0?[`iP100?[`iP030000003jl>H0n_3V03l0n_3V
00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000B0?[`iP8000002P3j
l>H2000000L0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003j
l>H0n_3V00d0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003j
l>H0n_3V00h0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003j
l>H0n_3V00h0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003j
l>H0n_3V00h0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003j
l>H0n_3V00h0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003j
l>H0n_3V00d0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003j
l>H0n_3V00d0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP080?[`iP40oooo000W
0?[`i_l00000G`00000:0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00
o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`
iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00W03jl>H3000000030?[`iP00
0000n_3V0080n_3V0P0000030?[`iP@0000000P0n_3V000000000000n_3V0000003jl>H000000?[`
iPD0000000@0n_3V0000000000000000203jl>H4000000@0n_3V0`0000020?[`iP<00000103jl>H2
000000<0n_3V100000030?[`iP<0000000<0n_3V0000000000000P0000040?[`iP@000000P3jl>H2
000000@0n_3V0`0000030?[`iP8000000P3jl>H200000080n_3V0P0000210?[`iP40oooo002M0?[`
iP040000003jl>H0000000000080n_3V00@000000?[`iP3jl>H000000`3jl>H00`000000n_3V0?[`
iP020?[`iP060000003jl>H000000?[`iP000000n_3V100000030?[`iP030000003jl>H0n_3V00P0
n_3V00@000000?[`iP3jl>H00000103jl>H00`000000n_3V0?[`iP040?[`iP040000003jl>H0n_3V
00000080n_3V00D000000?[`iP3jl>H0n_3V000000060?[`iP050000003jl>H0n_3V0?[`iP000000
0P3jl>H010000000n_3V0?[`iP0000020?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`
iP3jl>H00P3jl>H01@000000n_3V0?[`iP3jl>H000000080n_3V00@000000?[`iP3jl>H000000P3j
l>H00`000000n_3V0?[`iP200?[`iP40oooo002M0?[`iP040000003jl>H0000000000080n_3V00@0
00000?[`iP3jl>H000000`3jl>H00`000000n_3V0?[`iP020?[`iP050000003jl>H000000?[`iP00
0000103jl>H01@000000n_3V0?[`iP3jl>H0000000X0n_3V00@000000?[`iP3jl>H00000103jl>H0
10000000n_3V0?[`iP3jl>H3000000<0n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`
iP040?[`iP050000003jl>H0n_3V0?[`iP0000000P3jl>H010000000n_3V0?[`iP0000020?[`iP04
0000003jl>H0n_3V000000L0n_3V00D000000?[`iP3jl>H0n_3V000000020?[`iP040000003jl>H0
n_3V00000080n_3V00<000000?[`iP3jl>H0P03jl>H10?ooo`00W@3jl>H2000000030?[`iP000000
n_3V0080n_3V0P0000030?[`iP@0000000H0n_3V00000000000000000?[`iP0000030?[`iP<00000
0`3jl>H00`000000n_3V0?[`iP080?[`iP040000003jl>H0n_3V000000<0n_3V0P0000030?[`iP@0
000000<0n_3V0000000000000`0000020?[`iP@000000`3jl>H2000000<0n_3V0`0000020?[`iP80
000000@0n_3V000000000000n_3V1@0000030?[`iP800000103jl>H200000080n_3V100000230?[`
iP40oooo002M0?[`iP80000000<0n_3V0000003jl>H06P3jl>H00`000000n_3V0?[`iP080?[`iP04
0000003jl>H0n_3V000000h0n_3V00<000000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP090?[`
iP030000003jl>H0n_3V09D0n_3V0@3oool009`0n_3V0P000000103jl>H0000000000000000I0?[`
iP8000002@3jl>H4000000D0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP020000
01<0n_3V00<000000?[`iP3jl>H0S@3jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V
0@3oool00?l0n_3VT03jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {-0.000830538, -5.00002*^-06, \
0.00251043, 0.00406196}, {{0.3125, 398.625}, {246.188, 0}} -> {-1.42548, \
-0.0179625, 0.0300836, 0.000970951}, {{0.3125, 398.625}, {246.188, 0}} -> \
{-1.42548, -0.0179625, 0.0300836, 0.000970951}}]
}, Open  ]],

Cell[BoxData[
    \(Clear[f]\)], "Input",
  CellLabel->"In[5]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->{},
WindowSize->{494, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 57, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1836, 56, 450, 17, 50, "Usage",
      CellTags->"Function?"],
    Cell[2289, 75, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 58336, 1631}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 57, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1836, 56, 450, 17, 50, "Usage",
  CellTags->"Function?"],
Cell[2289, 75, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2386, 80, 163, 3, 58, "MathCaption"],
Cell[2552, 85, 138, 3, 58, "MathCaption"],
Cell[2693, 90, 212, 6, 58, "MathCaption"],
Cell[2908, 98, 228, 6, 58, "MathCaption"],
Cell[3139, 106, 164, 6, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3328, 116, 34, 0, 39, "ExampleSection"],
Cell[3365, 118, 183, 3, 49, "Input"],
Cell[3551, 123, 145, 3, 42, "Text"],

Cell[CellGroupData[{
Cell[3721, 130, 99, 2, 29, "Input"],
Cell[3823, 134, 140, 3, 53, "Output"]
}, Open  ]],
Cell[3978, 140, 325, 9, 59, "Text"],

Cell[CellGroupData[{
Cell[4328, 153, 643, 11, 229, "Input"],
Cell[4974, 166, 52603, 1439, 254, 13544, 953, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[57592, 1608, 65, 2, 29, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

