(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5314,        166]*)
(*NotebookOutlinePosition[      6210,        198]*)
(*  CellTagsIndexPosition[      6136,        192]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["FineGrainLines", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["FineGrainLines",
            "MR"], 
          StyleBox["[",
            "MR"], \(distance, \ grain, \ distfunc\), "]"}], "[", "expr", 
        "]"}]]],
  " will fine grain the points defining all Lines in expr using \
FineGrainPoints."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "The distance is calculated by applying the optional distfunc to adjacent \
points. The default distfunc is ",
  Cell[BoxData[
      \(\((\@\(\((#2 - #1)\) . \((#2 - #1)\)\) &)\)\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "At each iteration ",
  Cell[BoxData[
      \(grain - 1\)]],
  " points are inserted."
}], "MathCaption"],

Cell["\<\
It may be necessary to fine grain points in a Line to obtain smooth \
transformations with DrawingTransform. Think of the points as the \"hinges\" \
where the Line can be bent.\
\>", "MathCaption"],

Cell["FineGrainLines will also work on 3D Lines.", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawingTransform",
    ButtonData:>{"DrawingTransform"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FineGrainPolygons",
    ButtonData:>{"FineGrainPolygons"},
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["FineGrainPoints",
    ButtonData:>{"FineGrainPoints"},
    ButtonStyle->"AddOnsLink"],
  " ."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
This draws a rectangle in the \[Theta]-r plane. \
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Line[{{\[Pi]/4, 1}, {\[Pi]/2, 
                1}, {\[Pi]/2, 2}, {\[Pi]/4, 2}, {\[Pi]/4, 
                1}}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {\[Theta], 
            r}, \[IndentingNewLine]PlotRange \[Rule] {{0.5, 2}, {0, 
              3}}, \[IndentingNewLine]Background \[Rule] Linen];\)\)], "Input",\

  CellLabel->"In[2]:="],

Cell["\<\
We will transform this to the x-y plane using DrawingTransform. But this is \
unsatisfactory because the long straight portions of the Line do not bend.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Line[{{\[Pi]/4, 1}, {\[Pi]/2, 
                  1}, {\[Pi]/2, 2}, {\[Pi]/4, 2}, {\[Pi]/4, 1}}] /. 
            DrawingTransform[#2\ Cos[#1] &, #2\ Sin[#1] &]}, \
\[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            y}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]PlotRange \[Rule] {0, 
            2.1}, \[IndentingNewLine]Background \[Rule] Linen];\)\)], "Input",\

  CellLabel->"In[3]:="],

Cell["The solution is to fine grain the Lines before transforming.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{\((Line[{{\[Pi]/4, 1}, {\[Pi]/2, 
                      1}, {\[Pi]/2, 2}, {\[Pi]/4, 2}, {\[Pi]/4, 1}}] // 
                FineGrainLines[0.1, 4])\) /. 
            DrawingTransform[#2\ Cos[#1] &, #2\ Sin[#1] &]}, \
\[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            y}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]PlotRange \[Rule] {0, 
            2.1}, \[IndentingNewLine]Background \[Rule] Linen];\)\)], "Input",\

  CellLabel->"In[4]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{538, 730},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 61, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1840, 56, 385, 13, 50, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5965, 183}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 61, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1840, 56, 385, 13, 50, "Usage",
  CellTags->"Function?"],
Cell[2228, 71, 226, 6, 59, "MathCaption"],
Cell[2457, 79, 123, 5, 41, "MathCaption"],
Cell[2583, 86, 207, 4, 58, "MathCaption"],
Cell[2793, 92, 65, 0, 41, "MathCaption"],
Cell[2861, 94, 380, 14, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3266, 112, 33, 0, 39, "ExampleSection"],
Cell[3302, 114, 97, 2, 29, "Input"],
Cell[3402, 118, 72, 2, 25, "Text"],
Cell[3477, 122, 436, 8, 129, "Input"],
Cell[3916, 132, 176, 3, 42, "Text"],
Cell[4095, 137, 528, 10, 169, "Input"],
Cell[4626, 149, 76, 0, 25, "Text"],
Cell[4705, 151, 581, 11, 189, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

