(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4132,        142]*)
(*NotebookOutlinePosition[      5028,        174]*)
(*  CellTagsIndexPosition[      4954,        168]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["FineGrainPoints", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["FineGrainPoints",
            "MR"], 
          StyleBox["[",
            "MR"], \(distance, \ grain, \ distfunc\), "]"}], "[", "pointlist",
         "]"}]]],
  " will linearly interpolate a set of points into a list of points so that \
the separation between adjacent points is not greater than distance."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "The distance is calculated by applying the optional distfunc to adjacent \
points. The default distfunc is ",
  Cell[BoxData[
      \(\((\@\(\((#2 - #1)\) . \((#2 - #1)\)\) &)\)\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "At each iteration ",
  Cell[BoxData[
      \(grain - 1\)]],
  " points are inserted."
}], "MathCaption"],

Cell["\<\
It may be necessary to fine grain points in a Line or Polygon to obtain \
smooth transformations with DrawingTransform. Think of the points as the \
\"hinges\" where the Line can be bent.\
\>", "MathCaption"],

Cell["\<\
It will be generally simpler to use FineGrainLines or FineGrainPolygons which \
in turn use this routine.\
\>", "MathCaption"],

Cell["FineGrainPoints will work on a list of 3D points.", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawingTransform",
    ButtonData:>{"DrawingTransform"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FineGrainPolygons",
    ButtonData:>{"FineGrainPolygons"},
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["FineGrainLines",
    ButtonData:>{"FineGrainLines"},
    ButtonStyle->"AddOnsLink"],
  " ."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Here is a list of two dimensional points is fine grained so that their \
separation distance does not exceed 0.2.\
\>", "Text"],

Cell[BoxData[{
    \({{0, 0}, {1, 0}, {1, 1}}\), "\[IndentingNewLine]", 
    \(% // FineGrainPoints[0.2, 2]\)}], "Input",
  CellLabel->"In[2]:="],

Cell["This does the same for a list of 3D points.", "Text"],

Cell[BoxData[{
    \({{0, 0, 0}, {1, 1, 1}}\), "\n", 
    \(% // FineGrainPoints[0.2, 2]\)}], "Input",
  CellLabel->"In[4]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{538, 730},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 62, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1841, 56, 455, 13, 67, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 4783, 159}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 62, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1841, 56, 455, 13, 67, "Usage",
  CellTags->"Function?"],
Cell[2299, 71, 226, 6, 59, "MathCaption"],
Cell[2528, 79, 123, 5, 41, "MathCaption"],
Cell[2654, 86, 218, 4, 75, "MathCaption"],
Cell[2875, 92, 136, 3, 58, "MathCaption"],
Cell[3014, 97, 72, 0, 41, "MathCaption"],
Cell[3089, 99, 378, 14, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3492, 117, 33, 0, 39, "ExampleSection"],
Cell[3528, 119, 97, 2, 29, "Input"],
Cell[3628, 123, 137, 3, 42, "Text"],
Cell[3768, 128, 145, 3, 49, "Input"],
Cell[3916, 133, 59, 0, 25, "Text"],
Cell[3978, 135, 126, 3, 49, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

