(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5776,        183]*)
(*NotebookOutlinePosition[      6672,        215]*)
(*  CellTagsIndexPosition[      6598,        209]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["FineGrainPolygons", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["FineGrainPolygons",
            "MR"], 
          StyleBox["[",
            "MR"], \(distance, \ grain, \ distfunc\), "]"}], "[", "expr", 
        "]"}]]],
  " will fine grain the points defining all Polygons in expr using \
FineGrainPoints."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "The distance is calculated by applying the optional distfunc to adjacent \
points. The default distfunc is ",
  Cell[BoxData[
      \(\((\@\(\((#2 - #1)\) . \((#2 - #1)\)\) &)\)\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "At each iteration ",
  Cell[BoxData[
      \(grain - 1\)]],
  " points are inserted."
}], "MathCaption"],

Cell["\<\
If the last point defining the polygon is not the same as the first point, \
the first point is appended to the polygon point list before fine graining.\
\>", "MathCaption"],

Cell["\<\
It may be necessary to fine grain points in a Polygon to obtain smooth \
transformations with DrawingTransform. Think of the points as the \"hinges\" \
where the Line defining the Polygon can be bent.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawingTransform",
    ButtonData:>{"DrawingTransform"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FineGrainPoints",
    ButtonData:>{"FineGrainPoints"},
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["FineGrainLines",
    ButtonData:>{"FineGrainLines"},
    ButtonStyle->"AddOnsLink"],
  " ."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Suppose we want to make a contour plot of the following polar function.\
\>", "Text"],

Cell[BoxData[
    \(f[r_, \[Theta]_] := \((2 - 3  r + r\^2)\) Cos[2  \[Theta]]\)], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
ContourPlot always makes rectangular plots. We could make a rectangular plot \
in the r-\[Theta] plane and then transform it to the x-y plane.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{ContourDraw[
            f[r, \[Theta]], {r, 0, 1.5}, {\[Theta], 0, 2  \[Pi]}, 
            ColorFunction \[Rule] Hue, 
            PlotPoints \[Rule] 50]}, \[IndentingNewLine]AspectRatio \[Rule] 
          2];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
Using DrawingTransform, we can obtain a circular plot in the x-y plane. \
However, the Polygon regions that meet the edge have long straight lines. In \
the following plot, the result is that the zero (light blue) region is lost \
and the contour edges which meet the outer edge of the circular plot are not \
circular.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{ContourDraw[
              f[r, \[Theta]], {r, 0, 1.5}, {\[Theta], 0, 2  \[Pi]}, 
              ColorFunction \[Rule] Hue, PlotPoints \[Rule] 50] /. 
            DrawingTransform[#1\ Cos[#2] &, #1 
                   Sin[#2] &], \[IndentingNewLine]Circle[{0, 0}, 
            1.5]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
By fine graining the Polygons, before using DrawingTransform, we obtain a \
proper rendering. \
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{\((ContourDraw[
                  f[r, \[Theta]], {r, 0, 1.5}, {\[Theta], 0, 2  \[Pi]}, 
                  ColorFunction \[Rule] Hue, PlotPoints \[Rule] 50] // 
                FineGrainPolygons[0.3, 4])\) /. 
            DrawingTransform[#1\ Cos[#2] &, #1 
                   Sin[#2] &], \[IndentingNewLine]Circle[{0, 0}, 
            1.5]}, \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(Clear[f]\)], "Input",
  CellLabel->"In[6]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{544, 730},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 64, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1843, 56, 391, 13, 50, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6427, 200}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 64, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1843, 56, 391, 13, 50, "Usage",
  CellTags->"Function?"],
Cell[2237, 71, 226, 6, 59, "MathCaption"],
Cell[2466, 79, 123, 5, 41, "MathCaption"],
Cell[2592, 86, 183, 3, 58, "MathCaption"],
Cell[2778, 91, 231, 4, 75, "MathCaption"],
Cell[3012, 97, 374, 14, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3411, 115, 33, 0, 39, "ExampleSection"],
Cell[3447, 117, 97, 2, 29, "Input"],
Cell[3547, 121, 95, 2, 25, "Text"],
Cell[3645, 125, 115, 2, 30, "Input"],
Cell[3763, 129, 166, 3, 42, "Text"],
Cell[3932, 134, 298, 6, 89, "Input"],
Cell[4233, 142, 343, 6, 59, "Text"],
Cell[4579, 150, 432, 8, 129, "Input"],
Cell[5014, 160, 118, 3, 25, "Text"],
Cell[5135, 165, 545, 10, 149, "Input"],
Cell[5683, 177, 65, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

