(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1136651,      36333]*)
(*NotebookOutlinePosition[   1137588,      36366]*)
(*  CellTagsIndexPosition[   1137509,      36360]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["HollisGrid", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["HollisGrid",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\({p1, p2,  ... , pn}, \ opts ... \),
          "TI"], 
        StyleBox["]",
          "TI"]}]]],
  " creates a grid over the polygon with vertices p1, p2,..., pn.\n\
\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["HollisGrid",
          "MR"], 
        StyleBox["[",
          "MR"], 
        RowBox[{
          RowBox[{
            StyleBox["{",
              "MR"], 
            StyleBox[\(\[Gamma]1[t], \[Gamma]2[t]\),
              "TI"], 
            StyleBox["}",
              "TI"]}], 
          StyleBox[",",
            "TI"], 
          StyleBox[\({t, tmin, tmax}\),
            "TI"], 
          StyleBox[",",
            "TI"], 
          StyleBox[" ",
            "TI"], 
          StyleBox[\(opts ... \),
            "TI"]}], 
        StyleBox["]",
          "TI"]}]]],
  " creates a grid over the region whose boundary is parameterized by ",
  Cell[BoxData[
      \(\[Gamma]\)]],
  "."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  Cell[BoxData[
      \(HollisGrid\)]],
  " is a function that generates a grid on a ",
  StyleBox["star-like",
    FontSlant->"Italic"],
  " region in the plane. (\[OpenCurlyDoubleQuote]Star-like\
\[CloseCurlyDoubleQuote] is used here in the topological sense.) The grid \
consists of polygons that have at most five vertices; usually most have four. \
If the region is itself a polygon, then ",
  Cell[BoxData[
      \(\(\(HollisGrid\)\(\ \)\)\)]],
  "only needs to know its vertices. Otherwise, one must provide ",
  Cell[BoxData[
      \(HollisGrid\)]],
  " with a parameterization of the boundary."
}], "MathCaption"],

Cell[TextData[{
  "The grid has a nexus or hub, like a polar grid, except that divisions near \
the nexus are decreased with the result that all polygons are approximately \
the same size. The option ",
  Cell[BoxData[
      \(GridNexus \[Rule] {xloc, yloc}\)]],
  " can be used to specify the location of the nexus, otherwise its position \
is automatically determined by the algorithm."
}], "MathCaption"],

Cell[TextData[{
  "The grid can be smoothed by using the options ",
  Cell[BoxData[
      \(GridSmoothness \[Rule] s\)]],
  " and ",
  Cell[BoxData[
      \(GridExtraSmoothing \[Rule] True | False\)]],
  ". The smoothness parameter must be in the range ",
  Cell[BoxData[
      \(0 \[LessEqual] s \[LessEqual] 1\)]],
  ". The default value is ",
  Cell[BoxData[
      \(0.5\)]],
  ". ",
  Cell[BoxData[
      \(GridExtraSmoothing\)]],
  " specifies that smoothing is done individually for each tier in the grid.  \
"
}], "MathCaption"],

Cell[TextData[{
  Cell[BoxData[
      \(HollisGrid\)]],
  ", unlike ",
  Cell[BoxData[
      \(MakePolyGrid\)]],
  ", returns a list of lists. Each inner list specifies the vertices of a \
polygon. Standard usage would be to map Line or Polygon onto the returned \
list to obtain the drawing objects."
}], "MathCaption"],

Cell[TextData[{
  "When the first form of ",
  Cell[BoxData[
      \(HollisGrid\)]],
  " is used the results are best if the vertices are roughly evenly spaced."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawingTransform",
    ButtonData:>{"DrawingTransform"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["TrimPolygons",
    ButtonData:>{"TrimPolygons"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MakePolyGrid",
    ButtonData:>{"MakePolyGrid"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PolygonOutline",
    ButtonData:>{"PolygonOutline"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RaiseTo3D",
    ButtonData:>{"RaiseTo3D"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[310]:="],

Cell["\<\
The following is a Hollis grid on a slightly irregular polygon. The vertices \
were clicked off the plot.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Module[{vertices, 
          grid}, \[IndentingNewLine]vertices = {{0.940775, 
              7.35199}, {6.09762, 
              5.33106}, {8.04886, \(-0.871089\)}, {4.63419, \(-7.07324\)}, \
{\(-1.08015\), \(-7.07324\)}, {\(-5.6795\), \(-4.56451\)}, {\(-7.07324\), 
              0.174217}, {\(-4.70388\), 5.88856}}; \[IndentingNewLine]grid = 
          HollisGrid[vertices, 
            GridExtraSmoothing \[Rule] 
              True]; \[IndentingNewLine]Draw2D[\[IndentingNewLine]{Line /@ 
              grid}, \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 
                  1}, {\(-1\), 1}} 10, \[IndentingNewLine]Background \[Rule] 
            Linen]\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[314]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.05 0.5 0.05 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 0 r
.5 Mabswid
[ ] 0 setdash
.59849 .79889 m
.54142 .81623 L
.54704 .8676 L
.6115 .84234 L
s
.65489 .77679 m
.59849 .79889 L
.6115 .84234 L
.67596 .81708 L
s
.71129 .75468 m
.65489 .77679 L
.67596 .81708 L
.74042 .79181 L
s
.76331 .72686 m
.71129 .75468 L
.74042 .79181 L
.80488 .76655 L
s
.78904 .66474 m
.76331 .72686 L
.80488 .76655 L
.82927 .68903 L
s
.81038 .59691 m
.78904 .66474 L
.82927 .68903 L
.85366 .6115 L
s
.83172 .52907 m
.81038 .59691 L
.85366 .6115 L
.87805 .53397 L
s
.84573 .46124 m
.83172 .52907 L
.87805 .53397 L
.90244 .45645 L
s
.81572 .3934 m
.84573 .46124 L
.90244 .45645 L
.85976 .37892 L
s
.77837 .32556 m
.81572 .3934 L
.85976 .37892 L
.81708 .30139 L
s
.74102 .25773 m
.77837 .32556 L
.81708 .30139 L
.77439 .22386 L
s
.70053 .19837 m
.74102 .25773 L
.77439 .22386 L
.73171 .14634 L
s
.64117 .18989 m
.70053 .19837 L
.73171 .14634 L
.66028 .14634 L
s
.57867 .18989 m
.64117 .18989 L
.66028 .14634 L
.58885 .14634 L
s
.51617 .18989 m
.57867 .18989 L
.58885 .14634 L
.51742 .14634 L
s
.45519 .19332 m
.51617 .18989 L
.51742 .14634 L
.44599 .14634 L
s
.40336 .21733 m
.45519 .19332 L
.44599 .14634 L
.3885 .1777 L
s
.35306 .24477 m
.40336 .21733 L
.3885 .1777 L
.33101 .20906 L
s
.30275 .27221 m
.35306 .24477 L
.33101 .20906 L
.27352 .24042 L
s
.25683 .3027 m
.30275 .27221 L
.27352 .24042 L
.21603 .27177 L
s
.2372 .35148 m
.25683 .3027 L
.21603 .27177 L
.1986 .33101 L
s
.22196 .40331 m
.2372 .35148 L
.1986 .33101 L
.18118 .39024 L
s
.20672 .45514 m
.22196 .40331 L
.18118 .39024 L
.16376 .44948 L
s
.19662 .5083 m
.20672 .45514 L
.16376 .44948 L
.14634 .50871 L
s
.21739 .56947 m
.19662 .5083 L
.14634 .50871 L
.17596 .58014 L
s
.2433 .63197 m
.21739 .56947 L
.17596 .58014 L
.20557 .65157 L
s
.26922 .69447 m
.2433 .63197 L
.20557 .65157 L
.23519 .723 L
s
.29961 .75116 m
.26922 .69447 L
.23519 .723 L
.26481 .79443 L
s
.35687 .77298 m
.29961 .75116 L
.26481 .79443 L
.33536 .81272 L
s
.41861 .78898 m
.35687 .77298 L
.33536 .81272 L
.40592 .83101 L
s
.48035 .80499 m
.41861 .78898 L
.40592 .83101 L
.47648 .84931 L
s
.54142 .81623 m
.48035 .80499 L
.47648 .84931 L
.54704 .8676 L
s
.5357 .76418 m
.54142 .81623 L
.59849 .79889 L
.58533 .75443 L
s
.58533 .75443 m
.59849 .79889 L
.65489 .77679 L
.63382 .7365 L
s
.63382 .7365 m
.65489 .77679 L
.71129 .75468 L
.68123 .71633 L
s
.68123 .71633 m
.71129 .75468 L
.76331 .72686 L
.72112 .68636 L
s
.72112 .68636 m
.76331 .72686 L
.78904 .66474 L
.74787 .63924 L
s
.74787 .63924 m
.78904 .66474 L
.81038 .59691 L
.7671 .58232 L
s
.7671 .58232 m
.81038 .59691 L
.83172 .52907 L
.78382 .52417 L
s
.78382 .52417 m
.83172 .52907 L
.84573 .46124 L
.78796 .46603 L
s
.78796 .46603 m
.84573 .46124 L
.81572 .3934 L
.7701 .40788 L
s
.7701 .40788 m
.81572 .3934 L
.77837 .32556 L
.73966 .34974 L
s
.73966 .34974 m
.77837 .32556 L
.74102 .25773 L
.70697 .29341 L
s
.70697 .29341 m
.74102 .25773 L
.70053 .19837 L
.6689 .25162 L
s
.6689 .25162 m
.70053 .19837 L
.64117 .18989 L
.62139 .23526 L
s
.62139 .23526 m
.64117 .18989 L
.57867 .18989 L
.56849 .23345 L
s
.56849 .23345 m
.57867 .18989 L
.51617 .18989 L
.51524 .23418 L
s
.51524 .23418 m
.51617 .18989 L
.45519 .19332 L
.46461 .2408 L
s
.46461 .2408 m
.45519 .19332 L
.40336 .21733 L
.41855 .2577 L
s
.41855 .2577 m
.40336 .21733 L
.35306 .24477 L
.37511 .28049 L
s
.37511 .28049 m
.35306 .24477 L
.30275 .27221 L
.33293 .30466 L
s
.33293 .30466 m
.30275 .27221 L
.25683 .3027 L
.29826 .33406 L
s
.29826 .33406 m
.25683 .3027 L
.2372 .35148 L
.27674 .3726 L
s
.27674 .3726 m
.2372 .35148 L
.22196 .40331 L
.26274 .41638 L
s
.26274 .41638 m
.22196 .40331 L
.20672 .45514 L
.25077 .46109 L
s
.25077 .46109 m
.20672 .45514 L
.19662 .5083 L
.24763 .50808 L
s
.24763 .50808 m
.19662 .5083 L
.21739 .56947 L
.25992 .55908 L
s
.25992 .55908 m
.21739 .56947 L
.2433 .63197 L
.28103 .61237 L
s
.28103 .61237 m
.2433 .63197 L
.26922 .69447 L
.3042 .6647 L
s
.3042 .6647 m
.26922 .69447 L
.29961 .75116 L
.33505 .70706 L
s
.33505 .70706 m
.29961 .75116 L
.35687 .77298 L
.37933 .73199 L
s
.37933 .73199 m
.35687 .77298 L
.41861 .78898 L
.43129 .74695 L
s
.43129 .74695 m
.41861 .78898 L
.48035 .80499 L
.48407 .75965 L
s
.48407 .75965 m
.48035 .80499 L
.54142 .81623 L
.5357 .76418 L
s
.53057 .71631 m
.5357 .76418 L
.58533 .75443 L
.57211 .70945 L
s
.57211 .70945 m
.58533 .75443 L
.63382 .7365 L
.61253 .69574 L
s
.61253 .69574 m
.63382 .7365 L
.68123 .71633 L
.65069 .67736 L
s
.65069 .67736 m
.68123 .71633 L
.72112 .68636 L
.68276 .65085 L
s
.68276 .65085 m
.72112 .68636 L
.74787 .63924 L
.70622 .61312 L
s
.70622 .61312 m
.74787 .63924 L
.7671 .58232 L
.72329 .56747 L
s
.72329 .56747 m
.7671 .58232 L
.78382 .52417 L
.73513 .51927 L
s
.73513 .51927 m
.78382 .52417 L
.78796 .46603 L
.73662 .47082 L
s
.73662 .47082 m
.78796 .46603 L
.7701 .40788 L
.7237 .42236 L
s
.7237 .42236 m
.7701 .40788 L
.73966 .34974 L
.70048 .37429 L
s
.70048 .37429 m
.73966 .34974 L
.70697 .29341 L
.67259 .33 L
s
.67259 .33 m
.70697 .29341 L
.6689 .25162 L
.64002 .29744 L
s
.64002 .29744 m
.6689 .25162 L
.62139 .23526 L
.60127 .28154 L
s
.60127 .28154 m
.62139 .23526 L
.56849 .23345 L
.55824 .27753 L
s
.55824 .27753 m
.56849 .23345 L
.51524 .23418 L
.51448 .27884 L
s
.51448 .27884 m
.51524 .23418 L
.46461 .2408 L
.4727 .28527 L
s
.4727 .28527 m
.46461 .2408 L
.41855 .2577 L
.43391 .29844 L
s
.43391 .29844 m
.41855 .2577 L
.37511 .28049 L
.39742 .31649 L
s
.39742 .31649 m
.37511 .28049 L
.33293 .30466 L
.36357 .33743 L
s
.36357 .33743 m
.33293 .30466 L
.29826 .33406 L
.33586 .36275 L
s
.33586 .36275 m
.29826 .33406 L
.27674 .3726 L
.31675 .39405 L
s
.31675 .39405 m
.27674 .3726 L
.26274 .41638 L
.30394 .42964 L
s
.30394 .42964 m
.26274 .41638 L
.25077 .46109 L
.29538 .46718 L
s
.29538 .46718 m
.25077 .46109 L
.24763 .50808 L
.29414 .5067 L
s
.29414 .5067 m
.24763 .50808 L
.25992 .55908 L
.303 .54884 L
s
.303 .54884 m
.25992 .55908 L
.28103 .61237 L
.31919 .59257 L
s
.31919 .59257 m
.28103 .61237 L
.3042 .6647 L
.33967 .6343 L
s
.33967 .6343 m
.3042 .6647 L
.33505 .70706 L
.36658 .66805 L
s
.36658 .66805 m
.33505 .70706 L
.37933 .73199 L
.40228 .69038 L
s
.40228 .69038 m
.37933 .73199 L
.43129 .74695 L
.44415 .70445 L
s
.44415 .70445 m
.43129 .74695 L
.48407 .75965 L
.48772 .7138 L
s
.48772 .7138 m
.48407 .75965 L
.5357 .76418 L
.53057 .71631 L
s
.52567 .67013 m
.53057 .71631 L
.57211 .70945 L
.55894 .66514 L
s
.55894 .66514 m
.57211 .70945 L
.61253 .69574 L
.59105 .65461 L
s
.59105 .65461 m
.61253 .69574 L
.65069 .67736 L
.62082 .63922 L
s
.62082 .63922 m
.65069 .67736 L
.68276 .65085 L
.64597 .61739 L
s
.64597 .61739 m
.68276 .65085 L
.70622 .61312 L
.66518 .58787 L
s
.66518 .58787 m
.70622 .61312 L
.72329 .56747 L
.67907 .55242 L
s
.67907 .55242 m
.72329 .56747 L
.73513 .51927 L
.68751 .51432 L
s
.68751 .51432 m
.73513 .51927 L
.73662 .47082 L
.68789 .47561 L
s
.68789 .47561 m
.73662 .47082 L
.7237 .42236 L
.67838 .43692 L
s
.67838 .43692 m
.7237 .42236 L
.70048 .37429 L
.66093 .39914 L
s
.66093 .39914 m
.70048 .37429 L
.67259 .33 L
.63862 .3653 L
s
.63862 .3653 m
.67259 .33 L
.64002 .29744 L
.61226 .34024 L
s
.61226 .34024 m
.64002 .29744 L
.60127 .28154 L
.58164 .32657 L
s
.58164 .32657 m
.60127 .28154 L
.55824 .27753 L
.54793 .32204 L
s
.54793 .32204 m
.55824 .27753 L
.51448 .27884 L
.51346 .32305 L
s
.51346 .32305 m
.51448 .27884 L
.4727 .28527 L
.48024 .32852 L
s
.48024 .32852 m
.4727 .28527 L
.43391 .29844 L
.44907 .33868 L
s
.44907 .33868 m
.43391 .29844 L
.39742 .31649 L
.41994 .35272 L
s
.41994 .35272 m
.39742 .31649 L
.36357 .33743 L
.39357 .36978 L
s
.39357 .36978 m
.36357 .33743 L
.33586 .36275 L
.37189 .39035 L
s
.37189 .39035 m
.33586 .36275 L
.31675 .39405 L
.35614 .41505 L
s
.35614 .41505 m
.31675 .39405 L
.30394 .42964 L
.34548 .44306 L
s
.34548 .44306 m
.30394 .42964 L
.29538 .46718 L
.33925 .47309 L
s
.33925 .47309 m
.29538 .46718 L
.29414 .5067 L
.33881 .50484 L
s
.33881 .50484 m
.29414 .5067 L
.303 .54884 L
.34535 .53835 L
s
.34535 .53835 m
.303 .54884 L
.31919 .59257 L
.35769 .57261 L
s
.35769 .57261 m
.31919 .59257 L
.33967 .6343 L
.3745 .6048 L
s
.3745 .6048 m
.33967 .6343 L
.36658 .66805 L
.3965 .63111 L
s
.3965 .63111 m
.36658 .66805 L
.40228 .69038 L
.42454 .64961 L
s
.42454 .64961 m
.40228 .69038 L
.44415 .70445 L
.45714 .66157 L
s
.45714 .66157 m
.44415 .70445 L
.48772 .7138 L
.49151 .66863 L
s
.49151 .66863 m
.48772 .7138 L
.53057 .71631 L
.52567 .67013 L
s
.5697 .61374 m
.52094 .62507 L
.52567 .67013 L
.55894 .66514 L
.59105 .65461 L
s
.61021 .58529 m
.5697 .61374 L
.59105 .65461 L
.62082 .63922 L
.64597 .61739 L
s
.63513 .53751 m
.61021 .58529 L
.64597 .61739 L
.66518 .58787 L
.67907 .55242 L
s
.64092 .48041 m
.63513 .53751 L
.67907 .55242 L
.68751 .51432 L
.68789 .47561 L
s
.62164 .42379 m
.64092 .48041 L
.68789 .47561 L
.67838 .43692 L
.66093 .39914 L
s
.58525 .38101 m
.62164 .42379 L
.66093 .39914 L
.63862 .3653 L
.61226 .34024 L
s
.53765 .36626 m
.58525 .38101 L
.61226 .34024 L
.58164 .32657 L
.54793 .32204 L
s
.48741 .37096 m
.53765 .36626 L
.54793 .32204 L
.51346 .32305 L
.48024 .32852 L
s
.44232 .3888 m
.48741 .37096 L
.48024 .32852 L
.44907 .33868 L
.41994 .35272 L
s
.40688 .41723 m
.44232 .3888 L
.41994 .35272 L
.39357 .36978 L
.37189 .39035 L
s
.38679 .45637 m
.40688 .41723 L
.37189 .39035 L
.35614 .41505 L
.34548 .44306 L
s
.38227 .50265 m
.38679 .45637 L
.34548 .44306 L
.33925 .47309 L
.33881 .50484 L
s
.39596 .55276 m
.38227 .50265 L
.33881 .50484 L
.34535 .53835 L
.35769 .57261 L
s
.42536 .59556 m
.39596 .55276 L
.35769 .57261 L
.3745 .6048 L
.3965 .63111 L
s
.47004 .61895 m
.42536 .59556 L
.3965 .63111 L
.42454 .64961 L
.45714 .66157 L
s
.52094 .62507 m
.47004 .61895 L
.45714 .66157 L
.49151 .66863 L
.52567 .67013 L
s
.51607 .57873 m
.52094 .62507 L
.5697 .61374 L
.54756 .57123 L
s
.54756 .57123 m
.5697 .61374 L
.61021 .58529 L
.57334 .5519 L
s
.57334 .5519 m
.61021 .58529 L
.63513 .53751 L
.58937 .52171 L
s
.58937 .52171 m
.63513 .53751 L
.64092 .48041 L
.59223 .48528 L
s
.59223 .48528 m
.64092 .48041 L
.62164 .42379 L
.58071 .44976 L
s
.58071 .44976 m
.62164 .42379 L
.58525 .38101 L
.55743 .4236 L
s
.55743 .4236 m
.58525 .38101 L
.53765 .36626 L
.52713 .41234 L
s
.52713 .41234 m
.53765 .36626 L
.48741 .37096 L
.49494 .41442 L
s
.49494 .41442 m
.48741 .37096 L
.44232 .3888 L
.46562 .42589 L
s
.46562 .42589 m
.44232 .3888 L
.40688 .41723 L
.44295 .44486 L
s
.44295 .44486 m
.40688 .41723 L
.38679 .45637 L
.42959 .47036 L
s
.42959 .47036 m
.38679 .45637 L
.38227 .50265 L
.42702 .50066 L
s
.42702 .50066 m
.38227 .50265 L
.39596 .55276 L
.43572 .53221 L
s
.43572 .53221 m
.39596 .55276 L
.42536 .59556 L
.45525 .55873 L
s
.45525 .55873 m
.42536 .59556 L
.47004 .61895 L
.48353 .57468 L
s
.48353 .57468 m
.47004 .61895 L
.52094 .62507 L
.51607 .57873 L
s
.53915 .52198 m
.51161 .53531 L
.51607 .57873 L
.54756 .57123 L
.57334 .5519 L
s
.54802 .49014 m
.53915 .52198 L
.57334 .5519 L
.58937 .52171 L
.59223 .48528 L
s
.53154 .46105 m
.54802 .49014 L
.59223 .48528 L
.58071 .44976 L
.55743 .4236 L
s
.50153 .45577 m
.53154 .46105 L
.55743 .4236 L
.52713 .41234 L
.49494 .41442 L
s
.47634 .47063 m
.50153 .45577 L
.49494 .41442 L
.46562 .42589 L
.44295 .44486 L
s
.46862 .49787 m
.47634 .47063 L
.44295 .44486 L
.42959 .47036 L
.42702 .50066 L
s
.48242 .52543 m
.46862 .49787 L
.42702 .50066 L
.43572 .53221 L
.45525 .55873 L
s
.51161 .53531 m
.48242 .52543 L
.45525 .55873 L
.48353 .57468 L
.51607 .57873 L
s
.5074 .49477 m
.5074 .49477 L
.51161 .53531 L
.53915 .52198 L
.54802 .49014 L
s
.5074 .49477 m
.5074 .49477 L
.54802 .49014 L
.53154 .46105 L
.50153 .45577 L
s
.5074 .49477 m
.5074 .49477 L
.50153 .45577 L
.47634 .47063 L
.46862 .49787 L
s
.5074 .49477 m
.5074 .49477 L
.46862 .49787 L
.48242 .52543 L
.51161 .53531 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[314]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3j
l>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40
oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`
iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3o
ool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V
803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?oo
o`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP
0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo
003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00
n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool0
0?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803j
l>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00800n_3VD`00001<0?[`iP40
oooo001n0?[`iP<000004`3jl>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V0140n_3V
00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0000001;0?[`iP40oooo001l0?[`iP8000000P3j
l>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H0403j
l>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0000004/0n_3V0@3oool007X0n_3V0P000004
0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0A
0?[`iP030000003jl>H0n_3V0140n_3V00D000000?[`iP3jl>H0n_3V0000001:0?[`iP40oooo001h
0?[`iP8000001`3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V0140n_3V00<00000
0?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0B0?[`iP050000003jl>H0n_3V0?[`iP000000BP3j
l>H10?ooo`00MP3jl>H2000000T0n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0A
0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP03
0?[`iP030000003jl>H0n_3V04L0n_3V0@3oool007@0n_3V0P00000;0?[`iP030000003jl>H0n_3V
0100n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V
0100n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP170?[`iP40oooo001b0?[`iP80
00003@3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3j
l>H0403jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3j
l>H0AP3jl>H10?ooo`00L03jl>H2000000l0n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V
0?[`iP0@0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V
0?[`iP060?[`iP030000003jl>H0n_3V04H0n_3V0@3oool006l0n_3V00<000000?[`iP3jl>H03`3j
l>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H0403j
l>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0A@3j
l>H10?ooo`00K@3jl>H300000140n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0@
0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP08
0?[`iP030000003jl>H0n_3V04D0n_3V0@3oool006/0n_3V0P0000030?[`iP030000003jl>H0n_3V
00l0n_3V00<000000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V
0100n_3V00<000000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V
04@0n_3V0@3oool006T0n_3V0P0000050?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3j
l>H03`3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3j
l>H0403jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V04@0n_3V0@3oool006P0n_3V
00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00L0n_3V
<@00000=0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0@`3jl>H10?ooo`00IP3j
l>H2000000T0n_3V00<000000?[`iP3jl>H03@3jl>H;000000P0n_3V00<000000?[`iP3jl>H03`3j
l>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V0080n_3V200000050?[`iP030000003j
l>H0n_3V00`0n_3V00<000000?[`iP3jl>H0@`3jl>H10?ooo`00I03jl>H2000000/0n_3V00<00000
0?[`iP3jl>H02`3jl>H2000000030?[`iP000000n_3V0100n_3V00<000000?[`iP3jl>H03P3jl>H0
0`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00/0n_3V1@00000@0?[`iP030000003jl>H0
n_3V0480n_3V0@3oool00680n_3V0P00000=0?[`iP030000003jl>H0n_3V00T0n_3V0P0000030?[`
iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0?0?[`
iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP0000003`3jl>H00`000000n_3V0?[`iP120?[`
iP40oooo001P0?[`iP800000403jl>H00`000000n_3V0?[`iP060?[`iP8000001P3jl>H00`000000
n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000
n_3V0?[`iP0?0?[`iP030000003jl>H000000100n_3V00<000000?[`iP3jl>H0@@3jl>H10?ooo`00
G`3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V00@0n_3V0P0000080?[`iP030000
003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0>0?[`iP030000
003jl>H0n_3V00h0n_3V00D000000?[`iP3jl>H0n_3V0000000?0?[`iP030000003jl>H0n_3V0440
n_3V0@3oool005d0n_3V0P0000000`3jl>H000000?[`iP0@0?[`iP030000003jl>H0n_3V0080n_3V
0P00000:0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V
0?[`iP0>0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V
0?[`iP0=0?[`iP030000003jl>H0n_3V0400n_3V0@3oool005/0n_3V0P0000030?[`iP030000003j
l>H0n_3V0100n_3V00@000000?[`iP0000000000303jl>H00`000000n_3V0?[`iP0=0?[`iP030000
003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0>0?[`iP030000
003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP100?[`iP40oooo
001I0?[`iP8000001P3jl>H00`000000n_3V0?[`iP0?0?[`iP8000003P3jl>H00`000000n_3V0?[`
iP0=0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`
iP0>0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`
iP0o0?[`iP40oooo001G0?[`iP800000203jl>H00`000000n_3V0?[`iP0=0?[`iP<00000403jl>H0
0`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H03@3jl>H0
0`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0303jl>H0
0`000000n_3V0?[`iP0o0?[`iP40oooo001E0?[`iP8000002`3jl>H00`000000n_3V0?[`iP0:0?[`
iP8000000`3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`
iP3jl>H03@3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`
iP3jl>H01`3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V03h0n_3V0@3oool005<0
n_3V0P00000=0?[`iP030000003jl>H0n_3V00P0n_3V0P0000050?[`iP030000003jl>H0n_3V00d0
n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V00d0
n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00/0
n_3V00<000000?[`iP000000?`3jl>H10?ooo`00D@3jl>H200000100n_3V00<000000?[`iP3jl>H0
1P3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0
303jl>H00`000000n_3V0?[`iP060?[`iPl000001`3jl>H00`000000n_3V0?[`iP0>0?[`iP030000
003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02P3jl>H010000000n_3V0?[`iP00000o0?[`iP40
oooo001?0?[`iP8000004P3jl>H00`000000n_3V0?[`iP040?[`iP8000002@3jl>H00`000000n_3V
0?[`iP0=0?[`iP030000003jl>H0n_3V00P0n_3V300000070?[`iP030000003jl>H0n_3V00D0n_3V
2@00000>0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V
0?[`iP020?[`iP030000003jl>H0n_3V03`0n_3V0@3oool004h0n_3V00<000000?[`iP3jl>H04`3j
l>H010000000n_3V0?[`iP3jl>H2000000`0n_3V00<000000?[`iP3jl>H0303jl>H010000000n_3V
0?[`iP3jl>H7000000<0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0<0?[`iP04
0000003jl>H00000000000/0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP060?[`
iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H0?03jl>H10?ooo`00C03jl>H200000003
0?[`iP000000n_3V01<0n_3V00@000000?[`iP00000000003P3jl>H00`000000n_3V0?[`iP0;0?[`
iPD000002P3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`
iP3jl>H00P3jl>H3000000P0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP040?[`
iP8000001`3jl>H00`000000n_3V0?[`iP0k0?[`iP40oooo001:0?[`iP800000103jl>H00`000000
n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H01`3jl>H300000003
0?[`iP000000n_3V00`0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0<0?[`iP03
0000003jl>H0n_3V00D0n_3V0`0000040?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3j
l>H00P3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V03/0n_3V0@3oool004P0n_3V
0P0000060?[`iP030000003jl>H0n_3V0100n_3V0P0000000`3jl>H000000?[`iP0?0?[`iP030000
003jl>H0n_3V00<0n_3V100000040?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0
303jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00T0n_3V0P0000020?[`iP030000
003jl>H0n_3V0100n_3V00@000000?[`iP3jl>H000002`3jl>H00`000000n_3V0?[`iP0j0?[`iP40
oooo00170?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H03@3jl>H2000000<0n_3V
00<000000?[`iP3jl>H03`3jl>H00`000000n_3V00000002000000P0n_3V00<000000?[`iP3jl>H0
2`3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0
2`3jl>H2000001<0n_3V00<000000?[`iP000000303jl>H00`000000n_3V0?[`iP0j0?[`iP40oooo
00150?[`iP8000002`3jl>H00`000000n_3V0?[`iP0:0?[`iP8000001P3jl>H00`000000n_3V0?[`
iP0>0?[`iP800000303jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00/0n_3V00<0
00000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0000001<0n_3V00<0
00000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0i0?[`iP40oooo00130?[`iP8000003P3jl>H0
0`000000n_3V0?[`iP070?[`iP800000203jl>H00`000000n_3V0?[`iP0<0?[`iP<000003@3jl>H0
0`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02`3jl>H0
0`000000n_3V0?[`iP0<0?[`iP040000003jl>H0n_3V00000140n_3V00<000000?[`iP0000003@3j
l>H00`000000n_3V0?[`iP0i0?[`iP40oooo00110?[`iP8000004@3jl>H00`000000n_3V0?[`iP04
0?[`iP8000002`3jl>H00`000000n_3V0?[`iP090?[`iP8000000`3jl>H00`000000n_3V0?[`iP0:
0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0:
0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0=
0?[`iP040000003jl>H0n_3V000000h0n_3V00<000000?[`iP3jl>H0>03jl>H10?ooo`00?`3jl>H2
000001<0n_3V00<000000?[`iP3jl>H00P3jl>H2000000h0n_3V00<000000?[`iP3jl>H01P3jl>H2
000000D0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0
n_3V00/0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0
n_3V00<0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0
n_3V00`0n_3V00<000000?[`iP3jl>H0=`3jl>H10?ooo`00?P3jl>H00`000000n_3V0?[`iP0D0?[`
iP040000003jl>H0000000000100n_3V00<000000?[`iP3jl>H0103jl>H2000000L0n_3V00<00000
0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00X0n_3V00<00000
0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00D0n_3V00<00000
0?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V00`0n_3V00<00000
0?[`iP3jl>H0=`3jl>H10?ooo`00?P3jl>H2000001H0n_3V00<000000?[`iP3jl>H04@3jl>H01000
0000n_3V0?[`iP3jl>H2000000X0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0:
0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0;
0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP05
0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0=P3jl>H10?ooo`00?@3jl>H00`00
0000n_3V0?[`iP0200000180n_3V0P0000000`3jl>H000000?[`iP0A0?[`iP040000003jl>H00000
000000`0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0
n_3V00@0n_3V300000060?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0303jl>H0
0`000000n_3V0?[`iP0f0?[`iP40oooo000m0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`
iP3jl>H03@3jl>H2000000@0n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0<0?[`
iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0103jl>H<000000H0n_3V00<000000?[`
iP3jl>H00`3jl>H8000000`0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP050?[`
iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0e0?[`
iP40oooo000m0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP050?[`iP030000003jl>H0n_3V00d0n_3V0P0000000`3jl>H000000?[`iP0=0?[`iP03
0000003jl>H0n_3V00P0n_3V200000050?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3j
l>H02@3jl>H010000000n_3V0000000000090?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`
iP3jl>H00`3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`
iP3jl>H0=@3jl>H10?ooo`00?@3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V00P0
n_3V0P0000090?[`iP030000003jl>H0n_3V00X0n_3V0P0000030?[`iP030000003jl>H0n_3V00`0
n_3V00<000000?[`iP3jl>H01@3jl>H3000000030?[`iP000000n_3V00X0n_3V00<000000?[`iP3j
l>H02@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V0080n_3V0P0000070?[`iP03
0000003jl>H0n_3V00`0n_3V00D000000?[`iP3jl>H0n_3V0000000<0?[`iP030000003jl>H0n_3V
00`0n_3V00<000000?[`iP3jl>H0=03jl>H10?ooo`00?03jl>H00`000000n_3V0?[`iP060?[`iP03
0000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP080?[`iP03
0000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP030?[`iP80
0000103jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3j
l>H02@3jl>H00`000000n_3V0?[`iP040?[`iP800000103jl>H00`000000n_3V0?[`iP0>0?[`iP03
0000003jl>H0000000d0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0d0?[`iP40
oooo000l0?[`iP030000003jl>H0n_3V00L0n_3V0P0000040?[`iP8000003P3jl>H00`000000n_3V
0?[`iP050?[`iP800000203jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0000000800000
1P3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0
203jl>H00`000000n_3V0?[`iP070?[`iP8000000P3jl>H00`000000n_3V0?[`iP0?0?[`iP030000
003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo
000l0?[`iP030000003jl>H0n_3V00T0n_3V00@000000?[`iP00000000004@3jl>H00`000000n_3V
0?[`iP020?[`iP8000002P3jl>H00`000000n_3V0?[`iP0;0?[`iP8000002P3jl>H00`000000n_3V
0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V
0?[`iP090?[`iP8000004@3jl>H00`000000n_3V0000000?0?[`iP030000003jl>H0n_3V00/0n_3V
00<000000?[`iP3jl>H0<`3jl>H10?ooo`00>`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003j
l>H0n_3V0180n_3V00@000000?[`iP00000000003@3jl>H00`000000n_3V0?[`iP080?[`iP<00000
2`3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0
203jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0000000l0n_3V00@000000?[`iP3jl>H0
00003`3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V0380n_3V0@3oool003/0n_3V
00<000000?[`iP3jl>H02`3jl>H2000001@0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V
0?[`iP050?[`iP8000000`3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V
00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00X0n_3V
00@000000?[`iP3jl>H000003@3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00d0
n_3V00<000000?[`iP3jl>H02@3jl>H2000000030?[`iP000000n_3V0380n_3V0@3oool003/0n_3V
00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0200000140n_3V00<000000?[`iP000000
403jl>H00`000000n_3V0?[`iP020?[`iP8000001@3jl>H00`000000n_3V0?[`iP080?[`iP030000
003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP030000
003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP090?[`iP030000
003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP080?[`iP050000
003jl>H0n_3V0?[`iP000000<`3jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP0;0?[`iP030000
003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0303jl>H2000000<0n_3V00<000000?[`iP3jl>H0
3@3jl>H00`000000n_3V0?[`iP02000000L0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V
0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V
0?[`iP090?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V
0?[`iP050?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H01@3jl>H2000000D0n_3V
00<000000?[`iP3jl>H0<03jl>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003j
l>H0n_3V00<0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP040?[`iP030000003j
l>H0n_3V00d0n_3V0P00000:0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0203j
l>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H02P3j
l>H00`000000n_3V0?[`iP050?[`iP8000001`3jl>H00`000000n_3V0?[`iP060?[`iP030000003j
l>H0n_3V00`0n_3V00<000000?[`iP3jl>H00`3jl>H2000000L0n_3V00<000000?[`iP3jl>H0<03j
l>H10?ooo`00>P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00D0n_3V0P000009
0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H02P3jl>H2000000030?[`iP000000
n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0
n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0
n_3V00P0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0
n_3V00d0n_3V00D000000?[`iP3jl>H0n_3V0000000:0?[`iP030000003jl>H0n_3V02l0n_3V0@3o
ool003X0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0
n_3V00D0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP8000000`3jl>H0
0`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H01@3jl>HA
000000@0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0:0?[`iP050000003jl>H0
n_3V0?[`iP0000002`3jl>H00`000000n_3V0?[`iP0<0?[`iP040000003jl>H00000000000/0n_3V
00<000000?[`iP3jl>H0;`3jl>H10?ooo`00>@3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003j
l>H0n_3V00T0n_3V00<000000?[`iP3jl>H00P3jl>H2000000`0n_3V00<000000?[`iP3jl>H01@3j
l>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H01`3j
l>H00`000000n_3V0?[`iP05000000`0n_3V00<000000?[`iP3jl>H00P3jl>H6000000X0n_3V00<0
00000?[`iP3jl>H02`3jl>H00`000000n_3V0000000=0?[`iP030000003jl>H0n_3V00`0n_3V00<0
00000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0^0?[`iP40oooo000i0?[`iP030000003jl>H0
n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H2000000030?[`iP000000n_3V00h0n_3V00<00000
0?[`iP3jl>H00P3jl>H2000000L0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP06
0?[`iP@000004@3jl>H00`000000n_3V0?[`iP080?[`iP8000001`3jl>H00`000000n_3V0?[`iP0=
0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H02P3jl>H2000000030?[`iP000000
n_3V00`0n_3V00<000000?[`iP3jl>H0;P3jl>H10?ooo`00>@3jl>H3000000X0n_3V00<000000?[`
iP3jl>H0303jl>H00`000000n_3V0?[`iP0?0?[`iP040000003jl>H00000000000X0n_3V00<00000
0?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP030?[`iP<0000000<0n_3V0000003jl>H04@3jl>H0
0`000000n_3V0?[`iP0;0?[`iP800000103jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0
000000h0n_3V00<000000?[`iP3jl>H0203jl>H01@000000n_3V0?[`iP3jl>H0000000h0n_3V00<0
00000?[`iP3jl>H0;@3jl>H10?ooo`00>03jl>H010000000n_3V0?[`iP3jl>H2000000L0n_3V00<0
00000?[`iP3jl>H0303jl>H00`000000n_3V0000000A0?[`iP030000003jl>H0n_3V00X0n_3V00<0
00000?[`iP3jl>H0203jl>H00`000000n_3V00000002000000@0n_3V00<000000?[`iP3jl>H0403j
l>H00`000000n_3V0?[`iP0=0?[`iP8000000P3jl>H00`000000n_3V0?[`iP0<0?[`iP040000003j
l>H0n_3V000000h0n_3V00<000000?[`iP3jl>H01P3jl>H2000000D0n_3V00<000000?[`iP3jl>H0
2`3jl>H00`000000n_3V0?[`iP0]0?[`iP40oooo000h0?[`iP030000003jl>H0n_3V00<0n_3V0P00
00050?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H00P00000>0?[`iP030000003j
l>H0000000`0n_3V00<000000?[`iP3jl>H01`3jl>H2000000L0n_3V00<000000?[`iP3jl>H0403j
l>H00`000000n_3V0?[`iP0?0?[`iP8000003P3jl>H00`000000n_3V0?[`iP020?[`iP030000003j
l>H0n_3V00`0n_3V00<000000?[`iP3jl>H00`3jl>H2000000L0n_3V00<000000?[`iP3jl>H0303j
l>H00`000000n_3V0?[`iP0/0?[`iP40oooo000h0?[`iP030000003jl>H0n_3V00D0n_3V0P000003
0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0:
0?[`iP050000003jl>H0n_3V0?[`iP0000002`3jl>H00`000000n_3V0?[`iP050?[`iP8000002P3j
l>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP000000303j
l>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V00d0n_3V00D000000?[`iP3jl>H0n_3V
0000000:0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0:`3jl>H10?ooo`00>03j
l>H00`000000n_3V0?[`iP070?[`iP<000003P3jl>H00`000000n_3V0?[`iP040?[`iP030000003j
l>H0n_3V00P0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003j
l>H0n_3V0080n_3V0P00000<0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0403j
l>H010000000n_3V0?[`iP00000:0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0
303jl>H010000000n_3V00000000000;0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3j
l>H0:`3jl>H10?ooo`00=`3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00/0n_3V
00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V00@0n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP02000000h0n_3V00<000000?[`iP3jl>H0
3P3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0
1P3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0
303jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V02X0n_3V0@3oool003L0n_3V00<0
00000?[`iP3jl>H02P3jl>H3000000/0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`
iP040?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H02@3jl>H200000100n_3V00<0
00000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00@0n_3V0P00
00050?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H02P3jl>H2000000030?[`iP00
0000n_3V00d0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0Z0?[`iP40oooo000g
0?[`iP030000003jl>H0n_3V00T0n_3V00@000000?[`iP3jl>H0n_3V0P0000080?[`iP030000003j
l>H0n_3V00T0n_3V0P0000030?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H01P3j
l>H2000000030?[`iP000000n_3V00l0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`
iP0>0?[`iP030000003jl>H0n_3V00H0n_3V00D000000?[`iP3jl>H0n_3V0000000<0?[`iP030000
003jl>H0n_3V00P0n_3V00D000000?[`iP3jl>H0n_3V0000000>0?[`iP030000003jl>H0n_3V00`0
n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00=P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000
003jl>H0n_3V00<0n_3V0P0000060?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP000000
303jl>H00`000000n_3V0?[`iP040?[`iP050000003jl>H0n_3V0?[`iP000000403jl>H00`000000
n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0203jl>H00`000000
n_3V0000000>0?[`iP030000003jl>H0n_3V00D0n_3V0P0000050?[`iP030000003jl>H0n_3V00`0
n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo000f0?[`iP030000
003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H01@3jl>H2000000<0n_3V00<000000?[`iP3jl>H0
3@3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V0080n_3V0P0000050?[`iP030000
003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0=0?[`iP030000
003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP030?[`iP800000
1`3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0
:03jl>H10?ooo`00=P3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V0P00
00000`3jl>H000000?[`iP0=0?[`iP030000003jl>H0000000d0n_3V00@000000?[`iP0000000000
1`3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00D0n_3V2@00000>0?[`iP030000
003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H03@3jl>H01@000000n_3V0?[`iP3jl>H0000000X0
n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V02P0
n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000
003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H00P00000<0?[`iP030000003jl>H0n_3V00P0n_3V
00<000000?[`iP3jl>H0303jl>H9000000L0n_3V00<000000?[`iP0000000P00000:0?[`iP030000
003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H03@3jl>H010000000n_3V00000000000;0?[`iP03
0000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0W0?[`iP40
oooo000e0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H3000000`0n_3V
00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00X0n_3V
00<000000?[`iP3jl>H02@3jl>H2000000030?[`iP000000n_3V00d0n_3V00<000000?[`iP3jl>H0
0P3jl>H4000000D0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0=0?[`iP030000
003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0;0?[`iP030000
003jl>H0n_3V02L0n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`
iP0:0?[`iP050000003jl>H0n_3V0?[`iP0000002P3jl>H00`000000n_3V0?[`iP050?[`iP030000
003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP060?[`iP<00000
0`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00L0n_3V0`0000020?[`iP030000
003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H02`3jl>H3000000h0n_3V00<000000?[`iP3jl>H0
3@3jl>H00`000000n_3V0?[`iP0:0?[`iP800000:03jl>H10?ooo`00=@3jl>H00`000000n_3V0?[`
iP090?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H00P3jl>H2000000P0n_3V00<0
00000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V00d0n_3V00<0
00000?[`iP3jl>H00P3jl>H3000000L0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`
iP0:0?[`iP8000004P3jl>H00`000000n_3V0?[`iP080?[`iP8000000`3jl>H00`000000n_3V0?[`
iP0<0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H01`3jl>H300000080n_3V00<0
00000?[`iP3jl>H09@3jl>H10?ooo`00=03jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0
n_3V00X0n_3V00<000000?[`iP3jl>H0103jl>H2000000D0n_3V00<000000?[`iP3jl>H0203jl>H2
000000<0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP02000000X0n_3V00<00000
0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H000000180n_3V00<00000
0?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V00`0n_3V00<00000
0?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP030?[`iP<000001@3jl>H00`000000n_3V0?[`iP0U
0?[`iP40oooo000d0?[`iP8000002P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V
00L0n_3V00D000000?[`iP3jl>H0n_3V0000000=0?[`iP030000003jl>H000000180n_3V0P00000<
0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H010000000n_3V0?[`iP00
000A0?[`iP030000003jl>H0n_3V00@0n_3V0P0000070?[`iP030000003jl>H0n_3V00`0n_3V00<0
00000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP03000000T0n_3V00<000000?[`iP3jl>H0903j
l>H10?ooo`00=03jl>H00`000000n_3V00000002000000L0n_3V00<000000?[`iP3jl>H02P3jl>H0
0`000000n_3V0?[`iP080?[`iP80000000<0n_3V0000003jl>H03@3jl>H00`000000n_3V0?[`iP0@
0?[`iP030000003jl>H0000000`0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0:
0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H03`3jl>H010000000n_3V0?[`iP3j
l>H2000000T0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0<0?[`iP<00000303j
l>H00`000000n_3V0?[`iP0T0?[`iP40oooo000c0?[`iP030000003jl>H0n_3V00<0n_3V0P000005
0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0<
0?[`iP040000003jl>H00000000000h0n_3V0P0000020?[`iP030000003jl>H0n_3V00/0n_3V00<0
00000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00@0n_3V00<0
00000?[`iP3jl>H03P3jl>H010000000n_3V00000000000<0?[`iP030000003jl>H0n_3V00`0n_3V
00<000000?[`iP3jl>H02@3jl>H2000000030?[`iP000000n_3V00d0n_3V00<000000?[`iP3jl>H0
8`3jl>H10?ooo`00<`3jl>H00`000000n_3V0?[`iP050?[`iP<0000000<0n_3V0000003jl>H0303j
l>H00`000000n_3V0?[`iP0:0?[`iP<00000303jl>H01@000000n_3V0?[`iP3jl>H0000000`0n_3V
00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00P0n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V00h0n_3V
00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00H0n_3V
0`0000040?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H08P3jl>H10?ooo`00<`3j
l>H00`000000n_3V0?[`iP080?[`iP<000002`3jl>H00`000000n_3V0?[`iP0:0?[`iP040000003j
l>H0n_3V0?[`iP8000002@3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V00P0n_3V
00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00P0n_3V
00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V00`0n_3V
0`00000>0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H00P3jl>H3000000L0n_3V
00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0R0?[`iP40oooo000c0?[`iP030000003j
l>H0n_3V00T0n_3V00<000000?[`iP0000000P0000080?[`iP030000003jl>H0n_3V00X0n_3V00<0
00000?[`iP3jl>H00`3jl>H2000000L0n_3V00<000000?[`iP3jl>H0103jl>H2000000L0n_3V00<0
00000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00X0n_3V00D0
00000?[`iP3jl>H0n_3V0000000>0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0
0P00000;0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00<P3j
l>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00<0n_3V0`0000050?[`iP030000003j
l>H0n_3V00X0n_3V00<000000?[`iP3jl>H01@3jl>H2000000@0n_3V00<000000?[`iP3jl>H01`3j
l>H00`000000n_3V0?[`iP020?[`iP8000002P3jl>H00`000000n_3V0?[`iP090?[`iP030000003j
l>H0n_3V00H0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP090?[`iP030000003j
l>H0n_3V00L0n_3V0P0000040?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0303j
l>H3000000d0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0Q0?[`iP40oooo000b
0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H01P3jl>H3000000030?[`iP000000
n_3V00/0n_3V00<000000?[`iP3jl>H0203jl>H200000080n_3V00<000000?[`iP3jl>H0203jl>H2
000000030?[`iP000000n_3V00/0n_3V00<000000?[`iP3jl>H0203jl>H<000000P0n_3V00<00000
0?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP040?[`iP8000001`3jl>H00`000000n_3V0?[`iP0<
0?[`iP030000003jl>H0n_3V00L0n_3V100000000`3jl>H000000?[`iP0=0?[`iP030000003jl>H0
n_3V00d0n_3V00<000000?[`iP3jl>H0803jl>H10?ooo`00<P3jl>H00`000000n_3V0?[`iP090?[`
iP030000003jl>H0n_3V00T0n_3V0`00000;0?[`iP030000003jl>H0n_3V00X0n_3V0P00000=0?[`
iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP000000n_3V
00T0n_3V0P0000050?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H00P3jl>H00`00
0000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0103jl>H30000
00H0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V
0200n_3V0@3oool00340n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP03
0000003jl>H0000000800000203jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00/0
n_3V0`00000=0?[`iP030000003jl>H0n_3V0080n_3V0P0000030?[`iP030000003jl>H0n_3V00X0
n_3V0`0000020?[`iP030000003jl>H0n_3V00h0n_3V00@000000?[`iP00000000002`3jl>H00`00
0000n_3V0?[`iP0<0?[`iP030000003jl>H0000000<000002@3jl>H00`000000n_3V0?[`iP0<0?[`
iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H07`3jl>H10?ooo`00<@3jl>H00`000000
n_3V0?[`iP090?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H00`3jl>H3000000D0
n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0;0?[`iP050000003jl>H0n_3V0?[`
iP000000303jl>H00`000000n_3V0?[`iP02000000D0n_3V00<000000?[`iP3jl>H03@3jl>H20000
0180n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`iP<000003@3jl>H00`00
0000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H07P3jl>H10?oo
o`00<@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3j
l>H01P3jl>H3000000030?[`iP000000n_3V00`0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP020?[`iP030000003jl>H0n_3V00X0n_3V0P0000070?[`iP030000003jl>H0n_3V00d0
n_3V00<000000?[`iP0000003`3jl>H3000000h0n_3V00<000000?[`iP3jl>H01`3jl>H300000003
0?[`iP000000n_3V00h0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0=0?[`iP03
0000003jl>H0n_3V01h0n_3V0@3oool00300n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V
0?[`iP0:0?[`iP030000003jl>H0n_3V00T0n_3V0`00000;0?[`iP030000003jl>H0n_3V00/0n_3V
00<000000?[`iP3jl>H0103jl>H2000000T0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V
0?[`iP0=0?[`iP040000003jl>H0n_3V000000d0n_3V00D000000?[`iP3jl>H0n_3V0000000=0?[`
iP030000003jl>H0n_3V00<0n_3V100000050?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`
iP3jl>H0303jl>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V01d0n_3V0@3oool00300
n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00/0
n_3V00<000000?[`iP0000000P0000080?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3j
l>H01P3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3j
l>H0303jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00P0n_3V0P0000040?[`iP03
0000003jl>H0n_3V00`0n_3V00<000000?[`iP0000000P0000090?[`iP030000003jl>H0n_3V00`0
n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V01d0
n_3V0@3oool00300n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0:0?[`iP030000
003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H00`3jl>H3000000D0n_3V00<000000?[`iP3jl>H0
2P3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V0080n_3V0P00000<0?[`iP030000
003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP070?[`iP030000
003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0303jl>H2000000`0n_3V00<000000?[`iP3jl>H0
303jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0
703jl>H10?ooo`00<03jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00X0n_3V00<0
00000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP060?[`iP<0000000<0n_3V0000003jl>H0303j
l>H00`000000n_3V0?[`iP090?[`iP80000000<0n_3V0000003jl>H03@3jl>H00`000000n_3V0?[`
iP0:0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0103jl>H2000000P0n_3V00<0
00000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00d0n_3V00<0
00000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V01/0n_3V0@3o
ool002l0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0
n_3V00X0n_3V00<000000?[`iP3jl>H02@3jl>H3000000/0n_3V00<000000?[`iP3jl>H0303jl>H0
0`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H01P3jl>H0
0`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0303jl>H0
0`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H03@3jl>H0
0`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V01/0n_3V0@3oool002l0n_3V0`00000:0?[`
iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0:0?[`
iP030000003jl>H0000000<000001`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H00000
00h0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP070?[`iP040000003jl>H00000
000000/0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0
n_3V00`0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0
n_3V01X0n_3V0@3oool002l0n_3V00<000000?[`iP3jl>H01P0000030?[`iP030000003jl>H0n_3V
00X0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V
00@0n_3V100000020?[`iP030000003jl>H0n_3V00`0n_3V00@000000?[`iP3jl>H000003@3jl>H0
0`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02`3jl>H0
0`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H03@3jl>H0
0`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H06P3jl>H1
0?ooo`00;P3jl>H00`000000n_3V0?[`iP070?[`iPH000002P3jl>H00`000000n_3V0?[`iP0:0?[`
iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0203jl>H4000000`0n_3V00<000000?[`
iP3jl>H00P3jl>H00`000000n_3V0?[`iP0:0?[`iP<000001`3jl>H00`000000n_3V0?[`iP0:0?[`
iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0<0?[`
iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0;0?[`
iPD000006`3jl>H10?ooo`00;P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00H0
00000`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3j
l>H02P3jl>H00`000000n_3V00000002000000T0n_3V00<000000?[`iP3jl>H00`3jl>H2000000P0
n_3V0`0000020?[`iP@000000`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00/0
n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00`0
n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP020?[`iPP00000103jl>H00`000000
n_3V0?[`iP0I0?[`iP40oooo000^0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0
1P3jl>H7000000X0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000
003jl>H0n_3V0080n_3V0`0000050?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0
103jl>H010000000n_3V0?[`iP0000060?[`iP<000003P3jl>H00`000000n_3V0?[`iP0;0?[`iP03
0000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0=0?[`iP03
0000003jl>H0n_3V00H0n_3V3000000;0?[`iP030000003jl>H0n_3V01X0n_3V0@3oool002h0n_3V
00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0:0?[`iP040000003jl>H0n_3V0?[`iPH0
00000`3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3j
l>H01@3jl>H300000080n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP020?[`iP03
0000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP0;0?[`iP03
0000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`iP03
0000003jl>H0n_3V00X0n_3V300000070?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3j
l>H06P3jl>H10?ooo`00;@3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00X0n_3V
00<000000?[`iP3jl>H01`3jl>H:000000H0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V
0?[`iP090?[`iP8000002`3jl>H010000000n_3V0000000000050?[`iP030000003jl>H0n_3V00H0
n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00/0
n_3V00<000000?[`iP3jl>H0303jl>H010000000n_3V0?[`iP3jl>H8000000<0n_3V00<000000?[`
iP3jl>H03@3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V01X0n_3V0@3oool002d0
n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00X0
n_3V00<000000?[`iP3jl>H0103jl>H7000000`0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000
n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000
n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0303jl>H00`000000
n_3V0?[`iP050?[`iPX000002`3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00d0
n_3V00<000000?[`iP3jl>H06`3jl>H10?ooo`00;@3jl>H00`000000n_3V0?[`iP0:0?[`iP030000
003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000
003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000
003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000
003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H01@3jl>H>000000H0n_3V00<000000?[`iP3jl>H0
303jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H0
6`3jl>H10?ooo`00;03jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00X0n_3V00<0
00000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00X0n_3V00<0
00000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00H0n_3V00<0
00000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00T0n_3V2`00
00060?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`
iP0<0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H06`3jl>H10?ooo`00;03jl>H0
0`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02P3jl>H0
0`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H0
0`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H02@3jl>H0
0`000000n_3V0?[`iP0:0?[`iP040000003jl>H0n_3V0?[`iPL000000`3jl>H00`000000n_3V0?[`
iP0;0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`
iP0=0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H06`3jl>H10?ooo`00;03jl>H0
0`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02P3jl>H0
0`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02@3jl>H0
0`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0203jl>H0
0`000000n_3V0?[`iP050?[`iPT000002P3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0
n_3V00/0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0
n_3V00`0n_3V00<000000?[`iP3jl>H0703jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP0;0?[`
iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`
iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0:0?[`
iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0103jl>H<000000D0n_3V00<000000?[`
iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`
iP3jl>H02`3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`
iP3jl>H0703jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00/0
n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00T0
n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00<0
n_3V300000050?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H0703jl>H10?ooo`00
:`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0
2P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0
2P3jl>H00`000000n_3V0?[`iP040?[`iP/000001@3jl>H00`000000n_3V0?[`iP080?[`iP030000
003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000
003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0<0?[`iP030000
003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H07@3jl>H10?ooo`00:`3jl>H00`000000n_3V0?[`
iP0:0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`
iP0:0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0103jl>H=000000D0n_3V00<0
00000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00X0n_3V00<0
00000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00X0n_3V00<0
00000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00`0n_3V00<0
00000?[`iP3jl>H07@3jl>H10?ooo`00:P3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0
n_3V00`0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP040?[`iQT000001P3jl>H0
0`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0203jl>H0
0`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02`3jl>H0
0`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H02`3jl>H0
0`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V01d0n_3V0@3oool002X0n_3V<@0000060?[`
iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP090?[`
iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0;0?[`
iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0:0?[`
iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0<0?[`
iP030000003jl>H0n_3V01h0n_3V0@3oool002X0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000
n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000
n_3V0?[`iP060?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000
n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0303jl>H00`000000
n_3V0?[`iP0N0?[`iP40oooo000[0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0
2`3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0
2@3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0
1P3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0
2P3jl>H00`000000n_3V0?[`iP0<0?[`iP@000002@3jl>H00`000000n_3V0?[`iP0;0?[`iP030000
003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0N0?[`iP40oooo
000[0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`
iP090?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`
iP0;0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`
iP050?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`
iP0<0?[`iP040000003jl>H0n_3V0?[`iPH000000`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000
003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0N0?[`iP40oooo
000/0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`
iP0:0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`
iP0;0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`
iP050?[`iP030000003jl>H0n_3V00`0n_3V0P00000;0?[`iP030000003jl>H0n_3V00/0n_3V00<0
00000?[`iP3jl>H0203jl>H:000000L0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`
iP0<0?[`iP030000003jl>H0n_3V01l0n_3V0@3oool002`0n_3V00<000000?[`iP3jl>H02`3jl>H0
0`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H0
0`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02`3jl>H2
000000H0n_3V00<000000?[`iP3jl>H00`3jl>H2000000030?[`iP000000n_3V00/0n_3V00<00000
0?[`iP3jl>H00P0000090?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02`3jl>H0
0`000000n_3V0?[`iP040?[`iPh000001`3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0
n_3V01l0n_3V0@3oool002`0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`
iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`
iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP020000
00@0n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP030000003jl>H0n_3V00T0n_3V00<00000
0?[`iP3jl>H00P3jl>H3000000H0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;
0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0103jl>H;000000/0n_3V00<00000
0?[`iP3jl>H07`3jl>H10?ooo`00;@3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V
00/0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V
00T0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
00<0n_3V0`0000000`3jl>H000000?[`iP02000000L0n_3V00<000000?[`iP3jl>H01`3jl>H00`00
0000n_3V0?[`iP060?[`iP<000000`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V
00X0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0;0?[`iP040000003jl>H0n_3V
0?[`iPL000000`3jl>H00`000000n_3V0?[`iP0P0?[`iP40oooo000]0?[`iP030000003jl>H0n_3V
00/0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V
00/0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP080?[`iP80000000<0n_3V0000
003jl>H0203jl>H00`000000n_3V0?[`iP060?[`iP<000002P3jl>H00`000000n_3V0?[`iP060?[`
iP030000003jl>H0n_3V00T0n_3V0P0000000`3jl>H000000?[`iP0;0?[`iP030000003jl>H0n_3V
00/0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V
00T0n_3V1000000R0?[`iP40oooo000]0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3j
l>H02`3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V0`00000<0?[`iP03
0000003jl>H0n_3V00H0n_3V0P0000030?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3j
l>H0203jl>H00`000000n_3V0?[`iP0:0?[`iP8000001@3jl>H00`000000n_3V0?[`iP0<0?[`iP<0
00002`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3j
l>H02`3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V0200n_3V0@3oool002h0n_3V
00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00X0n_3V
00<000000?[`iP3jl>H0103jl>H400000080n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V
0?[`iP040?[`iP8000001P3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V00T0n_3V
00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00`0n_3V
00<000000?[`iP3jl>H00`0000080?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0
2`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0
8@3jl>H10?ooo`00;P3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00X0n_3V00<0
00000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP04000000L0n_3V00<000000?[`iP3jl>H02@3j
l>H00`000000n_3V0?[`iP020?[`iP800000203jl>H00`000000n_3V0?[`iP030?[`iP030000003j
l>H0n_3V00X0n_3V00<000000?[`iP3jl>H03@3jl>H010000000n_3V0?[`iP00000?0?[`iP030000
003jl>H0n_3V00<0n_3V0`0000050?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0
303jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0
8@3jl>H10?ooo`00;`3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00X0n_3V00<0
00000?[`iP3jl>H02@3jl>H4000000/0n_3V00<000000?[`iP3jl>H02P3jl>H010000000n_3V0000
0000000;0?[`iP050000003jl>H0n_3V0?[`iP0000003P3jl>H00`000000n_3V0?[`iP0=0?[`iP03
0000003jl>H0000000h0n_3V00<000000?[`iP3jl>H01`3jl>H3000000030?[`iP000000n_3V00`0
n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00`0
n_3V00<000000?[`iP3jl>H08@3jl>H10?ooo`00;`3jl>H00`000000n_3V0?[`iP0:0?[`iP030000
003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0103jl>H4000000030?[`iP000000n_3V00`0n_3V
00<000000?[`iP3jl>H02P3jl>H2000000h0n_3V00@000000?[`iP3jl>H000003P3jl>H00`000000
n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H02P3jl>H3000000`0
n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00/0
n_3V00<000000?[`iP3jl>H08P3jl>H10?ooo`00;`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000
003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0100000060?[`iP030000003jl>H0n_3V00X0n_3V
00<000000?[`iP3jl>H0203jl>H2000000030?[`iP000000n_3V00d0n_3V00<000000?[`iP000000
3`3jl>H00`000000n_3V0?[`iP0<0?[`iP80000000<0n_3V0000003jl>H0303jl>H00`000000n_3V
0?[`iP0<0?[`iP030000003jl>H00000008000002@3jl>H00`000000n_3V0?[`iP0;0?[`iP030000
003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0R0?[`iP40oooo
000`0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02@3jl>H4000000X0n_3V00<0
00000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP050?[`iP8000000`3jl>H00`000000n_3V0?[`
iP0=0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`
iP020?[`iP8000002`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00<0n_3V1000
00040?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`
iP0<0?[`iP030000003jl>H0n_3V0280n_3V0@3oool00300n_3V00<000000?[`iP3jl>H02P3jl>H0
0`000000n_3V0?[`iP050?[`iP@0000000<0n_3V0000003jl>H0303jl>H00`000000n_3V0?[`iP0:
0?[`iP030000003jl>H0n_3V00<0n_3V0P0000060?[`iP030000003jl>H0n_3V00/0n_3V00@00000
0?[`iP00000000003P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00D0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00L0n_3V0`00
00000`3jl>H000000?[`iP0<0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02`3j
l>H00`000000n_3V0?[`iP0S0?[`iP40oooo000`0?[`iP030000003jl>H0n_3V00/0n_3V00<00000
0?[`iP3jl>H0100000060?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H0
10000000n_3V0?[`iP3jl>H2000000T0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`
iP020?[`iP800000303jl>H00`000000n_3V0?[`iP080?[`iP8000002@3jl>H00`000000n_3V0?[`
iP060?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02`3jl>H3000000`0n_3V00<0
00000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V02<0n_3V0@3o
ool00340n_3V00<000000?[`iP3jl>H02@3jl>H4000000X0n_3V00<000000?[`iP3jl>H02P3jl>H0
0`000000n_3V0?[`iP0;0?[`iP<00000303jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0
n_3V00@0n_3V0P00000;0?[`iP030000003jl>H0n_3V00D0n_3V0P00000<0?[`iP030000003jl>H0
n_3V00@0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0<0?[`iP040000003jl>H0
0000000000X0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003j
l>H0n_3V02<0n_3V0@3oool00340n_3V00<000000?[`iP3jl>H01@3jl>H4000000030?[`iP000000
n_3V00`0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0
n_3V00`0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP070?[`iP@000001`3jl>H0
0`000000n_3V0?[`iP020?[`iP<0000000<0n_3V0000003jl>H0303jl>H00`000000n_3V0?[`iP03
0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP02
0?[`iP<000001`3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00/0n_3V00<00000
0?[`iP3jl>H0903jl>H10?ooo`00<P3jl>H00`000000n_3V0?[`iP04000000H0n_3V00<000000?[`
iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00P0n_3V0P0000000`3j
l>H000000?[`iP0=0?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H02@3jl>H00`00
0000n_3V0?[`iP0500000080n_3V00<000000?[`iP0000000P0000050?[`iP030000003jl>H0n_3V
00/0n_3V0P0000020?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0303jl>H00`00
0000n_3V0?[`iP050?[`iP<000000`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V
00/0n_3V00<000000?[`iP3jl>H0903jl>H10?ooo`00<P3jl>H3000000X0n_3V00<000000?[`iP3j
l>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00H0n_3V0P0000030?[`iP03
0000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP090?[`iP03
0000003jl>H0n_3V00H0n_3V100000080?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP00
00003P3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00T0n_3V0P0000000`3jl>H0
00000?[`iP0;0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0903jl>H10?ooo`00
<P3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0
2P3jl>H00`000000n_3V0?[`iP030?[`iP8000001P3jl>H00`000000n_3V0?[`iP0=0?[`iP050000
003jl>H0n_3V0?[`iP000000303jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0
n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00`0
n_3V00<000000?[`iP3jl>H02`3jl>H3000000/0n_3V00<000000?[`iP3jl>H0303jl>H00`000000
n_3V0?[`iP0T0?[`iP40oooo000c0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0
2P3jl>H00`000000n_3V0?[`iP0:0?[`iP040000003jl>H0n_3V0?[`iP800000203jl>H00`000000
n_3V0?[`iP0=0?[`iP050000003jl>H0n_3V0?[`iP000000303jl>H00`000000n_3V0?[`iP080?[`
iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0000000=0?[`
iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V000000020000
00P0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0U0?[`iP40oooo000c0?[`iP03
0000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0:0?[`iP<0
00002`3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0000000`0n_3V00<000000?[`iP3j
l>H02@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00T0n_3V0P0000030?[`iP03
0000003jl>H0n_3V00T0n_3V00@000000?[`iP00000000002`3jl>H00`000000n_3V0?[`iP0<0?[`
iP030000003jl>H0n_3V00<0n_3V0`0000050?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`
iP3jl>H09@3jl>H10?ooo`00=03jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00X0
n_3V00<000000?[`iP3jl>H02@3jl>H2000000d0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000
n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000
n_3V0?[`iP080?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0203jl>H010000000
n_3V0?[`iP3jl>H2000000T0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP060?[`
iP<0000000<0n_3V0000003jl>H03@3jl>H00`000000n_3V0?[`iP0U0?[`iP40oooo000d0?[`iP03
0000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP070?[`iP80
000000<0n_3V0000003jl>H03@3jl>H00`000000n_3V0?[`iP0<0?[`iP040000003jl>H000000000
00/0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V
00H0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V
00@0n_3V00<000000?[`iP3jl>H01P3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V
00X0n_3V0`00000<0?[`iP030000003jl>H0n_3V02H0n_3V0@3oool003D0n_3V00<000000?[`iP3j
l>H02@3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00@0n_3V0P0000040?[`iP03
0000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP020?[`iP80
00002@3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3j
l>H0103jl>H2000000X0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP050?[`iP80
00001@3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP00
00000P0000090?[`iP030000003jl>H0n_3V02H0n_3V0@3oool003D0n_3V00<000000?[`iP3jl>H0
2P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V0080n_3V0P0000060?[`iP030000
003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP040?[`iP030000
003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0:0?[`iP030000
003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP030?[`iP030000
003jl>H0n_3V00P0n_3V0P0000030?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0
2P3jl>H00`000000n_3V0?[`iP030?[`iP@000001@3jl>H00`000000n_3V0?[`iP0V0?[`iP40oooo
000f0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H02`3jl>H010000000n_3V0000
000000090?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP0000002P3jl>H00`000000n_3V
0?[`iP060?[`iP8000001@3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00X0n_3V
00D000000?[`iP3jl>H0n_3V0000000?0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3j
l>H02P3jl>H3000000h0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP070?[`iP<0
000000<0n_3V0000003jl>H0:03jl>H10?ooo`00=P3jl>H00`000000n_3V0?[`iP0:0?[`iP030000
003jl>H0n_3V00X0n_3V0P00000;0?[`iP030000003jl>H0n_3V00T0n_3V00@000000?[`iP3jl>H0
00002@3jl>H00`000000n_3V0?[`iP090?[`iP8000000`3jl>H00`000000n_3V0?[`iP0;0?[`iP03
0000003jl>H0n_3V00/0n_3V0`00000A0?[`iP040000003jl>H0n_3V000000l0n_3V00<000000?[`
iP3jl>H0303jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00X0n_3V0P00000Y0?[`
iP40oooo000f0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0203jl>H3000000d0
n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00D0
n_3V00<000000?[`iP3jl>H0303jl>H3000000h0n_3V00<000000?[`iP3jl>H02@3jl>H3000001@0
n_3V00<000000?[`iP0000003P3jl>H010000000n_3V00000000000<0?[`iP030000003jl>H0n_3V
00X0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0W0?[`iP40oooo000g0?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H01P3jl>H2000000<0n_3V00<000000?[`iP3j
l>H02P3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3j
l>H00`3jl>H00`000000n_3V0?[`iP0?0?[`iP@000002`3jl>H00`000000n_3V0?[`iP050?[`iP@0
00000`3jl>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V00d0n_3V00D000000?[`iP3j
l>H0n_3V0000000:0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02`3jl>H00`00
0000n_3V0?[`iP0X0?[`iP40oooo000g0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3j
l>H00`3jl>H2000000D0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP030?[`iP80
0000203jl>H01@000000n_3V0?[`iP3jl>H000000180n_3V00@000000?[`iP3jl>H0n_3V20000003
0?[`iP030000003jl>H0n_3V00D000001`3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0
000000d0n_3V00<000000?[`iP3jl>H00`3jl>H2000000P0n_3V00<000000?[`iP3jl>H02`3jl>H0
0`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V02P0n_3V0@3oool003P0n_3V00<000000?[`
iP3jl>H02@3jl>H010000000n_3V0?[`iP3jl>H2000000P0n_3V00<000000?[`iP3jl>H02P3jl>H0
0`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00P0n_3V00D000000?[`iP3jl>H0n_3V0000
000A0?[`iP030000003jl>H0n_3V00X0n_3V1P00000=0?[`iP030000003jl>H0n_3V00l0n_3V00D0
00000?[`iP3jl>H0n_3V0000000;0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0
103jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0
:03jl>H10?ooo`00>03jl>H00`000000n_3V0?[`iP0:0?[`iP<000002P3jl>H00`000000n_3V0?[`
iP0;0?[`iP040000003jl>H0n_3V000000`0n_3V00<000000?[`iP0000004P3jl>H00`000000n_3V
0?[`iP0=0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H03@3jl>H2000000D0n_3V
00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP800000103jl>H00`000000n_3V
0?[`iP0;0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00>@3j
l>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02P3j
l>H00`000000n_3V0000000>0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H03@3j
l>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H01P3j
l>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V00X0n_3V00D000000?[`iP3jl>H0n_3V
0000000=0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00>@3j
l>H00`000000n_3V0?[`iP070?[`iP<000003@3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003j
l>H0n_3V00`0n_3V00@000000?[`iP00000000004@3jl>H00`000000n_3V0?[`iP0=0?[`iP030000
003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP080?[`iP800000
1P3jl>H00`000000n_3V0?[`iP0;0?[`iP<000003P3jl>H00`000000n_3V0?[`iP0;0?[`iP030000
003jl>H0n_3V02T0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H0103jl>H2000000<0n_3V00<0
00000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0000000`0n_3V00<0
00000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V00h0n_3V00<0
00000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP070?[`iP8000003@3jl>H00`000000n_3V0?[`
iP020?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`
iP0;0?[`iP030000003jl>H0n_3V02X0n_3V0@3oool003X0n_3V00<000000?[`iP3jl>H00P3jl>H2
000000D0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP070?[`iP8000000`3jl>H0
0`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00<0n_3V0P00000=0?[`iP030000003jl>H0
n_3V00h0n_3V00<000000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP050?[`iP8000000P3jl>H0
0`000000n_3V0?[`iP0;0?[`iP040000003jl>H0n_3V00000100n_3V00@000000?[`iP0000000000
2`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V02X0n_3V0@3oool003/0n_3V00@0
00000?[`iP0000000000203jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00D0n_3V
00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V00H0n_3V
0P00000;0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V
0?[`iP020?[`iP800000103jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H000000100n_3V
00@000000?[`iP3jl>H0n_3V0P0000090?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3j
l>H0:P3jl>H10?ooo`00>`3jl>H2000000X0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V
0?[`iP040?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V
0?[`iP090?[`iP8000002@3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00l0n_3V
00<000000?[`iP3jl>H00P0000070?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0
3P3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H0
2`3jl>H00`000000n_3V0?[`iP0[0?[`iP40oooo000k0?[`iP030000003jl>H0n_3V00X0n_3V00<0
00000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00L0n_3V00<0
00000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00<000001@3j
l>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V00l0n_3V0`00000:0?[`iP030000003j
l>H0n_3V00X0n_3V00<000000?[`iP0000003`3jl>H00`000000n_3V0?[`iP050?[`iP8000001@3j
l>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V02/0n_3V0@3oool003`0n_3V00<00000
0?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V008000002`3jl>H0
0`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H00`3jl>H4
000000030?[`iP000000n_3V0140n_3V00<000000?[`iP3jl>H0303jl>H3000000030?[`iP000000
n_3V00/0n_3V00<000000?[`iP3jl>H0203jl>H01@000000n_3V0?[`iP3jl>H0000000d0n_3V00<0
00000?[`iP3jl>H0203jl>H2000000<0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`
iP0[0?[`iP40oooo000l0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02`3jl>H2
000000h0n_3V00D000000?[`iP3jl>H0n_3V0000000;0?[`iP030000003jl>H0n_3V00P0n_3V1000
000@0?[`iP030000003jl>H0n_3V00T0n_3V0`0000050?[`iP030000003jl>H0n_3V00T0n_3V00<0
00000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V00T0n_3V00<0
00000?[`iP3jl>H02`3jl>H3000000h0n_3V00<000000?[`iP3jl>H0:`3jl>H10?ooo`00?@3jl>H0
0`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H03P3jl>H0
0`000000n_3V0000000<0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H01@00000;
0?[`iP030000003jl>H0n_3V00D0n_3V100000080?[`iP030000003jl>H0n_3V00X0n_3V00<00000
0?[`iP3jl>H0103jl>H2000000L0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0=
0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0;03jl>H10?ooo`00?@3jl>H00`00
0000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP000000403jl>H00`00
0000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H01P3jl>H70000
00@0n_3V00<000000?[`iP3jl>H01@0000020?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`
iP3jl>H02P3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00P0n_3V0P0000070?[`
iP030000003jl>H0n_3V00h0n_3V0`00000;0?[`iP030000003jl>H0n_3V02`0n_3V0@3oool003d0
n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP080?[`iP040000003jl>H0n_3V0000
00l0n_3V00@000000?[`iP00000000002P3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0
n_3V00P0n_3V00<000000?[`iP3jl>H00P3jl>H7000000P0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP0;0?[`iP040000003jl>H0n_3V000000d0n_3V00<000000?[`iP3jl>H00`3j
l>H00`000000n_3V0?[`iP0>0?[`iP040000003jl>H0n_3V0?[`iP8000002@3jl>H00`000000n_3V
0?[`iP0/0?[`iP40oooo000n0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H01`3j
l>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H00P3j
l>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H0203j
l>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203j
l>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0000000l0n_3V00<000000?[`iP3jl>H00P3j
l>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H01@3j
l>H00`000000n_3V0?[`iP0]0?[`iP40oooo000n0?[`iP030000003jl>H0n_3V00X0n_3V00<00000
0?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V00X0n_3V00<00000
0?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V00T0n_3V00<00000
0?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V00P0n_3V00<00000
0?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0:0?[`iP8000004@3jl>H010000000n_3V0?[`iP00
000@0?[`iP030000003jl>H0n_3V00D0n_3V0P0000050?[`iP030000003jl>H0n_3V02d0n_3V0@3o
ool003h0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP030?[`iP800000203jl>H0
0`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00D0n_3V0P0000040?[`iP030000003jl>H0
n_3V00X0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0
n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP8000000P3jl>H0
0`000000n_3V0?[`iP0?0?[`iP030000003jl>H000000100n_3V00<000000?[`iP3jl>H01`3jl>H2
000000<0n_3V00<000000?[`iP3jl>H0;@3jl>H10?ooo`00?`3jl>H00`000000n_3V0?[`iP0:0?[`
iP050000003jl>H0n_3V0?[`iP0000002P3jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0
n_3V00P0n_3V00D000000?[`iP3jl>H0n_3V0000000<0?[`iP030000003jl>H0n_3V00P0n_3V00<0
00000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00P0n_3V00<0
00000?[`iP3jl>H01@3jl>H2000000D0n_3V00<000000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`
iP0?0?[`iP030000003jl>H0n_3V00T0n_3V0`00000`0?[`iP40oooo000o0?[`iP030000003jl>H0
n_3V00X0n_3V00@000000?[`iP3jl>H00000303jl>H00`000000n_3V0?[`iP050?[`iP030000003j
l>H0n_3V00X0n_3V0`00000=0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203j
l>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H00P3j
l>H2000000L0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0000000?0?[`iP030000003j
l>H0n_3V00`0n_3V00<000000?[`iP3jl>H0;P3jl>H10?ooo`00@03jl>H00`000000n_3V0?[`iP0:
0?[`iP8000003P3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V00d0n_3V0P00000;
0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP08
0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H00P00000:0?[`iP030000003jl>H0
n_3V00/0n_3V0P0000030?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0303jl>H0
0`000000n_3V0?[`iP0^0?[`iP40oooo00100?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`
iP3jl>H03P3jl>H01@000000n_3V0?[`iP3jl>H0000000l0n_3V00<000000?[`iP3jl>H00`000008
0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP09
0?[`iP030000003jl>H0n_3V00P0n_3V0`00000=0?[`iP030000003jl>H0n_3V00T0n_3V00<00000
0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00`0n_3V00<00000
0?[`iP3jl>H0;`3jl>H10?ooo`00@03jl>H00`000000n_3V0?[`iP090?[`iP800000403jl>H01@00
0000n_3V0?[`iP3jl>H0000000l0n_3V00<000000?[`iP3jl>H00`3jl>H3000000D0n_3V00<00000
0?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00T0n_3V00<00000
0?[`iP3jl>H01@3jl>H3000000030?[`iP000000n_3V00h0n_3V00<000000?[`iP3jl>H01`3jl>H0
0`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H0303jl>H0
0`000000n_3V0?[`iP0_0?[`iP40oooo00110?[`iP030000003jl>H0n_3V00H0n_3V0P0000020?[`
iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP0000003`3jl>H00`000000n_3V0?[`iP070?[`
iP<0000000<0n_3V0000003jl>H02P3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V
00T0n_3V00<000000?[`iP3jl>H00`3jl>H2000000D0n_3V00<000000?[`iP3jl>H03@3jl>H00`00
0000n_3V0?[`iP050?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0203jl>H00`00
0000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool00440n_3V00<000000?[`iP3j
l>H01@3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3j
l>H03P3jl>H00`000000n_3V0?[`iP0:0?[`iP@000002@3jl>H00`000000n_3V0?[`iP0:0?[`iP03
0000003jl>H0n_3V00T0n_3V00<000000?[`iP0000000P0000070?[`iP030000003jl>H0n_3V00h0
n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0:0?[`iP8000001`3jl>H00`000000
n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V0300n_3V0@3oool00440n_3V00<000000?[`iP3jl>H0
103jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V00d0n_3V00@000000?[`iP000000
00003@3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00H000000`3jl>H00`000000
n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00L0n_3V1000000;0?[`iP030000003jl>H0n_3V00d0
n_3V00@000000?[`iP3jl>H0n_3V0P00000?0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`
iP3jl>H0303jl>H00`000000n_3V0?[`iP0`0?[`iP40oooo00120?[`iP030000003jl>H0n_3V0080
n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V0080
n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00L0
n_3V2P0000060?[`iP040000003jl>H0n_3V0?[`iPH000000P3jl>H00`000000n_3V0?[`iP0:0?[`
iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP0000004P3jl>H00`000000n_3V0?[`iP030?[`
iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0<03jl>H10?ooo`00@P3jl>H00`000000
n_3V0?[`iP02000000T0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP040?[`iP80
00002@3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3j
l>H0103jl>H:000000P0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0=0?[`iP80
0000503jl>H01@000000n_3V0?[`iP3jl>H0000000h0n_3V00<000000?[`iP3jl>H0<@3jl>H10?oo
o`00@`3jl>H2000000/0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP060?[`iP03
0000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP0:0?[`iP03
0000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0:0?[`iP03
0000003jl>H0n_3V00/0n_3V0P0000020?[`iP030000003jl>H0n_3V0180n_3V00@000000?[`iP3j
l>H000003P3jl>H00`000000n_3V0?[`iP0a0?[`iP40oooo00130?[`iP030000003jl>H0n_3V00/0
n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP080?[`iP8000001@3jl>H00`000000
n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000
n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0203jl>H2000000D0
n_3V00<000000?[`iP3jl>H04P3jl>H2000000l0n_3V00<000000?[`iP3jl>H0<@3jl>H10?ooo`00
@`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0
2`3jl>H01@000000n_3V0?[`iP3jl>H0000000l0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00X0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP050?[`iP<000001`3jl>H00`000000n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V00`0
n_3V00<000000?[`iP3jl>H0<P3jl>H10?ooo`00A03jl>H00`000000n_3V0?[`iP0;0?[`iP030000
003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H03@3jl>H2000000030?[`iP000000n_3V00h0n_3V
00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00X0n_3V
00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP020?[`iP8000002`3jl>H00`000000n_3V
0?[`iP0@0?[`iP80000000<0n_3V0000003jl>H0303jl>H00`000000n_3V0?[`iP0b0?[`iP40oooo
00140?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`
iP0@0?[`iP8000003P3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00X0n_3V00<0
00000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V008000003P3j
l>H00`000000n_3V0?[`iP0=0?[`iP800000103jl>H00`000000n_3V0?[`iP0:0?[`iP030000003j
l>H0n_3V0380n_3V0@3oool004D0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP02
0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H01000000:0?[`iP030000003jl>H0
n_3V00/0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0
n_3V00/0n_3V0`00000A0?[`iP030000003jl>H0n_3V00X0n_3V0P0000070?[`iP030000003jl>H0
n_3V00T0n_3V00<000000?[`iP3jl>H0<P3jl>H10?ooo`00A@3jl>H00`000000n_3V0?[`iP0;0?[`
iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP040?[`
iP@000001P3jl>H00`000000n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`
iP3jl>H02`3jl>H00`000000n_3V0?[`iP080?[`iP<000000P3jl>H00`000000n_3V0?[`iP0@0?[`
iP030000003jl>H0n_3V00L0n_3V0P00000:0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`
iP3jl>H0<`3jl>H10?ooo`00AP3jl>H00`000000n_3V0?[`iP0;0?[`iP040000003jl>H0n_3V0000
0180n_3V00<000000?[`iP3jl>H02@3jl>H4000000030?[`iP000000n_3V00d0n_3V00<000000?[`
iP3jl>H0303jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00H0n_3V0P0000050?[`
iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H0103jl>H2000000d0n_3V00<000000?[`
iP3jl>H01P3jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo00160?[`iP030000003jl>H0n_3V00/0
n_3V00<000000?[`iP0000004`3jl>H00`000000n_3V0?[`iP0=0?[`iP<000003@3jl>H00`000000
n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP3jl>H00P3jl>H3000000P0
n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP020?[`iP800000403jl>H2000000H0
n_3V00<000000?[`iP3jl>H0<`3jl>H10?ooo`00A`3jl>H00`000000n_3V0?[`iP0;0?[`iP800000
4P3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0000000<000002@3jl>H00`000000n_3V
0?[`iP0<0?[`iP030000003jl>H0n_3V00/0n_3V00<000000?[`iP0000000P00000;0?[`iP030000
003jl>H0n_3V0140n_3V00@000000?[`iP0000000000503jl>H00`000000n_3V0?[`iP020?[`iP03
0000003jl>H0n_3V03@0n_3V0@3oool004L0n_3V00<000000?[`iP3jl>H02P3jl>H00`000000n_3V
0?[`iP03000000l0n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP040?[`iP@00000
1@3jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00T0n_3V1000000?0?[`iP030000
003jl>H0n_3V0100n_3V0P00000G0?[`iP050000003jl>H0n_3V0?[`iP000000=P3jl>H10?ooo`00
A`3jl>H00`000000n_3V0?[`iP090?[`iP030000003jl>H0n_3V00@0n_3V0`00000;0?[`iP030000
003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0203jl>H4000000030?[`iP000000n_3V00d0n_3V
00<000000?[`iP3jl>H01@3jl>H400000080n_3V00<000000?[`iP3jl>H03P3jl>H00`000000n_3V
0?[`iP0=0?[`iP<000000P3jl>H00`000000n_3V0?[`iP0E0?[`iP040000003jl>H0n_3V000003H0
n_3V0@3oool004P0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP070?[`iP800000
2@3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00`0n_3V2@0000070?[`iP030000
003jl>H0n_3V00D000001`3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00T0n_3V
0`0000050?[`iP030000003jl>H0n_3V01H0n_3V0P00000g0?[`iP40oooo00180?[`iP030000003j
l>H0n_3V00L0n_3V00<000000?[`iP3jl>H02P3jl>H3000000D0n_3V00<000000?[`iP3jl>H0403j
l>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V00D0n_3V2P00000<0?[`iP030000003j
l>H0n_3V00h0n_3V00<000000?[`iP3jl>H01`3jl>H2000000T0n_3V00<000000?[`iP3jl>H05@3j
l>H2000003L0n_3V0@3oool004T0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0>
0?[`iP<000000P3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00h0n_3V00<00000
0?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP0<0?[`iP030000003jl>H0n_3V00l0n_3V00<00000
0?[`iP3jl>H00`3jl>H3000000`0n_3V00<000000?[`iP3jl>H04P3jl>H2000003T0n_3V0@3oool0
04T0n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0B0?[`iP<000004@3jl>H00`00
0000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H03@3jl>H00`00
0000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00<00000403jl>H00`000000n_3V0?[`iP0?0?[`
iP800000>`3jl>H10?ooo`00BP3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0180
n_3V00<000000?[`iP3jl>H01000000=0?[`iP030000003jl>H0n_3V00h0n_3V00<000000?[`iP3j
l>H0303jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V00h0n_3V0`00000C0?[`iP03
0000003jl>H0n_3V00`0n_3V0`00000m0?[`iP40oooo001:0?[`iP030000003jl>H0n_3V0080n_3V
00<000000?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP040?[`iP<000002P3jl>H00`000000n_3V
0?[`iP0>0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V
0?[`iP0<0?[`iP8000000P3jl>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V00T0n_3V
0P0000100?[`iP40oooo001;0?[`iP040000003jl>H0n_3V000001D0n_3V00<000000?[`iP3jl>H0
203jl>H4000000D0n_3V00<000000?[`iP3jl>H03`3jl>H00`000000n_3V0?[`iP0=0?[`iP030000
003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H02P3jl>H2000000@0n_3V00<000000?[`iP3jl>H0
4`3jl>H00`000000n_3V0?[`iP050?[`iP<00000@P3jl>H10?ooo`00B`3jl>H00`000000n_3V0000
000F0?[`iP030000003jl>H0n_3V00`0n_3V100000000`3jl>H000000?[`iP0?0?[`iP030000003j
l>H0n_3V00h0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP070?[`iP8000001`3j
l>H00`000000n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V0080n_3V0P0000150?[`iP40oooo001<
0?[`iP8000005@3jl>H00`000000n_3V0?[`iP0A0?[`iP<000003`3jl>H00`000000n_3V0?[`iP0>
0?[`iP030000003jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H0103jl>H3000000T0n_3V00<00000
0?[`iP3jl>H04`3jl>H00`000000n_3V0?[`iP02000004L0n_3V0@3oool004`0n_3V0P00000E0?[`
iP030000003jl>H0n_3V0180n_3V00<000000?[`iP0000000`00000;0?[`iP030000003jl>H0n_3V
00h0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP020?[`iP8000003@3jl>H00`00
0000n_3V0?[`iP0B0?[`iP<00000B@3jl>H10?ooo`00CP3jl>H300000140n_3V00<000000?[`iP3j
l>H04P3jl>H00`000000n_3V0?[`iP040?[`iP<00000203jl>H00`000000n_3V0?[`iP0>0?[`iP03
0000003jl>H0n_3V00h0n_3V00@000000?[`iP00000000003`3jl>H00`000000n_3V0?[`iP0@0?[`
iP800000C03jl>H10?ooo`00D@3jl>H4000000d0n_3V00<000000?[`iP3jl>H04P3jl>H00`000000
n_3V0?[`iP070?[`iP<000001@3jl>H00`000000n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00d0
n_3V0`00000B0?[`iP030000003jl>H0n_3V00`0n_3V0`00001>0?[`iP40oooo001E0?[`iP<00000
2@3jl>H00`000000n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V00X0n_3V100000000`3jl>H00000
0?[`iP0?0?[`iP030000003jl>H0n_3V00X0n_3V0`0000000`3jl>H000000?[`iP0C0?[`iP030000
003jl>H0n_3V00T0n_3V0P00001A0?[`iP40oooo001H0?[`iP<000001P3jl>H00`000000n_3V0?[`
iP0B0?[`iP030000003jl>H0n_3V00l0n_3V1000000?0?[`iP030000003jl>H0n_3V00H0n_3V0`00
00050?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H01P3jl>H3000005<0n_3V0@3o
ool005/0n_3V100000000`3jl>H000000?[`iP0D0?[`iP030000003jl>H0n_3V0100n_3V00<00000
0?[`iP3jl>H01P0000090?[`iP030000003jl>H0n_3V0080n_3V100000080?[`iP030000003jl>H0
n_3V0180n_3V00<000000?[`iP3jl>H00P3jl>H3000005H0n_3V0@3oool005l0n_3V0`00000D0?[`
iP030000003jl>H0n_3V0100n_3V00<000000?[`iP3jl>H01P3jl>H6000000<0n_3V00<000000?[`
iP0000000P00000<0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H00P00001I0?[`
iP40oooo001R0?[`iP@000003`3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00`0
n_3V1@00000@0?[`iP030000003jl>H0n_3V0140n_3V0`00001K0?[`iP40oooo001V0?[`iP@00000
2`3jl>H00`000000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0
3`3jl>H00`000000n_3V0?[`iP0>0?[`iP<00000GP3jl>H10?ooo`00JP3jl>H4000000L0n_3V00<0
00000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00l0n_3V00<0
00000?[`iP3jl>H0303jl>H200000640n_3V0@3oool006h0n_3V100000020?[`iP030000003jl>H0
n_3V0140n_3V00<000000?[`iP3jl>H0403jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0
n_3V00P0n_3V0`00001S0?[`iP40oooo001b0?[`iP@000004P3jl>H00`000000n_3V0?[`iP0A0?[`
iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H01@3jl>H3000006H0n_3V0@3oool007H0
n_3V1000000>0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H03`3jl>H00`000000
n_3V0?[`iP030?[`iP800000J@3jl>H10?ooo`00NP3jl>H4000000X0n_3V00<000000?[`iP3jl>H0
4@3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0000000800000J`3jl>H10?ooo`00OP3j
l>H4000000H0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0?0?[`iP<00000KP3j
l>H10?ooo`00PP3jl>H400000080n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0=
0?[`iP800000L@3jl>H10?ooo`00QP3jl>H500000140n_3V00<000000?[`iP3jl>H02P3jl>H30000
07<0n_3V0@3oool008/0n_3V1000000=0?[`iP030000003jl>H0n_3V00P0n_3V0P00001f0?[`iP40
oooo002?0?[`iP@000002P3jl>H00`000000n_3V0?[`iP040?[`iP<00000N03jl>H10?ooo`00T`3j
l>H4000000H0n_3V00@000000?[`iP3jl>H0n_3V0`00001k0?[`iP40oooo002G0?[`iP@000000P3j
l>H010000000n_3V00000000001n0?[`iP40oooo002K0?[`iP@00000P03jl>H10?ooo`00o`3jl>HP
0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo
003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00
n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool0
0?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803j
l>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00
o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`
iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o
0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V
0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0
n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H1
0?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.0001, -10.0001, 0.0696871, \
0.0696871}}]
}, Open  ]],

Cell["\<\
The next example is a grid on a sinoval curve, parametrized as follows:\
\>", "Text"],

Cell[BoxData[
    \(\(sinoval[n_, a_]\)[t_] := {a\ Cos[t], a\ Nest[Sin, t, n]}\)], "Input",
  CellLabel->"In[315]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(grid = 
        HollisGrid[\(sinoval[5, 7]\)[t], {t, 0, 2  \[Pi]}, 
          GridExtraSmoothing \[Rule] True, 
          PlotPoints \[Rule] 64];\)\), "\[IndentingNewLine]", 
    \(\(Draw2D[\[IndentingNewLine]{PaleGreen, 
          Polygon /@ grid, \[IndentingNewLine]Black, 
          Line /@ grid}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 
                1}, {\(-1\), 1}} 10, \[IndentingNewLine]Background \[Rule] 
          Linen];\)\)}], "Input",
  CellLabel->"In[316]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.05 0.5 0.05 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.596 .984 .596 r
.82615 .53177 m
.82773 .5 L
.85 .5 L
.84831 .53409 L
F
.82143 .5621 m
.82615 .53177 L
.84831 .53409 L
.84327 .5666 L
F
.81362 .58981 m
.82143 .5621 L
.84327 .5666 L
.83493 .59625 L
F
.80278 .61413 m
.81362 .58981 L
.83493 .59625 L
.82336 .62223 L
F
.78903 .63476 m
.80278 .61413 L
.82336 .62223 L
.80867 .64423 L
F
.7725 .65179 m
.78903 .63476 L
.80867 .64423 L
.79101 .66235 L
F
.75334 .66552 m
.7725 .65179 L
.79101 .66235 L
.77055 .67693 L
F
.73174 .6764 m
.75334 .66552 L
.77055 .67693 L
.74749 .68848 L
F
.70791 .6849 m
.73174 .6764 L
.74749 .68848 L
.72204 .69749 L
F
.68208 .69145 m
.70791 .6849 L
.72204 .69749 L
.69445 .70442 L
F
.65449 .69641 m
.68208 .69145 L
.69445 .70442 L
.66499 .70967 L
F
.62542 .70009 m
.65449 .69641 L
.66499 .70967 L
.63394 .71357 L
F
.59513 .70273 m
.62542 .70009 L
.63394 .71357 L
.6016 .71636 L
F
.56394 .7045 m
.59513 .70273 L
.6016 .71636 L
.56828 .71823 L
F
.53212 .70551 m
.56394 .7045 L
.56828 .71823 L
.53431 .7193 L
F
.5 .70584 m
.53212 .70551 L
.53431 .7193 L
.5 .71965 L
F
.46788 .70551 m
.5 .70584 L
.5 .71965 L
.46569 .7193 L
F
.43606 .7045 m
.46788 .70551 L
.46569 .7193 L
.43172 .71823 L
F
.40487 .70273 m
.43606 .7045 L
.43172 .71823 L
.3984 .71636 L
F
.37458 .70009 m
.40487 .70273 L
.3984 .71636 L
.36606 .71357 L
F
.34551 .69641 m
.37458 .70009 L
.36606 .71357 L
.33501 .70967 L
F
.31792 .69145 m
.34551 .69641 L
.33501 .70967 L
.30555 .70442 L
F
.29209 .6849 m
.31792 .69145 L
.30555 .70442 L
.27796 .69749 L
F
.26826 .6764 m
.29209 .6849 L
.27796 .69749 L
.25251 .68848 L
F
.24666 .66552 m
.26826 .6764 L
.25251 .68848 L
.22945 .67693 L
F
.2275 .65179 m
.24666 .66552 L
.22945 .67693 L
.20899 .66235 L
F
.21097 .63476 m
.2275 .65179 L
.20899 .66235 L
.19133 .64423 L
F
.19722 .61413 m
.21097 .63476 L
.19133 .64423 L
.17664 .62223 L
F
.18638 .58981 m
.19722 .61413 L
.17664 .62223 L
.16507 .59625 L
F
.17857 .5621 m
.18638 .58981 L
.16507 .59625 L
.15673 .5666 L
F
.17385 .53177 m
.17857 .5621 L
.15673 .5666 L
.15169 .53409 L
F
.17227 .5 m
.17385 .53177 L
.15169 .53409 L
.15 .5 L
F
.17385 .46823 m
.17227 .5 L
.15 .5 L
.15169 .46591 L
F
.17857 .4379 m
.17385 .46823 L
.15169 .46591 L
.15673 .4334 L
F
.18638 .41019 m
.17857 .4379 L
.15673 .4334 L
.16507 .40375 L
F
.19722 .38587 m
.18638 .41019 L
.16507 .40375 L
.17664 .37777 L
F
.21097 .36524 m
.19722 .38587 L
.17664 .37777 L
.19133 .35577 L
F
.2275 .34821 m
.21097 .36524 L
.19133 .35577 L
.20899 .33765 L
F
.24666 .33448 m
.2275 .34821 L
.20899 .33765 L
.22945 .32307 L
F
.26826 .3236 m
.24666 .33448 L
.22945 .32307 L
.25251 .31152 L
F
.29209 .3151 m
.26826 .3236 L
.25251 .31152 L
.27796 .30251 L
F
.31792 .30855 m
.29209 .3151 L
.27796 .30251 L
.30555 .29558 L
F
.34551 .30359 m
.31792 .30855 L
.30555 .29558 L
.33501 .29033 L
F
.37458 .29991 m
.34551 .30359 L
.33501 .29033 L
.36606 .28643 L
F
.40487 .29727 m
.37458 .29991 L
.36606 .28643 L
.3984 .28364 L
F
.43606 .2955 m
.40487 .29727 L
.3984 .28364 L
.43172 .28177 L
F
.46788 .29449 m
.43606 .2955 L
.43172 .28177 L
.46569 .2807 L
F
.5 .29416 m
.46788 .29449 L
.46569 .2807 L
.5 .28035 L
F
.53212 .29449 m
.5 .29416 L
.5 .28035 L
.53431 .2807 L
F
.56394 .2955 m
.53212 .29449 L
.53431 .2807 L
.56828 .28177 L
F
.59513 .29727 m
.56394 .2955 L
.56828 .28177 L
.6016 .28364 L
F
.62542 .29991 m
.59513 .29727 L
.6016 .28364 L
.63394 .28643 L
F
.65449 .30359 m
.62542 .29991 L
.63394 .28643 L
.66499 .29033 L
F
.68208 .30855 m
.65449 .30359 L
.66499 .29033 L
.69445 .29558 L
F
.70791 .3151 m
.68208 .30855 L
.69445 .29558 L
.72204 .30251 L
F
.73174 .3236 m
.70791 .3151 L
.72204 .30251 L
.74749 .31152 L
F
.75334 .33448 m
.73174 .3236 L
.74749 .31152 L
.77055 .32307 L
F
.7725 .34821 m
.75334 .33448 L
.77055 .32307 L
.79101 .33765 L
F
.78903 .36524 m
.7725 .34821 L
.79101 .33765 L
.80867 .35577 L
F
.80278 .38587 m
.78903 .36524 L
.80867 .35577 L
.82336 .37777 L
F
.81362 .41019 m
.80278 .38587 L
.82336 .37777 L
.83493 .40375 L
F
.82143 .4379 m
.81362 .41019 L
.83493 .40375 L
.84327 .4334 L
F
.82615 .46823 m
.82143 .4379 L
.84327 .4334 L
.84831 .46591 L
F
.82773 .5 m
.82615 .46823 L
.84831 .46591 L
.85 .5 L
F
.80514 .5 m
.82773 .5 L
.82615 .53177 L
.80368 .52932 L
F
.80368 .52932 m
.82615 .53177 L
.82143 .5621 L
.79928 .55735 L
F
.79928 .55735 m
.82143 .5621 L
.81362 .58981 L
.79201 .58303 L
F
.79201 .58303 m
.81362 .58981 L
.80278 .61413 L
.78192 .60566 L
F
.78192 .60566 m
.80278 .61413 L
.78903 .63476 L
.76911 .62494 L
F
.76911 .62494 m
.78903 .63476 L
.7725 .65179 L
.75372 .6409 L
F
.75372 .6409 m
.7725 .65179 L
.75334 .66552 L
.73588 .65382 L
F
.73588 .65382 m
.75334 .66552 L
.73174 .6764 L
.71577 .66409 L
F
.71577 .66409 m
.73174 .6764 L
.70791 .6849 L
.69358 .67212 L
F
.69358 .67212 m
.70791 .6849 L
.68208 .69145 L
.66953 .67831 L
F
.66953 .67831 m
.68208 .69145 L
.65449 .69641 L
.64384 .68302 L
F
.64384 .68302 m
.65449 .69641 L
.62542 .70009 L
.61677 .68651 L
F
.61677 .68651 m
.62542 .70009 L
.59513 .70273 L
.58858 .68901 L
F
.58858 .68901 m
.59513 .70273 L
.56394 .7045 L
.55953 .69069 L
F
.55953 .69069 m
.56394 .7045 L
.53212 .70551 L
.52991 .69165 L
F
.52991 .69165 m
.53212 .70551 L
.5 .70584 L
.5 .69196 L
F
.5 .69196 m
.5 .70584 L
.46788 .70551 L
.47009 .69165 L
F
.47009 .69165 m
.46788 .70551 L
.43606 .7045 L
.44047 .69069 L
F
.44047 .69069 m
.43606 .7045 L
.40487 .70273 L
.41142 .68901 L
F
.41142 .68901 m
.40487 .70273 L
.37458 .70009 L
.38323 .68651 L
F
.38323 .68651 m
.37458 .70009 L
.34551 .69641 L
.35616 .68302 L
F
.35616 .68302 m
.34551 .69641 L
.31792 .69145 L
.33047 .67831 L
F
.33047 .67831 m
.31792 .69145 L
.29209 .6849 L
.30642 .67212 L
F
.30642 .67212 m
.29209 .6849 L
.26826 .6764 L
.28423 .66409 L
F
.28423 .66409 m
.26826 .6764 L
.24666 .66552 L
.26412 .65382 L
F
.26412 .65382 m
.24666 .66552 L
.2275 .65179 L
.24628 .6409 L
F
.24628 .6409 m
.2275 .65179 L
.21097 .63476 L
.23089 .62494 L
F
.23089 .62494 m
.21097 .63476 L
.19722 .61413 L
.21808 .60566 L
F
.21808 .60566 m
.19722 .61413 L
.18638 .58981 L
.20799 .58303 L
F
.20799 .58303 m
.18638 .58981 L
.17857 .5621 L
.20072 .55735 L
F
.20072 .55735 m
.17857 .5621 L
.17385 .53177 L
.19632 .52932 L
F
.19632 .52932 m
.17385 .53177 L
.17227 .5 L
.19486 .5 L
F
.19486 .5 m
.17227 .5 L
.17385 .46823 L
.19632 .47068 L
F
.19632 .47068 m
.17385 .46823 L
.17857 .4379 L
.20072 .44265 L
F
.20072 .44265 m
.17857 .4379 L
.18638 .41019 L
.20799 .41697 L
F
.20799 .41697 m
.18638 .41019 L
.19722 .38587 L
.21808 .39434 L
F
.21808 .39434 m
.19722 .38587 L
.21097 .36524 L
.23089 .37506 L
F
.23089 .37506 m
.21097 .36524 L
.2275 .34821 L
.24628 .3591 L
F
.24628 .3591 m
.2275 .34821 L
.24666 .33448 L
.26412 .34618 L
F
.26412 .34618 m
.24666 .33448 L
.26826 .3236 L
.28423 .33591 L
F
.28423 .33591 m
.26826 .3236 L
.29209 .3151 L
.30642 .32788 L
F
.30642 .32788 m
.29209 .3151 L
.31792 .30855 L
.33047 .32169 L
F
.33047 .32169 m
.31792 .30855 L
.34551 .30359 L
.35616 .31698 L
F
.35616 .31698 m
.34551 .30359 L
.37458 .29991 L
.38323 .31349 L
F
.38323 .31349 m
.37458 .29991 L
.40487 .29727 L
.41142 .31099 L
F
.41142 .31099 m
.40487 .29727 L
.43606 .2955 L
.44047 .30931 L
F
.44047 .30931 m
.43606 .2955 L
.46788 .29449 L
.47009 .30835 L
F
.47009 .30835 m
.46788 .29449 L
.5 .29416 L
.5 .30804 L
F
.5 .30804 m
.5 .29416 L
.53212 .29449 L
.52991 .30835 L
F
.52991 .30835 m
.53212 .29449 L
.56394 .2955 L
.55953 .30931 L
F
.55953 .30931 m
.56394 .2955 L
.59513 .29727 L
.58858 .31099 L
F
.58858 .31099 m
.59513 .29727 L
.62542 .29991 L
.61677 .31349 L
F
.61677 .31349 m
.62542 .29991 L
.65449 .30359 L
.64384 .31698 L
F
.64384 .31698 m
.65449 .30359 L
.68208 .30855 L
.66953 .32169 L
F
.66953 .32169 m
.68208 .30855 L
.70791 .3151 L
.69358 .32788 L
F
.69358 .32788 m
.70791 .3151 L
.73174 .3236 L
.71577 .33591 L
F
.71577 .33591 m
.73174 .3236 L
.75334 .33448 L
.73588 .34618 L
F
.73588 .34618 m
.75334 .33448 L
.7725 .34821 L
.75372 .3591 L
F
.75372 .3591 m
.7725 .34821 L
.78903 .36524 L
.76911 .37506 L
F
.76911 .37506 m
.78903 .36524 L
.80278 .38587 L
.78192 .39434 L
F
.78192 .39434 m
.80278 .38587 L
.81362 .41019 L
.79201 .41697 L
F
.79201 .41697 m
.81362 .41019 L
.82143 .4379 L
.79928 .44265 L
F
.79928 .44265 m
.82143 .4379 L
.82615 .46823 L
.80368 .47068 L
F
.80368 .47068 m
.82615 .46823 L
.82773 .5 L
.80514 .5 L
F
.78267 .5 m
.80514 .5 L
.80368 .52932 L
.78131 .52693 L
F
.78131 .52693 m
.80368 .52932 L
.79928 .55735 L
.77724 .55271 L
F
.77724 .55271 m
.79928 .55735 L
.79201 .58303 L
.7705 .57639 L
F
.7705 .57639 m
.79201 .58303 L
.78192 .60566 L
.76115 .59733 L
F
.76115 .59733 m
.78192 .60566 L
.76911 .62494 L
.74929 .61524 L
F
.74929 .61524 m
.76911 .62494 L
.75372 .6409 L
.73503 .63013 L
F
.73503 .63013 m
.75372 .6409 L
.73588 .65382 L
.7185 .64222 L
F
.7185 .64222 m
.73588 .65382 L
.71577 .66409 L
.69988 .65185 L
F
.69988 .65185 m
.71577 .66409 L
.69358 .67212 L
.67932 .6594 L
F
.67932 .6594 m
.69358 .67212 L
.66953 .67831 L
.65704 .66523 L
F
.65704 .66523 m
.66953 .67831 L
.64384 .68302 L
.63325 .66966 L
F
.63325 .66966 m
.64384 .68302 L
.61677 .68651 L
.60817 .67296 L
F
.60817 .67296 m
.61677 .68651 L
.58858 .68901 L
.58205 .67532 L
F
.58205 .67532 m
.58858 .68901 L
.55953 .69069 L
.55515 .6769 L
F
.55515 .6769 m
.55953 .69069 L
.52991 .69165 L
.52771 .67781 L
F
.52771 .67781 m
.52991 .69165 L
.5 .69196 L
.5 .67811 L
F
.5 .67811 m
.5 .69196 L
.47009 .69165 L
.47229 .67781 L
F
.47229 .67781 m
.47009 .69165 L
.44047 .69069 L
.44485 .6769 L
F
.44485 .6769 m
.44047 .69069 L
.41142 .68901 L
.41795 .67532 L
F
.41795 .67532 m
.41142 .68901 L
.38323 .68651 L
.39183 .67296 L
F
.39183 .67296 m
.38323 .68651 L
.35616 .68302 L
.36675 .66966 L
F
.36675 .66966 m
.35616 .68302 L
.33047 .67831 L
.34296 .66523 L
F
.34296 .66523 m
.33047 .67831 L
.30642 .67212 L
.32068 .6594 L
F
.32068 .6594 m
.30642 .67212 L
.28423 .66409 L
.30012 .65185 L
F
.30012 .65185 m
.28423 .66409 L
.26412 .65382 L
.2815 .64222 L
F
.2815 .64222 m
.26412 .65382 L
.24628 .6409 L
.26497 .63013 L
F
.26497 .63013 m
.24628 .6409 L
.23089 .62494 L
.25071 .61524 L
F
.25071 .61524 m
.23089 .62494 L
.21808 .60566 L
.23885 .59733 L
F
.23885 .59733 m
.21808 .60566 L
.20799 .58303 L
.2295 .57639 L
F
.2295 .57639 m
.20799 .58303 L
.20072 .55735 L
.22276 .55271 L
F
.22276 .55271 m
.20072 .55735 L
.19632 .52932 L
.21869 .52693 L
F
.21869 .52693 m
.19632 .52932 L
.19486 .5 L
.21733 .5 L
F
.21733 .5 m
.19486 .5 L
.19632 .47068 L
.21869 .47307 L
F
.21869 .47307 m
.19632 .47068 L
.20072 .44265 L
.22276 .44729 L
F
.22276 .44729 m
.20072 .44265 L
.20799 .41697 L
.2295 .42361 L
F
.2295 .42361 m
.20799 .41697 L
.21808 .39434 L
.23885 .40267 L
F
.23885 .40267 m
.21808 .39434 L
.23089 .37506 L
.25071 .38476 L
F
.25071 .38476 m
.23089 .37506 L
.24628 .3591 L
.26497 .36987 L
F
.26497 .36987 m
.24628 .3591 L
.26412 .34618 L
.2815 .35778 L
F
.2815 .35778 m
.26412 .34618 L
.28423 .33591 L
.30012 .34815 L
F
.30012 .34815 m
.28423 .33591 L
.30642 .32788 L
.32068 .3406 L
F
.32068 .3406 m
.30642 .32788 L
.33047 .32169 L
.34296 .33477 L
F
.34296 .33477 m
.33047 .32169 L
.35616 .31698 L
.36675 .33034 L
F
.36675 .33034 m
.35616 .31698 L
.38323 .31349 L
.39183 .32704 L
F
.39183 .32704 m
.38323 .31349 L
.41142 .31099 L
.41795 .32468 L
F
.41795 .32468 m
.41142 .31099 L
.44047 .30931 L
.44485 .3231 L
F
.44485 .3231 m
.44047 .30931 L
.47009 .30835 L
.47229 .32219 L
F
.47229 .32219 m
.47009 .30835 L
.5 .30804 L
.5 .32189 L
F
.5 .32189 m
.5 .30804 L
.52991 .30835 L
.52771 .32219 L
F
.52771 .32219 m
.52991 .30835 L
.55953 .30931 L
.55515 .3231 L
F
.55515 .3231 m
.55953 .30931 L
.58858 .31099 L
.58205 .32468 L
F
.58205 .32468 m
.58858 .31099 L
.61677 .31349 L
.60817 .32704 L
F
.60817 .32704 m
.61677 .31349 L
.64384 .31698 L
.63325 .33034 L
F
.63325 .33034 m
.64384 .31698 L
.66953 .32169 L
.65704 .33477 L
F
.65704 .33477 m
.66953 .32169 L
.69358 .32788 L
.67932 .3406 L
F
.67932 .3406 m
.69358 .32788 L
.71577 .33591 L
.69988 .34815 L
F
.69988 .34815 m
.71577 .33591 L
.73588 .34618 L
.7185 .35778 L
F
.7185 .35778 m
.73588 .34618 L
.75372 .3591 L
.73503 .36987 L
F
.73503 .36987 m
.75372 .3591 L
.76911 .37506 L
.74929 .38476 L
F
.74929 .38476 m
.76911 .37506 L
.78192 .39434 L
.76115 .40267 L
F
.76115 .40267 m
.78192 .39434 L
.79201 .41697 L
.7705 .42361 L
F
.7705 .42361 m
.79201 .41697 L
.79928 .44265 L
.77724 .44729 L
F
.77724 .44729 m
.79928 .44265 L
.80368 .47068 L
.78131 .47307 L
F
.78131 .47307 m
.80368 .47068 L
.80514 .5 L
.78267 .5 L
F
.76029 .5 m
.78267 .5 L
.78131 .52693 L
.75904 .52459 L
F
.75904 .52459 m
.78131 .52693 L
.77724 .55271 L
.75529 .54817 L
F
.75529 .54817 m
.77724 .55271 L
.7705 .57639 L
.74909 .56988 L
F
.74909 .56988 m
.7705 .57639 L
.76115 .59733 L
.74048 .58915 L
F
.74048 .58915 m
.76115 .59733 L
.74929 .61524 L
.72956 .60568 L
F
.72956 .60568 m
.74929 .61524 L
.73503 .63013 L
.71643 .61947 L
F
.71643 .61947 m
.73503 .63013 L
.7185 .64222 L
.70121 .63071 L
F
.70121 .63071 m
.7185 .64222 L
.69988 .65185 L
.68406 .63969 L
F
.68406 .63969 m
.69988 .65185 L
.67932 .6594 L
.66513 .64674 L
F
.66513 .64674 m
.67932 .6594 L
.65704 .66523 L
.64461 .6522 L
F
.64461 .6522 m
.65704 .66523 L
.63325 .66966 L
.6227 .65635 L
F
.6227 .65635 m
.63325 .66966 L
.60817 .67296 L
.59961 .65944 L
F
.59961 .65944 m
.60817 .67296 L
.58205 .67532 L
.57556 .66165 L
F
.57556 .66165 m
.58205 .67532 L
.55515 .6769 L
.55078 .66314 L
F
.55078 .66314 m
.55515 .6769 L
.52771 .67781 L
.52551 .66399 L
F
.52551 .66399 m
.52771 .67781 L
.5 .67811 L
.5 .66427 L
F
.5 .66427 m
.5 .67811 L
.47229 .67781 L
.47449 .66399 L
F
.47449 .66399 m
.47229 .67781 L
.44485 .6769 L
.44922 .66314 L
F
.44922 .66314 m
.44485 .6769 L
.41795 .67532 L
.42444 .66165 L
F
.42444 .66165 m
.41795 .67532 L
.39183 .67296 L
.40039 .65944 L
F
.40039 .65944 m
.39183 .67296 L
.36675 .66966 L
.3773 .65635 L
F
.3773 .65635 m
.36675 .66966 L
.34296 .66523 L
.35539 .6522 L
F
.35539 .6522 m
.34296 .66523 L
.32068 .6594 L
.33487 .64674 L
F
.33487 .64674 m
.32068 .6594 L
.30012 .65185 L
.31594 .63969 L
F
.31594 .63969 m
.30012 .65185 L
.2815 .64222 L
.29879 .63071 L
F
.29879 .63071 m
.2815 .64222 L
.26497 .63013 L
.28357 .61947 L
F
.28357 .61947 m
.26497 .63013 L
.25071 .61524 L
.27044 .60568 L
F
.27044 .60568 m
.25071 .61524 L
.23885 .59733 L
.25952 .58915 L
F
.25952 .58915 m
.23885 .59733 L
.2295 .57639 L
.25091 .56988 L
F
.25091 .56988 m
.2295 .57639 L
.22276 .55271 L
.24471 .54817 L
F
.24471 .54817 m
.22276 .55271 L
.21869 .52693 L
.24096 .52459 L
F
.24096 .52459 m
.21869 .52693 L
.21733 .5 L
.23971 .5 L
F
.23971 .5 m
.21733 .5 L
.21869 .47307 L
.24096 .47541 L
F
.24096 .47541 m
.21869 .47307 L
.22276 .44729 L
.24471 .45183 L
F
.24471 .45183 m
.22276 .44729 L
.2295 .42361 L
.25091 .43012 L
F
.25091 .43012 m
.2295 .42361 L
.23885 .40267 L
.25952 .41085 L
F
.25952 .41085 m
.23885 .40267 L
.25071 .38476 L
.27044 .39432 L
F
.27044 .39432 m
.25071 .38476 L
.26497 .36987 L
.28357 .38053 L
F
.28357 .38053 m
.26497 .36987 L
.2815 .35778 L
.29879 .36929 L
F
.29879 .36929 m
.2815 .35778 L
.30012 .34815 L
.31594 .36031 L
F
.31594 .36031 m
.30012 .34815 L
.32068 .3406 L
.33487 .35326 L
F
.33487 .35326 m
.32068 .3406 L
.34296 .33477 L
.35539 .3478 L
F
.35539 .3478 m
.34296 .33477 L
.36675 .33034 L
.3773 .34365 L
F
.3773 .34365 m
.36675 .33034 L
.39183 .32704 L
.40039 .34056 L
F
.40039 .34056 m
.39183 .32704 L
.41795 .32468 L
.42444 .33835 L
F
.42444 .33835 m
.41795 .32468 L
.44485 .3231 L
.44922 .33686 L
F
.44922 .33686 m
.44485 .3231 L
.47229 .32219 L
.47449 .33601 L
F
.47449 .33601 m
.47229 .32219 L
.5 .32189 L
.5 .33573 L
F
.5 .33573 m
.5 .32189 L
.52771 .32219 L
.52551 .33601 L
F
.52551 .33601 m
.52771 .32219 L
.55515 .3231 L
.55078 .33686 L
F
.55078 .33686 m
.55515 .3231 L
.58205 .32468 L
.57556 .33835 L
F
.57556 .33835 m
.58205 .32468 L
.60817 .32704 L
.59961 .34056 L
F
.59961 .34056 m
.60817 .32704 L
.63325 .33034 L
.6227 .34365 L
F
.6227 .34365 m
.63325 .33034 L
.65704 .33477 L
.64461 .3478 L
F
.64461 .3478 m
.65704 .33477 L
.67932 .3406 L
.66513 .35326 L
F
.66513 .35326 m
.67932 .3406 L
.69988 .34815 L
.68406 .36031 L
F
.68406 .36031 m
.69988 .34815 L
.7185 .35778 L
.70121 .36929 L
F
.70121 .36929 m
.7185 .35778 L
.73503 .36987 L
.71643 .38053 L
F
.71643 .38053 m
.73503 .36987 L
.74929 .38476 L
.72956 .39432 L
F
.72956 .39432 m
.74929 .38476 L
.76115 .40267 L
.74048 .41085 L
F
.74048 .41085 m
.76115 .40267 L
.7705 .42361 L
.74909 .43012 L
F
.74909 .43012 m
.7705 .42361 L
.77724 .44729 L
.75529 .45183 L
F
.75529 .45183 m
.77724 .44729 L
.78131 .47307 L
.75904 .47541 L
F
.75904 .47541 m
.78131 .47307 L
.78267 .5 L
.76029 .5 L
F
.73803 .5 m
.76029 .5 L
.75904 .52459 L
.73688 .52231 L
F
.73688 .52231 m
.75904 .52459 L
.75529 .54817 L
.73346 .54373 L
F
.73346 .54373 m
.75529 .54817 L
.74909 .56988 L
.72778 .5635 L
F
.72778 .5635 m
.74909 .56988 L
.74048 .58915 L
.71991 .58109 L
F
.71991 .58109 m
.74048 .58915 L
.72956 .60568 L
.70992 .59625 L
F
.70992 .59625 m
.72956 .60568 L
.71643 .61947 L
.69791 .60893 L
F
.69791 .60893 m
.71643 .61947 L
.70121 .63071 L
.684 .6193 L
F
.684 .6193 m
.70121 .63071 L
.68406 .63969 L
.66831 .62761 L
F
.66831 .62761 m
.68406 .63969 L
.66513 .64674 L
.651 .63415 L
F
.651 .63415 m
.66513 .64674 L
.64461 .6522 L
.63224 .63922 L
F
.63224 .63922 m
.64461 .6522 L
.6227 .65635 L
.61221 .64308 L
F
.61221 .64308 m
.6227 .65635 L
.59961 .65944 L
.59109 .64595 L
F
.59109 .64595 m
.59961 .65944 L
.57556 .66165 L
.5691 .64801 L
F
.5691 .64801 m
.57556 .66165 L
.55078 .66314 L
.54644 .6494 L
F
.54644 .6494 m
.55078 .66314 L
.52551 .66399 L
.52333 .65019 L
F
.52333 .65019 m
.52551 .66399 L
.5 .66427 L
.5 .65045 L
F
.5 .65045 m
.5 .66427 L
.47449 .66399 L
.47667 .65019 L
F
.47667 .65019 m
.47449 .66399 L
.44922 .66314 L
.45356 .6494 L
F
.45356 .6494 m
.44922 .66314 L
.42444 .66165 L
.4309 .64801 L
F
.4309 .64801 m
.42444 .66165 L
.40039 .65944 L
.40891 .64595 L
F
.40891 .64595 m
.40039 .65944 L
.3773 .65635 L
.38779 .64308 L
F
.38779 .64308 m
.3773 .65635 L
.35539 .6522 L
.36776 .63922 L
F
.36776 .63922 m
.35539 .6522 L
.33487 .64674 L
.349 .63415 L
F
.349 .63415 m
.33487 .64674 L
.31594 .63969 L
.33169 .62761 L
F
.33169 .62761 m
.31594 .63969 L
.29879 .63071 L
.316 .6193 L
F
.316 .6193 m
.29879 .63071 L
.28357 .61947 L
.30209 .60893 L
F
.30209 .60893 m
.28357 .61947 L
.27044 .60568 L
.29008 .59625 L
F
.29008 .59625 m
.27044 .60568 L
.25952 .58915 L
.28009 .58109 L
F
.28009 .58109 m
.25952 .58915 L
.25091 .56988 L
.27222 .5635 L
F
.27222 .5635 m
.25091 .56988 L
.24471 .54817 L
.26654 .54373 L
F
.26654 .54373 m
.24471 .54817 L
.24096 .52459 L
.26312 .52231 L
F
.26312 .52231 m
.24096 .52459 L
.23971 .5 L
.26197 .5 L
F
.26197 .5 m
.23971 .5 L
.24096 .47541 L
.26312 .47769 L
F
.26312 .47769 m
.24096 .47541 L
.24471 .45183 L
.26654 .45627 L
F
.26654 .45627 m
.24471 .45183 L
.25091 .43012 L
.27222 .4365 L
F
.27222 .4365 m
.25091 .43012 L
.25952 .41085 L
.28009 .41891 L
F
.28009 .41891 m
.25952 .41085 L
.27044 .39432 L
.29008 .40375 L
F
.29008 .40375 m
.27044 .39432 L
.28357 .38053 L
.30209 .39107 L
F
.30209 .39107 m
.28357 .38053 L
.29879 .36929 L
.316 .3807 L
F
.316 .3807 m
.29879 .36929 L
.31594 .36031 L
.33169 .37239 L
F
.33169 .37239 m
.31594 .36031 L
.33487 .35326 L
.349 .36585 L
F
.349 .36585 m
.33487 .35326 L
.35539 .3478 L
.36776 .36078 L
F
.36776 .36078 m
.35539 .3478 L
.3773 .34365 L
.38779 .35692 L
F
.38779 .35692 m
.3773 .34365 L
.40039 .34056 L
.40891 .35405 L
F
.40891 .35405 m
.40039 .34056 L
.42444 .33835 L
.4309 .35199 L
F
.4309 .35199 m
.42444 .33835 L
.44922 .33686 L
.45356 .3506 L
F
.45356 .3506 m
.44922 .33686 L
.47449 .33601 L
.47667 .34981 L
F
.47667 .34981 m
.47449 .33601 L
.5 .33573 L
.5 .34955 L
F
.5 .34955 m
.5 .33573 L
.52551 .33601 L
.52333 .34981 L
F
.52333 .34981 m
.52551 .33601 L
.55078 .33686 L
.54644 .3506 L
F
.54644 .3506 m
.55078 .33686 L
.57556 .33835 L
.5691 .35199 L
F
.5691 .35199 m
.57556 .33835 L
.59961 .34056 L
.59109 .35405 L
F
.59109 .35405 m
.59961 .34056 L
.6227 .34365 L
.61221 .35692 L
F
.61221 .35692 m
.6227 .34365 L
.64461 .3478 L
.63224 .36078 L
F
.63224 .36078 m
.64461 .3478 L
.66513 .35326 L
.651 .36585 L
F
.651 .36585 m
.66513 .35326 L
.68406 .36031 L
.66831 .37239 L
F
.66831 .37239 m
.68406 .36031 L
.70121 .36929 L
.684 .3807 L
F
.684 .3807 m
.70121 .36929 L
.71643 .38053 L
.69791 .39107 L
F
.69791 .39107 m
.71643 .38053 L
.72956 .39432 L
.70992 .40375 L
F
.70992 .40375 m
.72956 .39432 L
.74048 .41085 L
.71991 .41891 L
F
.71991 .41891 m
.74048 .41085 L
.74909 .43012 L
.72778 .4365 L
F
.72778 .4365 m
.74909 .43012 L
.75529 .45183 L
.73346 .45627 L
F
.73346 .45627 m
.75529 .45183 L
.75904 .47541 L
.73688 .47769 L
F
.73688 .47769 m
.75904 .47541 L
.76029 .5 L
.73803 .5 L
F
.71587 .5 m
.73803 .5 L
.73688 .52231 L
.71483 .52008 L
F
.71483 .52008 m
.73688 .52231 L
.73346 .54373 L
.71172 .53938 L
F
.71172 .53938 m
.73346 .54373 L
.72778 .5635 L
.70657 .55723 L
F
.70657 .55723 m
.72778 .5635 L
.71991 .58109 L
.69944 .57316 L
F
.69944 .57316 m
.71991 .58109 L
.70992 .59625 L
.69038 .58693 L
F
.69038 .58693 m
.70992 .59625 L
.69791 .60893 L
.67949 .5985 L
F
.67949 .5985 m
.69791 .60893 L
.684 .6193 L
.66687 .60799 L
F
.66687 .60799 m
.684 .6193 L
.66831 .62761 L
.65264 .6156 L
F
.65264 .6156 m
.66831 .62761 L
.651 .63415 L
.63695 .62162 L
F
.63695 .62162 m
.651 .63415 L
.63224 .63922 L
.61993 .62629 L
F
.61993 .62629 m
.63224 .63922 L
.61221 .64308 L
.60176 .62985 L
F
.60176 .62985 m
.61221 .64308 L
.59109 .64595 L
.58261 .6325 L
F
.58261 .6325 m
.59109 .64595 L
.5691 .64801 L
.56266 .6344 L
F
.56266 .6344 m
.5691 .64801 L
.54644 .6494 L
.54211 .63568 L
F
.54211 .63568 m
.54644 .6494 L
.52333 .65019 L
.52116 .63642 L
F
.52116 .63642 m
.52333 .65019 L
.5 .65045 L
.5 .63666 L
F
.5 .63666 m
.5 .65045 L
.47667 .65019 L
.47884 .63642 L
F
.47884 .63642 m
.47667 .65019 L
.45356 .6494 L
.45789 .63568 L
F
.45789 .63568 m
.45356 .6494 L
.4309 .64801 L
.43734 .6344 L
F
.43734 .6344 m
.4309 .64801 L
.40891 .64595 L
.41739 .6325 L
F
.41739 .6325 m
.40891 .64595 L
.38779 .64308 L
.39824 .62985 L
F
.39824 .62985 m
.38779 .64308 L
.36776 .63922 L
.38007 .62629 L
F
.38007 .62629 m
.36776 .63922 L
.349 .63415 L
.36305 .62162 L
F
.36305 .62162 m
.349 .63415 L
.33169 .62761 L
.34736 .6156 L
F
.34736 .6156 m
.33169 .62761 L
.316 .6193 L
.33313 .60799 L
F
.33313 .60799 m
.316 .6193 L
.30209 .60893 L
.32051 .5985 L
F
.32051 .5985 m
.30209 .60893 L
.29008 .59625 L
.30962 .58693 L
F
.30962 .58693 m
.29008 .59625 L
.28009 .58109 L
.30056 .57316 L
F
.30056 .57316 m
.28009 .58109 L
.27222 .5635 L
.29343 .55723 L
F
.29343 .55723 m
.27222 .5635 L
.26654 .54373 L
.28828 .53938 L
F
.28828 .53938 m
.26654 .54373 L
.26312 .52231 L
.28517 .52008 L
F
.28517 .52008 m
.26312 .52231 L
.26197 .5 L
.28413 .5 L
F
.28413 .5 m
.26197 .5 L
.26312 .47769 L
.28517 .47992 L
F
.28517 .47992 m
.26312 .47769 L
.26654 .45627 L
.28828 .46062 L
F
.28828 .46062 m
.26654 .45627 L
.27222 .4365 L
.29343 .44277 L
F
.29343 .44277 m
.27222 .4365 L
.28009 .41891 L
.30056 .42684 L
F
.30056 .42684 m
.28009 .41891 L
.29008 .40375 L
.30962 .41307 L
F
.30962 .41307 m
.29008 .40375 L
.30209 .39107 L
.32051 .4015 L
F
.32051 .4015 m
.30209 .39107 L
.316 .3807 L
.33313 .39201 L
F
.33313 .39201 m
.316 .3807 L
.33169 .37239 L
.34736 .3844 L
F
.34736 .3844 m
.33169 .37239 L
.349 .36585 L
.36305 .37838 L
F
.36305 .37838 m
.349 .36585 L
.36776 .36078 L
.38007 .37371 L
F
.38007 .37371 m
.36776 .36078 L
.38779 .35692 L
.39824 .37015 L
F
.39824 .37015 m
.38779 .35692 L
.40891 .35405 L
.41739 .3675 L
F
.41739 .3675 m
.40891 .35405 L
.4309 .35199 L
.43734 .3656 L
F
.43734 .3656 m
.4309 .35199 L
.45356 .3506 L
.45789 .36432 L
F
.45789 .36432 m
.45356 .3506 L
.47667 .34981 L
.47884 .36358 L
F
.47884 .36358 m
.47667 .34981 L
.5 .34955 L
.5 .36334 L
F
.5 .36334 m
.5 .34955 L
.52333 .34981 L
.52116 .36358 L
F
.52116 .36358 m
.52333 .34981 L
.54644 .3506 L
.54211 .36432 L
F
.54211 .36432 m
.54644 .3506 L
.5691 .35199 L
.56266 .3656 L
F
.56266 .3656 m
.5691 .35199 L
.59109 .35405 L
.58261 .3675 L
F
.58261 .3675 m
.59109 .35405 L
.61221 .35692 L
.60176 .37015 L
F
.60176 .37015 m
.61221 .35692 L
.63224 .36078 L
.61993 .37371 L
F
.61993 .37371 m
.63224 .36078 L
.651 .36585 L
.63695 .37838 L
F
.63695 .37838 m
.651 .36585 L
.66831 .37239 L
.65264 .3844 L
F
.65264 .3844 m
.66831 .37239 L
.684 .3807 L
.66687 .39201 L
F
.66687 .39201 m
.684 .3807 L
.69791 .39107 L
.67949 .4015 L
F
.67949 .4015 m
.69791 .39107 L
.70992 .40375 L
.69038 .41307 L
F
.69038 .41307 m
.70992 .40375 L
.71991 .41891 L
.69944 .42684 L
F
.69944 .42684 m
.71991 .41891 L
.72778 .4365 L
.70657 .44277 L
F
.70657 .44277 m
.72778 .4365 L
.73346 .45627 L
.71172 .46062 L
F
.71172 .46062 m
.73346 .45627 L
.73688 .47769 L
.71483 .47992 L
F
.71483 .47992 m
.73688 .47769 L
.73803 .5 L
.71587 .5 L
F
.69381 .5 m
.71587 .5 L
.71483 .52008 L
.69288 .5179 L
F
.69288 .5179 m
.71483 .52008 L
.71172 .53938 L
.69009 .53511 L
F
.69009 .53511 m
.71172 .53938 L
.70657 .55723 L
.68547 .55108 L
F
.68547 .55108 m
.70657 .55723 L
.69944 .57316 L
.67906 .56536 L
F
.67906 .56536 m
.69944 .57316 L
.69038 .58693 L
.67093 .57775 L
F
.67093 .57775 m
.69038 .58693 L
.67949 .5985 L
.66115 .58818 L
F
.66115 .58818 m
.67949 .5985 L
.66687 .60799 L
.64982 .59677 L
F
.64982 .59677 m
.66687 .60799 L
.65264 .6156 L
.63705 .60368 L
F
.63705 .60368 m
.65264 .6156 L
.63695 .62162 L
.62295 .60915 L
F
.62295 .60915 m
.63695 .62162 L
.61993 .62629 L
.60768 .61341 L
F
.60768 .61341 m
.61993 .62629 L
.60176 .62985 L
.59136 .61666 L
F
.59136 .61666 m
.60176 .62985 L
.58261 .6325 L
.57417 .61908 L
F
.57417 .61908 m
.58261 .6325 L
.56266 .6344 L
.55626 .62082 L
F
.55626 .62082 m
.56266 .6344 L
.54211 .63568 L
.53781 .62199 L
F
.53781 .62199 m
.54211 .63568 L
.52116 .63642 L
.519 .62266 L
F
.519 .62266 m
.52116 .63642 L
.5 .63666 L
.5 .62288 L
F
.5 .62288 m
.5 .63666 L
.47884 .63642 L
.481 .62266 L
F
.481 .62266 m
.47884 .63642 L
.45789 .63568 L
.46219 .62199 L
F
.46219 .62199 m
.45789 .63568 L
.43734 .6344 L
.44374 .62082 L
F
.44374 .62082 m
.43734 .6344 L
.41739 .6325 L
.42583 .61908 L
F
.42583 .61908 m
.41739 .6325 L
.39824 .62985 L
.40864 .61666 L
F
.40864 .61666 m
.39824 .62985 L
.38007 .62629 L
.39232 .61341 L
F
.39232 .61341 m
.38007 .62629 L
.36305 .62162 L
.37705 .60915 L
F
.37705 .60915 m
.36305 .62162 L
.34736 .6156 L
.36295 .60368 L
F
.36295 .60368 m
.34736 .6156 L
.33313 .60799 L
.35018 .59677 L
F
.35018 .59677 m
.33313 .60799 L
.32051 .5985 L
.33885 .58818 L
F
.33885 .58818 m
.32051 .5985 L
.30962 .58693 L
.32907 .57775 L
F
.32907 .57775 m
.30962 .58693 L
.30056 .57316 L
.32094 .56536 L
F
.32094 .56536 m
.30056 .57316 L
.29343 .55723 L
.31453 .55108 L
F
.31453 .55108 m
.29343 .55723 L
.28828 .53938 L
.30991 .53511 L
F
.30991 .53511 m
.28828 .53938 L
.28517 .52008 L
.30712 .5179 L
F
.30712 .5179 m
.28517 .52008 L
.28413 .5 L
.30619 .5 L
F
.30619 .5 m
.28413 .5 L
.28517 .47992 L
.30712 .4821 L
F
.30712 .4821 m
.28517 .47992 L
.28828 .46062 L
.30991 .46489 L
F
.30991 .46489 m
.28828 .46062 L
.29343 .44277 L
.31453 .44892 L
F
.31453 .44892 m
.29343 .44277 L
.30056 .42684 L
.32094 .43464 L
F
.32094 .43464 m
.30056 .42684 L
.30962 .41307 L
.32907 .42225 L
F
.32907 .42225 m
.30962 .41307 L
.32051 .4015 L
.33885 .41182 L
F
.33885 .41182 m
.32051 .4015 L
.33313 .39201 L
.35018 .40323 L
F
.35018 .40323 m
.33313 .39201 L
.34736 .3844 L
.36295 .39632 L
F
.36295 .39632 m
.34736 .3844 L
.36305 .37838 L
.37705 .39085 L
F
.37705 .39085 m
.36305 .37838 L
.38007 .37371 L
.39232 .38659 L
F
.39232 .38659 m
.38007 .37371 L
.39824 .37015 L
.40864 .38334 L
F
.40864 .38334 m
.39824 .37015 L
.41739 .3675 L
.42583 .38092 L
F
.42583 .38092 m
.41739 .3675 L
.43734 .3656 L
.44374 .37918 L
F
.44374 .37918 m
.43734 .3656 L
.45789 .36432 L
.46219 .37801 L
F
.46219 .37801 m
.45789 .36432 L
.47884 .36358 L
.481 .37734 L
F
.481 .37734 m
.47884 .36358 L
.5 .36334 L
.5 .37712 L
F
.5 .37712 m
.5 .36334 L
.52116 .36358 L
.519 .37734 L
F
.519 .37734 m
.52116 .36358 L
.54211 .36432 L
.53781 .37801 L
F
.53781 .37801 m
.54211 .36432 L
.56266 .3656 L
.55626 .37918 L
F
.55626 .37918 m
.56266 .3656 L
.58261 .3675 L
.57417 .38092 L
F
.57417 .38092 m
.58261 .3675 L
.60176 .37015 L
.59136 .38334 L
F
.59136 .38334 m
.60176 .37015 L
.61993 .37371 L
.60768 .38659 L
F
.60768 .38659 m
.61993 .37371 L
.63695 .37838 L
.62295 .39085 L
F
.62295 .39085 m
.63695 .37838 L
.65264 .3844 L
.63705 .39632 L
F
.63705 .39632 m
.65264 .3844 L
.66687 .39201 L
.64982 .40323 L
F
.64982 .40323 m
.66687 .39201 L
.67949 .4015 L
.66115 .41182 L
F
.66115 .41182 m
.67949 .4015 L
.69038 .41307 L
.67093 .42225 L
F
.67093 .42225 m
.69038 .41307 L
.69944 .42684 L
.67906 .43464 L
F
.67906 .43464 m
.69944 .42684 L
.70657 .44277 L
.68547 .44892 L
F
.68547 .44892 m
.70657 .44277 L
.71172 .46062 L
.69009 .46489 L
F
.69009 .46489 m
.71172 .46062 L
.71483 .47992 L
.69288 .4821 L
F
.69288 .4821 m
.71483 .47992 L
.71587 .5 L
.69381 .5 L
F
.67186 .5 m
.69381 .5 L
.69288 .5179 L
.67104 .51576 L
F
.67104 .51576 m
.69288 .5179 L
.69009 .53511 L
.66856 .53093 L
F
.66856 .53093 m
.69009 .53511 L
.68547 .55108 L
.66446 .54503 L
F
.66446 .54503 m
.68547 .55108 L
.67906 .56536 L
.65878 .55768 L
F
.65878 .55768 m
.67906 .56536 L
.67093 .57775 L
.65157 .56867 L
F
.65157 .56867 m
.67093 .57775 L
.66115 .58818 L
.6429 .57797 L
F
.6429 .57797 m
.66115 .58818 L
.64982 .59677 L
.63285 .58564 L
F
.63285 .58564 m
.64982 .59677 L
.63705 .60368 L
.62153 .59184 L
F
.62153 .59184 m
.63705 .60368 L
.62295 .60915 L
.60903 .59675 L
F
.60903 .59675 m
.62295 .60915 L
.60768 .61341 L
.59548 .60058 L
F
.59548 .60058 m
.60768 .61341 L
.59136 .61666 L
.58102 .60351 L
F
.58102 .60351 m
.59136 .61666 L
.57417 .61908 L
.56577 .6057 L
F
.56577 .6057 m
.57417 .61908 L
.55626 .62082 L
.54989 .60727 L
F
.54989 .60727 m
.55626 .62082 L
.53781 .62199 L
.53353 .60833 L
F
.53353 .60833 m
.53781 .62199 L
.519 .62266 L
.51685 .60893 L
F
.51685 .60893 m
.519 .62266 L
.5 .62288 L
.5 .60913 L
F
.5 .60913 m
.5 .62288 L
.481 .62266 L
.48315 .60893 L
F
.48315 .60893 m
.481 .62266 L
.46219 .62199 L
.46647 .60833 L
F
.46647 .60833 m
.46219 .62199 L
.44374 .62082 L
.45011 .60727 L
F
.45011 .60727 m
.44374 .62082 L
.42583 .61908 L
.43423 .6057 L
F
.43423 .6057 m
.42583 .61908 L
.40864 .61666 L
.41898 .60351 L
F
.41898 .60351 m
.40864 .61666 L
.39232 .61341 L
.40452 .60058 L
F
.40452 .60058 m
.39232 .61341 L
.37705 .60915 L
.39097 .59675 L
F
.39097 .59675 m
.37705 .60915 L
.36295 .60368 L
.37847 .59184 L
F
.37847 .59184 m
.36295 .60368 L
.35018 .59677 L
.36715 .58564 L
F
.36715 .58564 m
.35018 .59677 L
.33885 .58818 L
.3571 .57797 L
F
.3571 .57797 m
.33885 .58818 L
.32907 .57775 L
.34843 .56867 L
F
.34843 .56867 m
.32907 .57775 L
.32094 .56536 L
.34122 .55768 L
F
.34122 .55768 m
.32094 .56536 L
.31453 .55108 L
.33554 .54503 L
F
.33554 .54503 m
.31453 .55108 L
.30991 .53511 L
.33144 .53093 L
F
.33144 .53093 m
.30991 .53511 L
.30712 .5179 L
.32896 .51576 L
F
.32896 .51576 m
.30712 .5179 L
.30619 .5 L
.32814 .5 L
F
.32814 .5 m
.30619 .5 L
.30712 .4821 L
.32896 .48424 L
F
.32896 .48424 m
.30712 .4821 L
.30991 .46489 L
.33144 .46907 L
F
.33144 .46907 m
.30991 .46489 L
.31453 .44892 L
.33554 .45497 L
F
.33554 .45497 m
.31453 .44892 L
.32094 .43464 L
.34122 .44232 L
F
.34122 .44232 m
.32094 .43464 L
.32907 .42225 L
.34843 .43133 L
F
.34843 .43133 m
.32907 .42225 L
.33885 .41182 L
.3571 .42203 L
F
.3571 .42203 m
.33885 .41182 L
.35018 .40323 L
.36715 .41436 L
F
.36715 .41436 m
.35018 .40323 L
.36295 .39632 L
.37847 .40816 L
F
.37847 .40816 m
.36295 .39632 L
.37705 .39085 L
.39097 .40325 L
F
.39097 .40325 m
.37705 .39085 L
.39232 .38659 L
.40452 .39942 L
F
.40452 .39942 m
.39232 .38659 L
.40864 .38334 L
.41898 .39649 L
F
.41898 .39649 m
.40864 .38334 L
.42583 .38092 L
.43423 .3943 L
F
.43423 .3943 m
.42583 .38092 L
.44374 .37918 L
.45011 .39273 L
F
.45011 .39273 m
.44374 .37918 L
.46219 .37801 L
.46647 .39167 L
F
.46647 .39167 m
.46219 .37801 L
.481 .37734 L
.48315 .39107 L
F
.48315 .39107 m
.481 .37734 L
.5 .37712 L
.5 .39087 L
F
.5 .39087 m
.5 .37712 L
.519 .37734 L
.51685 .39107 L
F
.51685 .39107 m
.519 .37734 L
.53781 .37801 L
.53353 .39167 L
F
.53353 .39167 m
.53781 .37801 L
.55626 .37918 L
.54989 .39273 L
F
.54989 .39273 m
.55626 .37918 L
.57417 .38092 L
.56577 .3943 L
F
.56577 .3943 m
.57417 .38092 L
.59136 .38334 L
.58102 .39649 L
F
.58102 .39649 m
.59136 .38334 L
.60768 .38659 L
.59548 .39942 L
F
.59548 .39942 m
.60768 .38659 L
.62295 .39085 L
.60903 .40325 L
F
.60903 .40325 m
.62295 .39085 L
.63705 .39632 L
.62153 .40816 L
F
.62153 .40816 m
.63705 .39632 L
.64982 .40323 L
.63285 .41436 L
F
.63285 .41436 m
.64982 .40323 L
.66115 .41182 L
.6429 .42203 L
F
.6429 .42203 m
.66115 .41182 L
.67093 .42225 L
.65157 .43133 L
F
.65157 .43133 m
.67093 .42225 L
.67906 .43464 L
.65878 .44232 L
F
.65878 .44232 m
.67906 .43464 L
.68547 .44892 L
.66446 .45497 L
F
.66446 .45497 m
.68547 .44892 L
.69009 .46489 L
.66856 .46907 L
F
.66856 .46907 m
.69009 .46489 L
.69288 .4821 L
.67104 .48424 L
F
.67104 .48424 m
.69288 .4821 L
.69381 .5 L
.67186 .5 L
F
.64714 .52683 m
.65002 .5 L
.67186 .5 L
.67104 .51576 L
.66856 .53093 L
F
.6386 .55011 m
.64714 .52683 L
.66856 .53093 L
.66446 .54503 L
.65878 .55768 L
F
.62474 .56787 m
.6386 .55011 L
.65878 .55768 L
.65157 .56867 L
.6429 .57797 L
F
.60608 .58008 m
.62474 .56787 L
.6429 .57797 L
.63285 .58564 L
.62153 .59184 L
F
.58335 .58781 m
.60608 .58008 L
.62153 .59184 L
.60903 .59675 L
.59548 .60058 L
F
.55741 .59235 m
.58335 .58781 L
.59548 .60058 L
.58102 .60351 L
.56577 .6057 L
F
.52927 .59469 m
.55741 .59235 L
.56577 .6057 L
.54989 .60727 L
.53353 .60833 L
F
.5 .5954 m
.52927 .59469 L
.53353 .60833 L
.51685 .60893 L
.5 .60913 L
F
.47073 .59469 m
.5 .5954 L
.5 .60913 L
.48315 .60893 L
.46647 .60833 L
F
.44259 .59235 m
.47073 .59469 L
.46647 .60833 L
.45011 .60727 L
.43423 .6057 L
F
.41665 .58781 m
.44259 .59235 L
.43423 .6057 L
.41898 .60351 L
.40452 .60058 L
F
.39392 .58008 m
.41665 .58781 L
.40452 .60058 L
.39097 .59675 L
.37847 .59184 L
F
.37526 .56787 m
.39392 .58008 L
.37847 .59184 L
.36715 .58564 L
.3571 .57797 L
F
.3614 .55011 m
.37526 .56787 L
.3571 .57797 L
.34843 .56867 L
.34122 .55768 L
F
.35286 .52683 m
.3614 .55011 L
.34122 .55768 L
.33554 .54503 L
.33144 .53093 L
F
.34998 .5 m
.35286 .52683 L
.33144 .53093 L
.32896 .51576 L
.32814 .5 L
F
.35286 .47317 m
.34998 .5 L
.32814 .5 L
.32896 .48424 L
.33144 .46907 L
F
.3614 .44989 m
.35286 .47317 L
.33144 .46907 L
.33554 .45497 L
.34122 .44232 L
F
.37526 .43213 m
.3614 .44989 L
.34122 .44232 L
.34843 .43133 L
.3571 .42203 L
F
.39392 .41992 m
.37526 .43213 L
.3571 .42203 L
.36715 .41436 L
.37847 .40816 L
F
.41665 .41219 m
.39392 .41992 L
.37847 .40816 L
.39097 .40325 L
.40452 .39942 L
F
.44259 .40765 m
.41665 .41219 L
.40452 .39942 L
.41898 .39649 L
.43423 .3943 L
F
.47073 .40531 m
.44259 .40765 L
.43423 .3943 L
.45011 .39273 L
.46647 .39167 L
F
.5 .4046 m
.47073 .40531 L
.46647 .39167 L
.48315 .39107 L
.5 .39087 L
F
.52927 .40531 m
.5 .4046 L
.5 .39087 L
.51685 .39107 L
.53353 .39167 L
F
.55741 .40765 m
.52927 .40531 L
.53353 .39167 L
.54989 .39273 L
.56577 .3943 L
F
.58335 .41219 m
.55741 .40765 L
.56577 .3943 L
.58102 .39649 L
.59548 .39942 L
F
.60608 .41992 m
.58335 .41219 L
.59548 .39942 L
.60903 .40325 L
.62153 .40816 L
F
.62474 .43213 m
.60608 .41992 L
.62153 .40816 L
.63285 .41436 L
.6429 .42203 L
F
.6386 .44989 m
.62474 .43213 L
.6429 .42203 L
.65157 .43133 L
.65878 .44232 L
F
.64714 .47317 m
.6386 .44989 L
.65878 .44232 L
.66446 .45497 L
.66856 .46907 L
F
.65002 .5 m
.64714 .47317 L
.66856 .46907 L
.67104 .48424 L
.67186 .5 L
F
.62735 .5 m
.65002 .5 L
.64714 .52683 L
.62491 .52224 L
F
.62491 .52224 m
.64714 .52683 L
.6386 .55011 L
.61766 .54177 L
F
.61766 .54177 m
.6386 .55011 L
.62474 .56787 L
.60589 .55698 L
F
.60589 .55698 m
.62474 .56787 L
.60608 .58008 L
.59005 .56768 L
F
.59005 .56768 m
.60608 .58008 L
.58335 .58781 L
.57075 .57458 L
F
.57075 .57458 m
.58335 .58781 L
.55741 .59235 L
.54874 .57869 L
F
.54874 .57869 m
.55741 .59235 L
.52927 .59469 L
.52485 .58081 L
F
.52485 .58081 m
.52927 .59469 L
.5 .5954 L
.5 .58147 L
F
.5 .58147 m
.5 .5954 L
.47073 .59469 L
.47515 .58081 L
F
.47515 .58081 m
.47073 .59469 L
.44259 .59235 L
.45126 .57869 L
F
.45126 .57869 m
.44259 .59235 L
.41665 .58781 L
.42925 .57458 L
F
.42925 .57458 m
.41665 .58781 L
.39392 .58008 L
.40995 .56768 L
F
.40995 .56768 m
.39392 .58008 L
.37526 .56787 L
.39411 .55698 L
F
.39411 .55698 m
.37526 .56787 L
.3614 .55011 L
.38234 .54177 L
F
.38234 .54177 m
.3614 .55011 L
.35286 .52683 L
.37509 .52224 L
F
.37509 .52224 m
.35286 .52683 L
.34998 .5 L
.37265 .5 L
F
.37265 .5 m
.34998 .5 L
.35286 .47317 L
.37509 .47776 L
F
.37509 .47776 m
.35286 .47317 L
.3614 .44989 L
.38234 .45823 L
F
.38234 .45823 m
.3614 .44989 L
.37526 .43213 L
.39411 .44302 L
F
.39411 .44302 m
.37526 .43213 L
.39392 .41992 L
.40995 .43232 L
F
.40995 .43232 m
.39392 .41992 L
.41665 .41219 L
.42925 .42542 L
F
.42925 .42542 m
.41665 .41219 L
.44259 .40765 L
.45126 .42131 L
F
.45126 .42131 m
.44259 .40765 L
.47073 .40531 L
.47515 .41919 L
F
.47515 .41919 m
.47073 .40531 L
.5 .4046 L
.5 .41853 L
F
.5 .41853 m
.5 .4046 L
.52927 .40531 L
.52485 .41919 L
F
.52485 .41919 m
.52927 .40531 L
.55741 .40765 L
.54874 .42131 L
F
.54874 .42131 m
.55741 .40765 L
.58335 .41219 L
.57075 .42542 L
F
.57075 .42542 m
.58335 .41219 L
.60608 .41992 L
.59005 .43232 L
F
.59005 .43232 m
.60608 .41992 L
.62474 .43213 L
.60589 .44302 L
F
.60589 .44302 m
.62474 .43213 L
.6386 .44989 L
.61766 .45823 L
F
.61766 .45823 m
.6386 .44989 L
.64714 .47317 L
.62491 .47776 L
F
.62491 .47776 m
.64714 .47317 L
.65002 .5 L
.62735 .5 L
F
.60511 .5 m
.62735 .5 L
.62491 .52224 L
.60309 .51797 L
F
.60309 .51797 m
.62491 .52224 L
.61766 .54177 L
.59711 .53391 L
F
.59711 .53391 m
.61766 .54177 L
.60589 .55698 L
.58739 .54655 L
F
.58739 .54655 m
.60589 .55698 L
.59005 .56768 L
.57432 .55561 L
F
.57432 .55561 m
.59005 .56768 L
.57075 .57458 L
.55839 .56157 L
F
.55839 .56157 m
.57075 .57458 L
.54874 .57869 L
.54022 .56516 L
F
.54022 .56516 m
.54874 .57869 L
.52485 .58081 L
.52051 .56704 L
F
.52051 .56704 m
.52485 .58081 L
.5 .58147 L
.5 .56762 L
F
.5 .56762 m
.5 .58147 L
.47515 .58081 L
.47949 .56704 L
F
.47949 .56704 m
.47515 .58081 L
.45126 .57869 L
.45978 .56516 L
F
.45978 .56516 m
.45126 .57869 L
.42925 .57458 L
.44161 .56157 L
F
.44161 .56157 m
.42925 .57458 L
.40995 .56768 L
.42568 .55561 L
F
.42568 .55561 m
.40995 .56768 L
.39411 .55698 L
.41261 .54655 L
F
.41261 .54655 m
.39411 .55698 L
.38234 .54177 L
.40289 .53391 L
F
.40289 .53391 m
.38234 .54177 L
.37509 .52224 L
.39691 .51797 L
F
.39691 .51797 m
.37509 .52224 L
.37265 .5 L
.39489 .5 L
F
.39489 .5 m
.37265 .5 L
.37509 .47776 L
.39691 .48203 L
F
.39691 .48203 m
.37509 .47776 L
.38234 .45823 L
.40289 .46609 L
F
.40289 .46609 m
.38234 .45823 L
.39411 .44302 L
.41261 .45345 L
F
.41261 .45345 m
.39411 .44302 L
.40995 .43232 L
.42568 .44439 L
F
.42568 .44439 m
.40995 .43232 L
.42925 .42542 L
.44161 .43843 L
F
.44161 .43843 m
.42925 .42542 L
.45126 .42131 L
.45978 .43484 L
F
.45978 .43484 m
.45126 .42131 L
.47515 .41919 L
.47949 .43296 L
F
.47949 .43296 m
.47515 .41919 L
.5 .41853 L
.5 .43238 L
F
.5 .43238 m
.5 .41853 L
.52485 .41919 L
.52051 .43296 L
F
.52051 .43296 m
.52485 .41919 L
.54874 .42131 L
.54022 .43484 L
F
.54022 .43484 m
.54874 .42131 L
.57075 .42542 L
.55839 .43843 L
F
.55839 .43843 m
.57075 .42542 L
.59005 .43232 L
.57432 .44439 L
F
.57432 .44439 m
.59005 .43232 L
.60589 .44302 L
.58739 .45345 L
F
.58739 .45345 m
.60589 .44302 L
.61766 .45823 L
.59711 .46609 L
F
.59711 .46609 m
.61766 .45823 L
.62491 .47776 L
.60309 .48203 L
F
.60309 .48203 m
.62491 .47776 L
.62735 .5 L
.60511 .5 L
F
.58328 .5 m
.60511 .5 L
.60309 .51797 L
.58168 .51397 L
F
.58168 .51397 m
.60309 .51797 L
.59711 .53391 L
.57694 .52647 L
F
.57694 .52647 m
.59711 .53391 L
.58739 .54655 L
.56924 .53652 L
F
.56924 .53652 m
.58739 .54655 L
.57432 .55561 L
.55889 .54387 L
F
.55889 .54387 m
.57432 .55561 L
.55839 .56157 L
.54627 .54878 L
F
.54627 .54878 m
.55839 .56157 L
.54022 .56516 L
.53187 .55179 L
F
.53187 .55179 m
.54022 .56516 L
.52051 .56704 L
.51625 .55337 L
F
.51625 .55337 m
.52051 .56704 L
.5 .56762 L
.5 .55386 L
F
.5 .55386 m
.5 .56762 L
.47949 .56704 L
.48375 .55337 L
F
.48375 .55337 m
.47949 .56704 L
.45978 .56516 L
.46813 .55179 L
F
.46813 .55179 m
.45978 .56516 L
.44161 .56157 L
.45373 .54878 L
F
.45373 .54878 m
.44161 .56157 L
.42568 .55561 L
.44111 .54387 L
F
.44111 .54387 m
.42568 .55561 L
.41261 .54655 L
.43076 .53652 L
F
.43076 .53652 m
.41261 .54655 L
.40289 .53391 L
.42306 .52647 L
F
.42306 .52647 m
.40289 .53391 L
.39691 .51797 L
.41832 .51397 L
F
.41832 .51397 m
.39691 .51797 L
.39489 .5 L
.41672 .5 L
F
.41672 .5 m
.39489 .5 L
.39691 .48203 L
.41832 .48603 L
F
.41832 .48603 m
.39691 .48203 L
.40289 .46609 L
.42306 .47353 L
F
.42306 .47353 m
.40289 .46609 L
.41261 .45345 L
.43076 .46348 L
F
.43076 .46348 m
.41261 .45345 L
.42568 .44439 L
.44111 .45613 L
F
.44111 .45613 m
.42568 .44439 L
.44161 .43843 L
.45373 .45122 L
F
.45373 .45122 m
.44161 .43843 L
.45978 .43484 L
.46813 .44821 L
F
.46813 .44821 m
.45978 .43484 L
.47949 .43296 L
.48375 .44663 L
F
.48375 .44663 m
.47949 .43296 L
.5 .43238 L
.5 .44614 L
F
.5 .44614 m
.5 .43238 L
.52051 .43296 L
.51625 .44663 L
F
.51625 .44663 m
.52051 .43296 L
.54022 .43484 L
.53187 .44821 L
F
.53187 .44821 m
.54022 .43484 L
.55839 .43843 L
.54627 .45122 L
F
.54627 .45122 m
.55839 .43843 L
.57432 .44439 L
.55889 .45613 L
F
.55889 .45613 m
.57432 .44439 L
.58739 .45345 L
.56924 .46348 L
F
.56924 .46348 m
.58739 .45345 L
.59711 .46609 L
.57694 .47353 L
F
.57694 .47353 m
.59711 .46609 L
.60309 .48203 L
.58168 .48603 L
F
.58168 .48603 m
.60309 .48203 L
.60511 .5 L
.58328 .5 L
F
.55715 .51939 m
.56186 .5 L
.58328 .5 L
.58168 .51397 L
.57694 .52647 L
F
.54374 .53244 m
.55715 .51939 L
.57694 .52647 L
.56924 .53652 L
.55889 .54387 L
F
.52367 .53857 m
.54374 .53244 L
.55889 .54387 L
.54627 .54878 L
.53187 .55179 L
F
.5 .54021 m
.52367 .53857 L
.53187 .55179 L
.51625 .55337 L
.5 .55386 L
F
.47633 .53857 m
.5 .54021 L
.5 .55386 L
.48375 .55337 L
.46813 .55179 L
F
.45626 .53244 m
.47633 .53857 L
.46813 .55179 L
.45373 .54878 L
.44111 .54387 L
F
.44285 .51939 m
.45626 .53244 L
.44111 .54387 L
.43076 .53652 L
.42306 .52647 L
F
.43814 .5 m
.44285 .51939 L
.42306 .52647 L
.41832 .51397 L
.41672 .5 L
F
.44285 .48061 m
.43814 .5 L
.41672 .5 L
.41832 .48603 L
.42306 .47353 L
F
.45626 .46756 m
.44285 .48061 L
.42306 .47353 L
.43076 .46348 L
.44111 .45613 L
F
.47633 .46143 m
.45626 .46756 L
.44111 .45613 L
.45373 .45122 L
.46813 .44821 L
F
.5 .45979 m
.47633 .46143 L
.46813 .44821 L
.48375 .44663 L
.5 .44614 L
F
.52367 .46143 m
.5 .45979 L
.5 .44614 L
.51625 .44663 L
.53187 .44821 L
F
.54374 .46756 m
.52367 .46143 L
.53187 .44821 L
.54627 .45122 L
.55889 .45613 L
F
.55715 .48061 m
.54374 .46756 L
.55889 .45613 L
.56924 .46348 L
.57694 .47353 L
F
.56186 .5 m
.55715 .48061 L
.57694 .47353 L
.58168 .48603 L
.58328 .5 L
F
.53967 .5 m
.56186 .5 L
.55715 .51939 L
.53665 .51187 L
F
.53665 .51187 m
.55715 .51939 L
.54374 .53244 L
.52805 .52048 L
F
.52805 .52048 m
.54374 .53244 L
.52367 .53857 L
.51518 .52497 L
F
.51518 .52497 m
.52367 .53857 L
.5 .54021 L
.5 .52626 L
F
.5 .52626 m
.5 .54021 L
.47633 .53857 L
.48482 .52497 L
F
.48482 .52497 m
.47633 .53857 L
.45626 .53244 L
.47195 .52048 L
F
.47195 .52048 m
.45626 .53244 L
.44285 .51939 L
.46335 .51187 L
F
.46335 .51187 m
.44285 .51939 L
.43814 .5 L
.46033 .5 L
F
.46033 .5 m
.43814 .5 L
.44285 .48061 L
.46335 .48813 L
F
.46335 .48813 m
.44285 .48061 L
.45626 .46756 L
.47195 .47952 L
F
.47195 .47952 m
.45626 .46756 L
.47633 .46143 L
.48482 .47503 L
F
.48482 .47503 m
.47633 .46143 L
.5 .45979 L
.5 .47374 L
F
.5 .47374 m
.5 .45979 L
.52367 .46143 L
.51518 .47503 L
F
.51518 .47503 m
.52367 .46143 L
.54374 .46756 L
.52805 .47952 L
F
.52805 .47952 m
.54374 .46756 L
.55715 .48061 L
.53665 .48813 L
F
.53665 .48813 m
.55715 .48061 L
.56186 .5 L
.53967 .5 L
F
.51349 .50972 m
.51908 .5 L
.53967 .5 L
.53665 .51187 L
.52805 .52048 L
F
.5 .51281 m
.51349 .50972 L
.52805 .52048 L
.51518 .52497 L
.5 .52626 L
F
.48651 .50972 m
.5 .51281 L
.5 .52626 L
.48482 .52497 L
.47195 .52048 L
F
.48092 .5 m
.48651 .50972 L
.47195 .52048 L
.46335 .51187 L
.46033 .5 L
F
.48651 .49028 m
.48092 .5 L
.46033 .5 L
.46335 .48813 L
.47195 .47952 L
F
.5 .48719 m
.48651 .49028 L
.47195 .47952 L
.48482 .47503 L
.5 .47374 L
F
.51349 .49028 m
.5 .48719 L
.5 .47374 L
.51518 .47503 L
.52805 .47952 L
F
.51908 .5 m
.51349 .49028 L
.52805 .47952 L
.53665 .48813 L
.53967 .5 L
F
.5 .5 m
.5 .5 L
.51908 .5 L
.51349 .50972 L
.5 .51281 L
F
.5 .5 m
.5 .5 L
.5 .51281 L
.48651 .50972 L
.48092 .5 L
F
.5 .5 m
.5 .5 L
.48092 .5 L
.48651 .49028 L
.5 .48719 L
F
.5 .5 m
.5 .5 L
.5 .48719 L
.51349 .49028 L
.51908 .5 L
F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
.82615 .53177 m
.82773 .5 L
.85 .5 L
.84831 .53409 L
s
.82143 .5621 m
.82615 .53177 L
.84831 .53409 L
.84327 .5666 L
s
.81362 .58981 m
.82143 .5621 L
.84327 .5666 L
.83493 .59625 L
s
.80278 .61413 m
.81362 .58981 L
.83493 .59625 L
.82336 .62223 L
s
.78903 .63476 m
.80278 .61413 L
.82336 .62223 L
.80867 .64423 L
s
.7725 .65179 m
.78903 .63476 L
.80867 .64423 L
.79101 .66235 L
s
.75334 .66552 m
.7725 .65179 L
.79101 .66235 L
.77055 .67693 L
s
.73174 .6764 m
.75334 .66552 L
.77055 .67693 L
.74749 .68848 L
s
.70791 .6849 m
.73174 .6764 L
.74749 .68848 L
.72204 .69749 L
s
.68208 .69145 m
.70791 .6849 L
.72204 .69749 L
.69445 .70442 L
s
.65449 .69641 m
.68208 .69145 L
.69445 .70442 L
.66499 .70967 L
s
.62542 .70009 m
.65449 .69641 L
.66499 .70967 L
.63394 .71357 L
s
.59513 .70273 m
.62542 .70009 L
.63394 .71357 L
.6016 .71636 L
s
.56394 .7045 m
.59513 .70273 L
.6016 .71636 L
.56828 .71823 L
s
.53212 .70551 m
.56394 .7045 L
.56828 .71823 L
.53431 .7193 L
s
.5 .70584 m
.53212 .70551 L
.53431 .7193 L
.5 .71965 L
s
.46788 .70551 m
.5 .70584 L
.5 .71965 L
.46569 .7193 L
s
.43606 .7045 m
.46788 .70551 L
.46569 .7193 L
.43172 .71823 L
s
.40487 .70273 m
.43606 .7045 L
.43172 .71823 L
.3984 .71636 L
s
.37458 .70009 m
.40487 .70273 L
.3984 .71636 L
.36606 .71357 L
s
.34551 .69641 m
.37458 .70009 L
.36606 .71357 L
.33501 .70967 L
s
.31792 .69145 m
.34551 .69641 L
.33501 .70967 L
.30555 .70442 L
s
.29209 .6849 m
.31792 .69145 L
.30555 .70442 L
.27796 .69749 L
s
.26826 .6764 m
.29209 .6849 L
.27796 .69749 L
.25251 .68848 L
s
.24666 .66552 m
.26826 .6764 L
.25251 .68848 L
.22945 .67693 L
s
.2275 .65179 m
.24666 .66552 L
.22945 .67693 L
.20899 .66235 L
s
.21097 .63476 m
.2275 .65179 L
.20899 .66235 L
.19133 .64423 L
s
.19722 .61413 m
.21097 .63476 L
.19133 .64423 L
.17664 .62223 L
s
.18638 .58981 m
.19722 .61413 L
.17664 .62223 L
.16507 .59625 L
s
.17857 .5621 m
.18638 .58981 L
.16507 .59625 L
.15673 .5666 L
s
.17385 .53177 m
.17857 .5621 L
.15673 .5666 L
.15169 .53409 L
s
.17227 .5 m
.17385 .53177 L
.15169 .53409 L
.15 .5 L
s
.17385 .46823 m
.17227 .5 L
.15 .5 L
.15169 .46591 L
s
.17857 .4379 m
.17385 .46823 L
.15169 .46591 L
.15673 .4334 L
s
.18638 .41019 m
.17857 .4379 L
.15673 .4334 L
.16507 .40375 L
s
.19722 .38587 m
.18638 .41019 L
.16507 .40375 L
.17664 .37777 L
s
.21097 .36524 m
.19722 .38587 L
.17664 .37777 L
.19133 .35577 L
s
.2275 .34821 m
.21097 .36524 L
.19133 .35577 L
.20899 .33765 L
s
.24666 .33448 m
.2275 .34821 L
.20899 .33765 L
.22945 .32307 L
s
.26826 .3236 m
.24666 .33448 L
.22945 .32307 L
.25251 .31152 L
s
.29209 .3151 m
.26826 .3236 L
.25251 .31152 L
.27796 .30251 L
s
.31792 .30855 m
.29209 .3151 L
.27796 .30251 L
.30555 .29558 L
s
.34551 .30359 m
.31792 .30855 L
.30555 .29558 L
.33501 .29033 L
s
.37458 .29991 m
.34551 .30359 L
.33501 .29033 L
.36606 .28643 L
s
.40487 .29727 m
.37458 .29991 L
.36606 .28643 L
.3984 .28364 L
s
.43606 .2955 m
.40487 .29727 L
.3984 .28364 L
.43172 .28177 L
s
.46788 .29449 m
.43606 .2955 L
.43172 .28177 L
.46569 .2807 L
s
.5 .29416 m
.46788 .29449 L
.46569 .2807 L
.5 .28035 L
s
.53212 .29449 m
.5 .29416 L
.5 .28035 L
.53431 .2807 L
s
.56394 .2955 m
.53212 .29449 L
.53431 .2807 L
.56828 .28177 L
s
.59513 .29727 m
.56394 .2955 L
.56828 .28177 L
.6016 .28364 L
s
.62542 .29991 m
.59513 .29727 L
.6016 .28364 L
.63394 .28643 L
s
.65449 .30359 m
.62542 .29991 L
.63394 .28643 L
.66499 .29033 L
s
.68208 .30855 m
.65449 .30359 L
.66499 .29033 L
.69445 .29558 L
s
.70791 .3151 m
.68208 .30855 L
.69445 .29558 L
.72204 .30251 L
s
.73174 .3236 m
.70791 .3151 L
.72204 .30251 L
.74749 .31152 L
s
.75334 .33448 m
.73174 .3236 L
.74749 .31152 L
.77055 .32307 L
s
.7725 .34821 m
.75334 .33448 L
.77055 .32307 L
.79101 .33765 L
s
.78903 .36524 m
.7725 .34821 L
.79101 .33765 L
.80867 .35577 L
s
.80278 .38587 m
.78903 .36524 L
.80867 .35577 L
.82336 .37777 L
s
.81362 .41019 m
.80278 .38587 L
.82336 .37777 L
.83493 .40375 L
s
.82143 .4379 m
.81362 .41019 L
.83493 .40375 L
.84327 .4334 L
s
.82615 .46823 m
.82143 .4379 L
.84327 .4334 L
.84831 .46591 L
s
.82773 .5 m
.82615 .46823 L
.84831 .46591 L
.85 .5 L
s
.80514 .5 m
.82773 .5 L
.82615 .53177 L
.80368 .52932 L
s
.80368 .52932 m
.82615 .53177 L
.82143 .5621 L
.79928 .55735 L
s
.79928 .55735 m
.82143 .5621 L
.81362 .58981 L
.79201 .58303 L
s
.79201 .58303 m
.81362 .58981 L
.80278 .61413 L
.78192 .60566 L
s
.78192 .60566 m
.80278 .61413 L
.78903 .63476 L
.76911 .62494 L
s
.76911 .62494 m
.78903 .63476 L
.7725 .65179 L
.75372 .6409 L
s
.75372 .6409 m
.7725 .65179 L
.75334 .66552 L
.73588 .65382 L
s
.73588 .65382 m
.75334 .66552 L
.73174 .6764 L
.71577 .66409 L
s
.71577 .66409 m
.73174 .6764 L
.70791 .6849 L
.69358 .67212 L
s
.69358 .67212 m
.70791 .6849 L
.68208 .69145 L
.66953 .67831 L
s
.66953 .67831 m
.68208 .69145 L
.65449 .69641 L
.64384 .68302 L
s
.64384 .68302 m
.65449 .69641 L
.62542 .70009 L
.61677 .68651 L
s
.61677 .68651 m
.62542 .70009 L
.59513 .70273 L
.58858 .68901 L
s
.58858 .68901 m
.59513 .70273 L
.56394 .7045 L
.55953 .69069 L
s
.55953 .69069 m
.56394 .7045 L
.53212 .70551 L
.52991 .69165 L
s
.52991 .69165 m
.53212 .70551 L
.5 .70584 L
.5 .69196 L
s
.5 .69196 m
.5 .70584 L
.46788 .70551 L
.47009 .69165 L
s
.47009 .69165 m
.46788 .70551 L
.43606 .7045 L
.44047 .69069 L
s
.44047 .69069 m
.43606 .7045 L
.40487 .70273 L
.41142 .68901 L
s
.41142 .68901 m
.40487 .70273 L
.37458 .70009 L
.38323 .68651 L
s
.38323 .68651 m
.37458 .70009 L
.34551 .69641 L
.35616 .68302 L
s
.35616 .68302 m
.34551 .69641 L
.31792 .69145 L
.33047 .67831 L
s
.33047 .67831 m
.31792 .69145 L
.29209 .6849 L
.30642 .67212 L
s
.30642 .67212 m
.29209 .6849 L
.26826 .6764 L
.28423 .66409 L
s
.28423 .66409 m
.26826 .6764 L
.24666 .66552 L
.26412 .65382 L
s
.26412 .65382 m
.24666 .66552 L
.2275 .65179 L
.24628 .6409 L
s
.24628 .6409 m
.2275 .65179 L
.21097 .63476 L
.23089 .62494 L
s
.23089 .62494 m
.21097 .63476 L
.19722 .61413 L
.21808 .60566 L
s
.21808 .60566 m
.19722 .61413 L
.18638 .58981 L
.20799 .58303 L
s
.20799 .58303 m
.18638 .58981 L
.17857 .5621 L
.20072 .55735 L
s
.20072 .55735 m
.17857 .5621 L
.17385 .53177 L
.19632 .52932 L
s
.19632 .52932 m
.17385 .53177 L
.17227 .5 L
.19486 .5 L
s
.19486 .5 m
.17227 .5 L
.17385 .46823 L
.19632 .47068 L
s
.19632 .47068 m
.17385 .46823 L
.17857 .4379 L
.20072 .44265 L
s
.20072 .44265 m
.17857 .4379 L
.18638 .41019 L
.20799 .41697 L
s
.20799 .41697 m
.18638 .41019 L
.19722 .38587 L
.21808 .39434 L
s
.21808 .39434 m
.19722 .38587 L
.21097 .36524 L
.23089 .37506 L
s
.23089 .37506 m
.21097 .36524 L
.2275 .34821 L
.24628 .3591 L
s
.24628 .3591 m
.2275 .34821 L
.24666 .33448 L
.26412 .34618 L
s
.26412 .34618 m
.24666 .33448 L
.26826 .3236 L
.28423 .33591 L
s
.28423 .33591 m
.26826 .3236 L
.29209 .3151 L
.30642 .32788 L
s
.30642 .32788 m
.29209 .3151 L
.31792 .30855 L
.33047 .32169 L
s
.33047 .32169 m
.31792 .30855 L
.34551 .30359 L
.35616 .31698 L
s
.35616 .31698 m
.34551 .30359 L
.37458 .29991 L
.38323 .31349 L
s
.38323 .31349 m
.37458 .29991 L
.40487 .29727 L
.41142 .31099 L
s
.41142 .31099 m
.40487 .29727 L
.43606 .2955 L
.44047 .30931 L
s
.44047 .30931 m
.43606 .2955 L
.46788 .29449 L
.47009 .30835 L
s
.47009 .30835 m
.46788 .29449 L
.5 .29416 L
.5 .30804 L
s
.5 .30804 m
.5 .29416 L
.53212 .29449 L
.52991 .30835 L
s
.52991 .30835 m
.53212 .29449 L
.56394 .2955 L
.55953 .30931 L
s
.55953 .30931 m
.56394 .2955 L
.59513 .29727 L
.58858 .31099 L
s
.58858 .31099 m
.59513 .29727 L
.62542 .29991 L
.61677 .31349 L
s
.61677 .31349 m
.62542 .29991 L
.65449 .30359 L
.64384 .31698 L
s
.64384 .31698 m
.65449 .30359 L
.68208 .30855 L
.66953 .32169 L
s
.66953 .32169 m
.68208 .30855 L
.70791 .3151 L
.69358 .32788 L
s
.69358 .32788 m
.70791 .3151 L
.73174 .3236 L
.71577 .33591 L
s
.71577 .33591 m
.73174 .3236 L
.75334 .33448 L
.73588 .34618 L
s
.73588 .34618 m
.75334 .33448 L
.7725 .34821 L
.75372 .3591 L
s
.75372 .3591 m
.7725 .34821 L
.78903 .36524 L
.76911 .37506 L
s
.76911 .37506 m
.78903 .36524 L
.80278 .38587 L
.78192 .39434 L
s
.78192 .39434 m
.80278 .38587 L
.81362 .41019 L
.79201 .41697 L
s
.79201 .41697 m
.81362 .41019 L
.82143 .4379 L
.79928 .44265 L
s
.79928 .44265 m
.82143 .4379 L
.82615 .46823 L
.80368 .47068 L
s
.80368 .47068 m
.82615 .46823 L
.82773 .5 L
.80514 .5 L
s
.78267 .5 m
.80514 .5 L
.80368 .52932 L
.78131 .52693 L
s
.78131 .52693 m
.80368 .52932 L
.79928 .55735 L
.77724 .55271 L
s
.77724 .55271 m
.79928 .55735 L
.79201 .58303 L
.7705 .57639 L
s
.7705 .57639 m
.79201 .58303 L
.78192 .60566 L
.76115 .59733 L
s
.76115 .59733 m
.78192 .60566 L
.76911 .62494 L
.74929 .61524 L
s
.74929 .61524 m
.76911 .62494 L
.75372 .6409 L
.73503 .63013 L
s
.73503 .63013 m
.75372 .6409 L
.73588 .65382 L
.7185 .64222 L
s
.7185 .64222 m
.73588 .65382 L
.71577 .66409 L
.69988 .65185 L
s
.69988 .65185 m
.71577 .66409 L
.69358 .67212 L
.67932 .6594 L
s
.67932 .6594 m
.69358 .67212 L
.66953 .67831 L
.65704 .66523 L
s
.65704 .66523 m
.66953 .67831 L
.64384 .68302 L
.63325 .66966 L
s
.63325 .66966 m
.64384 .68302 L
.61677 .68651 L
.60817 .67296 L
s
.60817 .67296 m
.61677 .68651 L
.58858 .68901 L
.58205 .67532 L
s
.58205 .67532 m
.58858 .68901 L
.55953 .69069 L
.55515 .6769 L
s
.55515 .6769 m
.55953 .69069 L
.52991 .69165 L
.52771 .67781 L
s
.52771 .67781 m
.52991 .69165 L
.5 .69196 L
.5 .67811 L
s
.5 .67811 m
.5 .69196 L
.47009 .69165 L
.47229 .67781 L
s
.47229 .67781 m
.47009 .69165 L
.44047 .69069 L
.44485 .6769 L
s
.44485 .6769 m
.44047 .69069 L
.41142 .68901 L
.41795 .67532 L
s
.41795 .67532 m
.41142 .68901 L
.38323 .68651 L
.39183 .67296 L
s
.39183 .67296 m
.38323 .68651 L
.35616 .68302 L
.36675 .66966 L
s
.36675 .66966 m
.35616 .68302 L
.33047 .67831 L
.34296 .66523 L
s
.34296 .66523 m
.33047 .67831 L
.30642 .67212 L
.32068 .6594 L
s
.32068 .6594 m
.30642 .67212 L
.28423 .66409 L
.30012 .65185 L
s
.30012 .65185 m
.28423 .66409 L
.26412 .65382 L
.2815 .64222 L
s
.2815 .64222 m
.26412 .65382 L
.24628 .6409 L
.26497 .63013 L
s
.26497 .63013 m
.24628 .6409 L
.23089 .62494 L
.25071 .61524 L
s
.25071 .61524 m
.23089 .62494 L
.21808 .60566 L
.23885 .59733 L
s
.23885 .59733 m
.21808 .60566 L
.20799 .58303 L
.2295 .57639 L
s
.2295 .57639 m
.20799 .58303 L
.20072 .55735 L
.22276 .55271 L
s
.22276 .55271 m
.20072 .55735 L
.19632 .52932 L
.21869 .52693 L
s
.21869 .52693 m
.19632 .52932 L
.19486 .5 L
.21733 .5 L
s
.21733 .5 m
.19486 .5 L
.19632 .47068 L
.21869 .47307 L
s
.21869 .47307 m
.19632 .47068 L
.20072 .44265 L
.22276 .44729 L
s
.22276 .44729 m
.20072 .44265 L
.20799 .41697 L
.2295 .42361 L
s
.2295 .42361 m
.20799 .41697 L
.21808 .39434 L
.23885 .40267 L
s
.23885 .40267 m
.21808 .39434 L
.23089 .37506 L
.25071 .38476 L
s
.25071 .38476 m
.23089 .37506 L
.24628 .3591 L
.26497 .36987 L
s
.26497 .36987 m
.24628 .3591 L
.26412 .34618 L
.2815 .35778 L
s
.2815 .35778 m
.26412 .34618 L
.28423 .33591 L
.30012 .34815 L
s
.30012 .34815 m
.28423 .33591 L
.30642 .32788 L
.32068 .3406 L
s
.32068 .3406 m
.30642 .32788 L
.33047 .32169 L
.34296 .33477 L
s
.34296 .33477 m
.33047 .32169 L
.35616 .31698 L
.36675 .33034 L
s
.36675 .33034 m
.35616 .31698 L
.38323 .31349 L
.39183 .32704 L
s
.39183 .32704 m
.38323 .31349 L
.41142 .31099 L
.41795 .32468 L
s
.41795 .32468 m
.41142 .31099 L
.44047 .30931 L
.44485 .3231 L
s
.44485 .3231 m
.44047 .30931 L
.47009 .30835 L
.47229 .32219 L
s
.47229 .32219 m
.47009 .30835 L
.5 .30804 L
.5 .32189 L
s
.5 .32189 m
.5 .30804 L
.52991 .30835 L
.52771 .32219 L
s
.52771 .32219 m
.52991 .30835 L
.55953 .30931 L
.55515 .3231 L
s
.55515 .3231 m
.55953 .30931 L
.58858 .31099 L
.58205 .32468 L
s
.58205 .32468 m
.58858 .31099 L
.61677 .31349 L
.60817 .32704 L
s
.60817 .32704 m
.61677 .31349 L
.64384 .31698 L
.63325 .33034 L
s
.63325 .33034 m
.64384 .31698 L
.66953 .32169 L
.65704 .33477 L
s
.65704 .33477 m
.66953 .32169 L
.69358 .32788 L
.67932 .3406 L
s
.67932 .3406 m
.69358 .32788 L
.71577 .33591 L
.69988 .34815 L
s
.69988 .34815 m
.71577 .33591 L
.73588 .34618 L
.7185 .35778 L
s
.7185 .35778 m
.73588 .34618 L
.75372 .3591 L
.73503 .36987 L
s
.73503 .36987 m
.75372 .3591 L
.76911 .37506 L
.74929 .38476 L
s
.74929 .38476 m
.76911 .37506 L
.78192 .39434 L
.76115 .40267 L
s
.76115 .40267 m
.78192 .39434 L
.79201 .41697 L
.7705 .42361 L
s
.7705 .42361 m
.79201 .41697 L
.79928 .44265 L
.77724 .44729 L
s
.77724 .44729 m
.79928 .44265 L
.80368 .47068 L
.78131 .47307 L
s
.78131 .47307 m
.80368 .47068 L
.80514 .5 L
.78267 .5 L
s
.76029 .5 m
.78267 .5 L
.78131 .52693 L
.75904 .52459 L
s
.75904 .52459 m
.78131 .52693 L
.77724 .55271 L
.75529 .54817 L
s
.75529 .54817 m
.77724 .55271 L
.7705 .57639 L
.74909 .56988 L
s
.74909 .56988 m
.7705 .57639 L
.76115 .59733 L
.74048 .58915 L
s
.74048 .58915 m
.76115 .59733 L
.74929 .61524 L
.72956 .60568 L
s
.72956 .60568 m
.74929 .61524 L
.73503 .63013 L
.71643 .61947 L
s
.71643 .61947 m
.73503 .63013 L
.7185 .64222 L
.70121 .63071 L
s
.70121 .63071 m
.7185 .64222 L
.69988 .65185 L
.68406 .63969 L
s
.68406 .63969 m
.69988 .65185 L
.67932 .6594 L
.66513 .64674 L
s
.66513 .64674 m
.67932 .6594 L
.65704 .66523 L
.64461 .6522 L
s
.64461 .6522 m
.65704 .66523 L
.63325 .66966 L
.6227 .65635 L
s
.6227 .65635 m
.63325 .66966 L
.60817 .67296 L
.59961 .65944 L
s
.59961 .65944 m
.60817 .67296 L
.58205 .67532 L
.57556 .66165 L
s
.57556 .66165 m
.58205 .67532 L
.55515 .6769 L
.55078 .66314 L
s
.55078 .66314 m
.55515 .6769 L
.52771 .67781 L
.52551 .66399 L
s
.52551 .66399 m
.52771 .67781 L
.5 .67811 L
.5 .66427 L
s
.5 .66427 m
.5 .67811 L
.47229 .67781 L
.47449 .66399 L
s
.47449 .66399 m
.47229 .67781 L
.44485 .6769 L
.44922 .66314 L
s
.44922 .66314 m
.44485 .6769 L
.41795 .67532 L
.42444 .66165 L
s
.42444 .66165 m
.41795 .67532 L
.39183 .67296 L
.40039 .65944 L
s
.40039 .65944 m
.39183 .67296 L
.36675 .66966 L
.3773 .65635 L
s
.3773 .65635 m
.36675 .66966 L
.34296 .66523 L
.35539 .6522 L
s
.35539 .6522 m
.34296 .66523 L
.32068 .6594 L
.33487 .64674 L
s
.33487 .64674 m
.32068 .6594 L
.30012 .65185 L
.31594 .63969 L
s
.31594 .63969 m
.30012 .65185 L
.2815 .64222 L
.29879 .63071 L
s
.29879 .63071 m
.2815 .64222 L
.26497 .63013 L
.28357 .61947 L
s
.28357 .61947 m
.26497 .63013 L
.25071 .61524 L
.27044 .60568 L
s
.27044 .60568 m
.25071 .61524 L
.23885 .59733 L
.25952 .58915 L
s
.25952 .58915 m
.23885 .59733 L
.2295 .57639 L
.25091 .56988 L
s
.25091 .56988 m
.2295 .57639 L
.22276 .55271 L
.24471 .54817 L
s
.24471 .54817 m
.22276 .55271 L
.21869 .52693 L
.24096 .52459 L
s
.24096 .52459 m
.21869 .52693 L
.21733 .5 L
.23971 .5 L
s
.23971 .5 m
.21733 .5 L
.21869 .47307 L
.24096 .47541 L
s
.24096 .47541 m
.21869 .47307 L
.22276 .44729 L
.24471 .45183 L
s
.24471 .45183 m
.22276 .44729 L
.2295 .42361 L
.25091 .43012 L
s
.25091 .43012 m
.2295 .42361 L
.23885 .40267 L
.25952 .41085 L
s
.25952 .41085 m
.23885 .40267 L
.25071 .38476 L
.27044 .39432 L
s
.27044 .39432 m
.25071 .38476 L
.26497 .36987 L
.28357 .38053 L
s
.28357 .38053 m
.26497 .36987 L
.2815 .35778 L
.29879 .36929 L
s
.29879 .36929 m
.2815 .35778 L
.30012 .34815 L
.31594 .36031 L
s
.31594 .36031 m
.30012 .34815 L
.32068 .3406 L
.33487 .35326 L
s
.33487 .35326 m
.32068 .3406 L
.34296 .33477 L
.35539 .3478 L
s
.35539 .3478 m
.34296 .33477 L
.36675 .33034 L
.3773 .34365 L
s
.3773 .34365 m
.36675 .33034 L
.39183 .32704 L
.40039 .34056 L
s
.40039 .34056 m
.39183 .32704 L
.41795 .32468 L
.42444 .33835 L
s
.42444 .33835 m
.41795 .32468 L
.44485 .3231 L
.44922 .33686 L
s
.44922 .33686 m
.44485 .3231 L
.47229 .32219 L
.47449 .33601 L
s
.47449 .33601 m
.47229 .32219 L
.5 .32189 L
.5 .33573 L
s
.5 .33573 m
.5 .32189 L
.52771 .32219 L
.52551 .33601 L
s
.52551 .33601 m
.52771 .32219 L
.55515 .3231 L
.55078 .33686 L
s
.55078 .33686 m
.55515 .3231 L
.58205 .32468 L
.57556 .33835 L
s
.57556 .33835 m
.58205 .32468 L
.60817 .32704 L
.59961 .34056 L
s
.59961 .34056 m
.60817 .32704 L
.63325 .33034 L
.6227 .34365 L
s
.6227 .34365 m
.63325 .33034 L
.65704 .33477 L
.64461 .3478 L
s
.64461 .3478 m
.65704 .33477 L
.67932 .3406 L
.66513 .35326 L
s
.66513 .35326 m
.67932 .3406 L
.69988 .34815 L
.68406 .36031 L
s
.68406 .36031 m
.69988 .34815 L
.7185 .35778 L
.70121 .36929 L
s
.70121 .36929 m
.7185 .35778 L
.73503 .36987 L
.71643 .38053 L
s
.71643 .38053 m
.73503 .36987 L
.74929 .38476 L
.72956 .39432 L
s
.72956 .39432 m
.74929 .38476 L
.76115 .40267 L
.74048 .41085 L
s
.74048 .41085 m
.76115 .40267 L
.7705 .42361 L
.74909 .43012 L
s
.74909 .43012 m
.7705 .42361 L
.77724 .44729 L
.75529 .45183 L
s
.75529 .45183 m
.77724 .44729 L
.78131 .47307 L
.75904 .47541 L
s
.75904 .47541 m
.78131 .47307 L
.78267 .5 L
.76029 .5 L
s
.73803 .5 m
.76029 .5 L
.75904 .52459 L
.73688 .52231 L
s
.73688 .52231 m
.75904 .52459 L
.75529 .54817 L
.73346 .54373 L
s
.73346 .54373 m
.75529 .54817 L
.74909 .56988 L
.72778 .5635 L
s
.72778 .5635 m
.74909 .56988 L
.74048 .58915 L
.71991 .58109 L
s
.71991 .58109 m
.74048 .58915 L
.72956 .60568 L
.70992 .59625 L
s
.70992 .59625 m
.72956 .60568 L
.71643 .61947 L
.69791 .60893 L
s
.69791 .60893 m
.71643 .61947 L
.70121 .63071 L
.684 .6193 L
s
.684 .6193 m
.70121 .63071 L
.68406 .63969 L
.66831 .62761 L
s
.66831 .62761 m
.68406 .63969 L
.66513 .64674 L
.651 .63415 L
s
.651 .63415 m
.66513 .64674 L
.64461 .6522 L
.63224 .63922 L
s
.63224 .63922 m
.64461 .6522 L
.6227 .65635 L
.61221 .64308 L
s
.61221 .64308 m
.6227 .65635 L
.59961 .65944 L
.59109 .64595 L
s
.59109 .64595 m
.59961 .65944 L
.57556 .66165 L
.5691 .64801 L
s
.5691 .64801 m
.57556 .66165 L
.55078 .66314 L
.54644 .6494 L
s
.54644 .6494 m
.55078 .66314 L
.52551 .66399 L
.52333 .65019 L
s
.52333 .65019 m
.52551 .66399 L
.5 .66427 L
.5 .65045 L
s
.5 .65045 m
.5 .66427 L
.47449 .66399 L
.47667 .65019 L
s
.47667 .65019 m
.47449 .66399 L
.44922 .66314 L
.45356 .6494 L
s
.45356 .6494 m
.44922 .66314 L
.42444 .66165 L
.4309 .64801 L
s
.4309 .64801 m
.42444 .66165 L
.40039 .65944 L
.40891 .64595 L
s
.40891 .64595 m
.40039 .65944 L
.3773 .65635 L
.38779 .64308 L
s
.38779 .64308 m
.3773 .65635 L
.35539 .6522 L
.36776 .63922 L
s
.36776 .63922 m
.35539 .6522 L
.33487 .64674 L
.349 .63415 L
s
.349 .63415 m
.33487 .64674 L
.31594 .63969 L
.33169 .62761 L
s
.33169 .62761 m
.31594 .63969 L
.29879 .63071 L
.316 .6193 L
s
.316 .6193 m
.29879 .63071 L
.28357 .61947 L
.30209 .60893 L
s
.30209 .60893 m
.28357 .61947 L
.27044 .60568 L
.29008 .59625 L
s
.29008 .59625 m
.27044 .60568 L
.25952 .58915 L
.28009 .58109 L
s
.28009 .58109 m
.25952 .58915 L
.25091 .56988 L
.27222 .5635 L
s
.27222 .5635 m
.25091 .56988 L
.24471 .54817 L
.26654 .54373 L
s
.26654 .54373 m
.24471 .54817 L
.24096 .52459 L
.26312 .52231 L
s
.26312 .52231 m
.24096 .52459 L
.23971 .5 L
.26197 .5 L
s
.26197 .5 m
.23971 .5 L
.24096 .47541 L
.26312 .47769 L
s
.26312 .47769 m
.24096 .47541 L
.24471 .45183 L
.26654 .45627 L
s
.26654 .45627 m
.24471 .45183 L
.25091 .43012 L
.27222 .4365 L
s
.27222 .4365 m
.25091 .43012 L
.25952 .41085 L
.28009 .41891 L
s
.28009 .41891 m
.25952 .41085 L
.27044 .39432 L
.29008 .40375 L
s
.29008 .40375 m
.27044 .39432 L
.28357 .38053 L
.30209 .39107 L
s
.30209 .39107 m
.28357 .38053 L
.29879 .36929 L
.316 .3807 L
s
.316 .3807 m
.29879 .36929 L
.31594 .36031 L
.33169 .37239 L
s
.33169 .37239 m
.31594 .36031 L
.33487 .35326 L
.349 .36585 L
s
.349 .36585 m
.33487 .35326 L
.35539 .3478 L
.36776 .36078 L
s
.36776 .36078 m
.35539 .3478 L
.3773 .34365 L
.38779 .35692 L
s
.38779 .35692 m
.3773 .34365 L
.40039 .34056 L
.40891 .35405 L
s
.40891 .35405 m
.40039 .34056 L
.42444 .33835 L
.4309 .35199 L
s
.4309 .35199 m
.42444 .33835 L
.44922 .33686 L
.45356 .3506 L
s
.45356 .3506 m
.44922 .33686 L
.47449 .33601 L
.47667 .34981 L
s
.47667 .34981 m
.47449 .33601 L
.5 .33573 L
.5 .34955 L
s
.5 .34955 m
.5 .33573 L
.52551 .33601 L
.52333 .34981 L
s
.52333 .34981 m
.52551 .33601 L
.55078 .33686 L
.54644 .3506 L
s
.54644 .3506 m
.55078 .33686 L
.57556 .33835 L
.5691 .35199 L
s
.5691 .35199 m
.57556 .33835 L
.59961 .34056 L
.59109 .35405 L
s
.59109 .35405 m
.59961 .34056 L
.6227 .34365 L
.61221 .35692 L
s
.61221 .35692 m
.6227 .34365 L
.64461 .3478 L
.63224 .36078 L
s
.63224 .36078 m
.64461 .3478 L
.66513 .35326 L
.651 .36585 L
s
.651 .36585 m
.66513 .35326 L
.68406 .36031 L
.66831 .37239 L
s
.66831 .37239 m
.68406 .36031 L
.70121 .36929 L
.684 .3807 L
s
.684 .3807 m
.70121 .36929 L
.71643 .38053 L
.69791 .39107 L
s
.69791 .39107 m
.71643 .38053 L
.72956 .39432 L
.70992 .40375 L
s
.70992 .40375 m
.72956 .39432 L
.74048 .41085 L
.71991 .41891 L
s
.71991 .41891 m
.74048 .41085 L
.74909 .43012 L
.72778 .4365 L
s
.72778 .4365 m
.74909 .43012 L
.75529 .45183 L
.73346 .45627 L
s
.73346 .45627 m
.75529 .45183 L
.75904 .47541 L
.73688 .47769 L
s
.73688 .47769 m
.75904 .47541 L
.76029 .5 L
.73803 .5 L
s
.71587 .5 m
.73803 .5 L
.73688 .52231 L
.71483 .52008 L
s
.71483 .52008 m
.73688 .52231 L
.73346 .54373 L
.71172 .53938 L
s
.71172 .53938 m
.73346 .54373 L
.72778 .5635 L
.70657 .55723 L
s
.70657 .55723 m
.72778 .5635 L
.71991 .58109 L
.69944 .57316 L
s
.69944 .57316 m
.71991 .58109 L
.70992 .59625 L
.69038 .58693 L
s
.69038 .58693 m
.70992 .59625 L
.69791 .60893 L
.67949 .5985 L
s
.67949 .5985 m
.69791 .60893 L
.684 .6193 L
.66687 .60799 L
s
.66687 .60799 m
.684 .6193 L
.66831 .62761 L
.65264 .6156 L
s
.65264 .6156 m
.66831 .62761 L
.651 .63415 L
.63695 .62162 L
s
.63695 .62162 m
.651 .63415 L
.63224 .63922 L
.61993 .62629 L
s
.61993 .62629 m
.63224 .63922 L
.61221 .64308 L
.60176 .62985 L
s
.60176 .62985 m
.61221 .64308 L
.59109 .64595 L
.58261 .6325 L
s
.58261 .6325 m
.59109 .64595 L
.5691 .64801 L
.56266 .6344 L
s
.56266 .6344 m
.5691 .64801 L
.54644 .6494 L
.54211 .63568 L
s
.54211 .63568 m
.54644 .6494 L
.52333 .65019 L
.52116 .63642 L
s
.52116 .63642 m
.52333 .65019 L
.5 .65045 L
.5 .63666 L
s
.5 .63666 m
.5 .65045 L
.47667 .65019 L
.47884 .63642 L
s
.47884 .63642 m
.47667 .65019 L
.45356 .6494 L
.45789 .63568 L
s
.45789 .63568 m
.45356 .6494 L
.4309 .64801 L
.43734 .6344 L
s
.43734 .6344 m
.4309 .64801 L
.40891 .64595 L
.41739 .6325 L
s
.41739 .6325 m
.40891 .64595 L
.38779 .64308 L
.39824 .62985 L
s
.39824 .62985 m
.38779 .64308 L
.36776 .63922 L
.38007 .62629 L
s
.38007 .62629 m
.36776 .63922 L
.349 .63415 L
.36305 .62162 L
s
.36305 .62162 m
.349 .63415 L
.33169 .62761 L
.34736 .6156 L
s
.34736 .6156 m
.33169 .62761 L
.316 .6193 L
.33313 .60799 L
s
.33313 .60799 m
.316 .6193 L
.30209 .60893 L
.32051 .5985 L
s
.32051 .5985 m
.30209 .60893 L
.29008 .59625 L
.30962 .58693 L
s
.30962 .58693 m
.29008 .59625 L
.28009 .58109 L
.30056 .57316 L
s
.30056 .57316 m
.28009 .58109 L
.27222 .5635 L
.29343 .55723 L
s
.29343 .55723 m
.27222 .5635 L
.26654 .54373 L
.28828 .53938 L
s
.28828 .53938 m
.26654 .54373 L
.26312 .52231 L
.28517 .52008 L
s
.28517 .52008 m
.26312 .52231 L
.26197 .5 L
.28413 .5 L
s
.28413 .5 m
.26197 .5 L
.26312 .47769 L
.28517 .47992 L
s
.28517 .47992 m
.26312 .47769 L
.26654 .45627 L
.28828 .46062 L
s
.28828 .46062 m
.26654 .45627 L
.27222 .4365 L
.29343 .44277 L
s
.29343 .44277 m
.27222 .4365 L
.28009 .41891 L
.30056 .42684 L
s
.30056 .42684 m
.28009 .41891 L
.29008 .40375 L
.30962 .41307 L
s
.30962 .41307 m
.29008 .40375 L
.30209 .39107 L
.32051 .4015 L
s
.32051 .4015 m
.30209 .39107 L
.316 .3807 L
.33313 .39201 L
s
.33313 .39201 m
.316 .3807 L
.33169 .37239 L
.34736 .3844 L
s
.34736 .3844 m
.33169 .37239 L
.349 .36585 L
.36305 .37838 L
s
.36305 .37838 m
.349 .36585 L
.36776 .36078 L
.38007 .37371 L
s
.38007 .37371 m
.36776 .36078 L
.38779 .35692 L
.39824 .37015 L
s
.39824 .37015 m
.38779 .35692 L
.40891 .35405 L
.41739 .3675 L
s
.41739 .3675 m
.40891 .35405 L
.4309 .35199 L
.43734 .3656 L
s
.43734 .3656 m
.4309 .35199 L
.45356 .3506 L
.45789 .36432 L
s
.45789 .36432 m
.45356 .3506 L
.47667 .34981 L
.47884 .36358 L
s
.47884 .36358 m
.47667 .34981 L
.5 .34955 L
.5 .36334 L
s
.5 .36334 m
.5 .34955 L
.52333 .34981 L
.52116 .36358 L
s
.52116 .36358 m
.52333 .34981 L
.54644 .3506 L
.54211 .36432 L
s
.54211 .36432 m
.54644 .3506 L
.5691 .35199 L
.56266 .3656 L
s
.56266 .3656 m
.5691 .35199 L
.59109 .35405 L
.58261 .3675 L
s
.58261 .3675 m
.59109 .35405 L
.61221 .35692 L
.60176 .37015 L
s
.60176 .37015 m
.61221 .35692 L
.63224 .36078 L
.61993 .37371 L
s
.61993 .37371 m
.63224 .36078 L
.651 .36585 L
.63695 .37838 L
s
.63695 .37838 m
.651 .36585 L
.66831 .37239 L
.65264 .3844 L
s
.65264 .3844 m
.66831 .37239 L
.684 .3807 L
.66687 .39201 L
s
.66687 .39201 m
.684 .3807 L
.69791 .39107 L
.67949 .4015 L
s
.67949 .4015 m
.69791 .39107 L
.70992 .40375 L
.69038 .41307 L
s
.69038 .41307 m
.70992 .40375 L
.71991 .41891 L
.69944 .42684 L
s
.69944 .42684 m
.71991 .41891 L
.72778 .4365 L
.70657 .44277 L
s
.70657 .44277 m
.72778 .4365 L
.73346 .45627 L
.71172 .46062 L
s
.71172 .46062 m
.73346 .45627 L
.73688 .47769 L
.71483 .47992 L
s
.71483 .47992 m
.73688 .47769 L
.73803 .5 L
.71587 .5 L
s
.69381 .5 m
.71587 .5 L
.71483 .52008 L
.69288 .5179 L
s
.69288 .5179 m
.71483 .52008 L
.71172 .53938 L
.69009 .53511 L
s
.69009 .53511 m
.71172 .53938 L
.70657 .55723 L
.68547 .55108 L
s
.68547 .55108 m
.70657 .55723 L
.69944 .57316 L
.67906 .56536 L
s
.67906 .56536 m
.69944 .57316 L
.69038 .58693 L
.67093 .57775 L
s
.67093 .57775 m
.69038 .58693 L
.67949 .5985 L
.66115 .58818 L
s
.66115 .58818 m
.67949 .5985 L
.66687 .60799 L
.64982 .59677 L
s
.64982 .59677 m
.66687 .60799 L
.65264 .6156 L
.63705 .60368 L
s
.63705 .60368 m
.65264 .6156 L
.63695 .62162 L
.62295 .60915 L
s
.62295 .60915 m
.63695 .62162 L
.61993 .62629 L
.60768 .61341 L
s
.60768 .61341 m
.61993 .62629 L
.60176 .62985 L
.59136 .61666 L
s
.59136 .61666 m
.60176 .62985 L
.58261 .6325 L
.57417 .61908 L
s
.57417 .61908 m
.58261 .6325 L
.56266 .6344 L
.55626 .62082 L
s
.55626 .62082 m
.56266 .6344 L
.54211 .63568 L
.53781 .62199 L
s
.53781 .62199 m
.54211 .63568 L
.52116 .63642 L
.519 .62266 L
s
.519 .62266 m
.52116 .63642 L
.5 .63666 L
.5 .62288 L
s
.5 .62288 m
.5 .63666 L
.47884 .63642 L
.481 .62266 L
s
.481 .62266 m
.47884 .63642 L
.45789 .63568 L
.46219 .62199 L
s
.46219 .62199 m
.45789 .63568 L
.43734 .6344 L
.44374 .62082 L
s
.44374 .62082 m
.43734 .6344 L
.41739 .6325 L
.42583 .61908 L
s
.42583 .61908 m
.41739 .6325 L
.39824 .62985 L
.40864 .61666 L
s
.40864 .61666 m
.39824 .62985 L
.38007 .62629 L
.39232 .61341 L
s
.39232 .61341 m
.38007 .62629 L
.36305 .62162 L
.37705 .60915 L
s
.37705 .60915 m
.36305 .62162 L
.34736 .6156 L
.36295 .60368 L
s
.36295 .60368 m
.34736 .6156 L
.33313 .60799 L
.35018 .59677 L
s
.35018 .59677 m
.33313 .60799 L
.32051 .5985 L
.33885 .58818 L
s
.33885 .58818 m
.32051 .5985 L
.30962 .58693 L
.32907 .57775 L
s
.32907 .57775 m
.30962 .58693 L
.30056 .57316 L
.32094 .56536 L
s
.32094 .56536 m
.30056 .57316 L
.29343 .55723 L
.31453 .55108 L
s
.31453 .55108 m
.29343 .55723 L
.28828 .53938 L
.30991 .53511 L
s
.30991 .53511 m
.28828 .53938 L
.28517 .52008 L
.30712 .5179 L
s
.30712 .5179 m
.28517 .52008 L
.28413 .5 L
.30619 .5 L
s
.30619 .5 m
.28413 .5 L
.28517 .47992 L
.30712 .4821 L
s
.30712 .4821 m
.28517 .47992 L
.28828 .46062 L
.30991 .46489 L
s
.30991 .46489 m
.28828 .46062 L
.29343 .44277 L
.31453 .44892 L
s
.31453 .44892 m
.29343 .44277 L
.30056 .42684 L
.32094 .43464 L
s
.32094 .43464 m
.30056 .42684 L
.30962 .41307 L
.32907 .42225 L
s
.32907 .42225 m
.30962 .41307 L
.32051 .4015 L
.33885 .41182 L
s
.33885 .41182 m
.32051 .4015 L
.33313 .39201 L
.35018 .40323 L
s
.35018 .40323 m
.33313 .39201 L
.34736 .3844 L
.36295 .39632 L
s
.36295 .39632 m
.34736 .3844 L
.36305 .37838 L
.37705 .39085 L
s
.37705 .39085 m
.36305 .37838 L
.38007 .37371 L
.39232 .38659 L
s
.39232 .38659 m
.38007 .37371 L
.39824 .37015 L
.40864 .38334 L
s
.40864 .38334 m
.39824 .37015 L
.41739 .3675 L
.42583 .38092 L
s
.42583 .38092 m
.41739 .3675 L
.43734 .3656 L
.44374 .37918 L
s
.44374 .37918 m
.43734 .3656 L
.45789 .36432 L
.46219 .37801 L
s
.46219 .37801 m
.45789 .36432 L
.47884 .36358 L
.481 .37734 L
s
.481 .37734 m
.47884 .36358 L
.5 .36334 L
.5 .37712 L
s
.5 .37712 m
.5 .36334 L
.52116 .36358 L
.519 .37734 L
s
.519 .37734 m
.52116 .36358 L
.54211 .36432 L
.53781 .37801 L
s
.53781 .37801 m
.54211 .36432 L
.56266 .3656 L
.55626 .37918 L
s
.55626 .37918 m
.56266 .3656 L
.58261 .3675 L
.57417 .38092 L
s
.57417 .38092 m
.58261 .3675 L
.60176 .37015 L
.59136 .38334 L
s
.59136 .38334 m
.60176 .37015 L
.61993 .37371 L
.60768 .38659 L
s
.60768 .38659 m
.61993 .37371 L
.63695 .37838 L
.62295 .39085 L
s
.62295 .39085 m
.63695 .37838 L
.65264 .3844 L
.63705 .39632 L
s
.63705 .39632 m
.65264 .3844 L
.66687 .39201 L
.64982 .40323 L
s
.64982 .40323 m
.66687 .39201 L
.67949 .4015 L
.66115 .41182 L
s
.66115 .41182 m
.67949 .4015 L
.69038 .41307 L
.67093 .42225 L
s
.67093 .42225 m
.69038 .41307 L
.69944 .42684 L
.67906 .43464 L
s
.67906 .43464 m
.69944 .42684 L
.70657 .44277 L
.68547 .44892 L
s
.68547 .44892 m
.70657 .44277 L
.71172 .46062 L
.69009 .46489 L
s
.69009 .46489 m
.71172 .46062 L
.71483 .47992 L
.69288 .4821 L
s
.69288 .4821 m
.71483 .47992 L
.71587 .5 L
.69381 .5 L
s
.67186 .5 m
.69381 .5 L
.69288 .5179 L
.67104 .51576 L
s
.67104 .51576 m
.69288 .5179 L
.69009 .53511 L
.66856 .53093 L
s
.66856 .53093 m
.69009 .53511 L
.68547 .55108 L
.66446 .54503 L
s
.66446 .54503 m
.68547 .55108 L
.67906 .56536 L
.65878 .55768 L
s
.65878 .55768 m
.67906 .56536 L
.67093 .57775 L
.65157 .56867 L
s
.65157 .56867 m
.67093 .57775 L
.66115 .58818 L
.6429 .57797 L
s
.6429 .57797 m
.66115 .58818 L
.64982 .59677 L
.63285 .58564 L
s
.63285 .58564 m
.64982 .59677 L
.63705 .60368 L
.62153 .59184 L
s
.62153 .59184 m
.63705 .60368 L
.62295 .60915 L
.60903 .59675 L
s
.60903 .59675 m
.62295 .60915 L
.60768 .61341 L
.59548 .60058 L
s
.59548 .60058 m
.60768 .61341 L
.59136 .61666 L
.58102 .60351 L
s
.58102 .60351 m
.59136 .61666 L
.57417 .61908 L
.56577 .6057 L
s
.56577 .6057 m
.57417 .61908 L
.55626 .62082 L
.54989 .60727 L
s
.54989 .60727 m
.55626 .62082 L
.53781 .62199 L
.53353 .60833 L
s
.53353 .60833 m
.53781 .62199 L
.519 .62266 L
.51685 .60893 L
s
.51685 .60893 m
.519 .62266 L
.5 .62288 L
.5 .60913 L
s
.5 .60913 m
.5 .62288 L
.481 .62266 L
.48315 .60893 L
s
.48315 .60893 m
.481 .62266 L
.46219 .62199 L
.46647 .60833 L
s
.46647 .60833 m
.46219 .62199 L
.44374 .62082 L
.45011 .60727 L
s
.45011 .60727 m
.44374 .62082 L
.42583 .61908 L
.43423 .6057 L
s
.43423 .6057 m
.42583 .61908 L
.40864 .61666 L
.41898 .60351 L
s
.41898 .60351 m
.40864 .61666 L
.39232 .61341 L
.40452 .60058 L
s
.40452 .60058 m
.39232 .61341 L
.37705 .60915 L
.39097 .59675 L
s
.39097 .59675 m
.37705 .60915 L
.36295 .60368 L
.37847 .59184 L
s
.37847 .59184 m
.36295 .60368 L
.35018 .59677 L
.36715 .58564 L
s
.36715 .58564 m
.35018 .59677 L
.33885 .58818 L
.3571 .57797 L
s
.3571 .57797 m
.33885 .58818 L
.32907 .57775 L
.34843 .56867 L
s
.34843 .56867 m
.32907 .57775 L
.32094 .56536 L
.34122 .55768 L
s
.34122 .55768 m
.32094 .56536 L
.31453 .55108 L
.33554 .54503 L
s
.33554 .54503 m
.31453 .55108 L
.30991 .53511 L
.33144 .53093 L
s
.33144 .53093 m
.30991 .53511 L
.30712 .5179 L
.32896 .51576 L
s
.32896 .51576 m
.30712 .5179 L
.30619 .5 L
.32814 .5 L
s
.32814 .5 m
.30619 .5 L
.30712 .4821 L
.32896 .48424 L
s
.32896 .48424 m
.30712 .4821 L
.30991 .46489 L
.33144 .46907 L
s
.33144 .46907 m
.30991 .46489 L
.31453 .44892 L
.33554 .45497 L
s
.33554 .45497 m
.31453 .44892 L
.32094 .43464 L
.34122 .44232 L
s
.34122 .44232 m
.32094 .43464 L
.32907 .42225 L
.34843 .43133 L
s
.34843 .43133 m
.32907 .42225 L
.33885 .41182 L
.3571 .42203 L
s
.3571 .42203 m
.33885 .41182 L
.35018 .40323 L
.36715 .41436 L
s
.36715 .41436 m
.35018 .40323 L
.36295 .39632 L
.37847 .40816 L
s
.37847 .40816 m
.36295 .39632 L
.37705 .39085 L
.39097 .40325 L
s
.39097 .40325 m
.37705 .39085 L
.39232 .38659 L
.40452 .39942 L
s
.40452 .39942 m
.39232 .38659 L
.40864 .38334 L
.41898 .39649 L
s
.41898 .39649 m
.40864 .38334 L
.42583 .38092 L
.43423 .3943 L
s
.43423 .3943 m
.42583 .38092 L
.44374 .37918 L
.45011 .39273 L
s
.45011 .39273 m
.44374 .37918 L
.46219 .37801 L
.46647 .39167 L
s
.46647 .39167 m
.46219 .37801 L
.481 .37734 L
.48315 .39107 L
s
.48315 .39107 m
.481 .37734 L
.5 .37712 L
.5 .39087 L
s
.5 .39087 m
.5 .37712 L
.519 .37734 L
.51685 .39107 L
s
.51685 .39107 m
.519 .37734 L
.53781 .37801 L
.53353 .39167 L
s
.53353 .39167 m
.53781 .37801 L
.55626 .37918 L
.54989 .39273 L
s
.54989 .39273 m
.55626 .37918 L
.57417 .38092 L
.56577 .3943 L
s
.56577 .3943 m
.57417 .38092 L
.59136 .38334 L
.58102 .39649 L
s
.58102 .39649 m
.59136 .38334 L
.60768 .38659 L
.59548 .39942 L
s
.59548 .39942 m
.60768 .38659 L
.62295 .39085 L
.60903 .40325 L
s
.60903 .40325 m
.62295 .39085 L
.63705 .39632 L
.62153 .40816 L
s
.62153 .40816 m
.63705 .39632 L
.64982 .40323 L
.63285 .41436 L
s
.63285 .41436 m
.64982 .40323 L
.66115 .41182 L
.6429 .42203 L
s
.6429 .42203 m
.66115 .41182 L
.67093 .42225 L
.65157 .43133 L
s
.65157 .43133 m
.67093 .42225 L
.67906 .43464 L
.65878 .44232 L
s
.65878 .44232 m
.67906 .43464 L
.68547 .44892 L
.66446 .45497 L
s
.66446 .45497 m
.68547 .44892 L
.69009 .46489 L
.66856 .46907 L
s
.66856 .46907 m
.69009 .46489 L
.69288 .4821 L
.67104 .48424 L
s
.67104 .48424 m
.69288 .4821 L
.69381 .5 L
.67186 .5 L
s
.64714 .52683 m
.65002 .5 L
.67186 .5 L
.67104 .51576 L
.66856 .53093 L
s
.6386 .55011 m
.64714 .52683 L
.66856 .53093 L
.66446 .54503 L
.65878 .55768 L
s
.62474 .56787 m
.6386 .55011 L
.65878 .55768 L
.65157 .56867 L
.6429 .57797 L
s
.60608 .58008 m
.62474 .56787 L
.6429 .57797 L
.63285 .58564 L
.62153 .59184 L
s
.58335 .58781 m
.60608 .58008 L
.62153 .59184 L
.60903 .59675 L
.59548 .60058 L
s
.55741 .59235 m
.58335 .58781 L
.59548 .60058 L
.58102 .60351 L
.56577 .6057 L
s
.52927 .59469 m
.55741 .59235 L
.56577 .6057 L
.54989 .60727 L
.53353 .60833 L
s
.5 .5954 m
.52927 .59469 L
.53353 .60833 L
.51685 .60893 L
.5 .60913 L
s
.47073 .59469 m
.5 .5954 L
.5 .60913 L
.48315 .60893 L
.46647 .60833 L
s
.44259 .59235 m
.47073 .59469 L
.46647 .60833 L
.45011 .60727 L
.43423 .6057 L
s
.41665 .58781 m
.44259 .59235 L
.43423 .6057 L
.41898 .60351 L
.40452 .60058 L
s
.39392 .58008 m
.41665 .58781 L
.40452 .60058 L
.39097 .59675 L
.37847 .59184 L
s
.37526 .56787 m
.39392 .58008 L
.37847 .59184 L
.36715 .58564 L
.3571 .57797 L
s
.3614 .55011 m
.37526 .56787 L
.3571 .57797 L
.34843 .56867 L
.34122 .55768 L
s
.35286 .52683 m
.3614 .55011 L
.34122 .55768 L
.33554 .54503 L
.33144 .53093 L
s
.34998 .5 m
.35286 .52683 L
.33144 .53093 L
.32896 .51576 L
.32814 .5 L
s
.35286 .47317 m
.34998 .5 L
.32814 .5 L
.32896 .48424 L
.33144 .46907 L
s
.3614 .44989 m
.35286 .47317 L
.33144 .46907 L
.33554 .45497 L
.34122 .44232 L
s
.37526 .43213 m
.3614 .44989 L
.34122 .44232 L
.34843 .43133 L
.3571 .42203 L
s
.39392 .41992 m
.37526 .43213 L
.3571 .42203 L
.36715 .41436 L
.37847 .40816 L
s
.41665 .41219 m
.39392 .41992 L
.37847 .40816 L
.39097 .40325 L
.40452 .39942 L
s
.44259 .40765 m
.41665 .41219 L
.40452 .39942 L
.41898 .39649 L
.43423 .3943 L
s
.47073 .40531 m
.44259 .40765 L
.43423 .3943 L
.45011 .39273 L
.46647 .39167 L
s
.5 .4046 m
.47073 .40531 L
.46647 .39167 L
.48315 .39107 L
.5 .39087 L
s
.52927 .40531 m
.5 .4046 L
.5 .39087 L
.51685 .39107 L
.53353 .39167 L
s
.55741 .40765 m
.52927 .40531 L
.53353 .39167 L
.54989 .39273 L
.56577 .3943 L
s
.58335 .41219 m
.55741 .40765 L
.56577 .3943 L
.58102 .39649 L
.59548 .39942 L
s
.60608 .41992 m
.58335 .41219 L
.59548 .39942 L
.60903 .40325 L
.62153 .40816 L
s
.62474 .43213 m
.60608 .41992 L
.62153 .40816 L
.63285 .41436 L
.6429 .42203 L
s
.6386 .44989 m
.62474 .43213 L
.6429 .42203 L
.65157 .43133 L
.65878 .44232 L
s
.64714 .47317 m
.6386 .44989 L
.65878 .44232 L
.66446 .45497 L
.66856 .46907 L
s
.65002 .5 m
.64714 .47317 L
.66856 .46907 L
.67104 .48424 L
.67186 .5 L
s
.62735 .5 m
.65002 .5 L
.64714 .52683 L
.62491 .52224 L
s
.62491 .52224 m
.64714 .52683 L
.6386 .55011 L
.61766 .54177 L
s
.61766 .54177 m
.6386 .55011 L
.62474 .56787 L
.60589 .55698 L
s
.60589 .55698 m
.62474 .56787 L
.60608 .58008 L
.59005 .56768 L
s
.59005 .56768 m
.60608 .58008 L
.58335 .58781 L
.57075 .57458 L
s
.57075 .57458 m
.58335 .58781 L
.55741 .59235 L
.54874 .57869 L
s
.54874 .57869 m
.55741 .59235 L
.52927 .59469 L
.52485 .58081 L
s
.52485 .58081 m
.52927 .59469 L
.5 .5954 L
.5 .58147 L
s
.5 .58147 m
.5 .5954 L
.47073 .59469 L
.47515 .58081 L
s
.47515 .58081 m
.47073 .59469 L
.44259 .59235 L
.45126 .57869 L
s
.45126 .57869 m
.44259 .59235 L
.41665 .58781 L
.42925 .57458 L
s
.42925 .57458 m
.41665 .58781 L
.39392 .58008 L
.40995 .56768 L
s
.40995 .56768 m
.39392 .58008 L
.37526 .56787 L
.39411 .55698 L
s
.39411 .55698 m
.37526 .56787 L
.3614 .55011 L
.38234 .54177 L
s
.38234 .54177 m
.3614 .55011 L
.35286 .52683 L
.37509 .52224 L
s
.37509 .52224 m
.35286 .52683 L
.34998 .5 L
.37265 .5 L
s
.37265 .5 m
.34998 .5 L
.35286 .47317 L
.37509 .47776 L
s
.37509 .47776 m
.35286 .47317 L
.3614 .44989 L
.38234 .45823 L
s
.38234 .45823 m
.3614 .44989 L
.37526 .43213 L
.39411 .44302 L
s
.39411 .44302 m
.37526 .43213 L
.39392 .41992 L
.40995 .43232 L
s
.40995 .43232 m
.39392 .41992 L
.41665 .41219 L
.42925 .42542 L
s
.42925 .42542 m
.41665 .41219 L
.44259 .40765 L
.45126 .42131 L
s
.45126 .42131 m
.44259 .40765 L
.47073 .40531 L
.47515 .41919 L
s
.47515 .41919 m
.47073 .40531 L
.5 .4046 L
.5 .41853 L
s
.5 .41853 m
.5 .4046 L
.52927 .40531 L
.52485 .41919 L
s
.52485 .41919 m
.52927 .40531 L
.55741 .40765 L
.54874 .42131 L
s
.54874 .42131 m
.55741 .40765 L
.58335 .41219 L
.57075 .42542 L
s
.57075 .42542 m
.58335 .41219 L
.60608 .41992 L
.59005 .43232 L
s
.59005 .43232 m
.60608 .41992 L
.62474 .43213 L
.60589 .44302 L
s
.60589 .44302 m
.62474 .43213 L
.6386 .44989 L
.61766 .45823 L
s
.61766 .45823 m
.6386 .44989 L
.64714 .47317 L
.62491 .47776 L
s
.62491 .47776 m
.64714 .47317 L
.65002 .5 L
.62735 .5 L
s
.60511 .5 m
.62735 .5 L
.62491 .52224 L
.60309 .51797 L
s
.60309 .51797 m
.62491 .52224 L
.61766 .54177 L
.59711 .53391 L
s
.59711 .53391 m
.61766 .54177 L
.60589 .55698 L
.58739 .54655 L
s
.58739 .54655 m
.60589 .55698 L
.59005 .56768 L
.57432 .55561 L
s
.57432 .55561 m
.59005 .56768 L
.57075 .57458 L
.55839 .56157 L
s
.55839 .56157 m
.57075 .57458 L
.54874 .57869 L
.54022 .56516 L
s
.54022 .56516 m
.54874 .57869 L
.52485 .58081 L
.52051 .56704 L
s
.52051 .56704 m
.52485 .58081 L
.5 .58147 L
.5 .56762 L
s
.5 .56762 m
.5 .58147 L
.47515 .58081 L
.47949 .56704 L
s
.47949 .56704 m
.47515 .58081 L
.45126 .57869 L
.45978 .56516 L
s
.45978 .56516 m
.45126 .57869 L
.42925 .57458 L
.44161 .56157 L
s
.44161 .56157 m
.42925 .57458 L
.40995 .56768 L
.42568 .55561 L
s
.42568 .55561 m
.40995 .56768 L
.39411 .55698 L
.41261 .54655 L
s
.41261 .54655 m
.39411 .55698 L
.38234 .54177 L
.40289 .53391 L
s
.40289 .53391 m
.38234 .54177 L
.37509 .52224 L
.39691 .51797 L
s
.39691 .51797 m
.37509 .52224 L
.37265 .5 L
.39489 .5 L
s
.39489 .5 m
.37265 .5 L
.37509 .47776 L
.39691 .48203 L
s
.39691 .48203 m
.37509 .47776 L
.38234 .45823 L
.40289 .46609 L
s
.40289 .46609 m
.38234 .45823 L
.39411 .44302 L
.41261 .45345 L
s
.41261 .45345 m
.39411 .44302 L
.40995 .43232 L
.42568 .44439 L
s
.42568 .44439 m
.40995 .43232 L
.42925 .42542 L
.44161 .43843 L
s
.44161 .43843 m
.42925 .42542 L
.45126 .42131 L
.45978 .43484 L
s
.45978 .43484 m
.45126 .42131 L
.47515 .41919 L
.47949 .43296 L
s
.47949 .43296 m
.47515 .41919 L
.5 .41853 L
.5 .43238 L
s
.5 .43238 m
.5 .41853 L
.52485 .41919 L
.52051 .43296 L
s
.52051 .43296 m
.52485 .41919 L
.54874 .42131 L
.54022 .43484 L
s
.54022 .43484 m
.54874 .42131 L
.57075 .42542 L
.55839 .43843 L
s
.55839 .43843 m
.57075 .42542 L
.59005 .43232 L
.57432 .44439 L
s
.57432 .44439 m
.59005 .43232 L
.60589 .44302 L
.58739 .45345 L
s
.58739 .45345 m
.60589 .44302 L
.61766 .45823 L
.59711 .46609 L
s
.59711 .46609 m
.61766 .45823 L
.62491 .47776 L
.60309 .48203 L
s
.60309 .48203 m
.62491 .47776 L
.62735 .5 L
.60511 .5 L
s
.58328 .5 m
.60511 .5 L
.60309 .51797 L
.58168 .51397 L
s
.58168 .51397 m
.60309 .51797 L
.59711 .53391 L
.57694 .52647 L
s
.57694 .52647 m
.59711 .53391 L
.58739 .54655 L
.56924 .53652 L
s
.56924 .53652 m
.58739 .54655 L
.57432 .55561 L
.55889 .54387 L
s
.55889 .54387 m
.57432 .55561 L
.55839 .56157 L
.54627 .54878 L
s
.54627 .54878 m
.55839 .56157 L
.54022 .56516 L
.53187 .55179 L
s
.53187 .55179 m
.54022 .56516 L
.52051 .56704 L
.51625 .55337 L
s
.51625 .55337 m
.52051 .56704 L
.5 .56762 L
.5 .55386 L
s
.5 .55386 m
.5 .56762 L
.47949 .56704 L
.48375 .55337 L
s
.48375 .55337 m
.47949 .56704 L
.45978 .56516 L
.46813 .55179 L
s
.46813 .55179 m
.45978 .56516 L
.44161 .56157 L
.45373 .54878 L
s
.45373 .54878 m
.44161 .56157 L
.42568 .55561 L
.44111 .54387 L
s
.44111 .54387 m
.42568 .55561 L
.41261 .54655 L
.43076 .53652 L
s
.43076 .53652 m
.41261 .54655 L
.40289 .53391 L
.42306 .52647 L
s
.42306 .52647 m
.40289 .53391 L
.39691 .51797 L
.41832 .51397 L
s
.41832 .51397 m
.39691 .51797 L
.39489 .5 L
.41672 .5 L
s
.41672 .5 m
.39489 .5 L
.39691 .48203 L
.41832 .48603 L
s
.41832 .48603 m
.39691 .48203 L
.40289 .46609 L
.42306 .47353 L
s
.42306 .47353 m
.40289 .46609 L
.41261 .45345 L
.43076 .46348 L
s
.43076 .46348 m
.41261 .45345 L
.42568 .44439 L
.44111 .45613 L
s
.44111 .45613 m
.42568 .44439 L
.44161 .43843 L
.45373 .45122 L
s
.45373 .45122 m
.44161 .43843 L
.45978 .43484 L
.46813 .44821 L
s
.46813 .44821 m
.45978 .43484 L
.47949 .43296 L
.48375 .44663 L
s
.48375 .44663 m
.47949 .43296 L
.5 .43238 L
.5 .44614 L
s
.5 .44614 m
.5 .43238 L
.52051 .43296 L
.51625 .44663 L
s
.51625 .44663 m
.52051 .43296 L
.54022 .43484 L
.53187 .44821 L
s
.53187 .44821 m
.54022 .43484 L
.55839 .43843 L
.54627 .45122 L
s
.54627 .45122 m
.55839 .43843 L
.57432 .44439 L
.55889 .45613 L
s
.55889 .45613 m
.57432 .44439 L
.58739 .45345 L
.56924 .46348 L
s
.56924 .46348 m
.58739 .45345 L
.59711 .46609 L
.57694 .47353 L
s
.57694 .47353 m
.59711 .46609 L
.60309 .48203 L
.58168 .48603 L
s
.58168 .48603 m
.60309 .48203 L
.60511 .5 L
.58328 .5 L
s
.55715 .51939 m
.56186 .5 L
.58328 .5 L
.58168 .51397 L
.57694 .52647 L
s
.54374 .53244 m
.55715 .51939 L
.57694 .52647 L
.56924 .53652 L
.55889 .54387 L
s
.52367 .53857 m
.54374 .53244 L
.55889 .54387 L
.54627 .54878 L
.53187 .55179 L
s
.5 .54021 m
.52367 .53857 L
.53187 .55179 L
.51625 .55337 L
.5 .55386 L
s
.47633 .53857 m
.5 .54021 L
.5 .55386 L
.48375 .55337 L
.46813 .55179 L
s
.45626 .53244 m
.47633 .53857 L
.46813 .55179 L
.45373 .54878 L
.44111 .54387 L
s
.44285 .51939 m
.45626 .53244 L
.44111 .54387 L
.43076 .53652 L
.42306 .52647 L
s
.43814 .5 m
.44285 .51939 L
.42306 .52647 L
.41832 .51397 L
.41672 .5 L
s
.44285 .48061 m
.43814 .5 L
.41672 .5 L
.41832 .48603 L
.42306 .47353 L
s
.45626 .46756 m
.44285 .48061 L
.42306 .47353 L
.43076 .46348 L
.44111 .45613 L
s
.47633 .46143 m
.45626 .46756 L
.44111 .45613 L
.45373 .45122 L
.46813 .44821 L
s
.5 .45979 m
.47633 .46143 L
.46813 .44821 L
.48375 .44663 L
.5 .44614 L
s
.52367 .46143 m
.5 .45979 L
.5 .44614 L
.51625 .44663 L
.53187 .44821 L
s
.54374 .46756 m
.52367 .46143 L
.53187 .44821 L
.54627 .45122 L
.55889 .45613 L
s
.55715 .48061 m
.54374 .46756 L
.55889 .45613 L
.56924 .46348 L
.57694 .47353 L
s
.56186 .5 m
.55715 .48061 L
.57694 .47353 L
.58168 .48603 L
.58328 .5 L
s
.53967 .5 m
.56186 .5 L
.55715 .51939 L
.53665 .51187 L
s
.53665 .51187 m
.55715 .51939 L
.54374 .53244 L
.52805 .52048 L
s
.52805 .52048 m
.54374 .53244 L
.52367 .53857 L
.51518 .52497 L
s
.51518 .52497 m
.52367 .53857 L
.5 .54021 L
.5 .52626 L
s
.5 .52626 m
.5 .54021 L
.47633 .53857 L
.48482 .52497 L
s
.48482 .52497 m
.47633 .53857 L
.45626 .53244 L
.47195 .52048 L
s
.47195 .52048 m
.45626 .53244 L
.44285 .51939 L
.46335 .51187 L
s
.46335 .51187 m
.44285 .51939 L
.43814 .5 L
.46033 .5 L
s
.46033 .5 m
.43814 .5 L
.44285 .48061 L
.46335 .48813 L
s
.46335 .48813 m
.44285 .48061 L
.45626 .46756 L
.47195 .47952 L
s
.47195 .47952 m
.45626 .46756 L
.47633 .46143 L
.48482 .47503 L
s
.48482 .47503 m
.47633 .46143 L
.5 .45979 L
.5 .47374 L
s
.5 .47374 m
.5 .45979 L
.52367 .46143 L
.51518 .47503 L
s
.51518 .47503 m
.52367 .46143 L
.54374 .46756 L
.52805 .47952 L
s
.52805 .47952 m
.54374 .46756 L
.55715 .48061 L
.53665 .48813 L
s
.53665 .48813 m
.55715 .48061 L
.56186 .5 L
.53967 .5 L
s
.51349 .50972 m
.51908 .5 L
.53967 .5 L
.53665 .51187 L
.52805 .52048 L
s
.5 .51281 m
.51349 .50972 L
.52805 .52048 L
.51518 .52497 L
.5 .52626 L
s
.48651 .50972 m
.5 .51281 L
.5 .52626 L
.48482 .52497 L
.47195 .52048 L
s
.48092 .5 m
.48651 .50972 L
.47195 .52048 L
.46335 .51187 L
.46033 .5 L
s
.48651 .49028 m
.48092 .5 L
.46033 .5 L
.46335 .48813 L
.47195 .47952 L
s
.5 .48719 m
.48651 .49028 L
.47195 .47952 L
.48482 .47503 L
.5 .47374 L
s
.51349 .49028 m
.5 .48719 L
.5 .47374 L
.51518 .47503 L
.52805 .47952 L
s
.51908 .5 m
.51349 .49028 L
.52805 .47952 L
.53665 .48813 L
.53967 .5 L
s
.5 .5 m
.5 .5 L
.51908 .5 L
.51349 .50972 L
.5 .51281 L
s
.5 .5 m
.5 .5 L
.5 .51281 L
.48651 .50972 L
.48092 .5 L
s
.5 .5 m
.5 .5 L
.48092 .5 L
.48651 .49028 L
.5 .48719 L
s
.5 .5 m
.5 .5 L
.5 .48719 L
.51349 .49028 L
.51908 .5 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[316]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3j
l>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40
oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`
iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3o
ool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V
803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?oo
o`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP
0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo
003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00
n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool0
0?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803j
l>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00
o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`
iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o
0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V
0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0
n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H1
0?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3j
l>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40
oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`
iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3o
ool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V
803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool007L0n_3V<@00001g0?[`
iP40oooo001^0?[`iPT00000102HniP00`000000V?^H09SkV00709SkV0030000002HniP0V?^H00L0
V?^H00<0000009SkV02HniP01`2HniP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H00<0
V?^H2@00001^0?[`iP40oooo001U0?[`iPT00000102HniP00`000000V?^H09SkV00709SkV0030000
002HniP0V?^H00H0V?^H00<0000009SkV02HniP01`2HniP00`000000V?^H09SkV00609SkV0030000
002HniP0V?^H00L0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00309SkV0T00000
I@3jl>H10?ooo`00G03jl>H9000000@0V?^H00<0000009SkV02HniP01`2HniP00`000000V?^H09Sk
V00609SkV0030000002HniP0V?^H00L0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09Sk
V00609SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP01`2HniP00`000000V?^H09Sk
V00609SkV0030000002HniP0V?^H00<0V?^H2@00001L0?[`iP40oooo001F0?[`iPH000001@2HniP0
0`000000V?^H09SkV00609SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP00`2HniP]
000000@0V?^H00<0000009SkV02HniP01`2HniP00`000000V?^H09SkV00609SkV0030000002HniP0
V?^H00<0V?^H1P00001F0?[`iP40oooo001B0?[`iP@000000P2HniP00`000000V?^H09SkV00609Sk
V0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP00`2HniP9000000@0V?^H00<0000009Sk
V02HniP01P2HniP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H00H0V?^H00<0000009Sk
V02HniP01P2HniP00`000000V?^H09SkV00209SkV0T00000102HniP00`000000V?^H09SkV00609Sk
V0030000002HniP0V?^H00L0V?^H00<0000009SkV02HniP01000001B0?[`iP40oooo001>0?[`iP@0
00001`2HniP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H00<0V?^H2000000409SkV003
0000002HniP0V?^H00H0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00609SkV003
0000002HniP0V?^H00H0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00609SkV003
0000002HniP0V?^H00<0V?^H2000000509SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02H
niP01@2HniP4000004h0n_3V0@3oool004`0n_3V0P00000209SkV0030000002HniP0V?^H00L0V?^H
00<0000009SkV02HniP00`2HniP8000000@0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H
09SkV00609SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H
09SkV00609SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H
09SkV00609SkV0030000002HniP0V?^H0080V?^H2000000509SkV0030000002HniP0V?^H00L0V?^H
00<0000009SkV02HniP00P00001<0?[`iP40oooo001:0?[`iP8000001@2HniP00`000000V?^H09Sk
V00609SkV0H00000102HniP00`000000V?^H09SkV00509SkV0030000002HniP0V?^H00H0V?^H00<0
000009SkV02HniP00`2HniPY000000@0V?^H00<0000009SkV02HniP01`2HniP00`000000V?^H09Sk
V00509SkV0030000002HniP0V?^H0080V?^H1P00000809SkV0030000002HniP0V?^H00<0V?^H0P00
001:0?[`iP40oooo00170?[`iP<00000202HniP010000000V?^H09SkV02HniP400000080V?^H00<0
000009SkV02HniP01P2HniP00`000000V?^H09SkV00209SkV14000000`2HniP00`000000V?^H09Sk
V00509SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09Sk
V00509SkV0040000002HniP0V?^H09SkV1400000102HniP00`000000V?^H09SkV00609SkV0030000
002HniP0V?^H00@000000`2HniP00`000000V?^H09SkV00609SkV0<00000A`3jl>H10?ooo`00A@3j
l>H200000080V?^H00<0000009SkV02HniP01P2HniP4000000H0V?^H00<0000009SkV02HniP01P2H
niP5000000@0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00509SkV0030000002H
niP0V?^H00D0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00509SkV0030000002H
niP0V?^H00D0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00509SkV0030000002H
niP0V?^H0080V?^H1@00000709SkV0030000002HniP0V?^H00D0V?^H1000000809SkV0030000002H
niP0V?^H00800000A@3jl>H10?ooo`00@`3jl>H2000000D0V?^H0P00000209SkV0@000000P2HniP0
0`000000V?^H09SkV00609SkV0040000002HniP0V?^H09SkV0@000000P2HniP00`000000V?^H09Sk
V00409SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09Sk
V00509SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09Sk
V00509SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09Sk
V00509SkV0030000002HniP0V?^H00@000000`2HniP00`000000V?^H09SkV00609SkV0030000002H
niP0V?^H00@000000P2HniP2000000D0V?^H0P0000130?[`iP40oooo00110?[`iP8000002@2HniP2
000000L0V?^H00<0000009SkV02HniP01@2HniP4000000H0V?^H00<0000009SkV02HniP01@2HniP0
0`000000V?^H09SkV00509SkV0030000002HniP0V?^H0080V?^H9`00000409SkV0030000002HniP0
V?^H00D0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00509SkV0@000001`2HniP0
0`000000V?^H09SkV00509SkV08000002@2HniP200000440n_3V0@3oool003l0n_3V0P0000000`2H
niP000000000000609SkV080000000<0V?^H0000002HniP01`2HniP00`000000V?^H09SkV0040000
0080V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00209SkV0l000000`2HniP00`00
0000V?^H09SkV00509SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP01@2HniP00`00
0000V?^H09SkV00509SkV0040000002HniP0V?^H09SkV0l00000102HniP00`000000V?^H09SkV006
09SkV0030000002HniP0V?^H00@000000P2HniP00`000000V?^H09SkV00609SkV0040000002HniP0
0000000000H0V?^H0P0000000`2HniP000000000000o0?[`iP40oooo000n0?[`iP030000002HniP0
V?^H00<0V?^H0P00000209SkV0800000102HniP2000000H0V?^H0`00000709SkV0030000002HniP0
V?^H00D0V?^H1@00000309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP01@2HniP0
0`000000V?^H09SkV00509SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP0102HniP0
0`000000V?^H09SkV00509SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP0102HniP0
0`000000V?^H09SkV00209SkV0D000001`2HniP00`000000V?^H09SkV00509SkV0<000001P2HniP2
000000@0V?^H0P00000209SkV08000001@2HniP00`000000n_3V0?[`iP0l0?[`iP40oooo000l0?[`
iP800000202HniP2000000P0V?^H00<0000009SkV02HniP00`00000209SkV08000001`2HniP00`00
0000V?^H09SkV00400000080V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409Sk
V0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00409Sk
V0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00509Sk
V0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV0040000
0080V?^H00<0000009SkV02HniP01@2HniP200000080V?^H0`00000209SkV0030000002HniP0V?^H
00H0V?^H0P00000809SkV0800000?03jl>H10?ooo`00>`3jl>H00`000000V?^H09SkV00709SkV003
0000002HniP0000000T0V?^H0P00000709SkV0800000102HniP4000000H0V?^H00<0000009SkV02H
niP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H0080V?^H9@00000309SkV003
0000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00509SkV0@0
0000102HniP2000000L0V?^H0P00000909SkV0030000002HniP0000000T0V?^H00<000000?[`iP3j
l>H0>@3jl>H10?ooo`00>P3jl>H010000000V?^H00000000000509SkV08000000`2HniP2000000D0
V?^H0P0000000`2HniP000000000000709SkV0D000000`2HniP00`000000V?^H09SkV00509SkV003
0000002HniP0V?^H0080V?^H3@00000309SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02H
niP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02H
niP00P2HniP=000000@0V?^H00<0000009SkV02HniP01@2HniP010000000V?^H09SkV02HniP50000
00L0V?^H0P0000000`2HniP000000000000509SkV08000000`2HniP2000000D0V?^H0P0000000`2H
niP000000?[`iP0i0?[`iP40oooo000i0?[`iP030000002HniP0V?^H0080V?^H0P00000209SkV003
0000002HniP0V?^H00D0V?^H00<0000009SkV02HniP00P00000509SkV08000000P2HniP300000080
V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00209SkV0L000000`2HniP00`000000
V?^H09SkV00309SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP0102HniP00`000000
V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`000000
V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H00@0000009SkV02HniP0V?^H1`00000409Sk
V0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`00000209SkV08000001@2HniP20000
0080V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV002000000@0V?^H00<000000?[`
iP3jl>H0=`3jl>H10?ooo`00>03jl>H00`000000V?^H09SkV00509SkV08000002@2HniP2000000T0
V?^H0P00000609SkV0030000002HniP0V?^H00<0V?^H1@00000409SkV0030000002HniP0V?^H00<0
V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00@0
V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0
V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0
V?^H00<0000009SkV02HniP00P2HniP5000000D0V?^H00<0000009SkV02HniP0102HniP2000000T0
V?^H0P00000909SkV08000001P2HniP00`000000n_3V0?[`iP0g0?[`iP40oooo000h0?[`iP030000
002HniP0V?^H00D0V?^H00<0000009SkV00000001`2HniP010000000V?^H00000000000609SkV080
000000<0V?^H0000002HniP01P2HniP00`000000V?^H09SkV00200000080V?^H00<0000009SkV02H
niP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02H
niP00P2HniPQ000000<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV003
0000002HniP0V?^H00D0V?^H00<0000009SkV02HniP00P00000209SkV0030000002HniP0V?^H00D0
V?^H00@0000009SkV000000000001P2HniP20000000309SkV0000000V?^H00H0V?^H00<0000009Sk
V00000001`2HniP00`000000n_3V0?[`iP0f0?[`iP40oooo000g0?[`iP030000002HniP0V?^H00D0
V?^H00@0000009SkV02HniP0V?^H0P00000309SkV0800000102HniP200000080V?^H0P00000409Sk
V0030000002HniP0V?^H00@0V?^H0`00000509SkV0030000002HniP0V?^H00@0V?^H00<0000009Sk
V02HniP00P2HniP<000000<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00409Sk
V0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP010000000V?^H09SkV02HniP<
000000@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0<000001P2HniP0
0`000000V?^H09SkV00209SkV08000000P2HniP2000000@0V?^H0P00000309SkV08000000`2HniP0
0`000000V?^H09SkV00509SkV0030000003jl>H0n_3V03D0n_3V0@3oool003H0n_3V0P00000609Sk
V0030000002HniP0V?^H00@0V?^H00<0000009SkV0000000202HniP2000000L0V?^H00<0000009Sk
V02HniP00`00000209SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00P2HniP60000
0080V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H
00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H
00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0040000002HniP0V?^H
09SkV0H00000102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<000000P2HniP0
0`000000V?^H09SkV00509SkV0800000202HniP00`000000V?^H0000000609SkV0030000002HniP0
V?^H00@0V?^H0P00000f0?[`iP40oooo000e0?[`iP030000002HniP0V?^H00<000000P2HniP00`00
0000V?^H09SkV00609SkV0030000002HniP0V?^H00H0V?^H00@0000009SkV000000000001P2HniP3
000000H0V?^H0P00000309SkV0H000000`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0
V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV0040000002HniP0
V?^H09SkV0H000000`2HniP2000000H0V?^H0`00000609SkV080000000<0V?^H0000002HniP01`2H
niP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H00<000000P2HniP00`000000n_3V0?[`
iP0c0?[`iP40oooo000e0?[`iP030000002HniP0V?^H00<0V?^H0P00000809SkV0040000002HniP0
0000000000D0V?^H00<0000009SkV02HniP00P2HniP200000080V?^H0P00000209SkV08000001P2H
niP4000000<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV0030000002H
niP0V?^H0080V?^H:@00000309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102H
niP010000000V?^H09SkV02HniP4000000H0V?^H0P00000209SkV08000000P2HniP2000000@0V?^H
00<0000009SkV02HniP00`2HniP20000000309SkV0000000V?^H00L0V?^H0P00000509SkV0030000
003jl>H0n_3V03<0n_3V0@3oool003@0n_3V00<0000009SkV02HniP0102HniP010000000V?^H0000
0000000509SkV0030000002HniP0V?^H0080V?^H0P00000209SkV0030000002HniP0V?^H00D0V?^H
0P00000609SkV08000000P2HniP200000080V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00309SkV0040000002HniP0V?^H09SkV0H000000P2HniP00`000000V?^H09SkV00309SkV003
0000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV003
0000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00P2HniP010000000V?^H09SkV02HniP60000
00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H
008000000P2HniP2000000H0V?^H0P00000709SkV0030000002HniP0V?^H00800000102HniP00`00
0000V?^H09SkV00309SkV080000000<0V?^H0000002HniP01@2HniP00`000000n_3V0?[`iP0b0?[`
iP40oooo000c0?[`iP030000002HniP0V?^H00D0V?^H00@0000009SkV02HniP0V?^H0P00000209Sk
V0030000002HniP0V?^H00D0V?^H0P00000709SkV0030000002HniP0000000P0V?^H0P00000509Sk
V0030000002HniP0V?^H00<0V?^H00@0000009SkV02HniP0V?^H1@00000309SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV00309SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV00309SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP00`2HniP010000000V?^H09SkV02HniP5000000<0V?^H00<0
000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV0800000202HniP00`000000V?^H0000
000709SkV08000001`2HniP00`000000V?^H09SkV002000000<0V?^H00<0000009SkV02HniP01@2H
niP00`000000n_3V0?[`iP0a0?[`iP40oooo000c0?[`iP030000002HniP0V?^H00@0V?^H00<00000
09SkV02HniP0102HniP2000000P0V?^H00@0000009SkV00000000000102HniP010000000V?^H09Sk
V02HniP2000000@0V?^H0P0000000`2HniP0000009SkV00509SkV0040000002HniP0V?^H09SkV0D0
00000`2HniP00`000000V?^H09SkV00209SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02H
niP00`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H0080V?^H00<0000009SkV02H
niP00P2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H0080V?^H00<0000009SkV02H
niP00`2HniP00`000000V?^H09SkV00309SkV0040000002HniP0V?^H09SkV0D000000`2HniP00`00
0000V?^H09SkV00409SkV0040000002HniP00000000000@0V?^H0P00000309SkV0030000002HniP0
V?^H0080V?^H0P0000000`2HniP0000009SkV00709SkV08000001P2HniP00`000000V?^H09SkV004
09SkV0030000003jl>H0n_3V0340n_3V0@3oool00380n_3V0P00000509SkV0030000002HniP0V?^H
00D0V?^H00@0000009SkV00000000000102HniP2000000@0V?^H0P0000000`2HniP0000009SkV005
09SkV0040000002HniP00000000000@0V?^H00<0000009SkV02HniP00`2HniP4000000<0V?^H00<0
000009SkV02HniP00P2HniP00`000000V?^H09SkV00309SkV0040000002HniP0V?^H09SkV2D00000
0`2HniP00`000000V?^H09SkV00209SkV0030000002HniP0V?^H00<0V?^H00@0000009SkV02HniP0
V?^H1000000509SkV0030000002HniP0V?^H0080V?^H0P0000000`2HniP0000009SkV00509SkV004
0000002HniP00000000000@0V?^H0P00000409SkV080000000<0V?^H0000002HniP01P2HniP00`00
0000V?^H09SkV00309SkV0800000<P3jl>H10?ooo`00<P3jl>H00`000000V?^H0000000200000080
V?^H00<0000009SkV02HniP01@2HniP010000000V?^H09SkV02HniP20000000309SkV0000000V?^H
00L0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00509SkV0030000002HniP0V?^H
008000000P2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H0080V?^H00@0000009Sk
V02HniP0V?^H1@00000209SkV0030000002HniP0V?^H0080V?^H00<0000009SkV02HniP00`2HniP0
0`000000V?^H09SkV00209SkV0030000002HniP0V?^H0080V?^H00<0000009SkV02HniP00`2HniP0
1@000000V?^H09SkV02HniP0000000<0V?^H1@00000309SkV0030000002HniP0V?^H0080V?^H00<0
000009SkV02HniP00`2HniP00`000000V?^H09SkV00200000080V?^H00<0000009SkV02HniP01@2H
niP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H00H0V?^H00@0000009SkV00000000000
0`2HniP00`000000V?^H09SkV00509SkV0030000002HniP0V?^H00<0000000<0V?^H0000003jl>H0
<@3jl>H10?ooo`00<@3jl>H00`000000V?^H09SkV00309SkV08000001`2HniP00`000000V?^H09Sk
V00409SkV0030000002HniP0V?^H00H0V?^H00@0000009SkV000000000001@2HniP010000000V?^H
00000000000609SkV08000001@2HniP00`000000V?^H09SkV00309SkV0P000000P2HniP00`000000
V?^H09SkV00309SkV0050000002HniP0V?^H09SkV00000001@2HniP00`000000V?^H09SkV00209Sk
V0030000002HniP0V?^H0080V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV00209Sk
V0030000002HniP0V?^H0080V?^H00@0000009SkV02HniP0V?^H2000000509SkV0030000002HniP0
V?^H00<0V?^H0P00000609SkV080000000<0V?^H0000002HniP0102HniP20000000309SkV0000000
V?^H00L0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00509SkV08000001@2HniP0
0`000000n_3V0?[`iP0_0?[`iP40oooo000a0?[`iP030000002HniP0V?^H00@0V?^H0`00000409Sk
V0030000002HniP0V?^H00@0V?^H00@0000009SkV000000000001@2HniP00`000000V?^H09SkV002
09SkV080000000<0V?^H000000000000102HniP200000080V?^H0P0000000`2HniP0000000000005
09SkV0030000002HniP0V?^H0080000000<0V?^H0000002HniP00`2HniP00`000000V?^H09SkV002
09SkV0030000002HniP0V?^H0080V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV002
09SkV0030000002HniP0V?^H0080V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV002
09SkV0050000002HniP0V?^H09SkV00000001@2HniP00`000000V?^H09SkV00209SkV0030000002H
niP0V?^H0080V?^H00@0000009SkV000000000000P2HniP00`000000V?^H09SkV00309SkV0800000
00<0V?^H0000000000000P2HniP2000000@0V?^H0P0000000`2HniP000000000000409SkV0030000
002HniP0V?^H00<0V?^H0P0000000`2HniP0000009SkV00509SkV0030000002HniP0V?^H0080V?^H
0`00000609SkV0030000003jl>H0n_3V02l0n_3V0@3oool00300n_3V00<0000009SkV02HniP0102H
niP010000000V?^H09SkV02HniP200000080V?^H00<0000009SkV02HniP0102HniP010000000V?^H
09SkV02HniP200000080V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00609SkV080
00001@2HniP2000000<0V?^H0`00000409SkV0030000002HniP0V?^H0080V?^H00D0000009SkV02H
niP0V?^H0000000309SkV24000000P2HniP00`000000V?^H09SkV00209SkV0030000002HniP0V?^H
0080V?^H00<0000009SkV02HniP00P2HniP3000000<0V?^H0P00000509SkV0800000202HniP00`00
0000V?^H09SkV00509SkV0030000002HniP0V?^H008000000`2HniP00`000000V?^H09SkV00409Sk
V0030000002HniP0V?^H008000000`2HniP00`000000V?^H09SkV00409SkV0030000003jl>H0n_3V
02h0n_3V0@3oool00300n_3V00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0<0
00001@2HniP00`000000V?^H09SkV00409SkV0<000001P2HniP010000000V?^H00000000000509Sk
V0040000002HniP00000000000H0V?^H0`00000209SkV0030000002HniP0V?^H00<0V?^H00@00000
09SkV02HniP0V?^H2000000609SkV0030000002HniP0V?^H00L0V?^H00<0000009SkV02HniP01P2H
niP00`000000V?^H09SkV00509SkV0P000000`2HniP00`000000V?^H09SkV00309SkV0030000002H
niP0V?^H00<000001P2HniP20000000309SkV0000000V?^H00@0V?^H0P0000000`2HniP0000009Sk
V00509SkV0<000001P2HniP00`000000V?^H09SkV00309SkV0<000001@2HniP00`000000V?^H09Sk
V00409SkV0030000003jl>H0n_3V02h0n_3V0@3oool002l0n_3V00<0000009SkV02HniP0102HniP0
0`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<000000P2HniP00`000000V?^H09SkV004
09SkV0030000002HniP0V?^H00<000000P2HniP00`000000V?^H09SkV00209SkV080000000<0V?^H
000000000000102HniP200000080V?^H0P0000000`2HniP0000009SkV00309SkV08000000`2HniP4
000000H0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00609SkV0030000002HniP0
V?^H00H0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00409SkV0@000000`2HniP2
000000@0V?^H00@0000009SkV000000000000P2HniP2000000@0V?^H0P0000000`2HniP000000000
000409SkV0030000002HniP0V?^H00<000000P2HniP00`000000V?^H09SkV00409SkV0030000002H
niP0V?^H00<0000000<0V?^H0000002HniP01P2HniP00`000000V?^H09SkV00409SkV0030000003j
l>H0n_3V02d0n_3V0@3oool002l0n_3V0P00000509SkV0030000002HniP0V?^H00@0V?^H00<00000
09SkV02HniP00`2HniP3000000D0V?^H00<0000009SkV02HniP0102HniP2000000L0V?^H00<00000
09SkV02HniP01P2HniP2000000@0V?^H00<0000009SkV02HniP00`2HniP300000080V?^H00<00000
09SkV02HniP01P2HniP00`000000V?^H09SkV00509SkV0030000002HniP0V?^H00H0V?^H00<00000
09SkV02HniP01@2HniP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H00H0V?^H00<00000
09SkV02HniP00`00000509SkV0030000002HniP0V?^H0080V?^H0P00000809SkV0030000002HniP0
V?^H00D0V?^H0P00000509SkV0030000002HniP0V?^H00@0V?^H0`00000509SkV0030000002HniP0
V?^H00@0V?^H00<0000009SkV02HniP00`2HniP2000002l0n_3V0@3oool002l0n_3V00<0000009Sk
V00000000P0000000`2HniP0000009SkV00509SkV0030000002HniP0V?^H00@0V?^H00<0000009Sk
V02HniP00`00000209SkV0030000002HniP0V?^H00@0V?^H00@0000009SkV00000000000102HniP0
10000000V?^H00000000000509SkV0040000002HniP00000000000@0V?^H00<0000009SkV02HniP0
0P00000509SkV0030000002HniP0V?^H00H0V?^H8`00000709SkV0030000002HniP0V?^H00@0V?^H
0P00000209SkV0030000002HniP0V?^H0080V?^H0P0000000`2HniP0000009SkV00409SkV0800000
00<0V?^H0000002HniP00`2HniP20000000309SkV0000000V?^H00D0V?^H00<0000009SkV02HniP0
0`0000000`2HniP0000009SkV00509SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV0000000
0P0000000`2HniP000000?[`iP0^0?[`iP40oooo000^0?[`iP030000002HniP0V?^H00<0V?^H0`00
000509SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP2000000L0V?^H00@0
000009SkV02HniP0V?^H0P0000000`2HniP0000009SkV00309SkV08000000P2HniP00`000000V?^H
09SkV00209SkV08000000P2HniP3000000P0V?^H00@0000009SkV02HniP0V?^H100000000`2HniP0
000009SkV00609SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP01@2HniP00`000000
V?^H09SkV00409SkV0030000002HniP0V?^H00@000000`2HniP00`000000V?^H09SkV00609SkV0<0
00000P2HniP2000000@0V?^H00<0000009SkV02HniP00P00000409SkV0040000002HniP000000000
00<0V?^H00<0000009SkV02HniP01@2HniP2000000D0V?^H00<0000009SkV02HniP0102HniP00`00
0000V?^H09SkV00309SkV0<000001@2HniP00`000000n_3V0?[`iP0/0?[`iP40oooo000^0?[`iP03
0000002HniP0V?^H00@0V?^H00<0000009SkV00000000P0000000`2HniP0000009SkV00509SkV003
0000002HniP0V?^H00D0V?^H0`00000409SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02H
niP01@2HniP2000000L0V?^H0P00000209SkV08000001`2HniP4000000H0V?^H00<0000009SkV02H
niP0102HniP00`000000V?^H09SkV00509SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02H
niP01@2HniP00`000000V?^H09SkV00409SkV0@000001`2HniP200000080V?^H0P00000709SkV080
00001`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H0080V?^H0`00000609SkV003
0000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`0000000`2HniP0000009SkV00509SkV003
0000003jl>H0n_3V02`0n_3V0@3oool002h0n_3V00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00309SkV0<000001@2HniP00`000000V?^H09SkV00409SkV0040000002HniP0V?^H09SkV080
00000P2HniP00`000000V?^H09SkV00309SkV0040000002HniP00000000000D0V?^H00@0000009Sk
V00000000000102HniP00`000000V?^H09SkV00409SkV08000000P2HniP300000080V?^H00<00000
09SkV02HniP01@2HniP00`000000V?^H09SkV00509SkV0030000002HniP0V?^H00@0V?^H00<00000
09SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00H0V?^H00<00000
09SkV02HniP00`00000209SkV08000001P2HniP00`000000V?^H09SkV00209SkV080000000<0V?^H
0000002HniP0102HniP3000000H0V?^H00<0000009SkV02HniP00P00000309SkV0030000002HniP0
V?^H00@0V?^H00<0000009SkV02HniP00`2HniP3000000@0V?^H00<0000009SkV02HniP0102HniP0
0`000000n_3V0?[`iP0/0?[`iP40oooo000]0?[`iP030000002HniP0V?^H00@0V?^H00<0000009Sk
V02HniP0102HniP00`000000V?^H000000020000000309SkV0000000V?^H00H0V?^H00<0000009Sk
V02HniP00`2HniP3000000D0V?^H00@0000009SkV02HniP0V?^H0P00000209SkV0030000002HniP0
V?^H0080V?^H0P0000000`2HniP0000009SkV00809SkV08000001P2HniP00`000000V?^H09SkV004
09SkV1l000001P2HniP00`000000V?^H09SkV00409SkV08000002@2HniP010000000V?^H00000000
000409SkV0030000002HniP0V?^H008000000`2HniP00`000000V?^H09SkV00309SkV0<000001@2H
niP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0000000<0V?^H0000002HniP01@2H
niP00`000000V?^H09SkV00409SkV0030000003jl>H0n_3V02/0n_3V0@3oool002d0n_3V00<00000
09SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H0`000006
09SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV00000000P0000000`2HniP0000009SkV005
09SkV0<000001P2HniP00`000000V?^H09SkV00609SkV080000000<0V?^H0000002HniP01P2HniP0
0`000000V?^H09SkV0030000000309SkV0000000V?^H00D0V?^H00<0000009SkV02HniP0102HniP0
0`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`000002
09SkV0030000002HniP0V?^H00D0V?^H00@0000009SkV00000000000202HniP00`000000V?^H09Sk
V00409SkV0<000001@2HniP00`000000V?^H09SkV0030000000309SkV0000000V?^H00D0V?^H00<0
000009SkV02HniP0102HniP3000000@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09Sk
V00409SkV0030000003jl>H0n_3V02/0n_3V0@3oool002d0n_3V00<0000009SkV02HniP0102HniP0
0`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV00000000`000000
0`2HniP0000009SkV00509SkV0030000002HniP0V?^H00<0V?^H0`00000509SkV0030000002HniP0
V?^H00<000000P2HniP010000000V?^H00000000000509SkV0030000002HniP0V?^H0080V?^H00<0
000009SkV02HniP0102HniP3000000D0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09Sk
V00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09Sk
V00309SkV0<000001P2HniP00`000000V?^H09SkV00209SkV0030000002HniP0V?^H00<0V?^H0P00
00000`2HniP000000000000209SkV08000000P2HniP00`000000V?^H09SkV00309SkV0<000001@2H
niP00`000000V?^H09SkV00409SkV0030000002HniP0000000<0000000<0V?^H0000002HniP01@2H
niP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<000000?[`iP3jl>H0:`3j
l>H10?ooo`00;03jl>H00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H00<00000
09SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0<000001@2HniP00`000000V?^H09SkV004
09SkV0030000002HniP00000008000000P2HniP00`000000V?^H09SkV00309SkV0800000102HniP2
0000000309SkV0000000000000H0V?^H00<0000009SkV02HniP00`00000209SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0
V?^H00<000000P2HniP00`000000V?^H09SkV00409SkV080000000<0V?^H0000000000001@2HniP2
000000@0V?^H00<0000009SkV02HniP00`0000000`2HniP0000009SkV00509SkV0030000002HniP0
V?^H00<0V?^H0`00000609SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP0
0`000000V?^H09SkV00509SkV0030000003jl>H0n_3V02X0n_3V0@3oool002`0n_3V1000000309Sk
V0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00509Sk
V0030000002HniP000000080000000<0V?^H0000002HniP01@2HniP00`000000V?^H09SkV00309Sk
V0<000001@2HniP00`000000V?^H09SkV00509SkV0030000002HniP0V?^H00L0V?^H0P00000609Sk
V0040000002HniP0V?^H09SkV1d000000`2HniP00`000000V?^H09SkV00409SkV08000002@2HniP0
0`000000V?^H09SkV00609SkV0030000002HniP0V?^H0080V?^H0`00000509SkV0030000002HniP0
V?^H00@0V?^H00<0000009SkV00000000P0000000`2HniP0000009SkV00609SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP0102HniP010000000V?^H09SkV02HniP4000002`0n_3V0@3o
ool002`0n_3V00@0000009SkV02HniP0V?^H1@00000409SkV0030000002HniP0V?^H00@0V?^H00<0
000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0<000001@2HniP00`000000V?^H09Sk
V00309SkV0030000002HniP0V?^H008000000P2HniP00`000000V?^H09SkV00509SkV0040000002H
niP00000000000H0V?^H00@0000009SkV000000000001P2HniP3000000<0V?^H00<0000009SkV02H
niP00P2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02H
niP00P2HniP010000000V?^H09SkV02HniP3000000H0V?^H0P0000000`2HniP0000009SkV00509Sk
V080000000<0V?^H0000002HniP01P2HniP00`000000V?^H09SkV0020000000309SkV0000000V?^H
00D0V?^H00<0000009SkV02HniP00`2HniP3000000D0V?^H00<0000009SkV02HniP0102HniP00`00
0000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H1@00000309SkV0030000003jl>H0n_3V
02X0n_3V0@3oool002`0n_3V00<0000009SkV02HniP0102HniP00`000000V?^H0000000200000003
09SkV0000000V?^H00D0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV003
0000002HniP000000080000000<0V?^H0000002HniP01@2HniP00`000000V?^H09SkV00209SkV080
00001`2HniP00`000000V?^H09SkV00209SkV08000000P2HniP2000000@0V?^H0P00000209SkV080
000000<0V?^H0000002HniP00`2HniP00`000000V?^H09SkV00209SkV0030000002HniP0V?^H00<0
V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV00209SkV0030000002HniP0V?^H00<0
V?^H00@0000009SkV000000000000P2HniP2000000@0V?^H0P00000209SkV0800000102HniP00`00
0000V?^H09SkV00509SkV0800000102HniP00`000000V?^H09SkV00409SkV0030000002HniP00000
0080000000<0V?^H0000002HniP01@2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H
00@0V?^H00<0000009SkV00000000P0000000`2HniP0000009SkV00509SkV0030000003jl>H0n_3V
02X0n_3V0@3oool002`0n_3V00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00209SkV0@0
00000`2HniP00`000000V?^H09SkV00509SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02H
niP00`2HniP4000000<0V?^H00<0000009SkV02HniP0102HniP3000000D0V?^H00<0000009SkV02H
niP0102HniP2000000P0V?^H0P00000409SkV0030000002HniP0V?^H0080V?^H00<0000009SkV02H
niP00P2HniP00`000000V?^H09SkV00209SkV0030000002HniP0V?^H0080V?^H00<0000009SkV02H
niP00P2HniP00`000000V?^H09SkV00209SkV0030000002HniP0V?^H0080V?^H0P00000809SkV080
00001P2HniP00`000000V?^H09SkV00309SkV0<000001@2HniP00`000000V?^H09SkV00209SkV0@0
00001@2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00D0V?^H00@0000009SkV02H
niP0V?^H1000000409SkV0030000002HniP0V?^H00@0V?^H00<000000?[`iP3jl>H0:P3jl>H10?oo
o`00;03jl>H00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02H
niP01`00000309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`000000
V?^H09SkV005000000@0V?^H00@0000009SkV02HniP0V?^H0P00000209SkV0030000002HniP0V?^H
00D0V?^H00@0000009SkV000000000001@2HniP00`000000V?^H0000000509SkV0040000002HniP0
V?^H09SkV1D000000`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0000000D0V?^H0P00
00000`2HniP0000009SkV00609SkV0030000002HniP0V?^H008000000P2HniP00`000000V?^H09Sk
V00309SkV0D000000P2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H00@0
000009SkV02HniP0V?^H1`00000209SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0
0`2HniP00`000000n_3V0?[`iP0Z0?[`iP40oooo000[0?[`iP030000002HniP0V?^H00@0V?^H00<0
000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0040000002HniP0V?^H09SkV0H00000
0`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV0000000
0P0000000`2HniP0000009SkV00409SkV0<000001P2HniP00`000000V?^H09SkV00209SkV0800000
00<0V?^H0000000000000`2HniP2000000<0V?^H100000000`2HniP0000009SkV00709SkV0030000
002HniP0V?^H00D0V?^H00<0000009SkV02HniP01000000309SkV08000000`2HniP20000000309Sk
V0000000000000@0V?^H00<0000009SkV02HniP0102HniP3000000D0V?^H00<0000009SkV0000000
0P0000000`2HniP0000009SkV00509SkV0030000002HniP0V?^H00@0V?^H00@0000009SkV02HniP0
V?^H1P00000309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000
V?^H09SkV00409SkV0030000003jl>H0n_3V02T0n_3V0@3oool002/0n_3V00<0000009SkV02HniP0
102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0
102HniP00`000000V?^H09SkV005000000D0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00309SkV08000001P2HniP00`000000V?^H0000000200000080V?^H00<0000009SkV02HniP0
1@2HniP00`000000V?^H09SkV00509SkV0<000001P2HniP00`000000V?^H09SkV00509SkV0030000
002HniP0V?^H00D0V?^H00<0000009SkV02HniP0102HniP3000000L0V?^H00<0000009SkV02HniP0
1@2HniP00`000000V?^H09SkV0030000000309SkV0000000V?^H00D0V?^H0P00000509SkV0030000
002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP500000080V?^H00<0000009SkV02HniP0
102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0
102HniP00`000000n_3V0?[`iP0Y0?[`iP40oooo000[0?[`iP030000002HniP0V?^H00@0V?^H00<0
000009SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H00<0
000009SkV02HniP00`2HniP00`000000V?^H000000020000000309SkV0000000V?^H00D0V?^H00<0
000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H0`00
000609SkV0040000002HniP00000000000@0V?^H00<0000009SkV00000001`2HniP00`000000V?^H
09SkV00209SkV0L000000`2HniP00`000000V?^H09SkV00609SkV0030000002HniP0000000@0V?^H
0P0000000`2HniP0000009SkV00509SkV0<000001@2HniP00`000000V?^H09SkV00309SkV0030000
002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H000000020000000309Sk
V0000000V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000
002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`000000n_3V0?[`iP0Y0?[`iP40oooo
000[0?[`iP030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09Sk
V00309SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09Sk
V00209SkV0@000000`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H00<0
000009SkV02HniP0102HniP00`000000V?^H0000000200000080V?^H00<0000009SkV02HniP00P2H
niP20000000309SkV0000000V?^H0080V?^H00<0000009SkV02HniP0102HniP5000000<0V?^H00@0
000009SkV02HniP0V?^H1@00000609SkV0060000002HniP0V?^H09SkV0000000V?^H0P00000409Sk
V0030000002HniP0V?^H00<0000000<0V?^H0000002HniP01@2HniP00`000000V?^H09SkV00309Sk
V0030000002HniP0V?^H00D0V?^H00@0000009SkV02HniP0V?^H1000000409SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00309SkV0030000002HniP0
V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000n_3V0?[`iP0Y0?[`iP40oooo000[0?[`
iP<000000`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009Sk
V02HniP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009Sk
V02HniP01`00000309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00309SkV0<000001P2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H
00<000000P2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009Sk
V02HniP00`00000209SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP30000
00D0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0040000002HniP0V?^H
09SkV0L000000P2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<00000
09SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00@00000
09SkV02HniP0V?^H0`00000[0?[`iP40oooo000[0?[`iP030000002HniP0V?^H00L000000`2HniP0
0`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP0
0`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00@0000009SkV02HniP0V?^H1P00
000309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H0000
000200000080V?^H00<0000009SkV02HniP01@2HniP2000000D0V?^H00<0000009SkV02HniP00`2H
niP00`000000V?^H09SkV00209SkV0030000002HniP0V?^H00@0V?^H0P00000709SkV0030000002H
niP0V?^H00<0000000<0V?^H0000002HniP01@2HniP00`000000V?^H09SkV00409SkV0040000002H
niP0V?^H09SkV0H000000`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H
00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H
00@0000009SkV02HniP0V?^H1`00000209SkV0030000003jl>H0n_3V02T0n_3V0@3oool002/0n_3V
00<0000009SkV02HniP00`2HniP010000000V?^H09SkV02HniP=000000<0V?^H00<0000009SkV02H
niP00`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02H
niP0102HniP00`000000V?^H09SkV005000000D0V?^H00<0000009SkV02HniP00`2HniP00`000000
V?^H09SkV00309SkV0<000001P2HniP010000000V?^H00000000000509SkV0040000002HniP0V?^H
09SkV0<000000`2HniP00`000000V?^H09SkV00309SkV080000000<0V?^H0000002HniP01@2HniP3
000000D0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV0D000000P2HniP0
0`000000V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP0
0`000000V?^H09SkV00309SkV0040000002HniP0V?^H09SkV0d000000`2HniP00`000000V?^H09Sk
V00309SkV0030000003jl>H0n_3V02T0n_3V0@3oool002/0n_3V00<0000009SkV02HniP00`2HniP0
0`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00@0000009SkV02HniP0V?^H1P00
000309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09Sk
V00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV00000000P0000000`2HniP0000009Sk
V00509SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV00000000P00000209SkV0030000002H
niP0V?^H0080V?^H0P00000309SkV0@0000000<0V?^H0000002HniP01000000309SkV0800000102H
niP00`000000V?^H09SkV0030000000309SkV0000000V?^H00D0V?^H00<0000009SkV02HniP0102H
niP00`000000V?^H000000020000000309SkV0000000V?^H00@0V?^H00<0000009SkV02HniP0102H
niP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00@0000009SkV02HniP0V?^H
1P00000309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H
09SkV00309SkV0030000003jl>H0n_3V02T0n_3V0@3oool002/0n_3V00<0000009SkV02HniP00`2H
niP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102H
niP00`000000V?^H09SkV00=000000<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09Sk
V00409SkV0030000002HniP0V?^H0080V?^H1000000309SkV0030000002HniP0V?^H00@0V?^H00<0
000009SkV02HniP00`2HniP2000000L0V?^H0`00000509SkV0030000002HniP0V?^H00<0V?^H0`00
000709SkV0800000102HniP00`000000V?^H09SkV00509SkV0040000002HniP0V?^H09SkV0@00000
102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00@0000009SkV02HniP0
V?^H3@00000209SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000
V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<000000?[`iP3jl>H0:@3jl>H10?ooo`00
:`3jl>H00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0
0`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0
0`2HniP010000000V?^H09SkV02HniP:000000H0V?^H00<0000009SkV02HniP00`2HniP00`000000
V?^H09SkV007000000<0V?^H00<0000009SkV02HniP0102HniP3000000@0V?^H00<0000009SkV000
00001P2HniP00`000000V?^H09SkV00409SkV0030000002HniP0000000@0V?^H0`00000609SkV004
0000002HniP0V?^H09SkV0L000000P2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H
00@0V?^H2P00000309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`00
0000V?^H09SkV00309SkV0030000003jl>H0n_3V02T0n_3V0@3oool002/0n_3V00<0000009SkV02H
niP00`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02H
niP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02H
niP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02H
niP0102HniP00`000000V?^H09SkV00309SkV0040000002HniP0V?^H09SkV0@000001@2HniP01000
0000V?^H09SkV02HniP20000000309SkV0000000V?^H0080V?^H0P00000309SkV0<000000`2HniP2
000000<0V?^H00@0000009SkV000000000000`2HniP00`000000V?^H09SkV00309SkV0@000000`2H
niP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102H
niP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2H
niP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2H
niP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<000000?[`iP3jl>H0:@3j
l>H10?ooo`00:`3jl>H00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<00000
09SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<00000
09SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<00000
09SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<00000
09SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<00000
09SkV02HniP0102HniP30000000309SkV0000000V?^H00<000001P2HniP00`000000V?^H09SkV003
09SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV003
09SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV003
09SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV004
09SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV003
09SkV0030000002HniP0V?^H00<0V?^H00<000000?[`iP3jl>H0:@3jl>H10?ooo`00:`3jl>H00`00
0000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`00
0000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP01@00
0000V?^H09SkV02HniP0000000<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV003
09SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV004
09SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV004
09SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV004
09SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV003
09SkV0030000002HniP0V?^H00<0V?^H00<000000?[`iP3jl>H0:@3jl>H10?ooo`00:`3jl>H00`00
0000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`00
0000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00209SkV0030000002HniP0V?^H0080V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`00
0000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<000000?[`iP3jl>H0:@3jl>H10?oo
o`00:`3jl>K9000002/0n_3V0@3oool002/0n_3V00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H
09SkV00209SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H
09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H
09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H
09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H
09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00309SkV0030000003jl>H0n_3V02T0n_3V0@3oool002/0n_3V00<0000009SkV02HniP00`2H
niP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2H
niP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2H
niP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2H
niP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102H
niP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00D0000009SkV02HniP0V?^H
0000000309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H
09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H
09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H
09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00309SkV0030000003jl>H0n_3V02T0n_3V0@3oool002/0n_3V00<0000009SkV02HniP00`2H
niP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2H
niP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102H
niP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2H
niP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2H
niP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H0P00000209SkV0030000002H
niP0V?^H008000001P2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0
000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0
000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0
000009SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0
000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0
00000?[`iP3jl>H0:@3jl>H10?ooo`00:`3jl>H00`000000V?^H09SkV00309SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0
V?^H00<0V?^H00@0000009SkV02HniP0V?^H1000000509SkV0040000002HniP0V?^H09SkV0800000
00<0V?^H0000002HniP00`2HniP00`000000V?^H09SkV00500000080V?^H00<0000009SkV02HniP0
0P2HniP010000000V?^H00000000000309SkV0030000002HniP0V?^H00<0V?^H1000000309SkV003
0000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV003
0000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV003
0000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV003
0000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000n_3V0?[`iP0Y0?[`iP40
oooo000[0?[`iP030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H
09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00309SkV0040000002HniP0V?^H09SkV0X000001P2HniP00`000000V?^H09SkV00309SkV004
0000002HniP0V?^H09SkV0H000000`2HniP00`000000V?^H09SkV00409SkV0<00000102HniP01000
0000V?^H00000000000509SkV0030000002HniP0V?^H00<0V?^H0P0000000`2HniP0000009SkV003
09SkV0<000001P2HniP010000000V?^H09SkV02HniP6000000<0V?^H00<0000009SkV02HniP00`2H
niP00`000000V?^H09SkV00409SkV0X000000`2HniP00`000000V?^H09SkV00309SkV0030000002H
niP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002H
niP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000n_3V0?[`iP0Y0?[`iP40oooo000[
0?[`iP030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV003
09SkV0030000002HniP0V?^H00@0V?^H00@0000009SkV02HniP0V?^H3000000309SkV0030000002H
niP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00209SkV0D000000P2H
niP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H0P00000709SkV08000001P2H
niP00`000000V?^H09SkV00409SkV08000001`2HniP2000000@0V?^H00<0000009SkV02HniP01@2H
niP00`000000V?^H09SkV005000000@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09Sk
V00309SkV0040000002HniP0V?^H09SkV0`000000`2HniP00`000000V?^H09SkV00409SkV0030000
002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000
003jl>H0n_3V02T0n_3V0@3oool002/0n_3V00<0000009SkV02HniP00`2HniP00`000000V?^H09Sk
V00409SkV0030000002HniP0V?^H00<0V?^H00@0000009SkV02HniP0V?^H1`00000209SkV0030000
002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000
002HniP0V?^H00@0V?^H00<0000009SkV00000000P0000000`2HniP0000009SkV00509SkV0030000
002HniP0V?^H00@0V?^H00<0000009SkV00000000P00000209SkV0030000002HniP0V?^H0080V?^H
0P00000209SkV0@000000P2HniP00`000000V?^H09SkV00400000080V?^H0P00000409SkV0030000
002HniP0V?^H00<0000000<0V?^H0000002HniP01@2HniP00`000000V?^H09SkV00409SkV0030000
002HniP000000080000000<0V?^H0000002HniP0102HniP00`000000V?^H09SkV00409SkV0030000
002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV007000000<0V?^H
00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H
00<000000?[`iP3jl>H0:@3jl>H10?ooo`00:`3jl>H00`000000V?^H09SkV00309SkV0040000002H
niP0V?^H09SkV0d000000`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H
00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0040000002HniP0V?^H09SkV0@0
00001@2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H0`00000609SkV004
0000002HniP00000000000D0V?^H00<0000009SkV02HniP01@00000209SkV0030000002HniP0V?^H
00<0V?^H0P0000000`2HniP0000009SkV00509SkV0<000001@2HniP00`000000V?^H09SkV00309Sk
V0030000002HniP0V?^H00<0V?^H1000000309SkV0030000002HniP0V?^H00@0V?^H00<0000009Sk
V02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00@0000009Sk
V02HniP0V?^H3@00000309SkV0030000002HniP0V?^H00<0V?^H00<000000?[`iP3jl>H0:@3jl>H1
0?ooo`00:`3jl>H010000000V?^H09SkV02HniP6000000<0V?^H00<0000009SkV02HniP00`2HniP0
0`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP0
0`000000V?^H09SkV00309SkV0040000002HniP0V?^H09SkV0L000000P2HniP00`000000V?^H09Sk
V00409SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV00000000P00000209SkV0030000002H
niP0V?^H00D0V?^H0P00000509SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00P2H
niP00`000000V?^H09SkV00409SkV08000001`2HniP00`000000V?^H09SkV0030000000309SkV000
0000V?^H00D0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV007000000<0V?^H00<0
000009SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0
000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0040000002HniP0V?^H09SkV0H00000
0`2HniP00`000000n_3V0?[`iP0Y0?[`iP40oooo000[0?[`iP@000000P2HniP00`000000V?^H09Sk
V00409SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09Sk
V00409SkV0030000002HniP0V?^H00<0V?^H00@0000009SkV02HniP0V?^H1P00000309SkV0030000
002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV0<00000
1P2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<000000P2HniP00`000000V?^H
09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`00000209SkV0030000
002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP3000000D0V?^H00<0000009SkV02HniP0
0`2HniP00`000000V?^H09SkV00409SkV0040000002HniP0V?^H09SkV0H000000`2HniP00`000000
V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`000000
V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP01000000[0?[`iP40
oooo000[0?[`iP030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H
09SkV00309SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00209SkV0D000000P2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H
00<0000009SkV02HniP0102HniP00`000000V?^H0000000200000080V?^H00<0000009SkV02HniP0
0P2HniP20000000309SkV0000000V?^H0080V?^H00<0000009SkV02HniP0102HniP5000000<0V?^H
00@0000009SkV02HniP0V?^H1@00000609SkV0060000002HniP0V?^H09SkV0000000V?^H0P000004
09SkV0030000002HniP0V?^H00<0000000<0V?^H0000002HniP01@2HniP00`000000V?^H09SkV003
09SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP01@00000409SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00309SkV0030000002HniP0
V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000n_3V0?[`iP0Y0?[`iP40oooo000[0?[`
iP030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00409Sk
V0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H000000020000
000309SkV0000000V?^H00D0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309Sk
V0030000002HniP0V?^H00<0V?^H0`00000609SkV0040000002HniP00000000000@0V?^H00<00000
09SkV00000001`2HniP00`000000V?^H09SkV00209SkV0L000000`2HniP00`000000V?^H09SkV006
09SkV0030000002HniP0000000@0V?^H0P0000000`2HniP0000009SkV00509SkV0<000001@2HniP0
0`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP0
0`000000V?^H000000020000000309SkV0000000V?^H00@0V?^H00<0000009SkV02HniP0102HniP0
0`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP0
0`000000n_3V0?[`iP0Y0?[`iP40oooo000[0?[`iP030000002HniP0V?^H00@0V?^H00<0000009Sk
V02HniP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00@0000009Sk
V02HniP0V?^H1000000509SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP2
000000H0V?^H00<0000009SkV00000000P00000209SkV0030000002HniP0V?^H00D0V?^H00<00000
09SkV02HniP01@2HniP2000000L0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV005
09SkV0030000002HniP0V?^H00D0V?^H0P00000709SkV0030000002HniP0V?^H00D0V?^H00<00000
09SkV02HniP00`0000000`2HniP0000009SkV00509SkV08000001@2HniP00`000000V?^H09SkV003
09SkV0030000002HniP0V?^H00<0V?^H1000000309SkV0030000002HniP0V?^H00@0V?^H00<00000
09SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H00<00000
0?[`iP3jl>H0:@3jl>H10?ooo`00:`3jl>H00`000000V?^H09SkV00409SkV0030000002HniP0V?^H
00@0V?^H00<0000009SkV02HniP00`2HniP010000000V?^H09SkV02HniP700000080V?^H00<00000
09SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP000000080000000<0V?^H
0000002HniP01@2HniP2000000H0V?^H00<0000009SkV02HniP00P2HniP20000000309SkV0000000
V?^H00@0V?^H00<0000009SkV02HniP01000000209SkV0030000002HniP0V?^H00H0V?^H00<00000
09SkV02HniP01@2HniP010000000V?^H09SkV02HniP400000080V?^H00<0000009SkV02HniP00`2H
niP010000000V?^H00000000000409SkV0030000002HniP0V?^H00@0V?^H0P00000609SkV0030000
002HniP000000080000000<0V?^H0000002HniP01@2HniP00`000000V?^H09SkV00409SkV0030000
002HniP0V?^H00L000000`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H
00<0000009SkV02HniP0102HniP00`000000n_3V0?[`iP0Y0?[`iP40oooo000/0?[`iP030000002H
niP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP010000000V?^H09SkV02HniP6000000<0V?^H
00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0040000002HniP0V?^H09SkV0@0
0000102HniP00`000000V?^H09SkV00209SkV080000000<0V?^H0000002HniP01P2HniP010000000
V?^H00000000000409SkV080000000<0V?^H000000000000102HniP00`000000V?^H09SkV00G0000
0080V?^H00<0000009SkV02HniP00P2HniP20000000309SkV0000000000000@0V?^H0P0000000`2H
niP0000009SkV00609SkV0040000002HniP00000000000<0V?^H00<0000009SkV02HniP00`2HniP4
000000<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0040000002HniP0
V?^H09SkV0H000000`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H00<0
00000?[`iP3jl>H0:P3jl>H10?ooo`00;03jl>H00`000000V?^H09SkV00409SkV0030000002HniP0
V?^H0080V?^H1@00000209SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP00`2HniP0
0`000000V?^H09SkV00309SkV0D000000P2HniP00`000000V?^H09SkV00409SkV0040000002HniP0
0000000000@0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00609SkV0030000002H
niP0V?^H00<0V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV00209SkV0030000002H
niP0V?^H0080V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV00209SkV0030000002H
niP0V?^H0080V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00609SkV0030000002H
niP0V?^H00D0V?^H00<0000009SkV02HniP00P2HniP20000000309SkV0000000V?^H00@0V?^H00@0
000009SkV02HniP0V?^H1@00000509SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0
1@2HniP00`000000V?^H09SkV005000000@0V?^H00<0000009SkV02HniP0102HniP00`000000n_3V
0?[`iP0Z0?[`iP40oooo000/0?[`iP030000002HniP0V?^H00@0V?^H00<0000009SkV00000000P00
00000`2HniP0000009SkV00509SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102H
niP00`000000V?^H000000020000000309SkV0000000V?^H00D0V?^H00<0000009SkV02HniP00P2H
niP3000000H0V?^H00<0000009SkV02HniP00`2HniP20000000309SkV0000000V?^H00@0V?^H0P00
00000`2HniP000000000000209SkV0030000002HniP0V?^H0080V?^H00<0000009SkV02HniP00P2H
niP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H0080V?^H00<0000009SkV02HniP00P2H
niP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H0080000000<0V?^H0000000000001@2H
niP010000000V?^H00000000000509SkV0030000002HniP0V?^H00@0V?^H0`00000409SkV0030000
002HniP0V?^H00@0V?^H00<0000009SkV00000000P0000000`2HniP0000009SkV00509SkV0030000
002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H000000020000000309Sk
V0000000V?^H00D0V?^H00<000000?[`iP3jl>H0:P3jl>H10?ooo`00;03jl>H010000000V?^H09Sk
V02HniP5000000@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0030000
002HniP0V?^H00<0V?^H0`00000509SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0
0P00000209SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP00P00000409SkV0800000
00<0V?^H0000000000001@2HniP4000000<0V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H
09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00P2HniP010000000V?^H
09SkV02HniP4000000D0V?^H0P0000000`2HniP000000000000409SkV08000000P2HniP00`000000
V?^H09SkV00509SkV0030000002HniP0V?^H0080000000<0V?^H0000002HniP01@2HniP00`000000
V?^H09SkV00309SkV0<000001@2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0
V?^H00<0000009SkV02HniP00`2HniP5000000<0V?^H00<000000?[`iP3jl>H0:P3jl>H10?ooo`00
;03jl>H4000000<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000
002HniP0V?^H00D0V?^H00<0000009SkV00000000P0000000`2HniP0000009SkV00509SkV0030000
002HniP0V?^H00<0V?^H0`00000509SkV0030000002HniP0V?^H00D0V?^H0P00000809SkV0800000
1P2HniP010000000V?^H09SkV02HniPM000000<0V?^H00<0000009SkV02HniP0102HniP2000000P0
V?^H0P00000809SkV0030000002HniP0V?^H0080V?^H0`00000509SkV0030000002HniP0V?^H00@0
V?^H00<0000009SkV00000000P0000000`2HniP0000009SkV00609SkV0030000002HniP0V?^H00<0
V?^H00<0000009SkV02HniP0102HniP010000000V?^H09SkV02HniP4000002`0n_3V0@3oool002`0
n_3V00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0
V?^H00<0000009SkV02HniP0102HniP3000000D0V?^H00<0000009SkV02HniP0102HniP00`000000
V?^H0000000200000080V?^H00<0000009SkV02HniP00`2HniP2000000@0V?^H0P0000000`2HniP0
00000000000609SkV0030000002HniP0V?^H00<000000P2HniP00`000000V?^H09SkV00309SkV003
0000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV003
0000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00300000080
V?^H00<0000009SkV02HniP0102HniP20000000309SkV0000000000000D0V?^H0P00000409SkV003
0000002HniP0V?^H00<0000000<0V?^H0000002HniP01@2HniP00`000000V?^H09SkV00309SkV0<0
00001P2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02H
niP01@2HniP00`000000n_3V0?[`iP0Z0?[`iP40oooo000]0?[`iP030000002HniP0V?^H00@0V?^H
00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0000000<00000
00<0V?^H0000002HniP01@2HniP00`000000V?^H09SkV00309SkV0<000001@2HniP00`000000V?^H
09SkV00300000080V?^H00@0000009SkV000000000001@2HniP00`000000V?^H09SkV00209SkV003
0000002HniP0V?^H00@0V?^H0`00000509SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02H
niP0102HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02H
niP00`2HniP3000000H0V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV00309SkV080
000000<0V?^H0000000000000P2HniP200000080V?^H00<0000009SkV02HniP00`2HniP3000000D0
V?^H00<0000009SkV02HniP0102HniP00`000000V?^H000000030000000309SkV0000000V?^H00D0
V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0030000003jl>H0n_3V02/0
n_3V0@3oool002d0n_3V00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV0030000
002HniP0V?^H00<0V?^H0`00000609SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV0000000
0P0000000`2HniP0000009SkV00609SkV08000001P2HniP00`000000V?^H09SkV00609SkV0800000
00<0V?^H0000002HniP01P2HniP00`000000V?^H09SkV0030000000309SkV0000000V?^H00D0V?^H
00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H
00<0000009SkV02HniP00`00000209SkV0030000002HniP0V?^H00D0V?^H00@0000009SkV0000000
0000202HniP00`000000V?^H09SkV00409SkV08000001P2HniP00`000000V?^H09SkV00300000003
09SkV0000000V?^H00D0V?^H00<0000009SkV02HniP0102HniP3000000@0V?^H00<0000009SkV02H
niP0102HniP00`000000V?^H09SkV00409SkV0030000003jl>H0n_3V02/0n_3V0@3oool002d0n_3V
00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0000000800000
00<0V?^H0000002HniP01P2HniP00`000000V?^H09SkV00409SkV08000001@2HniP00`000000V?^H
09SkV00209SkV080000000<0V?^H0000002HniP00`2HniP20000000309SkV0000000V?^H00P0V?^H
0P00000609SkV0030000002HniP0V?^H00@0V?^H7`00000609SkV0030000002HniP0V?^H00@0V?^H
0P00000909SkV0040000002HniP00000000000@0V?^H00@0000009SkV00000000000102HniP00`00
0000V?^H09SkV00309SkV08000001P2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H
00<0000000<0V?^H0000002HniP01@2HniP00`000000V?^H09SkV00409SkV0030000003jl>H0n_3V
02/0n_3V0@3oool002h0n_3V00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV0<0
00001@2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H0080V?^H0P0000000`2HniP0
000009SkV00409SkV0030000002HniP0V?^H00800000102HniP010000000V?^H00000000000409Sk
V0030000002HniP0V?^H00@0V?^H0P00000209SkV0<000000P2HniP00`000000V?^H09SkV00509Sk
V0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409Sk
V0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV0030000
0080V?^H0P00000609SkV0030000002HniP0V?^H0080V?^H0P0000000`2HniP0000009SkV00309Sk
V080000000<0V?^H0000002HniP01@2HniP010000000V?^H00000000000409SkV0030000002HniP0
V?^H00@0V?^H00<0000009SkV02HniP00`2HniP3000000@0V?^H00<0000009SkV02HniP0102HniP0
0`000000n_3V0?[`iP0/0?[`iP40oooo000^0?[`iP030000002HniP0V?^H00@0V?^H00<0000009Sk
V00000000P0000000`2HniP0000009SkV00509SkV0030000002HniP0V?^H00D0V?^H00@0000009Sk
V000000000000`2HniP00`000000V?^H09SkV00409SkV08000001`2HniP00`000000V?^H09SkV005
09SkV08000000P2HniP2000000L0V?^H0`00000709SkV0030000002HniP0V?^H00@0V?^H00<00000
09SkV02HniP01@2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00D0V?^H00<00000
09SkV02HniP01@2HniP3000000L0V?^H0P00000209SkV08000001`2HniP00`000000V?^H09SkV005
09SkV08000001P2HniP010000000V?^H09SkV02HniP20000000309SkV0000000V?^H00D0V?^H00<0
000009SkV02HniP0102HniP00`000000V?^H09SkV0030000000309SkV0000000V?^H00D0V?^H00<0
00000?[`iP3jl>H0;03jl>H10?ooo`00;P3jl>H00`000000V?^H09SkV00309SkV0<000001@2HniP0
0`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H0`00000609SkV0040000002HniP0
V?^H09SkV080000000<0V?^H0000002HniP0102HniP20000000309SkV0000000V?^H00<0V?^H0P00
000209SkV08000002@2HniP00`000000V?^H09SkV00400000080V?^H00<0000009SkV02HniP01@2H
niP00`000000V?^H09SkV00509SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP0102H
niP010000000V?^H09SkV02HniP400000080V?^H00<0000009SkV02HniP01`2HniP200000080V?^H
0P00000409SkV0040000002HniP00000000000D0V?^H00@0000009SkV000000000000`2HniP00`00
0000V?^H09SkV00409SkV0<000001@2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H
00<0V?^H0`00000509SkV0030000003jl>H0n_3V02`0n_3V0@3oool002l0n_3V00<0000009SkV000
00000P0000000`2HniP0000009SkV00509SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02H
niP00`00000209SkV0030000002HniP0V?^H00@0V?^H00@0000009SkV00000000000102HniP00`00
0000V?^H09SkV002000000@0V?^H00@0000009SkV00000000000102HniP010000000V?^H00000000
000609SkV0030000002HniP0V?^H00D0V?^H9@00000609SkV0030000002HniP0V?^H00D0V?^H0P00
00000`2HniP0000009SkV00309SkV080000000<0V?^H0000002HniP00`2HniP200000080V?^H00<0
000009SkV02HniP00P2HniP20000000309SkV0000000V?^H00D0V?^H00<0000009SkV02HniP00`00
00000`2HniP0000009SkV00509SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV00000000P00
00000`2HniP000000?[`iP0^0?[`iP40oooo000_0?[`iP8000001@2HniP00`000000V?^H09SkV004
09SkV0030000002HniP0V?^H00<0V?^H0`00000509SkV0030000002HniP0V?^H00@0V?^H0P000007
09SkV08000001`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H0080V?^H0`000003
09SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV006
09SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV006
09SkV0040000002HniP0V?^H09SkV0<00000102HniP00`000000V?^H09SkV00309SkV0030000002H
niP0V?^H00D0V?^H0P00000709SkV08000001@2HniP00`000000V?^H09SkV00409SkV0<000001@2H
niP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0V?^H0P00000_0?[`iP40oooo000_
0?[`iP030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV003
00000080V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00300000080V?^H00<00000
09SkV02HniP00P2HniP20000000309SkV0000000V?^H00@0V?^H0P0000000`2HniP0000000000002
09SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP01000000709SkV0030000002HniP0
V?^H00H0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00609SkV0030000002HniP0
V?^H00H0V?^H00<0000009SkV02HniP01@2HniP400000080V?^H00<0000009SkV02HniP00`2HniP0
0`000000V?^H09SkV0020000000309SkV0000000000000D0V?^H00@0000009SkV00000000000102H
niP00`000000V?^H09SkV00300000080V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09Sk
V0030000000309SkV0000000V?^H00H0V?^H00<0000009SkV02HniP0102HniP00`000000n_3V0?[`
iP0]0?[`iP40oooo000`0?[`iP030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP2
000000D0V?^H00<0000009SkV02HniP01@2HniP2000000H0V?^H00@0000009SkV00000000000102H
niP20000000309SkV0000000000000D0V?^H0`00000309SkV0800000102HniP00`000000V?^H09Sk
V009000000H0V?^H00<0000009SkV02HniP01`2HniP00`000000V?^H09SkV00609SkV0030000002H
niP0V?^H00D0V?^H2@00000209SkV0030000002HniP0V?^H0080V?^H0P00000309SkV0<000001@2H
niP20000000309SkV0000000000000@0V?^H0P0000000`2HniP0000009SkV00509SkV08000001`2H
niP00`000000V?^H09SkV00309SkV08000001P2HniP00`000000V?^H09SkV00409SkV0030000003j
l>H0n_3V02h0n_3V0@3oool00300n_3V00<0000009SkV02HniP0102HniP00`000000V?^H09SkV002
09SkV080000000<0V?^H0000002HniP01@2HniP00`000000V?^H09SkV00209SkV080000000<0V?^H
0000002HniP01P2HniP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H00@0V?^H0P000002
09SkV0<000001@2HniP00`000000V?^H09SkV00209SkV0050000002HniP0V?^H09SkV00000000`2H
niPQ00000080V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV00209SkV0030000002H
niP0V?^H00<0V?^H0`00000209SkV08000001P2HniP00`000000V?^H09SkV00609SkV0030000002H
niP0V?^H00D0V?^H00@0000009SkV00000000000102HniP00`000000V?^H09SkV00409SkV0040000
002HniP00000000000@0V?^H00<0000009SkV02HniP0102HniP00`000000n_3V0?[`iP0^0?[`iP40
oooo000a0?[`iP030000002HniP0V?^H00@0V?^H00@0000009SkV000000000000`2HniP00`000000
V?^H09SkV00409SkV0030000002HniP0V?^H00800000102HniP00`000000V?^H09SkV00209SkV080
000000<0V?^H0000002HniP0102HniP20000000309SkV000000000000080V?^H0P00000509SkV004
0000002HniP0000000000080V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV00209Sk
V0030000002HniP0V?^H0080V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV00209Sk
V0030000002HniP0V?^H0080V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV00209Sk
V0050000002HniP0V?^H09SkV00000001@2HniP00`000000V?^H09SkV00209SkV0030000002HniP0
V?^H0080V?^H00<0000009SkV02HniP00P0000000`2HniP0000009SkV00409SkV08000000P2HniP2
0000000309SkV0000000000000D0V?^H00@0000009SkV00000000000102HniP00`000000V?^H09Sk
V00209SkV08000000P2HniP00`000000V?^H09SkV00409SkV0040000002HniP0V?^H09SkV0800000
00<0V?^H0000002HniP01@2HniP00`000000n_3V0?[`iP0_0?[`iP40oooo000a0?[`iP030000002H
niP0V?^H00<0V?^H0`00000609SkV0030000002HniP0V?^H00@0V?^H0P00000709SkV0040000002H
niP00000000000@0V?^H0P0000000`2HniP000000000000509SkV0<000001@2HniP00`000000V?^H
09SkV00209SkV0T000000P2HniP00`000000V?^H09SkV00309SkV0050000002HniP0V?^H09SkV000
00001@2HniP00`000000V?^H09SkV00209SkV0030000002HniP0V?^H0080V?^H00<0000009SkV02H
niP00P2HniP00`000000V?^H09SkV00209SkV0030000002HniP0V?^H0080V?^H00@0000009SkV02H
niP0V?^H2@00000409SkV0030000002HniP0V?^H00<0V?^H0`00000509SkV080000000<0V?^H0000
00000000102HniP20000000309SkV0000000V?^H00H0V?^H0P00000609SkV0030000002HniP0V?^H
00@0V?^H0`00000509SkV0030000003jl>H0n_3V02l0n_3V0@3oool00380n_3V00<0000009SkV000
00000P00000209SkV0030000002HniP0V?^H00D0V?^H00@0000009SkV02HniP0V?^H0P0000000`2H
niP0000009SkV00709SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP01@2HniP00`00
0000V?^H09SkV00200000080V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00209Sk
V0040000002HniP0V?^H09SkV0D000000P2HniP00`000000V?^H09SkV00209SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP00P2HniP00`000000V?^H09SkV00209SkV0030000002HniP0
V?^H00<0V?^H00D0000009SkV02HniP0V?^H0000000309SkV0D000000`2HniP00`000000V?^H09Sk
V00209SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00P00000209SkV0030000002H
niP0V?^H00D0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00609SkV0040000002H
niP00000000000<0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV0030000000309Sk
V0000000n_3V0340n_3V0@3oool00380n_3V0P00000509SkV0030000002HniP0V?^H00D0V?^H00@0
000009SkV00000000000102HniP2000000@0V?^H0P0000000`2HniP0000009SkV00509SkV0040000
002HniP00000000000@0V?^H00<0000009SkV02HniP00`2HniP4000000<0V?^H00<0000009SkV02H
niP00P2HniP00`000000V?^H09SkV00309SkV0040000002HniP0V?^H09SkV2D000000`2HniP00`00
0000V?^H09SkV00209SkV0030000002HniP0V?^H00<0V?^H00@0000009SkV02HniP0V?^H10000005
09SkV0030000002HniP0V?^H0080V?^H0P0000000`2HniP0000009SkV00509SkV0040000002HniP0
0000000000@0V?^H0P00000409SkV080000000<0V?^H0000002HniP01P2HniP00`000000V?^H09Sk
V00309SkV0800000<P3jl>H10?ooo`00<`3jl>H00`000000V?^H09SkV00409SkV0030000002HniP0
V?^H00D0V?^H00<0000009SkV02HniP01P2HniP010000000V?^H00000000000409SkV0040000002H
niP0V?^H09SkV0800000102HniP20000000309SkV0000000V?^H00D0V?^H00@0000009SkV02HniP0
V?^H1@00000309SkV0030000002HniP0V?^H0080V?^H00<0000009SkV02HniP00`2HniP00`000000
V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00P2HniP00`000000
V?^H09SkV00209SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00P2HniP00`000000
V?^H09SkV00309SkV0030000002HniP0V?^H00<0V?^H00@0000009SkV02HniP0V?^H1@00000309Sk
V0030000002HniP0V?^H00@0V?^H00@0000009SkV00000000000102HniP2000000<0V?^H00<00000
09SkV02HniP00P2HniP20000000309SkV0000000V?^H00L0V?^H00<0000009SkV02HniP01@2HniP0
0`000000V?^H09SkV00409SkV0030000003jl>H0n_3V0340n_3V0@3oool003<0n_3V00<0000009Sk
V02HniP01@2HniP00`000000V?^H09SkV00209SkV080000000<0V?^H0000002HniP01`2HniP00`00
0000V?^H09SkV00509SkV0030000002HniP0000000P0V?^H0`00000309SkV08000001@2HniP01000
0000V?^H09SkV02HniP5000000<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV002
09SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV002
09SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV003
09SkV0040000002HniP0V?^H09SkV0D000000`2HniP00`000000V?^H09SkV00309SkV08000000`2H
niP3000000P0V?^H00<0000009SkV00000001`2HniP00`000000V?^H09SkV00609SkV0040000002H
niP00000000000@0V?^H00<0000009SkV02HniP01@2HniP00`000000n_3V0?[`iP0a0?[`iP40oooo
000d0?[`iP030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00P00000409SkV0030000002H
niP0V?^H00<0V?^H0P0000000`2HniP0000009SkV00609SkV08000001P2HniP2000000<0V?^H1000
000509SkV0030000002HniP0V?^H00<0V?^H00@0000009SkV02HniP0V?^H1@00000309SkV0030000
002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV0030000
002HniP0V?^H00<0V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00209SkV0030000
002HniP0V?^H0080V?^H1@00000309SkV0030000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0
0`2HniP4000000<0V?^H0P00000609SkV08000001`2HniP010000000V?^H00000000000509SkV003
0000002HniP0V?^H0080V?^H0P00000209SkV0030000002HniP0V?^H00@0V?^H00<000000?[`iP3j
l>H0<P3jl>H10?ooo`00=@3jl>H00`000000V?^H09SkV00309SkV0<000001`2HniP00`000000V?^H
09SkV002000000@0V?^H00<0000009SkV02HniP00P2HniP200000080V?^H0P00000209SkV0800000
1P2HniP00`000000V?^H09SkV00200000080V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H
09SkV00309SkV0040000002HniP0V?^H09SkV2/000000P2HniP00`000000V?^H09SkV00309SkV003
0000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00P00000209SkV0030000002HniP0V?^H00@0
V?^H0P00000209SkV08000000P2HniP2000000@0V?^H00<0000009SkV02HniP00P2HniP200000080
V?^H00<0000009SkV02HniP01@2HniP3000000D0V?^H00<000000?[`iP3jl>H0<`3jl>H10?ooo`00
=@3jl>H00`000000V?^H09SkV00300000080V?^H00<0000009SkV02HniP01P2HniP2000000L0V?^H
00@0000009SkV000000000001P2HniP3000000H0V?^H00<0000009SkV02HniP00`2HniP4000000@0
V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00@0
V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H00<0
V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00<0
V?^H00<0000009SkV02HniP00`2HniP00`000000V?^H09SkV00209SkV0@000001@2HniP00`000000
V?^H09SkV00409SkV0<000001P2HniP20000000309SkV0000000V?^H00H0V?^H0P00000809SkV003
0000002HniP0V?^H00<000000P2HniP00`000000n_3V0?[`iP0c0?[`iP40oooo000f0?[`iP800000
1P2HniP00`000000V?^H09SkV00409SkV0030000002HniP0000000P0V?^H00<0000009SkV02HniP0
1P2HniP00`000000V?^H09SkV00300000080V?^H00<0000009SkV02HniP0102HniP010000000V?^H
09SkV02HniP6000000<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV003
0000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV003
0000002HniP0V?^H00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00309SkV003
0000002HniP0V?^H0080V?^H1P00000309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02H
niP00`00000209SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP01P2HniP00`000000
V?^H0000000609SkV0030000002HniP0V?^H00@0V?^H0P00000f0?[`iP40oooo000g0?[`iP030000
002HniP0V?^H00D0V?^H00@0000009SkV02HniP0V?^H0P00000309SkV0800000102HniP200000003
09SkV0000000000000D0V?^H00<0000009SkV02HniP0102HniP3000000D0V?^H00<0000009SkV02H
niP0102HniP010000000V?^H09SkV02HniP=000000<0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00`2HniP01000
0000V?^H09SkV02HniP=000000<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV003
09SkV0<000001P2HniP00`000000V?^H09SkV00309SkV080000000<0V?^H000000000000102HniP2
000000<0V?^H0P00000309SkV0030000002HniP0V?^H00D0V?^H00<000000?[`iP3jl>H0=@3jl>H1
0?ooo`00>03jl>H00`000000V?^H09SkV00509SkV0030000002HniP0000000L0V?^H00@0000009Sk
V000000000001@2HniP200000080V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV002
00000080V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0
V?^H00<0V?^H00<0000009SkV02HniP00P2HniPQ000000<0V?^H00<0000009SkV02HniP0102HniP0
0`000000V?^H09SkV00309SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP00P000002
09SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP00P00000509SkV080000000<0V?^H
0000002HniP01P2HniP00`000000V?^H0000000709SkV0030000003jl>H0n_3V03H0n_3V0@3oool0
03P0n_3V00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00709SkV0030000002HniP0V?^H
00L0V?^H0`00000609SkV0030000002HniP0V?^H00<0V?^H1@00000409SkV0030000002HniP0V?^H
00<0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H
00@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H
00<0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00309SkV0030000002HniP0V?^H
00@0V?^H00<0000009SkV02HniP00P2HniP5000000D0V?^H00<0000009SkV02HniP0102HniP30000
00T0V?^H00<0000009SkV02HniP01`2HniP00`000000V?^H09SkV00509SkV0030000003jl>H0n_3V
03L0n_3V0@3oool003T0n_3V00<0000009SkV02HniP00`2HniP20000000309SkV0000000V?^H00H0
V?^H00@0000009SkV000000000001P2HniP200000080V?^H0`00000209SkV0030000002HniP0V?^H
00@0V?^H00<0000009SkV02HniP00P2HniP6000000@0V?^H00<0000009SkV02HniP00`2HniP00`00
0000V?^H09SkV00509SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`00
0000V?^H09SkV00409SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`00
0000V?^H09SkV00409SkV0030000002HniP0V?^H0080V?^H1P00000409SkV0030000002HniP0V?^H
00@0V?^H00<0000009SkV02HniP00`00000209SkV08000001P2HniP20000000309SkV0000000V?^H
00H0V?^H00@0000009SkV000000000001@2HniP00`000000n_3V0?[`iP0g0?[`iP40oooo000j0?[`
iP030000002HniP0V?^H00800000102HniP2000000<0V?^H0P00000409SkV08000000P2HniP20000
00L0V?^H1000000409SkV0030000002HniP0V?^H00D0V?^H00@0000009SkV02HniP0V?^H3P000003
09SkV0030000002HniP0V?^H00D0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV004
09SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP00P2HniP>000000<0V?^H00<00000
09SkV02HniP01@2HniP00`000000V?^H09SkV00209SkV0@000001`2HniP200000080V?^H0P000004
09SkV08000000`2HniP2000000@0V?^H0P00000209SkV0030000003jl>H0n_3V03P0n_3V0@3oool0
03/0n_3V0P00000809SkV0030000002HniP0000000P0V?^H0`00000709SkV08000000`2HniP50000
00H0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H
0080V?^H9@00000309SkV0030000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`00
0000V?^H09SkV00509SkV0D000000`2HniP2000000L0V?^H0`00000809SkV0030000002HniP00000
00P0V?^H0P00000k0?[`iP40oooo000l0?[`iP800000202HniP00`000000V?^H09SkV00709SkV003
0000002HniP0V?^H00<000000P2HniP2000000L0V?^H00<0000009SkV02HniP01000000209SkV003
0000002HniP0V?^H00@0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00509SkV003
0000002HniP0V?^H00D0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00409SkV003
0000002HniP0V?^H00D0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00409SkV003
0000002HniP0V?^H00@0V?^H00<0000009SkV02HniP01000000209SkV0030000002HniP0V?^H00D0
V?^H0P00000209SkV0<000000P2HniP00`000000V?^H09SkV00709SkV0030000002HniP0V?^H00H0
V?^H0P00000l0?[`iP40oooo000n0?[`iP030000002HniP0V?^H00<0V?^H0P0000000`2HniP00000
0000000509SkV08000001P2HniP3000000L0V?^H00<0000009SkV02HniP01@2HniP5000000<0V?^H
00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00509SkV0030000002HniP0V?^H00D0V?^H
00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00D0V?^H
00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H0080V?^H
1@00000709SkV0030000002HniP0V?^H00D0V?^H0`00000609SkV08000001@2HniP20000000309Sk
V0000000000000D0V?^H00<000000?[`iP3jl>H0?03jl>H10?ooo`00?`3jl>H20000000309SkV000
0000000000D0V?^H0P00000209SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP01000
000209SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP00P2HniP>000000@0V?^H00<0
000009SkV02HniP01@2HniP00`000000V?^H09SkV00509SkV0030000002HniP0V?^H00D0V?^H00<0
000009SkV02HniP01@2HniP00`000000V?^H09SkV00209SkV0h00000102HniP00`000000V?^H09Sk
V00609SkV0030000002HniP0V?^H00@000000P2HniP00`000000V?^H09SkV00609SkV0030000002H
niP0V?^H008000001@2HniP20000000309SkV0000000000003l0n_3V0@3oool00440n_3V0P000008
09SkV0<000001`2HniP00`000000V?^H09SkV00509SkV0<000001`2HniP00`000000V?^H09SkV005
09SkV0030000002HniP0V?^H00D0V?^H00@0000009SkV02HniP0V?^H:@00000309SkV0030000002H
niP0V?^H00D0V?^H00<0000009SkV02HniP0102HniP00`000000V?^H09SkV00609SkV0<000001`2H
niP00`000000V?^H09SkV00509SkV0<00000202HniP200000440n_3V0@3oool004<0n_3V0P000006
09SkV0030000002HniP0V?^H00@000000P2HniP00`000000V?^H09SkV00609SkV0030000002HniP0
V?^H00@000000`2HniP00`000000V?^H09SkV00409SkV0030000002HniP0V?^H00D0V?^H00<00000
09SkV02HniP01P2HniP00`000000V?^H09SkV00509SkV0030000002HniP0V?^H00D0V?^H00<00000
09SkV02HniP01@2HniP00`000000V?^H09SkV00509SkV0030000002HniP0V?^H00D0V?^H00<00000
09SkV02HniP01@2HniP00`000000V?^H09SkV00509SkV0040000002HniP0V?^H09SkV0@000000P2H
niP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H00@000000P2HniP00`000000V?^H09Sk
V00409SkV0800000@`3jl>H10?ooo`00A@3jl>H200000080V?^H0P00000709SkV0<000001`2HniP0
0`000000V?^H09SkV00509SkV0H00000102HniP00`000000V?^H09SkV00509SkV0030000002HniP0
V?^H00D0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00609SkV0030000002HniP0
V?^H00D0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00609SkV0030000002HniP0
V?^H00D0V?^H00<0000009SkV02HniP00P2HniP6000000H0V?^H00<0000009SkV02HniP01P2HniP3
000000L0V?^H0P00000209SkV0800000A@3jl>H10?ooo`00A`3jl>H3000000P0V?^H00<0000009Sk
V02HniP01000000309SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP00P2HniP@0000
00@0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H
00H0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00209SkV1000000102HniP00`00
0000V?^H09SkV00609SkV0040000002HniP0V?^H09SkV0@000000P2HniP00`000000V?^H09SkV006
09SkV0<00000A`3jl>H10?ooo`00BP3jl>H2000000D0V?^H00<0000009SkV02HniP01@2HniP60000
00D0V?^H00<0000009SkV02HniP01@2HniP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H
0080V?^H:`00000309SkV0030000002HniP0V?^H00L0V?^H00<0000009SkV02HniP01@2HniP00`00
0000V?^H09SkV00309SkV0H000001`2HniP00`000000V?^H09SkV00309SkV0800000BP3jl>H10?oo
o`00C03jl>H200000080V?^H00<0000009SkV02HniP01`2HniP00`000000V?^H09SkV00209SkV0P0
00001@2HniP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02H
niP01@2HniP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02H
niP01@2HniP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02H
niP00`2HniP8000000@0V?^H00<0000009SkV02HniP01`2HniP00`000000V?^H09SkV002000004`0
n_3V0@3oool004h0n_3V0`00000809SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP0
0P2HniP9000000@0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00609SkV0030000
002HniP0V?^H00H0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00509SkV0030000
002HniP0V?^H00H0V?^H00<0000009SkV02HniP00`2HniP9000000@0V?^H00<0000009SkV02HniP0
1P2HniP00`000000V?^H09SkV00609SkV0<00000CP3jl>H10?ooo`00D@3jl>H4000000<0V?^H00<0
000009SkV02HniP01P2HniP00`000000V?^H09SkV00609SkV0030000002HniP0V?^H00<0V?^H2@00
000409SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09Sk
V00609SkV0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP00P2HniP9000000@0V?^H00<0
000009SkV02HniP01P2HniP00`000000V?^H09SkV00709SkV0040000002HniP0V?^H09SkV0@00000
D@3jl>H10?ooo`00E@3jl>H7000000D0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09Sk
V00609SkV0030000002HniP0V?^H00<0V?^H;@00000409SkV0030000002HniP0V?^H00L0V?^H00<0
000009SkV02HniP01P2HniP00`000000V?^H09SkV00309SkV0L00000E@3jl>H10?ooo`00G03jl>H9
000000@0V?^H00<0000009SkV02HniP01`2HniP00`000000V?^H09SkV00609SkV0030000002HniP0
V?^H00L0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00609SkV0030000002HniP0
V?^H00H0V?^H00<0000009SkV02HniP01`2HniP00`000000V?^H09SkV00609SkV0030000002HniP0
V?^H00<0V?^H2@00001L0?[`iP40oooo001U0?[`iPT00000102HniP00`000000V?^H09SkV00709Sk
V0030000002HniP0V?^H00H0V?^H00<0000009SkV02HniP01`2HniP00`000000V?^H09SkV00609Sk
V0030000002HniP0V?^H00L0V?^H00<0000009SkV02HniP01P2HniP00`000000V?^H09SkV00309Sk
V0T00000I@3jl>H10?ooo`00KP3jl>H9000000@0V?^H00<0000009SkV02HniP01`2HniP00`000000
V?^H09SkV00709SkV0030000002HniP0V?^H00L0V?^H00<0000009SkV02HniP01P2HniP00`000000
V?^H09SkV00309SkV0T00000KP3jl>H10?ooo`00M`3jl>Ha000007L0n_3V0@3oool00?l0n_3V803j
l>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00
o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`
iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o
0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V
0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0
n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H1
0?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3j
l>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40
oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`
iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3o
ool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V
803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?oo
o`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP
0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo
003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00
n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool0
0?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803j
l>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00
o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`
iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o
0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V
0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0
n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.0001, -10.0001, 0.0696871, \
0.0696871}}]
}, Open  ]],

Cell["The following raises the grid to a 3D surface.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{SurfaceColor[Melon], 
          EdgeForm[\(ColorMix[Melon, Black]\)[
              0.4]], \[IndentingNewLine]Polygon /@ grid // 
            RaiseTo3D[Sin[#1] Cos[#2] &]}, \[IndentingNewLine]NeutralLighting[
          0.3, 0.5, 
          0.1], \[IndentingNewLine]BoxRatios \[Rule] {2, 1, 
            0.4}, \[IndentingNewLine]BoxStyle \[Rule] 
          Gray, \[IndentingNewLine]Background \[Rule] 
          Peacock, \[IndentingNewLine]ImageSize \[Rule] 450];\)\)], "Input",
  CellLabel->"In[318]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .62309 
%%ImageSize: 450 280.389 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.2 .63 .79 r
MFill
% Scaling calculations
-0.00444444 1.00444 -0.16211 1.00444 [
[ 0 0 0 0 ]
[ 1 .62309 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.753 .753 .753 r
.25 Mabswid
[ ] 0 setdash
.01702 .28002 m
0 .42162 L
s
0 .42162 m
.23959 .62309 L
s
.23959 .62309 m
.24759 .48841 L
s
.24759 .48841 m
.01702 .28002 L
s
.8081 0 m
.98268 .26071 L
s
.98268 .26071 m
1 .40289 L
s
1 .40289 m
.82052 .14881 L
s
.82052 .14881 m
.8081 0 L
s
.01702 .28002 m
0 .42162 L
s
0 .42162 m
.82052 .14881 L
s
.82052 .14881 m
.8081 0 L
s
.8081 0 m
.01702 .28002 L
s
.24759 .48841 m
.98268 .26071 L
s
.98268 .26071 m
1 .40289 L
s
1 .40289 m
.23959 .62309 L
s
.23959 .62309 m
.24759 .48841 L
s
0 0 m
1 0 L
1 .62309 L
0 .62309 L
closepath
clip
newpath
.5 Mabswid
.832 .61 .389 r
.33805 .453 m .31102 .45989 L .32258 .43605 L p F P
.534 .396 .246 r
s
.832 .61 .389 r
.32258 .43605 m .34778 .43447 L .33805 .453 L p F P
.534 .396 .246 r
s
.741 .546 .355 r
.36578 .45714 m .33805 .453 L .34778 .43447 L p F P
.534 .396 .246 r
s
.916 .672 .421 r
.31102 .45989 m .2844 .47634 L .29781 .44773 L p F P
.534 .396 .246 r
s
.916 .672 .421 r
.29781 .44773 m .32258 .43605 L .31102 .45989 L p F P
.534 .396 .246 r
s
1 .754 .469 r
.33391 .42113 m .32258 .43605 L .29781 .44773 L p F P
.534 .396 .246 r
s
.904 .681 .433 r
.32258 .43605 m .33391 .42113 L .35735 .42501 L p F P
.534 .396 .246 r
s
.904 .681 .433 r
.35735 .42501 m .34778 .43447 L .32258 .43605 L p F P
.534 .396 .246 r
s
.732 .561 .369 r
.34778 .43447 m .35735 .42501 L .38154 .43957 L p F P
.534 .396 .246 r
s
.732 .561 .369 r
.38154 .43957 m .37371 .44394 L .34778 .43447 L p F P
.534 .396 .246 r
s
.741 .546 .355 r
.34778 .43447 m .37371 .44394 L .36578 .45714 L p F P
.534 .396 .246 r
s
.653 .489 .325 r
.39461 .46926 m .36578 .45714 L .37371 .44394 L p F P
.534 .396 .246 r
s
.963 .707 .438 r
.2844 .47634 m .25826 .49556 L .27344 .46455 L p F P
.534 .396 .246 r
s
.963 .707 .438 r
.27344 .46455 m .29781 .44773 L .2844 .47634 L p F P
.534 .396 .246 r
s
1 .772 .475 r
.31092 .42784 m .29781 .44773 L .27344 .46455 L p F P
.534 .396 .246 r
s
1 .754 .469 r
.29781 .44773 m .31092 .42784 L .33391 .42113 L p F P
.534 .396 .246 r
s
.715 .579 .358 r
.34489 .417 m .33391 .42113 L .31092 .42784 L p F P
.534 .396 .246 r
s
.556 .466 .305 r
.33391 .42113 m .34489 .417 L .36668 .42522 L p F P
.534 .396 .246 r
s
.556 .466 .305 r
.36668 .42522 m .35819 .42503 L p .35774 .4241 L F P
.534 .396 .246 r
s
.398 .322 .227 r
.35735 .42501 m .36668 .42522 L .38923 .44307 L p F P
.534 .396 .246 r
s
.398 .322 .227 r
.38923 .44307 m .38181 .43969 L p .38167 .43879 L F P
.534 .396 .246 r
s
.272 .207 .158 r
.38154 .43957 m .38923 .44307 L .41284 .46705 L p F P
.534 .396 .246 r
s
.272 .207 .158 r
.41284 .46705 m .41011 .46466 L p .41007 .46461 L F P
.534 .396 .246 r
s
.474 .382 .267 r
.40071 .46174 m .42909 .48225 L .42484 .48357 L p F P
.534 .396 .246 r
s
.292 .172 .107 r
.42909 .48225 m .42196 .47709 L p .42436 .47909 L F P
.534 .396 .246 r
s
.344 .198 .123 r
.43684 .48742 m .42962 .4851 L p .42909 .48225 L F P
.534 .396 .246 r
s
.344 .198 .123 r
.42962 .4851 m .42484 .48357 L .42754 .48273 L p F P
.534 .396 .246 r
s
.344 .198 .123 r
.42754 .48273 m .42909 .48225 L p .42962 .4851 L F P
.534 .396 .246 r
s
.292 .172 .107 r
.43341 .48583 m .42909 .48225 L p .4247 .47932 L F P
.534 .396 .246 r
s
.292 .172 .107 r
.43341 .48583 m .4247 .47932 L .42464 .47928 L F
.43341 .48583 m .42464 .47928 L .42549 .47999 L F
.344 .198 .123 r
.42909 .48225 m .43327 .484 L .43684 .48742 L F
.376 .225 .136 r
.43341 .48583 m .46144 .50414 L p .43566 .48669 L F P
.534 .396 .246 r
s
.376 .225 .136 r
.42909 .48225 m .43341 .48583 L p .43566 .48669 L F P
.534 .396 .246 r
s
.344 .198 .123 r
.45656 .49375 m .43922 .48819 L p .43327 .484 L F P
.534 .396 .246 r
s
.344 .198 .123 r
.43922 .48819 m .43684 .48742 L p .43327 .484 L F P
.534 .396 .246 r
s
.376 .225 .136 r
.46144 .50414 m .45895 .49832 L .42909 .48225 L p F P
.534 .396 .246 r
s
.344 .198 .123 r
.42909 .48225 m .45895 .49832 L .45656 .49375 L p F P
.534 .396 .246 r
s
.292 .172 .107 r
.40681 .46177 m .43341 .48583 L p .42507 .47968 L F P
.534 .396 .246 r
s
.367 .218 .132 r
.43341 .48583 m .42481 .47805 L p .43183 .48522 L F P
.534 .396 .246 r
s
.367 .218 .132 r
.43774 .49125 m .43341 .48583 L p .43183 .48522 L F P
.534 .396 .246 r
s
.367 .218 .132 r
.42481 .47805 m .40681 .46177 L p .42128 .47557 L F P
.534 .396 .246 r
s
.367 .218 .132 r
.43774 .49125 m .42481 .47805 L .42128 .47557 L F
.345 .199 .123 r
.43341 .48583 m .43774 .49125 L .46396 .50829 L p F P
.534 .396 .246 r
s
.345 .199 .123 r
.46396 .50829 m .46144 .50414 L .44865 .49578 L p F P
.534 .396 .246 r
s
.345 .199 .123 r
.46396 .50829 m .44865 .49578 L .44488 .49426 L F
.224 .136 .084 r
.46144 .50414 m .46396 .50829 L .49129 .51127 L p F P
.534 .396 .246 r
s
.41 .332 .235 r
.45452 .50215 m .44302 .49468 L p .45313 .50048 L F P
.534 .396 .246 r
s
.41 .332 .235 r
.46651 .50815 m .44302 .49468 L .44157 .4935 L F
.46651 .50815 m .45452 .50215 L .45313 .50048 L F
.44302 .49468 m .43774 .49125 L p .44157 .4935 L F P
.534 .396 .246 r
s
.41 .332 .235 r
.44213 .49499 m .46651 .50815 L p .43842 .49165 L F P
.534 .396 .246 r
s
.345 .199 .123 r
.44865 .49578 m .43341 .48583 L p .44488 .49426 L F P
.534 .396 .246 r
s
.632 .484 .325 r
.44213 .49499 m .44661 .49384 L .44806 .49436 L p F P
.534 .396 .246 r
s
.385 .241 .153 r
.48961 .49507 m .45656 .49375 L .45895 .49832 L p F P
.534 .396 .246 r
s
.385 .241 .153 r
.45895 .49832 m .49013 .50331 L .48961 .49507 L p F P
.534 .396 .246 r
s
.306 .179 .111 r
.45895 .49832 m .46144 .50414 L .49071 .5094 L p F P
.534 .396 .246 r
s
.306 .179 .111 r
.49071 .5094 m .49013 .50331 L .45895 .49832 L p F P
.534 .396 .246 r
s
.632 .484 .325 r
.44806 .49436 m .46912 .50188 L p .45032 .49708 L F P
.534 .396 .246 r
s
.632 .484 .325 r
.45032 .49708 m .44213 .49499 L .44806 .49436 L F
.41 .332 .235 r
.46651 .50815 m .46396 .50829 L .45452 .50215 L p F P
.534 .396 .246 r
s
.292 .172 .107 r
.42549 .47999 m .42464 .47928 L .42337 .47843 L F
.42337 .47843 m .42436 .47909 L .40071 .46174 L F
.42196 .47709 m .40071 .46174 L p .42436 .47909 L F P
.534 .396 .246 r
s
.292 .172 .107 r
.40071 .46174 m .40681 .46177 L p .42507 .47968 L F P
.534 .396 .246 r
s
.367 .218 .132 r
.41284 .46705 m .41945 .47347 L p .41718 .47137 L F P
.534 .396 .246 r
s
.367 .218 .132 r
.40681 .46177 m .41284 .46705 L p .41718 .47137 L F P
.534 .396 .246 r
s
.343 .204 .124 r
.41284 .46705 m .40559 .45968 L p .40791 .46213 L F P
.534 .396 .246 r
s
.367 .218 .132 r
.42084 .47507 m .40681 .46177 L .41718 .47137 L F
.42055 .47473 m .41718 .47137 L .41945 .47347 L F
.42084 .47507 m .41718 .47137 L .42055 .47473 L F
.343 .204 .124 r
.40132 .45557 m .40559 .45968 L .40095 .45519 L F
.367 .218 .132 r
.4292 .48311 m .40681 .46177 L .43036 .48408 L F
.343 .204 .124 r
.41892 .47375 m .40791 .46213 L .40132 .45557 L F
.40791 .46213 m .40559 .45968 L .40132 .45557 L F
.41892 .47375 m .41284 .46705 L p .40791 .46213 L F P
.534 .396 .246 r
s
.367 .218 .132 r
.41945 .47347 m .43036 .48408 L p .42084 .47507 L F P
.534 .396 .246 r
s
.367 .218 .132 r
.43036 .48408 m .43774 .49125 L p .4292 .48311 L F P
.534 .396 .246 r
s
.273 .207 .16 r
.41284 .46705 m .41892 .47375 L .4318 .48554 L p F P
.534 .396 .246 r
s
.41 .332 .235 r
.43774 .49125 m .43802 .49149 L p .43842 .49165 L F P
.534 .396 .246 r
s
.41 .332 .235 r
.43802 .49149 m .44213 .49499 L p .43842 .49165 L F P
.534 .396 .246 r
s
.273 .207 .16 r
.44213 .49499 m .43774 .49125 L .43036 .48408 L p F P
.534 .396 .246 r
s
.273 .207 .16 r
.44213 .49499 m .43036 .48408 L .43312 .4864 L F
.4318 .48554 m .44213 .49499 L p .43469 .48789 L F P
.534 .396 .246 r
s
.273 .207 .16 r
.43036 .48408 m .42593 .47977 L p .43312 .4864 L F P
.534 .396 .246 r
s
.273 .207 .16 r
.42593 .47977 m .41284 .46705 L p .4255 .47912 L F P
.534 .396 .246 r
s
.273 .207 .16 r
.43312 .4864 m .42593 .47977 L .4255 .47912 L F
.416 .335 .239 r
.42511 .47766 m .44661 .49384 L p .42472 .47796 L F P
.534 .396 .246 r
s
.273 .207 .16 r
.43469 .48789 m .41284 .46705 L .4318 .48554 L F
.416 .335 .239 r
.41892 .47375 m .42409 .47701 L p .42472 .47796 L F P
.534 .396 .246 r
s
.416 .335 .239 r
.42409 .47701 m .42511 .47766 L p .42472 .47796 L F P
.534 .396 .246 r
s
.343 .204 .124 r
.40559 .45968 m .39252 .44641 L p .40095 .45519 L F P
.534 .396 .246 r
s
.343 .204 .124 r
.40095 .45519 m .39252 .44641 L .39265 .4466 L F
.417 .336 .24 r
.39473 .44758 m .41267 .46127 L p .39375 .44771 L F P
.534 .396 .246 r
s
.343 .204 .124 r
.3969 .45098 m .39979 .45397 L p .39296 .44693 L F P
.534 .396 .246 r
s
.343 .204 .124 r
.40153 .45578 m .39296 .44693 L .39979 .45397 L F
.39296 .44693 m .39029 .44416 L .3969 .45098 L F
.39252 .44641 m .38923 .44307 L p .39265 .4466 L F P
.534 .396 .246 r
s
.343 .204 .124 r
.38923 .44307 m .39034 .44422 L p .39029 .44416 L F P
.534 .396 .246 r
s
.343 .204 .124 r
.39034 .44422 m .3969 .45098 L p .39029 .44416 L F P
.534 .396 .246 r
s
.343 .204 .124 r
.40998 .46451 m .39265 .4466 L .40994 .46447 L F
.39265 .4466 m .38923 .44307 L .39296 .44693 L F
.39265 .4466 m .39296 .44693 L .40994 .46447 L F
.353 .206 .127 r
.3969 .45098 m .38549 .44078 L .38403 .44001 L F
.38403 .44001 m .37903 .435 L .37581 .433 L F
.38549 .44078 m .37903 .435 L .38403 .44001 L F
.38141 .43723 m .38629 .44157 L p .38151 .43787 L F P
.534 .396 .246 r
s
.353 .206 .127 r
.38629 .44157 m .39367 .44812 L p .38418 .44012 L F P
.534 .396 .246 r
s
.353 .206 .127 r
.38418 .44012 m .38151 .43787 L .38629 .44157 L F
.39464 .44906 m .38151 .43787 L .39367 .44812 L F
.323 .188 .117 r
.39367 .44812 m .38778 .44289 L p .39358 .44847 L F P
.534 .396 .246 r
s
.323 .188 .117 r
.39358 .44847 m .38778 .44289 L .38716 .44261 L F
.353 .206 .127 r
.3969 .45098 m .38923 .44307 L .37903 .435 L p F P
.534 .396 .246 r
s
.343 .204 .124 r
.39979 .45397 m .40994 .46447 L p .40153 .45578 L F P
.534 .396 .246 r
s
.515 .398 .275 r
.41267 .46127 m .43147 .47526 L p .41116 .46263 L F P
.534 .396 .246 r
s
.331 .257 .193 r
.4144 .46907 m .3969 .45098 L p .41292 .46613 L F P
.534 .396 .246 r
s
.331 .257 .193 r
.41892 .47375 m .4144 .46907 L p .41806 .47099 L F P
.534 .396 .246 r
s
.331 .257 .193 r
.41806 .47099 m .4144 .46907 L .41292 .46613 L F
.42511 .47766 m .42128 .47524 L p .41806 .47099 L F P
.534 .396 .246 r
s
.331 .257 .193 r
.42128 .47524 m .41892 .47375 L p .41806 .47099 L F P
.534 .396 .246 r
s
.331 .257 .193 r
.40468 .4586 m .42511 .47766 L p .41806 .47099 L F P
.534 .396 .246 r
s
.331 .257 .193 r
.3969 .45098 m .40468 .4586 L p .41806 .47099 L F P
.534 .396 .246 r
s
.323 .188 .117 r
.3852 .44159 m .40468 .4586 L p .38604 .44159 L F P
.534 .396 .246 r
s
.323 .188 .117 r
.39464 .44906 m .39385 .44839 L .39444 .44925 L F
.40125 .45547 m .39464 .44906 L .39444 .44925 L F
.40468 .4586 m .39952 .45369 L .40125 .45547 L F
.39952 .45369 m .39367 .44812 L .40125 .45547 L F
.39444 .44925 m .39434 .44912 L .39358 .44847 L F
.39434 .44912 m .39367 .44812 L .39358 .44847 L F
.417 .336 .24 r
.40468 .4586 m .3852 .44159 L p .39006 .44507 L F P
.534 .396 .246 r
s
.323 .188 .117 r
.39464 .44906 m .39367 .44812 L .39385 .44839 L F
.353 .206 .127 r
.39367 .44812 m .39482 .44921 L p .39464 .44906 L F P
.534 .396 .246 r
s
.323 .188 .117 r
.3969 .45098 m .39367 .44812 L p .39952 .45369 L F P
.534 .396 .246 r
s
.323 .188 .117 r
.40468 .4586 m .3969 .45098 L p .39952 .45369 L F P
.534 .396 .246 r
s
.417 .336 .24 r
.40837 .45819 m .40468 .4586 L .39006 .44507 L F
.515 .398 .275 r
.40468 .4586 m .41003 .46039 L p .41116 .46263 L F P
.534 .396 .246 r
s
.515 .398 .275 r
.41003 .46039 m .41267 .46127 L p .41116 .46263 L F P
.534 .396 .246 r
s
.417 .336 .24 r
.41267 .46127 m .41003 .46039 L p .40837 .45819 L F P
.534 .396 .246 r
s
.417 .336 .24 r
.41003 .46039 m .40468 .4586 L p .40837 .45819 L F P
.534 .396 .246 r
s
.353 .206 .127 r
.37903 .435 m .36668 .42522 L p .37581 .433 L F P
.534 .396 .246 r
s
.353 .206 .127 r
.36668 .42522 m .3759 .43234 L .38141 .43723 L p F P
.534 .396 .246 r
s
.353 .206 .127 r
.38151 .43787 m .36668 .42522 L .38141 .43723 L F
.323 .188 .117 r
.3759 .43234 m .3847 .44109 L p .38604 .44159 L F P
.534 .396 .246 r
s
.323 .188 .117 r
.3847 .44109 m .3852 .44159 L p .38604 .44159 L F P
.534 .396 .246 r
s
.398 .322 .227 r
.38154 .43957 m .35735 .42501 L p .38167 .43879 L F P
.534 .396 .246 r
s
.483 .392 .272 r
.37371 .44394 m .38154 .43957 L .40681 .46177 L p F P
.534 .396 .246 r
s
.262 .156 .097 r
.37754 .43742 m .38075 .43932 L p .37897 .43818 L F P
.534 .396 .246 r
s
.262 .156 .097 r
.37897 .43818 m .372 .43372 L .37754 .43742 L F
.309 .18 .112 r
.36093 .43304 m .37754 .43742 L p .3623 .43206 L F P
.534 .396 .246 r
s
.309 .18 .112 r
.34835 .42715 m .36093 .43304 L p .3623 .43206 L F P
.534 .396 .246 r
s
.12 .082 .051 r
.36093 .43304 m .34477 .43545 L p .35942 .43413 L F P
.534 .396 .246 r
s
.309 .18 .112 r
.37754 .43742 m .3665 .43036 L .34835 .42715 L p F P
.534 .396 .246 r
s
.613 .503 .331 r
.37754 .43742 m .37173 .43589 L p .37306 .43504 L F P
.534 .396 .246 r
s
.613 .503 .331 r
.37173 .43589 m .36093 .43304 L p .3713 .43475 L F P
.534 .396 .246 r
s
.613 .503 .331 r
.37306 .43504 m .37173 .43589 L .3713 .43475 L F
.36093 .43304 m .36919 .4329 L p .37306 .43504 L F P
.534 .396 .246 r
s
.262 .156 .097 r
.38148 .43972 m .372 .43372 L .38075 .43932 L F
.272 .207 .158 r
.40681 .46177 m .38154 .43957 L p .41007 .46461 L F P
.534 .396 .246 r
s
.398 .322 .227 r
.38181 .43969 m .38154 .43957 L p .38167 .43879 L F P
.534 .396 .246 r
s
.262 .156 .097 r
.38311 .44049 m .372 .43372 L .38208 .4401 L F
.3665 .43036 m .3706 .43298 L p .372 .43372 L F P
.534 .396 .246 r
s
.262 .156 .097 r
.3706 .43298 m .37754 .43742 L p .372 .43372 L F P
.534 .396 .246 r
s
.262 .156 .097 r
.3852 .44159 m .3665 .43036 L p .38506 .44168 L F P
.534 .396 .246 r
s
.322 .187 .116 r
.36787 .42837 m .35561 .42104 L .35308 .42105 L F
.3759 .43234 m .3666 .42716 L .36787 .42837 L F
.3666 .42716 m .35561 .42104 L .36787 .42837 L F
.35684 .42223 m .36773 .42801 L p .36448 .42649 L F P
.534 .396 .246 r
s
.322 .187 .116 r
.36448 .42649 m .35726 .42312 L .35685 .42227 L F
.36448 .42649 m .35685 .42227 L .35684 .42223 L F
.37006 .42945 m .35726 .42312 L .36773 .42801 L F
.35561 .42104 m .34489 .417 L p .35308 .42105 L F P
.534 .396 .246 r
s
.322 .187 .116 r
.34489 .417 m .35568 .42162 L .35684 .42223 L p F P
.534 .396 .246 r
s
.322 .187 .116 r
.35726 .42312 m .34489 .417 L .35684 .42223 L F
.373 .22 .134 r
.35568 .42162 m .3665 .43036 L .376 .43606 L p F P
.534 .396 .246 r
s
.373 .22 .134 r
.376 .43606 m .3852 .44159 L p .37341 .43361 L F P
.534 .396 .246 r
s
.373 .22 .134 r
.37341 .43361 m .35568 .42162 L .376 .43606 L F
.322 .187 .116 r
.36773 .42801 m .3759 .43234 L p .37006 .42945 L F P
.534 .396 .246 r
s
.373 .22 .134 r
.3852 .44159 m .3759 .43234 L .35568 .42162 L p F P
.534 .396 .246 r
s
.613 .503 .331 r
.36919 .4329 m .3739 .43282 L p .37306 .43504 L F P
.534 .396 .246 r
s
.12 .082 .051 r
.3739 .43282 m .36093 .43304 L p .35942 .43413 L F P
.534 .396 .246 r
s
.297 .177 .112 r
.36093 .43304 m .34835 .42715 L .33057 .43257 L p F P
.534 .396 .246 r
s
.297 .177 .112 r
.34477 .43545 m .36093 .43304 L p .34559 .43281 L F P
.534 .396 .246 r
s
.297 .177 .112 r
.33057 .43257 m .34477 .43545 L p .34559 .43281 L F P
.534 .396 .246 r
s
.124 .084 .052 r
.34477 .43545 m .32899 .44416 L p .34386 .43841 L F P
.534 .396 .246 r
s
.12 .082 .051 r
.35936 .43242 m .37052 .43273 L p .36223 .4336 L F P
.534 .396 .246 r
s
.12 .082 .051 r
.34477 .43545 m .35936 .43242 L p .36223 .4336 L F P
.534 .396 .246 r
s
.12 .082 .051 r
.37067 .43311 m .34477 .43545 L .37052 .43273 L F
.124 .084 .052 r
.35936 .43242 m .34477 .43545 L p .34386 .43841 L F P
.534 .396 .246 r
s
1 .768 .477 r
.35936 .43242 m .3453 .43637 L p .3555 .43082 L F P
.534 .396 .246 r
s
.322 .187 .116 r
.3759 .43234 m .36668 .42522 L .35561 .42104 L p F P
.534 .396 .246 r
s
.556 .466 .305 r
.35735 .42501 m .33391 .42113 L p .35774 .4241 L F P
.534 .396 .246 r
s
.556 .466 .305 r
.35819 .42503 m .35735 .42501 L p .35774 .4241 L F P
.534 .396 .246 r
s
.345 .207 .127 r
.3665 .43036 m .35568 .42162 L .33598 .4206 L p F P
.534 .396 .246 r
s
.345 .207 .127 r
.33598 .4206 m .34835 .42715 L .3665 .43036 L p F P
.534 .396 .246 r
s
1 .768 .477 r
.37438 .42055 m .35936 .43242 L p .3555 .43082 L F P
.534 .396 .246 r
s
.12 .082 .051 r
.37052 .43273 m .3739 .43282 L p .37067 .43311 L F P
.534 .396 .246 r
s
.323 .188 .117 r
.38778 .44289 m .3759 .43234 L p .38716 .44261 L F P
.534 .396 .246 r
s
.613 .503 .331 r
.38893 .43767 m .37754 .43742 L p .37306 .43504 L F P
.534 .396 .246 r
s
.613 .503 .331 r
.3739 .43282 m .38893 .43767 L p .37306 .43504 L F P
.534 .396 .246 r
s
.262 .156 .097 r
.38075 .43932 m .38208 .4401 L p .38148 .43972 L F P
.534 .396 .246 r
s
.417 .336 .24 r
.39375 .44771 m .38806 .44363 L .39214 .44605 L F
.38806 .44363 m .38663 .44261 L .39214 .44605 L F
.39214 .44605 m .38663 .44261 L .3919 .4458 L F
.3919 .4458 m .39473 .44758 L p .39375 .44771 L F P
.534 .396 .246 r
s
.262 .156 .097 r
.38208 .4401 m .39473 .44758 L p .38311 .44049 L F P
.534 .396 .246 r
s
.417 .336 .24 r
.3852 .44159 m .38605 .44212 L p .38663 .44261 L F P
.534 .396 .246 r
s
.417 .336 .24 r
.38605 .44212 m .3919 .4458 L p .38663 .44261 L F P
.534 .396 .246 r
s
.262 .156 .097 r
.39203 .44593 m .38601 .4421 L .38506 .44168 L F
.38601 .4421 m .3852 .44159 L .38506 .44168 L F
.39473 .44758 m .3919 .4458 L p .39203 .44593 L F P
.534 .396 .246 r
s
.262 .156 .097 r
.3919 .4458 m .3852 .44159 L p .39203 .44593 L F P
.534 .396 .246 r
s
.343 .204 .124 r
.40994 .46447 m .41892 .47375 L p .40998 .46451 L F P
.534 .396 .246 r
s
.272 .207 .158 r
.41011 .46466 m .40681 .46177 L p .41007 .46461 L F P
.534 .396 .246 r
s
.715 .579 .358 r
.31092 .42784 m .32359 .41933 L .34489 .417 L p F P
.534 .396 .246 r
s
.264 .157 .097 r
.32359 .41933 m .33598 .4206 L .3452 .42108 L p F P
.534 .396 .246 r
s
.264 .157 .097 r
.3452 .42108 m .35568 .42162 L p .34795 .42107 L F P
.534 .396 .246 r
s
.264 .157 .097 r
.34795 .42107 m .32359 .41933 L .3452 .42108 L F
.483 .392 .272 r
.40681 .46177 m .40071 .46174 L .37371 .44394 L p F P
.534 .396 .246 r
s
.653 .489 .325 r
.37371 .44394 m .40071 .46174 L .39461 .46926 L p F P
.534 .396 .246 r
s
.744 .592 .356 r
.32359 .41933 m .31092 .42784 L .28826 .442 L p F P
.534 .396 .246 r
s
1 .772 .475 r
.27344 .46455 m .28826 .442 L .31092 .42784 L p F P
.534 .396 .246 r
s
.474 .382 .267 r
.42484 .48357 m .39461 .46926 L .40071 .46174 L p F P
.534 .396 .246 r
s
1 .762 .469 r
.28826 .442 m .27344 .46455 L .24974 .47826 L p F P
.534 .396 .246 r
s
.969 .711 .439 r
.24974 .47826 m .27344 .46455 L .25826 .49556 L p F P
.534 .396 .246 r
s
.969 .711 .439 r
.25826 .49556 m .23309 .5065 L .24974 .47826 L p F P
.534 .396 .246 r
s
.264 .157 .097 r
.35568 .42162 m .34489 .417 L .32359 .41933 L p F P
.534 .396 .246 r
s
.784 .618 .37 r
.30259 .4307 m .28826 .442 L .26605 .45784 L p F P
.534 .396 .246 r
s
.744 .592 .356 r
.28826 .442 m .30259 .4307 L .32359 .41933 L p F P
.534 .396 .246 r
s
.843 .663 .403 r
.26605 .45784 m .24467 .46867 L p .25302 .46389 L F P
.534 .396 .246 r
s
1 .762 .469 r
.26605 .45784 m .28826 .442 L p .27666 .45293 L F P
.534 .396 .246 r
s
.784 .618 .37 r
.2819 .44734 m .30259 .4307 L p .29788 .4342 L F P
.534 .396 .246 r
s
.784 .618 .37 r
.26605 .45784 m .2819 .44734 L p .29788 .4342 L F P
.534 .396 .246 r
s
.843 .663 .403 r
.2819 .44734 m .26605 .45784 L p .25302 .46389 L F P
.534 .396 .246 r
s
1 .762 .469 r
.24974 .47826 m .26605 .45784 L p .27666 .45293 L F P
.534 .396 .246 r
s
.977 .724 .452 r
.26605 .45784 m .24974 .47826 L .22729 .48038 L p F P
.534 .396 .246 r
s
.977 .724 .452 r
.24467 .46867 m .26605 .45784 L p .24449 .47038 L F P
.534 .396 .246 r
s
.977 .724 .452 r
.22729 .48038 m .24467 .46867 L p .24449 .47038 L F P
.534 .396 .246 r
s
.882 .656 .418 r
.24467 .46867 m .22729 .48038 L .20665 .46772 L p F P
.534 .396 .246 r
s
.882 .656 .418 r
.22464 .47002 m .24467 .46867 L p .21606 .46795 L F P
.534 .396 .246 r
s
.882 .656 .418 r
.20665 .46772 m .22464 .47002 L p .21606 .46795 L F P
.534 .396 .246 r
s
.781 .626 .393 r
.24467 .46867 m .22464 .47002 L p .24487 .46675 L F P
.534 .396 .246 r
s
.703 .537 .355 r
.22464 .47002 m .20665 .46772 L .18796 .4463 L p F P
.534 .396 .246 r
s
.703 .537 .355 r
.18796 .4463 m .20643 .46243 L .22464 .47002 L p F P
.534 .396 .246 r
s
.843 .663 .403 r
.24467 .46867 m .26158 .46406 L p .2819 .44734 L F P
.534 .396 .246 r
s
.843 .663 .403 r
.26158 .46406 m .26176 .46401 L .2819 .44734 L p F P
.534 .396 .246 r
s
.781 .626 .393 r
.26176 .46401 m .24467 .46867 L p .24487 .46675 L F P
.534 .396 .246 r
s
.781 .626 .393 r
.22464 .47002 m .24266 .4754 L .26176 .46401 L p F P
.534 .396 .246 r
s
.467 .39 .263 r
.22464 .47002 m .20643 .46243 L p .23375 .47221 L F P
.534 .396 .246 r
s
.467 .39 .263 r
.24266 .4754 m .22464 .47002 L p .23375 .47221 L F P
.534 .396 .246 r
s
.214 .131 .081 r
.33598 .4206 m .32359 .41933 L .30259 .4307 L p F P
.534 .396 .246 r
s
.188 .118 .073 r
.31661 .42904 m .30259 .4307 L .2819 .44734 L p F P
.534 .396 .246 r
s
.214 .131 .081 r
.30259 .4307 m .31661 .42904 L .33598 .4206 L p F P
.534 .396 .246 r
s
.942 .691 .43 r
.23309 .5065 m .2097 .49874 L .22729 .48038 L p F P
.534 .396 .246 r
s
.942 .691 .43 r
.22729 .48038 m .24974 .47826 L .23309 .5065 L p F P
.534 .396 .246 r
s
.331 .203 .133 r
.34835 .42715 m .33598 .4206 L .31661 .42904 L p F P
.534 .396 .246 r
s
.888 .654 .413 r
.2097 .49874 m .18867 .47072 L .20665 .46772 L p F P
.534 .396 .246 r
s
.888 .654 .413 r
.20665 .46772 m .22729 .48038 L .2097 .49874 L p F P
.534 .396 .246 r
s
.785 .589 .382 r
.18867 .47072 m .16974 .43457 L .18796 .4463 L p F P
.534 .396 .246 r
s
.785 .589 .382 r
.18796 .4463 m .20665 .46772 L .18867 .47072 L p F P
.534 .396 .246 r
s
.43 .349 .247 r
.16974 .43457 m .15209 .40907 L .17105 .42753 L p F P
.534 .396 .246 r
s
.43 .349 .247 r
.17105 .42753 m .18796 .4463 L .16974 .43457 L p F P
.534 .396 .246 r
s
.311 .192 .129 r
.33057 .43257 m .31661 .42904 L .29749 .44471 L p F P
.534 .396 .246 r
s
.331 .203 .133 r
.31661 .42904 m .33057 .43257 L .34835 .42715 L p F P
.534 .396 .246 r
s
.188 .118 .073 r
.2819 .44734 m .29749 .44471 L .31661 .42904 L p F P
.534 .396 .246 r
s
.186 .116 .072 r
.29749 .44471 m .2819 .44734 L .26176 .46401 L p F P
.534 .396 .246 r
s
.391 .236 .142 r
.15209 .40907 m .13556 .40392 L .15612 .41769 L p F P
.534 .396 .246 r
s
.391 .236 .142 r
.15612 .41769 m .17105 .42753 L .15209 .40907 L p F P
.534 .396 .246 r
s
.29 .18 .121 r
.3131 .44545 m .29749 .44471 L .27879 .46348 L p F P
.534 .396 .246 r
s
.311 .192 .129 r
.29749 .44471 m .3131 .44545 L .33057 .43257 L p F P
.534 .396 .246 r
s
.186 .116 .072 r
.26176 .46401 m .27879 .46348 L .29749 .44471 L p F P
.534 .396 .246 r
s
.329 .256 .191 r
.20643 .46243 m .18796 .4463 L .17105 .42753 L p F P
.534 .396 .246 r
s
.289 .178 .117 r
.34477 .43545 m .33057 .43257 L .3131 .44545 L p F P
.534 .396 .246 r
s
.261 .161 .105 r
.52361 .48582 m .48961 .49507 L .49013 .50331 L p F P
.534 .396 .246 r
s
.21 .129 .08 r
.27879 .46348 m .26176 .46401 L .24266 .4754 L p F P
.534 .396 .246 r
s
.463 .292 .17 r
.19038 .45014 m .17105 .42753 L .15612 .41769 L p F P
.534 .396 .246 r
s
.329 .256 .191 r
.17105 .42753 m .19038 .45014 L .20643 .46243 L p F P
.534 .396 .246 r
s
.261 .161 .105 r
.49013 .50331 m .5222 .49348 L .52361 .48582 L p F P
.534 .396 .246 r
s
.735 .583 .348 r
.55812 .46744 m .52361 .48582 L .5222 .49348 L p F P
.534 .396 .246 r
s
.298 .175 .109 r
.13556 .40392 m .12154 .41109 L .14432 .41183 L p F P
.534 .396 .246 r
s
.298 .175 .109 r
.14432 .41183 m .15612 .41769 L .13556 .40392 L p F P
.534 .396 .246 r
s
.252 .157 .104 r
.32899 .44416 m .3131 .44545 L .29603 .46259 L p F P
.534 .396 .246 r
s
.289 .178 .117 r
.3131 .44545 m .32899 .44416 L .34477 .43545 L p F P
.534 .396 .246 r
s
.29 .18 .121 r
.27879 .46348 m .29603 .46259 L .3131 .44545 L p F P
.534 .396 .246 r
s
.416 .335 .239 r
.44661 .49384 m .44213 .49499 L .41892 .47375 L p F P
.534 .396 .246 r
s
.647 .501 .335 r
.37754 .43742 m .38893 .43767 L .40456 .44593 L p F P
.534 .396 .246 r
s
.647 .501 .335 r
.40456 .44593 m .39473 .44758 L .37754 .43742 L p F P
.534 .396 .246 r
s
.515 .398 .275 r
.43147 .47526 m .42511 .47766 L .40468 .4586 L p F P
.534 .396 .246 r
s
.735 .583 .348 r
.5222 .49348 m .55466 .46972 L .55812 .46744 L p F P
.534 .396 .246 r
s
.955 .705 .439 r
.59275 .44374 m .55812 .46744 L .55466 .46972 L p F P
.534 .396 .246 r
s
.251 .154 .099 r
.29603 .46259 m .27879 .46348 L .26096 .47978 L p F P
.534 .396 .246 r
s
.21 .129 .08 r
.24266 .4754 m .26096 .47978 L .27879 .46348 L p F P
.534 .396 .246 r
s
.156 .101 .062 r
.49013 .50331 m .49071 .5094 L .52079 .49739 L p F P
.534 .396 .246 r
s
.82 .651 .402 r
.49071 .5094 m .49129 .51127 L .49734 .50809 L p F P
.534 .396 .246 r
s
.156 .101 .062 r
.52079 .49739 m .5222 .49348 L .5094 .4974 L p F P
.534 .396 .246 r
s
.156 .101 .062 r
.52079 .49739 m .5094 .4974 L .50625 .5002 L F
.82 .651 .402 r
.51932 .49651 m .52079 .49739 L .51224 .50081 L p F P
.534 .396 .246 r
s
.82 .651 .402 r
.51224 .50081 m .49071 .5094 L p .50791 .50165 L F P
.534 .396 .246 r
s
.82 .651 .402 r
.51932 .49651 m .51224 .50081 L .50791 .50165 L F
.50118 .50469 m .49071 .5094 L .49734 .50809 L F
.984 .742 .465 r
.49129 .51127 m .49187 .50752 L .49776 .50364 L p F P
.534 .396 .246 r
s
.156 .101 .062 r
.5094 .4974 m .49013 .50331 L p .50625 .5002 L F P
.534 .396 .246 r
s
.984 .742 .465 r
.49776 .50364 m .5178 .49043 L p .50208 .50279 L F P
.534 .396 .246 r
s
.984 .742 .465 r
.50208 .50279 m .49129 .51127 L .49776 .50364 L F
.82 .651 .402 r
.49734 .50809 m .51932 .49651 L p .50118 .50469 L F P
.534 .396 .246 r
s
.305 .178 .111 r
.22523 .47801 m .20643 .46243 L .19038 .45014 L p F P
.534 .396 .246 r
s
.467 .39 .263 r
.20643 .46243 m .22523 .47801 L .24266 .4754 L p F P
.534 .396 .246 r
s
.224 .136 .084 r
.48239 .50791 m .46144 .50414 L p .47754 .50799 L F P
.534 .396 .246 r
s
.756 .596 .388 r
.46651 .50815 m .49187 .50752 L p .47109 .50809 L F P
.534 .396 .246 r
s
.756 .596 .388 r
.46396 .50829 m .46604 .50818 L p .47109 .50809 L F P
.534 .396 .246 r
s
.756 .596 .388 r
.46604 .50818 m .46651 .50815 L p .47109 .50809 L F P
.534 .396 .246 r
s
.224 .136 .084 r
.49129 .51127 m .49071 .5094 L .48239 .50791 L p F P
.534 .396 .246 r
s
.224 .136 .084 r
.49129 .51127 m .48239 .50791 L .47754 .50799 L F
.955 .705 .439 r
.55466 .46972 m .58704 .43752 L .59275 .44374 L p F P
.534 .396 .246 r
s
.823 .598 .378 r
.62721 .41964 m .59275 .44374 L .58704 .43752 L p F P
.534 .396 .246 r
s
.254 .151 .094 r
.26096 .47978 m .24266 .4754 L .22523 .47801 L p F P
.534 .396 .246 r
s
.635 .477 .319 r
.39473 .44758 m .40456 .44593 L .4209 .45573 L p F P
.534 .396 .246 r
s
.635 .477 .319 r
.4209 .45573 m .41267 .46127 L .39473 .44758 L p F P
.534 .396 .246 r
s
.823 .598 .378 r
.58704 .43752 m .61911 .40506 L .62721 .41964 L p F P
.534 .396 .246 r
s
.766 .554 .354 r
.66137 .39998 m .62721 .41964 L .61911 .40506 L p F P
.534 .396 .246 r
s
.848 .618 .39 r
.61101 .39318 m .61911 .40506 L .58704 .43752 L p F P
.534 .396 .246 r
s
.788 .573 .365 r
.61911 .40506 m .61101 .39318 L .64037 .36426 L p F P
.534 .396 .246 r
s
.788 .573 .365 r
.64037 .36426 m .65084 .38027 L .61911 .40506 L p F P
.534 .396 .246 r
s
.766 .554 .354 r
.61911 .40506 m .65084 .38027 L .66137 .39998 L p F P
.534 .396 .246 r
s
.984 .757 .462 r
.55113 .46917 m .55466 .46972 L .5222 .49348 L p F P
.534 .396 .246 r
s
.984 .757 .462 r
.5222 .49348 m .52079 .49739 L .55113 .46917 L p F P
.534 .396 .246 r
s
.955 .705 .439 r
.58128 .43122 m .58704 .43752 L .55466 .46972 L p F P
.534 .396 .246 r
s
.848 .618 .39 r
.58704 .43752 m .58128 .43122 L .61101 .39318 L p F P
.534 .396 .246 r
s
.463 .292 .17 r
.15612 .41769 m .17703 .436 L .19038 .45014 L p F P
.534 .396 .246 r
s
.374 .223 .135 r
.17703 .436 m .15612 .41769 L .14432 .41183 L p F P
.534 .396 .246 r
s
.831 .605 .383 r
.63008 .35291 m .64037 .36426 L .61101 .39318 L p F P
.534 .396 .246 r
s
.783 .572 .366 r
.64037 .36426 m .63008 .35291 L .65688 .33646 L p F P
.534 .396 .246 r
s
.783 .572 .366 r
.65688 .33646 m .66948 .35027 L .64037 .36426 L p F P
.534 .396 .246 r
s
.75 .546 .351 r
.65084 .38027 m .64037 .36426 L .66948 .35027 L p F P
.534 .396 .246 r
s
.886 .646 .405 r
.60299 .38434 m .61101 .39318 L .58128 .43122 L p F P
.534 .396 .246 r
s
.831 .605 .383 r
.61101 .39318 m .60299 .38434 L .63008 .35291 L p F P
.534 .396 .246 r
s
.124 .084 .052 r
.3453 .43637 m .35936 .43242 L p .34949 .43623 L F P
.534 .396 .246 r
s
.124 .084 .052 r
.32899 .44416 m .3453 .43637 L p .34949 .43623 L F P
.534 .396 .246 r
s
.089 .066 .041 r
.3453 .43637 m .32899 .44416 L .31368 .45683 L p F P
.534 .396 .246 r
s
1 .777 .475 r
.3453 .43637 m .33178 .44319 L p .34049 .43653 L F P
.534 .396 .246 r
s
1 .777 .475 r
.36202 .42009 m .3453 .43637 L p .34049 .43653 L F P
.534 .396 .246 r
s
.252 .157 .104 r
.29603 .46259 m .31368 .45683 L .32899 .44416 L p F P
.534 .396 .246 r
s
.955 .705 .439 r
.55466 .46972 m .55113 .46917 L .58128 .43122 L p F P
.534 .396 .246 r
s
.75 .546 .351 r
.66948 .35027 m .68231 .36825 L .65084 .38027 L p F P
.534 .396 .246 r
s
.738 .536 .345 r
.69515 .38843 m .66137 .39998 L .65084 .38027 L p F P
.534 .396 .246 r
s
.738 .536 .345 r
.65084 .38027 m .68231 .36825 L .69515 .38843 L p F P
.534 .396 .246 r
s
.885 .646 .406 r
.61996 .3465 m .63008 .35291 L .60299 .38434 L p F P
.534 .396 .246 r
s
.84 .617 .393 r
.63008 .35291 m .61996 .3465 L .64453 .32802 L p F P
.534 .396 .246 r
s
.84 .617 .393 r
.64453 .32802 m .65688 .33646 L .63008 .35291 L p F P
.534 .396 .246 r
s
.93 .704 .447 r
.38726 .42333 m .3739 .43282 L .35936 .43242 L p F P
.534 .396 .246 r
s
.812 .608 .392 r
.3739 .43282 m .38726 .42333 L .40069 .42831 L p F P
.534 .396 .246 r
s
.812 .608 .392 r
.40069 .42831 m .38893 .43767 L .3739 .43282 L p F P
.534 .396 .246 r
s
.166 .106 .066 r
.31368 .45683 m .29603 .46259 L .27976 .47882 L p F P
.534 .396 .246 r
s
.251 .154 .099 r
.26096 .47978 m .27976 .47882 L .29603 .46259 L p F P
.534 .396 .246 r
s
.611 .458 .308 r
.42511 .47766 m .43147 .47526 L .4512 .48568 L p F P
.534 .396 .246 r
s
.611 .458 .308 r
.4512 .48568 m .44661 .49384 L .42511 .47766 L p F P
.534 .396 .246 r
s
.734 .543 .354 r
.38893 .43767 m .40069 .42831 L .41469 .43466 L p F P
.534 .396 .246 r
s
.734 .543 .354 r
.41469 .43466 m .40456 .44593 L .38893 .43767 L p F P
.534 .396 .246 r
s
.305 .178 .111 r
.19038 .45014 m .21019 .47072 L .22523 .47801 L p F P
.534 .396 .246 r
s
.245 .181 .143 r
.21019 .47072 m .19038 .45014 L .17703 .436 L p F P
.534 .396 .246 r
s
.922 .673 .419 r
.59503 .37845 m .60299 .38434 L .57548 .4249 L p F P
.534 .396 .246 r
s
.885 .646 .406 r
.60299 .38434 m .59503 .37845 L .61996 .3465 L p F P
.534 .396 .246 r
s
.886 .646 .405 r
.58128 .43122 m .57548 .4249 L .60299 .38434 L p F P
.534 .396 .246 r
s
.93 .704 .447 r
.35936 .43242 m .37438 .42055 L .38726 .42333 L p F P
.534 .396 .246 r
s
.632 .484 .325 r
.46912 .50188 m .46651 .50815 L .44213 .49499 L p F P
.534 .396 .246 r
s
.646 .478 .317 r
.41267 .46127 m .4209 .45573 L .438 .46464 L p F P
.534 .396 .246 r
s
.646 .478 .317 r
.438 .46464 m .43147 .47526 L .41267 .46127 L p F P
.534 .396 .246 r
s
.958 .704 .437 r
.57548 .4249 m .58128 .43122 L .55113 .46917 L p F P
.534 .396 .246 r
s
.948 .695 .432 r
.60996 .34477 m .61996 .3465 L .59503 .37845 L p F P
.534 .396 .246 r
s
.929 .688 .433 r
.61996 .3465 m .60996 .34477 L .63239 .3254 L p F P
.534 .396 .246 r
s
.929 .688 .433 r
.63239 .3254 m .64453 .32802 L .61996 .3465 L p F P
.534 .396 .246 r
s
.756 .596 .388 r
.49187 .50752 m .49129 .51127 L .46396 .50829 L p F P
.534 .396 .246 r
s
.762 .569 .37 r
.65688 .33646 m .64453 .32802 L .66877 .32447 L p F P
.534 .396 .246 r
s
.762 .569 .37 r
.66877 .32447 m .68344 .33621 L .65688 .33646 L p F P
.534 .396 .246 r
s
.723 .535 .349 r
.66948 .35027 m .65688 .33646 L .68344 .33621 L p F P
.534 .396 .246 r
s
.723 .535 .349 r
.68344 .33621 m .69839 .35217 L .66948 .35027 L p F P
.534 .396 .246 r
s
.715 .527 .344 r
.68231 .36825 m .66948 .35027 L .69839 .35217 L p F P
.534 .396 .246 r
s
.847 .642 .413 r
.64453 .32802 m .63239 .3254 L .65439 .31859 L p F P
.534 .396 .246 r
s
.847 .642 .413 r
.65439 .31859 m .66877 .32447 L .64453 .32802 L p F P
.534 .396 .246 r
s
.194 .12 .075 r
.27976 .47882 m .26096 .47978 L .24469 .48791 L p F P
.534 .396 .246 r
s
.254 .151 .094 r
.22523 .47801 m .24469 .48791 L .26096 .47978 L p F P
.534 .396 .246 r
s
.698 .513 .335 r
.40456 .44593 m .41469 .43466 L .42934 .44108 L p F P
.534 .396 .246 r
s
.698 .513 .335 r
.42934 .44108 m .4209 .45573 L .40456 .44593 L p F P
.534 .396 .246 r
s
.955 .698 .432 r
.58711 .37519 m .59503 .37845 L .56966 .41855 L p F P
.534 .396 .246 r
s
.948 .695 .432 r
.59503 .37845 m .58711 .37519 L .60996 .34477 L p F P
.534 .396 .246 r
s
.922 .673 .419 r
.57548 .4249 m .56966 .41855 L .59503 .37845 L p F P
.534 .396 .246 r
s
.715 .527 .344 r
.69839 .35217 m .71352 .36992 L .68231 .36825 L p F P
.534 .396 .246 r
s
.721 .533 .347 r
.72846 .38647 m .69515 .38843 L .68231 .36825 L p F P
.534 .396 .246 r
s
.721 .533 .347 r
.68231 .36825 m .71352 .36992 L .72846 .38647 L p F P
.534 .396 .246 r
s
1 .775 .477 r
.54753 .46549 m .55113 .46917 L .52079 .49739 L p F P
.534 .396 .246 r
s
.958 .704 .437 r
.55113 .46917 m .54753 .46549 L .57548 .4249 L p F P
.534 .396 .246 r
s
.238 .144 .089 r
.24469 .48791 m .22523 .47801 L .21019 .47072 L p F P
.534 .396 .246 r
s
1 .768 .477 r
.3453 .43637 m .36202 .42009 L .37438 .42055 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.31368 .45683 m .33178 .44319 L .3453 .43637 L p F P
.534 .396 .246 r
s
.958 .702 .435 r
.56966 .41855 m .57548 .4249 L .54753 .46549 L p F P
.534 .396 .246 r
s
1 .775 .477 r
.52079 .49739 m .51932 .49651 L .54753 .46549 L p F P
.534 .396 .246 r
s
.836 .641 .414 r
.12154 .41109 m .11239 .41269 L .13725 .39941 L p F P
.534 .396 .246 r
s
.836 .641 .414 r
.13725 .39941 m .14432 .41183 L .12154 .41109 L p F P
.534 .396 .246 r
s
1 .744 .458 r
.60003 .34698 m .60996 .34477 L .58711 .37519 L p F P
.534 .396 .246 r
s
1 .768 .475 r
.60996 .34477 m .60003 .34698 L .6204 .32825 L p F P
.534 .396 .246 r
s
1 .768 .475 r
.6204 .32825 m .63239 .3254 L .60996 .34477 L p F P
.534 .396 .246 r
s
.838 .616 .392 r
.38726 .42333 m .37438 .42055 L p .37901 .39642 L F P
.534 .396 .246 r
s
.838 .616 .392 r
.37901 .39642 m .40095 .40473 L .38726 .42333 L p F P
.534 .396 .246 r
s
.764 .558 .359 r
.40069 .42831 m .38726 .42333 L .40095 .40473 L p F P
.534 .396 .246 r
s
.838 .616 .392 r
.37438 .42055 m .36202 .42009 L .37901 .39642 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.33178 .44319 m .31368 .45683 L .29915 .46925 L p F P
.534 .396 .246 r
s
.166 .106 .066 r
.27976 .47882 m .29915 .46925 L .31368 .45683 L p F P
.534 .396 .246 r
s
.914 .711 .448 r
.63239 .3254 m .6204 .32825 L .64026 .31917 L p F P
.534 .396 .246 r
s
.914 .711 .448 r
.64026 .31917 m .65439 .31859 L .63239 .3254 L p F P
.534 .396 .246 r
s
.764 .558 .359 r
.41469 .43466 m .40069 .42831 L p .40095 .40473 L F P
.534 .396 .246 r
s
.678 .498 .327 r
.43147 .47526 m .438 .46464 L .45587 .47001 L p F P
.534 .396 .246 r
s
.678 .498 .327 r
.45587 .47001 m .4512 .48568 L .43147 .47526 L p F P
.534 .396 .246 r
s
.983 .721 .444 r
.57919 .37397 m .58711 .37519 L .56382 .41217 L p F P
.534 .396 .246 r
s
1 .744 .458 r
.58711 .37519 m .57919 .37397 L .60003 .34698 L p F P
.534 .396 .246 r
s
.955 .698 .432 r
.56966 .41855 m .56382 .41217 L .58711 .37519 L p F P
.534 .396 .246 r
s
.692 .505 .33 r
.4209 .45573 m .42934 .44108 L .44464 .44603 L p F P
.534 .396 .246 r
s
.692 .505 .33 r
.44464 .44603 m .438 .46464 L .4209 .45573 L p F P
.534 .396 .246 r
s
.913 .671 .421 r
.36202 .42009 m .35026 .42122 L p .35956 .3899 L F P
.534 .396 .246 r
s
.913 .671 .421 r
.35956 .3899 m .37901 .39642 L .36202 .42009 L p F P
.534 .396 .246 r
s
1 .777 .475 r
.33178 .44319 m .35026 .42122 L .36202 .42009 L p F P
.534 .396 .246 r
s
.416 .335 .239 r
.19823 .45372 m .17703 .436 L .16725 .41821 L p F P
.534 .396 .246 r
s
.245 .181 .143 r
.17703 .436 m .19823 .45372 L .21019 .47072 L p F P
.534 .396 .246 r
s
.374 .223 .135 r
.14432 .41183 m .16725 .41821 L .17703 .436 L p F P
.534 .396 .246 r
s
.704 .522 .342 r
.44661 .49384 m .4512 .48568 L .47176 .48878 L p F P
.534 .396 .246 r
s
.704 .522 .342 r
.47176 .48878 m .46912 .50188 L .44661 .49384 L p F P
.534 .396 .246 r
s
.958 .701 .433 r
.56382 .41217 m .56966 .41855 L .54386 .45872 L p F P
.534 .396 .246 r
s
.958 .702 .435 r
.54753 .46549 m .54386 .45872 L .56966 .41855 L p F P
.534 .396 .246 r
s
.984 .742 .465 r
.5178 .49043 m .51932 .49651 L .49129 .51127 L p F P
.534 .396 .246 r
s
.829 .605 .384 r
.41517 .37851 m .40095 .40473 L .37901 .39642 L p F P
.534 .396 .246 r
s
.757 .55 .353 r
.40095 .40473 m .41517 .37851 L .43581 .3882 L p F P
.534 .396 .246 r
s
.757 .55 .353 r
.43581 .3882 m .42503 .41473 L .40095 .40473 L p F P
.534 .396 .246 r
s
.764 .558 .359 r
.40095 .40473 m .42503 .41473 L .41469 .43466 L p F P
.534 .396 .246 r
s
.73 .53 .342 r
.42934 .44108 m .41469 .43466 L .42503 .41473 L p F P
.534 .396 .246 r
s
.991 .733 .454 r
.54386 .45872 m .54753 .46549 L .51932 .49651 L p F P
.534 .396 .246 r
s
.814 .609 .393 r
.46651 .50815 m .46912 .50188 L .49244 .49759 L p F P
.534 .396 .246 r
s
.814 .609 .393 r
.49244 .49759 m .49187 .50752 L .46651 .50815 L p F P
.534 .396 .246 r
s
.712 .556 .367 r
.16725 .41821 m .14432 .41183 L .13725 .39941 L p F P
.534 .396 .246 r
s
.906 .663 .415 r
.39658 .36728 m .37901 .39642 L .35956 .3899 L p F P
.534 .396 .246 r
s
.829 .605 .384 r
.37901 .39642 m .39658 .36728 L .41517 .37851 L p F P
.534 .396 .246 r
s
.57 .458 .31 r
.66877 .32447 m .65439 .31859 L .67582 .32287 L p F P
.534 .396 .246 r
s
.57 .458 .31 r
.67582 .32287 m .69253 .3335 L .66877 .32447 L p F P
.534 .396 .246 r
s
.582 .453 .308 r
.68344 .33621 m .66877 .32447 L .69253 .3335 L p F P
.534 .396 .246 r
s
.582 .453 .308 r
.69253 .3335 m .70958 .34901 L .68344 .33621 L p F P
.534 .396 .246 r
s
.598 .459 .311 r
.69839 .35217 m .68344 .33621 L .70958 .34901 L p F P
.534 .396 .246 r
s
1 .777 .474 r
.5901 .352 m .60003 .34698 L .57919 .37397 L p F P
.534 .396 .246 r
s
1 .764 .463 r
.60003 .34698 m .5901 .352 L .60848 .33548 L p F P
.534 .396 .246 r
s
1 .764 .463 r
.60848 .33548 m .6204 .32825 L .60003 .34698 L p F P
.534 .396 .246 r
s
.86 .628 .396 r
.41394 .34052 m .39658 .36728 L .3804 .35603 L p F P
.534 .396 .246 r
s
.798 .581 .37 r
.39658 .36728 m .41394 .34052 L .4293 .35243 L p F P
.534 .396 .246 r
s
.798 .581 .37 r
.4293 .35243 m .41517 .37851 L .39658 .36728 L p F P
.534 .396 .246 r
s
.906 .663 .415 r
.35956 .3899 m .3804 .35603 L .39658 .36728 L p F P
.534 .396 .246 r
s
1 .785 .478 r
.35026 .42122 m .33178 .44319 L .31905 .44994 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.29915 .46925 m .31905 .44994 L .33178 .44319 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.29915 .46925 m .27976 .47882 L .26494 .48798 L p F P
.534 .396 .246 r
s
.194 .12 .075 r
.24469 .48791 m .26494 .48798 L .27976 .47882 L p F P
.534 .396 .246 r
s
.752 .546 .351 r
.41517 .37851 m .4293 .35243 L .44646 .36216 L p F P
.534 .396 .246 r
s
.752 .546 .351 r
.44646 .36216 m .43581 .3882 L .41517 .37851 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.6204 .32825 m .60848 .33548 L .6263 .32569 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.6263 .32569 m .64026 .31917 L .6204 .32825 L p F P
.534 .396 .246 r
s
.991 .733 .454 r
.51932 .49651 m .5178 .49043 L .54386 .45872 L p F P
.534 .396 .246 r
s
.479 .404 .267 r
.65947 .31901 m .67582 .32287 L .65439 .31859 L p F P
.534 .396 .246 r
s
.479 .404 .267 r
.65439 .31859 m .64026 .31917 L .65947 .31901 L p F P
.534 .396 .246 r
s
.827 .606 .386 r
.43102 .32139 m .41394 .34052 L .40077 .3283 L p F P
.534 .396 .246 r
s
.777 .567 .364 r
.41394 .34052 m .43102 .32139 L .44322 .33226 L p F P
.534 .396 .246 r
s
.777 .567 .364 r
.44322 .33226 m .4293 .35243 L .41394 .34052 L p F P
.534 .396 .246 r
s
.86 .628 .396 r
.3804 .35603 m .40077 .3283 L .41394 .34052 L p F P
.534 .396 .246 r
s
.598 .459 .311 r
.70958 .34901 m .72686 .36635 L .69839 .35217 L p F P
.534 .396 .246 r
s
.64 .489 .328 r
.71352 .36992 m .69839 .35217 L .72686 .36635 L p F P
.534 .396 .246 r
s
.958 .701 .433 r
.55794 .40576 m .56382 .41217 L .54013 .44919 L p F P
.534 .396 .246 r
s
.983 .721 .444 r
.56382 .41217 m .55794 .40576 L .57919 .37397 L p F P
.534 .396 .246 r
s
.958 .701 .433 r
.54386 .45872 m .54013 .44919 L .56382 .41217 L p F P
.534 .396 .246 r
s
.726 .526 .339 r
.42503 .41473 m .43581 .3882 L .45836 .39403 L p F P
.534 .396 .246 r
s
.726 .526 .339 r
.45836 .39403 m .45135 .42166 L .42503 .41473 L p F P
.534 .396 .246 r
s
.73 .53 .342 r
.44464 .44603 m .42934 .44108 L p .42503 .41473 L F P
.534 .396 .246 r
s
.73 .53 .342 r
.42503 .41473 m .45135 .42166 L .44464 .44603 L p F P
.534 .396 .246 r
s
.913 .671 .421 r
.35026 .42122 m .33927 .42228 L .35956 .3899 L p F P
.534 .396 .246 r
s
1 .785 .478 r
.31905 .44994 m .33927 .42228 L .35026 .42122 L p F P
.534 .396 .246 r
s
1 .741 .455 r
.57126 .3741 m .57919 .37397 L .55794 .40576 L p F P
.534 .396 .246 r
s
1 .777 .474 r
.57919 .37397 m .57126 .3741 L .5901 .352 L p F P
.534 .396 .246 r
s
.745 .543 .35 r
.4293 .35243 m .44322 .33226 L .45693 .3417 L p F P
.534 .396 .246 r
s
.745 .543 .35 r
.45693 .3417 m .44646 .36216 L .4293 .35243 L p F P
.534 .396 .246 r
s
.238 .144 .089 r
.21019 .47072 m .2308 .48366 L .24469 .48791 L p F P
.534 .396 .246 r
s
.482 .388 .27 r
.2308 .48366 m .21019 .47072 L .19823 .45372 L p F P
.534 .396 .246 r
s
.897 .661 .417 r
.42065 .3106 m .40077 .3283 L .3905 .31789 L p F P
.534 .396 .246 r
s
.827 .606 .386 r
.40077 .3283 m .42065 .3106 L .43102 .32139 L p F P
.534 .396 .246 r
s
.921 .675 .422 r
.36759 .34498 m .3905 .31789 L .40077 .3283 L p F P
.534 .396 .246 r
s
.921 .675 .422 r
.40077 .3283 m .3804 .35603 L .36759 .34498 L p F P
.534 .396 .246 r
s
.705 .514 .334 r
.438 .46464 m .44464 .44603 L .46059 .44799 L p F P
.534 .396 .246 r
s
.705 .514 .334 r
.46059 .44799 m .45587 .47001 L .438 .46464 L p F P
.534 .396 .246 r
s
.943 .69 .428 r
.3439 .3801 m .36759 .34498 L .3804 .35603 L p F P
.534 .396 .246 r
s
.943 .69 .428 r
.3804 .35603 m .35956 .3899 L .3439 .3801 L p F P
.534 .396 .246 r
s
.951 .698 .434 r
.54013 .44919 m .54386 .45872 L .5178 .49043 L p F P
.534 .396 .246 r
s
.733 .532 .343 r
.43581 .3882 m .44646 .36216 L .46522 .36876 L p F P
.534 .396 .246 r
s
.733 .532 .343 r
.46522 .36876 m .45836 .39403 L .43581 .3882 L p F P
.534 .396 .246 r
s
.64 .489 .328 r
.72686 .36635 m .74418 .38201 L .71352 .36992 L p F P
.534 .396 .246 r
s
.556 .45 .305 r
.76102 .3926 m .72846 .38647 L .71352 .36992 L p F P
.534 .396 .246 r
s
.556 .45 .305 r
.71352 .36992 m .74418 .38201 L .76102 .3926 L p F P
.534 .396 .246 r
s
.697 .565 .365 r
.26494 .48798 m .24469 .48791 L .2308 .48366 L p F P
.534 .396 .246 r
s
.725 .53 .344 r
.4512 .48568 m .45587 .47001 L .47444 .46948 L p F P
.534 .396 .246 r
s
.725 .53 .344 r
.47444 .46948 m .47176 .48878 L .4512 .48568 L p F P
.534 .396 .246 r
s
.808 .601 .387 r
.43102 .32139 m .42065 .3106 L p .43432 .29811 L F P
.534 .396 .246 r
s
.808 .601 .387 r
.43432 .29811 m .44783 .31275 L .43102 .32139 L p F P
.534 .396 .246 r
s
.716 .528 .345 r
.44322 .33226 m .43102 .32139 L .44783 .31275 L p F P
.534 .396 .246 r
s
.195 .121 .075 r
.64026 .31917 m .6263 .32569 L .64341 .32237 L p F P
.534 .396 .246 r
s
.195 .121 .075 r
.64341 .32237 m .65947 .31901 L .64026 .31917 L p F P
.534 .396 .246 r
s
.916 .677 .426 r
.49187 .50752 m .49244 .49759 L .51623 .47938 L p F P
.534 .396 .246 r
s
.916 .677 .426 r
.51623 .47938 m .5178 .49043 L .49187 .50752 L p F P
.534 .396 .246 r
s
.808 .601 .387 r
.42065 .3106 m .41269 .30196 L .43432 .29811 L p F P
.534 .396 .246 r
s
.897 .661 .417 r
.3905 .31789 m .41269 .30196 L .42065 .3106 L p F P
.534 .396 .246 r
s
.943 .69 .429 r
.3439 .3801 m .35956 .3899 L .33927 .42228 L p F P
.534 .396 .246 r
s
.794 .584 .375 r
.46912 .50188 m .47176 .48878 L .493 .48186 L p F P
.534 .396 .246 r
s
.794 .584 .375 r
.493 .48186 m .49244 .49759 L .46912 .50188 L p F P
.534 .396 .246 r
s
.732 .535 .346 r
.44646 .36216 m .45693 .3417 L .47192 .34933 L p F P
.534 .396 .246 r
s
.732 .535 .346 r
.47192 .34933 m .46522 .36876 L .44646 .36216 L p F P
.534 .396 .246 r
s
.999 .763 .463 r
.31905 .44994 m .29915 .46925 L .28594 .47612 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.26494 .48798 m .28594 .47612 L .29915 .46925 L p F P
.534 .396 .246 r
s
.699 .521 .343 r
.19003 .42764 m .16725 .41821 L .16196 .39329 L p F P
.534 .396 .246 r
s
.416 .335 .239 r
.16725 .41821 m .19003 .42764 L .19823 .45372 L p F P
.534 .396 .246 r
s
.712 .556 .367 r
.13725 .39941 m .16196 .39329 L .16725 .41821 L p F P
.534 .396 .246 r
s
.716 .528 .345 r
.45693 .3417 m .44322 .33226 L p .44783 .31275 L F P
.534 .396 .246 r
s
.958 .702 .434 r
.55204 .39933 m .55794 .40576 L .53637 .43752 L p F P
.534 .396 .246 r
s
1 .741 .455 r
.55794 .40576 m .55204 .39933 L .57126 .3741 L p F P
.534 .396 .246 r
s
.958 .701 .433 r
.54013 .44919 m .53637 .43752 L .55794 .40576 L p F P
.534 .396 .246 r
s
.737 .535 .344 r
.46059 .44799 m .44464 .44603 L .45135 .42166 L p F P
.534 .396 .246 r
s
.951 .698 .434 r
.5178 .49043 m .51623 .47938 L .54013 .44919 L p F P
.534 .396 .246 r
s
1 .779 .471 r
.58014 .35844 m .5901 .352 L .57126 .3741 L p F P
.534 .396 .246 r
s
.793 .621 .369 r
.5901 .352 m .58014 .35844 L .59655 .34543 L p F P
.534 .396 .246 r
s
.793 .621 .369 r
.59655 .34543 m .60848 .33548 L .5901 .352 L p F P
.534 .396 .246 r
s
.985 .736 .46 r
.41269 .30196 m .3905 .31789 L .3841 .31085 L p F P
.534 .396 .246 r
s
.983 .725 .449 r
.35952 .33466 m .3841 .31085 L .3905 .31789 L p F P
.534 .396 .246 r
s
.983 .725 .449 r
.3905 .31789 m .36759 .34498 L .35952 .33466 L p F P
.534 .396 .246 r
s
.923 .675 .421 r
.53637 .43752 m .54013 .44919 L .51623 .47938 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.60848 .33548 m .59655 .34543 L .6124 .33658 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.6124 .33658 m .6263 .32569 L .60848 .33548 L p F P
.534 .396 .246 r
s
.943 .69 .429 r
.33927 .42228 m .32934 .42115 L p .3439 .3801 L F P
.534 .396 .246 r
s
1 .767 .47 r
.30751 .45284 m .32934 .42115 L .33927 .42228 L p F P
.534 .396 .246 r
s
1 .767 .47 r
.33927 .42228 m .31905 .44994 L .30751 .45284 L p F P
.534 .396 .246 r
s
.739 .537 .346 r
.45135 .42166 m .45836 .39403 L .48262 .39429 L p F P
.534 .396 .246 r
s
.739 .537 .346 r
.48262 .39429 m .47977 .41996 L .45135 .42166 L p F P
.534 .396 .246 r
s
.737 .535 .344 r
.47711 .44571 m .46059 .44799 L p .45135 .42166 L F P
.534 .396 .246 r
s
.737 .535 .344 r
.45135 .42166 m .47977 .41996 L .47711 .44571 L p F P
.534 .396 .246 r
s
1 .758 .465 r
.56329 .37475 m .57126 .3741 L .55204 .39933 L p F P
.534 .396 .246 r
s
1 .779 .471 r
.57126 .3741 m .56329 .37475 L .58014 .35844 L p F P
.534 .396 .246 r
s
.999 .763 .463 r
.28594 .47612 m .30751 .45284 L .31905 .44994 L p F P
.534 .396 .246 r
s
.734 .534 .344 r
.45587 .47001 m .46059 .44799 L .47711 .44571 L p F P
.534 .396 .246 r
s
.734 .534 .344 r
.47711 .44571 m .47444 .46948 L .45587 .47001 L p F P
.534 .396 .246 r
s
.868 .679 .432 r
.41269 .30196 m .40781 .29692 L p .43011 .29365 L F P
.534 .396 .246 r
s
.868 .679 .432 r
.43432 .29811 m .41269 .30196 L p .42585 .29568 L F P
.534 .396 .246 r
s
.868 .679 .432 r
.43205 .29571 m .43432 .29811 L p .42585 .29568 L F P
.534 .396 .246 r
s
.868 .679 .432 r
.40781 .29692 m .40668 .29548 L .43011 .29365 L p F P
.534 .396 .246 r
s
.503 .42 .284 r
.45679 .30589 m .43432 .29811 L .43011 .29365 L p F P
.534 .396 .246 r
s
.232 .14 .087 r
.43762 .29783 m .40815 .29559 L .40965 .29647 L F
.40668 .29548 m .40699 .29558 L p .40815 .29559 L F P
.534 .396 .246 r
s
.232 .14 .087 r
.40699 .29558 m .40965 .29647 L p .40815 .29559 L F P
.534 .396 .246 r
s
.868 .679 .432 r
.43011 .29365 m .43205 .29571 L p .42585 .29568 L F P
.534 .396 .246 r
s
.985 .736 .46 r
.3841 .31085 m .40781 .29692 L .41269 .30196 L p F P
.534 .396 .246 r
s
.744 .543 .35 r
.45836 .39403 m .46522 .36876 L .48535 .37227 L p F P
.534 .396 .246 r
s
.744 .543 .35 r
.48535 .37227 m .48262 .39429 L .45836 .39403 L p F P
.534 .396 .246 r
s
.961 .704 .435 r
.33402 .36442 m .35952 .33466 L .36759 .34498 L p F P
.534 .396 .246 r
s
.961 .704 .435 r
.36759 .34498 m .3439 .3801 L .33402 .36442 L p F P
.534 .396 .246 r
s
.716 .528 .345 r
.44783 .31275 m .46724 .32981 L .45693 .3417 L p F P
.534 .396 .246 r
s
.654 .489 .325 r
.47192 .34933 m .45693 .3417 L .46724 .32981 L p F P
.534 .396 .246 r
s
.639 .479 .319 r
.22006 .46568 m .19823 .45372 L .19003 .42764 L p F P
.534 .396 .246 r
s
.482 .388 .27 r
.19823 .45372 m .22006 .46568 L .2308 .48366 L p F P
.534 .396 .246 r
s
.782 .571 .365 r
.47176 .48878 m .47444 .46948 L .49355 .46155 L p F P
.534 .396 .246 r
s
.782 .571 .365 r
.49355 .46155 m .493 .48186 L .47176 .48878 L p F P
.534 .396 .246 r
s
.87 .637 .402 r
.49244 .49759 m .493 .48186 L .51463 .46418 L p F P
.534 .396 .246 r
s
.87 .637 .402 r
.51463 .46418 m .51623 .47938 L .49244 .49759 L p F P
.534 .396 .246 r
s
.74 .544 .353 r
.46522 .36876 m .47192 .34933 L .48798 .35564 L p F P
.534 .396 .246 r
s
.74 .544 .353 r
.48798 .35564 m .48535 .37227 L .46522 .36876 L p F P
.534 .396 .246 r
s
.859 .633 .402 r
.16196 .39329 m .13725 .39941 L .13591 .37478 L p F P
.534 .396 .246 r
s
.903 .664 .418 r
.13591 .37478 m .13725 .39941 L .11239 .41269 L p F P
.534 .396 .246 r
s
.904 .66 .412 r
.53257 .42444 m .53637 .43752 L .51463 .46418 L p F P
.534 .396 .246 r
s
.958 .702 .434 r
.53637 .43752 m .53257 .42444 L .55204 .39933 L p F P
.534 .396 .246 r
s
.923 .675 .421 r
.51623 .47938 m .51463 .46418 L .53637 .43752 L p F P
.534 .396 .246 r
s
.958 .703 .436 r
.54612 .39286 m .55204 .39933 L .53257 .42444 L p F P
.534 .396 .246 r
s
1 .758 .465 r
.55204 .39933 m .54612 .39286 L .56329 .37475 L p F P
.534 .396 .246 r
s
.281 .166 .103 r
.67582 .32287 m .65947 .31901 L .67777 .32522 L p F P
.534 .396 .246 r
s
.368 .293 .212 r
.69253 .3335 m .67582 .32287 L .69637 .33445 L p F P
.534 .396 .246 r
s
.281 .166 .103 r
.67777 .32522 m .69637 .33445 L .67582 .32287 L p F P
.534 .396 .246 r
s
.21 .129 .08 r
.6263 .32569 m .6124 .33658 L .62752 .33191 L p F P
.534 .396 .246 r
s
.21 .129 .08 r
.62752 .33191 m .64341 .32237 L .6263 .32569 L p F P
.534 .396 .246 r
s
.903 .664 .418 r
.11239 .41269 m .10986 .39682 L .13591 .37478 L p F P
.534 .396 .246 r
s
.666 .513 .342 r
.46524 .31484 m .44783 .31275 L .43432 .29811 L p F P
.534 .396 .246 r
s
.636 .484 .325 r
.44783 .31275 m .46524 .31484 L .47791 .32692 L p F P
.534 .396 .246 r
s
.636 .484 .325 r
.47791 .32692 m .46724 .32981 L .44783 .31275 L p F P
.534 .396 .246 r
s
.368 .293 .212 r
.69637 .33445 m .71543 .35003 L .69253 .3335 L p F P
.534 .396 .246 r
s
.389 .311 .225 r
.70958 .34901 m .69253 .3335 L .71543 .35003 L p F P
.534 .396 .246 r
s
.769 .562 .361 r
.18602 .3943 m .16196 .39329 L .16158 .36121 L p F P
.534 .396 .246 r
s
.699 .521 .343 r
.16196 .39329 m .18602 .3943 L .19003 .42764 L p F P
.534 .396 .246 r
s
.859 .633 .402 r
.13591 .37478 m .16158 .36121 L .16196 .39329 L p F P
.534 .396 .246 r
s
.993 .754 .472 r
.28594 .47612 m .26494 .48798 L .25234 .4849 L p F P
.534 .396 .246 r
s
.697 .565 .365 r
.2308 .48366 m .25234 .4849 L .26494 .48798 L p F P
.534 .396 .246 r
s
.298 .174 .108 r
.65947 .31901 m .64341 .32237 L .6596 .32406 L p F P
.534 .396 .246 r
s
.298 .174 .108 r
.6596 .32406 m .67777 .32522 L .65947 .31901 L p F P
.534 .396 .246 r
s
.776 .564 .361 r
.47444 .46948 m .47711 .44571 L .49409 .43852 L p F P
.534 .396 .246 r
s
.776 .564 .361 r
.49409 .43852 m .49355 .46155 L .47444 .46948 L p F P
.534 .396 .246 r
s
.89 .65 .408 r
.52876 .4108 m .53257 .42444 L .513 .44608 L p F P
.534 .396 .246 r
s
.958 .703 .436 r
.53257 .42444 m .52876 .4108 L .54612 .39286 L p F P
.534 .396 .246 r
s
.904 .66 .412 r
.51463 .46418 m .513 .44608 L .53257 .42444 L p F P
.534 .396 .246 r
s
.844 .615 .389 r
.513 .44608 m .51463 .46418 L .493 .48186 L p F P
.534 .396 .246 r
s
.844 .615 .389 r
.493 .48186 m .49355 .46155 L .513 .44608 L p F P
.534 .396 .246 r
s
.792 .578 .369 r
.49409 .43852 m .47711 .44571 L .47977 .41996 L p F P
.534 .396 .246 r
s
.804 .588 .375 r
.47977 .41996 m .48262 .39429 L .5081 .38891 L p F P
.534 .396 .246 r
s
.804 .588 .375 r
.5081 .38891 m .5097 .40718 L .47977 .41996 L p F P
.534 .396 .246 r
s
.792 .578 .369 r
.51136 .42657 m .49409 .43852 L p .47977 .41996 L F P
.534 .396 .246 r
s
.792 .578 .369 r
.47977 .41996 m .5097 .40718 L .51136 .42657 L p F P
.534 .396 .246 r
s
.654 .489 .325 r
.48798 .35564 m .47192 .34933 L p .46724 .32981 L F P
.534 .396 .246 r
s
.943 .69 .429 r
.32934 .42115 m .32084 .41605 L .3439 .3801 L p F P
.534 .396 .246 r
s
.98 .72 .445 r
.29767 .44868 m .32084 .41605 L .32934 .42115 L p F P
.534 .396 .246 r
s
.98 .72 .445 r
.32934 .42115 m .30751 .45284 L .29767 .44868 L p F P
.534 .396 .246 r
s
.986 .759 .467 r
.40781 .29692 m .3841 .31085 L .38248 .30758 L p F P
.534 .396 .246 r
s
1 .784 .479 r
.35739 .32708 m .38248 .30758 L .3841 .31085 L p F P
.534 .396 .246 r
s
1 .784 .479 r
.3841 .31085 m .35952 .33466 L .35739 .32708 L p F P
.534 .396 .246 r
s
.77 .579 .377 r
.25234 .4849 m .2308 .48366 L .22006 .46568 L p F P
.534 .396 .246 r
s
.962 .703 .435 r
.33402 .36442 m .3439 .3801 L .32084 .41605 L p F P
.534 .396 .246 r
s
.986 .759 .467 r
.38248 .30758 m .40668 .29548 L .40781 .29692 L p F P
.534 .396 .246 r
s
.389 .311 .225 r
.71543 .35003 m .73482 .36864 L .70958 .34901 L p F P
.534 .396 .246 r
s
.405 .326 .233 r
.72686 .36635 m .70958 .34901 L .73482 .36864 L p F P
.534 .396 .246 r
s
.797 .586 .376 r
.48262 .39429 m .48535 .37227 L .50647 .37341 L p F P
.534 .396 .246 r
s
.797 .586 .376 r
.50647 .37341 m .5081 .38891 L .48262 .39429 L p F P
.534 .396 .246 r
s
.699 .513 .335 r
.21299 .43598 m .19003 .42764 L .18602 .3943 L p F P
.534 .396 .246 r
s
.639 .479 .319 r
.19003 .42764 m .21299 .43598 L .22006 .46568 L p F P
.534 .396 .246 r
s
.795 .626 .376 r
.56329 .37475 m .54612 .39286 L .54017 .38637 L p F P
.534 .396 .246 r
s
.795 .626 .376 r
.58014 .35844 m .56329 .37475 L p .54017 .38637 L F P
.534 .396 .246 r
s
.666 .513 .342 r
.43432 .29811 m .45679 .30589 L .46524 .31484 L p F P
.534 .396 .246 r
s
.929 .72 .438 r
.55968 .36987 m .57011 .36481 L .56611 .36769 L p F P
.534 .396 .246 r
s
.929 .72 .438 r
.56611 .36769 m .54017 .38637 L p .55968 .36987 L F P
.534 .396 .246 r
s
.819 .651 .403 r
.54924 .37222 m .55968 .36987 L .55451 .37186 L p F P
.534 .396 .246 r
s
.819 .651 .403 r
.55451 .37186 m .53409 .37973 L p .54924 .37222 L F P
.534 .396 .246 r
s
.819 .651 .403 r
.53409 .37973 m .52801 .3731 L .54924 .37222 L p F P
.534 .396 .246 r
s
.658 .54 .345 r
.53881 .37127 m .54924 .37222 L .53944 .37263 L p F P
.534 .396 .246 r
s
.658 .54 .345 r
.53944 .37263 m .52801 .3731 L p .53724 .37154 L F P
.534 .396 .246 r
s
.658 .54 .345 r
.53881 .37127 m .53944 .37263 L .53724 .37154 L F
.37 .221 .134 r
.53881 .37127 m .52193 .36647 L .51587 .35985 L p F P
.534 .396 .246 r
s
.247 .148 .092 r
.52511 .36514 m .53284 .36935 L p .5179 .36099 L F P
.534 .396 .246 r
s
.658 .54 .345 r
.52801 .3731 m .52193 .36647 L .53881 .37127 L p F P
.534 .396 .246 r
s
.247 .148 .092 r
.53417 .37001 m .51587 .35985 L p .53284 .36935 L F P
.534 .396 .246 r
s
.195 .121 .075 r
.54924 .37222 m .53881 .37127 L .5438 .3726 L p F P
.534 .396 .246 r
s
.929 .72 .438 r
.54017 .38637 m .53409 .37973 L .55968 .36987 L p F P
.534 .396 .246 r
s
.195 .121 .075 r
.5438 .3726 m .55471 .37549 L p .54924 .37222 L F P
.534 .396 .246 r
s
.37 .221 .134 r
.51689 .36036 m .53357 .36703 L .53881 .37127 L F
.51674 .3602 m .55471 .37549 L .51689 .36036 L F
.55471 .37549 m .54036 .37168 L p .53357 .36703 L F P
.534 .396 .246 r
s
.37 .221 .134 r
.54036 .37168 m .53881 .37127 L p .53357 .36703 L F P
.534 .396 .246 r
s
.37 .221 .134 r
.51587 .35985 m .51674 .3602 L .51689 .36036 L F
.51587 .35985 m .5402 .37336 L .55471 .37549 L p F P
.534 .396 .246 r
s
.285 .167 .104 r
.5402 .37336 m .52511 .36514 L .53688 .37408 L p F P
.534 .396 .246 r
s
.374 .222 .135 r
.50517 .34783 m .5284 .36704 L .52511 .36514 L F
.50405 .34685 m .50499 .34763 L .50517 .34783 L F
.50499 .34763 m .5284 .36704 L .50517 .34783 L F
.50397 .34676 m .5284 .36704 L .50405 .34685 L F
.53688 .37408 m .52511 .36514 L p .5284 .36704 L F P
.534 .396 .246 r
s
.374 .222 .135 r
.52511 .36514 m .50963 .35304 L .50357 .34644 L p F P
.534 .396 .246 r
s
.374 .222 .135 r
.51646 .35815 m .53688 .37408 L p .50397 .34676 L F P
.534 .396 .246 r
s
.288 .22 .168 r
.51803 .35904 m .51646 .35815 L p .49954 .34182 L F P
.534 .396 .246 r
s
.288 .22 .168 r
.49778 .34011 m .49913 .34138 L p .49954 .34182 L F P
.534 .396 .246 r
s
.288 .22 .168 r
.49913 .34138 m .51803 .35904 L p .49954 .34182 L F P
.534 .396 .246 r
s
.374 .222 .135 r
.50357 .34644 m .50397 .34676 L .50405 .34685 L F
.50357 .34644 m .50383 .34667 L p .50397 .34676 L F P
.534 .396 .246 r
s
.374 .222 .135 r
.50383 .34667 m .51646 .35815 L p .50397 .34676 L F P
.534 .396 .246 r
s
.247 .148 .092 r
.52511 .36514 m .5179 .36099 L .51587 .35985 L F
.53284 .36935 m .5402 .37336 L .53417 .37001 L p F P
.534 .396 .246 r
s
.158 .102 .063 r
.55968 .36987 m .54924 .37222 L .5531 .37209 L p F P
.534 .396 .246 r
s
.795 .626 .376 r
.54017 .38637 m .57011 .36481 L p .57571 .36153 L F P
.534 .396 .246 r
s
.158 .102 .063 r
.5531 .37209 m .56928 .37155 L p .55968 .36987 L F P
.534 .396 .246 r
s
.116 .08 .05 r
.57011 .36481 m .55968 .36987 L .56351 .36866 L p F P
.534 .396 .246 r
s
.116 .08 .05 r
.56351 .36866 m .58387 .36228 L p .57011 .36481 L F P
.534 .396 .246 r
s
.795 .626 .376 r
.57011 .36481 m .58014 .35844 L p .57571 .36153 L F P
.534 .396 .246 r
s
.134 .089 .055 r
.59655 .34543 m .58014 .35844 L .57011 .36481 L p F P
.534 .396 .246 r
s
.829 .604 .382 r
.49355 .46155 m .49409 .43852 L .51136 .42657 L p F P
.534 .396 .246 r
s
.829 .604 .382 r
.51136 .42657 m .513 .44608 L .49355 .46155 L p F P
.534 .396 .246 r
s
.89 .65 .408 r
.513 .44608 m .51136 .42657 L .52876 .4108 L p F P
.534 .396 .246 r
s
.944 .701 .44 r
.54612 .39286 m .52876 .4108 L p .5097 .40718 L F P
.534 .396 .246 r
s
.944 .701 .44 r
.5097 .40718 m .54017 .38637 L .54612 .39286 L p F P
.534 .396 .246 r
s
.794 .578 .368 r
.18624 .35777 m .16158 .36121 L .16584 .32674 L p F P
.534 .396 .246 r
s
.769 .562 .361 r
.16158 .36121 m .18624 .35777 L .18602 .3943 L p F P
.534 .396 .246 r
s
.863 .63 .397 r
.14018 .34129 m .16584 .32674 L .16158 .36121 L p F P
.534 .396 .246 r
s
.863 .63 .397 r
.16158 .36121 m .13591 .37478 L .14018 .34129 L p F P
.534 .396 .246 r
s
.58 .452 .307 r
.46724 .32981 m .47791 .32692 L .4932 .33985 L p F P
.534 .396 .246 r
s
.58 .452 .307 r
.4932 .33985 m .49052 .345 L .46724 .32981 L p F P
.534 .396 .246 r
s
.654 .489 .325 r
.46724 .32981 m .49052 .345 L .48798 .35564 L p F P
.534 .396 .246 r
s
.134 .089 .055 r
.6124 .33658 m .59655 .34543 L p .57011 .36481 L F P
.534 .396 .246 r
s
.944 .701 .44 r
.52876 .4108 m .51136 .42657 L .5097 .40718 L p F P
.534 .396 .246 r
s
.773 .575 .373 r
.48535 .37227 m .48798 .35564 L .50479 .36124 L p F P
.534 .396 .246 r
s
.773 .575 .373 r
.50479 .36124 m .50647 .37341 L .48535 .37227 L p F P
.534 .396 .246 r
s
.728 .529 .342 r
.20976 .39944 m .18602 .3943 L .18624 .35777 L p F P
.534 .396 .246 r
s
.699 .513 .335 r
.18602 .3943 m .20976 .39944 L .21299 .43598 L p F P
.534 .396 .246 r
s
1 .746 .462 r
.30751 .45284 m .28594 .47612 L .27472 .47284 L p F P
.534 .396 .246 r
s
.993 .754 .472 r
.25234 .4849 m .27472 .47284 L .28594 .47612 L p F P
.534 .396 .246 r
s
.813 .593 .377 r
.19034 .32374 m .16584 .32674 L .17404 .29675 L p F P
.534 .396 .246 r
s
.794 .578 .368 r
.16584 .32674 m .19034 .32374 L .18624 .35777 L p F P
.534 .396 .246 r
s
.88 .642 .403 r
.14917 .30757 m .17404 .29675 L .16584 .32674 L p F P
.534 .396 .246 r
s
.88 .642 .403 r
.16584 .32674 m .14018 .34129 L .14917 .30757 L p F P
.534 .396 .246 r
s
1 .746 .462 r
.27472 .47284 m .29767 .44868 L .30751 .45284 L p F P
.534 .396 .246 r
s
.744 .54 .348 r
.21022 .36232 m .18624 .35777 L .19034 .32374 L p F P
.534 .396 .246 r
s
.728 .529 .342 r
.18624 .35777 m .21022 .36232 L .20976 .39944 L p F P
.534 .396 .246 r
s
.287 .172 .109 r
.64341 .32237 m .62752 .33191 L .64174 .3307 L p F P
.534 .396 .246 r
s
.287 .172 .109 r
.64174 .3307 m .6596 .32406 L .64341 .32237 L p F P
.534 .396 .246 r
s
.905 .66 .412 r
.14018 .34129 m .13591 .37478 L .10986 .39682 L p F P
.534 .396 .246 r
s
1 .747 .46 r
.33145 .3487 m .35739 .32708 L .35952 .33466 L p F P
.534 .396 .246 r
s
1 .747 .46 r
.35952 .33466 m .33402 .36442 L .33145 .3487 L p F P
.534 .396 .246 r
s
.405 .326 .233 r
.73482 .36864 m .75433 .38604 L .72686 .36635 L p F P
.534 .396 .246 r
s
.411 .334 .235 r
.74418 .38201 m .72686 .36635 L .75433 .38604 L p F P
.534 .396 .246 r
s
.944 .701 .44 r
.5097 .40718 m .5081 .38891 L .53409 .37973 L p F P
.534 .396 .246 r
s
.944 .701 .44 r
.53409 .37973 m .54017 .38637 L .5097 .40718 L p F P
.534 .396 .246 r
s
.753 .549 .353 r
.21401 .33059 m .19034 .32374 L .1978 .29766 L p F P
.534 .396 .246 r
s
.744 .54 .348 r
.19034 .32374 m .21401 .33059 L .21022 .36232 L p F P
.534 .396 .246 r
s
.813 .593 .377 r
.17404 .29675 m .1978 .29766 L .19034 .32374 L p F P
.534 .396 .246 r
s
.134 .089 .055 r
.57011 .36481 m .59845 .34955 L .6124 .33658 L p F P
.534 .396 .246 r
s
.214 .132 .083 r
.62752 .33191 m .6124 .33658 L .59845 .34955 L p F P
.534 .396 .246 r
s
.834 .614 .392 r
.1978 .29766 m .17404 .29675 L .18549 .27702 L p F P
.534 .396 .246 r
s
.922 .679 .426 r
.16185 .2819 m .18549 .27702 L .17404 .29675 L p F P
.534 .396 .246 r
s
.922 .679 .426 r
.17404 .29675 m .14917 .30757 L .16185 .2819 L p F P
.534 .396 .246 r
s
.911 .683 .434 r
.5081 .38891 m .50647 .37341 L .52801 .3731 L p F P
.534 .396 .246 r
s
.911 .683 .434 r
.52801 .3731 m .53409 .37973 L .5081 .38891 L p F P
.534 .396 .246 r
s
.458 .375 .261 r
.50479 .36124 m .48798 .35564 L .49052 .345 L p F P
.534 .396 .246 r
s
.962 .703 .435 r
.32084 .41605 m .31411 .4064 L p .33402 .36442 L F P
.534 .396 .246 r
s
.926 .676 .42 r
.28999 .43629 m .31411 .4064 L .32084 .41605 L p F P
.534 .396 .246 r
s
.926 .676 .42 r
.32084 .41605 m .29767 .44868 L .28999 .43629 L p F P
.534 .396 .246 r
s
.364 .217 .132 r
.79222 .40214 m .76102 .3926 L .74418 .38201 L p F P
.534 .396 .246 r
s
.364 .217 .132 r
.74418 .38201 m .77367 .39815 L .79222 .40214 L p F P
.534 .396 .246 r
s
.411 .334 .235 r
.75433 .38604 m .77367 .39815 L .74418 .38201 L p F P
.534 .396 .246 r
s
.733 .538 .349 r
.24269 .46771 m .22006 .46568 L .21299 .43598 L p F P
.534 .396 .246 r
s
.77 .579 .377 r
.22006 .46568 m .24269 .46771 L .25234 .4849 L p F P
.534 .396 .246 r
s
.933 .682 .424 r
.14917 .30757 m .14018 .34129 L .11402 .36504 L p F P
.534 .396 .246 r
s
.905 .66 .412 r
.10986 .39682 m .11402 .36504 L .14018 .34129 L p F P
.534 .396 .246 r
s
.745 .55 .357 r
.22076 .30858 m .1978 .29766 L .20814 .28328 L p F P
.534 .396 .246 r
s
.753 .549 .353 r
.1978 .29766 m .22076 .30858 L .21401 .33059 L p F P
.534 .396 .246 r
s
.834 .614 .392 r
.18549 .27702 m .20814 .28328 L .1978 .29766 L p F P
.534 .396 .246 r
s
.725 .526 .34 r
.23396 .37023 m .21022 .36232 L .21401 .33059 L p F P
.534 .396 .246 r
s
.724 .525 .339 r
.21022 .36232 m .23396 .37023 L .23356 .40414 L p F P
.534 .396 .246 r
s
.724 .525 .339 r
.23356 .40414 m .20976 .39944 L .21022 .36232 L p F P
.534 .396 .246 r
s
.232 .14 .087 r
.43762 .29783 m .43011 .29365 L .40668 .29548 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.38614 .30716 m .40965 .29647 L .40668 .29548 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.40668 .29548 m .38248 .30758 L .38614 .30716 L p F P
.534 .396 .246 r
s
.867 .64 .406 r
.27472 .47284 m .25234 .4849 L .24269 .46771 L p F P
.534 .396 .246 r
s
.72 .525 .341 r
.23734 .34267 m .21401 .33059 L .22076 .30858 L p F P
.534 .396 .246 r
s
.725 .526 .34 r
.21401 .33059 m .23734 .34267 L .23396 .37023 L p F P
.534 .396 .246 r
s
.116 .08 .05 r
.58387 .36228 m .59845 .34955 L .57011 .36481 L p F P
.534 .396 .246 r
s
.826 .631 .408 r
.50647 .37341 m .50479 .36124 L .52193 .36647 L p F P
.534 .396 .246 r
s
.826 .631 .408 r
.52193 .36647 m .52801 .3731 L .50647 .37341 L p F P
.534 .396 .246 r
s
1 .744 .459 r
.16185 .2819 m .14917 .30757 L .12376 .32786 L p F P
.534 .396 .246 r
s
.933 .682 .424 r
.11402 .36504 m .12376 .32786 L .14917 .30757 L p F P
.534 .396 .246 r
s
.723 .526 .34 r
.20976 .39944 m .23356 .40414 L .2364 .43888 L p F P
.534 .396 .246 r
s
.723 .526 .34 r
.2364 .43888 m .21299 .43598 L .20976 .39944 L p F P
.534 .396 .246 r
s
.733 .538 .349 r
.21299 .43598 m .2364 .43888 L .24269 .46771 L p F P
.534 .396 .246 r
s
1 .747 .46 r
.33145 .3487 m .33402 .36442 L .30943 .39325 L p F P
.534 .396 .246 r
s
.962 .703 .435 r
.31411 .4064 m .30943 .39325 L .33402 .36442 L p F P
.534 .396 .246 r
s
.716 .568 .337 r
.38248 .30758 m .35739 .32708 L .3618 .32357 L p F P
.534 .396 .246 r
s
.716 .568 .337 r
.3618 .32357 m .38614 .30716 L .38248 .30758 L p F P
.534 .396 .246 r
s
.324 .188 .117 r
.67777 .32522 m .6596 .32406 L .67457 .3284 L p F P
.534 .396 .246 r
s
.324 .188 .117 r
.67457 .3284 m .69478 .33419 L .67777 .32522 L p F P
.534 .396 .246 r
s
.296 .174 .108 r
.69637 .33445 m .67777 .32522 L .69478 .33419 L p F P
.534 .396 .246 r
s
.409 .329 .236 r
.46524 .31484 m .45679 .30589 L .47789 .32152 L p F P
.534 .396 .246 r
s
.409 .329 .236 r
.47791 .32692 m .46524 .31484 L p .47789 .32152 L F P
.534 .396 .246 r
s
.214 .132 .083 r
.64174 .3307 m .62752 .33191 L p .59845 .34955 L F P
.534 .396 .246 r
s
.905 .663 .415 r
.26607 .45774 m .28999 .43629 L .29767 .44868 L p F P
.534 .396 .246 r
s
.905 .663 .415 r
.29767 .44868 m .27472 .47284 L .26607 .45774 L p F P
.534 .396 .246 r
s
.334 .262 .194 r
.71543 .35003 m .69637 .33445 L .71556 .34828 L p F P
.534 .396 .246 r
s
.296 .174 .108 r
.69478 .33419 m .71556 .34828 L .69637 .33445 L p F P
.534 .396 .246 r
s
.888 .646 .404 r
.28478 .41734 m .30943 .39325 L .31411 .4064 L p F P
.534 .396 .246 r
s
.888 .646 .404 r
.31411 .4064 m .28999 .43629 L .28478 .41734 L p F P
.534 .396 .246 r
s
.503 .42 .284 r
.43011 .29365 m .45444 .30311 L .45679 .30589 L p F P
.534 .396 .246 r
s
.25 .15 .093 r
.45444 .30311 m .43011 .29365 L .43762 .29783 L p F P
.534 .396 .246 r
s
.809 .615 .398 r
.20814 .28328 m .18549 .27702 L .19969 .27053 L p F P
.534 .396 .246 r
s
.969 .735 .462 r
.17749 .26911 m .19969 .27053 L .18549 .27702 L p F P
.534 .396 .246 r
s
.969 .735 .462 r
.18549 .27702 m .16185 .2819 L .17749 .26911 L p F P
.534 .396 .246 r
s
.306 .18 .113 r
.6596 .32406 m .64174 .3307 L .65481 .33165 L p F P
.534 .396 .246 r
s
.306 .18 .113 r
.65481 .33165 m .67457 .3284 L .6596 .32406 L p F P
.534 .396 .246 r
s
.321 .252 .185 r
.45679 .30589 m .45444 .30311 L p .47925 .32223 L F P
.534 .396 .246 r
s
.321 .252 .185 r
.47925 .32223 m .47789 .32152 L .45679 .30589 L p F P
.534 .396 .246 r
s
.867 .64 .406 r
.24269 .46771 m .26607 .45774 L .27472 .47284 L p F P
.534 .396 .246 r
s
.458 .375 .261 r
.49052 .345 m .4932 .33985 L .50963 .35304 L p F P
.534 .396 .246 r
s
.458 .375 .261 r
.50963 .35304 m .51587 .35985 L .49052 .345 L p F P
.534 .396 .246 r
s
.458 .375 .261 r
.52193 .36647 m .50479 .36124 L p .49052 .345 L F P
.534 .396 .246 r
s
.458 .375 .261 r
.49052 .345 m .51587 .35985 L .52193 .36647 L p F P
.534 .396 .246 r
s
.689 .511 .336 r
.24339 .32485 m .22076 .30858 L .23014 .29851 L p F P
.534 .396 .246 r
s
.72 .525 .341 r
.22076 .30858 m .24339 .32485 L .23734 .34267 L p F P
.534 .396 .246 r
s
.745 .55 .357 r
.20814 .28328 m .23014 .29851 L .22076 .30858 L p F P
.534 .396 .246 r
s
.409 .329 .236 r
.47789 .32152 m .48808 .33186 L .47791 .32692 L p F P
.534 .396 .246 r
s
.297 .228 .173 r
.4932 .33985 m .47791 .32692 L .48808 .33186 L p F P
.534 .396 .246 r
s
.92 .715 .435 r
.17749 .26911 m .16185 .2819 L .13768 .29642 L p F P
.534 .396 .246 r
s
1 .744 .459 r
.12376 .32786 m .13768 .29642 L .16185 .2819 L p F P
.534 .396 .246 r
s
.964 .74 .447 r
.33672 .33987 m .3618 .32357 L .35739 .32708 L p F P
.534 .396 .246 r
s
.991 .76 .464 r
.30672 .36566 m .30871 .35556 L p .33672 .33987 L F P
.534 .396 .246 r
s
.991 .76 .464 r
.31289 .34936 m .33672 .33987 L p .31607 .35144 L F P
.534 .396 .246 r
s
.991 .76 .464 r
.30871 .35556 m .31289 .34936 L p .31607 .35144 L F P
.534 .396 .246 r
s
.851 .667 .426 r
.29632 .34612 m .30855 .34653 L p .31289 .34936 L F P
.534 .396 .246 r
s
.095 .069 .043 r
.33672 .33987 m .31289 .34936 L p .32898 .34434 L F P
.534 .396 .246 r
s
.851 .667 .426 r
.30855 .34653 m .31915 .34689 L .31289 .34936 L p F P
.534 .396 .246 r
s
.964 .74 .447 r
.35403 .32988 m .33145 .3487 L .33672 .33987 L p F P
.534 .396 .246 r
s
.991 .76 .464 r
.33672 .33987 m .33145 .3487 L .30672 .36566 L p F P
.534 .396 .246 r
s
.095 .069 .043 r
.34951 .33794 m .33672 .33987 L p .32898 .34434 L F P
.534 .396 .246 r
s
.964 .74 .447 r
.35739 .32708 m .35403 .32988 L p .33672 .33987 L F P
.534 .396 .246 r
s
.794 .579 .37 r
.26607 .45774 m .24269 .46771 L .2364 .43888 L p F P
.534 .396 .246 r
s
.651 .498 .333 r
.23014 .29851 m .20814 .28328 L .22106 .28194 L p F P
.534 .396 .246 r
s
.809 .615 .398 r
.19969 .27053 m .22106 .28194 L .20814 .28328 L p F P
.534 .396 .246 r
s
.739 .537 .346 r
.25786 .37601 m .23396 .37023 L .23734 .34267 L p F P
.534 .396 .246 r
s
.747 .542 .348 r
.23396 .37023 m .25786 .37601 L .25767 .40386 L p F P
.534 .396 .246 r
s
.747 .542 .348 r
.25767 .40386 m .23356 .40414 L .23396 .37023 L p F P
.534 .396 .246 r
s
.334 .262 .194 r
.71556 .34828 m .73684 .36765 L .71543 .35003 L p F P
.534 .396 .246 r
s
.355 .28 .206 r
.73482 .36864 m .71543 .35003 L .73684 .36765 L p F P
.534 .396 .246 r
s
.262 .163 .108 r
.59845 .34955 m .58387 .36228 L .60555 .35842 L p F P
.534 .396 .246 r
s
.262 .163 .108 r
.60555 .35842 m .62403 .3431 L .59845 .34955 L p F P
.534 .396 .246 r
s
.214 .132 .083 r
.59845 .34955 m .62403 .3431 L .64174 .3307 L p F P
.534 .396 .246 r
s
1 .747 .46 r
.30943 .39325 m .30695 .37885 L p .33145 .3487 L F P
.534 .396 .246 r
s
.868 .632 .397 r
.28217 .39557 m .30695 .37885 L .30943 .39325 L p F P
.534 .396 .246 r
s
.868 .632 .397 r
.30943 .39325 m .28478 .41734 L .28217 .39557 L p F P
.534 .396 .246 r
s
.762 .553 .354 r
.23356 .40414 m .25767 .40386 L .26036 .43304 L p F P
.534 .396 .246 r
s
.762 .553 .354 r
.26036 .43304 m .2364 .43888 L .23356 .40414 L p F P
.534 .396 .246 r
s
.726 .532 .346 r
.26076 .35402 m .23734 .34267 L .24339 .32485 L p F P
.534 .396 .246 r
s
.739 .537 .346 r
.23734 .34267 m .26076 .35402 L .25786 .37601 L p F P
.534 .396 .246 r
s
.844 .614 .387 r
.26036 .43304 m .28478 .41734 L .28999 .43629 L p F P
.534 .396 .246 r
s
.844 .614 .387 r
.28999 .43629 m .26607 .45774 L .26036 .43304 L p F P
.534 .396 .246 r
s
.794 .579 .37 r
.2364 .43888 m .26036 .43304 L .26607 .45774 L p F P
.534 .396 .246 r
s
.158 .102 .063 r
.56928 .37155 m .58387 .36228 L .55968 .36987 L p F P
.534 .396 .246 r
s
.22 .134 .083 r
.65481 .33165 m .64174 .3307 L .62403 .3431 L p F P
.534 .396 .246 r
s
.232 .14 .087 r
.40965 .29647 m .41665 .29866 L .43762 .29783 L p F P
.534 .396 .246 r
s
.178 .112 .07 r
.39499 .30796 m .41665 .29866 L .40965 .29647 L p F P
.534 .396 .246 r
s
.178 .112 .07 r
.40965 .29647 m .38614 .30716 L .39499 .30796 L p F P
.534 .396 .246 r
s
.321 .252 .185 r
.45444 .30311 m .45928 .30667 L .47925 .32223 L p F P
.534 .396 .246 r
s
.25 .15 .093 r
.43762 .29783 m .45928 .30667 L .45444 .30311 L p F P
.534 .396 .246 r
s
1 .747 .46 r
.30695 .37885 m .30672 .36566 L .33145 .3487 L p F P
.534 .396 .246 r
s
.865 .631 .397 r
.28212 .37515 m .30672 .36566 L .30695 .37885 L p F P
.534 .396 .246 r
s
.865 .631 .397 r
.30695 .37885 m .28217 .39557 L .28212 .37515 L p F P
.534 .396 .246 r
s
.811 .589 .373 r
.25767 .40386 m .28217 .39557 L .28478 .41734 L p F P
.534 .396 .246 r
s
.811 .589 .373 r
.28478 .41734 m .26036 .43304 L .25767 .40386 L p F P
.534 .396 .246 r
s
.92 .715 .435 r
.13768 .29642 m .15481 .27744 L .17749 .26911 L p F P
.534 .396 .246 r
s
.355 .28 .206 r
.73684 .36765 m .75841 .38768 L .73482 .36864 L p F P
.534 .396 .246 r
s
.355 .283 .204 r
.75433 .38604 m .73482 .36864 L .75841 .38768 L p F P
.534 .396 .246 r
s
.795 .578 .368 r
.28217 .39557 m .25767 .40386 L .25786 .37601 L p F P
.534 .396 .246 r
s
.789 .576 .368 r
.28212 .37515 m .25786 .37601 L .26076 .35402 L p F P
.534 .396 .246 r
s
.795 .578 .368 r
.25786 .37601 m .28212 .37515 L .28217 .39557 L p F P
.534 .396 .246 r
s
.684 .512 .338 r
.26615 .34037 m .24339 .32485 L .25193 .31791 L p F P
.534 .396 .246 r
s
.726 .532 .346 r
.24339 .32485 m .26615 .34037 L .26076 .35402 L p F P
.534 .396 .246 r
s
.689 .511 .336 r
.23014 .29851 m .25193 .31791 L .24339 .32485 L p F P
.534 .396 .246 r
s
.149 .097 .06 r
.37259 .32276 m .39499 .30796 L .38614 .30716 L p F P
.534 .396 .246 r
s
.149 .097 .06 r
.38614 .30716 m .3618 .32357 L .37259 .32276 L p F P
.534 .396 .246 r
s
.55 .427 .292 r
.25193 .31791 m .23014 .29851 L .24198 .30043 L p F P
.534 .396 .246 r
s
.651 .498 .333 r
.22106 .28194 m .24198 .30043 L .23014 .29851 L p F P
.534 .396 .246 r
s
.297 .228 .173 r
.50963 .35304 m .4932 .33985 L p .48808 .33186 L F P
.534 .396 .246 r
s
.283 .166 .103 r
.67457 .3284 m .65481 .33165 L .66646 .33311 L p F P
.534 .396 .246 r
s
.283 .166 .103 r
.66646 .33311 m .68795 .33265 L .67457 .3284 L p F P
.534 .396 .246 r
s
.165 .106 .066 r
.67639 .33333 m .69065 .33381 L p .68795 .33265 L F P
.534 .396 .246 r
s
.271 .161 .1 r
.69478 .33419 m .68509 .33141 L p .68795 .33265 L F P
.534 .396 .246 r
s
.396 .318 .227 r
.71556 .34828 m .69478 .33419 L .71003 .34192 L p F P
.534 .396 .246 r
s
.271 .161 .1 r
.68795 .33265 m .71003 .34192 L .69478 .33419 L p F P
.534 .396 .246 r
s
.561 .458 .309 r
.71003 .34192 m .68795 .33265 L .69936 .3341 L p F P
.534 .396 .246 r
s
.165 .106 .066 r
.69065 .33381 m .69936 .3341 L .68795 .33265 L p F P
.534 .396 .246 r
s
.271 .161 .1 r
.68509 .33141 m .67457 .3284 L .68795 .33265 L p F P
.534 .396 .246 r
s
.785 .58 .374 r
.28454 .35929 m .26076 .35402 L .26615 .34037 L p F P
.534 .396 .246 r
s
.789 .576 .368 r
.26076 .35402 m .28454 .35929 L .28212 .37515 L p F P
.534 .396 .246 r
s
.452 .373 .257 r
.22106 .28194 m .19969 .27053 L .21642 .27706 L p F P
.534 .396 .246 r
s
.497 .425 .275 r
.19969 .27053 m .17749 .26911 L .19579 .26986 L p F P
.534 .396 .246 r
s
.497 .425 .275 r
.19579 .26986 m .21642 .27706 L .19969 .27053 L p F P
.534 .396 .246 r
s
.878 .646 .408 r
.28454 .35929 m .30871 .35556 L .30672 .36566 L p F P
.534 .396 .246 r
s
.878 .646 .408 r
.30672 .36566 m .28212 .37515 L .28454 .35929 L p F P
.534 .396 .246 r
s
.207 .127 .079 r
.19579 .26986 m .17749 .26911 L .15481 .27744 L p F P
.534 .396 .246 r
s
.279 .165 .102 r
.77367 .39815 m .75433 .38604 L .77993 .40334 L p F P
.534 .396 .246 r
s
.355 .283 .204 r
.75841 .38768 m .77993 .40334 L .75433 .38604 L p F P
.534 .396 .246 r
s
.195 .121 .075 r
.55471 .37549 m .56928 .37155 L .54924 .37222 L p F P
.534 .396 .246 r
s
.258 .159 .104 r
.58387 .36228 m .56928 .37155 L .58716 .37166 L p F P
.534 .396 .246 r
s
.258 .159 .104 r
.58716 .37166 m .60555 .35842 L .58387 .36228 L p F P
.534 .396 .246 r
s
.29 .18 .12 r
.62403 .3431 m .60555 .35842 L .62348 .35753 L p F P
.534 .396 .246 r
s
.29 .18 .12 r
.62348 .35753 m .64538 .34228 L .62403 .3431 L p F P
.534 .396 .246 r
s
.22 .134 .083 r
.66646 .33311 m .65481 .33165 L p .62403 .3431 L F P
.534 .396 .246 r
s
.22 .134 .083 r
.62403 .3431 m .64538 .34228 L .66646 .33311 L p F P
.534 .396 .246 r
s
.415 .263 .166 r
.82115 .4082 m .79222 .40214 L .77367 .39815 L p F P
.534 .396 .246 r
s
.275 .163 .101 r
.45928 .30667 m .43762 .29783 L .45538 .30688 L p F P
.534 .396 .246 r
s
.363 .222 .139 r
.45538 .30688 m .43762 .29783 L .41665 .29866 L p F P
.534 .396 .246 r
s
.128 .086 .054 r
.34951 .33794 m .37259 .32276 L .3618 .32357 L p F P
.534 .396 .246 r
s
.128 .086 .054 r
.3618 .32357 m .33672 .33987 L .34951 .33794 L p F P
.534 .396 .246 r
s
.279 .165 .102 r
.77993 .40334 m .80105 .41066 L .77367 .39815 L p F P
.534 .396 .246 r
s
.415 .263 .166 r
.77367 .39815 m .80105 .41066 L .82115 .4082 L p F P
.534 .396 .246 r
s
.288 .22 .168 r
.47789 .32152 m .47925 .32223 L p .49602 .33841 L F P
.534 .396 .246 r
s
.288 .22 .168 r
.49642 .33885 m .47789 .32152 L p .49602 .33841 L F P
.534 .396 .246 r
s
.297 .228 .173 r
.48808 .33186 m .47789 .32152 L .49778 .34011 L p F P
.534 .396 .246 r
s
.288 .22 .168 r
.47925 .32223 m .49195 .33375 L .49778 .34011 L p F P
.534 .396 .246 r
s
.371 .22 .134 r
.47925 .32223 m .4692 .3144 L p .49161 .33346 L F P
.534 .396 .246 r
s
.371 .22 .134 r
.49195 .33375 m .4692 .3144 L .46746 .31346 L F
.4692 .3144 m .45928 .30667 L p .46746 .31346 L F P
.534 .396 .246 r
s
.371 .22 .134 r
.49034 .33236 m .46752 .31349 L .4705 .31513 L F
.45928 .30667 m .4705 .31513 L p .46752 .31349 L F P
.534 .396 .246 r
s
.371 .22 .134 r
.49061 .33264 m .46746 .31346 L .49034 .33236 L F
.46746 .31346 m .45928 .30667 L .46752 .31349 L F
.46746 .31346 m .46752 .31349 L .49034 .33236 L F
.49195 .33375 m .49169 .33352 L p .49161 .33346 L F P
.534 .396 .246 r
s
.371 .22 .134 r
.49169 .33352 m .47925 .32223 L p .49161 .33346 L F P
.534 .396 .246 r
s
.371 .22 .134 r
.4705 .31513 m .48578 .32703 L .49195 .33375 L p F P
.534 .396 .246 r
s
.241 .145 .09 r
.47936 .32001 m .48578 .32703 L .4705 .31513 L p F P
.534 .396 .246 r
s
.358 .212 .129 r
.47936 .32001 m .45538 .30688 L .44065 .30461 L p F P
.534 .396 .246 r
s
.358 .212 .129 r
.44065 .30461 m .45463 .30813 L p .46177 .31301 L F P
.534 .396 .246 r
s
.358 .212 .129 r
.45463 .30813 m .45617 .30851 L p .46177 .31301 L F P
.534 .396 .246 r
s
.363 .222 .139 r
.41665 .29866 m .42722 .30138 L p .45538 .30688 L F P
.534 .396 .246 r
s
.363 .222 .139 r
.42722 .30138 m .44065 .30461 L .45538 .30688 L p F P
.534 .396 .246 r
s
.17 .108 .067 r
.44522 .30732 m .45617 .30851 L .45125 .30728 L p F P
.534 .396 .246 r
s
.17 .108 .067 r
.45125 .30728 m .44065 .30461 L p .44522 .30732 L F P
.534 .396 .246 r
s
.17 .108 .067 r
.44065 .30461 m .4255 .30833 L .44522 .30732 L p F P
.534 .396 .246 r
s
.123 .084 .052 r
.43401 .30946 m .44522 .30732 L .44139 .30751 L p F P
.534 .396 .246 r
s
.123 .084 .052 r
.44139 .30751 m .4255 .30833 L p .43401 .30946 L F P
.534 .396 .246 r
s
.123 .084 .052 r
.4255 .30833 m .40988 .31748 L .43401 .30946 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.42251 .31441 m .43401 .30946 L .43015 .31074 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.43015 .31074 m .40988 .31748 L p .42251 .31441 L F P
.534 .396 .246 r
s
.089 .066 .041 r
.40988 .31748 m .39378 .33036 L .42251 .31441 L p F P
.534 .396 .246 r
s
.092 .068 .042 r
.42251 .31441 m .39378 .33036 L .37796 .34381 L p F P
.534 .396 .246 r
s
.869 .679 .41 r
.42251 .31441 m .41115 .32084 L p .41588 .3176 L F P
.534 .396 .246 r
s
.226 .137 .085 r
.4255 .30833 m .44065 .30461 L .42722 .30138 L p F P
.534 .396 .246 r
s
.869 .679 .41 r
.45351 .29181 m .42251 .31441 L p .41588 .3176 L F P
.534 .396 .246 r
s
.967 .746 .455 r
.43401 .30946 m .42251 .31441 L .42664 .3114 L p F P
.534 .396 .246 r
s
.967 .746 .455 r
.42664 .3114 m .45351 .29181 L p .43401 .30946 L F P
.534 .396 .246 r
s
.862 .681 .422 r
.44522 .30732 m .43401 .30946 L .43924 .30736 L p F P
.534 .396 .246 r
s
.862 .681 .422 r
.43924 .30736 m .4601 .299 L p .44522 .30732 L F P
.534 .396 .246 r
s
.692 .563 .36 r
.45617 .30851 m .44522 .30732 L .45504 .30676 L p F P
.534 .396 .246 r
s
.241 .145 .09 r
.45713 .30784 m .46124 .31009 L p .45876 .30873 L F P
.534 .396 .246 r
s
.241 .145 .09 r
.45876 .30873 m .45538 .30688 L .45713 .30784 L p F P
.534 .396 .246 r
s
.275 .163 .101 r
.45538 .30688 m .4705 .31513 L .45928 .30667 L p F P
.534 .396 .246 r
s
.692 .563 .36 r
.45504 .30676 m .4666 .3061 L p .45766 .30817 L F P
.534 .396 .246 r
s
.692 .563 .36 r
.45617 .30851 m .45504 .30676 L .45766 .30817 L F
.241 .145 .09 r
.46124 .31009 m .47777 .31914 L p .46183 .31041 L F P
.534 .396 .246 r
s
.241 .145 .09 r
.45876 .30873 m .46124 .31009 L .46183 .31041 L F
.47777 .31914 m .47936 .32001 L p .47763 .31907 L F P
.534 .396 .246 r
s
.241 .145 .09 r
.45876 .30873 m .47777 .31914 L .47763 .31907 L F
.4705 .31513 m .45876 .30873 L p .47763 .31907 L F P
.534 .396 .246 r
s
.241 .145 .09 r
.4705 .31513 m .47763 .31907 L .47936 .32001 L F
.358 .212 .129 r
.47936 .32001 m .46177 .31301 L .45617 .30851 L F
.371 .22 .134 r
.49195 .33375 m .49061 .33264 L .49034 .33236 L F
.288 .22 .168 r
.49778 .34011 m .49642 .33885 L p .49602 .33841 L F P
.534 .396 .246 r
s
.247 .148 .092 r
.51587 .35985 m .50963 .35304 L .52511 .36514 L p F P
.534 .396 .246 r
s
.396 .318 .227 r
.71003 .34192 m .73277 .35916 L .71556 .34828 L p F P
.534 .396 .246 r
s
.421 .34 .242 r
.73684 .36765 m .71556 .34828 L .73277 .35916 L p F P
.534 .396 .246 r
s
.226 .137 .085 r
.40842 .30857 m .42722 .30138 L .41665 .29866 L p F P
.534 .396 .246 r
s
.226 .137 .085 r
.41665 .29866 m .39499 .30796 L .40842 .30857 L p F P
.534 .396 .246 r
s
.376 .299 .217 r
.24198 .30043 m .22106 .28194 L .23644 .29241 L p F P
.534 .396 .246 r
s
.452 .373 .257 r
.21642 .27706 m .23644 .29241 L .22106 .28194 L p F P
.534 .396 .246 r
s
.909 .68 .431 r
.30871 .35556 m .28454 .35929 L .2893 .3496 L p F P
.534 .396 .246 r
s
.785 .58 .374 r
.26615 .34037 m .2893 .3496 L .28454 .35929 L p F P
.534 .396 .246 r
s
.297 .228 .173 r
.49778 .34011 m .50357 .34644 L .48808 .33186 L p F P
.534 .396 .246 r
s
.297 .228 .173 r
.48808 .33186 m .50357 .34644 L .50963 .35304 L p F P
.534 .396 .246 r
s
.207 .127 .079 r
.15481 .27744 m .17474 .2721 L .19579 .26986 L p F P
.534 .396 .246 r
s
.909 .68 .431 r
.2893 .3496 m .31289 .34936 L .30871 .35556 L p F P
.534 .396 .246 r
s
.75 .571 .374 r
.2893 .3496 m .26615 .34037 L .27391 .33553 L p F P
.534 .396 .246 r
s
.684 .512 .338 r
.25193 .31791 m .27391 .33553 L .26615 .34037 L p F P
.534 .396 .246 r
s
.499 .399 .277 r
.27391 .33553 m .25193 .31791 L .26283 .32107 L p F P
.534 .396 .246 r
s
.55 .427 .292 r
.24198 .30043 m .26283 .32107 L .25193 .31791 L p F P
.534 .396 .246 r
s
.236 .146 .094 r
.38898 .32163 m .40842 .30857 L .39499 .30796 L p F P
.534 .396 .246 r
s
.236 .146 .094 r
.39499 .30796 m .37259 .32276 L .38898 .32163 L p F P
.534 .396 .246 r
s
.13 .087 .054 r
.67639 .33333 m .66646 .33311 L .64538 .34228 L p F P
.534 .396 .246 r
s
.13 .087 .054 r
.64538 .34228 m .67475 .33361 L .67639 .33333 L F
.165 .106 .066 r
.67944 .33283 m .66646 .33311 L .67639 .33333 L p F P
.534 .396 .246 r
s
.13 .087 .054 r
.68431 .33079 m .67639 .33333 L p .67475 .33361 L F P
.534 .396 .246 r
s
.165 .106 .066 r
.68795 .33265 m .67944 .33283 L p .67639 .33333 L F P
.534 .396 .246 r
s
.246 .147 .092 r
.56928 .37155 m .55471 .37549 L .56884 .37912 L p F P
.534 .396 .246 r
s
.246 .147 .092 r
.56884 .37912 m .58716 .37166 L .56928 .37155 L p F P
.534 .396 .246 r
s
.421 .34 .242 r
.73277 .35916 m .75601 .38017 L .73684 .36765 L p F P
.534 .396 .246 r
s
.45 .367 .258 r
.75841 .38768 m .73684 .36765 L .75601 .38017 L p F P
.534 .396 .246 r
s
.851 .667 .426 r
.31289 .34936 m .2893 .3496 L .29632 .34612 L p F P
.534 .396 .246 r
s
.75 .571 .374 r
.27391 .33553 m .29632 .34612 L .2893 .3496 L p F P
.534 .396 .246 r
s
.327 .254 .19 r
.26283 .32107 m .24198 .30043 L .25621 .31228 L p F P
.534 .396 .246 r
s
.376 .299 .217 r
.23644 .29241 m .25621 .31228 L .24198 .30043 L p F P
.534 .396 .246 r
s
.279 .173 .115 r
.60555 .35842 m .58716 .37166 L .60184 .37266 L p F P
.534 .396 .246 r
s
.279 .173 .115 r
.60184 .37266 m .62348 .35753 L .60555 .35842 L p F P
.534 .396 .246 r
s
.173 .11 .068 r
.30549 .34766 m .31419 .34747 L p .31915 .34689 L F P
.534 .396 .246 r
s
.095 .069 .043 r
.31289 .34936 m .31915 .34689 L p .32179 .34658 L F P
.534 .396 .246 r
s
.173 .11 .068 r
.31419 .34747 m .32741 .34718 L .31915 .34689 L p F P
.534 .396 .246 r
s
.095 .069 .043 r
.34951 .33794 m .32179 .34658 L .31915 .34689 L F
.561 .458 .309 r
.69936 .3341 m .72301 .34473 L .71003 .34192 L p F P
.534 .396 .246 r
s
.593 .461 .313 r
.73277 .35916 m .71003 .34192 L .72301 .34473 L p F P
.534 .396 .246 r
s
.226 .137 .085 r
.42722 .30138 m .40842 .30857 L .4255 .30833 L p F P
.534 .396 .246 r
s
.288 .222 .167 r
.27606 .33179 m .27814 .33327 L p .28395 .33829 L F P
.534 .396 .246 r
s
.482 .4 .273 r
.29632 .34612 m .28902 .34267 L p .28395 .33829 L F P
.534 .396 .246 r
s
.173 .11 .068 r
.31915 .34689 m .29632 .34612 L .30549 .34766 L p F P
.534 .396 .246 r
s
.482 .4 .273 r
.28395 .33829 m .30549 .34766 L .29632 .34612 L p F P
.534 .396 .246 r
s
.314 .183 .113 r
.30549 .34766 m .28395 .33829 L .29622 .34617 L p F P
.534 .396 .246 r
s
.288 .222 .167 r
.27814 .33327 m .29622 .34617 L .28395 .33829 L p F P
.534 .396 .246 r
s
.482 .4 .273 r
.28902 .34267 m .27391 .33553 L .28395 .33829 L p F P
.534 .396 .246 r
s
.499 .399 .277 r
.26283 .32107 m .28395 .33829 L .27391 .33553 L p F P
.534 .396 .246 r
s
.288 .22 .168 r
.51646 .35815 m .50357 .34644 L .49778 .34011 L p F P
.534 .396 .246 r
s
.167 .107 .066 r
.64538 .34228 m .62348 .35753 L .63632 .35697 L p F P
.534 .396 .246 r
s
.167 .107 .066 r
.63632 .35697 m .66077 .34036 L .64538 .34228 L p F P
.534 .396 .246 r
s
.855 .669 .427 r
.69936 .3341 m .68705 .33369 L p .68431 .33079 L F P
.534 .396 .246 r
s
.855 .669 .427 r
.68705 .33369 m .67639 .33333 L .68431 .33079 L p F P
.534 .396 .246 r
s
.13 .087 .054 r
.66077 .34036 m .68431 .33079 L p .66707 .33587 L F P
.534 .396 .246 r
s
.13 .087 .054 r
.64538 .34228 m .66077 .34036 L p .66707 .33587 L F P
.534 .396 .246 r
s
.86 .668 .399 r
.66077 .34036 m .63632 .35697 L .64291 .35358 L p F P
.534 .396 .246 r
s
.86 .668 .399 r
.64291 .35358 m .64625 .35068 L p .66077 .34036 L F P
.534 .396 .246 r
s
.86 .668 .399 r
.64625 .35068 m .66858 .33129 L .66077 .34036 L p F P
.534 .396 .246 r
s
.927 .718 .435 r
.68431 .33079 m .66077 .34036 L p .68226 .32862 L F P
.534 .396 .246 r
s
.927 .718 .435 r
.68996 .32442 m .68431 .33079 L p .68226 .32862 L F P
.534 .396 .246 r
s
.296 .173 .108 r
.21642 .27706 m .19579 .26986 L .21676 .281 L p F P
.534 .396 .246 r
s
.363 .222 .139 r
.21676 .281 m .19579 .26986 L .17474 .2721 L p F P
.534 .396 .246 r
s
.249 .154 .1 r
.36894 .33707 m .38898 .32163 L .37259 .32276 L p F P
.534 .396 .246 r
s
.249 .154 .1 r
.37259 .32276 m .34951 .33794 L .36894 .33707 L p F P
.534 .396 .246 r
s
.387 .241 .151 r
.56884 .37912 m .55471 .37549 L .5402 .37336 L p F P
.534 .396 .246 r
s
.316 .184 .114 r
.23644 .29241 m .21642 .27706 L .23574 .2932 L p F P
.534 .396 .246 r
s
.296 .173 .108 r
.21676 .281 m .23574 .2932 L .21642 .27706 L p F P
.534 .396 .246 r
s
.45 .367 .258 r
.75601 .38017 m .77945 .39933 L .75841 .38768 L p F P
.534 .396 .246 r
s
.498 .414 .282 r
.77993 .40334 m .75841 .38768 L .77945 .39933 L p F P
.534 .396 .246 r
s
.363 .222 .139 r
.17474 .2721 m .19751 .27686 L .21676 .281 L p F P
.534 .396 .246 r
s
.213 .131 .082 r
.40988 .31748 m .4255 .30833 L .40842 .30857 L p F P
.534 .396 .246 r
s
.213 .131 .082 r
.40842 .30857 m .38898 .32163 L .40988 .31748 L p F P
.534 .396 .246 r
s
.327 .254 .19 r
.25621 .31228 m .27606 .33179 L .26283 .32107 L p F P
.534 .396 .246 r
s
.357 .214 .13 r
.27606 .33179 m .25621 .31228 L .26992 .32673 L p F P
.534 .396 .246 r
s
.288 .222 .167 r
.28231 .33696 m .27381 .33002 L p .27606 .33179 L F P
.534 .396 .246 r
s
.288 .222 .167 r
.27381 .33002 m .26283 .32107 L .27239 .32882 L p F P
.534 .396 .246 r
s
.288 .222 .167 r
.27239 .32882 m .27606 .33179 L p .27381 .33002 L F P
.534 .396 .246 r
s
.329 .194 .119 r
.25435 .31082 m .26948 .32635 L p .25621 .31228 L F P
.534 .396 .246 r
s
.329 .194 .119 r
.26948 .32635 m .2729 .32987 L .26992 .32673 L p F P
.534 .396 .246 r
s
.329 .194 .119 r
.26992 .32673 m .25621 .31228 L p .26948 .32635 L F P
.534 .396 .246 r
s
.357 .214 .13 r
.26992 .32673 m .2729 .32987 L p .27606 .33179 L F P
.534 .396 .246 r
s
.288 .222 .167 r
.28395 .33829 m .28231 .33696 L p .27606 .33179 L F P
.534 .396 .246 r
s
.297 .228 .173 r
.50764 .34851 m .51803 .35904 L .49778 .34011 L p F P
.534 .396 .246 r
s
.297 .228 .173 r
.49778 .34011 m .49195 .33375 L .50764 .34851 L p F P
.534 .396 .246 r
s
.095 .069 .043 r
.31915 .34689 m .32741 .34718 L .34951 .33794 L p F P
.534 .396 .246 r
s
.593 .461 .313 r
.72301 .34473 m .74736 .36265 L .73277 .35916 L p F P
.534 .396 .246 r
s
.62 .473 .318 r
.75601 .38017 m .73277 .35916 L .74736 .36265 L p F P
.534 .396 .246 r
s
.258 .156 .099 r
.58716 .37166 m .56884 .37912 L .58037 .38232 L p F P
.534 .396 .246 r
s
.258 .156 .099 r
.58037 .38232 m .60184 .37266 L .58716 .37166 L p F P
.534 .396 .246 r
s
.855 .669 .427 r
.68431 .33079 m .7084 .33053 L .69936 .3341 L p F P
.534 .396 .246 r
s
.763 .578 .377 r
.72301 .34473 m .69936 .3341 L .7084 .33053 L p F P
.534 .396 .246 r
s
.285 .167 .104 r
.53688 .37408 m .5591 .38321 L .5402 .37336 L p F P
.534 .396 .246 r
s
.387 .241 .151 r
.58037 .38232 m .56884 .37912 L p .5402 .37336 L F P
.534 .396 .246 r
s
.387 .241 .151 r
.5402 .37336 m .5591 .38321 L .58037 .38232 L p F P
.534 .396 .246 r
s
.281 .17 .109 r
.84663 .40386 m .82115 .4082 L .80105 .41066 L p F P
.534 .396 .246 r
s
.316 .184 .114 r
.23574 .2932 m .25435 .31082 L .23957 .29563 L p F P
.534 .396 .246 r
s
.316 .184 .114 r
.23957 .29563 m .23644 .29241 L p .23574 .2932 L F P
.534 .396 .246 r
s
.261 .155 .096 r
.23574 .2932 m .21676 .281 L .23218 .29094 L p F P
.534 .396 .246 r
s
.329 .194 .119 r
.25621 .31228 m .23975 .29573 L p .25342 .30986 L F P
.534 .396 .246 r
s
.329 .194 .119 r
.25457 .31099 m .25342 .30986 L .25435 .31082 L F
.25621 .31228 m .25342 .30986 L .25457 .31099 L F
.23957 .29563 m .25435 .31082 L p .23975 .29573 L F P
.534 .396 .246 r
s
.261 .155 .096 r
.24062 .29639 m .25784 .31263 L .24299 .29958 L p F P
.534 .396 .246 r
s
.261 .155 .096 r
.24299 .29958 m .23574 .2932 L p .23807 .29472 L F P
.534 .396 .246 r
s
.261 .155 .096 r
.23807 .29472 m .24062 .29639 L .24299 .29958 L F
.3 .231 .174 r
.25435 .31082 m .25023 .30691 L p .25784 .31263 L F P
.534 .396 .246 r
s
.3 .231 .174 r
.25023 .30691 m .23574 .2932 L .24619 .30239 L p F P
.534 .396 .246 r
s
.3 .231 .174 r
.24619 .30239 m .25784 .31263 L p .25023 .30691 L F P
.534 .396 .246 r
s
.261 .155 .096 r
.23218 .29094 m .23756 .29441 L p .23574 .2932 L F P
.534 .396 .246 r
s
.261 .155 .096 r
.23756 .29441 m .24062 .29639 L p .23807 .29472 L F P
.534 .396 .246 r
s
.261 .155 .096 r
.23574 .2932 m .23756 .29441 L .23807 .29472 L F
.329 .194 .119 r
.23975 .29573 m .23644 .29241 L .23957 .29563 L p F P
.534 .396 .246 r
s
.365 .217 .132 r
.24062 .29639 m .21676 .281 L .19751 .27686 L p F P
.534 .396 .246 r
s
.47 .388 .268 r
.24062 .29639 m .22333 .28539 L p .23766 .29282 L F P
.534 .396 .246 r
s
.47 .388 .268 r
.26754 .3083 m .24099 .29655 L p .23766 .29282 L F P
.534 .396 .246 r
s
.47 .388 .268 r
.24099 .29655 m .24062 .29639 L p .23766 .29282 L F P
.534 .396 .246 r
s
.129 .087 .054 r
.80105 .41066 m .77993 .40334 L .80266 .41128 L p F P
.534 .396 .246 r
s
.129 .087 .054 r
.80266 .41128 m .82525 .4127 L .80105 .41066 L p F P
.534 .396 .246 r
s
.281 .17 .109 r
.80105 .41066 m .82525 .4127 L .84663 .40386 L p F P
.534 .396 .246 r
s
.498 .414 .282 r
.77945 .39933 m .80266 .41128 L .77993 .40334 L p F P
.534 .396 .246 r
s
.191 .12 .076 r
.62348 .35753 m .60184 .37266 L .61229 .37391 L p F P
.534 .396 .246 r
s
.191 .12 .076 r
.61229 .37391 m .63632 .35697 L .62348 .35753 L p F P
.534 .396 .246 r
s
.199 .123 .077 r
.36894 .33707 m .34951 .33794 L .32741 .34718 L p F P
.534 .396 .246 r
s
.297 .228 .173 r
.50764 .34851 m .49195 .33375 L .48578 .32703 L p F P
.534 .396 .246 r
s
.763 .578 .377 r
.7084 .33053 m .73321 .33985 L .72301 .34473 L p F P
.534 .396 .246 r
s
.705 .525 .345 r
.74736 .36265 m .72301 .34473 L .73321 .33985 L p F P
.534 .396 .246 r
s
.262 .156 .097 r
.5591 .38321 m .53688 .37408 L .54233 .37815 L p F P
.534 .396 .246 r
s
.319 .25 .184 r
.54233 .37815 m .53688 .37408 L .51646 .35815 L p F P
.534 .396 .246 r
s
.319 .25 .184 r
.54027 .37559 m .54233 .37815 L p .51646 .35815 L F P
.534 .396 .246 r
s
.319 .25 .184 r
.51646 .35815 m .51803 .35904 L .54027 .37559 L p F P
.534 .396 .246 r
s
.91 .681 .432 r
.7084 .33053 m .68431 .33079 L .68996 .32442 L p F P
.534 .396 .246 r
s
.215 .134 .085 r
.39378 .33036 m .40988 .31748 L .38898 .32163 L p F P
.534 .396 .246 r
s
.215 .134 .085 r
.38898 .32163 m .36894 .33707 L .39378 .33036 L p F P
.534 .396 .246 r
s
.62 .473 .318 r
.74736 .36265 m .77219 .38277 L .75601 .38017 L p F P
.534 .396 .246 r
s
.686 .52 .344 r
.77945 .39933 m .75601 .38017 L .77219 .38277 L p F P
.534 .396 .246 r
s
.199 .123 .077 r
.32741 .34718 m .33757 .34874 L p .36894 .33707 L F P
.534 .396 .246 r
s
.284 .167 .104 r
.31675 .35211 m .33757 .34874 L .32741 .34718 L p F P
.534 .396 .246 r
s
.284 .167 .104 r
.32741 .34718 m .30549 .34766 L .31675 .35211 L p F P
.534 .396 .246 r
s
.91 .681 .432 r
.68996 .32442 m .71475 .3206 L .7084 .33053 L p F P
.534 .396 .246 r
s
.787 .581 .374 r
.73321 .33985 m .7084 .33053 L .71475 .3206 L p F P
.534 .396 .246 r
s
.314 .183 .113 r
.29622 .34617 m .31675 .35211 L .30549 .34766 L p F P
.534 .396 .246 r
s
.297 .228 .173 r
.48578 .32703 m .50247 .34039 L p .50764 .34851 L F P
.534 .396 .246 r
s
.458 .375 .261 r
.5053 .33505 m .50247 .34039 L .48578 .32703 L p F P
.534 .396 .246 r
s
.458 .375 .261 r
.48578 .32703 m .47936 .32001 L .5053 .33505 L p F P
.534 .396 .246 r
s
.927 .718 .435 r
.69317 .31398 m .68996 .32442 L p .66077 .34036 L F P
.534 .396 .246 r
s
.927 .718 .435 r
.66077 .34036 m .66858 .33129 L .69317 .31398 L p F P
.534 .396 .246 r
s
.206 .127 .079 r
.60184 .37266 m .58037 .38232 L .58852 .38504 L p F P
.534 .396 .246 r
s
.206 .127 .079 r
.58852 .38504 m .61229 .37391 L .60184 .37266 L p F P
.534 .396 .246 r
s
.358 .212 .129 r
.45617 .30851 m .47302 .3131 L .47936 .32001 L p F P
.534 .396 .246 r
s
.692 .563 .36 r
.4666 .3061 m .47302 .3131 L .45617 .30851 L p F P
.534 .396 .246 r
s
.705 .525 .345 r
.73321 .33985 m .75873 .35577 L .74736 .36265 L p F P
.534 .396 .246 r
s
.706 .522 .341 r
.77219 .38277 m .74736 .36265 L .75873 .35577 L p F P
.534 .396 .246 r
s
.787 .581 .374 r
.71475 .3206 m .74025 .32588 L .73321 .33985 L p F P
.534 .396 .246 r
s
.733 .537 .348 r
.75873 .35577 m .73321 .33985 L .74025 .32588 L p F P
.534 .396 .246 r
s
.881 .648 .409 r
.71475 .3206 m .68996 .32442 L .69317 .31398 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.86762 .38499 m .84663 .40386 L .82525 .4127 L p F P
.534 .396 .246 r
s
.407 .328 .235 r
.51803 .35904 m .50764 .34851 L .51834 .35376 L p F P
.534 .396 .246 r
s
.297 .228 .173 r
.50247 .34039 m .51834 .35376 L .50764 .34851 L p F P
.534 .396 .246 r
s
.881 .648 .409 r
.69317 .31398 m .71821 .3043 L .71475 .3206 L p F P
.534 .396 .246 r
s
.789 .576 .368 r
.74025 .32588 m .71475 .3206 L .71821 .3043 L p F P
.534 .396 .246 r
s
.686 .52 .344 r
.77219 .38277 m .7971 .39885 L .77945 .39933 L p F P
.534 .396 .246 r
s
.811 .616 .399 r
.80266 .41128 m .77945 .39933 L .7971 .39885 L p F P
.534 .396 .246 r
s
.25 .15 .093 r
.58852 .38504 m .58037 .38232 L .5591 .38321 L p F P
.534 .396 .246 r
s
.375 .222 .135 r
.29622 .34617 m .27606 .33179 L .29164 .34599 L p F P
.534 .396 .246 r
s
.357 .214 .13 r
.2729 .32987 m .29164 .34599 L .27606 .33179 L p F P
.534 .396 .246 r
s
.458 .375 .261 r
.5053 .33505 m .47936 .32001 L .47302 .3131 L p F P
.534 .396 .246 r
s
.407 .328 .235 r
.53159 .36637 m .54027 .37559 L .51803 .35904 L p F P
.534 .396 .246 r
s
.407 .328 .235 r
.51834 .35376 m .53159 .36637 L p .51803 .35904 L F P
.534 .396 .246 r
s
.089 .066 .041 r
.63632 .35697 m .61229 .37391 L .61764 .37393 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.61764 .37393 m .64291 .35358 L .63632 .35697 L p F P
.534 .396 .246 r
s
.262 .156 .097 r
.54233 .37815 m .56799 .38832 L .5591 .38321 L p F P
.534 .396 .246 r
s
.25 .15 .093 r
.5591 .38321 m .59101 .38643 L .58852 .38504 L F
.5591 .38321 m .56799 .38832 L .59264 .38659 L p F P
.534 .396 .246 r
s
.838 .661 .42 r
.56453 .38429 m .58803 .38058 L p .5728 .38646 L F P
.534 .396 .246 r
s
.838 .661 .42 r
.56799 .38832 m .5664 .38647 L p .5728 .38646 L F P
.534 .396 .246 r
s
.838 .661 .42 r
.5664 .38647 m .56453 .38429 L p .5728 .38646 L F P
.534 .396 .246 r
s
.25 .15 .093 r
.59264 .38659 m .5922 .38643 L p .59101 .38643 L F P
.534 .396 .246 r
s
.25 .15 .093 r
.5922 .38643 m .58852 .38504 L p .59101 .38643 L F P
.534 .396 .246 r
s
.365 .217 .132 r
.19751 .27686 m .22333 .28539 L .24062 .29639 L p F P
.534 .396 .246 r
s
.199 .123 .077 r
.33757 .34874 m .34949 .34981 L .36894 .33707 L p F P
.534 .396 .246 r
s
.298 .175 .109 r
.33 .35676 m .34949 .34981 L .33757 .34874 L p F P
.534 .396 .246 r
s
.298 .175 .109 r
.33757 .34874 m .31675 .35211 L .33 .35676 L p F P
.534 .396 .246 r
s
.181 .114 .071 r
.39378 .33036 m .36894 .33707 L .34949 .34981 L p F P
.534 .396 .246 r
s
.862 .681 .422 r
.4601 .299 m .4666 .3061 L .44522 .30732 L p F P
.534 .396 .246 r
s
.868 .634 .399 r
.71821 .3043 m .69317 .31398 L .69389 .30031 L p F P
.534 .396 .246 r
s
.868 .634 .399 r
.69389 .30031 m .71879 .28326 L .71821 .3043 L p F P
.534 .396 .246 r
s
.789 .576 .368 r
.71821 .3043 m .74393 .30328 L .74025 .32588 L p F P
.534 .396 .246 r
s
.795 .578 .368 r
.74393 .30328 m .71821 .3043 L .71879 .28326 L p F P
.534 .396 .246 r
s
.971 .742 .466 r
.82525 .4127 m .80266 .41128 L .82158 .40553 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.82525 .4127 m .84528 .40033 L .86762 .38499 L p F P
.534 .396 .246 r
s
.971 .742 .466 r
.82158 .40553 m .84528 .40033 L .82525 .4127 L p F P
.534 .396 .246 r
s
1 .762 .466 r
.69389 .30031 m .69317 .31398 L .66858 .33129 L p F P
.534 .396 .246 r
s
.811 .616 .399 r
.7971 .39885 m .82158 .40553 L .80266 .41128 L p F P
.534 .396 .246 r
s
.733 .537 .348 r
.74025 .32588 m .76647 .33747 L .75873 .35577 L p F P
.534 .396 .246 r
s
.742 .539 .347 r
.76647 .33747 m .74025 .32588 L .74393 .30328 L p F P
.534 .396 .246 r
s
.346 .202 .125 r
.31675 .35211 m .29622 .34617 L .31068 .35559 L p F P
.534 .396 .246 r
s
.375 .222 .135 r
.29164 .34599 m .31068 .35559 L .29622 .34617 L p F P
.534 .396 .246 r
s
.346 .202 .125 r
.31068 .35559 m .33 .35676 L .31675 .35211 L p F P
.534 .396 .246 r
s
.458 .375 .261 r
.47302 .3131 m .49052 .31824 L p .5053 .33505 L F P
.534 .396 .246 r
s
.826 .631 .408 r
.48874 .30546 m .49052 .31824 L .47302 .3131 L p F P
.534 .396 .246 r
s
.826 .631 .408 r
.47302 .3131 m .4666 .3061 L .48874 .30546 L p F P
.534 .396 .246 r
s
.873 .635 .399 r
.71879 .28326 m .69389 .30031 L .69222 .28526 L p F P
.534 .396 .246 r
s
.873 .635 .399 r
.69222 .28526 m .71664 .26075 L .71879 .28326 L p F P
.534 .396 .246 r
s
.795 .578 .368 r
.71879 .28326 m .74429 .27466 L .74393 .30328 L p F P
.534 .396 .246 r
s
.811 .589 .373 r
.74429 .27466 m .71879 .28326 L .71664 .26075 L p F P
.534 .396 .246 r
s
.575 .449 .305 r
.52984 .35092 m .51834 .35376 L .50247 .34039 L p F P
.534 .396 .246 r
s
.575 .449 .305 r
.50247 .34039 m .5053 .33505 L .52984 .35092 L p F P
.534 .396 .246 r
s
.706 .522 .341 r
.75873 .35577 m .7847 .37277 L .77219 .38277 L p F P
.534 .396 .246 r
s
.75 .553 .358 r
.7971 .39885 m .77219 .38277 L .7847 .37277 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.61229 .37391 m .58852 .38504 L .59264 .38659 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.59264 .38659 m .61764 .37393 L .61229 .37391 L p F P
.534 .396 .246 r
s
.726 .53 .343 r
.7847 .37277 m .75873 .35577 L .76647 .33747 L p F P
.534 .396 .246 r
s
.742 .539 .347 r
.74393 .30328 m .77036 .30899 L .76647 .33747 L p F P
.534 .396 .246 r
s
.749 .543 .349 r
.77036 .30899 m .74393 .30328 L .74429 .27466 L p F P
.534 .396 .246 r
s
.811 .589 .373 r
.71664 .26075 m .74161 .24468 L .74429 .27466 L p F P
.534 .396 .246 r
s
.749 .543 .349 r
.74429 .27466 m .77053 .27401 L .77036 .30899 L p F P
.534 .396 .246 r
s
.763 .553 .354 r
.77053 .27401 m .74429 .27466 L .74161 .24468 L p F P
.534 .396 .246 r
s
1 .762 .466 r
.66858 .33129 m .64291 .35358 L .64263 .34582 L p F P
.534 .396 .246 r
s
1 .762 .466 r
.64263 .34582 m .66804 .31484 L .66858 .33129 L p F P
.534 .396 .246 r
s
1 .762 .466 r
.69222 .28526 m .69389 .30031 L p .66858 .33129 L F P
.534 .396 .246 r
s
1 .762 .466 r
.66858 .33129 m .66804 .31484 L .69222 .28526 L p F P
.534 .396 .246 r
s
.276 .208 .161 r
.2729 .32987 m .25435 .31082 L .27495 .33076 L p F P
.534 .396 .246 r
s
.3 .231 .174 r
.25784 .31263 m .27495 .33076 L .25435 .31082 L p F P
.534 .396 .246 r
s
.846 .615 .388 r
.74161 .24468 m .71664 .26075 L .71211 .24091 L p F P
.534 .396 .246 r
s
.846 .615 .388 r
.71211 .24091 m .73635 .219 L .74161 .24468 L p F P
.534 .396 .246 r
s
.763 .553 .354 r
.74161 .24468 m .76736 .23825 L .77053 .27401 L p F P
.534 .396 .246 r
s
.794 .579 .37 r
.76736 .23825 m .74161 .24468 L .73635 .219 L p F P
.534 .396 .246 r
s
1 .775 .474 r
.88355 .35275 m .86762 .38499 L .84528 .40033 L p F P
.534 .396 .246 r
s
.896 .652 .407 r
.71664 .26075 m .69222 .28526 L .68836 .27133 L p F P
.534 .396 .246 r
s
.896 .652 .407 r
.68836 .27133 m .71211 .24091 L .71664 .26075 L p F P
.534 .396 .246 r
s
.492 .41 .278 r
.56799 .38832 m .54233 .37815 L .54027 .37559 L p F P
.534 .396 .246 r
s
.912 .668 .418 r
.73635 .219 m .71211 .24091 L .70555 .22739 L p F P
.534 .396 .246 r
s
.912 .668 .418 r
.70555 .22739 m .729 .20253 L .73635 .219 L p F P
.534 .396 .246 r
s
.794 .579 .37 r
.73635 .219 m .76143 .20823 L .76736 .23825 L p F P
.534 .396 .246 r
s
.866 .639 .406 r
.76143 .20823 m .73635 .219 L .729 .20253 L p F P
.534 .396 .246 r
s
.181 .114 .071 r
.34949 .34981 m .36301 .34863 L p .39378 .33036 L F P
.534 .396 .246 r
s
.266 .158 .098 r
.34513 .35871 m .36301 .34863 L .34949 .34981 L p F P
.534 .396 .246 r
s
.266 .158 .098 r
.34949 .34981 m .33 .35676 L .34513 .35871 L p F P
.534 .396 .246 r
s
.967 .746 .455 r
.45351 .29181 m .4601 .299 L .43401 .30946 L p F P
.534 .396 .246 r
s
.911 .683 .434 r
.48699 .28914 m .48874 .30546 L .4666 .3061 L p F P
.534 .396 .246 r
s
.911 .683 .434 r
.4666 .3061 m .4601 .299 L .48699 .28914 L p F P
.534 .396 .246 r
s
.729 .53 .342 r
.79745 .27839 m .77053 .27401 L .76736 .23825 L p F P
.534 .396 .246 r
s
.729 .53 .342 r
.76736 .23825 m .79402 .24039 L .79745 .27839 L p F P
.534 .396 .246 r
s
.741 .543 .352 r
.79402 .24039 m .76736 .23825 L .76143 .20823 L p F P
.534 .396 .246 r
s
1 .775 .474 r
.84528 .40033 m .86052 .37397 L .88355 .35275 L p F P
.534 .396 .246 r
s
.961 .704 .435 r
.89455 .31434 m .88355 .35275 L .86052 .37397 L p F P
.534 .396 .246 r
s
.938 .685 .425 r
.71211 .24091 m .68836 .27133 L .68257 .26081 L p F P
.534 .396 .246 r
s
.938 .685 .425 r
.68257 .26081 m .70555 .22739 L .71211 .24091 L p F P
.534 .396 .246 r
s
.726 .53 .343 r
.76647 .33747 m .79312 .35003 L .7847 .37277 L p F P
.534 .396 .246 r
s
.729 .529 .341 r
.79312 .35003 m .76647 .33747 L .77036 .30899 L p F P
.534 .396 .246 r
s
.728 .528 .34 r
.79731 .31698 m .77036 .30899 L .77053 .27401 L p F P
.534 .396 .246 r
s
.728 .528 .34 r
.77053 .27401 m .79745 .27839 L .79731 .31698 L p F P
.534 .396 .246 r
s
.979 .717 .441 r
.68836 .27133 m .69222 .28526 L .66804 .31484 L p F P
.534 .396 .246 r
s
.181 .114 .071 r
.36301 .34863 m .37796 .34381 L .39378 .33036 L p F P
.534 .396 .246 r
s
.313 .182 .113 r
.29164 .34599 m .2729 .32987 L .29216 .34709 L p F P
.534 .396 .246 r
s
.276 .208 .161 r
.27495 .33076 m .29216 .34709 L .2729 .32987 L p F P
.534 .396 .246 r
s
.729 .529 .341 r
.77036 .30899 m .79731 .31698 L .79312 .35003 L p F P
.534 .396 .246 r
s
.75 .553 .358 r
.7847 .37277 m .81065 .38438 L .7971 .39885 L p F P
.534 .396 .246 r
s
.835 .615 .392 r
.82158 .40553 m .7971 .39885 L .81065 .38438 L p F P
.534 .396 .246 r
s
.866 .639 .406 r
.729 .20253 m .7533 .18937 L .76143 .20823 L p F P
.534 .396 .246 r
s
.741 .543 .352 r
.76143 .20823 m .7876 .20907 L .79402 .24039 L p F P
.534 .396 .246 r
s
.782 .585 .38 r
.7876 .20907 m .76143 .20823 L .7533 .18937 L p F P
.534 .396 .246 r
s
1 .783 .476 r
.64291 .35358 m .61764 .37393 L .61743 .37091 L p F P
.534 .396 .246 r
s
1 .783 .476 r
.61743 .37091 m .64263 .34582 L .64291 .35358 L p F P
.534 .396 .246 r
s
.961 .704 .435 r
.86052 .37397 m .87091 .33888 L .89455 .31434 L p F P
.534 .396 .246 r
s
.923 .674 .42 r
.9014 .28111 m .89455 .31434 L .87091 .33888 L p F P
.534 .396 .246 r
s
.94 .694 .434 r
.84528 .40033 m .82158 .40553 L .83604 .38542 L p F P
.534 .396 .246 r
s
.94 .694 .434 r
.83604 .38542 m .86052 .37397 L .84528 .40033 L p F P
.534 .396 .246 r
s
.631 .481 .323 r
.55053 .36901 m .53159 .36637 L .51834 .35376 L p F P
.534 .396 .246 r
s
.631 .481 .323 r
.51834 .35376 m .52984 .35092 L .55053 .36901 L p F P
.534 .396 .246 r
s
.458 .375 .261 r
.49052 .31824 m .50801 .3239 L .5053 .33505 L p F P
.534 .396 .246 r
s
.771 .574 .372 r
.51082 .30636 m .50801 .3239 L .49052 .31824 L p F P
.534 .396 .246 r
s
.771 .574 .372 r
.49052 .31824 m .48874 .30546 L .51082 .30636 L p F P
.534 .396 .246 r
s
.755 .55 .354 r
.81065 .38438 m .7847 .37277 L .79312 .35003 L p F P
.534 .396 .246 r
s
.649 .486 .323 r
.52984 .35092 m .5053 .33505 L .50801 .3239 L p F P
.534 .396 .246 r
s
1 .756 .467 r
.729 .20253 m .70555 .22739 L .69725 .22193 L p F P
.534 .396 .246 r
s
1 .756 .467 r
.69725 .22193 m .71991 .1975 L .729 .20253 L p F P
.534 .396 .246 r
s
.992 .753 .471 r
.7533 .18937 m .729 .20253 L .71991 .1975 L p F P
.534 .396 .246 r
s
.658 .508 .339 r
.56453 .38429 m .54027 .37559 L .53159 .36637 L p F P
.534 .396 .246 r
s
.492 .41 .278 r
.54027 .37559 m .56453 .38429 L .56799 .38832 L p F P
.534 .396 .246 r
s
.305 .178 .111 r
.32728 .36237 m .34513 .35871 L .33 .35676 L p F P
.534 .396 .246 r
s
.305 .178 .111 r
.33 .35676 m .31068 .35559 L .32728 .36237 L p F P
.534 .396 .246 r
s
.835 .615 .392 r
.81065 .38438 m .83604 .38542 L .82158 .40553 L p F P
.534 .396 .246 r
s
.838 .661 .42 r
.59244 .38556 m .59264 .38659 L .56799 .38832 L p F P
.534 .396 .246 r
s
.838 .661 .42 r
.58803 .38058 m .59244 .38556 L p .56799 .38832 L F P
.534 .396 .246 r
s
.979 .717 .441 r
.68257 .26081 m .68836 .27133 L p .66804 .31484 L F P
.534 .396 .246 r
s
.944 .701 .44 r
.48529 .26987 m .48699 .28914 L .4601 .299 L p F P
.534 .396 .246 r
s
.944 .701 .44 r
.4601 .299 m .45351 .29181 L .48529 .26987 L p F P
.534 .396 .246 r
s
.331 .192 .119 r
.31068 .35559 m .29164 .34599 L .30959 .35834 L p F P
.534 .396 .246 r
s
.313 .182 .113 r
.29216 .34709 m .30959 .35834 L .29164 .34599 L p F P
.534 .396 .246 r
s
.997 .734 .452 r
.70555 .22739 m .68257 .26081 L .67508 .25481 L p F P
.534 .396 .246 r
s
.997 .734 .452 r
.67508 .25481 m .69725 .22193 L .70555 .22739 L p F P
.534 .396 .246 r
s
.187 .117 .073 r
.36195 .35536 m .37796 .34381 L .36301 .34863 L p F P
.534 .396 .246 r
s
.187 .117 .073 r
.36301 .34863 m .34513 .35871 L .36195 .35536 L p F P
.534 .396 .246 r
s
.658 .508 .339 r
.53159 .36637 m .55053 .36901 L .56453 .38429 L p F P
.534 .396 .246 r
s
.331 .192 .119 r
.30959 .35834 m .32728 .36237 L .31068 .35559 L p F P
.534 .396 .246 r
s
.933 .725 .444 r
.61764 .37393 m .59264 .38659 L .59244 .38556 L p F P
.534 .396 .246 r
s
.933 .725 .444 r
.59244 .38556 m .61743 .37091 L .61764 .37393 L p F P
.534 .396 .246 r
s
.978 .717 .442 r
.66804 .31484 m .64263 .34582 L .63574 .33495 L p F P
.534 .396 .246 r
s
.978 .717 .442 r
.63574 .33495 m .65971 .29804 L .66804 .31484 L p F P
.534 .396 .246 r
s
.979 .717 .441 r
.66804 .31484 m .65971 .29804 L .68257 .26081 L p F P
.534 .396 .246 r
s
.712 .521 .339 r
.82479 .28327 m .79745 .27839 L .79402 .24039 L p F P
.534 .396 .246 r
s
.712 .521 .339 r
.79402 .24039 m .82151 .24804 L .82479 .28327 L p F P
.534 .396 .246 r
s
.681 .507 .334 r
.82151 .24804 m .79402 .24039 L .7876 .20907 L p F P
.534 .396 .246 r
s
.732 .532 .344 r
.82435 .3216 m .79731 .31698 L .79745 .27839 L p F P
.534 .396 .246 r
s
.732 .532 .344 r
.79745 .27839 m .82479 .28327 L .82435 .3216 L p F P
.534 .396 .246 r
s
.923 .674 .42 r
.87091 .33888 m .87691 .30379 L .9014 .28111 L p F P
.534 .396 .246 r
s
.914 .673 .424 r
.90499 .26342 m .9014 .28111 L .87691 .30379 L p F P
.534 .396 .246 r
s
.891 .65 .408 r
.86052 .37397 m .83604 .38542 L .84579 .35413 L p F P
.534 .396 .246 r
s
.891 .65 .408 r
.84579 .35413 m .87091 .33888 L .86052 .37397 L p F P
.534 .396 .246 r
s
.796 .586 .376 r
.51373 .28311 m .51082 .30636 L .48874 .30546 L p F P
.534 .396 .246 r
s
.796 .586 .376 r
.48874 .30546 m .48699 .28914 L .51373 .28311 L p F P
.534 .396 .246 r
s
.092 .068 .042 r
.37796 .34381 m .39409 .33453 L p .42251 .31441 L F P
.534 .396 .246 r
s
.092 .068 .042 r
.39409 .33453 m .41115 .32084 L .42251 .31441 L p F P
.534 .396 .246 r
s
.755 .55 .354 r
.79312 .35003 m .81974 .35726 L .81065 .38438 L p F P
.534 .396 .246 r
s
.746 .542 .348 r
.81974 .35726 m .79312 .35003 L .79731 .31698 L p F P
.534 .396 .246 r
s
.992 .753 .471 r
.71991 .1975 m .74336 .18415 L .7533 .18937 L p F P
.534 .396 .246 r
s
.808 .636 .409 r
.77875 .18904 m .7533 .18937 L .74336 .18415 L p F P
.534 .396 .246 r
s
.782 .585 .38 r
.7533 .18937 m .77875 .18904 L .7876 .20907 L p F P
.534 .396 .246 r
s
.746 .542 .348 r
.79731 .31698 m .82435 .3216 L .81974 .35726 L p F P
.534 .396 .246 r
s
.47 .388 .268 r
.22333 .28539 m .25233 .29079 L .26754 .3083 L p F P
.534 .396 .246 r
s
.814 .593 .377 r
.83604 .38542 m .81065 .38438 L .81974 .35726 L p F P
.534 .396 .246 r
s
.87 .635 .4 r
.87091 .33888 m .84579 .35413 L .85101 .31794 L p F P
.534 .396 .246 r
s
.87 .635 .4 r
.85101 .31794 m .87691 .30379 L .87091 .33888 L p F P
.534 .396 .246 r
s
.681 .507 .334 r
.7876 .20907 m .81497 .21982 L .82151 .24804 L p F P
.534 .396 .246 r
s
.634 .488 .327 r
.81497 .21982 m .7876 .20907 L .77875 .18904 L p F P
.534 .396 .246 r
s
.565 .441 .301 r
.25784 .31263 m .24062 .29639 L .26754 .3083 L p F P
.534 .396 .246 r
s
.944 .701 .44 r
.48529 .26987 m .45351 .29181 L .44698 .28468 L p F P
.534 .396 .246 r
s
.869 .679 .41 r
.42887 .30367 m .44698 .28468 L .45351 .29181 L p F P
.534 .396 .246 r
s
.869 .679 .41 r
.41115 .32084 m .42887 .30367 L p .45351 .29181 L F P
.534 .396 .246 r
s
.957 .701 .434 r
.67508 .25481 m .68257 .26081 L .65971 .29804 L p F P
.534 .396 .246 r
s
.649 .486 .323 r
.50801 .3239 m .525 .3304 L p .52984 .35092 L F P
.534 .396 .246 r
s
.737 .542 .352 r
.53222 .30981 m .525 .3304 L .50801 .3239 L p F P
.534 .396 .246 r
s
.737 .542 .352 r
.50801 .3239 m .51082 .30636 L .53222 .30981 L p F P
.534 .396 .246 r
s
.804 .588 .375 r
.51673 .25605 m .51373 .28311 L .48699 .28914 L p F P
.534 .396 .246 r
s
.804 .588 .375 r
.48699 .28914 m .48529 .26987 L .51673 .25605 L p F P
.534 .396 .246 r
s
.814 .593 .377 r
.81974 .35726 m .84579 .35413 L .83604 .38542 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.38022 .34503 m .39409 .33453 L .37796 .34381 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.37796 .34381 m .36195 .35536 L .38022 .34503 L p F P
.534 .396 .246 r
s
.794 .578 .368 r
.84579 .35413 m .81974 .35726 L .82435 .3216 L p F P
.534 .396 .246 r
s
.791 .577 .369 r
.51673 .25605 m .48529 .26987 L .48353 .24941 L p F P
.534 .396 .246 r
s
.944 .701 .44 r
.46526 .26592 m .48353 .24941 L .48529 .26987 L p F P
.534 .396 .246 r
s
.944 .701 .44 r
.44698 .28468 m .46526 .26592 L p .48529 .26987 L F P
.534 .396 .246 r
s
.5 .394 .273 r
.27495 .33076 m .25784 .31263 L .2829 .3272 L p F P
.534 .396 .246 r
s
.565 .441 .301 r
.26754 .3083 m .2829 .3272 L .25784 .31263 L p F P
.534 .396 .246 r
s
1 .739 .457 r
.64263 .34582 m .61743 .37091 L .61183 .36374 L p F P
.534 .396 .246 r
s
1 .739 .457 r
.61183 .36374 m .63574 .33495 L .64263 .34582 L p F P
.534 .396 .246 r
s
.86 .635 .403 r
.87691 .30379 m .85101 .31794 L .85215 .284 L p F P
.534 .396 .246 r
s
.86 .635 .403 r
.85215 .284 m .87914 .27738 L .87691 .30379 L p F P
.534 .396 .246 r
s
.914 .673 .424 r
.87691 .30379 m .87914 .27738 L .90499 .26342 L p F P
.534 .396 .246 r
s
.189 .118 .073 r
.34588 .36243 m .36195 .35536 L .34513 .35871 L p F P
.534 .396 .246 r
s
.189 .118 .073 r
.34513 .35871 m .32728 .36237 L .34588 .36243 L p F P
.534 .396 .246 r
s
.794 .578 .368 r
.82435 .3216 m .85101 .31794 L .84579 .35413 L p F P
.534 .396 .246 r
s
.77 .563 .362 r
.85101 .31794 m .82435 .3216 L .82479 .28327 L p F P
.534 .396 .246 r
s
1 .777 .474 r
.69725 .22193 m .67508 .25481 L .66609 .25287 L p F P
.534 .396 .246 r
s
1 .777 .474 r
.66609 .25287 m .68739 .2236 L .69725 .22193 L p F P
.534 .396 .246 r
s
.968 .742 .448 r
.71991 .1975 m .69725 .22193 L .68739 .2236 L p F P
.534 .396 .246 r
s
.968 .742 .448 r
.68739 .2236 m .70921 .20265 L .71991 .1975 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.74336 .18415 m .71991 .1975 L .70921 .20265 L p F P
.534 .396 .246 r
s
.77 .563 .362 r
.82479 .28327 m .85215 .284 L .85101 .31794 L p F P
.534 .396 .246 r
s
.721 .535 .35 r
.85215 .284 m .82479 .28327 L .82151 .24804 L p F P
.534 .396 .246 r
s
.791 .577 .369 r
.48353 .24941 m .50166 .23676 L p .51673 .25605 L F P
.534 .396 .246 r
s
.83 .604 .383 r
.50222 .21247 m .50166 .23676 L .48353 .24941 L p F P
.534 .396 .246 r
s
.83 .604 .383 r
.48353 .24941 m .48178 .22875 L .50222 .21247 L p F P
.534 .396 .246 r
s
.892 .652 .409 r
.48178 .22875 m .48353 .24941 L .46526 .26592 L p F P
.534 .396 .246 r
s
.742 .541 .349 r
.53956 .28295 m .53222 .30981 L .51082 .30636 L p F P
.534 .396 .246 r
s
.742 .541 .349 r
.51082 .30636 m .51373 .28311 L .53956 .28295 L p F P
.534 .396 .246 r
s
.892 .652 .409 r
.46526 .26592 m .46112 .25127 L .48178 .22875 L p F P
.534 .396 .246 r
s
.958 .703 .436 r
.46112 .25127 m .46526 .26592 L .44698 .28468 L p F P
.534 .396 .246 r
s
.88 .682 .409 r
.39962 .32747 m .41115 .32084 L .39409 .33453 L p F P
.534 .396 .246 r
s
.88 .682 .409 r
.39409 .33453 m .38022 .34503 L .39962 .32747 L p F P
.534 .396 .246 r
s
.712 .525 .343 r
.55053 .36901 m .52984 .35092 L .54106 .33843 L p F P
.534 .396 .246 r
s
.649 .486 .323 r
.525 .3304 m .54106 .33843 L .52984 .35092 L p F P
.534 .396 .246 r
s
.791 .577 .369 r
.50166 .23676 m .51954 .22892 L .51673 .25605 L p F P
.534 .396 .246 r
s
.775 .564 .361 r
.52239 .20371 m .51954 .22892 L .50166 .23676 L p F P
.534 .396 .246 r
s
.775 .564 .361 r
.50166 .23676 m .50222 .21247 L .52239 .20371 L p F P
.534 .396 .246 r
s
.958 .703 .436 r
.44698 .28468 m .44039 .2775 L .46112 .25127 L p F P
.534 .396 .246 r
s
1 .755 .464 r
.44039 .2775 m .44698 .28468 L .42887 .30367 L p F P
.534 .396 .246 r
s
.845 .617 .39 r
.50281 .1908 m .50222 .21247 L .48178 .22875 L p F P
.534 .396 .246 r
s
.845 .617 .39 r
.48178 .22875 m .48002 .20941 L .50281 .1908 L p F P
.534 .396 .246 r
s
.906 .661 .413 r
.48002 .20941 m .48178 .22875 L .46112 .25127 L p F P
.534 .396 .246 r
s
.781 .57 .365 r
.5253 .1828 m .52239 .20371 L .50222 .21247 L p F P
.534 .396 .246 r
s
.781 .57 .365 r
.50222 .21247 m .50281 .1908 L .5253 .1828 L p F P
.534 .396 .246 r
s
1 .783 .476 r
.4198 .30405 m .42887 .30367 L .41115 .32084 L p F P
.534 .396 .246 r
s
1 .783 .476 r
.41115 .32084 m .39962 .32747 L .4198 .30405 L p F P
.534 .396 .246 r
s
.807 .601 .388 r
.57996 .37156 m .58803 .38058 L .56453 .38429 L p F P
.534 .396 .246 r
s
.807 .601 .388 r
.56899 .36008 m .57996 .37156 L p .56453 .38429 L F P
.534 .396 .246 r
s
.807 .601 .388 r
.56453 .38429 m .55053 .36901 L .56899 .36008 L p F P
.534 .396 .246 r
s
1 .755 .464 r
.42887 .30367 m .4198 .30405 L .44039 .2775 L p F P
.534 .396 .246 r
s
.721 .535 .35 r
.82151 .24804 m .84959 .25699 L .85215 .284 L p F P
.534 .396 .246 r
s
.59 .455 .308 r
.84959 .25699 m .82151 .24804 L .81497 .21982 L p F P
.534 .396 .246 r
s
.736 .535 .344 r
.54705 .25356 m .53956 .28295 L .51373 .28311 L p F P
.534 .396 .246 r
s
.736 .535 .344 r
.51373 .28311 m .51673 .25605 L .54705 .25356 L p F P
.534 .396 .246 r
s
.469 .377 .264 r
.29216 .34709 m .27495 .33076 L .29836 .34431 L p F P
.534 .396 .246 r
s
.5 .394 .273 r
.2829 .3272 m .29836 .34431 L .27495 .33076 L p F P
.534 .396 .246 r
s
.998 .748 .467 r
.61743 .37091 m .59244 .38556 L .58803 .38058 L p F P
.534 .396 .246 r
s
.957 .701 .434 r
.65971 .29804 m .63574 .33495 L .62326 .32309 L p F P
.534 .396 .246 r
s
.957 .701 .434 r
.62326 .32309 m .64503 .28708 L .65971 .29804 L p F P
.534 .396 .246 r
s
.957 .701 .434 r
.66609 .25287 m .67508 .25481 L p .65971 .29804 L F P
.534 .396 .246 r
s
.957 .701 .434 r
.65971 .29804 m .64503 .28708 L .66609 .25287 L p F P
.534 .396 .246 r
s
.808 .636 .409 r
.74336 .18415 m .76787 .18238 L .77875 .18904 L p F P
.534 .396 .246 r
s
.545 .449 .303 r
.80553 .20036 m .77875 .18904 L .76787 .18238 L p F P
.534 .396 .246 r
s
.634 .488 .327 r
.77875 .18904 m .80553 .20036 L .81497 .21982 L p F P
.534 .396 .246 r
s
.998 .748 .467 r
.58803 .38058 m .61183 .36374 L .61743 .37091 L p F P
.534 .396 .246 r
s
.728 .533 .345 r
.55243 .31663 m .54106 .33843 L .525 .3304 L p F P
.534 .396 .246 r
s
.728 .533 .345 r
.525 .3304 m .53222 .30981 L .55243 .31663 L p F P
.534 .396 .246 r
s
.733 .532 .343 r
.54705 .25356 m .51673 .25605 L .51954 .22892 L p F P
.534 .396 .246 r
s
.733 .532 .343 r
.51954 .22892 m .53711 .22601 L p .54705 .25356 L F P
.534 .396 .246 r
s
.731 .532 .343 r
.54224 .20232 m .53711 .22601 L .51954 .22892 L p F P
.534 .396 .246 r
s
.731 .532 .343 r
.51954 .22892 m .52239 .20371 L .54224 .20232 L p F P
.534 .396 .246 r
s
.794 .584 .375 r
.5283 .16783 m .5253 .1828 L .50281 .1908 L p F P
.534 .396 .246 r
s
.794 .584 .375 r
.50281 .1908 m .50343 .17349 L .5283 .16783 L p F P
.534 .396 .246 r
s
.871 .638 .403 r
.50343 .17349 m .50281 .1908 L .48002 .20941 L p F P
.534 .396 .246 r
s
.906 .661 .413 r
.46112 .25127 m .45697 .2371 L .48002 .20941 L p F P
.534 .396 .246 r
s
.871 .638 .403 r
.48002 .20941 m .47826 .19284 L .50343 .17349 L p F P
.534 .396 .246 r
s
.925 .676 .421 r
.47826 .19284 m .48002 .20941 L .45697 .2371 L p F P
.534 .396 .246 r
s
.958 .702 .434 r
.45697 .2371 m .46112 .25127 L .44039 .2775 L p F P
.534 .396 .246 r
s
.722 .528 .343 r
.54749 .18477 m .54224 .20232 L .52239 .20371 L p F P
.534 .396 .246 r
s
.722 .528 .343 r
.52239 .20371 m .5253 .1828 L .54749 .18477 L p F P
.534 .396 .246 r
s
.168 .107 .067 r
.32986 .36319 m .34588 .36243 L .32728 .36237 L p F P
.534 .396 .246 r
s
.168 .107 .067 r
.32728 .36237 m .30959 .35834 L .32986 .36319 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.70921 .20265 m .73176 .19125 L .74336 .18415 L p F P
.534 .396 .246 r
s
.132 .088 .055 r
.76787 .18238 m .74336 .18415 L .73176 .19125 L p F P
.534 .396 .246 r
s
.762 .584 .382 r
.87914 .27738 m .85215 .284 L .84959 .25699 L p F P
.534 .396 .246 r
s
.47 .387 .268 r
.30959 .35834 m .29216 .34709 L .31401 .35693 L p F P
.534 .396 .246 r
s
.469 .377 .264 r
.29836 .34431 m .31401 .35693 L .29216 .34709 L p F P
.534 .396 .246 r
s
.712 .525 .343 r
.55585 .34847 m .56899 .36008 L .55053 .36901 L p F P
.534 .396 .246 r
s
.712 .525 .343 r
.54106 .33843 m .55585 .34847 L p .55053 .36901 L F P
.534 .396 .246 r
s
.845 .644 .415 r
.90542 .26322 m .90499 .26342 L .88752 .27286 L p F P
.534 .396 .246 r
s
.845 .644 .415 r
.88952 .27179 m .90542 .26322 L .88752 .27286 L F
.88752 .27286 m .87914 .27738 L p .88952 .27179 L F P
.534 .396 .246 r
s
.845 .644 .415 r
.87914 .27738 m .87788 .26299 L .90542 .26322 L p F P
.534 .396 .246 r
s
.472 .389 .268 r
.90153 .26899 m .90542 .26322 L .87788 .26299 L p F P
.534 .396 .246 r
s
.472 .389 .268 r
.87788 .26299 m .87264 .255 L .89798 .26727 L p F P
.534 .396 .246 r
s
.472 .389 .268 r
.89798 .26727 m .90153 .26899 L p .89694 .26782 L F P
.534 .396 .246 r
s
.472 .389 .268 r
.87788 .26299 m .89798 .26727 L .89694 .26782 L F
.709 .571 .348 r
.36624 .35284 m .38022 .34503 L .36195 .35536 L p F P
.534 .396 .246 r
s
.709 .571 .348 r
.36195 .35536 m .34588 .36243 L .36624 .35284 L p F P
.534 .396 .246 r
s
.47 .387 .268 r
.31401 .35693 m .32986 .36319 L .30959 .35834 L p F P
.534 .396 .246 r
s
.958 .702 .434 r
.44039 .2775 m .43376 .27025 L .45697 .2371 L p F P
.534 .396 .246 r
s
1 .739 .454 r
.43376 .27025 m .44039 .2775 L .4198 .30405 L p F P
.534 .396 .246 r
s
.925 .676 .421 r
.45697 .2371 m .45278 .22421 L .47826 .19284 L p F P
.534 .396 .246 r
s
.914 .675 .425 r
.50408 .16169 m .50343 .17349 L .47826 .19284 L p F P
.534 .396 .246 r
s
.914 .675 .425 r
.47826 .19284 m .47648 .18022 L .50408 .16169 L p F P
.534 .396 .246 r
s
.951 .698 .434 r
.47648 .18022 m .47826 .19284 L .45278 .22421 L p F P
.534 .396 .246 r
s
.958 .701 .433 r
.45278 .22421 m .45697 .2371 L .43376 .27025 L p F P
.534 .396 .246 r
s
.733 .532 .343 r
.53711 .22601 m .5543 .22744 L .54705 .25356 L p F P
.534 .396 .246 r
s
.701 .511 .332 r
.5617 .20696 m .5543 .22744 L .53711 .22601 L p F P
.534 .396 .246 r
s
.701 .511 .332 r
.53711 .22601 m .54224 .20232 L .5617 .20696 L p F P
.534 .396 .246 r
s
.762 .584 .382 r
.84959 .25699 m .87788 .26299 L .87914 .27738 L p F P
.534 .396 .246 r
s
.729 .53 .342 r
.56395 .28877 m .55243 .31663 L .53222 .30981 L p F P
.534 .396 .246 r
s
.729 .53 .342 r
.53222 .30981 m .53956 .28295 L .56395 .28877 L p F P
.534 .396 .246 r
s
.815 .609 .393 r
.5314 .15937 m .5283 .16783 L .50343 .17349 L p F P
.534 .396 .246 r
s
.815 .609 .393 r
.50343 .17349 m .50408 .16169 L .5314 .15937 L p F P
.534 .396 .246 r
s
.706 .522 .342 r
.55291 .17447 m .54749 .18477 L .5253 .1828 L p F P
.534 .396 .246 r
s
.706 .522 .342 r
.5253 .1828 m .5283 .16783 L .55291 .17447 L p F P
.534 .396 .246 r
s
.59 .455 .308 r
.81497 .21982 m .84343 .23678 L .84959 .25699 L p F P
.534 .396 .246 r
s
.437 .355 .251 r
.84343 .23678 m .81497 .21982 L .80553 .20036 L p F P
.534 .396 .246 r
s
.742 .541 .349 r
.57106 .32693 m .55585 .34847 L .54106 .33843 L p F P
.534 .396 .246 r
s
.742 .541 .349 r
.54106 .33843 m .55243 .31663 L .57106 .32693 L p F P
.534 .396 .246 r
s
.932 .684 .427 r
.63574 .33495 m .61183 .36374 L .60156 .35275 L p F P
.534 .396 .246 r
s
.932 .684 .427 r
.60156 .35275 m .62326 .32309 L .63574 .33495 L p F P
.534 .396 .246 r
s
.722 .523 .338 r
.57567 .26022 m .56395 .28877 L .53956 .28295 L p F P
.534 .396 .246 r
s
.722 .523 .338 r
.53956 .28295 m .54705 .25356 L .57567 .26022 L p F P
.534 .396 .246 r
s
.904 .668 .421 r
.61183 .36374 m .58803 .38058 L .57996 .37156 L p F P
.534 .396 .246 r
s
.676 .497 .326 r
.56932 .19428 m .5617 .20696 L .54224 .20232 L p F P
.534 .396 .246 r
s
.676 .497 .326 r
.54224 .20232 m .54749 .18477 L .56932 .19428 L p F P
.534 .396 .246 r
s
1 .779 .472 r
.68739 .2236 m .66609 .25287 L .65572 .25328 L p F P
.534 .396 .246 r
s
1 .779 .472 r
.65572 .25328 m .67602 .22943 L .68739 .2236 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.70921 .20265 m .68739 .2236 L .67602 .22943 L p F P
.534 .396 .246 r
s
1 .739 .454 r
.4198 .30405 m .41063 .30387 L .43376 .27025 L p F P
.534 .396 .246 r
s
1 .773 .473 r
.41063 .30387 m .4198 .30405 L .39962 .32747 L p F P
.534 .396 .246 r
s
.726 .528 .341 r
.57567 .26022 m .54705 .25356 L .5543 .22744 L p F P
.534 .396 .246 r
s
.922 .678 .425 r
.65572 .25328 m .66609 .25287 L .64503 .28708 L p F P
.534 .396 .246 r
s
1 .776 .473 r
.38797 .33273 m .39962 .32747 L .38022 .34503 L p F P
.534 .396 .246 r
s
1 .776 .473 r
.38022 .34503 m .36624 .35284 L .38797 .33273 L p F P
.534 .396 .246 r
s
.958 .701 .433 r
.43376 .27025 m .42706 .26295 L .45278 .22421 L p F P
.534 .396 .246 r
s
.951 .698 .434 r
.45278 .22421 m .44854 .21338 L .47648 .18022 L p F P
.534 .396 .246 r
s
.958 .701 .433 r
.44854 .21338 m .45278 .22421 L .42706 .26295 L p F P
.534 .396 .246 r
s
.904 .668 .421 r
.57996 .37156 m .60156 .35275 L .61183 .36374 L p F P
.534 .396 .246 r
s
1 .773 .473 r
.39962 .32747 m .38797 .33273 L .41063 .30387 L p F P
.534 .396 .246 r
s
.934 .727 .452 r
.47467 .17237 m .47283 .16958 L .48207 .16557 L p F P
.534 .396 .246 r
s
.977 .734 .46 r
.50476 .1558 m .50408 .16169 L .4978 .16591 L p F P
.534 .396 .246 r
s
.977 .734 .46 r
.49317 .16581 m .50476 .1558 L .4978 .16591 L F
.47648 .18022 m .47467 .17237 L .50476 .1558 L p F P
.534 .396 .246 r
s
.803 .623 .404 r
.50408 .16169 m .50476 .1558 L .53463 .15687 L p F P
.534 .396 .246 r
s
.803 .623 .404 r
.5314 .15937 m .50408 .16169 L p .52669 .15812 L F P
.534 .396 .246 r
s
.803 .623 .404 r
.53463 .15687 m .532 .15891 L p .52669 .15812 L F P
.534 .396 .246 r
s
.803 .623 .404 r
.532 .15891 m .5314 .15937 L p .52669 .15812 L F P
.534 .396 .246 r
s
.495 .421 .274 r
.51241 .15608 m .50476 .1558 L p .51044 .15629 L F P
.534 .396 .246 r
s
.492 .403 .278 r
.5314 .15937 m .53463 .15687 L .56436 .17248 L p F P
.534 .396 .246 r
s
.495 .421 .274 r
.51044 .15629 m .53797 .15867 L .51241 .15608 L F
.50476 .1558 m .50549 .15541 L .51464 .15633 L p F P
.534 .396 .246 r
s
.495 .421 .274 r
.51464 .15633 m .53797 .15867 L p .51984 .1571 L F P
.534 .396 .246 r
s
.495 .421 .274 r
.50476 .1558 m .51464 .15633 L .51984 .1571 L F
.53797 .15867 m .53463 .15687 L .51241 .15608 L p F P
.534 .396 .246 r
s
.934 .727 .452 r
.48683 .16567 m .47467 .17237 L p .48684 .16568 L F P
.534 .396 .246 r
s
.934 .727 .452 r
.47467 .17237 m .48207 .16557 L .48684 .16568 L F
1 .767 .474 r
.47283 .16958 m .47467 .17237 L .44424 .20519 L p F P
.534 .396 .246 r
s
1 .767 .474 r
.44424 .20519 m .43987 .20004 L .47283 .16958 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.47283 .16958 m .47094 .1716 L .48496 .16673 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.48496 .16673 m .50625 .15932 L p .4885 .16477 L F P
.534 .396 .246 r
s
.934 .727 .452 r
.48684 .16568 m .49409 .16169 L .48683 .16567 L F
.49409 .16169 m .49526 .16104 L .48683 .16567 L F
.50549 .15541 m .50476 .1558 L .48683 .16567 L p F P
.534 .396 .246 r
s
.934 .727 .452 r
.48207 .16557 m .50109 .15732 L p .48684 .16568 L F P
.534 .396 .246 r
s
.934 .727 .452 r
.49409 .16169 m .50549 .15541 L .49526 .16104 L F
.48684 .16568 m .50109 .15732 L .50225 .15719 L F
.089 .066 .041 r
.47283 .16958 m .48496 .16673 L .4885 .16477 L F
.934 .727 .452 r
.50109 .15732 m .50549 .15541 L p .50225 .15719 L F P
.534 .396 .246 r
s
.977 .734 .46 r
.4978 .16591 m .47648 .18022 L p .49317 .16581 L F P
.534 .396 .246 r
s
.987 .729 .452 r
.47467 .17237 m .47648 .18022 L .44854 .21338 L p F P
.534 .396 .246 r
s
.726 .528 .341 r
.5543 .22744 m .57103 .23205 L p .57567 .26022 L F P
.534 .396 .246 r
s
.689 .503 .328 r
.58069 .21542 m .57103 .23205 L .5543 .22744 L p F P
.534 .396 .246 r
s
.689 .503 .328 r
.5543 .22744 m .5617 .20696 L .58069 .21542 L p F P
.534 .396 .246 r
s
.701 .52 .341 r
.25233 .29079 m .28435 .28787 L .29747 .30957 L p F P
.534 .396 .246 r
s
.701 .52 .341 r
.29747 .30957 m .26754 .3083 L .25233 .29079 L p F P
.534 .396 .246 r
s
.981 .72 .443 r
.42706 .26295 m .43376 .27025 L .41063 .30387 L p F P
.534 .396 .246 r
s
.775 .566 .363 r
.58766 .33967 m .56899 .36008 L .55585 .34847 L p F P
.534 .396 .246 r
s
.775 .566 .363 r
.55585 .34847 m .57106 .32693 L .58766 .33967 L p F P
.534 .396 .246 r
s
.419 .34 .24 r
.87788 .26299 m .84959 .25699 L .84343 .23678 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.67602 .22943 m .69688 .21389 L .70921 .20265 L p F P
.534 .396 .246 r
s
.147 .096 .06 r
.73176 .19125 m .70921 .20265 L .69688 .21389 L p F P
.534 .396 .246 r
s
.749 .544 .35 r
.58642 .29891 m .57106 .32693 L .55243 .31663 L p F P
.534 .396 .246 r
s
.749 .544 .35 r
.55243 .31663 m .56395 .28877 L .58642 .29891 L p F P
.534 .396 .246 r
s
.658 .501 .334 r
.55854 .17101 m .55291 .17447 L .5283 .16783 L p F P
.534 .396 .246 r
s
.658 .501 .334 r
.5283 .16783 m .5314 .15937 L .55854 .17101 L p F P
.534 .396 .246 r
s
.915 .67 .419 r
.64503 .28708 m .62326 .32309 L .60645 .31094 L p F P
.534 .396 .246 r
s
.915 .67 .419 r
.60645 .31094 m .62542 .27959 L .64503 .28708 L p F P
.534 .396 .246 r
s
.922 .678 .425 r
.64409 .25391 m .65572 .25328 L p .64503 .28708 L F P
.534 .396 .246 r
s
.922 .678 .425 r
.64503 .28708 m .62542 .27959 L .64409 .25391 L p F P
.534 .396 .246 r
s
.828 .607 .387 r
.60156 .35275 m .57996 .37156 L .56899 .36008 L p F P
.534 .396 .246 r
s
.907 .708 .446 r
.35222 .35602 m .36624 .35284 L .34588 .36243 L p F P
.534 .396 .246 r
s
.907 .708 .446 r
.34588 .36243 m .32986 .36319 L .35222 .35602 L p F P
.534 .396 .246 r
s
.828 .607 .387 r
.56899 .36008 m .58766 .33967 L .60156 .35275 L p F P
.534 .396 .246 r
s
.624 .467 .313 r
.57723 .18972 m .56932 .19428 L .54749 .18477 L p F P
.534 .396 .246 r
s
.624 .467 .313 r
.54749 .18477 m .55291 .17447 L .57723 .18972 L p F P
.534 .396 .246 r
s
.132 .088 .055 r
.73176 .19125 m .75515 .18832 L .76787 .18238 L p F P
.534 .396 .246 r
s
.545 .449 .303 r
.76787 .18238 m .79353 .19047 L .80553 .20036 L p F P
.534 .396 .246 r
s
.152 .099 .061 r
.79353 .19047 m .76787 .18238 L .75515 .18832 L p F P
.534 .396 .246 r
s
.694 .513 .337 r
.2829 .3272 m .26754 .3083 L .29747 .30957 L p F P
.534 .396 .246 r
s
.754 .548 .352 r
.60201 .27056 m .58642 .29891 L .56395 .28877 L p F P
.534 .396 .246 r
s
.754 .548 .352 r
.56395 .28877 m .57567 .26022 L .60201 .27056 L p F P
.534 .396 .246 r
s
.958 .701 .433 r
.42706 .26295 m .42032 .25559 L .44854 .21338 L p F P
.534 .396 .246 r
s
.987 .729 .452 r
.44854 .21338 m .44424 .20519 L .47467 .17237 L p F P
.534 .396 .246 r
s
.958 .702 .435 r
.44424 .20519 m .44854 .21338 L .42032 .25559 L p F P
.534 .396 .246 r
s
.864 .632 .398 r
.62326 .32309 m .60156 .35275 L .58766 .33967 L p F P
.534 .396 .246 r
s
.864 .632 .398 r
.58766 .33967 m .60645 .31094 L .62326 .32309 L p F P
.534 .396 .246 r
s
.65 .481 .319 r
.59069 .20785 m .58069 .21542 L .5617 .20696 L p F P
.534 .396 .246 r
s
.65 .481 .319 r
.5617 .20696 m .56932 .19428 L .59069 .20785 L p F P
.534 .396 .246 r
s
.462 .379 .264 r
.83358 .21992 m .80553 .20036 L .79353 .19047 L p F P
.534 .396 .246 r
s
.437 .355 .251 r
.80553 .20036 m .83358 .21992 L .84343 .23678 L p F P
.534 .396 .246 r
s
.798 .581 .37 r
.60645 .31094 m .58766 .33967 L .57106 .32693 L p F P
.534 .396 .246 r
s
.798 .581 .37 r
.57106 .32693 m .58642 .29891 L .60645 .31094 L p F P
.534 .396 .246 r
s
.726 .528 .341 r
.57103 .23205 m .58721 .23835 L .57567 .26022 L p F P
.534 .396 .246 r
s
.697 .512 .334 r
.59908 .22511 m .58721 .23835 L .57103 .23205 L p F P
.534 .396 .246 r
s
.697 .512 .334 r
.57103 .23205 m .58069 .21542 L .59908 .22511 L p F P
.534 .396 .246 r
s
.981 .72 .443 r
.41063 .30387 m .4014 .30227 L .42706 .26295 L p F P
.534 .396 .246 r
s
1 .741 .457 r
.4014 .30227 m .41063 .30387 L .38797 .33273 L p F P
.534 .396 .246 r
s
1 .768 .468 r
.67602 .22943 m .65572 .25328 L .64409 .25391 L p F P
.534 .396 .246 r
s
.762 .557 .358 r
.60201 .27056 m .57567 .26022 L .58721 .23835 L p F P
.534 .396 .246 r
s
.955 .699 .432 r
.42032 .25559 m .42706 .26295 L .4014 .30227 L p F P
.534 .396 .246 r
s
.701 .521 .342 r
.29836 .34431 m .2829 .3272 L .31089 .32906 L p F P
.534 .396 .246 r
s
.694 .513 .337 r
.29747 .30957 m .31089 .32906 L .2829 .3272 L p F P
.534 .396 .246 r
s
.842 .641 .413 r
.33828 .35326 m .35222 .35602 L .32986 .36319 L p F P
.534 .396 .246 r
s
.842 .641 .413 r
.32986 .36319 m .31401 .35693 L .33828 .35326 L p F P
.534 .396 .246 r
s
1 .766 .474 r
.37626 .33507 m .38797 .33273 L .36624 .35284 L p F P
.534 .396 .246 r
s
1 .766 .474 r
.36624 .35284 m .35222 .35602 L .37626 .33507 L p F P
.534 .396 .246 r
s
.83 .606 .385 r
.62542 .27959 m .60645 .31094 L .58642 .29891 L p F P
.534 .396 .246 r
s
.83 .606 .385 r
.58642 .29891 m .60201 .27056 L .62542 .27959 L p F P
.534 .396 .246 r
s
.147 .096 .06 r
.69688 .21389 m .71842 .20617 L .73176 .19125 L p F P
.534 .396 .246 r
s
.205 .126 .078 r
.75515 .18832 m .73176 .19125 L .71842 .20617 L p F P
.534 .396 .246 r
s
1 .768 .468 r
.64409 .25391 m .66318 .23569 L .67602 .22943 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.69688 .21389 m .67602 .22943 L .66318 .23569 L p F P
.534 .396 .246 r
s
1 .741 .457 r
.38797 .33273 m .37626 .33507 L .4014 .30227 L p F P
.534 .396 .246 r
s
.748 .561 .367 r
.31401 .35693 m .29836 .34431 L .32449 .34409 L p F P
.534 .396 .246 r
s
.701 .521 .342 r
.31089 .32906 m .32449 .34409 L .29836 .34431 L p F P
.534 .396 .246 r
s
.748 .561 .367 r
.32449 .34409 m .33828 .35326 L .31401 .35693 L p F P
.534 .396 .246 r
s
.84 .617 .393 r
.63129 .25308 m .64409 .25391 L .62542 .27959 L p F P
.534 .396 .246 r
s
.84 .617 .393 r
.61746 .24999 m .63129 .25308 L p .62542 .27959 L F P
.534 .396 .246 r
s
.84 .617 .393 r
.62542 .27959 m .60201 .27056 L .61746 .24999 L p F P
.534 .396 .246 r
s
.419 .34 .24 r
.84343 .23678 m .87264 .255 L .87788 .26299 L p F P
.534 .396 .246 r
s
.237 .143 .089 r
.53463 .15687 m .53797 .15867 L .5526 .1664 L p F P
.534 .396 .246 r
s
.492 .403 .278 r
.55854 .17101 m .53956 .16286 L p .56357 .17216 L F P
.534 .396 .246 r
s
.492 .403 .278 r
.53956 .16286 m .5314 .15937 L p .54156 .16341 L F P
.534 .396 .246 r
s
.492 .403 .278 r
.54156 .16341 m .56357 .17216 L .53956 .16286 L F
.56399 .17239 m .55854 .17101 L p .56357 .17216 L F P
.534 .396 .246 r
s
.383 .305 .221 r
.55854 .17101 m .56436 .17248 L .5939 .19646 L p F P
.534 .396 .246 r
s
.342 .271 .198 r
.60254 .20001 m .5939 .19646 L .58594 .19 L p F P
.534 .396 .246 r
s
.342 .271 .198 r
.58594 .19 m .56436 .17248 L p .58432 .18687 L F P
.534 .396 .246 r
s
.342 .271 .198 r
.58432 .18687 m .60254 .20001 L .58594 .19 L F
.56436 .17248 m .57036 .17579 L p .5717 .17746 L F P
.534 .396 .246 r
s
.342 .271 .198 r
.56436 .17248 m .58061 .18351 L .58432 .18687 L F
.237 .143 .089 r
.5526 .1664 m .57036 .17579 L p .55666 .16853 L F P
.534 .396 .246 r
s
.237 .143 .089 r
.53463 .15687 m .5526 .1664 L .55666 .16853 L F
.492 .403 .278 r
.56436 .17248 m .56399 .17239 L p .56357 .17216 L F P
.534 .396 .246 r
s
.237 .143 .089 r
.57036 .17579 m .56436 .17248 L .53975 .15956 L p F P
.534 .396 .246 r
s
.237 .143 .089 r
.53975 .15956 m .53463 .15687 L p .54138 .16044 L F P
.534 .396 .246 r
s
.237 .143 .089 r
.54138 .16044 m .57036 .17579 L .53975 .15956 L F
.245 .147 .091 r
.54142 .16228 m .54482 .16475 L p .56128 .17126 L F P
.534 .396 .246 r
s
.275 .163 .101 r
.57036 .17579 m .5526 .1664 L p .56872 .17374 L F P
.534 .396 .246 r
s
.275 .163 .101 r
.57646 .17727 m .57036 .17579 L p .56872 .17374 L F P
.534 .396 .246 r
s
.245 .147 .091 r
.57646 .17727 m .55706 .16897 L p .56128 .17126 L F P
.534 .396 .246 r
s
.245 .147 .091 r
.55706 .16897 m .54142 .16228 L p .56128 .17126 L F P
.534 .396 .246 r
s
.342 .271 .198 r
.57036 .17579 m .58061 .18351 L p .5717 .17746 L F P
.534 .396 .246 r
s
.342 .271 .198 r
.58061 .18351 m .60254 .20001 L p .58432 .18687 L F P
.534 .396 .246 r
s
.275 .163 .101 r
.55572 .16725 m .57646 .17727 L .5526 .1664 L F
.5526 .1664 m .53797 .15867 L p .55572 .16725 L F P
.534 .396 .246 r
s
.275 .163 .101 r
.53797 .15867 m .54142 .16228 L .57646 .17727 L p F P
.534 .396 .246 r
s
.245 .147 .091 r
.57646 .17727 m .57164 .17536 L .5767 .17223 L F
.57164 .17536 m .56295 .17193 L .56798 .17204 L F
.57164 .17536 m .56798 .17204 L .5767 .17223 L F
.54482 .16475 m .55295 .16666 L p .56295 .17193 L F P
.534 .396 .246 r
s
.245 .147 .091 r
.55295 .16666 m .5767 .17223 L p .56295 .17193 L F P
.534 .396 .246 r
s
.245 .147 .091 r
.5767 .17223 m .58245 .17358 L .57863 .17594 L p F P
.534 .396 .246 r
s
.245 .147 .091 r
.57863 .17594 m .57646 .17727 L p .5767 .17223 L F P
.534 .396 .246 r
s
.958 .702 .435 r
.42032 .25559 m .41352 .24817 L .44424 .20519 L p F P
.534 .396 .246 r
s
.958 .704 .437 r
.43987 .20004 m .44424 .20519 L .41352 .24817 L p F P
.534 .396 .246 r
s
.762 .557 .358 r
.58721 .23835 m .60273 .24478 L p .60201 .27056 L F P
.534 .396 .246 r
s
.734 .543 .354 r
.61671 .23352 m .60273 .24478 L .58721 .23835 L p F P
.534 .396 .246 r
s
.734 .543 .354 r
.58721 .23835 m .59908 .22511 L .61671 .23352 L p F P
.534 .396 .246 r
s
.762 .557 .358 r
.60273 .24478 m .61746 .24999 L .60201 .27056 L p F P
.534 .396 .246 r
s
.955 .699 .432 r
.4014 .30227 m .39213 .29847 L .42032 .25559 L p F P
.534 .396 .246 r
s
.925 .675 .42 r
.41352 .24817 m .42032 .25559 L .39213 .29847 L p F P
.534 .396 .246 r
s
.5 .392 .272 r
.58543 .19157 m .57723 .18972 L .55291 .17447 L p F P
.534 .396 .246 r
s
.5 .392 .272 r
.55291 .17447 m .55854 .17101 L .58543 .19157 L p F P
.534 .396 .246 r
s
.364 .289 .211 r
.87264 .255 m .84343 .23678 L .83358 .21992 L p F P
.534 .396 .246 r
s
1 .768 .476 r
.66318 .23569 m .64409 .25391 L .63129 .25308 L p F P
.534 .396 .246 r
s
.648 .486 .324 r
.61141 .22161 m .59908 .22511 L .58069 .21542 L p F P
.534 .396 .246 r
s
.648 .486 .324 r
.58069 .21542 m .59069 .20785 L .61141 .22161 L p F P
.534 .396 .246 r
s
.949 .697 .433 r
.39213 .29847 m .4014 .30227 L .37626 .33507 L p F P
.534 .396 .246 r
s
.557 .426 .291 r
.60109 .20863 m .59069 .20785 L .56932 .19428 L p F P
.534 .396 .246 r
s
.557 .426 .291 r
.56932 .19428 m .57723 .18972 L .60109 .20863 L p F P
.534 .396 .246 r
s
.813 .608 .392 r
.63339 .23863 m .61746 .24999 L .60273 .24478 L p F P
.534 .396 .246 r
s
.813 .608 .392 r
.60273 .24478 m .61671 .23352 L .63339 .23863 L p F P
.534 .396 .246 r
s
.933 .692 .435 r
.36454 .33315 m .37626 .33507 L .35222 .35602 L p F P
.534 .396 .246 r
s
.933 .692 .435 r
.35222 .35602 m .33828 .35326 L .36454 .33315 L p F P
.534 .396 .246 r
s
.727 .528 .341 r
.28435 .28787 m .31891 .27466 L .33 .29609 L p F P
.534 .396 .246 r
s
.727 .528 .341 r
.33 .29609 m .29747 .30957 L .28435 .28787 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.66318 .23569 m .68288 .22601 L .69688 .21389 L p F P
.534 .396 .246 r
s
.213 .133 .085 r
.71842 .20617 m .69688 .21389 L .68288 .22601 L p F P
.534 .396 .246 r
s
1 .768 .476 r
.63129 .25308 m .64893 .23931 L .66318 .23569 L p F P
.534 .396 .246 r
s
.929 .704 .446 r
.64893 .23931 m .63129 .25308 L .61746 .24999 L p F P
.534 .396 .246 r
s
.929 .704 .446 r
.61746 .24999 m .63339 .23863 L .64893 .23931 L p F P
.534 .396 .246 r
s
.949 .697 .433 r
.37626 .33507 m .36454 .33315 L .39213 .29847 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.50625 .15932 m .50549 .15541 L .47283 .16958 L p F P
.534 .396 .246 r
s
1 .778 .478 r
.47094 .1716 m .47283 .16958 L .43987 .20004 L p F P
.534 .396 .246 r
s
.925 .675 .42 r
.39213 .29847 m .38285 .29181 L .41352 .24817 L p F P
.534 .396 .246 r
s
.958 .704 .437 r
.41352 .24817 m .40666 .24069 L .43987 .20004 L p F P
.534 .396 .246 r
s
.89 .649 .406 r
.40666 .24069 m .41352 .24817 L .38285 .29181 L p F P
.534 .396 .246 r
s
.092 .068 .042 r
.66318 .23569 m .64893 .23931 L p .65897 .23538 L F P
.534 .396 .246 r
s
.092 .068 .042 r
.66579 .23441 m .66318 .23569 L p .65897 .23538 L F P
.534 .396 .246 r
s
.092 .068 .042 r
.68288 .22601 m .66579 .23441 L p .65897 .23538 L F P
.534 .396 .246 r
s
.092 .068 .042 r
.66719 .23455 m .68288 .22601 L p .66623 .23254 L F P
.534 .396 .246 r
s
.092 .068 .042 r
.64893 .23931 m .66719 .23455 L p .66623 .23254 L F P
.534 .396 .246 r
s
.444 .364 .253 r
.63124 .23211 m .61141 .22161 L p .63163 .23109 L F P
.534 .396 .246 r
s
.089 .066 .041 r
.66719 .23455 m .64893 .23931 L .63929 .23889 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.63893 .23852 m .66719 .23455 L .63929 .23889 L F
.63709 .23818 m .6376 .23812 L .637 .23879 L F
.6376 .23812 m .66719 .23455 L .63805 .23864 L F
.6376 .23812 m .63805 .23864 L .637 .23879 L F
.369 .294 .213 r
.62424 .22613 m .60109 .20863 L p .62297 .22411 L F P
.534 .396 .246 r
s
.444 .364 .253 r
.62424 .22613 m .63007 .22925 L p .62486 .22712 L F P
.534 .396 .246 r
s
.703 .562 .368 r
.63124 .23211 m .63776 .23375 L p .62922 .23365 L F P
.534 .396 .246 r
s
.703 .562 .368 r
.61671 .23352 m .62829 .23239 L p .62922 .23365 L F P
.534 .396 .246 r
s
.703 .562 .368 r
.62829 .23239 m .63124 .23211 L p .62922 .23365 L F P
.534 .396 .246 r
s
.369 .294 .213 r
.60109 .20863 m .61187 .21472 L .61962 .22067 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.637 .23879 m .63339 .23863 L p .63709 .23818 L F P
.534 .396 .246 r
s
.089 .066 .041 r
.63339 .23863 m .64558 .23728 L p .65132 .23647 L F P
.534 .396 .246 r
s
.089 .066 .041 r
.65006 .23665 m .64991 .2368 L .65132 .23647 L F
.64558 .23728 m .64991 .2368 L p .65006 .23665 L F P
.534 .396 .246 r
s
.703 .562 .368 r
.63775 .23382 m .64861 .23667 L p .63749 .23557 L F P
.534 .396 .246 r
s
.703 .562 .368 r
.61671 .23352 m .63776 .23375 L .63749 .23557 L F
.64991 .2368 m .63339 .23863 L .61671 .23352 L p F P
.534 .396 .246 r
s
.242 .145 .09 r
.64991 .2368 m .63124 .23211 L p .64975 .23697 L F P
.534 .396 .246 r
s
.242 .145 .09 r
.66705 .24152 m .64991 .2368 L p .64975 .23697 L F P
.534 .396 .246 r
s
.242 .145 .09 r
.64634 .23799 m .65108 .2388 L p .63829 .23396 L F P
.534 .396 .246 r
s
.242 .145 .09 r
.63829 .23396 m .65108 .2388 L .64906 .23679 L F
.63124 .23211 m .64634 .23799 L p .63829 .23396 L F P
.534 .396 .246 r
s
.444 .364 .253 r
.63007 .22925 m .64634 .23799 L p .63163 .23109 L F P
.534 .396 .246 r
s
.444 .364 .253 r
.61141 .22161 m .63007 .22925 L .63163 .23109 L F
.64634 .23799 m .63349 .23298 L p .63163 .23109 L F P
.534 .396 .246 r
s
.28 .165 .103 r
.62424 .22613 m .6375 .23439 L .65503 .24272 L p F P
.534 .396 .246 r
s
.283 .167 .103 r
.64634 .23799 m .66189 .24598 L .68462 .24716 L p F P
.534 .396 .246 r
s
.28 .165 .103 r
.66189 .24598 m .64634 .23799 L p .65427 .24196 L F P
.534 .396 .246 r
s
.28 .165 .103 r
.65503 .24272 m .66189 .24598 L p .65427 .24196 L F P
.534 .396 .246 r
s
.283 .167 .103 r
.68462 .24716 m .66705 .24152 L .65108 .2388 L p F P
.534 .396 .246 r
s
.283 .167 .103 r
.65108 .2388 m .64634 .23799 L p .65128 .23917 L F P
.534 .396 .246 r
s
.283 .167 .103 r
.65128 .23917 m .68462 .24716 L .65108 .2388 L F
.28 .165 .103 r
.64634 .23799 m .63753 .23326 L p .65427 .24196 L F P
.534 .396 .246 r
s
.28 .165 .103 r
.6391 .23396 m .65427 .24196 L .63753 .23326 L F
.65214 .24084 m .65503 .24272 L .65427 .24196 L F
.63753 .23326 m .62424 .22613 L p .6391 .23396 L F P
.534 .396 .246 r
s
.28 .165 .103 r
.62424 .22613 m .65238 .24129 L .65214 .24084 L F
.65238 .24129 m .65503 .24272 L .65214 .24084 L F
.35 .279 .201 r
.61187 .21472 m .62294 .2214 L .64539 .23677 L p F P
.534 .396 .246 r
s
.261 .156 .097 r
.66705 .24152 m .68462 .24716 L .70539 .2382 L p F P
.534 .396 .246 r
s
.183 .115 .071 r
.72481 .23475 m .70539 .2382 L .69724 .24172 L p F P
.534 .396 .246 r
s
.183 .115 .071 r
.69724 .24172 m .68462 .24716 L p .69606 .24363 L F P
.534 .396 .246 r
s
.183 .115 .071 r
.69606 .24363 m .72481 .23475 L .69724 .24172 L F
.213 .13 .081 r
.66189 .24598 m .67764 .24966 L .69333 .24802 L p F P
.534 .396 .246 r
s
.213 .13 .081 r
.67398 .24661 m .66189 .24598 L p .67151 .24624 L F P
.534 .396 .246 r
s
.183 .115 .071 r
.68462 .24716 m .70232 .24708 L .72481 .23475 L p F P
.534 .396 .246 r
s
.213 .13 .081 r
.68462 .24716 m .67398 .24661 L p .70232 .24708 L F P
.534 .396 .246 r
s
.213 .13 .081 r
.67151 .24624 m .70232 .24708 L .67398 .24661 L F
.66189 .24598 m .69333 .24802 L .69406 .24686 L F
.242 .145 .09 r
.65108 .2388 m .66705 .24152 L p .64906 .23679 L F P
.534 .396 .246 r
s
.246 .148 .092 r
.64991 .2368 m .66705 .24152 L .68607 .23599 L p F P
.534 .396 .246 r
s
.261 .156 .097 r
.70539 .2382 m .68607 .23599 L .66705 .24152 L p F P
.534 .396 .246 r
s
.662 .539 .351 r
.66457 .23927 m .69327 .24346 L p .66238 .24139 L F P
.534 .396 .246 r
s
.241 .145 .09 r
.66049 .24531 m .6375 .23439 L p .66137 .24347 L F P
.534 .396 .246 r
s
.241 .145 .09 r
.66137 .24347 m .67764 .24966 L .66049 .24531 L F
.65103 .24063 m .66451 .2452 L p .6375 .23439 L F P
.534 .396 .246 r
s
.241 .145 .09 r
.6375 .23439 m .66451 .2452 L .66683 .24555 L F
.662 .539 .351 r
.65103 .24063 m .66334 .2394 L p .66238 .24139 L F P
.534 .396 .246 r
s
.662 .539 .351 r
.66334 .2394 m .66457 .23927 L p .66238 .24139 L F P
.534 .396 .246 r
s
.241 .145 .09 r
.67764 .24966 m .66189 .24598 L .66049 .24531 L p F P
.534 .396 .246 r
s
.241 .145 .09 r
.66451 .2452 m .67764 .24966 L p .66683 .24555 L F P
.534 .396 .246 r
s
.213 .13 .081 r
.69333 .24802 m .70232 .24708 L p .69406 .24686 L F P
.534 .396 .246 r
s
.35 .279 .201 r
.64539 .23677 m .65103 .24063 L p .64479 .2365 L F P
.534 .396 .246 r
s
.35 .279 .201 r
.61187 .21472 m .64539 .23677 L .64479 .2365 L F
.369 .294 .213 r
.61962 .22067 m .62291 .22319 L p .62128 .22291 L F P
.534 .396 .246 r
s
.369 .294 .213 r
.62291 .22319 m .6375 .23439 L p .62297 .22411 L F P
.534 .396 .246 r
s
.369 .294 .213 r
.62128 .22291 m .62291 .22319 L .62297 .22411 L F
.60109 .20863 m .61962 .22067 L .62128 .22291 L F
.6375 .23439 m .62424 .22613 L p .62297 .22411 L F P
.534 .396 .246 r
s
.444 .364 .253 r
.61141 .22161 m .62424 .22613 L p .62486 .22712 L F P
.534 .396 .246 r
s
.444 .364 .253 r
.63349 .23298 m .63124 .23211 L p .63163 .23109 L F P
.534 .396 .246 r
s
.089 .066 .041 r
.63929 .23889 m .637 .23879 L p .63893 .23852 L F P
.534 .396 .246 r
s
.246 .148 .092 r
.66719 .23455 m .64991 .2368 L p .66807 .23639 L F P
.534 .396 .246 r
s
.246 .148 .092 r
.68607 .23599 m .66719 .23455 L p .66807 .23639 L F P
.534 .396 .246 r
s
.089 .066 .041 r
.64991 .2368 m .66719 .23455 L p .65132 .23647 L F P
.534 .396 .246 r
s
.152 .099 .061 r
.75515 .18832 m .77934 .1908 L .79353 .19047 L p F P
.534 .396 .246 r
s
.462 .379 .264 r
.79353 .19047 m .82024 .20474 L .83358 .21992 L p F P
.534 .396 .246 r
s
.65 .524 .346 r
.82024 .20474 m .79353 .19047 L .77934 .1908 L p F P
.534 .396 .246 r
s
1 .778 .478 r
.43987 .20004 m .43541 .19801 L .47094 .1716 L p F P
.534 .396 .246 r
s
.955 .705 .439 r
.43541 .19801 m .43987 .20004 L .40666 .24069 L p F P
.534 .396 .246 r
s
.741 .54 .348 r
.31089 .32906 m .29747 .30957 L .33 .29609 L p F P
.534 .396 .246 r
s
.889 .649 .407 r
.38285 .29181 m .39213 .29847 L .36454 .33315 L p F P
.534 .396 .246 r
s
.678 .52 .346 r
.63124 .23211 m .61671 .23352 L .59908 .22511 L p F P
.534 .396 .246 r
s
.678 .52 .346 r
.59908 .22511 m .61141 .22161 L .63124 .23211 L p F P
.534 .396 .246 r
s
.205 .126 .078 r
.71842 .20617 m .74059 .20333 L .75515 .18832 L p F P
.534 .396 .246 r
s
.166 .106 .066 r
.77934 .1908 m .75515 .18832 L .74059 .20333 L p F P
.534 .396 .246 r
s
.843 .62 .395 r
.35289 .3261 m .36454 .33315 L .33828 .35326 L p F P
.534 .396 .246 r
s
.843 .62 .395 r
.33828 .35326 m .32449 .34409 L .35289 .3261 L p F P
.534 .396 .246 r
s
.78 .57 .366 r
.32449 .34409 m .31089 .32906 L .34137 .31362 L p F P
.534 .396 .246 r
s
.741 .54 .348 r
.33 .29609 m .34137 .31362 L .31089 .32906 L p F P
.534 .396 .246 r
s
.78 .57 .366 r
.34137 .31362 m .35289 .3261 L .32449 .34409 L p F P
.534 .396 .246 r
s
.889 .649 .407 r
.36454 .33315 m .35289 .3261 L .38285 .29181 L p F P
.534 .396 .246 r
s
.23 .139 .087 r
.54142 .16228 m .53797 .15867 L .50549 .15541 L p F P
.534 .396 .246 r
s
.23 .139 .087 r
.50549 .15541 m .50625 .15932 L .54142 .16228 L p F P
.534 .396 .246 r
s
.89 .649 .406 r
.38285 .29181 m .37359 .28191 L .40666 .24069 L p F P
.534 .396 .246 r
s
.955 .705 .439 r
.40666 .24069 m .39975 .23315 L .43541 .19801 L p F P
.534 .396 .246 r
s
.851 .62 .391 r
.39975 .23315 m .40666 .24069 L .37359 .28191 L p F P
.534 .396 .246 r
s
.497 .395 .274 r
.62424 .22613 m .61141 .22161 L .59069 .20785 L p F P
.534 .396 .246 r
s
.497 .395 .274 r
.59069 .20785 m .60109 .20863 L .62424 .22613 L p F P
.534 .396 .246 r
s
.383 .305 .221 r
.5939 .19646 m .58543 .19157 L .55854 .17101 L p F P
.534 .396 .246 r
s
.833 .607 .384 r
.37359 .28191 m .38285 .29181 L .35289 .3261 L p F P
.534 .396 .246 r
s
.507 .405 .28 r
.86261 .2425 m .83358 .21992 L .82024 .20474 L p F P
.534 .396 .246 r
s
.364 .289 .211 r
.83358 .21992 m .86261 .2425 L .87264 .255 L p F P
.534 .396 .246 r
s
.761 .551 .352 r
.31891 .27466 m .35532 .25258 L .36438 .2687 L p F P
.534 .396 .246 r
s
.761 .551 .352 r
.36438 .2687 m .33 .29609 L .31891 .27466 L p F P
.534 .396 .246 r
s
.404 .325 .233 r
.61187 .21472 m .60109 .20863 L .57723 .18972 L p F P
.534 .396 .246 r
s
.404 .325 .233 r
.57723 .18972 m .58543 .19157 L .61187 .21472 L p F P
.534 .396 .246 r
s
.213 .133 .085 r
.68288 .22601 m .70321 .22293 L .71842 .20617 L p F P
.534 .396 .246 r
s
.248 .154 .1 r
.74059 .20333 m .71842 .20617 L .70321 .22293 L p F P
.534 .396 .246 r
s
.833 .607 .384 r
.35289 .3261 m .34137 .31362 L .37359 .28191 L p F P
.534 .396 .246 r
s
.787 .571 .364 r
.34137 .31362 m .33 .29609 L .36438 .2687 L p F P
.534 .396 .246 r
s
.907 .705 .427 r
.47094 .1716 m .43541 .19801 L .43085 .19889 L p F P
.534 .396 .246 r
s
.955 .705 .439 r
.39283 .2256 m .43085 .19889 L .43541 .19801 L p F P
.534 .396 .246 r
s
.955 .705 .439 r
.43541 .19801 m .39975 .23315 L .39283 .2256 L p F P
.534 .396 .246 r
s
.237 .145 .091 r
.70321 .22293 m .68288 .22601 L .66719 .23455 L p F P
.534 .396 .246 r
s
.851 .62 .391 r
.37359 .28191 m .36438 .2687 L .39975 .23315 L p F P
.534 .396 .246 r
s
.787 .571 .364 r
.36438 .2687 m .37359 .28191 L .34137 .31362 L p F P
.534 .396 .246 r
s
.412 .333 .237 r
.89153 .26157 m .90153 .26899 L .87264 .255 L p F P
.534 .396 .246 r
s
.412 .333 .237 r
.87264 .255 m .86261 .2425 L .89153 .26157 L p F P
.534 .396 .246 r
s
.824 .599 .379 r
.35532 .25258 m .39283 .2256 L .39975 .23315 L p F P
.534 .396 .246 r
s
.824 .599 .379 r
.39975 .23315 m .36438 .2687 L .35532 .25258 L p F P
.534 .396 .246 r
s
.155 .101 .062 r
.50625 .15932 m .47094 .1716 L .46897 .17759 L p F P
.534 .396 .246 r
s
.907 .705 .427 r
.43085 .19889 m .46897 .17759 L .47094 .1716 L p F P
.534 .396 .246 r
s
.166 .106 .066 r
.74059 .20333 m .76318 .20079 L .77934 .1908 L p F P
.534 .396 .246 r
s
.65 .524 .346 r
.77934 .1908 m .80409 .19442 L p .78937 .19422 L F P
.534 .396 .246 r
s
.65 .524 .346 r
.80409 .19442 m .82024 .20474 L p .78937 .19422 L F P
.534 .396 .246 r
s
.839 .664 .418 r
.80409 .19442 m .77934 .1908 L .76318 .20079 L p F P
.534 .396 .246 r
s
.883 .658 .419 r
.80409 .19442 m .78585 .1938 L p .81838 .19462 L F P
.534 .396 .246 r
s
.883 .658 .419 r
.82908 .1949 m .80409 .19442 L p .81838 .19462 L F P
.534 .396 .246 r
s
.507 .405 .28 r
.82024 .20474 m .84769 .22018 L .86261 .2425 L p F P
.534 .396 .246 r
s
.735 .556 .365 r
.84769 .22018 m .82024 .20474 L .80409 .19442 L p F P
.534 .396 .246 r
s
.237 .145 .091 r
.66719 .23455 m .68607 .23599 L .70321 .22293 L p F P
.534 .396 .246 r
s
.265 .158 .098 r
.54142 .16228 m .50625 .15932 L .50698 .16564 L p F P
.534 .396 .246 r
s
.155 .101 .062 r
.46897 .17759 m .50698 .16564 L .50625 .15932 L p F P
.534 .396 .246 r
s
.248 .154 .1 r
.70321 .22293 m .72404 .22195 L .74059 .20333 L p F P
.534 .396 .246 r
s
.164 .105 .065 r
.76318 .20079 m .74059 .20333 L .72404 .22195 L p F P
.534 .396 .246 r
s
.349 .275 .202 r
.62294 .2214 m .61187 .21472 L .58543 .19157 L p F P
.534 .396 .246 r
s
.349 .275 .202 r
.58543 .19157 m .5939 .19646 L .62294 .2214 L p F P
.534 .396 .246 r
s
.264 .162 .106 r
.72404 .22195 m .70321 .22293 L .68607 .23599 L p F P
.534 .396 .246 r
s
.597 .467 .316 r
.87498 .2315 m .89153 .26157 L .86261 .2425 L p F P
.534 .396 .246 r
s
.597 .467 .316 r
.86261 .2425 m .84769 .22018 L .87498 .2315 L p F P
.534 .396 .246 r
s
.839 .664 .418 r
.76318 .20079 m .78585 .1938 L p .78182 .19789 L F P
.534 .396 .246 r
s
.803 .635 .385 r
.78585 .1938 m .76341 .20072 L p .74505 .21729 L F P
.534 .396 .246 r
s
.803 .635 .385 r
.76341 .20072 m .76318 .20079 L .74505 .21729 L p F P
.534 .396 .246 r
s
.089 .066 .041 r
.74505 .21729 m .72481 .23475 L p .73013 .23075 L F P
.534 .396 .246 r
s
.803 .635 .385 r
.76585 .20391 m .78585 .1938 L p .77675 .19904 L F P
.534 .396 .246 r
s
.803 .635 .385 r
.74505 .21729 m .76585 .20391 L p .77675 .19904 L F P
.534 .396 .246 r
s
.089 .066 .041 r
.76585 .20391 m .74505 .21729 L p .73013 .23075 L F P
.534 .396 .246 r
s
.089 .066 .041 r
.72481 .23475 m .74393 .2204 L .76585 .20391 L p F P
.534 .396 .246 r
s
1 .78 .477 r
.76585 .20391 m .74393 .2204 L p .75674 .20799 L F P
.534 .396 .246 r
s
1 .78 .477 r
.78613 .17951 m .76585 .20391 L p .75674 .20799 L F P
.534 .396 .246 r
s
.999 .744 .462 r
.78585 .1938 m .76585 .20391 L p .78954 .19005 L F P
.534 .396 .246 r
s
.999 .744 .462 r
.80829 .17908 m .78585 .1938 L p .78954 .19005 L F P
.534 .396 .246 r
s
.839 .664 .418 r
.78585 .1938 m .80409 .19442 L p .78182 .19789 L F P
.534 .396 .246 r
s
.735 .556 .365 r
.80409 .19442 m .82908 .1949 L .84769 .22018 L p F P
.534 .396 .246 r
s
.265 .158 .098 r
.50698 .16564 m .54482 .16475 L .54142 .16228 L p F P
.534 .396 .246 r
s
.164 .105 .065 r
.72404 .22195 m .74505 .21729 L .76318 .20079 L p F P
.534 .396 .246 r
s
.264 .162 .106 r
.68607 .23599 m .70539 .2382 L .72404 .22195 L p F P
.534 .396 .246 r
s
.416 .338 .238 r
.61122 .19796 m .60254 .20001 L .57036 .17579 L p F P
.534 .396 .246 r
s
.416 .338 .238 r
.57036 .17579 m .57646 .17727 L .61122 .19796 L p F P
.534 .396 .246 r
s
.79 .591 .383 r
.85365 .18974 m .87498 .2315 L .84769 .22018 L p F P
.534 .396 .246 r
s
.79 .591 .383 r
.84769 .22018 m .82908 .1949 L .85365 .18974 L p F P
.534 .396 .246 r
s
.168 .107 .067 r
.74505 .21729 m .72404 .22195 L .70539 .2382 L p F P
.534 .396 .246 r
s
.35 .279 .201 r
.65103 .24063 m .6375 .23439 L .61187 .21472 L p F P
.534 .396 .246 r
s
.392 .314 .226 r
.63412 .22345 m .62294 .2214 L .5939 .19646 L p F P
.534 .396 .246 r
s
.392 .314 .226 r
.5939 .19646 m .60254 .20001 L .63412 .22345 L p F P
.534 .396 .246 r
s
.883 .658 .419 r
.78585 .1938 m .80829 .17908 L .82908 .1949 L p F P
.534 .396 .246 r
s
.897 .662 .418 r
.83007 .15714 m .85365 .18974 L .82908 .1949 L p F P
.534 .396 .246 r
s
.897 .662 .418 r
.82908 .1949 m .80829 .17908 L .83007 .15714 L p F P
.534 .396 .246 r
s
.168 .107 .067 r
.70539 .2382 m .72481 .23475 L .74505 .21729 L p F P
.534 .396 .246 r
s
.549 .432 .296 r
.61122 .19796 m .57646 .17727 L .58245 .17358 L p F P
.534 .396 .246 r
s
.999 .744 .462 r
.76585 .20391 m .78613 .17951 L .80829 .17908 L p F P
.534 .396 .246 r
s
.97 .713 .442 r
.80563 .1466 m .83007 .15714 L .80829 .17908 L p F P
.534 .396 .246 r
s
.97 .713 .442 r
.80829 .17908 m .78613 .17951 L .80563 .1466 L p F P
.534 .396 .246 r
s
.566 .448 .305 r
.64524 .2167 m .63412 .22345 L .60254 .20001 L p F P
.534 .396 .246 r
s
.566 .448 .305 r
.60254 .20001 m .61122 .19796 L .64524 .2167 L p F P
.534 .396 .246 r
s
.48 .397 .273 r
.66457 .23927 m .65103 .24063 L .62294 .2214 L p F P
.534 .396 .246 r
s
.48 .397 .273 r
.62294 .2214 m .63412 .22345 L .66457 .23927 L p F P
.534 .396 .246 r
s
.549 .432 .296 r
.58245 .17358 m .61965 .18755 L .61122 .19796 L p F P
.534 .396 .246 r
s
1 .78 .477 r
.74393 .2204 m .76247 .19329 L .78613 .17951 L p F P
.534 .396 .246 r
s
1 .737 .452 r
.78021 .15681 m .80563 .1466 L .78613 .17951 L p F P
.534 .396 .246 r
s
1 .737 .452 r
.78613 .17951 m .76247 .19329 L .78021 .15681 L p F P
.534 .396 .246 r
s
.694 .556 .333 r
.74393 .2204 m .72481 .23475 L .70232 .24708 L p F P
.534 .396 .246 r
s
.653 .489 .325 r
.64524 .2167 m .61122 .19796 L .61965 .18755 L p F P
.534 .396 .246 r
s
.662 .539 .351 r
.69327 .24346 m .67764 .24966 L .65103 .24063 L p F P
.534 .396 .246 r
s
.74 .566 .371 r
.6779 .2268 m .66457 .23927 L .63412 .22345 L p F P
.534 .396 .246 r
s
.74 .566 .371 r
.63412 .22345 m .64524 .2167 L .6779 .2268 L p F P
.534 .396 .246 r
s
.694 .556 .333 r
.70232 .24708 m .71978 .23588 L .74393 .2204 L p F P
.534 .396 .246 r
s
.741 .597 .37 r
.71978 .23588 m .70232 .24708 L .67764 .24966 L p F P
.534 .396 .246 r
s
1 .785 .479 r
.76247 .19329 m .74393 .2204 L .71978 .23588 L p F P
.534 .396 .246 r
s
.741 .597 .37 r
.67764 .24966 m .69327 .24346 L .71978 .23588 L p F P
.534 .396 .246 r
s
.996 .733 .451 r
.75296 .17719 m .78021 .15681 L .76247 .19329 L p F P
.534 .396 .246 r
s
1 .785 .479 r
.71978 .23588 m .73674 .21151 L .76247 .19329 L p F P
.534 .396 .246 r
s
.996 .733 .451 r
.76247 .19329 m .73674 .21151 L .75296 .17719 L p F P
.534 .396 .246 r
s
.653 .489 .325 r
.61965 .18755 m .65596 .19986 L .64524 .2167 L p F P
.534 .396 .246 r
s
.906 .684 .436 r
.70854 .2247 m .69327 .24346 L .66457 .23927 L p F P
.534 .396 .246 r
s
.906 .684 .436 r
.66457 .23927 m .6779 .2268 L .70854 .2247 L p F P
.534 .396 .246 r
s
1 .769 .477 r
.73674 .21151 m .71978 .23588 L .69327 .24346 L p F P
.534 .396 .246 r
s
.735 .542 .353 r
.6779 .2268 m .64524 .2167 L .65596 .19986 L p F P
.534 .396 .246 r
s
1 .769 .477 r
.69327 .24346 m .70854 .2247 L .73674 .21151 L p F P
.534 .396 .246 r
s
.939 .69 .431 r
.72318 .19556 m .75296 .17719 L .73674 .21151 L p F P
.534 .396 .246 r
s
.939 .69 .431 r
.73674 .21151 m .70854 .2247 L .72318 .19556 L p F P
.534 .396 .246 r
s
.735 .542 .353 r
.65596 .19986 m .69071 .20376 L .6779 .2268 L p F P
.534 .396 .246 r
s
.836 .614 .391 r
.70854 .2247 m .6779 .2268 L .69071 .20376 L p F P
.534 .396 .246 r
s
.836 .614 .391 r
.69071 .20376 m .72318 .19556 L .70854 .2247 L p F P
.534 .396 .246 r
s
.753 .753 .753 r
.25 Mabswid
.8081 0 m
.98268 .26071 L
s
.98268 .26071 m
1 .40289 L
s
1 .40289 m
.82052 .14881 L
s
.82052 .14881 m
.8081 0 L
s
.01702 .28002 m
0 .42162 L
s
0 .42162 m
.82052 .14881 L
s
.82052 .14881 m
.8081 0 L
s
.8081 0 m
.01702 .28002 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[318]:=",
  ImageSize->{450, 280.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400072000162000`400?l00000o`00003oo`3ooomZ
0?ooo`80`<30E`3oool00?l0<j7:I`0cXLX30<30`00303>QbP30`<00`<3005D0<j7:0@3oool00?l0
<j7:I00cXLX30<30`0@0<j7:0P30`<1E03>QbP40oooo003o03>QbV80<j7:0P30`<0703>QbP030<30
`00cXLX0`<3005@0<j7:0@3oool00?l0<j7:G`0cXLX30<30`0T0<j7:00@0`<3003>QbP0cXLX0`<30
D`0cXLX10?ooo`00o`0cXLYL03>QbP<0`<30300cXLX01030`<00<j7:03>QbP30`<1C03>QbP40oooo
003o03>QbUT0<j7:0`30`<0@03>QbP040<30`00cXLX0<j7:0<30`580<j7:0@3oool00?l0<j7:EP0c
XLX30<30`1<0<j7:00D0`<3003>QbP0cXLX0<j7:0<30`01A03>QbP40oooo003o03>QbU@0<j7:0P30
`<0F03>QbP050<30`00cXLX0<j7:03>QbP30`<00D@0cXLX10?ooo`00o`0cXLYA03>QbP<0`<30600c
XLX00`30`<00<j7:03>QbP0203>QbP030<30`00cXLX0<j7:04h0<j7:0@3oool00?l0<j7:CP0cXLX3
0<30`1/0<j7:00<0`<3003>QbP0cXLX00`0cXLX00`30`<00<j7:03>QbP1=03>QbP40oooo003o03>Q
bT/0<j7:0`30`<0N03>QbP030<30`00cXLX0<j7:00<0<j7:00<0`<3003>QbP0cXLX0C@0cXLX10?oo
o`00o`0cXLY803>QbP<0`<308@0cXLX00`30`<00<j7:03>QbP0403>QbP030<30`00cXLX0<j7:04`0
<j7:0@3oool00?l0<j7:A@0cXLX30<30`2@0<j7:00<0`<3003>QbP0cXLX01@0cXLX00`30`<00<j7:
03>QbP1;03>QbP40oooo003o03>QbT<0<j7:0P30`<0W03>QbP030<30`00cXLX0<j7:00D0<j7:00<0
`<3003>QbP0cXLX0B`0cXLX10?ooo`00o`0cXLY003>QbP<0`<30:@0cXLX00`30`<00<j7:03>QbP06
03>QbP030<30`00cXLX0<j7:04X0<j7:0@3oool00?l0<j7:?@0cXLX30<30`2`0<j7:00<0`<3003>Q
bP0cXLX01`0cXLX00`30`<00<j7:03>QbP1903>QbP40oooo003o03>QbSX0<j7:0`30`<0`03>QbP03
0<30`00cXLX0<j7:00H0<j7:00<0`<3003>QbP0cXLX0B@0cXLX10?ooo`00o`0cXLXg03>QbP<0`<30
<`0cXLX00`30`<00<j7:03>QbP0703>QbP030<30`00cXLX0<j7:04P0<j7:0@3oool00?l0<j7:=@0c
XLX20<30`3H0<j7:00<0`<3003>QbP0cXLX0200cXLX00`30`<00<j7:03>QbP1703>QbP40oooo003o
03>QbS80<j7:0`30`<0h03>QbP030<30`00cXLX0<j7:00P0<j7:00<0`<3003>QbP0cXLX0A`0cXLX1
0?ooo`00o`0cXLX_03>QbP<0`<30>`0cXLX00`30`<00<j7:03>QbP0903>QbP030<30`00cXLX0<j7:
04H0<j7:0@3oool00?l0<j7:;00cXLX30<30`3h0<j7:00<0`<3003>QbP0cXLX02P0cXLX00`30`<00
<j7:03>QbP1503>QbP40oooo003o03>QbRT0<j7:0`30`<1103>QbP030<30`00cXLX0<j7:00X0<j7:
00<0`<3003>QbP0cXLX0A@0cXLX10?ooo`00o`0cXLXV03>QbP<0`<30A00cXLX00`30`<00<j7:03>Q
bP0;03>QbP030<30`00cXLX0<j7:04@0<j7:0@3oool00?l0<j7:900cXLX20<30`4L0<j7:00<0`<30
03>QbP0cXLX0300cXLX00`30`<00<j7:03>QbP1303>QbP40oooo003o03>QbR40<j7:0`30`<1903>Q
bP030<30`00cXLX0<j7:00`0<j7:00<0`<3003>QbP0cXLX0@`0cXLX10?ooo`00o`0cXLXN03>QbP<0
`<30C00cXLX00`30`<00<j7:03>QbP0=03>QbP030<30`00cXLX0<j7:0480<j7:0@3oool00?l0<j7:
6`0cXLX30<30`500<j7:00<0`<3003>QbP0cXLX03@0cXLX00`30`<00<j7:03>QbP1103>QbP40oooo
003o03>QbQP0<j7:0`30`<1C03>QbP030<30`00cXLX0<j7:00d0<j7:00<0`<3003>QbP0cXLX0@@0c
XLX10?ooo`00o`0cXLXF03>QbP80`<30EP0cXLX00`30`<00<j7:03>QbP0>03>QbP030<30`00cXLX0
<j7:0400<j7:0@3oool00?l0<j7:4`0cXLX30<30`5P0<j7:00<0`<3003>QbP0cXLX03`0cXLX00`30
`<00<j7:03>QbP0o03>QbP40oooo003o03>QbQ00<j7:0`30`<1K03>QbP030<30`00cXLX0<j7:00l0
<j7:00<0`<3003>QbP0cXLX0?`0cXLX10?ooo`00o`0cXLX=03>QbP<0`<30GP0cXLX00`30`<00<j7:
03>QbP0@03>QbP030<30`00cXLX0<j7:03h0<j7:0@3oool00?l0<j7:2P0cXLX30<30`640<j7:00<0
`<3003>QbP0cXLX04@0cXLX00`30`<00<j7:03>QbP0m03>QbP40oooo003o03>QbPL0<j7:0`30`<1T
03>QbP030<30`00cXLX0<j7:0140<j7:00<0`<3003>QbP0cXLX0?@0cXLX10?ooo`00o`0cXLX503>Q
bP80`<30I`0cXLX00`30`<00<j7:03>QbP0B03>QbP030<30`00cXLX0<j7:03`0<j7:0@3oool00?l0
<j7:0P0cXLX30<30`6T0<j7:00<0`<3003>QbP0cXLX04`0cXLX00`30`<00<j7:03>QbP0k03>QbP40
oooo003n03>QbP<0`<30K00cXLX00`30`<00<j7:03>QbP0C03>QbP030<30`00cXLX0<j7:03/0<j7:
0@3oool00?/0<j7:0`30`<1_03>QbP030<30`00cXLX0<j7:01@0<j7:00<0`<3003>QbP0cXLX0>P0c
XLX10?ooo`00n00cXLX30<30`7<0<j7:00<0`<3003>QbP0cXLX0500cXLX00`30`<00<j7:03>QbP0i
03>QbP40oooo003f03>QbP80`<30MP0cXLX00`30`<00<j7:03>QbP0D03>QbP030<30`00cXLX0<j7:
03T0<j7:0@3oool00?<0<j7:0`30`<1h03>QbP030<30`00cXLX0<j7:01D0<j7:00<0`<3003>QbP0c
XLX0>00cXLX10?ooo`00l00cXLX30<30`7/0<j7:00<0`<3003>QbP0cXLX05P0cXLX00`30`<00<j7:
03>QbP0g03>QbP40oooo003]03>QbP<0`<30OP0cXLX00`30`<00<j7:03>QbP0F03>QbP030<30`00c
XLX0<j7:03L0<j7:0@3oool00>X0<j7:0`30`<2103>QbP030<30`00cXLX0<j7:01L0<j7:00<0`<30
03>QbP0cXLX0=P0cXLX10?ooo`00i`0cXLX30<30`8@0<j7:00<0`<3003>QbP0cXLX0600cXLX00`30
`<00<j7:03>QbP0e03>QbP40oooo003U03>QbP80`<30Q`0cXLX00`30`<00<j7:03>QbP0H03>QbP03
0<30`00cXLX0<j7:03D0<j7:0@3oool00>80<j7:0`30`<2903>QbP030<30`00cXLX0<j7:01T0<j7:
00<0`<3003>QbP0cXLX0=00cXLX10?ooo`00g`0cXLX30<30`8`0<j7:00<0`<3003>QbP0cXLX06P0c
XLX00`30`<00<j7:03>QbP0c03>QbP40oooo003L03>QbP<0`<30S`0cXLX00`30`<00<j7:03>QbP0J
03>QbP030<30`00cXLX0<j7:03<0<j7:0@3oool00=T0<j7:0`30`<2C03>QbP030<30`00cXLX0<j7:
01X0<j7:00<0`<3003>QbP0cXLX0<P0cXLX10?ooo`00e`0cXLX20<30`9H0<j7:00<0`<3003>QbP0c
XLX06`0cXLX00`30`<00<j7:03>QbP0a03>QbP40oooo003D03>QbP<0`<30V00cXLX00`30`<00<j7:
03>QbP0K03>QbP030<30`00cXLX0<j7:0340<j7:0@3oool00=40<j7:0`30`<2K03>QbP030<30`00c
XLX0<j7:01`0<j7:00<0`<3003>QbP0cXLX0<00cXLX10?ooo`00cP0cXLX30<30`9h0<j7:00<0`<30
03>QbP0cXLX07@0cXLX00`30`<00<j7:03>QbP0_03>QbP40oooo003;03>QbP<0`<30X@0cXLX00`30
`<00<j7:03>QbP0M03>QbP030<30`00cXLX0<j7:02l0<j7:0@3oool00<P0<j7:0`30`<2T03>QbP03
0<30`00cXLX0<j7:01h0<j7:00<0`<3003>QbP0cXLX0;P0cXLX10?ooo`00aP0cXLX20<30`:L0<j7:
00<0`<3003>QbP0cXLX07`0cXLX00`30`<00<j7:03>QbP0]03>QbP40oooo003303>QbP<0`<30Z@0c
XLX00`30`<00<j7:03>QbP0O03>QbP030<30`00cXLX0<j7:02d0<j7:0@3oool00<00<j7:0`30`<2/
03>QbP030<30`00cXLX0<j7:0200<j7:00<0`<3003>QbP0cXLX0;00cXLX10?ooo`00_@0cXLX30<30
`:l0<j7:00<0`<3003>QbP0cXLX08@0cXLX00`30`<00<j7:03>QbP0[03>QbP40oooo002j03>QbP<0
`<30/`0cXLX00`30`<00<j7:03>QbP0P03>QbP030<30`00cXLX0<j7:02/0<j7:0@3oool00;P0<j7:
0P30`<2f03>QbP030<30`00cXLX0<j7:0240<j7:00<0`<3003>QbP0cXLX0:P0cXLX10?ooo`00]@0c
XLX30<30`;P0<j7:00<0`<3003>QbP0cXLX08P0cXLX00`30`<00<j7:03>QbP0Y03>QbP40oooo002b
03>QbP<0`<30^`0cXLX00`30`<00<j7:03>QbP0R03>QbP030<30`00cXLX0<j7:02T0<j7:0@3oool0
0:l0<j7:0`30`<2f03>QbP<0R6Dn1@0cXLX00`30`<00<j7:03>QbP0S03>QbP030<30`00cXLX0<j7:
02P0<j7:0@3oool00:`0<j7:0`30`<2f03>QbP@0R6Dn0P3h]W4208QU?P80<j7:0P30`<0V03>QbP03
0<30`00cXLX0<j7:02L0<j7:0@3oool00:X0<j7:0P30`<2g03>QbP80R6Dn0`3o_7<01028ICh0n;Ia
0?RfL@3h]W430<30`080<j7:00<0`<3003>QbP0cXLX08`0cXLX00`30`<00<j7:03>QbP0W03>QbP40
oooo002W03>QbP<0`<30]P0cXLX308QU?P@0okac00<0R6Dn0?RfL@30`<000P30`<030?RfL@80R6Dn
00<0`<3003>QbP0cXLX0900cXLX00`30`<00<j7:03>QbP0V03>QbP40oooo002T03>QbP<0`<30>P0c
XLX@08QU?Vd0<j7:0P28ICh60?nlL`<0`<30203h]W400`28ICh0`<3003>QbP0U03>QbP030<30`00c
XLX0<j7:02D0<j7:0@3oool00:40<j7:0`30`<0k03>QbP80R6Dn00<05Q0:08QU?P0j8aH01P0j8aH9
08QU?VX0<j7:0P28ICh40?nlL`<0`<3000<0R6Dn0?RfL@3h]W402P3h]W400`30`<00R6Dn03>QbP0S
03>QbP030<30`00cXLX0<j7:02D0<j7:0@3oool009h0<j7:0`30`<0l03>QbP80R6Dn0`0F40X908QU
?PL0>R<F0`28ICiV03>QbP<0R6Dn0P3o_7<30<30`080okac00<0R6Dn0?RfL@3h]W402`3h]W400`28
ICh0`<3008QU?P0T03>QbP030<30`00cXLX0<j7:02@0<j7:0@3oool009/0<j7:0`30`<0l03>QbP<0
R6Dn0P0F40X208QU?P809aT?00<0R6Dn04<X6@13:1T01@13:1T<08QU?V<0<j7:00<0R6Dn0?jkL`3n
^g<00`30`<050?nlL`0308QU?P3h]W40n;Ia00X0n;Ia00D0R6Dn0>FYJ`30`<00iJU[08QU?P0T03>Q
bP030<30`00cXLX0<j7:02<0<j7:0@3oool009T0<j7:0P30`<0m03>QbP80R6Dn0P0F40X308QU?P<0
9aT?5`28ICiP03>QbP0408QU?P30`<00`<300<30`0L0okac00<0R6Dn0?RfL@3h]W402P3h]W401P28
ICh0iJU[0>FYJ`3UZF/0`<3008QU?R@0<j7:00<0`<3003>QbP0cXLX08`0cXLX10?ooo`00UP0cXLX3
0<30`3d0<j7:1P28ICh302LI3`@0R6Dn2@3@Vf@208QU?PH0Z81E1`28ICiL03>QbP<0`<300P3n^g<0
0`28ICh0okac0?nlL`050?nlL`0308QU?P3h]W40n;Ia00T0n;Ia00<0R6Dn0>FYJ`3UZF/00`3UZF/0
0`30`<00R6Dn03>QbP0S03>QbP030<30`00cXLX0<j7:0280<j7:0@3oool009<0<j7:0`30`<0n03>Q
bP@0R6Dn100W6@l308QU?P<0jJa/00<0R6Dn0=2KI03@Vf@00`3@Vf@408QU?P030<^EG`28ICh0]8EG
00@0R6Dn102XP5D308QU?P0303hU5`28ICh0R6Dn00<0R6DnE00cXLX30<30`0@0o[]c00<0R6Dn0?nl
L`3o_7<01@3o_7<00`28ICh0n;Ia0?RfL@080?RfL@80R6Dn1P3UZF/00`30`<00iJU[08QU?P0T03>Q
bP030<30`00cXLX0<j7:0240<j7:0@3oool00900<j7:0`30`<1003>QbP80R6Dn1@0W6@l308QU?PD0
jJa/00<0R6Dn0=2KI028ICh00`28ICh40<^EG`0308QU?P2dQEL0]8EG00@0]8EG1028ICh20:R0E@<0
R6Dn100n9AL408QU?Td0<j7:0`30`<000`0cXLX0R6Dn0?jkL`040?jkL`0308QU?P3o_7<0okac00@0
okac00<0R6Dn0?RfL@3h]W40203h]W400`28ICh0iJU[0>FYJ`070>FYJ`030<30`03UZF/0R6Dn02<0
<j7:00<0`<3003>QbP0cXLX08@0cXLX10?ooo`00S@0cXLX30<30`480<j7:00<0j;A]08QU?P0W6@l0
0P0W6@l408QU?PL0jJa/0P28ICh80<^EG`0308QU?P2dQEL0]8EG00P0]8EG0`28ICh0101oI4D0R6Dn
069>>028ICh603hU5`<0R6DnA`0cXLX30<30`080<j7:0P28ICh50?jkL`0308QU?P3o_7<0okac00D0
okac00<0R6Dn0?RfL@3h]W401`3h]W400`28ICh0iJU[0>FYJ`090>FYJ`030<30`028ICh0<j7:02<0
<j7:00<0`<3003>QbP0cXLX0800cXLX10?ooo`00R`0cXLX20<30`4<0<j7:0P3X]6d00`28ICh09aT?
08QU?P0208QU?P030?ZkM@28ICh0R6Dn00L0jJa/0P28ICh90<^EG`0308QU?P2dQEL0]8EG00P0]8EG
00<0R6Dn09mgD028ICh00P1oI4D208QU?P03069>>028ICh0R6Dn0080?RDG0P28ICh208a^B`<0R6Dn
@@0cXLX30<30`0@0<j7:00<0R6Dn0?jkL`3n^g<01@3n^g<00`28ICh0okac0?nlL`040?nlL`0308QU
?P3h]W40n;Ia00L0n;Ia00<0R6Dn0>FYJ`3UZF/02P3UZF/00`30`<00iJU[08QU?P0T03>QbP030<30
`00cXLX0<j7:01l0<j7:0@3oool008P0<j7:0`30`<1403>QbP<0j;A]0P28ICh0103l^W<0R6Dn08QU
?P28ICh70>V/K080R6Dn00<0gZ=W08QU?P3;UEl0203;UEl00`28ICh0]8EG0;B5E`080;B5E`0508QU
?P2OMe00WgM@09mgD028ICh00P1oI4D00`28ICh0HThh05M5<P0208QU?PL0S6i;0`28IChk03>QbP<0
`<301P0cXLX00`28ICh0o[]c0?jkL`050?jkL`0308QU?P3o_7<0okac00D0okac00<0R6Dn0?RfL@3h
]W400P3h]W4508QU?Ph0iJU[00<0`<300>FYJ`28ICh08`0cXLX00`30`<00<j7:03>QbP0O03>QbP40
oooo002503>QbP<0`<30A@0cXLX30>RdK@80R6Dn0`3l^W<00`28ICh0jJa/0>V/K0060>V/K00508QU
?P3NXfL0gZ=W0=jSI`28ICh0203;UEl00`28ICh0]8EG0;B5E`080;B5E`0308QU?P2OMe00WgM@00<0
WgM@0P28ICh0101oI4D0R6Dn069>>01RCSP308QU?PP0S6i;0P28IChf03>QbP<0`<301`0cXLX308QU
?PL0o[]c00<0R6Dn0?nlL`3o_7<0103o_7<608QU?P<0okif00<0R6Dn0>:XJ`28ICh03P3UZF/00`30
`<00iJU[08QU?P0S03>QbP030<30`00cXLX0<j7:01h0<j7:0@3oool00880<j7:0`30`<1703>QbP80
j;A]0`28ICh30?bjL`80R6Dn1`3Y[6`01@28ICh0gZ=W0=jSI`3NXfL0R6Dn00P0biEO1P28ICh60;B5
E`0308QU?P2OMe00WgM@00D0WgM@00D0R6Dn07mTA@28ICh0R6Dn069>>00408QU?PP0S6i;0`28ICh`
03>QbP<0`<30200cXLX208QU?P030?2`KP28ICh0o[]c00H0o[]c00<0R6Dn0?nlL`3o_7<00`3o_7<2
08QU?PL0okif00<0R6Dn0>:XJ`3RZ6/00P3RZ6/208QU?Pd0iJU[00<0`<300>FYJ`28ICh08`0cXLX0
0`30`<00<j7:03>QbP0M03>QbP40oooo001o03>QbP<0`<30B00cXLX20>RdK@80R6Dn00<0olAi08QU
?P3l^W<00P3l^W<00`28ICh0lk9_08QU?P050>V/K080R6Dn103NXfL00`28ICh0biEO0<^EG`040<^E
G`80R6Dn00<0ai5M08QU?P2hQeL00`2hQeL608QU?PX0WgM@00@0R6Dn07mTA@28ICh0HThh0P28ICh0
0`1ZES`0R6Dn08QU?P0908a^B`<0R6Dn:P0cXLX30<30`0X0<j7:00D0R6Dn0?2`KP3`/6h0l;1^08QU
?P070?jkL`0408QU?P3o_7<0okac0?nlL`<0R6Dn1`3o_WH00`28ICh0hZQ[0>:XJ`050>:XJ`0308QU
?P3UZF/0iJU[00X0iJU[00<0`<300>FYJ`28ICh08`0cXLX00`30`<00<j7:03>QbP0M03>QbP40oooo
001l03>QbP<0`<30BP0cXLX00`3X]6d0R6Dn08QU?P020?o4N@0308QU?P3l^W<0o;Yc0080o;Yc00<0
R6Dn0?>bK`28ICh0103Y[6`00`28ICh0gZ=W0=jSI`040=jSI`0408QU?P3;UEl0biEO0<^EG`<0R6Dn
0`37TEd00`28ICh0^8MG0;R7E`070;R7E`0408QU?P2]Oe<0R6Dn08QU?PP0WgM@0`28ICh00`1RCSP0
R6Dn08QU?P0206YF?00308QU?P2<KT/0S6i;00T0S6i;0`28IChT03>QbP<0`<302`0cXLX208QU?P<0
l;1^00<0R6Dn0?jkL`3n^g<01@3n^g<01@28ICh0okac0?nlL`3o_7<0R6Dn0080olMj00<0R6Dn0?nn
MP3o_WH00`3o_WH208QU?PT0hZQ[00<0R6Dn0>FYJ`3UZF/02P3UZF/00`30`<00iJU[08QU?P0S03>Q
bP030<30`00cXLX0<j7:01`0<j7:0@3oool007X0<j7:0P30`<1;03>QbP040>RdK@28ICh0R6Dn0?o7
NP<0olAi00D0R6Dn0?bjL`3l^W<0o;Yc08QU?P030?>bK`0408QU?P3Y[6`0jJa/08QU?PL0gZ=W00@0
R6Dn0<^EG`28ICh0R6Dn1P37TEd00`28ICh0^8MG0;R7E`060;R7E`0308QU?P2]Oe<0[GmC0080[GmC
0`28ICh709mgD0H0R6Dn00<0JUHl08QU?P28ICh02@2<KT/00`28ICh0YgeC0:MmD`0208QU?Ql0<j7:
0`30`<0=03>QbP0308QU?P3`/6h0l;1^00<0l;1^00<0R6Dn0?jkL`3n^g<01@3n^g<01028ICh0okac
08QU?P28ICh20?o7NP0308QU?P3o_WH0okif00<0okif00<0R6Dn0>:XJ`3RZ6/02P3RZ6/00`28ICh0
iJU[0>FYJ`0:0>FYJ`030<30`028ICh0R6Dn02<0<j7:00<0`<3003>QbP0cXLX06`0cXLX10?ooo`00
M`0cXLX30<30`4`0<j7:0P28ICh20?o7NP<0olAi00D0R6Dn0?bjL`3l^W<0o;Yc08QU?P040?>bK`<0
R6Dn203NXfL208QU?PP0ai5M00<0R6Dn0;R7E`2hQeL01P2hQeL00`28ICh0[GmC0:eoD`050:eoD`80
R6Dn0`2OMe0208QU?P0508i]BP28ICh0R6Dn08QU?P1RCSP00P28ICh206YF?080R6Dn1P2<KT/00`28
ICh0YgeC0:MmD`030:MmD`<0R6Dn6@0cXLX30<30`0h0<j7:0P28ICh50?2`KP0308QU?P3n^g<0o[]c
00D0o[]c0`28ICh30?o7NP0308QU?P3o_WH0okif0080okif0P28ICh>0>:XJ`80R6Dn1`3UZF/308QU
?P030<30`03:Uf80R6Dn02<0<j7:00<0`<3003>QbP0cXLX06`0cXLX10?ooo`00M00cXLX30<30`4d0
<j7:0`28ICh20?o7NP<0olAi00D0R6Dn0?bjL`3l^W<0o;Yc08QU?P050?>bK`0308QU?P3NXfL0gZ=W
00L0gZ=W0P28ICh80<NAG@0308QU?P2hQeL0^8MG00L0^8MG00<0R6Dn0:eoD`2]Oe<01`2]Oe<308QU
?P@0SVe:00<0R6Dn06MC>`28ICh00`28ICh306YF?080R6Dn102<KT/00`28ICh0YgeC0:MmD`060:Mm
D`<0R6Dn4`0cXLX30<30`0l0<j7:0P28ICh70?2`KP0308QU?P3n^g<0o[]c00D0o[]c00<0R6Dn0?o7
NP3oagX00P3oagX00`28ICh0okif0?nnMP020?nnMP0308QU?P3RZ6/0hZQ[0100hZQ[00<0R6Dn0>FY
J`3UZF/01028ICh40<ZGHP030<30`03:Uf80R6Dn02<0<j7:00<0`<3003>QbP0cXLX06P0cXLX10?oo
o`00L@0cXLX30<30`4h0<j7:1028ICh20?o7NP<0olAi00D0R6Dn0?bjL`3l^W<0o;Yc08QU?P050?>b
K`80R6Dn1`3NXfL208QU?P030=RMH`28ICh0ai5M00L0ai5M00<0R6Dn0;R7E`2hQeL01`2hQeL00`28
ICh0[GmC0:eoD`070:eoD`0308QU?P2VNe40R6Dn00D0SVe:00<0R6Dn06MC>`28ICh01028ICh306YF
?00408QU?P2<KT/0S6i;08QU?P`0YgeC0P28ICh>03>QbP<0`<303`0cXLX308QU?PP0l;1^00<0R6Dn
0?jkL`3n^g<0103n^g<208QU?P@0olMj00D0R6Dn0?nnMP3o_WH0okif08QU?P040=JYJ`0308QU?P2V
QUP0YXIH00<0YXIH00<0R6Dn0;b>G@2lSUd00P2lSUd808QU?PT0bYMR00<0`<3008QU?P0cXLX08`0c
XLX00`30`<00<j7:03>QbP0I03>QbP40oooo001^03>QbP<0`<30D00cXLX308QU?P<0olMj0`3oa7T0
0`28ICh0o;Yc0?bjL`020?bjL`0308QU?P3c/Vl0lk9_0080lk9_00<0R6Dn0>b]J`28ICh01P3NXfL0
1@28ICh0f9eS0=RMH`3HWF<0R6Dn00P0ai5M00<0R6Dn0;R7E`2hQeL01P2hQeL00`28ICh0[GmC0:eo
D`080:eoD`0508QU?P2VNe40YW]A0:IkD@28ICh0102>KDX01028ICh0Ie<k08QU?P1IAS<308QU?P<0
JUHl0P28ICh?0:MmD`<0R6Dn200cXLX30<30`0h0<j7:1028ICh20=JMI00308QU?P3`/6h0l;1^00H0
l;1^00<0R6Dn0?jkL`3n^g<00`3n^g<208QU?P@0olMj00<0R6Dn0?nnMP3o_WH00P28ICh00`38UF40
R6Dn0:9lD`050:9lD`0308QU?P2VQUP0YXIH0080YXIH00<0R6Dn0;b>G@2lSUd01`2lSUd00`28ICh0
bYMR0<ZGHP070<ZGHP030<30`03:Uf80R6Dn02<0<j7:00<0`<3003>QbP0cXLX06@0cXLX10?ooo`00
K00cXLX20<30`540<j7:0P28ICh00`3d]700R6Dn0?BdL00208QU?P<0olAi00<0R6Dn0?bjL`3l^W<0
0P3l^W<00`28ICh0lk9_0?>bK`030?>bK`0308QU?P3/[F/0R6Dn00D0gZ=W00<0R6Dn0=RMH`3HWF<0
0P3HWF<00`28ICh0ai5M0<NAG@060<NAG@0308QU?P2hQeL0^8MG00H0^8MG00<0R6Dn0:eoD`2]Oe<0
1`2]Oe<00`28ICh0YW]A0:IkD@040:IkD@0408QU?P2>KDX0SVe:08i]BP80R6Dn00<0Ie<k08QU?P28
ICh01028ICh2091bCP80R6Dn402WOE<508QU?P<0`<3000<0R6Dn03>QbP0cXLX02@0cXLX508QU?PD0
eYeT00<0R6Dn0?2`KP3`/6h01P3`/6h00`28ICh0o[]c0?jkL`020?jkL`80R6Dn00<0olQj08QU?P3o
agX00`3oagX00`28ICh0okif08QU?P030<REH@0308QU?P2RO5<0XWaC00H0XWaC0P28ICh20:J6F003
08QU?P2lSUd0_8iM00H0_8iM00<0R6Dn0<ZGHP3:Uf80203:Uf800`30`<00R6Dn03>QbP0S03>QbP03
0<30`00cXLX0<j7:01P0<j7:0@3oool006T0<j7:0`30`<1B03>QbP0408QU?P3d]700m;A`08QU?P80
m;A`00D0R6Dn0?FdK`28ICh0olAi08QU?P040?bjL`0308QU?P3c/Vl0lk9_00<0lk9_00D0R6Dn0>b]
J`3/[F/0k:e[08QU?P030=jSI`0308QU?P3HWF<0f9eS00<0f9eS00<0R6Dn0<NAG@37TEd01@37TEd=
08QU?PL0[GmC00<0R6Dn0:IkD@2VNe401@2VNe4208QU?P<0SVe:00<0R6Dn06MC>`28ICh01028ICh4
091bCP80R6Dn3P2WOE<00`28ICh0_8YJ0<30`0020<30`0@0_8YJ2`28ICh:0=JMI00308QU?P3`/6h0
l;1^00H0l;1^00D0R6Dn0?jkL`3n^g<0o[]c08QU?P020?o8NP0308QU?P3oagX0olMj0080olMj0P28
ICh60<REH@0308QU?P2RO5<0XWaC00H0XWaC0P28ICh207IQ@`80R6Dn1`2lSUd00`28ICh0bYMR0<ZG
HP080<ZGHP030<30`028ICh0<j7:02<0<j7:00<0`<3003>QbP0cXLX05`0cXLX10?ooo`00IP0cXLX3
0<30`5@0<j7:00@0R6Dn0?BdL03d]700R6Dn0P3d]7001@28ICh0mKA_0?FdK`3e]6l0R6Dn00@0o;Yc
00<0R6Dn0?>bK`3c/Vl00`3c/Vl00`28ICh0k:e[0>b]J`020>b]J`0408QU?P3NXfL0R6Dn08QU?PH0
f9eS00<0R6Dn0<NAG@37TEd00`37TEd208QU?P030<J@G028ICh0^hQG00L0^hQG00<0R6Dn0;>2E02c
PU@01028ICh20:eoD`0308QU?P2VNe40YW]A00P0YW]A0P28ICh208i]BP0708QU?P1WDc/0R6Dn05U6
<`28ICh0I50i08QU?P05091bCP80R6Dn2`2WOE<30<30`0h0_8YJ00<0R6Dn0=JMI03FWF@02P3FWF@0
0`28ICh0l;1^0?2`KP060?2`KP0308QU?P3n^g<0o[]c0080R6Dn0P3ob7X00`28ICh0olMj0?o7NP02
0?o7NP0308QU?P38UF40b9EQ00H0b9EQ00<0R6Dn0:9lD`2RO5<01`2RO5<00`28ICh0KeY008QU?P02
07IQ@`80R6Dn1P2lSUd00`28ICh0bYMR0<ZGHP080<ZGHP030<30`00cXLX0<j7:0280<j7:00<0`<30
03>QbP0cXLX05`0cXLX10?ooo`00H`0cXLX30<30`5D0<j7:0P28ICh20?BdL00408QU?P3d]700m;A`
08QU?P<0mKA_0P28ICh30?bjL`0308QU?P3c/Vl0lk9_00<0lk9_00<0R6Dn0>b]J`3/[F/00`3/[F/2
08QU?PP0f9eS00@0R6Dn0<NAG@37TEd0ai5M0P28ICh30<J@G00308QU?P2kR5L0^hQG00H0^hQG00<0
R6Dn0;>2E02cPU@0102cPU@308QU?P`0YW]A0P28ICh0202>KDX0R6Dn06MC>`28ICh0FDHc08QU?P1T
D3T0R6Dn1P2@LTh208QU?PH0YgeC0`30`<000`28ICh0_8YJ0;b:FP0>0;b:FP0308QU?P3FWF@0eYeT
00X0eYeT00<0R6Dn0?2`KP3`/6h01P3`/6h00`28ICh0o[]c08QU?P030?o8NP0408QU?P3oagX0olMj
0?o7NPH0R6Dn1P38UF400`28ICh0XWaC0:9lD`060:9lD`0408QU?P1_FT00KeY008QU?P<0MV5300<0
R6Dn0;b>G@2lSUd0102lSUd00`28ICh0bYMR0<ZGHP070<ZGHP030<30`028ICh0<j7:02<0<j7:00<0
`<3003>QbP0cXLX05P0cXLX10?ooo`00H00cXLX30<30`5L0<j7:00D0R6Dn0?BdL03d]700m;A`08QU
?P030?BdL00708QU?P3e]6l0mKA_0?FdK`28ICh0mK=_08QU?P020?bjL`0308QU?P3c/Vl0lk9_0080
lk9_00<0R6Dn0>b]J`3/[F/0103/[F/00`28ICh0f9eS0=RMH`070=RMH`0408QU?P37TEd0R6Dn08QU
?PD0aY1L00<0R6Dn0;^8E`2kR5L01@2kR5L00`28ICh0/h9D0;>2E0070;>2E0<0R6Dn2@2VNe400`28
ICh0YGaB08QU?P0708QU?P0306A@>@28ICh0R6Dn00H0T79>0P28ICh0102WOE<0`<300<30`030`<02
0:MmD`0308QU?P2lRUX0_8YJ00h0_8YJ00<0R6Dn0=JMI03FWF@02P3FWF@00`28ICh0l;1^0?2`KP06
0?2`KP<0R6Dn103ob7X00`28ICh0olMj0?o7NP0208QU?PD0_H]J2028ICh80:9lD`0508QU?P1_FT00
KeY006mJ@028ICh00P1fHD<208QU?P@0_8iM00<0R6Dn0<ZGHP3:Uf80203:Uf800`30`<00<j7:03>Q
bP0S03>QbP030<30`00cXLX0<j7:01D0<j7:0@3oool005d0<j7:0`30`<1H03>QbP80R6Dn0`3d]700
1@28ICh0m;A`0?BdL03d]700R6Dn00<0mKA_00H0R6Dn0?FcK`3e/fl0R6Dn0?bjL`28ICh50?>bK`03
08QU?P3/[F/0k:e[00<0k:e[0P28ICh90=RMH`80R6Dn1`36T5`00`28ICh0^hQG0;^8E`050;^8E`03
08QU?P2cPU@0/h9D00H0/h9D00@0R6Dn0;20D`2`P5<0/81C0P28ICh50:IkD@80R6Dn102UO5800`28
ICh0OfE608QU?P0408QU?P80I50i00<0R6Dn091bCP2@LTh00`2@LTh30<30`00508QU?P2WOE<0YgeC
0:MmD`28ICh04@2lRUX00`28ICh0eYeT0=JMI00:0=JMI00308QU?P3`/6h0l;1^00H0l;1^00<0R6Dn
0?o8NP3ob7X00`3ob7X01P28ICh0olMj0?o7NP28ICh0biAN08QU?P/0_H]J00@0R6Dn0:j1E@28ICh0
R6Dn1P2RO5<00`28ICh0KeY006mJ@00206mJ@00608QU?P1fHD<0MV5308QU?P21IdL0R6Dn0`2lSUd0
0`28ICh0bYMR0<ZGHP080<ZGHP030<30`00cXLX0<j7:0280<j7:00<0`<3003>QbP0cXLX05@0cXLX1
0?ooo`00F`0cXLX20<30`5X0<j7:00<0R6Dn0?BdL03d]7000P3d]7001@28ICh0m;A`0?BdL03d]700
R6Dn00<0mKA_00<0R6Dn0?FcK`3e/fl00P3e/fl00`28ICh0lk9_0?>bK`030?>bK`0308QU?P3/[F/0
k:e[00<0k:e[00<0R6Dn0>NYJ@28ICh0203HWF<208QU?PP0aY1L00<0R6Dn0;^8E`2kR5L01@2kR5L0
0`28ICh0/h9D0;>2E0060;>2E00308QU?P2`P5<0/81C00<0/81C0P28ICh20:IkD@0308QU?P2UO580
YGaB00D0YGaB00<0R6Dn07mUAP1oIDH01@28ICh00`1TD3T0R6Dn08QU?P030<30`0@0T79>0P28ICh0
0`2WOE<0R6Dn0;b:FP0?0;b:FP0308QU?P3FWF@0eYeT00X0eYeT00<0R6Dn0?2`KP3`/6h01@3`/6h2
08QU?PD0olQj00@0R6Dn0?o7NP28ICh0R6Dn0`3;U5h00`28ICh0_H]J0;f;FP080;f;FP0408QU?P2^
PED0[X5E0:j1E@80R6Dn1@2RO5<00`28ICh0KeY006mJ@00206mJ@00308QU?P1fHD<0R6Dn0080PFM7
00D0R6Dn0;b>G@2lSUd0_8iM08QU?P090<ZGHP030<30`00cXLX0<j7:02<0<j7:00<0`<3003>QbP0c
XLX0500cXLX10?ooo`00F00cXLX30<30`5X0<j7:0P28ICh40?BdL00508QU?P3d]700m;A`0?BdL028
ICh00`3e]6l00`28ICh0mK=_0?FcK`020?FcK`80R6Dn103c/Vl00`28ICh0k:e[0>b]J`030>b]J`04
08QU?P3WZFT0ijUY08QU?PL0f9eS00<0R6Dn0=BJHP28ICh01`36T5`00`28ICh0^hQG0;^8E`060;^8
E`0308QU?P2cPU@0/h9D00D0/h9D00<0R6Dn0;20D`2`P5<01P2`P5<208QU?PX0YGaB00@0R6Dn07mU
AP28ICh0GT/f0P28ICh30<30`00308QU?P2@LTh0T79>00H0T79>0P28ICh@0;b:FP0308QU?P3FWF@0
eYeT00X0eYeT00<0R6Dn0?2`KP3`/6h00`3`/6h208QU?P030?o4NP28ICh0olQj00<0olQj00<0R6Dn
0?o7NP28ICh01@3;U5h00`28ICh0_H]J0;f;FP090;f;FP0308QU?P2^PED0[X5E0080[X5E0`28ICh2
0:9lD`0308QU?P1_FT00KeY000@0KeY00P28ICh3085WA`0408QU?P2lSUd0_8iM08QU?PT0bYMR00<0
`<3003>QbP0cXLX08`0cXLX00`30`<00<j7:03>QbP0C03>QbP40oooo001E03>QbP<0`<30G00cXLX0
0`28ICh0m;A`0?BdL0030?BdL00508QU?P3d]700m;A`0?BdL028ICh0103e]6l00`28ICh0mK=_0?Fc
K`020?FcK`0308QU?P3e/fh0R6Dn0080lk9_00<0R6Dn0>b]J`3/[F/0103/[F/01028ICh0ijUY0>NY
J@28ICh60=RMH`0408QU?P3DVV80e9YR08QU?PL0aY1L00<0R6Dn0;^8E`2kR5L01P2kR5L00`28ICh0
/h9D0;>2E0050;>2E00308QU?P2`P5<0/81C00H0/81C00@0R6Dn0;:3E@28ICh0R6Dn2@2UO5800`28
ICh0`<300<30`0020<30`080R6Dn0P1TD3T00`28ICh0T79>091bCP03091bCP80R6Dn0P2mT5h308QU
?P`0_8YJ00<0R6Dn0=JMI03FWF@02P3FWF@00`28ICh0l;1^0?2`KP020?2`KP80R6Dn0P3oa7X00`28
ICh0olQj0?o8NP030?o8NP80R6Dn1P3;U5h00`28ICh0_H]J0;f;FP090;f;FP0308QU?P2^PED0[X5E
00D0[X5E0P28ICh00`2RO5<0R6Dn06mJ@00506mJ@080R6Dn1021IdL208QU?PT0bYMR00<0R6Dn0<30
`00cXLX08`0cXLX00`30`<00<j7:03>QbP0C03>QbP40oooo001B03>QbP<0`<30GP0cXLX00`28ICh0
m;A`0?BdL0030?BdL00508QU?P3d]700m;A`0?BdL028ICh0103e]6l00`28ICh0mK=_0?FcK`020?Fc
K`0408QU?P3e/fh0mK=^08QU?P80lk9_00<0R6Dn0>b]J`3/[F/00`3/[F/00`28ICh0ijUY0>NYJ@02
0>NYJ@0408QU?P3HWF<0f9eS0=RMH`80R6Dn0`3DVV800`28ICh0aY1L0<J@G0050<J@G00308QU?P2k
R5L0^hQG00D0^hQG00<0R6Dn0;>2E02cPU@01@2cPU@00`28ICh0/81C0;20D`070;20D`0408QU?P2b
PeD0/X=E0;:3E@80R6Dn1@2UO5830<30`080R6Dn00<0OfE608QU?P1NBcH01P28ICh00`2@LTh0R6Dn
08QU?P070;f@GP<0R6Dn2@2lRUX00`28ICh0eYeT0=JMI00:0=JMI00308QU?P3`/6h0l;1^0080R6Dn
0`3oa7X00`28ICh0olQj0?o8NP030?o8NP0308QU?P3;U5h0biAN00H0biAN00<0R6Dn0;f;FP2mReX0
2@2mReX00`28ICh0[X5E0:j1E@070:j1E@80R6Dn201_FT000`28ICh0PFM7085WA`03085WA`80R6Dn
203:Uf800`30`<00<j7:03>QbP0S03>QbP030<30`00cXLX0<j7:0180<j7:0@3oool004l0<j7:0`30
`<1O03>QbP0308QU?P3d]700m;A`00@0m;A`00<0R6Dn0?BdL03d]7000P3d]7001@28ICh0mKA_0?Fd
K`3e]6l0R6Dn00@0mK=_00<0R6Dn0?FcKP3e/fh00P3e/fh208QU?PD0k:e[00<0R6Dn0>NYJ@3WZFT0
0`3WZFT01028ICh0f9eS0=RMH`28ICh50=BJHP0308QU?P36T5`0aY1L00D0aY1L00<0R6Dn0;^8E`2k
R5L01@2kR5L00`28ICh0/h9D0;>2E0050;>2E00308QU?P2`P5<0/81C00H0/81C00<0R6Dn0;:3E@2b
PeD0102bPeD208QU?P<0`<300`28ICh20:f5F0<0R6Dn00<0GT/f08QU?P28ICh01028ICh<0;f@GP<0
R6Dn1@2lRUX00`28ICh0eYeT0=JMI00:0=JMI00408QU?P3`/6h0R6Dn08QU?PD0olAj00@0R6Dn0?o8
NP3ob7X0olQj0P28ICh90<^DGP0308QU?P2mReX0_H]J00T0_H]J00<0R6Dn0:j1E@2^PED0202^PED3
08QU?PL0KeY000<0R6Dn085WA`21IdL00`21IdL308QU?PH0bYMR00<0R6Dn0<30`00cXLX0900cXLX0
0`30`<00<j7:03>QbP0A03>QbP40oooo001=03>QbP80`<30H@0cXLX00`28ICh0m;A`0?BdL0040?Bd
L00308QU?P3d]700m;A`0080m;A`00D0R6Dn0?FdK`3e]6l0mKA_08QU?P050?FcK`0308QU?P3e/fh0
mK=^0080mK=^00<0R6Dn0>b]J`3/[F/00`3/[F/00`28ICh0ijUY0>NYJ@040>NYJ@0308QU?P3HWF<0
R6Dn00H0e9YR00<0R6Dn0<J@G036T5`01@36T5`00`28ICh0^hQG0;^8E`040;^8E`D0R6Dn0`2cPU@0
0`28ICh0/81C0;20D`070;20D`0308QU?P2bPeD0/X=E00<0/X=E0`30`<0308QU?PL0[HEH1P28ICh2
07YUA@80R6Dn3@2mT5h308QU?P80_8YJ00<0R6Dn0=JMI03FWF@0103FWF@808QU?PH0olAj00@0R6Dn
0?o8NP3ob7X0olQj0P28ICh;0<^DGP0308QU?P2mReX0_H]J00P0_H]J00<0R6Dn0:j1E@2^PED0202^
PED00`28ICh0UgA>09MdCP0208QU?PD0KeY00`28ICh3085WA`0308QU?P2HMe00V7M@0080R6Dn1@3:
Uf800`28ICh0`<3003>QbP0S03>QbP030<30`00cXLX0<j7:0140<j7:0@3oool004X0<j7:0`30`<1Q
03>QbP80R6Dn00<0dYUQ08QU?P3d]7000`3d]7000`28ICh0m;A`0?BdL0020?BdL00308QU?P3e]6l0
mKA_0080mKA_00<0R6Dn0?FcK`3e/fl00P3e/fl00`28ICh0mK=^0?FcKP020?FcKP80R6Dn103/[F/0
0`28ICh0ijUY0>NYJ@050>NYJ@80R6Dn1`3DVV800`28ICh0aY1L0<J@G0050<J@G00308QU?P2kR5L0
^hQG00@0R6Dn1@2kR5L508QU?PL0/81C00@0R6Dn0;:3E@2bPeD0/X=E0`30`<030;:3E@0408QU?P2k
ReX0R6Dn08QU?PP0[HEH0P28ICh0101NBcH0R6Dn08QU?P28ICh207YUA@80R6Dn3P2mT5h908QU?PD0
ijm_00<0R6Dn0?o4NP3oa7X01P3oa7X01P28ICh0olQj0?o8NP28ICh0f9eS08QU?P/0biAN00<0R6Dn
0;f;FP2mReX02@2mReX00`28ICh0[X5E0:j1E@080:j1E@0408QU?P2GM4h0UgA>09MdCP80R6Dn101_
FT000`28ICh0GDTf08QU?P03085WA`0408QU?P2HMe00V7M@09QgD0<0R6Dn0P3:Uf800`28ICh0<j7:
0<30`00T03>QbP030<30`00cXLX0<j7:0100<j7:0@3oool004L0<j7:0`30`<1S03>QbP0508QU?P3B
VF40dYUQ0=:IH@28ICh00`3d]7000`28ICh0m;A`0?BdL0020?BdL00308QU?P3e]6l0mKA_0080mKA_
00<0R6Dn0?FcK`3e/fl00P3e/fl00`28ICh0mK=^0?FcKP030?FcKP0308QU?P3e/fh0R6Dn0080k:e[
00<0R6Dn0>NYJ@3WZFT01P3WZFT00`28ICh0e9YR0=BJHP060=BJHP0308QU?P36T5`0aY1L00@0aY1L
1028ICh<0;^8E`0308QU?P2iQeL0R6Dn00<0R6Dn0`2`P5<01028ICh0`<300<30`030`<050;:3E@03
08QU?P2kReX0^h]J0080^h]J0P28ICh80:f5F0<0R6Dn00<0FDLc08QU?P1jIDD00P1jIDD208QU?P`0
_I1N00<0R6Dn0>N_K`3W[fl02P3W[fl00`28ICh0olAj0?o4NP060?o4NP0408QU?P3ob7X0R6Dn08QU
?P80f9eS00<0R6Dn0<^DGP3;U5h02@3;U5h00`28ICh0_H]J0;f;FP090;f;FP0308QU?P2^PED0[X5E
00P0[X5E00<0R6Dn09MdCP2GM4h00`2GM4h208QU?P80KeY000@0R6Dn05e9=P1MBCH0R6Dn0`21IdL0
0`28ICh0V7M@09QgD00309QgD080R6Dn00<0bYMR08QU?P30`<009@0cXLX00`30`<00<j7:03>QbP0?
03>QbP40oooo001403>QbP<0`<30I@0cXLX00`28ICh0dYUQ0=:IH@030=:IH@0308QU?P3d]700R6Dn
00@0m;A`00<0R6Dn0?FdK`3e]6l00P3e]6l00`28ICh0mK=_0?FcK`030?FcK`0308QU?P3e/fh0mK=^
0080mK=^00@0R6Dn0?FcKP3e/fh0R6Dn0P3/[F/00`28ICh0ijUY0>NYJ@050>NYJ@80R6Dn203DVV80
0`28ICh0aY1L0<J@G0020<J@G080R6Dn00<0bY=N08QU?P2kR5L0302kR5L00`28ICh0^HMG0;V7E`04
0;V7E`0408QU?P30`<00`<300<30`0L0/X=E00<0R6Dn0;^;FP2kReX01@2kReX208QU?PD0[HEH1`28
ICh407YUA@80R6Dn2@2mT5h00`28ICh0ijm_0>N_K`0:0>N_K`0308QU?P3oa7X0olAj00H0olAj00@0
R6Dn0?o8NP28ICh0R6Dn0`3HWF<00`28ICh0biAN0<^DGP090<^DGP0308QU?P2mReX0_H]J00T0_H]J
00<0R6Dn0:j1E@2^PED0202^PED00`28ICh0UgA>09MdCP0509MdCP80R6Dn00@0KeY008QU?P1MBCH0
GDTf0P28ICh00`21IdL0R6Dn09QgD00609QgD080R6Dn00<0<j7:0<30`00cXLX08`0cXLX00`30`<00
<j7:03>QbP0?03>QbP40oooo001103>QbP<0`<30IP0cXLX208QU?PL0dYUQ00<0R6Dn0?BdL03d]700
0`3d]7040?FdK`0308QU?P3e/fl0mK=_00<0mK=_00<0R6Dn0?FcKP3e/fh00P3e/fh00`28ICh0mK=^
0?FcKP020?FcKP80R6Dn1`3WZFT00`28ICh0i:IX08QU?P080=BJHP0308QU?P36T5`0R6Dn0080R6Dn
0`3:Teh00`28ICh0^hQG0;^8E`0;0;^8E`0308QU?P2iQeL0^HMG0080^HMG0`30`<030;V7E`80R6Dn
1@2bPeD00`28ICh0^h]J0;^;FP070;^;FPD0R6Dn102cSeh508QU?P@0NVE50P28ICh50;f@GP80R6Dn
303W[fl00`28ICh0olAj0?o4NP070?o4NP80R6Dn1@3HWF<00`28ICh0biAN0<^DGP0:0<^DGP0308QU
?P2mReX0_H]J00P0_H]J00<0R6Dn0:j1E@2^PED0202^PED00`28ICh0UgA>09MdCP0709MdCP80R6Dn
101MBCH00`28ICh0PFM708QU?P0809QgD00308QU?P0cXLX0`<3002@0<j7:00<0`<3003>QbP0cXLX0
3P0cXLX10?ooo`00?P0cXLX30<30`6P0<j7:00<0R6Dn0=:IH@3BVF401P3BVF400`28ICh0fIiT08QU
?P030?BdL00308QU?P3e]6l0mKA_0080mKA_00<0R6Dn0?FcK`3e/fl00P3e/fl00`28ICh0mK=^0?Fc
KP020?FcKP0308QU?P3e/fh0mK=^00<0mK=^00<0R6Dn0>NYJ@3WZFT01@3WZFT01028ICh0i:IX0>BV
J028ICh80=BJHP80R6Dn1P3:Teh00`28ICh0^hQG0;^8E`0;0;^8E`0308QU?P2iQeL0`<300080`<30
202iQeL208QU?P80/X=E00<0R6Dn0;^;FP2kReX0202kReX00`28ICh0d9]T0=2KI00408QU?P@0/hmN
1028ICh507YUA@80R6Dn0P2mT5h00`28ICh0ijm_0>N_K`0<0>N_K`0308QU?P3oa7X0olAj00D0olAj
0`28ICh60=RMH`0308QU?P3;U5h0biAN00X0biAN00<0R6Dn0;f;FP2mReX02@2mReX00`28ICh0[X5E
0:j1E@080:j1E@0308QU?P2GM4h0UgA>00P0UgA>00<0R6Dn05e9=P1MBCH00P1MBCH00`28ICh0PFM7
08QU?P0709QgD00308QU?P0cXLX0`<3002D0<j7:00<0`<3003>QbP0cXLX03@0cXLX10?ooo`00?00c
XLX20<30`6T0<j7:0P28ICh80=:IH@0708QU?P3IWV@0fIiT0=VNI028ICh0m;A`08QU?P040?FdK`03
08QU?P3e/fl0mK=_0080mK=_00<0R6Dn0?FcKP3e/fh00`3e/fh00`28ICh0mK=^0?FcKP020?FcKP80
R6Dn1P3WZFT01@28ICh0i:IX0>BVJ03TYVP0R6Dn00L0e9YR00<0R6Dn0<ZCGP3:Teh01P3:Teh00`28
ICh0^hQG0;^8E`0:0;^8E`<0`<303@2iQeL308QU?PT0^h]J00<0R6Dn0=2KI03@Vf@01@3@Vf@:08QU
?P@0NVE51P28ICh;0>N_K`0308QU?P3oa7X0olAj0080olAj1@28ICh80=RMH`0308QU?P3;U5h0biAN
00T0biAN1`28ICh60;f;FP0308QU?P2^PED0[X5E00P0[X5E00<0R6Dn09MdCP2GM4h0202GM4h308QU
?P<0GDTf00<0R6Dn085WA`28ICh01`2HMe000`28ICh0<j7:0<30`00T03>QbP030<30`00cXLX0<j7:
00d0<j7:0@3oool003T0<j7:0`30`<1Z03>QbP0308QU?P3BVF40dYUQ00L0dYUQ00<0R6Dn0=VNI03I
WV@00`3IWV@00`28ICh0mKA_0?FdK`020?FdK`0308QU?P3e/fl0mK=_00<0mK=_00<0R6Dn0?FcKP3e
/fh00P3e/fh00`28ICh0mK=^0?FcKP030?FcKP0308QU?P3e/fl0R6Dn00@0ijUY00<0R6Dn0>BVJ03T
YVP00`3TYVP00`28ICh0e9YR0=BJHP020=BJHP80R6Dn2@3:Teh00`28ICh0^hQG0;^8E`070;^8E`<0
`<3000<0R6Dn0;V7E`2iQeL03@2iQeL00`28ICh0`hiK0<>>F`0208QU?PD0^h]J0P28ICh80=2KI080
R6Dn1P3]]78608QU?PH0ZHUI1P28ICh40>N_K`0308QU?P3oa7X0R6Dn00<0R6Dn0P2mV5h00`28ICh0
f9eS0=RMH`090=RMH`0308QU?P3;U5h0biAN00@0biAN1028ICh00`33SEX0R6Dn0;Z7E`040;Z7E`P0
R6Dn2@2^PED00`28ICh0UgA>09MdCP0909MdCP0408QU?P1[Ecd0R6Dn08QU?P<0GDTf00<0R6Dn09Qg
D02HMe001@2HMe001028ICh0<j7:03>QbP30`<0T03>QbP030<30`00cXLX0<j7:00`0<j7:0@3oool0
03H0<j7:0`30`<1[03>QbP80R6Dn2@3BVF400`28ICh0fIiT0=VNI0030=VNI00308QU?P3SYVL0R6Dn
00<0mKA_1@3e/fl00`28ICh0mK=^0?FcKP020?FcKP0308QU?P3e/fh0mK=^00<0mK=^00@0R6Dn0?Fc
K`3e/fl0R6Dn103WZFT00`28ICh0i:IX0>BVJ0030>BVJ00508QU?P3DVV80e9YR0=BJHP28ICh02P3:
Teh00`28ICh0^hQG0;^8E`050;^8E`<0`<300`2kR5L00`28ICh0^HMG0;V7E`0=0;V7E`0308QU?P33
SU/0`hiK0080`hiK0P28ICh20;^;FP0308QU?P3@Vf@0d9]T00L0d9]T00<0R6Dn0>fdLP3]]7801@3]
]7801028ICh0olAi0?o4N@3oa7T408QU?P/0ZHUI1P28ICh40;fHGP80R6Dn303HWF<00`28ICh0biAN
0<^DGP0408QU?PD0`heJ00<0R6Dn0;Z7E`2jQeL02@2jQeL00`28ICh0]XEF08QU?P0308QU?PD0[X5E
00<0R6Dn09MdCP2GM4h02@2GM4h01@28ICh0JeLm06]G?@1[Ecd0R6Dn00<0GDTf00<0R6Dn09QgD02H
Me001@2HMe000`28ICh0<j7:0<30`00U03>QbP030<30`00cXLX0<j7:00/0<j7:0@3oool003<0<j7:
0`30`<1]03>QbP0308QU?P3BVF40dYUQ00P0dYUQ00<0R6Dn0=VNI03IWV@00`3IWV@01`28ICh0hjIW
0>>VI`3SYVL0R6Dn0?FdK`28ICh0103e/fl00`28ICh0mK=^0?FcKP030?FcKP0308QU?P3e/fh0mK=^
0080mK=^00D0R6Dn0?FcK`3e/fl0mK=_08QU?P030>NYJ@0308QU?P3TYVP0i:IX00@0i:IX00@0R6Dn
0=BJHP3DVV80R6Dn2`3:Teh00`28ICh0^hQG0;^8E`020;^8E`<0`<301P2kR5L00`28ICh0^HMG0;V7
E`0<0;V7E`0308QU?P33SU/0`hiK00D0`hiK0`28ICh80=2KI00308QU?P3]]780kKAb00D0kKAb00<0
R6Dn0?o4N@3oa7T00P3oa7T00`28ICh0olAg08QU?P0408QU?PP0ZHUI0P28ICh60;fHGP80R6Dn00<0
iJIX08QU?P3HWF<02`3HWF<308QU?PT0`heJ00<0R6Dn0;Z7E`2jQeL02@2jQeL00`28ICh0]XEF0;J5
EP030;J5EP@0R6Dn0P2^PED00`28ICh0UgA>09MdCP0809MdCP0308QU?P1[Ecd0JeLm0080JeLm0P28
ICh205e9=P80R6Dn1P2HMe000`28ICh0<j7:0<30`00T03>QbP030<30`00cXLX0<j7:00/0<j7:0@3o
ool00300<j7:0`30`<1_03>QbP0308QU?P3BVF40dYUQ00P0dYUQ00<0R6Dn0=VNI03IWV@0103IWV@0
0`28ICh0hjIW0>>VI`020>>VI`0308QU?P3e/fl0mK=_00<0mK=_00<0R6Dn0?FcKP3e/fh00P3e/fh0
0`28ICh0mK=^0?FcKP020?FcKP0308QU?P3e/fl0mK=_0080mK=_00@0R6Dn0>NYJ@3WZFT0R6Dn1`3T
YVP308QU?P`0bY=N00<0R6Dn0;^8E`30`<000P30`<090;^8E`0308QU?P2iQeL0^HMG00`0^HMG00<0
R6Dn0<>>F`33SU/02033SU/408QU?P80d9]T0P28ICh60>fdLP80R6Dn103oa7T01@28ICh0olAg0?o4
M`3oa7L0R6Dn0080olMh1028ICh30:V9F@80R6Dn0P2mV5h608QU?P050?2_K028ICh0iJIX0>FVJ028
ICh02@3HWF<308QU?P/0`heJ00<0R6Dn0;Z7E`2jQeL02@2jQeL00`28ICh0]XEF0;J5EP070;J5EP@0
R6Dn2P2GM4h00`28ICh0JeLm06]G?@0306]G?@0308QU?P1MBCH0GDTf00<0R6Dn102HMe001028ICh0
<j7:03>QbP30`<0T03>QbP030<30`00cXLX0<j7:00X0<j7:0@3oool002h0<j7:0P30`<1`03>QbP80
R6Dn2P3BVF400`28ICh0fIiT0=VNI0040=VNI00308QU?P3SYVL0hjIW0080hjIW00<0R6Dn0>b/J`28
ICh00`3e/fl00`28ICh0mK=^0?FcKP020?FcKP0308QU?P3e/fh0mK=^00<0mK=^00<0R6Dn0?FcK`3e
/fl00`3e/fl208QU?PP0i:IX00<0R6Dn0<ZCGP3:Teh02`3:Teh30<30`0/0^hQG00<0R6Dn0;V7E`2i
QeL0302iQeL00`28ICh0`hiK0<>>F`0=0<>>F`<0R6Dn1P3]]7800`28ICh0olAi0?o4N@030?o4N@03
08QU?P3oa7L0olAg0080olAg00@0R6Dn0?o7N03oagP0R6Dn0`3oaWT708QU?PH0l:m/00D0R6Dn0>FV
J03UYVP0iJIX08QU?P080=RMH`0408QU?P3?UUl0ciIO08QU?P/0`heJ00<0R6Dn0;Z7E`2jQeL02@2j
QeL00`28ICh0]XEF0;J5EP090;J5EP0308QU?P2hR5T0R6Dn0080R6Dn1`2GM4h00`28ICh0JeLm06]G
?@0406]G?@<0R6Dn0P1YEC`00`28ICh0V7M@09QgD00209QgD00408QU?P0cXLX0<j7:0<30`2@0<j7:
00<0`<3003>QbP0cXLX02@0cXLX10?ooo`00:`0cXLX30<30`740<j7:00<0R6Dn0=:IH@3BVF402@3B
VF400`28ICh0fIiT0=VNI0040=VNI00308QU?P3SYVL0hjIW00<0hjIW00<0R6Dn0>b/J`28ICh00P3e
/fl00`28ICh0mK=^0?FcKP030?FcKP0308QU?P3e/fh0mK=^0080mK=^00<0R6Dn0?FcK`3e/fl0103e
/fl00`28ICh0i:IX0>BVJ0060>BVJ080R6Dn2P3:Teh30<30`0030<ZCGP28ICh0^hQG00/0^hQG00<0
R6Dn0;V7E`2iQeL0302iQeL00`28ICh0`hiK0<>>F`0=0<>>F`0308QU?P3GWF@0eieT00<0R6Dn0P3]
]7800`28ICh0olAi0?o4N@030?o4N@0308QU?P3oa7L0olAg0080olAg00D0R6Dn0?o7N03oagP0olMh
08QU?P040?o6N@0308QU?P3o^g<0ok]c0080ok]c00<0R6Dn0?2_K03`[f`00`3`[f`00`28ICh0iJIX
0>FVJ0020>FVJ00308QU?P3HWF<0f9eS00@0f9eS0P28ICh30<nFG`0308QU?P33SEX0`heJ00T0`heJ
00<0R6Dn0;Z7E`2jQeL02@2jQeL00`28ICh0]XEF0;J5EP090;J5EP0308QU?P2hR5T0^8QI0080^8QI
1028ICh309MdCP0308QU?P1[Ecd0JeLm00H0JeLm0P28ICh206UE?080R6Dn0`2HMe000`28ICh0<j7:
0<30`00T03>QbP030<30`00cXLX0<j7:00T0<j7:0@3oool002P0<j7:0`30`<1b03>QbP<0R6Dn2P3B
VF400`28ICh0fIiT0=VNI0040=VNI00308QU?P3SYVL0hjIW00<0hjIW00L0R6Dn0>b/J`3/[6/0k:a[
08QU?P3e/fl0R6Dn00@0mK=^00<0R6Dn0?FcKP3e/fh00P3e/fh00`28ICh0mK=_0?FcK`040?FcK`80
R6Dn1P3TYVP208QU?P030?6cL028ICh0bY=N00H0bY=N0`30`<040<ZCGP0308QU?P2kR5L0^hQG00@0
^hQG2@28ICh;0;V7E`0308QU?P33SU/0`hiK00d0`hiK00<0R6Dn0=NMI03GWF@0103GWF@F08QU?P@0
ok]c00<0R6Dn0?2_K03`[f`00`3`[f`00`28ICh0iJIX0>FVJ0030>FVJ00308QU?P3HWF<0f9eS0080
f9eS0P28ICh60<nFG`0308QU?P33SEX0`heJ00P0`heJ00<0R6Dn0;Z7E`2jQeL02@2jQeL00`28ICh0
]XEF0;J5EP090;J5EP0308QU?P2hR5T0^8QI00H0^8QI0`28ICh00`2GM4h0R6Dn06]G?@0806]G?@05
08QU?P1YEC`0JEDl06UE?028ICh00P2HMe001028ICh0<j7:03>QbP30`<0T03>QbP030<30`00cXLX0
<j7:00P0<j7:0@3oool002D0<j7:0`30`<1d03>QbP0508QU?P32SEX0`XeJ0<:=FP28ICh0203BVF40
0`28ICh0fIiT0=VNI0040=VNI00308QU?P3SYVL0hjIW00<0hjIW00<0R6Dn0>b/J`3/[6/00`3/[6/0
0`28ICh0mK=^0?FcKP020?FcKP0308QU?P3e/fh0mK=^0080mK=^00<0R6Dn0?FcK`3e/fl0103e/fl0
0`28ICh0mK=_08QU?P050>BVJ00508QU?P3a/g00lK=`0?6cL028ICh0103:Teh30<30`0H0bY=N2028
ICh60;b8F00308QU?P2hQEH0^8EF00@0R6Dn1`2iQeL00`28ICh0`hiK0<>>F`0=0<>>F`0308QU?P3G
WF@0eieT00X0eieT00<0R6Dn0>b]K03/[F`01P3/[F`00`28ICh0m;=_0?BcK`040?BcK`0408QU?P3o
^g<0ok]c08QU?PD0l:m/00<0R6Dn0>FVJ03UYVP01@3UYVP01028ICh0f9eS0=RMH`28ICh80<nFG`03
08QU?P33SEX0`heJ00P0`heJ00<0R6Dn0;Z7E`2jQeL02@2jQeL00`28ICh0]XEF0;J5EP090;J5EP03
08QU?P2hR5T0^8QI00T0^8QI0`28ICh806]G?@<0R6Dn0P1YEC`208QU?P0509QgD028ICh0<j7:03>Q
bP30`<00900cXLX00`30`<00<j7:03>QbP0703>QbP40oooo000R03>QbP<0`<30M@0cXLX208QU?P@0
`XeJ00<0R6Dn0=:IH@3BVF401@3BVF400`28ICh0fIiT0=VNI0050=VNI00308QU?P3SYVL0hjIW0080
hjIW00<0R6Dn0>b/J`3/[6/00`3/[6/00`28ICh0m;9^08QU?P020?FcKP0308QU?P3e/fh0mK=^00<0
mK=^00<0R6Dn0?FcK`3e/fl00`3e/fl01028ICh0mK=_0?FcK`28ICh40>BVJ00308QU?P3a/g00lK=`
0080lK=`00<0R6Dn0<ZCGP30`<000P30`<070<ZCGP80R6Dn00<0cIIO08QU?P2lR5P02`2lR5P00`28
ICh0^8EF0;R5EP040;R5EP@0R6Dn0P2iQeL00`28ICh0`hiK0<>>F`0=0<>>F`0308QU?P3GWF@0eieT
00X0eieT00<0R6Dn0>b]K03/[F`01`3/[F`00`28ICh0m;=_0?BcK`050?BcK`0308QU?P3o^g<0R6Dn
00D0l:m/00<0R6Dn0>FVJ03UYVP01@3UYVP308QU?PT0ciIO00<0R6Dn0<>=FP33SEX02@33SEX00`28
ICh0^XMG0;Z7E`080;Z7E`0308QU?P2fQEH0]XEF00X0]XEF00<0R6Dn0;R8F@2hR5T02@2hR5T00`28
ICh0`iEQ08QU?P0308QU?PD0JeLm00@0R6Dn07QSA028ICh0R6Dn0P1YEC`208QU?P80<j7:00<0`<30
03>QbP0cXLX08P0cXLX00`30`<00<j7:03>QbP0703>QbP40oooo000O03>QbP<0`<30MP0cXLX208QU
?PL0`XeJ00<0R6Dn0=:IH@3BVF400`3BVF400`28ICh0fIiT0=VNI0050=VNI00308QU?P3SYVL0hjIW
00<0hjIW00<0R6Dn0>b/J`3/[6/00`3/[6/01P28ICh0m;9^0?BbKP28ICh0mK=^08QU?P@0mK=^00<0
R6Dn0?FcK`3e/fl0103e/fl01P28ICh0mK=_0?FcK`3e/fl0R6Dn0>BVJ080R6Dn103a/g030<30`0L0
bY=N0`28ICh30<fFG`0308QU?P2lR5P0_8QH00T0_8QH00<0R6Dn0;R5EP2hQEH02@2hQEH408QU?Pd0
`hiK00<0R6Dn0=NMI03GWF@02`3GWF@00`28ICh0k:e/0>b]K0060>b]K00308QU?P3d/fl0m;=_00L0
m;=_00<0R6Dn0?2_K03`[f`00`3`[f`00`28ICh0iJIX0>FVJ0060>FVJ00308QU?P3?UUl0ciIO00T0
ciIO00<0R6Dn0<>=FP33SEX02@33SEX00`28ICh0^XMG0;Z7E`090;Z7E`0308QU?P2fQEH0]XEF00T0
]XEF00<0R6Dn0;R8F@2hR5T02@2hR5T00`28ICh0`iEQ0<>EH@030<>EH@@0R6Dn00<0JeLm08QU?P1h
Hd@00P1hHd@208QU?P80JEDl00@0R6Dn03>QbP0cXLX0`<308`0cXLX20<30`0P0<j7:0@3oool001d0
<j7:0P30`<1h03>QbP0308QU?P32SEX0`XeJ00L0`XeJ00<0R6Dn0=:IH@3BVF400P3BVF400`28ICh0
fIiT0=VNI0050=VNI00308QU?P3SYVL0hjIW00<0hjIW00<0R6Dn0>b/J`3/[6/00`3/[6/00`28ICh0
m;9^0?BbKP020?BbKP0308QU?P3e/fh0mK=^0080mK=^00<0R6Dn0?FcK`3e/fl0103e/fl00`28ICh0
mK=_0?FcK`020?FcK`80R6Dn0`3a/g030<30`0030?6cL028ICh0bY=N00D0bY=N0P28ICh50<fFG`03
08QU?P2lR5P0_8QH00X0_8QH00<0R6Dn0;R5EP2hQEH02`2hQEH00`28ICh0`HaJ08QU?P0208QU?PT0
`hiK00<0R6Dn0=NMI03GWF@02`3GWF@00`28ICh0k:e/0>b]K0070>b]K00308QU?P3d/fl0m;=_00H0
m;=_0P28ICh40?2_K00308QU?P3UYVP0iJIX00H0iJIX0P28ICh;0<nFG`0308QU?P33SEX0`heJ00T0
`heJ00<0R6Dn0;Z7E`2jQeL02@2jQeL00`28ICh0]XEF0;J5EP090;J5EP0308QU?P2hR5T0^8QI00T0
^8QI00<0R6Dn0<>EH@33UF401`33UF4308QU?P@0N6=40P28ICh01@1YEC`0R6Dn08QU?P28ICh0`<30
0080R6Dn7@0cXLX30<30`00303>QbP30`<00<j7:00L0<j7:0@3oool001X0<j7:0`30`<1h03>QbP80
R6Dn2`32SEX01028ICh0dYUQ0=:IH@28ICh70=VNI00308QU?P3SYVL0hjIW00<0hjIW00<0R6Dn0>b/
J`3/[6/00`3/[6/00`28ICh0m;9^0?BbKP020?BbKP0308QU?P3k^740R6Dn0080mK=^00<0R6Dn0?Fc
K`3e/fl0103e/fl00`28ICh0mK=_0?FcK`030?FcK`0308QU?P3a/g00`<300080`<30103a/g001028
ICh0bY=N0<ZCGP3:Teh308QU?PL0cIIO00<0R6Dn0;b8F02lR5P02P2lR5P00`28ICh0^8EF0;R5EP0:
0;R5EP0308QU?P31S5X0`HaJ00<0`HaJ0`28ICh60<>>F`0308QU?P3GWF@0eieT00X0eieT00<0R6Dn
0>b]K03/[F`01`3/[F`00`28ICh0m;=_0?BcK`070?BcK`0308QU?P3j]g00R6Dn0080l:m/00<0R6Dn
0>FVJ03UYVP01P3UYVP00`28ICh0gj9V08QU?P0;0<nFG`0308QU?P33SEX0`heJ00T0`heJ00<0R6Dn
0;Z7E`2jQeL02@2jQeL00`28ICh0]XEF0;J5EP090;J5EP0308QU?P2hR5T0^8QI00T0^8QI00<0R6Dn
0<>EH@33UF402@33UF401028ICh0f:AZ0=RTJP3HY6X307QSA0<0R6Dn00@0N6=40<30`028ICh0R6Dn
6@0cXLX40<30`0@0<j7:00<0`<3003>QbP0cXLX01P0cXLX10?ooo`005`0cXLX30<30`7X0<j7:00<0
R6Dn0<:=FP32SEX02`32SEX00`28ICh0dYUQ08QU?P080=VNI00308QU?P3SYVL0hjIW00<0hjIW00<0
R6Dn0>b/J`3/[6/00`3/[6/00`28ICh0m;9^0?BbKP020?BbKP0608QU?P3k^740nkQa08QU?P3e/fh0
R6Dn1@3e/fl00`28ICh0mK=_0?FcK`030?FcK`<0`<301`3a/g001028ICh0bY=N08QU?P28ICh:0<fF
G`0308QU?P2lR5P0_8QH00X0_8QH00<0R6Dn0;R5EP2hQEH02P2hQEH00`28ICh0`HaJ0<6<FP060<6<
FP<0R6Dn0P33SU/00`28ICh0eieT0=NMI00:0=NMI00308QU?P3/[F`0k:e/00L0k:e/00<0R6Dn0?Bc
K`3d/fl01`3d/fl01028ICh0n[M`0?ZgL028ICh20?2_K00308QU?P3UYVP0iJIX00D0iJIX00@0R6Dn
0=nRIP3OXVH0R6Dn303?UUl00`28ICh0`heJ0<>=FP080<>=FP0308QU?P2jQeL0^XMG00T0^XMG00<0
R6Dn0;J5EP2fQEH02@2fQEH00`28ICh0^8QI0;R8F@090;R8F@0308QU?P33UF40`iEQ00T0`iEQ00<0
R6Dn0=RTJP3HY6X01@3HY6X01@1hHd@0R6Dn08QU?P1hHd@0`<3001L0<j7:0`30`<0803>QbP030<30
`00cXLX0<j7:00H0<j7:0@3oool001@0<j7:0`30`<0g03>QbPd0R6Dn=`0cXLX208QU?Pl0`XeJ00<0
R6Dn0=VNI03IWV@01P3IWV@00`28ICh0hjIW0>>VI`030>>VI`0308QU?P3/[6/0k:a[00<0k:a[00<0
R6Dn0?BbKP3d/Vh00P3d/Vh00`28ICh0nkQa0?^hL@020?^hL@0308QU?P3e/fl0mK=_00<0mK=_00@0
R6Dn0?FcK`3e/fl0mK=_0`30`<0:0?6cL080R6Dn303=UUl00`28ICh0_8QH0;b8F0090;b8F00308QU
?P2hQEH0^8EF00X0^8EF00<0R6Dn0<6<FP31S5X02P31S5X308QU?P/0eieT00<0R6Dn0>b]K03/[F`0
203/[F`00`28ICh0m;=_0?BcK`070?BcK`0408QU?P3j]g00n[M`0?ZgL080R6Dn1`3UYVP01@28ICh0
gj9V0=nRIP3OXVH0R6Dn00`0ciIO00<0R6Dn0<>=FP33SEX02033SEX00`28ICh0^XMG0;Z7E`090;Z7
E`0308QU?P2fQEH0]XEF00T0]XEF00<0R6Dn0;R8F@2hR5T02@2hR5T00`28ICh0`iEQ0<>EH@090<>E
H@0308QU?P3HY6X0f:AZ00D0f:AZ00<0R6Dn0>V/K028ICh00P28ICh00`30`<00<j7:03>QbP0A03>Q
bP<0`<302`0cXLX00`30`<00<j7:03>QbP0603>QbP40oooo000A03>QbP<0`<30>00cXLX808QU?PD0
G3PS1028IChc03>QbP80R6Dn4032SEX00`28ICh0bI9M08QU?P060=VNI00308QU?P3SYVL0hjIW00<0
hjIW00<0R6Dn0>b/J`3/[6/0103/[6/00`28ICh0m;9^0?BbKP020?BbKP0708QU?P3k^740nkQa0?^h
L@28ICh0oked08QU?P030?FcK`0308QU?P3e/fl0`<300080`<3000<0mK=_08QU?P3a/g00203a/g03
08QU?Pd0cIIO00<0R6Dn0;b8F02lR5P02@2lR5P00`28ICh0^8EF0;R5EP0:0;R5EP0308QU?P31S5X0
`HaJ00X0`HaJ00<0R6Dn0=BKHP3DVf800P28ICh80=NMI00308QU?P3/[F`0k:e/00P0k:e/00<0R6Dn
0?BcK`3d/fl01`3d/fl00`28ICh0n[M`0?ZgL0020?ZgL00308QU?P3UYVP0iJIX00D0iJIX00<0R6Dn
0=nRIP3OXVH00P3OXVH00`28ICh0ciIO0<nFG`0:0<nFG`0308QU?P33SEX0`heJ00P0`heJ00<0R6Dn
0;Z7E`2jQeL02@2jQeL00`28ICh0]XEF0;J5EP090;J5EP0308QU?P2hR5T0^8QI00X0^8QI00<0R6Dn
0<>EH@33UF402@33UF401028ICh0f:AZ0=RTJP3HY6X208QU?PD0jJa/00<0R6Dn03>QbP30`<003`0c
XLX30<30`0l0<j7:00<0`<3003>QbP0cXLX01@0cXLX10?ooo`003`0cXLX20<30`3P0<j7:1028ICh2
03@P5080n;af1@28ICh505`h8`D0R6Dn;P0cXLX208QU?Q00`XeJ0P28ICh20<VBG@0308QU?P3IWV@0
fIiT00<0fIiT00<0R6Dn0>>VI`3SYVL0103SYVL00`28ICh0k:a[0>b/J`030>b/J`0308QU?P3d/Vh0
m;9^0080m;9^00<0R6Dn0?^hL@3k^7400P3k^7400`28ICh0oked08QU?P020?FcK`<0`<300`3e/fl0
0`28ICh0lK=`0?6cL0070?6cL00408QU?P3a/g00lK=`08QU?Pd0cIIO00<0R6Dn0;b8F02lR5P02@2l
R5P00`28ICh0^8EF0;R5EP0:0;R5EP0308QU?P31S5X0`HaJ00X0`HaJ00<0R6Dn0=BKHP3DVf800P3D
Vf8308QU?PD0eieT00<0R6Dn0>b]K03/[F`0203/[F`00`28ICh0m;=_0?BcK`060?BcK`0308QU?P3j
]g00n[M`00<0n[M`00<0R6Dn0>FVJ03UYVP0103UYVP00`28ICh0gj9V0=nRIP040=nRIP0308QU?P3?
UUl0ciIO00P0ciIO3`28ICh90;Z7E`0308QU?P2fQEH0]XEF00T0]XEF00<0R6Dn0;R8F@2hR5T02P2h
R5T00`28ICh0`iEQ0<>EH@090<>EH@0408QU?P3HY6X0R6Dn08QU?PL0jJa/00<0R6Dn03>QbP30`<00
300cXLX30<30`180<j7:00<0`<3003>QbP0cXLX01@0cXLX10?ooo`00300cXLX30<30`3P0<j7:0`28
ICh00`3[]fl0R6Dn08QU?P050?RlMP<0R6Dn00<0cieU08QU?P28ICh00`28ICh205`h8`80R6Dn00<0
Bb`K08QU?P28ICh0:P0cXLX208QU?P030;Z7E`28ICh0`XeJ00h0`XeJ00<0R6Dn0<VBG@39TUd00`39
TUd01@28ICh0fIiT0=VNI03IWV@0R6Dn00H0hjIW00<0R6Dn0>b/J`3/[6/00`3/[6/00`28ICh0m;9^
0?BbKP020?BbKP0308QU?P3k^740nkQa0080nkQa00<0R6Dn0?nmM03o_G@00`30`<000`28ICh0mK=_
0?FcK`030?FcK`0308QU?P3a/g00lK=`00H0lK=`00D0R6Dn0?6cL03a/g00lK=`08QU?P0<0<fFG`03
08QU?P2lR5P0_8QH00X0_8QH00<0R6Dn0;R5EP2hQEH02@2hQEH00`28ICh0`HaJ0<6<FP0:0<6<FP03
08QU?P3DVf80e9]R00H0e9]R0P28ICh20=NMI00308QU?P3/[F`0k:e/00P0k:e/00<0R6Dn0?BcK`3d
/fl01`3d/fl00`28ICh0n[M`0?ZgL0040?ZgL00308QU?P3UYVP0iJIX0080iJIX00<0R6Dn0=nRIP3O
XVH01@3OXVH00`28ICh0ciIO0<nFG`050<nFG`<0R6Dn00<0bi=N08QU?P2oReT02@2oReT00`28ICh0
^XMG0;Z7E`0608QU?P<0^XMG00<0R6Dn0;J5EP2fQEH02P2fQEH00`28ICh0^8QI0;R8F@090;R8F@03
08QU?P33UF40`iEQ00P0`iEQ0`28ICh80>V/K00508QU?P0cXLX0<j7:03>QbP30`<001`0cXLX40<30
`1D0<j7:00<0`<3003>QbP0cXLX01@0cXLX10?ooo`002@0cXLX30<30`3T0<j7:0P28ICh30>^gK`04
08QU?P3h_7H0n;af0?RlMPD0R6Dn0P3EWF@308QU?P80cieU1`28ICh00`1;;1/0R6Dn03>QbP0U03>Q
bP<0R6Dn102jQeL00`28ICh0`XeJ0<:=FP0;0<:=FP0308QU?P39TUd0bI9M00D0bI9M00@0R6Dn0=VN
I03IWV@0R6Dn1@3SYVL00`28ICh0k:a[0>b/J`040>b/J`0308QU?P3d/Vh0m;9^0080m;9^00D0R6Dn
0?^hL@3k^740nkQa08QU?P030<30`080oked00<0R6Dn0?FcK`3e/fl00`3e/fl00`28ICh0lK=`0?6c
L0050?6cL080R6Dn103a/g000`28ICh0cIIO0<fFG`0:0<fFG`0308QU?P2lR5P0_8QH00T0_8QH00<0
R6Dn0;R5EP2hQEH02P2hQEH00`28ICh0`HaJ0<6<FP0:0<6<FP0308QU?P3DVf80e9]R00P0e9]R0`28
ICh90>b]K00308QU?P3d/fl0m;=_00L0m;=_00<0R6Dn0?ZgL03j]g001@3j]g001@28ICh0iJIX0>FV
J03UYVP0R6Dn00P0gj9V00<0R6Dn0<nFG`3?UUl00P3?UUl308QU?P@0bi=N00<0R6Dn0;n;F@2oReT0
202oReT00`28ICh0^XMG0;Z7E`060;Z7E`L0R6Dn2@2fQEH00`28ICh0^8QI0;R8F@090;R8F@0308QU
?P33UF40`iEQ00@0`iEQ1028ICh00`3LXVL0R6Dn0>V/K0080>V/K00308QU?P0cXLX0<j7:0080<j7:
00@0`<3003>QbP0cXLX0<j7:0`30`<0I03>QbP030<30`00cXLX0<j7:00D0<j7:0@3oool000L0<j7:
0P30`<0k03>QbP0308QU?P3[]fl0jkM_0080jkM_1@28ICh40>b]K@0308QU?P3EWF@0eIeT00<0eIeT
1028ICh00`3?WFD0R6Dn08QU?P0308QU?P0304//6`28ICh0R6Dn0240<j7:0`28ICh70;Z7E`0308QU
?P32SEX0`XeJ00X0`XeJ00<0R6Dn0<VBG@39TUd01P39TUd00`28ICh0fIiT08QU?P050>>VI`0308QU
?P3/[6/0k:a[00@0k:a[00<0R6Dn0?BbKP3d/Vh00P3d/Vh00`28ICh0nkQa0?^hL@030<30`0@0oked
00<0R6Dn0?o1MP28ICh00`3e/fl00`28ICh0lK=`0?6cL0050?6cL00308QU?P3a/g00lK=`00D0lK=`
00<0R6Dn0<fFG`3=UUl02@3=UUl00`28ICh0_8QH0;b8F0090;b8F00308QU?P2hQEH0^8EF00X0^8EF
00<0R6Dn0<6<FP31S5X02@31S5X00`28ICh0e9]R0=BKHP090=BKHP0308QU?P3ZZf/0jZ][0080R6Dn
1`3/[F`00`28ICh0m;=_0?BcK`070?BcK`0308QU?P3j]g00n[M`00D0n[M`00@0R6Dn0>FVJ03UYVP0
R6Dn2@3OXVH00`28ICh0ciIO08QU?P0208QU?PL0bi=N00<0R6Dn0;n;F@2oReT0202oReT00`28ICh0
^XMG0;Z7E`090;Z7E`0408QU?P2kR5P0^hQH0;^8F0H0R6Dn0`2fQEH00`28ICh0^8QI0;R8F@090;R8
F@0308QU?P33UF40`iEQ00@0R6Dn1@3LXVL00`28ICh0jJa/0>V/K0070>V/K00308QU?P0cXLX0<j7:
0080<j7:1030`<0L03>QbP030<30`00cXLX0<j7:00D0<j7:0@3oool000L0<j7:0P30`<0j03>QbP03
08QU?P3[]fl0jkM_0080jkM_0P28ICh70>b]K@0308QU?P3EWF@0eIeT00P0eIeT0`28ICh00`1M=b40
R6Dn08QU?P0408QU?Qh0<j7:0P28ICh;0;Z7E`0308QU?P32SEX0`XeJ00L0`XeJ0P28ICh:0<VBG@03
08QU?P3SYVL0hjIW00@0hjIW00<0R6Dn0>b/J`3/[6/00`3/[6/00`28ICh0m;9^0?BbKP020?BbKP06
08QU?P30`<00`<300<30`03k^740R6Dn103o_G@01`28ICh0ol5f0?o1MP3o`GH0R6Dn0?FcK`28ICh0
1P3a/g0208QU?PP0lK=`00<0R6Dn0<fFG`3=UUl0203=UUl?08QU?PX0^8EF00<0R6Dn0<6<FP31S5X0
2P31S5X00`28ICh0e9]R0=BKHP090=BKHP0308QU?P3ZZf/0jZ][0080jZ][0P28ICh40>b]K00308QU
?P3d/fl0m;=_00L0m;=_00<0R6Dn0?ZgL03j]g001`3j]g0208QU?PX0gj9V0P28ICh:0<^CGP0308QU
?P2oReT0_h]I00P0_h]I00<0R6Dn0;Z7E`2jQeL02@2jQeL00`28ICh0^hQH0;^8F0070;^8F180R6Dn
2@3LXVL00`28ICh0jJa/0>V/K0060>V/K080R6Dn0P0cXLX40<30`1h0<j7:00<0`<3003>QbP0cXLX0
1@0cXLX10?ooo`001`0cXLX00`30`<00<j7:0<30`00h03>QbP0408QU?P3[]fl0jkM_0>^gK`<0R6Dn
203/[Fd00`28ICh0eIeT0=FMI0080=FMI00508QU?P2nS5/0R6Dn08QU?P2VOeD00P1M=b4408QU?QX0
<j7:0`28ICh=0;Z7E`0308QU?P32SEX0`XeJ00H0`XeJ00<0R6Dn0<VBG@39TUd02@39TUd00`28ICh0
eI]R08QU?P040>>VI`0308QU?P3/[6/0k:a[00@0k:a[00<0R6Dn0?BbKP3d/Vh00`30`<030?^hL@03
08QU?P3o_G@0oked00<0oked00<0R6Dn0?o1MP3o`GH00P3o`GH00`28ICh0lK=`0?6cL0040?6cL003
08QU?P3a/g00lK=`00P0lK=`00<0R6Dn0<fFG`3=UUl0103=UUl408QU?P030<^FH028ICh0_HYI00X0
_HYI00<0R6Dn0;Z7E`28ICh00`28ICh60;R5EP0308QU?P31S5X0`HaJ00T0`HaJ00<0R6Dn0=BKHP3D
Vf802@3DVf800`28ICh0jZ][0>Z[J`050>Z[J`80R6Dn0P3/[F`00`28ICh0m;=_0?BcK`070?BcK`03
08QU?P3j]g00n[M`00L0n[M`00<0R6Dn0=nRIP3OXVH01`3OXVH308QU?P/0bi=N00<0R6Dn0;n;F@2o
ReT0202oReT00`28ICh0^XMG0;Z7E`090;Z7E`0308QU?P2kR5P0^hQH00X0^hQH00<0R6Dn0<F@G035
T5`02@35T5`00`28ICh0g:9W0=bRI`090=bRI`0308QU?P3Y[6`0jJa/00D0jJa/00<0R6Dn0>b/J`28
ICh00P30`<0403>QbP030<30`00cXLX0<j7:01/0<j7:00<0`<3003>QbP0cXLX01@0cXLX10?ooo`00
1`0cXLX01030`<00<j7:03>QbP30`<0f03>QbP0308QU?P3[]fl0jkM_0080R6Dn00<0okie08QU?P3/
[Fd01`3/[Fd00`28ICh0eIeT0=FMI0090=FMI00508QU?P2nS5/0_XaK0;j<F`28ICh00`2VOeD00`1M
=b40R6Dn07QSA00408QU?Q40<j7:1@28IChA0;Z7E`0308QU?P32SEX0`XeJ00@0`XeJ00<0R6Dn0<VB
G@39TUd02@39TUd01@28ICh0eI]R0=FKHP3EVf80R6Dn0080hjIW00<0R6Dn0>b/J`3/[6/0103/[6/0
1P28ICh0`<300<30`030`<00m;9^08QU?P@0nkQa00<0R6Dn0?nmM03o_G@00P3o_G@00`28ICh0ol5f
0?o1MP020?o1MP0308QU?P3N[FP0R6Dn00@0lK=`00<0R6Dn0?6cL03a/g002@3a/g000`28ICh0cIIO
0<fFG`0408QU?PD0biIP00<0R6Dn0;f:F@2mRUT0202mRUT00`28ICh0^XMG0;Z7E`040;Z7E`@0R6Dn
00<0^8EF08QU?P31S5X02`31S5X00`28ICh0e9]R0=BKHP090=BKHP0308QU?P3ZZf/0jZ][00L0jZ][
0P28ICh90?BcK`0308QU?P3j]g00n[M`00L0n[M`0P28ICh80=nRIP0408QU?P3NXVH0gZ9V08QU?P/0
bi=N00<0R6Dn0;n;F@2oReT0202oReT00`28ICh0^XMG0;Z7E`090;Z7E`0308QU?P2kR5P0^hQH00X0
^hQH00<0R6Dn0<F@G035T5`02@35T5`00`28ICh0g:9W0=bRI`090=bRI`0308QU?P3Y[6`0jJa/00@0
jJa/00<0R6Dn0>b/J`28ICh0200cXLX00`30`<00<j7:03>QbP0J03>QbP030<30`00cXLX0<j7:00D0
<j7:0@3oool000L0<j7:00@0`<3003>QbP0cXLX0<j7:0P30`<0d03>QbP0308QU?P3[]fl0R6Dn00<0
okie00<0R6Dn0>b]K@3/[Fd01P3/[Fd00`28ICh0eIeT0=FMI0080=FMI00308QU?P2nS5/0_XaK00<0
_XaK00<0R6Dn0:IoE@2VOeD00P2VOeD00`1M=b40R6Dn07QSA00207QSA0@0R6Dn1P0cXLX708QU?P@0
/hEG00<0R6Dn0;Z7E`2jQeL03`2jQeL00`28ICh0`XeJ0<:=FP030<:=FP0308QU?P39TUd0bI9M00T0
bI9M00<0R6Dn0=FKHP3EVf800`3EVf800`28ICh0hjIW08QU?P040>b/J`<0`<30103d/Vh01@28ICh0
nkQa0?^hL@3k^740R6Dn00@0oked00<0R6Dn0?o1MP3o`GH00P3o`GH01P28ICh0gZeX0=j]J03N[FP0
R6Dn0?6cL080R6Dn2`3a/g0408QU?PT0biIP00<0R6Dn0;f:F@2mRUT0202mRUT00`28ICh0^XMG0;Z7
E`080;Z7E`<0R6Dn2P31S5X00`28ICh0e9]R0=BKHP090=BKHP0308QU?P3ZZf/0jZ][00P0jZ][00@0
R6Dn0?BcK`28ICh0R6Dn1P3d/fl00`28ICh0n[M`0?ZgL0070?ZgL00308QU?P3o`gL0R6Dn00L0gj9V
00D0R6Dn0=jRIP3NXVH0gZ9V08QU?P0:0<^CGP0308QU?P2oReT0_h]I00T0_h]I00<0R6Dn0;Z7E`2j
QeL02@2jQeL00`28ICh0^hQH0;^8F00:0;^8F00308QU?P35T5`0aI1L00T0aI1L00<0R6Dn0=bRI`3L
XVL0203LXVL00`28ICh0jJa/0>V/K0040>V/K00408QU?P3/[6/0k:a[08QU?PP0<j7:00<0`<3003>Q
bP0cXLX06`0cXLX00`30`<00<j7:03>QbP0403>QbP40oooo000603>QbP030<30`00cXLX0<j7:00@0
<j7:00<0`<3003>QbP0cXLX0<00cXLX308QU?P<0okie00<0R6Dn0>b]K@3/[Fd01P3/[Fd00`28ICh0
eIeT0=FMI0090=FMI00308QU?P2nS5/0_XaK00@0_XaK0P28ICh30:IoE@<0R6Dn1@1hHd@608QU?P/0
/hEG00<0R6Dn0;Z7E`2jQeL0402jQeL00`28ICh0`XeJ0<:=FP0208QU?P/0bI9M00<0R6Dn0=FKHP3E
Vf801@3EVf800`28ICh0k:a[0>b/J`030<30`0030>b/J`28ICh0m;9^00<0m;9^00D0R6Dn0?^hL@3k
^740nkQa08QU?P040?nmM00308QU?P3o`GH0ol5f0080ol5f00<0R6Dn0=j]J03N[FP00`3N[FP00`28
ICh0lK=`0?6cL0080?6cL0<0R6Dn00<0jJi_08QU?P3;UV002P3;UV000`28ICh0_HYI0;f:F@080;f:
F@0308QU?P2jQeL0^XMG00T0^XMG00@0R6Dn0;n;F@28ICh0R6Dn2031S5X00`28ICh0e9]R0=BKHP09
0=BKHP0308QU?P3ZZf/0jZ][00P0jZ][00D0R6Dn0?BcK`3d/fl0m;=_08QU?P050?BcK`0308QU?P3j
]g00n[M`00H0n[M`00@0R6Dn0?o3M`3o`gL0R6Dn1@3OXVH208QU?P@0gZ9V00<0R6Dn0<^CGP3;Teh0
203;Teh00`28ICh0_h]I0;n;F@090;n;F@0308QU?P2jQeL0^XMG00T0^XMG00<0R6Dn0;^8F02kR5P0
2P2kR5P00`28ICh0aI1L0<F@G0090<F@G00308QU?P3LXVL0g:9W00P0g:9W00<0R6Dn0>V/K03Y[6`0
0P3Y[6`208QU?P<0k:a[00<0R6Dn03>QbP0cXLX01`0cXLX00`30`<00<j7:03>QbP0J03>QbP030<30
`00cXLX0<j7:00@0<j7:0@3oool000H0<j7:00<0`<3003>QbP0cXLX01@0cXLX00`30`<00<j7:03>Q
bP0^03>QbP80R6Dn1@3o_WD00`28ICh0k:e]0>b]K@060>b]K@0308QU?P3EWF@0eIeT00P0eIeT00<0
R6Dn0;j<F`2nS5/01`2nS5/00`28ICh0YWmE0:IoE@020:IoE@<0R6Dn1P1hHd@00`28ICh0/hEG0;>5
E`0<0;>5E`0308QU?P2jQeL0^XMG00l0^XMG00<0R6Dn0<:=FP28ICh03039TUd00`28ICh0eI]R0=FK
HP050=FKHP0408QU?P30`<00`<300<30`0<0k:a[00<0R6Dn0?BbKP3d/Vh00P3d/Vh00`28ICh0nkQa
0?^hL@020?^hL@0508QU?P3o_G@0oked0?nmM028ICh0103o`GH00`28ICh0gZeX0=j]J0030=j]J080
mkid00<0R6Dn0?6cL03a/g00103a/g0308QU?P@0jJi_00<0R6Dn0<^FH03;UV00203;UV000`28ICh0
_HYI0;f:F@080;f:F@0308QU?P2jQeL0^XMG00T0^XMG00<0R6Dn0;n;F@2oReT00P2oReT308QU?P@0
`HaJ00<0R6Dn0=BKHP3DVf802@3DVf800`28ICh0jZ][0>Z[J`080>Z[J`0308QU?P3d/fl0m;=_00<0
m;=_00D0R6Dn0?BcK`3d/fl0m;=_08QU?P090?ZgL00508QU?P3o`gL0ol=g0?o3M`28ICh00`3OXVH0
0`28ICh0gZ9V0=jRIP040=jRIP0308QU?P3;Teh0bi=N00P0bi=N00<0R6Dn0;n;F@2oReT02@2oReT0
0`28ICh0^XMG0;Z7E`090;Z7E`0308QU?P2kR5P0^hQH00X0^hQH00<0R6Dn0<F@G035T5`02@35T5`0
0`28ICh0g:9W0=bRI`080=bRI`0508QU?P3Y[6`0jJa/0>V/K028ICh01@3/[6/00`28ICh0<j7:03>Q
bP0803>QbP030<30`00cXLX0<j7:01T0<j7:00<0`<3003>QbP0cXLX0100cXLX10?ooo`001P0cXLX0
0`30`<00<j7:03>QbP0603>QbP030<30`00cXLX0<j7:02`0<j7:00<0R6Dn0?nnM@3o_WD0103o_WD0
0`28ICh0k:e]0>b]K@050>b]K@L0R6Dn1P3EWF@00`28ICh0_XaK0;j<F`080;j<F`80R6Dn0`2VOeD4
08QU?PD0N6=400<0R6Dn0;>5E`2cQEL02`2cQEL00`28ICh0^XMG0;Z7E`0?0;Z7E`80R6Dn3039TUd0
0`28ICh0eI]R0=FKHP040=FKHP<0`<300`3SYVP208QU?P030>b/J`28ICh0m;9^00<0m;9^00D0R6Dn
0?^hL@3k^740nkQa08QU?P030?nmM00308QU?P3o`GH0ol5f0080ol5f00<0R6Dn0=j]J03N[FP00`3N
[FP40?NnM00308QU?P3a/g00lK=`00<0R6Dn1`3Y[Vl00`28ICh0biIP0<^FH0080<^FH00308QU?P2m
RUT0_HYI00P0_HYI00<0R6Dn0;Z7E`2jQeL02@2jQeL00`28ICh0_h]I0;n;F@050;n;F@80R6Dn0P31
S5X00`28ICh0e9]R0=BKHP090=BKHP0308QU?P3ZZf/0jZ][00L0jZ][00<0R6Dn0?BcK`3d/fl01@3d
/fl208QU?P030?BcK`28ICh0n[M`00L0n[M`00<0R6Dn0?o3M`3o`gL00P3o`gL01028ICh0gj9V0=nR
IP28ICh70=jRIP0308QU?P3;Teh0bi=N00P0bi=N00<0R6Dn0;n;F@2oReT02@2oReT00`28ICh0^XMG
0;Z7E`090;Z7E`0308QU?P2kR5P0^hQH00X0^hQH00<0R6Dn0<F@G035T5`02@35T5`00`28ICh0g:9W
0=bRI`080=bRI`0408QU?P3Y[6`0jJa/08QU?PH0k:a[00<0R6Dn03>QbP0cXLX0200cXLX00`30`<00
<j7:03>QbP0I03>QbP030<30`00cXLX0<j7:00@0<j7:0@3oool000H0<j7:00<0`<3003>QbP0cXLX0
1`0cXLX00`30`<00<j7:03>QbP0Z03>QbP0308QU?P3o_WD0okie00D0okie00<0R6Dn0>b]K@3/[Fd0
0`3/[Fd208QU?P030>6TI`28ICh0d9MP00@0d9MP1`28ICh<0;j<F`<0R6Dn00<0YWmE08QU?P28ICh0
0`28ICh407QSA00308QU?P2cQEL0/hEG00/0/hEG00<0R6Dn0;Z7E`2jQeL0302jQeL208QU?P80_HYI
00<0R6Dn0<VBG@39TUd02039TUd00`28ICh0eI]R0=FKHP020=FKHP<0`<3000<0R6Dn0>>VJ03SYVP0
1@3SYVP00`28ICh0m;9^0?BbKP020?BbKP0508QU?P3k^740nkQa0?^hL@28ICh0103o_G@01@28ICh0
ol5f0?o1MP3o`GH0R6Dn00@0gZeX00<0R6Dn0?NnM03g_W@00`3g_W@308QU?P/0jJi_00<0R6Dn0<^F
H03;UV001`3;UV000`28ICh0_HYI0;f:F@080;f:F@0308QU?P2jQeL0^XMG00P0^XMG00<0R6Dn0;n;
F@2oReT0202oReT208QU?P/0e9]R00<0R6Dn0>Z[J`3ZZf/0203ZZf/00`28ICh0m;=_0?BcK`070?Bc
K`0308QU?P3j]g00n[M`00H0n[M`00<0R6Dn0?o3M`3o`gL00`3o`gL308QU?PP0gZ9V00<0R6Dn0<^C
GP3;Teh0203;Teh00`28ICh0_h]I0;n;F@090;n;F@0308QU?P2jQeL0^XMG00T0^XMG00<0R6Dn0;^8
F02kR5P02P2kR5P00`28ICh0aI1L0<F@G0090<F@G00308QU?P3LXVL0g:9W00P0g:9W00<0R6Dn0>V/
K028ICh01P3/[6/00`28ICh0<j7:03>QbP0:03>QbP030<30`00cXLX0<j7:01P0<j7:00<0`<3003>Q
bP0cXLX0100cXLX10?ooo`001P0cXLX00`30`<00<j7:03>QbP0803>QbP030<30`00cXLX0<j7:02T0
<j7:00<0R6Dn0?nnM@3o_WD0103o_WD00`28ICh0k:e]0>b]K@020>b]K@80R6Dn0P3QY6L00`28ICh0
d9MP0=2GH0090=2GH00408QU?P30S5X0R6Dn08QU?PT0_XaK00@0R6Dn0;22EP28ICh0S6e:1@28ICh0
0`2@L4d0R6Dn08QU?P0307QSA00308QU?P2cQEL0/hEG00/0/hEG00<0R6Dn0;Z7E`2jQeL0202jQeL3
08QU?P@0_HYI00<0R6Dn0<VBG@39TUd01`39TUd00`28ICh0eI]R0=FKHP030<30`0<0eI]R00<0R6Dn
0>>VJ03SYVP0103SYVP01028ICh0l[9^08QU?P28ICh20?BbKP0508QU?P3k^740nkQa0?^hL@28ICh0
0`3o_G@01@28ICh0ol5f0?o1MP3o`GH0R6Dn00@0gZeX00<0R6Dn0?NnM03g_W@00P3g_W@208QU?P80
g:i/00<0R6Dn0>V^K`3Y[Vl02@3Y[Vl00`28ICh0biIP0<^FH0070<^FH00308QU?P2mRUT0_HYI00L0
_HYI00<0R6Dn0;Z7E`2jQeL02@2jQeL00`28ICh0_h]I0;n;F@080;n;F@0408QU?P3<U5h0R6Dn08QU
?PT0e9]R00<0R6Dn0>Z[J`3ZZf/01`3ZZf/00`28ICh0m;=_0?BcK`070?BcK`80R6Dn1`3j]g000`28
ICh0ol=g0?o3M`040?o3M`0308QU?P3NXVH0gZ9V00P0gZ9V00<0R6Dn0<^CGP3;Teh0203;Teh00`28
ICh0_h]I0;n;F@090;n;F@0308QU?P2jQeL0^XMG00T0^XMG00<0R6Dn0;^8F02kR5P02P2kR5P00`28
ICh0aI1L0<F@G0080<F@G00308QU?P3LXVL0g:9W00T0g:9W0P28ICh70>b/J`0308QU?P0cXLX0<j7:
00/0<j7:00<0`<3003>QbP0cXLX05`0cXLX00`30`<00<j7:03>QbP0403>QbP40oooo000603>QbP03
0<30`00cXLX0<j7:00T0<j7:00<0`<3003>QbP0cXLX09`0cXLX00`28ICh0okie0?nnM@050?nnM@03
08QU?P3/[Fd0k:e]0080R6Dn103QY6L00`28ICh0d9MP0=2GH0080=2GH00308QU?P30S5X0`8aJ0080
`8aJ0`28ICh50;j<F`0508QU?P2`PUH0/89F0;22EP28ICh00`2<KDX308QU?P80T71=0`28ICh00`1h
Hd@0R6Dn0;>5E`0;0;>5E`0308QU?P2jQeL0^XMG00H0^XMG0P28ICh80;f:F@0308QU?P39TUd0bI9M
00D0bI9M00@0R6Dn0<30`030`<00`<301@3EVf800`28ICh0hjIX0>>VJ0040>>VJ00308QU?P3b/Vh0
l[9^0080l[9^3P28ICh30=j]J080R6Dn0`3g_W@208QU?PD0g:i/00<0R6Dn0>V^K`3Y[Vl0203Y[Vl0
0`28ICh0biIP0<^FH0070<^FH00308QU?P2mRUT0_HYI00L0_HYI00<0R6Dn0;Z7E`2jQeL0202jQeL0
0`28ICh0_h]I0;n;F@090;n;F@0508QU?P3<U5h0c9AN0<bDGP28ICh01`3DVf800`28ICh0jZ][0>Z[
J`080>Z[J`0308QU?P3d/fl0m;=_00L0m;=_00<0R6Dn0?ZgL@28ICh01@3j]g000`28ICh0ol=g0?o3
M`050?o3M`0308QU?P3NXVH0gZ9V00P0gZ9V00<0R6Dn0<^CGP3;Teh00`3;Teh708QU?PX0_h]I00<0
R6Dn0;Z7E`2jQeL02@2jQeL00`28ICh0^hQH0;^8F0090;^8F00308QU?P35T5`0aI1L00T0aI1L00<0
R6Dn0=bRI`3LXVL02@3LXVL00`28ICh0k:a[0>b/J`060>b/J`0308QU?P0cXLX0<j7:00/0<j7:00<0
`<3003>QbP0cXLX05`0cXLX00`30`<00<j7:03>QbP0403>QbP40oooo000603>QbP030<30`00cXLX0
<j7:00X0<j7:00<0`<3003>QbP0cXLX09P0cXLX00`28ICh0okie0?nnM@040?nnM@0408QU?P3/[Fd0
R6Dn08QU?PH0hJAW00<0R6Dn0=2GH03@Uf00203@Uf000`28ICh0`8aJ0<2<FP050<2<FP80R6Dn0P2n
S5/00`28ICh0/89F0;22EP030;22EP0408QU?P2<KDX0S6e:08a]BP<0R6Dn102@L4d308QU?P`0/hEG
00<0R6Dn0;Z7E`2jQeL00P2jQeL308QU?PX0_HYI00<0R6Dn0<VBG@39TUd00`39TUd30<30`0L0eI]R
00<0R6Dn0>>VJ03SYVP0103SYVP00`28ICh0l[9^0?:bKP030?:bKP0508QU?P3o_G@0oked0?nmM028
ICh00`3oaGT01@28ICh0olQi0?o8N@3ob7T0R6Dn00<0gZeX00<0R6Dn0?NnM03g_W@00`28ICh40=b^
K1/0R6Dn1`2mRUT00`28ICh0^XMG0;Z7E`080;Z7E`0308QU?P2oReT0_h]I00P0_h]I00<0R6Dn0<bD
GP3<U5h00`3<U5h208QU?PD0e9]R00<0R6Dn0>Z[J`3ZZf/01`3ZZf/00`28ICh0m;=_0?BcK`070?Bc
K`0408QU?P3j]g40n[Ma08QU?P@0n[M`00<0R6Dn0?o3M`3o`gL01P3o`gL00`28ICh0gZ9V0=jRIP07
0=jRIPL0R6Dn1@39Teh00`28ICh0_HUH08QU?P0308QU?PH0_h]I00<0R6Dn0;Z7E`2jQeL02@2jQeL0
0`28ICh0^hQH0;^8F0090;^8F00308QU?P35T5`0aI1L00T0aI1L00<0R6Dn0=bRI`3LXVL01`3LXVL3
08QU?PP0k:a[00<0R6Dn03>QbP0cXLX0300cXLX00`30`<00<j7:03>QbP0F03>QbP030<30`00cXLX0
<j7:00@0<j7:0@3oool000H0<j7:00<0`<3003>QbP0cXLX02`0cXLX00`30`<00<j7:03>QbP0T03>Q
bP0308QU?P3o_WD0okie00D0okie0P28ICh80>6TI`0308QU?P3@Uf00d9MP00P0d9MP00<0R6Dn0<2<
FP30S5X01`30S5X208QU?PL0/89F00@0R6Dn08a]BP2<KDX0S6e:0`28ICh5091`C@P0R6Dn1@2cQEL0
0`28ICh0^XMG0;Z7E`0208QU?Ph0_HYI00<0R6Dn0<VBG@30`<000P30`<000`28ICh0eI]R0=FKHP06
0=FKHP0308QU?P3SYVP0hjIX00D0hjIX00<0R6Dn0?:bKP3b/Vh00P3b/Vh01@28ICh0oked0?nmM03o
_G@0R6Dn00<0olEi00D0R6Dn0?o8N@3ob7T0olQi08QU?P020=j]J080R6Dn00<0mkid08QU?P28ICh0
2028ICh40;6@G00308QU?P3CXFP0dj5X00H0dj5X00<0R6Dn0<FBG`35TUl01`35TUl00`28ICh0_8YJ
0;b:FP0408QU?P80_HYI00<0R6Dn0;Z7E`2jQeL02@2jQeL00`28ICh0_h]I0;n;F@080;n;F@0308QU
?P3<U5h0c9AN00D0c9AN00D0R6Dn0=BKHP3DVf80e9]R08QU?P090>Z[J`0308QU?P3d/fl0m;=_00L0
m;=_00<0R6Dn0?ZgL@3j]g400P3j]g401@28ICh0n[M`0?ZgL03j]g00R6Dn00P0ol=g00<0R6Dn0=jR
IP3NXVH0103NXVH308QU?P030>6UJ028ICh0bI=N00T0bI=N00<0R6Dn0;f9F02mREP00`2mREP408QU
?P80_h]I00<0R6Dn0;Z7E`2jQeL02@2jQeL00`28ICh0^hQH0;^8F0090;^8F00308QU?P35T5`0aI1L
00T0aI1L00<0R6Dn0=bRI`3LXVL01@3LXVL208QU?P80gZ9V00<0R6Dn0>b/J`3/[6/01P3/[6/00`28
ICh0<j7:03>QbP0=03>QbP030<30`00cXLX0<j7:01H0<j7:00<0`<3003>QbP0cXLX00`0cXLX10?oo
o`001P0cXLX00`30`<00<j7:03>QbP0<03>QbP80`<30900cXLX00`28ICh0okie0?nnM@040?nnM@80
R6Dn203QY6L00`28ICh0d9MP0=2GH0080=2GH00308QU?P30S5X0`8aJ00T0`8aJ0P28ICh70;22EP80
R6Dn0P2<KDX308QU?PH0T71=00<0R6Dn0;63EP2aPeH00`2aPeH808QU?Pl0_HYI0`30`<020<VBG@03
08QU?P3EVf80eI]R00H0eI]R00<0R6Dn0>>VJ03SYVP01@3SYVP00`28ICh0l[9^0?:bKP030?:bKP05
08QU?P3o_G@0oked0?nmM028ICh00`3oaGT01028ICh0olQi0?o8N@28ICh20=j]J0D0R6Dn0`3>VF<0
0`28ICh0ZX=G0:Z3E`0205/f8@<0R6Dn0P2aT5`00`28ICh0dj5X0=>QJ0060=>QJ00308QU?P35TUl0
aI9O00L0aI9O00<0R6Dn0;b:FP2lRUX0102lRUX408QU?PT0^XMG00<0R6Dn0;n;F@2oReT0202oReT0
0`28ICh0c9AN0<bDGP070<bDGP80R6Dn00<0e9]R08QU?P3ZZf/0203ZZf/00`28ICh0m;=_0?BcK`07
0?BcK`0308QU?P3j]g40n[Ma0080n[Ma00@0R6Dn0?ZgL03j]g00R6Dn2@3o`gL00`28ICh0gZ9V0=jR
IP020=jRIP80R6Dn0`3QYFP00`28ICh0bI=N0<VCGP090<VCGP0308QU?P2mREP0_HUH00L0_HUH1028
ICh:0;Z7E`0308QU?P2kR5P0^hQH00T0^hQH00<0R6Dn0<F@G035T5`02@35T5`00`28ICh0g:9W0=bR
I`040=bRI`0508QU?P3NXVH0gZ9V0=jRIP28ICh0203/[6/00`28ICh0<j7:03>QbP0?03>QbP030<30
`00cXLX0<j7:01D0<j7:00<0`<3003>QbP0cXLX00`0cXLX10?ooo`001@0cXLX00`30`<00<j7:03>Q
bP0?03>QbP030<30`00cXLX0<j7:0200<j7:00<0R6Dn0?nnM@3o_WD00`3o_WD308QU?PT0hJAW00<0
R6Dn0=2GH03@Uf00203@Uf000`28ICh0`8aJ0<2<FP080<2<FP0308QU?P2hQUL0^8IG0080R6Dn1`2`
PUH01P28ICh0S6e:08a]BP28ICh0E34N08QU?PH0T71=00<0R6Dn0;63EP2aPeH02@2aPeH00`28ICh0
_HYI0;f:F@0:0;f:F@<0`<300P2mRUT00`28ICh0bI9M08QU?P080=FKHP0308QU?P3SYVP0hjIX00D0
hjIX00<0R6Dn0?:bKP3b/Vh00`3b/Vh01@28ICh0oked0?nmM03o_G@0R6Dn00<0olEi00D0R6Dn0?o8
N@3ob7T0R6Dn0=j]J00308QU?PP0cYUS1028ICh305/f8@@0R6Dn1`3CXFP00`28ICh0aI9O0<FBG`07
0<FBG`0308QU?P2lRUX0_8YJ00H0_8YJ00<0R6Dn0;Z8F028ICh00P28ICh60;Z7E`0308QU?P2oReT0
_h]I00P0_h]I00<0R6Dn0<bDGP3<U5h02@3<U5h00`28ICh0jZ][0>Z[J`070>Z[J`0308QU?P3d/fl0
m;=_00L0m;=_00<0R6Dn0?ZgL@3j]g40103j]g4208QU?PX0ol=g00<0R6Dn0=jRIP28ICh00P28ICh5
0>6UJ00308QU?P39Teh0bI=N00T0bI=N00<0R6Dn0;f9F02mREP02@2mREP00`28ICh0^XMG08QU?P03
08QU?PH0^XMG00<0R6Dn0;^8F02kR5P02@2kR5P00`28ICh0aI1L0<F@G0090<F@G00308QU?P3LXVL0
g:9W0080g:9W0P28ICh40=jRIP0308QU?P3/[6/0k:a[00H0k:a[00<0R6Dn03>QbP0cXLX03`0cXLX0
0`30`<00<j7:03>QbP0E03>QbP030<30`00cXLX0<j7:00<0<j7:0@3oool000D0<j7:00<0`<3003>Q
bP0cXLX0400cXLX00`30`<00<j7:03>QbP0O03>QbP0308QU?P3o_WD0okie0080okie00@0R6Dn0>j^
K03^[V`0R6Dn2@3QY6L00`28ICh0d9MP0=2GH0070=2GH00308QU?P30S5X0`8aJ00T0`8aJ00<0R6Dn
0;R6E`2hQUL00P2hQUL00`28ICh0/89F0;22EP050;22EP0408QU?P2<KDX0S6e:08a]BP<0R6Dn102@
L4d00`28ICh0/H=F0;63EP090;63EP0308QU?P2mRUT0_HYI00L0_HYI0`30`<060;f:F@0308QU?P3E
Vf80eI]R00H0eI]R00<0R6Dn0>>VJ03SYVP01@3SYVP00`28ICh0l[9^0?:bKP030?:bKP0508QU?P3o
_G@0oked0?nmM028ICh00`3oaGT01@28ICh0olQi0?o8N@28ICh0gZeX0080R6Dn203>VF<208QU?P04
0;N7F028ICh0XW]C0:9kD`<0R6Dn0`1K=R4308QU?PH0dj5X00<0R6Dn0<FBG`35TUl01@35TUl00`28
ICh0_8YJ0;b:FP060;b:FP0308QU?P2jR5P0^XQH00<0^XQH1028ICh00`2jQeL0R6Dn0;n;F@090;n;
F@0308QU?P3<U5h0c9AN00T0c9AN00@0R6Dn0=fQI@28ICh0R6Dn1P3ZZf/00`28ICh0m;=_0?BcK`07
0?BcK`0308QU?P3j]g40n[Ma00D0n[Ma00<0R6Dn0?o3M`3o`gL02@3o`gL208QU?PP0hJEX00<0R6Dn
0<VCGP39Teh02039Teh00`28ICh0_HUH0;f9F00:0;f9F00308QU?P2jQeL0^XMG00<0^XMG1028ICh2
0;Z7E`0308QU?P2kR5P0^hQH00T0^hQH00<0R6Dn0<F@G035T5`02@35T5`00`28ICh0g:9W0=bRI`02
08QU?PH0gZ9V00<0R6Dn0>b/J`3/[6/01P3/[6/00`28ICh0<j7:03>QbP0@03>QbP030<30`00cXLX0
<j7:01@0<j7:00<0`<3003>QbP0cXLX00`0cXLX10?ooo`001@0cXLX00`30`<00<j7:03>QbP0A03>Q
bP030<30`00cXLX0<j7:01d0<j7:00<0R6Dn0?nnM@3o_WD00P3o_WD01@28ICh0kZi/0>j^K03^[V`0
R6Dn00P0hJAW00<0R6Dn0=2GH03@Uf00203@Uf000`28ICh0`8aJ0<2<FP090<2<FP0308QU?P2hQUL0
^8IG00<0^8IG00<0R6Dn0;22EP2`PUH01@2`PUH01028ICh0S6e:08a]BP2<KDX408QU?P<0T71=00<0
R6Dn0;63EP2aPeH02@2aPeH00`28ICh0_HYI0;f:F@030;f:F@<0`<301`2mRUT208QU?P030<NAG@28
ICh0eI]R00D0eI]R00<0R6Dn0>>VJ03SYVP01@3SYVP00`28ICh0l[9^0?:bKP030?:bKP0508QU?P3o
_G@0oked0?nmM028ICh00`3oaGT00`28ICh0olQi0?o8N@0308QU?P80di]R00<0R6Dn0<jIH`3>VF<0
0`3>VF<208QU?P@0]hMH00<0R6Dn0:9kD`2RNe<00`2RNe<01028ICh0FcHQ05/f8@1K=R4508QU?P80
dj5X00<0R6Dn0<FBG`35TUl01@35TUl00`28ICh0_8YJ0;b:FP060;b:FP0308QU?P2jR5P0^XQH00L0
^XQH0P28ICh:0;n;F@0308QU?P3<U5h0c9AN00P0c9AN00<0R6Dn0=fQI@3MXFD00P3MXFD00`28ICh0
jZ][0>Z[J`030>Z[J`0308QU?P3d/fl0m;=_00H0m;=_00<0R6Dn0?ZgL@3j]g401@3j]g4208QU?PT0
ol=g0`28ICh90>6UJ00308QU?P39Teh0bI=N00P0bI=N00<0R6Dn0;f9F02mREP02@2mREP00`28ICh0
^XMG0;Z7E`080;Z7E`D0R6Dn2@2kR5P00`28ICh0aI1L0<F@G0090<F@G0<0R6Dn203NXVH00`28ICh0
k:a[0>b/J`050>b/J`80R6Dn4`0cXLX00`30`<00<j7:03>QbP0C03>QbP030<30`00cXLX0<j7:00<0
<j7:0@3oool000D0<j7:00<0`<3003>QbP0cXLX04P0cXLX00`30`<00<j7:03>QbP0L03>QbP0308QU
?P3o_WD0okie0080R6Dn103^[V`00`28ICh0hJAW0>6TI`060>6TI`0308QU?P3@Uf00d9MP00P0d9MP
00<0R6Dn0<2<FP30S5X02030S5X00`28ICh0^8IG0;R6E`050;R6E`0308QU?P2`PUH0/89F00D0/89F
0`28ICh01@2<KDX0R6Dn08QU?P1oI4D0R6Dn00<0T71=00<0R6Dn0;63EP2aPeH02@2aPeH00`28ICh0
_HYI0<30`0020<30`0P0_HYI0P28ICh40<NAG@0308QU?P3EVf80eI]R00<0eI]R00<0R6Dn0>>VJ03S
YVP0103SYVP00`28ICh0l[9^0?:bKP030?:bKP0308QU?P3o_G@0oked0080oked00@0R6Dn0?o5N@3o
aGT0R6Dn0P3ob7T208QU?PD0di]R00<0R6Dn0<jIH`3>VF<00P28ICh70;N7F00308QU?P2RNe<0XW]C
00<0XW]C00D0R6Dn06QD?01N>280FcHQ08QU?P0307EO@P@0R6Dn1P35TUl00`28ICh0_8YJ0;b:FP06
0;b:FP0308QU?P2jR5P0^XQH00L0^XQH00@0R6Dn0;f:F@28ICh0R6Dn1`2oReT00`28ICh0c9AN0<bD
GP090<bDGP0308QU?P3MXFD0gJ5U00<0gJ5U00D0R6Dn0>Z[J`3ZZf/0jZ][08QU?P090?BcK`0308QU
?P3j]g40n[Ma00@0n[Ma00<0R6Dn0?o3M`28ICh0203o`gL00`28ICh0kKM_08QU?P090>6UJ00308QU
?P39Teh0bI=N00T0bI=N00<0R6Dn0;f9F02mREP02@2mREP00`28ICh0^XMG0;Z7E`0:0;Z7E`0308QU
?P2nRUT0_XYI00H0R6Dn0`2kR5P00`28ICh0aI1L0<F@G0040<F@G0H0R6Dn2P3NXVH00`28ICh0k:a[
0>b/J`040>b/J`80R6Dn500cXLX00`30`<00<j7:03>QbP0C03>QbP030<30`00cXLX0<j7:00<0<j7:
0@3oool000D0<j7:00<0`<3003>QbP0cXLX04`0cXLX00`30`<00<j7:03>QbP0J03>QbP0408QU?P3o
_WD0okie08QU?PD0kZi/00<0R6Dn0>6TI`3QY6L01`3QY6L00`28ICh0d9MP0=2GH0070=2GH00308QU
?P30S5X0`8aJ00T0`8aJ00<0R6Dn0;R6E`2hQUL01P2hQUL208QU?P@0/89F00@0R6Dn0:n3EP28ICh0
OfI61028ICh00`1oI4D0R6Dn08QU?P02091`C@0308QU?P2aPeH0/H=F00L0/H=F0`30`<090;f:F@80
R6Dn1`37TEd01@28ICh0eI]R0=FKHP3EVf80R6Dn00H0hjIX00<0R6Dn0?:bKP3b/Vh0103b/Vh01@28
ICh0oked0?nmM03o_G@0R6Dn0080olEi00@0R6Dn0?o8N@3ob7T0R6Dn203CVf8208QU?PX0]hMH00<0
R6Dn0:9kD`2RNe<00`2RNe<00`28ICh0J5@l05hh8P0208QU?PH0MEm21028ICh20<FBG`0308QU?P2l
RUX0_8YJ00D0_8YJ00<0R6Dn0;Z8F02jR5P0202jR5P01@28ICh0_HYI0;f:F@2mRUT0R6Dn00H0_h]I
00<0R6Dn0<bDGP3<U5h0203<U5h00`28ICh0gJ5U0=fQI@050=fQI@80R6Dn00<0jZ][08QU?P3d/fl0
1`3d/fl00`28ICh0n[Ma0?ZgL@050?ZgL@0308QU?P3o`gL0R6Dn00L0ol=g00@0R6Dn0>fgK`3]]fl0
R6Dn1`3QYFP508QU?PT0bI=N00<0R6Dn0;f9F02mREP02@2mREP00`28ICh0^XMG0;Z7E`0:0;Z7E`03
08QU?P2nRUT0_XYI00H0_XYI2P28ICh50<^CGP0308QU?P3NXVH0gZ9V00L0gZ9V00<0R6Dn0>b/J`3/
[6/0103/[6/00`28ICh0m[A_08QU?P0E03>QbP030<30`00cXLX0<j7:0180<j7:00<0`<3003>QbP0c
XLX00`0cXLX10?ooo`001@0cXLX00`30`<00<j7:03>QbP0D03>QbP030<30`00cXLX0<j7:01T0<j7:
00<0R6Dn0?nnM@28ICh01P3^[V`00`28ICh0hJAW0>6TI`070>6TI`0308QU?P3@Uf00d9MP00D0d9MP
1028ICh:0<2<FP0308QU?P2hQUL0^8IG00P0^8IG00@0R6Dn0;22EP28ICh0R6Dn0`2_PeH208QU?P80
OfI60P28ICh207mTA@<0R6Dn1P2aPeH30<30`080/H=F00<0R6Dn0;f:F@2mRUT01@2mRUT208QU?PX0
ai5M00<0R6Dn0=FKHP28ICh01P3SYVP00`28ICh0l[9^0?:bKP040?:bKP0508QU?P3o_G@0oked0?nm
M028ICh00`3oaGT308QU?PP0di]R00<0R6Dn0<JAG@28ICh02`2gQeP00`28ICh0XW]C0:9kD`030:9k
D`0408QU?P1XE3`0GSPR05hh8P80R6Dn201eGd8408QU?PH0_8YJ00<0R6Dn0;Z8F02jR5P01`2jR5P0
0`28ICh0_HYI0;f:F@030;f:F@80R6Dn0`2oReT00`28ICh0c9AN0<bDGP080<bDGP0308QU?P3MXFD0
gJ5U00P0gJ5U00<0R6Dn0?BcK`3d/fl01P3d/fl00`28ICh0n[Ma0?ZgL@050?ZgL@0408QU?P3o`gL0
ol=g08QU?PD0ol=g0P28ICh20>fgK`0308QU?P3QYFP0hJEX00H0R6Dn00<0j:i^08QU?P39U5l00P39
U5l608QU?P<0bI=N00<0R6Dn0;f9F02mREP02@2mREP00`28ICh0^XMG0;Z7E`0:0;Z7E`0308QU?P2n
RUT0_XYI00T0_XYI00<0R6Dn0<^CGP3;Teh02@3;Teh00`28ICh0gZ9V0=jRIP070=jRIP0308QU?P3/
[6/0k:a[00<0k:a[00@0R6Dn0?JdK`3f]6l0R6Dn5P0cXLX00`30`<00<j7:03>QbP0A03>QbP030<30
`00cXLX0<j7:00<0<j7:0@3oool000D0<j7:00<0`<3003>QbP0cXLX05@0cXLX00`30`<00<j7:03>Q
bP0G03>QbP<0R6Dn1`3^[V`00`28ICh0hJAW0>6TI`060>6TI`0308QU?P3@Uf00d9MP00H0R6Dn0P3;
Teh00`28ICh0_XYI08QU?P0308QU?PH0`8aJ00<0R6Dn0;R6E`2hQUL02@2hQUL00`28ICh0[h=F0:n3
EP050:n3EP0308QU?P1oITH0OfI60080R6Dn0`1oI4D208QU?P80/H=F0`30`<060;63EP0308QU?P2m
RUT0_HYI0080_HYI0P28ICh=0<NAG@0308QU?P3SYVP0hjIX00D0hjIX00<0R6Dn0?:bKP3b/Vh00`3b
/Vh01@28ICh0oked0?nmM03o_G@0R6Dn00<0olEi0`28ICh80=>KHP0508QU?P36TEd0aY5M0<JAG@28
ICh02`2gQeP00`28ICh0XW]C0:9kD`030:9kD`0408QU?P1XE3`0J5@l05hh8P<0R6Dn201eGd801028
ICh0YWaB08QU?P28ICh40;b:FP0308QU?P2jR5P0^XQH00L0^XQH00<0R6Dn0;f:F@2mRUT01@2mRUT2
08QU?P030;n;F@28ICh0c9AN00P0c9AN00<0R6Dn0=fQI@3MXFD0203MXFD00`28ICh0kZm]08QU?P07
0?BcK`0308QU?P3j]g40n[Ma00@0n[Ma00<0R6Dn0?o3M`3o`gL00P3o`gL01@28ICh0ol=g0?o3M`3o
`gL0R6Dn00@0kKM_0`28ICh60>R^KP0308QU?P39U5l0bIAO00P0bIAO1@28ICh:0;f9F00308QU?P2j
QeL0^XMG00T0^XMG00<0R6Dn0;j:F@2nRUT02P2nRUT00`28ICh0bi=N0<^CGP090<^CGP0308QU?P3N
XVH0gZ9V00L0gZ9V00<0R6Dn0>b/J`3/[6/00P3/[6/01@28ICh0m[A_0?JdK`3f]6l0R6Dn01H0<j7:
00<0`<3003>QbP0cXLX04P0cXLX00`30`<00<j7:03>QbP0203>QbP40oooo000503>QbP030<30`00c
XLX0<j7:01H0<j7:0P30`<0G03>QbP0308QU?P3^[V`0kZi/00L0kZi/00<0R6Dn0>6TI`3QY6L01P3Q
Y6L308QU?PP0bi=N00<0R6Dn0;j:F@2nRUT00`2nRUT408QU?P030<2<FP28ICh0^8IG00/0^8IG0`28
ICh60:n3EP0308QU?P1oITH0OfI60080R6Dn0`1oI4D30<30`0@0R6Dn1@2aPeH00`28ICh0_HYI0;f:
F@0208QU?Pd0ai5M0P28ICh00`3GWVD0R6Dn08QU?P040>>VJ00308QU?P3b/Vh0l[9^00<0l[9^00<0
R6Dn0?nmM03o_G@00P3o_G@00`28ICh0olEi08QU?P0308QU?PP0di]R00<0R6Dn0<JAG@36TEd00`36
TEd208QU?PX0]hMH00@0R6Dn0:9kD`2RNe<0XW]C1028ICh0101XE3`0GSPR08QU?P1eGd8208QU?PD0
MEm200<0R6Dn0:IlDP2VO5800P2VO58208QU?P030;b:FP28ICh0^XQH00P0^XQH00<0R6Dn0;f:F@2m
RUT0202mRUT00`28ICh0c9AN0<bDGP080<bDGP0308QU?P3MXFD0gJ5U00P0gJ5U00@0R6Dn0>j_K@3^
[fd0R6Dn1@3d/fl00`28ICh0n[Ma0?ZgL@040?ZgL@0308QU?P3o`gL0ol=g00<0ol=g00@0R6Dn0?o3
M`3o`gL0R6Dn103]]fl00`28ICh0j:i^0>R^KP070>R^KP0308QU?P39U5l0bIAO00/0bIAO00@0R6Dn
0;^9F@28ICh0R6Dn202mREP00`28ICh0^XMG0;Z7E`090;Z7E`0308QU?P2nRUT0_XYI00X0_XYI00<0
R6Dn0<^CGP3;Teh0203;Teh00`28ICh0gZ9V0=jRIP080=jRIP0508QU?P3/[6/0k:a[0>b/J`28ICh0
0`3f]6l00`28ICh0<j7:03>QbP0F03>QbP030<30`00cXLX0<j7:0140<j7:00<0`<3003>QbP0cXLX0
0P0cXLX10?ooo`001@0cXLX00`30`<00<j7:03>QbP0H03>QbP030<30`00cXLX0<j7:01@0<j7:00<0
R6Dn0>j^K03^[V`01P3^[V`00`28ICh0hJAW0>6TI`050>6TI`<0R6Dn2P3;Teh00`28ICh0_XYI0;j:
F@070;j:F@80R6Dn2`2hQUL01@28ICh0^HQH0;V8F02iR5P0R6Dn00H0[h=F00@0R6Dn07mVAP1oITH0
R6Dn0`30`<0207mTA@0308QU?P2cQEL0/hEG0080/hEG2028ICh=0<NAG@80R6Dn1@3GWVD208QU?P03
0>>VJ028ICh0l[9^00D0l[9^00@0R6Dn0?nmM03o_G@0oked1@28ICh00`3LX6D0R6Dn0=>KHP060=>K
HP0308QU?P36TEd0aY5M00H0aY5M00<0R6Dn0;N7F02gQeP0202gQeP308QU?P<0U7=>0`28ICh01@1N
>280R6Dn07EO@P1eGd80R6Dn00@0MEm200<0R6Dn0:IlDP2VO580102VO58208QU?PP0^XQH00<0R6Dn
0;f:F@2mRUT0202mRUT01028ICh0aY1L08QU?P28ICh70<bDGP0308QU?P3MXFD0gJ5U00P0gJ5U00<0
R6Dn0>j_K@3^[fd00P3^[fd208QU?P80m;=_00<0R6Dn0?ZgL@3j]g40103j]g400`28ICh0ol=g0?o3
M`040?o3M`<0R6Dn0`3]]fl=08QU?P`0bIAO00<0R6Dn0;^9F@2kRET00P2kRET208QU?PD0_HUH00<0
R6Dn0;Z7E`2jQeL02P2jQeL00`28ICh0_XYI0;j:F@090;j:F@0308QU?P3;Teh0bi=N00T0bi=N00<0
R6Dn0=jRIP3NXVH0203NXVH01028ICh0k:a[0>b/J`28ICh40?JdK`0308QU?P0cXLX0<j7:01L0<j7:
00<0`<3003>QbP0cXLX0400cXLX00`30`<00<j7:03>QbP0203>QbP40oooo000403>QbP030<30`00c
XLX0<j7:01X0<j7:00<0`<3003>QbP0cXLX04`0cXLX00`28ICh0kZi/0>j^K0060>j^K00308QU?P3Q
Y6L0hJAW00<0hJAW0P28ICh20=bQI@0308QU?P3;Teh0bi=N00L0bi=N00<0R6Dn0;j:F@2nRUT02@2n
RUT308QU?PT0^8IG00<0R6Dn0;V8F02iR5P00P2iR5P00`28ICh0[h=F0:n3EP040:n3EP<0`<300`28
ICh307mTA@0308QU?P2cQEL0/hEG00P0/hEG00<0R6Dn0<NAG@37TEd02P37TEd00`28ICh0eiiU0=NN
I@070=NNI@<0R6Dn103b/Vh00`28ICh0oked08QU?P0308QU?P030?o6N@28ICh0R6Dn00<0g:1U00<0
R6Dn0=>KHP3CVf80103CVf800`28ICh0aY5M0<JAG@070<JAG@0308QU?P2gQeP0]hMH00H0]hMH00@0
R6Dn0:MmD`28ICh0R6Dn102DLdh00`28ICh0C3X/08QU?P0208QU?P<0MEm200<0R6Dn07EO@P28ICh0
2@2VO58208QU?PH0^XQH00<0R6Dn0;f:F@2mRUT01`2mRUT00`28ICh0aY1L0<J@G0020<J@G00308QU
?P3<U5h0c9AN00<0c9AN00<0R6Dn0=fQI@3MXFD0203MXFD00`28ICh0kZm]0>j_K@050>j_K@0308QU
?P3d/fl0R6Dn00H0n[Ma00<0R6Dn0?o3M`3o`gL0103o`gL01028ICh0kKM_0>fgK`3]]fl308QU?PP0
fZ]]0P28ICh20<>CH080R6Dn2P39U5l00`28ICh0^hUI0;^9F@040;^9F@80R6Dn0`2mREP00`28ICh0
^XMG0;Z7E`0:0;Z7E`0308QU?P2nRUT0_XYI00T0_XYI00<0R6Dn0<^CGP3;Teh02@3;Teh00`28ICh0
gZ9V0=jRIP080=jRIP0308QU?P3/[6/0R6Dn00D0m[A_00<0R6Dn03>QbP0cXLX0600cXLX00`30`<00
<j7:03>QbP0?03>QbP030<30`00cXLX0<j7:0080<j7:0@3oool000@0<j7:00<0`<3003>QbP0cXLX0
6`0cXLX00`30`<00<j7:03>QbP0A03>QbP0308QU?P3^[V`0kZi/00L0kZi/00@0R6Dn0>6TI`3QY6L0
hJAW0P28ICh40=bQI@0308QU?P3;Teh0bi=N00L0bi=N00<0R6Dn0;j:F@2nRUT02@2nRUT00`28ICh0
^HIG0;V6E`0208QU?PH0^8IG00<0R6Dn0;V8F02iR5P0102iR5P208QU?P040:n3EP30`<00`<300<30
`080[h=F00<0R6Dn07mVAP28ICh00P28ICh307mTA@0308QU?P2cQEL0/hEG00P0/hEG00<0R6Dn0<NA
G@37TEd01`37TEd208QU?PT0eiiU00@0R6Dn0>jaK`3^/Fl0k[5_1P28ICh0103oa7T0R6Dn0?o6N@3o
aWT308QU?P<0g:1U00<0R6Dn0=>KHP3CVf800`3CVf800`28ICh0aY5M0<JAG@070<JAG@0408QU?P2n
ReT0R6Dn08QU?PD0]hMH00<0R6Dn0:MmD`2WOE<00P2WOE<00`28ICh0U7=>09AcCP0209AcCP80R6Dn
00@0C3X/08QU?P28ICh0R6Dn0`1eGd800`28ICh0YWaB0:IlDP090:IlDP80R6Dn0`2jR5P00`28ICh0
_HYI0;f:F@080;f:F@0308QU?P36T5`0aY1L00<0aY1L00D0R6Dn0<bDGP3<U5h0c9AN08QU?P0;0=fQ
I@0308QU?P3^[fd0kZm]00H0kZm]00<0R6Dn0?ZgL@3j]g40103j]g400`28ICh0ol=g0?o3M`040?o3
M`0308QU?P3]]fl0kKM_00d0R6Dn1P33Tf0208QU?PL0bIAO00<0R6Dn0;^9F@2kRET01`2kRET208QU
?P030;f9F028ICh0^XMG00/0^XMG00<0R6Dn0;j:F@2nRUT02@2nRUT00`28ICh0bi=N0<^CGP090<^C
GP0308QU?P3NXVH0gZ9V00L0gZ9V00<0R6Dn0>b/J`28ICh01@3f]6l00`28ICh0<j7:03>QbP0I03>Q
bP030<30`00cXLX0<j7:00l0<j7:00<0`<3003>QbP0cXLX00P0cXLX10?ooo`00100cXLX00`30`<00
<j7:03>QbP0L03>QbP030<30`00cXLX0<j7:0100<j7:00<0R6Dn0>j^K03^[V`01`3^[V`01028ICh0
hJAW08QU?P28ICh50=bQI@0308QU?P3;Teh0bi=N00P0bi=N00<0R6Dn0;j:F@2nRUT02@2nRUT00`28
ICh0^HIG0;V6E`020;V6E`0308QU?P2hQUL0^8IG00<0^8IG00<0R6Dn0;V8F02iR5P0102iR5P30<30
`0H0[h=F1P28ICh00`1oI4D0R6Dn0;>5E`0:0;>5E`0308QU?P37TEd0ai5M00D0ai5M00<0R6Dn0=NN
I@3GWVD0203GWVD00`28ICh0k[5_0>jaK`040>jaK`0608QU?P3oa7T0olAi0?o4N@28ICh0olIi1028
ICh50=bPI@0508QU?P3CVf80di]R0=>KHP28ICh02@36TEd00`28ICh0_X]I0;j;F@020;j;F@0308QU
?P2gQeP0]hMH0080]hMH00<0R6Dn0:MmD`2WOE<00`2WOE<208QU?P@0U7=>00D0R6Dn04`j;028ICh0
C3X/08QU?P0207EO@P<0R6Dn2`2VO58208QU?P030;Z8F028ICh0_HYI00P0_HYI00<0R6Dn0<J@G036
T5`01@36T5`208QU?P030<bDGP28ICh0gJ5U00T0gJ5U00<0R6Dn0>j_K@3^[fd01P3^[fd00`28ICh0
oked08QU?P040?ZgL@0308QU?P3o`gL0ol=g00@0ol=g00<0R6Dn0>fgK`28ICh01P28ICh409AcCPH0
R6Dn1P33Tf0308QU?P@0bIAO00<0R6Dn0;^9F@2kRET02@2kRET208QU?P`0^XMG00<0R6Dn0;j:F@2n
RUT02@2nRUT00`28ICh0bi=N0<^CGP090<^CGP0308QU?P3NXVH0gZ9V00L0gZ9V0P28ICh60?JdK`03
08QU?P0cXLX0<j7:01X0<j7:00<0`<3003>QbP0cXLX03P0cXLX00`30`<00<j7:03>QbP0203>QbP40
oooo000403>QbP030<30`00cXLX0<j7:01d0<j7:00<0`<3003>QbP0cXLX03`0cXLX00`28ICh0kZi/
0>j^K0060>j^K0<0R6Dn1`3LXFD00`28ICh0bi=N0<^CGP080<^CGP0308QU?P2nRUT0_XYI00P0_XYI
00<0R6Dn0;V6E`2iQUL0102iQUL208QU?P<0^8IG00@0R6Dn0;V8F02iR5P0^HQH0`30`<030;V8F080
R6Dn0P2_PeH208QU?P030;nBG`28ICh0R6Dn0080R6Dn00@0N61308QU?P28ICh0R6Dn2`2cQEL00`28
ICh0ai5M0<NAG@020<NAG@80R6Dn2@3GWVD208QU?PH0k[5_00H0R6Dn0?o4N@3oa7T0olAi08QU?P3o
aWT208QU?P030>^/K028ICh0g:1U00H0g:1U00<0R6Dn0=>KHP28ICh02P36TEd00`28ICh0_X]I0;j;
F@030;j;F@80R6Dn00<0]hMH08QU?P2WOE<01`2WOE<208QU?P<0U7=>00@0R6Dn04`j;028ICh0C3X/
0P28ICh309=bCP0308QU?P2VO580YWaB00X0YWaB00<0R6Dn0;f:F@2mRUT01`2mRUT00`28ICh0aY1L
0<J@G0080<J@G00308QU?P3MXFD0gJ5U00P0gJ5U00<0R6Dn0>j_K@3^[fd01P3^[fd01028ICh0oked
0?nmM028ICh30?ZgL@0308QU?P3o`gL0ol=g00<0ol=g1028ICh70;V8F@80R6Dn0`2DLdh708QU?PL0
`i=P0P28ICh00`39U5l0R6Dn0;^9F@0<0;^9F@<0R6Dn2P2jQeL00`28ICh0_XYI0;j:F@090;j:F@03
08QU?P3;Teh0bi=N00T0bi=N00<0R6Dn0=jRIP3NXVH01`3NXVH00`28ICh0m[A_0?JdK`050?JdK`03
08QU?P0cXLX0<j7:01/0<j7:00<0`<3003>QbP0cXLX03@0cXLX00`30`<00<j7:03>QbP0203>QbP40
oooo000403>QbP030<30`00cXLX0<j7:01h0<j7:00<0`<3003>QbP0cXLX03P0cXLX00`28ICh0kZi/
0>j^K0060>j^K00308QU?P3LXFD0g:5U00L0g:5U00<0R6Dn0<^CGP3;Teh0203;Teh00`28ICh0_XYI
0;j:F@080;j:F@0308QU?P2iQUL0^HIG00H0^HIG0`28ICh0102iR5P0`<300<30`030`<080;V8F080
R6Dn1@2oTUl308QU?P80N6130P28ICh;0;>5E`0408QU?P37TEd0R6Dn08QU?PX0eiiU00<0R6Dn0>ja
K`3^/Fl01@3^/Fl01P28ICh0olAi0?o4N@3oa7T0R6Dn0?o6N@80R6Dn00<0jja/08QU?P3LX6D0203L
X6D00`28ICh0aY5M0<JAG@080<JAG@0308QU?P2nReT0_X]I00H0_X]I00<0R6Dn0:MmD`2WOE<02@2W
OE<02@28ICh0U7=>09AcCP2DLdh0R6Dn04`j;028ICh0C3X/08QU?P0409=bCP80R6Dn2@2VO5801028
ICh0]XIG08QU?P28ICh60;f:F@0308QU?P36T5`0aY1L00P0aY1L00<0R6Dn0=>KH`28ICh0203MXFD0
0`28ICh0kZm]0>j_K@060>j_K@0308QU?P3o_G@0oked0080oked00@0R6Dn0?ZgL@3j]g40R6Dn103o
`gL308QU?PX0^HQI0`28ICh209AcCPP0R6Dn1`33Tf0208QU?P`0^hUI00@0R6Dn0;V7E`2iQeL0^HMG
0P28ICh80;Z7E`0308QU?P2nRUT0_XYI00T0_XYI00<0R6Dn0<^CGP3;Teh02@3;Teh00`28ICh0gZ9V
0=jRIP050=jRIP<0R6Dn1P3f]6l00`28ICh0<j7:03>QbP0L03>QbP030<30`00cXLX0<j7:00d0<j7:
00<0`<3003>QbP0cXLX00P0cXLX10?ooo`00100cXLX00`30`<00<j7:03>QbP0O03>QbP030<30`00c
XLX0<j7:00`0<j7:00<0R6Dn0>j^K03^[V`01P3^[V`208QU?PT0g:5U00<0R6Dn0<^CGP3;Teh0203;
Teh00`28ICh0_XYI0;j:F@080;j:F@0308QU?P2iQUL0^HIG00L0^HIG0`30`<0;0;V8F00308QU?P38
U5l0R6Dn0080R6Dn102oTUl208QU?P80N6130P28ICh60;>5E`H0R6Dn2`3GWVD00`28ICh0k[5_0>ja
K`050>jaK`0308QU?P3oa7T0olAi0080R6Dn00<0olIi08QU?P28ICh00P3[[6`00`28ICh0g:1U0=bP
I@060=bPI@0408QU?P3<U5h0R6Dn08QU?PL0aY5M00<0R6Dn0;j;F@2nReT01P2nReT01028ICh0^hQH
08QU?P28ICh:0:MmD`<0R6Dn00H0MEm208QU?P28ICh0R6Dn04`j;028ICh509=bCP80R6Dn1P2VO580
0`28ICh0]XIG0;J6E`020;J6E`80R6Dn102mRUT00`28ICh0aY1L0<J@G0070<J@G00508QU?P3CVf<0
di]S0=>KH`28ICh01`3MXFD00`28ICh0kZm]0>j_K@060>j_K@0308QU?P3o_G@0oked0080oked00<0
R6Dn0?ZgL@28ICh0103o`gL208QU?P030<RBG@28ICh0^HQI00X0^HQI00D0R6Dn09UeC`28ICh0R6Dn
09AcCP0908QU?P<0`i=P0P28ICh20;B6F080R6Dn2P2kRET00`28ICh0^HMG0;V7E`030;V7E`80R6Dn
1@2jQeL00`28ICh0_XYI0;j:F@0:0;j:F@0308QU?P3;Teh0bi=N00T0bi=N00<0R6Dn0=jRIP3NXVH0
103NXVH00`28ICh0i:IX08QU?P070?JdK`0308QU?P0cXLX0<j7:01d0<j7:00<0`<3003>QbP0cXLX0
3@0cXLX01030`<00<j7:03>QbP0cXLX10?ooo`00100cXLX00`30`<00<j7:03>QbP0P03>QbP030<30
`00cXLX0<j7:00/0<j7:00<0R6Dn0>j^K03^[V`01@3^[V`00`28ICh0ijQY08QU?P090=bQI@0308QU
?P3;Teh0bi=N00P0bi=N00<0R6Dn0;j:F@2nRUT0202nRUT00`28ICh0^HIG0;V6E`040;V6E`<0`<30
00<0^HIG08QU?P2mREP00P28ICh80;V8F00308QU?P38U5l0b9AO00<0b9AO0P28ICh40;nBG`0408QU
?P1hH4<0N61307QP@`H0R6Dn1P2oSed00`28ICh0eiiU0=NNI@070=NNI@0308QU?P3^/Fl0k[5_00@0
k[5_0P28ICh20?o4N@0408QU?P3oaWT0olIi08QU?P<0jja/00<0R6Dn0=bPI@3LX6D01`3LX6D01@28
ICh0c9AN0<bDGP3<U5h0R6Dn00D0aY5M00<0R6Dn0;j;F@2nReT01`2nReT01@28ICh0^hQH0;^8F02k
R5P0R6Dn00/0YgeC00@0R6Dn07EO@P1eGd80MEm20P28ICh00`1<>R`0R6Dn09=bCP0509=bCP0308QU
?P2VO580YWaB0080YWaB00<0R6Dn0;J6E`2fQUL01@2fQUL208QU?P030;f:F@28ICh0aY1L00T0aY1L
00<0R6Dn0=>KH`3CVf<00P3CVf<208QU?P@0gJ5U00<0R6Dn0>j_K@3^[fd01P3^[fd00`28ICh0oked
0?nmM0040?nmM00308QU?P3o`gL0ol=g0080ol=g00<0R6Dn0<RBG@38TUd00P38TUd00`28ICh0^HQI
0;V8F@090;V8F@0308QU?P2IMDl0VGE?0080R6Dn00<0U7=>08QU?P1SCcT01028ICh0102GMU00R6Dn
08QU?P28ICh60;B6F00308QU?P2kRET0^hUI00L0^hUI00<0R6Dn0;V7E`2iQeL01@2iQeL208QU?P<0
^XMG00<0R6Dn0;j:F@2nRUT02P2nRUT00`28ICh0bi=N0<^CGP080<^CGP0308QU?P3NXVH0gZ9V00<0
gZ9V0P28ICh20>BVJ00308QU?P3f]6l0m[A_00D0m[A_00<0R6Dn03>QbP0cXLX07P0cXLX00`30`<00
<j7:03>QbP0<03>QbP040<30`00cXLX0<j7:03>QbP40oooo000403>QbP030<30`00cXLX0<j7:0240
<j7:0P30`<0;03>QbP0308QU?P3^[V`0kZi/00@0kZi/00@0R6Dn0>NXJ@3WZ6T0R6Dn2@3LXFD00`28
ICh0bi=N0<^CGP080<^CGP0308QU?P2nRUT0_XYI00P0_XYI00@0R6Dn0;V6E`2iQUL0^HIG0`30`<04
0;V6E`0408QU?P2mREP0_HUH0;f9F080R6Dn1P2iR5P00`28ICh0b9AO0<RDG`050<RDG`<0R6Dn0P2o
TUl208QU?P80N6130P28ICh:0;n?G@0308QU?P3GWVD0eiiU00D0eiiU00<0R6Dn0>jaK`3^/Fl0103^
/Fl01P28ICh0olAi0?o4N@3oa7T0R6Dn0?o6N@80R6Dn0`3[[6`00`28ICh0g:1U0=bPI@070=bPI@03
08QU?P3<U5h0c9AN00<0c9AN00<0R6Dn0<JAG@36TEd00P36TEd00`28ICh0_X]I0;j;F@060;j;F@03
08QU?P2kR5P0^hQH00<0^hQH0P28ICh90:MmD`<0R6Dn0P1eGd8508QU?PD0Tg9>0P28ICh00`2VO580
R6Dn0;J6E`090;J6E`0308QU?P36T5`0aY1L00P0aY1L00<0R6Dn0=>KH`3CVf<01@3CVf<01028ICh0
gJ5U0=fQI@28ICh80>j_K@0308QU?P3o_G@0oked00@0oked0P28ICh30?o3M`0308QU?P38TUd0b99M
00@0b99M00<0R6Dn0;V8F@2iR5T02@2iR5T01028ICh0VGE?09UeC`2IMDl308QU?P0306=?>@28ICh0
R6Dn0080R6Dn0P2GMU0208QU?PH0]8IH0P28ICh60;^9F@0308QU?P2iQeL0^HMG00P0^HMG0P28ICh0
0`2jQeL0R6Dn0;j:F@0:0;j:F@0308QU?P3;Teh0bi=N00T0bi=N00@0R6Dn0=jRIP3NXVH0gZ9V0P28
ICh40>BVJ00308QU?P3f]6l0m[A_00D0m[A_00<0R6Dn03>QbP0cXLX07P0cXLX00`30`<00<j7:03>Q
bP0<03>QbP040<30`00cXLX0<j7:03>QbP40oooo000403>QbP030<30`00cXLX0<j7:02<0<j7:00<0
`<3003>QbP0cXLX0200cXLX00`28ICh0kZi/0>j^K0030>j^K00408QU?P3WZ6T0ijQY08QU?PX0g:5U
00<0R6Dn0<^CGP3;Teh01`3;Teh00`28ICh0_XYI0;j:F@090;j:F@0408QU?P30`<00`<300<30`0L0
^HIG00<0R6Dn0;f9F02mREP00`2mREP208QU?P@0^HQH00<0R6Dn0<RDG`38U5l02038U5l608QU?P80
N61300<0R6Dn0;n?G@2oSed0202oSed208QU?P<0eiiU0P28ICh60>jaK`0408QU?P3oa7T0olAi0?o4
N@<0R6Dn103[[6`00`28ICh0g:1U0=bPI@080=bPI@0308QU?P3<U5h0c9AN00@0c9AN0P28ICh00`36
TEd0R6Dn0;j;F@080;j;F@0308QU?P2kR5P0^hQH00D0^hQH0P28ICh70:MmD`0308QU?P1eGd80MEm2
0080R6Dn00<0MEm208QU?P28ICh00`28ICh509=bCP80R6Dn302fQUL00`28ICh0aY1L0<J@G0060<J@
G00308QU?P3CVf<0di]S00L0di]S00<0R6Dn0=fQI@28ICh01`3^[fd00`28ICh0oked0?nmM0040?nm
M00408QU?P3ob7T0R6Dn0?o3M`80R6Dn1`38TUd808QU?PD0^HQI00<0R6Dn09UeC`2IMDl00P2IMDl2
08QU?P80Hdli0`28ICh309MfD00308QU?P2dQUP0]8IH00D0]8IH0P28ICh40;^9F@0308QU?P2iQeL0
^HMG00X0^HMG0`28ICh:0;j:F@0308QU?P3;Teh0bi=N00T0bi=N00@0R6Dn0=jRIP3NXVH0R6Dn1P3T
YVP00`28ICh0m[A_0?JdK`040?JdK`0308QU?P0cXLX0<j7:0200<j7:00<0`<3003>QbP0cXLX02`0c
XLX01030`<00<j7:03>QbP0cXLX10?ooo`000`0cXLX00`30`<00<j7:03>QbP0U03>QbP030<30`00c
XLX0<j7:00H0<j7:00<0R6Dn0>j^K03^[V`00`3^[V`01@28ICh0ijQY0>NXJ@3WZ6T0R6Dn00X0g:5U
00<0R6Dn0<^CGP3;Teh01`3;Teh00`28ICh0_XYI0;j:F@070;j:F@<0`<302P2iQUL00`28ICh0_HUH
0;f9F0050;f9F080R6Dn00<0^HQH08QU?P38U5l02P38U5l00`28ICh0j:i^0>R^KP020>R^KPD0R6Dn
2`2oSed00`28ICh0eiiU08QU?P070>jaK`0308QU?P3oa7T0olAi00<0R6Dn0P3a/6d01@28ICh0jja/
0>^/K03[[6`0R6Dn00T0g:1U00<0R6Dn0<bDGP3<U5h01`3<U5h00`28ICh0_X]I0;j;F@070;j;F@03
08QU?P2kR5P0^hQH00H0^hQH00@0R6Dn0;f;FP28ICh0R6Dn102WOE<00`28ICh0MEm207EO@P0307EO
@P80R6Dn00<0MEm208QU?P28ICh00P28ICh209=bCP80R6Dn0P2QNe800`28ICh0]XIG0;J6E`0:0;J6
E`0308QU?P36T5`0aY1L00@0aY1L00<0R6Dn0=>KH`3CVf<02@3CVf<00`28ICh0kZm]0>j_K@050>j_
K@0308QU?P3o_G@0oked00@0oked00<0R6Dn0?o8N@3ob7T00P28ICh70<RBG@80R6Dn0P2oReT00`28
ICh0]hIH0;N6F0030;N6F0P0R6Dn102IMDl208QU?P0406=?>@28ICh0R6Dn08QU?P<0UgI@00<0R6Dn
0;B6F02dQUP01P2dQUP01@28ICh0^hUI0;^9F@2kRET0R6Dn00d0^HMG00<0R6Dn0<6<FP28ICh00`28
ICh60;j:F@0308QU?P3;Teh0bi=N00T0bi=N0`28ICh60>BVJ00308QU?P3f]6l0m[A_00D0m[A_00<0
R6Dn03>QbP0cXLX08@0cXLX00`30`<00<j7:03>QbP0:03>QbP040<30`00cXLX0<j7:03>QbP40oooo
000303>QbP030<30`00cXLX0<j7:02H0<j7:00<0`<3003>QbP0cXLX01@0cXLX01028ICh0kZi/0>j^
K03^[V`208QU?P@0ijQY00<0R6Dn0=bQI@3LXFD01`3LXFD00`28ICh0bi=N0<^CGP080<^CGP0308QU
?P2nRUT0_XYI00<0_XYI1030`<020;j:F@0308QU?P2iQUL0^HIG00P0^HIG00<0R6Dn0;f9F02mREP0
1`2mREP408QU?PP0b9AO00<0R6Dn0>R^KP3X[Vh0103X[Vh208QU?P0407QSA028ICh0R6Dn08QU?PH0
_hmM2028ICh40>jaK`D0R6Dn1@3a/6d00`28ICh0jja/08QU?P090=bPI@0308QU?P3<U5h0c9AN00L0
c9AN00@0R6Dn0<2;F@28ICh0R6Dn1`2nReT00`28ICh0^hQH0;^8F0050;^8F00308QU?P2mReX0_H]J
0080_H]J0`28ICh00`2WOE<0R6Dn07EO@P0607EO@P@0R6Dn00<0J5<l08QU?P28ICh01@2QNe800`28
ICh0]XIG0;J6E`0:0;J6E`0308QU?P36T5`0aY1L0080aY1L00<0R6Dn0=>KH`3CVf<02@3CVf<00`28
ICh0ij][08QU?P050>j_K@0308QU?P3o_G@0oked00@0oked00D0R6Dn0?o8N@3ob7T0olQi08QU?P06
0<RBG@80R6Dn102oReT00`28ICh0]hIH0;N6F00:0;N6F0<0R6Dn0`2IMDl208QU?P0306=?>@28ICh0
R6Dn0080R6Dn0P2GMU0208QU?PL0]8IH0`28ICh=0;V7E`0308QU?P31S5X0`HaJ00@0`HaJ1028ICh2
0;j:F@0308QU?P3;Teh0bi=N00@0bi=N1P28ICh80>BVJ00308QU?P3f]6l0m[A_00@0m[A_0P28IChT
03>QbP030<30`00cXLX0<j7:00T0<j7:00@0`<3003>QbP0cXLX0<j7:0@3oool000<0<j7:00<0`<30
03>QbP0cXLX09`0cXLX00`30`<00<j7:03>QbP0403>QbP0408QU?P3^[V`0kZi/08QU?PH0ijQY00<0
R6Dn0=bQI@3LXFD01`3LXFD00`28ICh0bi=N0<^CGP080<^CGP0308QU?P2nRUT0_XYI00<0`<301@2n
RUT00`28ICh0^HIG0;V6E`080;V6E`0308QU?P2mREP0_HUH00T0_HUH00<0R6Dn0<VCGP39Teh01@28
ICh30<RDG`0308QU?P3X[Vh0j:i^0080j:i^1P28ICh00`1hHd@0R6Dn08QU?P0508QU?PP0ejAY2028
ICh70?6`K@0308QU?P3LX6D0g:1U00P0g:1U00<0R6Dn0<bDGP3<U5h01`3<U5h01@28ICh0`8]I0<2;
F@30ReT0R6Dn00D0_X]I00<0R6Dn0;^8F02kR5P01P2kR5P00`28ICh0_H]J0;f;FP050;f;FP<0R6Dn
201eGd8308QU?P0306QC?028ICh0XG]B00D0XG]B00<0R6Dn0;J6E`2fQUL02P2fQUL01@28ICh0aY1L
0<J@G036T5`0R6Dn00X0di]S00D0R6Dn0>N[J`3WZf/0ij][08QU?P040>j_K@0308QU?P3o_G@0oked
00<0oked00D0R6Dn0?o8N@3ob7T0olQi08QU?P050<RBG@80R6Dn1`2oReT00`28ICh0]hIH0;N6F00:
0;N6F00408QU?P2SOE<0R6Dn08QU?P80VGE?0P28ICh00`1SCcT0R6Dn08QU?P0208QU?P<0UgI@00<0
R6Dn0;B6F02dQUP01P2dQUP00`28ICh0^HMG0;V7E`0;0;V7E`0308QU?P31S5X0`HaJ00P0`HaJ2@28
ICh50=2GH00308QU?P3TYVP0i:IX00H0i:IX00<0R6Dn0?JdK`3f]6l00`3f]6l208QU?RD0<j7:00<0
`<3003>QbP0cXLX02@0cXLX01030`<00<j7:03>QbP0cXLX10?ooo`000`0cXLX00`30`<00<j7:03>Q
bP0X03>QbP030<30`00cXLX0<j7:00<0<j7:00<0R6Dn0>j^K028ICh01`3WZ6T00`28ICh0g:5U0=bQ
I@070=bQI@0308QU?P3;Teh0bi=N00<0bi=N1@28ICh30<30`0P0_XYI00<0R6Dn0;V6E`2iQUL0202i
QUL00`28ICh0_HUH0;f9F0090;f9F00308QU?P39Teh0bI=N00D0bI=N2028ICh50>2UJ0@0R6Dn00<0
N6=408QU?P28ICh02@3GY6T308QU?P050>ReLP28ICh0R6Dn0?JdK`28ICh01`3a/6d01028ICh0ijUZ
08QU?P28ICh70=bPI@0308QU?P3<U5h0c9AN00L0c9AN00<0R6Dn0<2;F@30ReT00`30ReT208QU?P<0
_X]I00<0R6Dn0;^8F02kR5P01@2kR5P00`28ICh0_H]J0;f;FP070;f;FP0308QU?P35Tel0R6Dn00<0
R6Dn1P1eGd801028ICh0J5<l06QC?028ICh60:5kDP0308QU?P2fQUL0]XIG00X0]XIG00<0R6Dn0<J@
G028ICh02P3CVf<00`28ICh0ij][0>N[J`020>N[J`0508QU?P3^[fd0kZm]0>j_K@28ICh01@3o_G@0
0`28ICh0olQi0?o8N@0208QU?P@0b99M0P28ICh:0;n;F@0308QU?P2gQUP0]hIH00X0]hIH00<0R6Dn
0:=mD`2SOE<00P28ICh00`2IMDl0R6Dn08QU?P0308QU?P0306]G?@28ICh0R6Dn0080UgI@00<0R6Dn
0;B6F02dQUP00`2dQUP208QU?P030;B5E`28ICh0R6Dn00/0^HMG00<0R6Dn0<6<FP31S5X02P31S5X0
0`28ICh0d9MP0=2GH0080=2GH00308QU?P3TYVP0i:IX00L0i:IX00<0R6Dn0?JdK`3f]6l00P3f]6l0
0`28ICh0olIi08QU?P0V03>QbP030<30`00cXLX0<j7:00P0<j7:00@0`<3003>QbP0cXLX0<j7:0@3o
ool000<0<j7:00<0`<3003>QbP0cXLX0:@0cXLX01`30`<00<j7:03>QbP0cXLX0R6Dn0>j^K028ICh0
203WZ6T00`28ICh0g:5U0=bQI@070=bQI@H0R6Dn0P34Se`30<30`00308QU?P2jQeL0^XMG00H0R6Dn
0P2nRUT00`28ICh0^HIG0;V6E`080;V6E`0308QU?P2mREP0_HUH00P0_HUH00<0R6Dn0<VCGP39Teh0
2039Teh00`28ICh0h:EX0>2UJ0070>2UJ00308QU?P3m`WH0oL9f00L0R6Dn0`3GY6T408QU?P80j;Eb
0P28ICh20?JdK`0308QU?P3a/6d0lK1]00H0lK1]00D0R6Dn0>NYJP3WZFX0ijUZ08QU?P060=bPI@03
08QU?P3<U5h0c9AN00L0c9AN00<0R6Dn0<2;F@30ReT01@30ReT308QU?PP0^hQH00<0R6Dn0;f;FP2m
ReX01P2mReX00`28ICh0aI=O0<FCG`040<FCG`<0R6Dn101eGd8208QU?P0306QC?028ICh0R6Dn00D0
XG]B0P28ICh;0;J6E`0308QU?P3CVf<0di]S00P0di]S00<0R6Dn0>N[J`3WZf/0103WZf/00`28ICh0
kZm]08QU?P050?nmM00608QU?P3ob7T0olQi08QU?P3DVV80R6Dn0P38TUd208QU?Pd0_h]I00<0R6Dn
0;N6F02gQUP02@2gQUP00`28ICh0XgeC0:=mD`020:=mD`80R6Dn00<0VGE?08QU?P28ICh00P28ICh0
0`1[Ecd0R6Dn08QU?P0408QU?P030;B6F028ICh0R6Dn00D0]8EG0P28ICh80;V7E`0308QU?P31S5X0
`HaJ00X0`HaJ00<0R6Dn0=2GH03@Uf002@3@Uf000`28ICh0i:IX0>BVJ0060>BVJ00308QU?P3f]6l0
m[A_0080m[A_00<0R6Dn0?o6N@28ICh0:00cXLX00`30`<00<j7:03>QbP0803>QbP030<30`00cXLX0
<j7:0040oooo000303>QbP030<30`00cXLX0<j7:02X0<j7:00<0`<3003>QbP0cXLX00P28ICh90>NX
J@0308QU?P3LXFD0g:5U00D0g:5U0`28ICh40<B?G0<0`<300`34Se`00`28ICh0^XMG0;Z7E`060;Z7
E`@0R6Dn2@2iQUL00`28ICh0_HUH0;f9F0080;f9F00308QU?P39Teh0bI=N00P0bI=N00<0R6Dn0>2U
J03PYFP01`3PYFP308QU?PD0okme2`28ICh30?JdK`0308QU?P3a/6d0lK1]00H0lK1]00<0R6Dn0>NY
JP3WZFX00`3WZFX208QU?P<0g:1U00<0R6Dn0<bDGP3<U5h01`3<U5h00`28ICh0`8]I0<2;F@080<2;
F@80R6Dn1`2kR5P00`28ICh0_H]J0;f;FP060;f;FP0308QU?P35Tel0aI=O00D0aI=O00<0R6Dn0=>Q
J028ICh00`28ICh01P1eGd80R6Dn08QU?P28ICh0J5<l08QU?PH0XG]B00<0R6Dn0;J6E`2fQUL01P2f
QUL208QU?P030<jIH`28ICh0di]S00H0di]S0P28ICh80>N[J`0308QU?P3o_G@0oked00<0oked00@0
R6Dn0?o8N@3ob7T0R6Dn0`3DVV8208QU?Pl0_h]I00<0R6Dn0;N6F02gQUP02P2gQUP00`28ICh0XgeC
0:=mD`030:=mD`H0R6Dn00<0JeLm08QU?P2NNE400P2NNE4208QU?PT0]8EG00<0R6Dn0;V7E`2iQeL0
1@2iQeL00`28ICh0`HaJ0<6<FP0:0<6<FP0308QU?P3@Uf00d9MP00T0d9MP00<0R6Dn0>BVJ03TYVP0
1P3TYVP01@28ICh0m[A_0?JdK`3f]6l0R6Dn0080olIi00<0R6Dn03>QbP0cXLX09P0cXLX00`30`<00
<j7:03>QbP0803>QbP030<30`00cXLX0<j7:0040oooo000303>QbP030<30`00cXLX0<j7:02/0<j7:
0P30`<000`28ICh0ijQY0>NXJ@080>NXJ@0308QU?P3LXFD0g:5U00<0g:5U0P28ICh20=^RIP0308QU
?P34Se`0`<300080`<301P34Se`00`28ICh0^XMG0;Z7E`080;Z7E`0308QU?P2iQUH0R6Dn00<0R6Dn
1@2iQUL00`28ICh0_HUH0;f9F0080;f9F00308QU?P39Teh0bI=N00P0bI=N00<0R6Dn0>2UJ03PYFP0
1P3PYFP208QU?P`0okme00<0R6Dn0?JdK`3f]6l01P3f]6l00`28ICh0lK1]0?6`K@060?6`K@0308QU
?P3WZFX0ijUZ00D0ijUZ0P28ICh00`3LX6D0R6Dn0<bDGP080<bDGP0308QU?P30ReT0`8]I00P0`8]I
00<0R6Dn0;^8E`28ICh00`28ICh20;^8F00308QU?P2mReX0_H]J00L0_H]J00<0R6Dn0<FCG`35Tel0
1@35Tel00`28ICh0dj5X0=>QJ0030=>QJ0<0R6Dn00<0DCl_08QU?P1XDc`00`28ICh40:5kDP0308QU
?P2fQUL0]XIG00<0]XIG0P28ICh40<jIH`0308QU?P3CVf<0di]S00<0di]S00<0R6Dn0>N[J`3WZf/0
1P3WZf/208QU?P030?noM`28ICh0oked0080oked00@0R6Dn0?o8N@3ob7T0R6Dn0`3DVV800`28ICh0
bI9M08QU?P0@0;n;F@0308QU?P2gQUP0]hIH00X0]hIH00<0R6Dn0:=mD`2SOE<0102SOE<508QU?P03
06]G?@28ICh0WWUA00<0WWUA00<0R6Dn0;B5E`2dQEL01`2dQEL208QU?PD0^HMG00<0R6Dn0<6<FP31
S5X02P31S5X00`28ICh0d9MP0=2GH0090=2GH00308QU?P3TYVP0i:IX00H0i:IX00@0R6Dn0?JdK`3f
]6l0R6Dn0P3oaWT00`28ICh0<j7:03>QbP0X03>QbP030<30`00cXLX0<j7:00L0<j7:00<0`<3003>Q
bP0cXLX00@3oool000<0<j7:00<0`<3003>QbP0cXLX0;@0cXLX00`28ICh0ijQY0>NXJ@070>NXJ@03
08QU?P3LXFD0g:5U0080g:5U0P28ICh30=^RIP<0`<302@34Se`00`28ICh0^XMG0;Z7E`080;Z7E`03
08QU?P2iQUH0^HIF00<0^HIF1028ICh00`2iQUL0R6Dn0;f9F0090;f9F00308QU?P39Teh0bI=N00L0
bI=N00<0R6Dn0>2UJ03PYFP0103PYFP308QU?P030=fQI@28ICh0okme00X0okme00<0R6Dn0?JcK`28
ICh01P3f]6l00`28ICh0lK1]0?6`K@060?6`K@0308QU?P3WZFX0ijUZ00P0ijUZ00<0R6Dn0<bDGP3<
U5h01`3<U5h00`28ICh0`8]I0<2;F@080<2;F@0308QU?P2kR5L0^hQG00@0^hQG1@28ICh70;f;FP03
08QU?P35Tel0aI=O00D0aI=O00<0R6Dn0=>QJ03CXFP01P3CXFP308QU?P0306QC?028ICh0Z89F00@0
R6Dn00@0XG]B08QU?P2fQUL0]XIG0P28ICh70<jIH`0508QU?P3CVf<0di]S0=>KH`28ICh0203WZf/0
0`28ICh0okmg0?noM`020?noM`0308QU?P3o_G@0R6Dn0080olQi00D0R6Dn0=BJHP3DVV80e9YR08QU
?P020<VBG@0308QU?P2oReT0_h]I00h0_h]I2028ICh60;N6F00308QU?P2SOE<0XgeC00D0XgeC00H0
R6Dn06MC>`28ICh0R6Dn06]G?@28ICh409iiD@80R6Dn2@2dQEL208QU?P<0^HMG00<0R6Dn0<6<FP31
S5X02@31S5X00`28ICh0d9MP0=2GH0090=2GH00308QU?P3TYVP0i:IX00L0i:IX00<0R6Dn0?JdK`28
ICh00`3oaWT00`28ICh0<j7:03>QbP0Y03>QbP030<30`00cXLX0<j7:00H0<j7:00<0`<3003>QbP0c
XLX00@3oool000<0<j7:00<0`<3003>QbP0cXLX0;@0cXLX00`28ICh0ijQY0>NXJ@070>NXJ@0308QU
?P3LXFD0g:5U0080R6Dn0P3KXVH30<30`0030=^RIP28ICh0a8mL00T0a8mL00<0R6Dn0;Z7E`2jQeL0
202jQeL00`28ICh0^HIF0;V6EP070;V6EP<0R6Dn2@2mREP00`28ICh0bI=N0<VCGP070<VCGP0308QU
?P3PYFP0h:EX0080h:EX0P28ICh40=fQI@0308QU?P3o_gD0okme00P0okme00@0R6Dn0?JcK`3f/fl0
R6Dn1@3f]6l00`28ICh0lK1]0?6`K@060?6`K@0308QU?P3WZFX0ijUZ00P0ijUZ00@0R6Dn0=BJHP28
ICh0R6Dn1`3<U5h00`28ICh0`8]I0<2;F@080<2;F@0308QU?P2kR5L0^hQG00H0^hQG00<0R6Dn0;j;
F@2nReT01028ICh20;f;FP0308QU?P35Tel0aI=O00L0aI=O00<0R6Dn0=>QJ03CXFP01P3CXFP01@28
ICh0Z8YH08QU?P1XDc`0R6Dn00@0Z89F1028ICh:0<jIH`0308QU?P3CVf<0R6Dn00P0ij][00<0R6Dn
0?noM`3o_gL0103o_gL01028ICh0olQi08QU?P28ICh30=BJHP0308QU?P39TUd0bI9M0080bI9M00<0
R6Dn0;n;F@2oReT02`2oReT208QU?P80_8UH00<0R6Dn0;R8F02hR5P00`2hR5P908QU?PH0XgeC1`28
ICh409iiD@0308QU?P2dQEL0]8EG00P0]8EG0`28ICh<0<6<FP0308QU?P3@Uf00d9MP00T0d9MP00<0
R6Dn0>BVJ03TYVP01P3TYVP00`28ICh0m[A_08QU?P030?o6N@0308QU?P0cXLX0<j7:02X0<j7:00<0
`<3003>QbP0cXLX01P0cXLX00`30`<00<j7:03>QbP010?ooo`000P0cXLX00`30`<00<j7:03>QbP0^
03>QbP0308QU?P3WZ6T0ijQY00L0ijQY0`28ICh0103KXVH0`<300<30`030`<040=^RIP0308QU?P34
Se`0a8mL00P0a8mL00<0R6Dn0;Z7E`2jQeL0202jQeL00`28ICh0^HIF0;V6EP080;V6EP0308QU?P2o
RUT0R6Dn0080R6Dn1@2mREP00`28ICh0bI=N0<VCGP080<VCGP0308QU?P3PYFP0R6Dn0080R6Dn1P3M
XFD00`28ICh0okme0?noM@070?noM@0308QU?P3f/fl0m[=_0080m[=_00<0R6Dn0?JdK`3f]6l00P3f
]6l00`28ICh0lK1]0?6`K@060?6`K@0308QU?P3WZFX0ijUZ00P0ijUZ00D0R6Dn0=BJHP3DVV80e9YR
08QU?P050<bDGP0308QU?P30ReT0`8]I00P0`8]I00<0R6Dn0;^8E`2kR5L01P2kR5L00`28ICh0_X]I
0;j;F@050;j;F@L0R6Dn1@35Tel00`28ICh0dj5X0=>QJ0030=>QJ0D0R6Dn00<0Z8YH08QU?P28ICh0
1`2XPUH00`28ICh0cYUS0<jIH`090<jIH`0308QU?P3WZf/0ij][00D0ij][0P28ICh50?noM`@0R6Dn
103DVV800`28ICh0bI9M0<VBG@030<VBG@0308QU?P2oReT0_h]I00T0_h]I0P28ICh40;b9F00308QU
?P2hR5P0^8QH00/0^8QH0`28ICh50:=mD`D0R6Dn00<0JeLm08QU?P2NNE400`2NNE400`28ICh0]8EG
0;B5E`090;B5E`80R6Dn2`31S5X00`28ICh0d9MP0=2GH0090=2GH00308QU?P3TYVP0i:IX00H0i:IX
0P28ICh40?o6N@0308QU?P0cXLX0<j7:02/0<j7:00<0`<3003>QbP0cXLX01@0cXLX00`30`<00<j7:
03>QbP010?ooo`000P0cXLX00`30`<00<j7:03>QbP0]03>QbP0308QU?P3WZ6T0ijQY00P0ijQY00@0
R6Dn0<30`030`<00`<301`3KXVH00`28ICh0a8mL0<B?G0080<B?G00308QU?P2jQeL0^XMG00P0^XMG
00<0R6Dn0;V6EP2iQUH0202iQUH00`28ICh0_hYI0;n:F@020;n:F@@0R6Dn00<0_HUH08QU?P39Teh0
1039Teh708QU?PT0gJ5U00<0R6Dn0?noM@3o_gD01P3o_gD00`28ICh0m[=_0?JcK`030?JcK`0508QU
?P3f]6l0m[A_0?JdK`28ICh0203a/6d00`28ICh0ijUZ0>NYJP080>NYJP0308QU?P3DVV80e9YR00<0
e9YR0P28ICh30<bDGP0308QU?P30ReT0`8]I00P0`8]I00<0R6Dn0;^8E`2kR5L01P2kR5L00`28ICh0
_X]I0;j;F@070;j;F@0308QU?P3<UV00c9IP0080c9IP2`28ICh50>V^K`0408QU?P3AYVL0dJIW08QU
?PL0Z89F00<0R6Dn0<jIH`3>VF<02@3>VF<00`28ICh0ij][0>N[J`030>N[J`0308QU?P3o_gL0okmg
00<0okmg0P28ICh20>jiL@0308QU?P3DVV80e9YR0080e9YR00<0R6Dn0<VBG@39TUd01@39TUd00`28
ICh0_h]I0;n;F@050;n;F@<0R6Dn1`2lREP00`28ICh0^8QH0;R8F00;0;R8F00308QU?P2>Ldh0R6Dn
0080R6Dn0`2SOE<708QU?P@0WWUA00<0R6Dn0;B5E`2dQEL01`2dQEL00`28ICh0_heK0;n=F`0208QU
?PP0`HaJ00<0R6Dn0=2GH03@Uf002@3@Uf000`28ICh0i:IX0>BVJ0060>BVJ080R6Dn103oaWT00`28
ICh0<j7:03>QbP0]03>QbP030<30`00cXLX0<j7:00@0<j7:00<0`<3003>QbP0cXLX00@3oool00080
<j7:00<0`<3003>QbP0cXLX0;@0cXLX00`28ICh0ijQY0>NXJ@060>NXJ@<0`<302P3KXVH00`28ICh0
a8mL0<B?G0080<B?G00308QU?P2jQeL0^XMG00P0^XMG00<0R6Dn0;V6EP2iQUH0202iQUH00`28ICh0
_hYI0;n:F@060;n:F@L0R6Dn1@3;Teh00`28ICh0gJ5U0=fQI@080=fQI@0308QU?P3o_gD0okme00D0
okme00<0R6Dn0?JcK`3f/fl01@3f/fl00`28ICh0m[A_08QU?P090?6`K@0308QU?P3WZFX0ijUZ00P0
ijUZ00<0R6Dn0=BJHP3DVV801@3DVV8308QU?PX0`8]I00<0R6Dn0;^8E`2kR5L01`2kR5L00`28ICh0
_X]I0;j;F@070;j;F@0308QU?P3<UV00c9IP00L0c9IP00<0R6Dn0>V^K`3Y[Vl0203Y[Vl00`28ICh0
dJIW0=6VI`0308QU?PH0Z89F00<0R6Dn0<jIH`3>VF<0203>VF<00`28ICh0ij][0>N[J`020>N[J`03
08QU?P3o_gL0okmg00<0okmg00@0R6Dn0>jiL@3^^G40R6Dn1@3DVV800`28ICh0bI9M0<VBG@070<VB
G@0308QU?P2oReT0_h]I0080_h]I0P28ICh;0;b9F00308QU?P2hR5P0^8QH00/0^8QH00@0R6Dn08ic
CP2>Ldh0SW=>0`28ICh00`2SOE<0R6Dn08QU?P0208QU?P0307=M@P28ICh0R6Dn00@0WWUA00<0R6Dn
0;B5E`2dQEL01@2dQEL00`28ICh0_heK0;n=F`030;n=F`80R6Dn1P31S5X00`28ICh0d9MP0=2GH009
0=2GH00308QU?P3TYVP0i:IX00@0i:IX0`28ICh50?o6N@0308QU?P0cXLX0<j7:02h0<j7:00<0`<30
03>QbP0cXLX00`0cXLX00`30`<00<j7:03>QbP010?ooo`000P0cXLX00`30`<00<j7:03>QbP0]03>Q
bP0308QU?P3WZ6T0ijQY00<0ijQY0`30`<000`28ICh0ijU[08QU?P0:0=^RIP0308QU?P34Se`0a8mL
00P0a8mL00<0R6Dn0;Z7E`2jQeL0202jQeL00`28ICh0^HIF0;V6EP080;V6EP0308QU?P2oRUT0_hYI
00L0_hYI00<0R6Dn0<^CGP3;Teh0203;Teh00`28ICh0gJ5U0=fQI@080=fQI@0308QU?P3o_gD0okme
00@0okme00<0R6Dn0?JcK`3f/fl01P3f/fl00`28ICh0m[A_08QU?P080?6`K@0308QU?P3WZFX0ijUZ
00P0ijUZ00<0R6Dn0=BJHP3DVV80203DVV8208QU?PT0`8]I00<0R6Dn0;^8E`2kR5L01`2kR5L00`28
ICh0_X]I0;j;F@070;j;F@0308QU?P3<UV00c9IP00L0c9IP00<0R6Dn0>V^K`3Y[Vl0203Y[Vl308QU
?P80kKQ`1@28ICh30:R2EP0308QU?P3>VF<0cYUS00P0cYUS00@0R6Dn0>N[J`28ICh0R6Dn103o_gL2
08QU?P030>jiL@28ICh0e9YR00D0e9YR00<0R6Dn0<VBG@39TUd02039TUd00`28ICh0_h]I0;n;F@02
08QU?Pd0_8UH00<0R6Dn0;R8F02hR5P02`2hR5P00`28ICh0SW=>08icCP0408icCP<0R6Dn00<0JEDl
08QU?P28ICh00`28ICh409iiD@80R6Dn0`2dQEL208QU?PP0_heK0P28ICh40<6<FP0308QU?P3@Uf00
d9MP00T0d9MP00<0R6Dn0>BVJ03TYVP00P3TYVP208QU?P80l;5_00<0R6Dn0?o6N@3oaWT00P3oaWT0
0`28ICh0<j7:03>QbP0_03>QbP030<30`00cXLX0<j7:00@0<j7:0@30`<0103>QbP40oooo000203>Q
bP030<30`00cXLX0<j7:02d0<j7:00<0R6Dn0>NXJ@3WZ6T00`30`<000`3WZ6T0R6Dn08QU?P020>NY
J`0308QU?P3KXVH0fj9V00P0fj9V00<0R6Dn0<B?G034Se`02034Se`00`28ICh0^XMG0;Z7E`080;Z7
E`0308QU?P2iQUH0^HIF00P0^HIF00<0R6Dn0;n:F@2oRUT01`2oRUT00`28ICh0bi=N0<^CGP080<^C
GP0308QU?P3MXFD0gJ5U00H0gJ5U0`28ICh60?noM@0308QU?P3f/fl0m[=_00L0m[=_00<0R6Dn0?6`
K@3a/6d01P3a/6d00`28ICh0ijUZ0>NYJP080>NYJP0308QU?P3DVV80e9YR00P0e9YR00<0R6Dn0<6<
FP31S5X00P28ICh60<2;F@0308QU?P2kR5L0^hQG00L0^hQG00<0R6Dn0;j;F@2nReT0202nReT00`28
ICh0c9IP0<bFH0070<bFH00308QU?P3Y[Vl0jJi_00D0jJi_0`28ICh20?6cL00308QU?P3]^700kKQ`
0080kKQ`0P28ICh00`1mJ4L0R6Dn08QU?P0308QU?PH0cYUS1@28ICh40?noM`@0R6Dn1`3DVV800`28
ICh0bI9M0<VBG@0:0<VBG@80R6Dn402lREP00`28ICh0^8QH0;R8F00;0;R8F00308QU?P2>Ldh0SW=>
00D0SW=>0P28ICh01@1YEC`0R6Dn08QU?P28ICh0Lee200@0R6Dn0P2NNE400`28ICh0]8EG08QU?P0<
0;n=F`80R6Dn00<0`HaJ08QU?P3@Uf002`3@Uf000`28ICh0i:IX0>BVJ00208QU?P<0l;5_00<0R6Dn
0?o6N@3oaWT00`3oaWT00`28ICh0<j7:03>QbP0`03>QbP030<30`00cXLX0<j7:00<0<j7:0@30`<01
03>QbP40oooo000203>QbP030<30`00cXLX0<j7:02d0<j7:0`30`<030>NXJ@0308QU?P3WZF/0ijU[
0080ijU[00<0R6Dn0=^RIP3KXVH0203KXVH00`28ICh0a8mL0<B?G0080<B?G00308QU?P2jQeL0^XMG
00P0^XMG00<0R6Dn0;V6EP2iQUH0202iQUH00`28ICh0_hYI0;n:F@070;n:F@0308QU?P3;Teh0bi=N
00P0bi=N00<0R6Dn0=fQI@3MXFD01@3MXFD01@28ICh0gZ5U0=jQI@3NXFD0R6Dn00@0okme00<0R6Dn
0?JcK`3f/fl01`3f/fl01028ICh0lK1]08QU?P28ICh60?6`K@0308QU?P3WZFX0ijUZ00P0ijUZ00<0
R6Dn0=BJHP3DVV80203DVV800`28ICh0`HaJ0<6<FP020<6<FP80R6Dn1030ReT00`28ICh0^hQG0;^8
E`070;^8E`0308QU?P2nReT0_X]I00L0_X]I00<0R6Dn0<bFH03<UV002@3<UV000`28ICh0jJi_0>V^
K`020>V^K`80R6Dn1P3a/g001028ICh0kKQ`08QU?P28ICh30<^PH080R6Dn0P1mJ4L708QU?PD0eZU[
00<0R6Dn0?noM`28ICh01028ICh70=BJHP0308QU?P39TUd0bI9M00T0bI9M0`28IChB0;b9F00308QU
?P2hR5P0^8QH00/0^8QH00<0R6Dn08icCP2>Ldh01P2>Ldh508QU?P0407=M@P28ICh0[hEH0:n5F0@0
R6Dn3`2oSE/708QU?PH0d9MP00@0R6Dn0>BVJ028ICh0R6Dn1@3`/Fl00`28ICh0olIi0?o6N@020?o6
N@0308QU?P0cXLX0<j7:0380<j7:00<0`<3003>QbP0cXLX00P0cXLX10<30`040<j7:0@3oool00080
<j7:00<0`<3003>QbP0cXLX0:P0cXLX30<30`00308QU?P3WZ6T0ijQY0080ijQY00<0R6Dn0>NYJ`3W
ZF/00`3WZF/00`28ICh0fj9V0=^RIP080=^RIP0308QU?P34Se`0a8mL00P0a8mL00<0R6Dn0;Z7E`2j
QeL0202jQeL00`28ICh0^HIF0;V6EP080;V6EP0308QU?P2oRUT0_hYI00L0_hYI00<0R6Dn0<^CGP3;
Teh0203;Teh00`28ICh0gJ5U0=fQI@030=fQI@80R6Dn103NXFD01@28ICh0okme0?noM@3o_gD0R6Dn
00X0m[=_00@0R6Dn0?6`K@3a/6d0lK1]0P28ICh30?6`K@0308QU?P3WZFX0ijUZ00P0ijUZ00<0R6Dn
0=BJHP3DVV80203DVV800`28ICh0`HaJ0<6<FP050<6<FP80R6Dn00<0`8]I08QU?P2kR5L02@2kR5L0
0`28ICh0_X]I0;j;F@070;j;F@0308QU?P3<UV00c9IP00T0c9IP00<0R6Dn0>V^K`28ICh00P28ICh9
0?6cL00308QU?P3;X600bj1P00<0bj1P00D0R6Dn0?o2M`28ICh0R6Dn07eXA`0208QU?PX0eZU[0`28
ICh0103/[6/0R6Dn0>:UI`28ICh50=BJHP0308QU?P39TUd0bI9M00T0bI9M00D0R6Dn0<B=FP34SEX0
a8eJ08QU?P0A0;b9F00308QU?P2hR5P0^8QH00H0^8QH2@28ICh708icCP@0R6Dn00<0Lee208QU?P28
ICh0102_QEP208QU?Pd0_heK00<0R6Dn0=FMI03EWF@0103EWF@808QU?PH0l;5_00<0R6Dn0?o6N@3o
aWT00`3oaWT00`28ICh0<j7:03>QbP0b03>QbP030<30`00cXLX0<j7:0080<j7:0@30`<0103>QbP40
oooo000203>QbP030<30`00cXLX0<j7:02L0<j7:0`30`<0303>QbP0508QU?P3WZ6T0ijQY0>NXJ@28
ICh01P3WZF/00`28ICh0fj9V0=^RIP080=^RIP0308QU?P34Se`0a8mL00P0a8mL00<0R6Dn0;Z7E`2j
QeL0202jQeL00`28ICh0^HIF0;V6EP080;V6EP0308QU?P2oRUT0_hYI00L0_hYI00<0R6Dn0<^CGP3;
Teh0203;Teh01028ICh0gJ5U0=fQI@3MXFD208QU?PH0gZ5U00@0R6Dn0?noM@3o_gD0R6Dn2P3f/fl0
0`28ICh0lK1]0?6`K@040?6`K@80R6Dn00<0lK1]08QU?P3WZFX0203WZFX00`28ICh0e9YR0=BJHP09
0=BJHP0308QU?P31S5X0`HaJ00L0`HaJ0`28ICh90;^8E`0308QU?P2nReT0_X]I00L0_X]I00<0R6Dn
0<bFH03<UV00203<UV0308QU?PX0lK=`0P28ICh00`3a/g00R6Dn0<^PH0020<^PH00608QU?P3o`WL0
ol9g0?o2M`28ICh0oked2028ICh30?BbKP0308QU?P3/[6/0k:a[0080k:a[00@0R6Dn0>:UI`3RYFL0
R6Dn0`3DVV800`28ICh0bI9M0<VBG@090<VBG@0308QU?P34SEX0a8eJ0080a8eJ00<0R6Dn0;b9F02l
REP03`2lREP908QU?PT0<j7:1@28ICh308icCP@0R6Dn0P1cGD800`28ICh0[hEH0:n5F0030:n5F003
08QU?P2oSE/0_heK00T0_heK00<0R6Dn0=FMI03EWF@02P3EWF@00`28ICh0l;5_0?2aK`050?2aK`03
08QU?P3oaWT0olIi0080olIi0P28IChf03>QbP060<30`00cXLX0<j7:03>QbP30`<00<j7:0@3oool0
0080<j7:00<0`<3003>QbP0cXLX0900cXLX30<30`0D0<j7:00D0R6Dn0>NXJ@3WZ6T0ijQY08QU?P07
0>NYJ`0308QU?P3KXVH0fj9V00P0fj9V00<0R6Dn0<B?G034Se`02034Se`00`28ICh0^XMG0;Z7E`08
0;Z7E`0308QU?P2iQUH0^HIF00P0^HIF00<0R6Dn0;n:F@2oRUT01`2oRUT00`28ICh0bi=N0<^CGP08
0<^CGP0408QU?P3MXFD0gJ5U08QU?PT0gZ5U0P28ICh:0?JcK`0308QU?P3a/6d0lK1]00L0lK1]0P28
ICh90>NYJP0308QU?P3DVV80e9YR00P0e9YR00<0R6Dn0<6<FP31S5X02@31S5X00`28ICh0^HIF08QU
?P0208QU?PD0^hQG00<0R6Dn0;j;F@2nReT0202nReT00`28ICh0c9IP0<bFH0040<bFH0@0R6Dn00<0
cIIO08QU?P3a/g002@3a/g000`28ICh0lK=`0?6cL0020?6cL00308QU?P3;X600R6Dn00<0ol9g00<0
R6Dn0?nmM03o_G@00P3o_G@01@28ICh0nkQa0?^hL@3k^740R6Dn00@0m;9^00D0R6Dn0>b/J`3/[6/0
k:a[08QU?P040>:UI`0308QU?P3DVV80R6Dn00X0bI9M0P28ICh60<B=FP0308QU?P2lREP0_8UH00/0
_8UH0`28IChG03>QbPT0R6Dn00<0Lee208QU?P2_QEP0102_QEP208QU?PP0_heK00<0R6Dn0=FMI03E
WF@02P3EWF@00`28ICh0l;5_0?2aK`060?2aK`0408QU?P3oaWT0olIi0?o6N@80R6Dn>00cXLX01@30
`<00<j7:03>QbP30`<00<j7:0040oooo00000`0cXLX0`<3003>QbP0S03>QbP<0`<30200cXLX01028
ICh0ijQY08QU?P28ICh80>NYJ`0308QU?P3KXVH0fj9V00L0fj9V1`28ICh50<B?G00308QU?P2jQeL0
^XMG00P0^XMG00<0R6Dn0;V6EP2iQUH0202iQUH00`28ICh0_hYI0;n:F@070;n:F@0308QU?P3;Teh0
bi=N00P0bi=N0`28ICh:0=jQI@0308QU?P3f/fl0m[=_00T0m[=_00<0R6Dn0?6`K@3a/6d01P3a/6d0
0`28ICh0jJ][0>V[J`0308QU?PD0ijUZ00<0R6Dn0=BJHP3DVV802@3DVV800`28ICh0`HaJ0<6<FP08
0<6<FP0308QU?P2iQUH0^HIF00<0^HIF1028ICh00`2kR5L0R6Dn0;j;F@090;j;F@0308QU?P3<UV00
c9IP00@0R6Dn1@3=UUl00`28ICh0lK=`0?6cL0070?6cL00308QU?P3a/g00lK=`00@0lK=`00D0R6Dn
0?o2M`3o`WL0ol9g08QU?P040?nmM00508QU?P3k^740nkQa0?^hL@28ICh0103d/Vh01@28ICh0k:a[
0>b/J`3/[6/0R6Dn00H0hZEW00<0R6Dn0<VBG@39TUd02039TUd00`28ICh0a8eJ0<B=FP060<B=FP03
08QU?P2lREP0_8UH00P0_8UH0`28IChO03>QbPL0R6Dn1P2_QEP208QU?PH0_heK00<0R6Dn0=FMI03E
WF@02P3EWF@00`28ICh0l;5_0?2aK`050?2aK`0508QU?P3oaWT0olIi0?o6N@28ICh0>P0cXLX01@30
`<00<j7:03>QbP30`<00<j7:0040oooo00000`0cXLX0`<3003>QbP0P03>QbP<0`<302`0cXLX208QU
?PX0ijU[00<0R6Dn0=^RIP3KXVH00`3KXVH408QU?P030;J>G@28ICh0/XEG00@0/XEG2028ICh80;Z7
E`0308QU?P2iQUH0^HIF00P0^HIF00<0R6Dn0;n:F@2oRUT01`2oRUT00`28ICh0bi=N0<^CGP070<^C
GP80R6Dn2`3NXFD208QU?PX0m[=_00<0R6Dn0?6`K@3a/6d01`3a/6d00`28ICh0jJ][0>V[J`030>V[
J`<0R6Dn0P3WZFX00`28ICh0e9YR0=BJHP080=BJHP0308QU?P31S5X0`HaJ00T0`HaJ00<0R6Dn0;V6
EP2iQUH01`2iQUH?08QU?PT0cIIO00<0R6Dn0?6cL03a/g001@3a/g0208QU?PH0lK=`00<0R6Dn0?Fc
K`28ICh00P3o`WL00`28ICh0oked0?nmM0020?nmM00508QU?P3k^740nkQa0?^hL@28ICh00`3d/Vh0
0`28ICh0k:a[0>b/J`020>b/J`0308QU?P3RYFL0hZEW00<0hZEW0P28ICh90<VBG@0308QU?P34SEX0
a8eJ00P0a8eJ00<0R6Dn0;b9F02lREP00`2lREP408QU?RH0<j7:1@28ICh60:n5F00308QU?P2oSE/0
_heK0080_heK00<0R6Dn0=FMI03EWF@02P3EWF@00`28ICh0l;5_0?2aK`060?2aK`0408QU?P3oaWT0
R6Dn08QU?S`0<j7:00@0`<3003>QbP30`<00<j7:0@3oool0000303>QbP30`<00<j7:01d0<j7:0`30
`<0>03>QbP0308QU?P3WZF/0ijU[00T0ijU[00<0R6Dn0=^RIP28ICh00`28ICh50;J>G@0308QU?P2b
QEL0/XEG00P0/XEG00<0R6Dn0;:3E@2bPeD01P28ICh20;Z7E`0308QU?P2iQUH0^HIF00P0^HIF00<0
R6Dn0;n:F@2oRUT01`2oRUT00`28ICh0bi=N0<^CGP040<^CGP<0R6Dn00<0ciIO08QU?P3NXFD02@3N
XFD01028ICh0hjEW0>>UI`28ICh90?JcK`0308QU?P3a/6d0lK1]00H0lK1]00<0R6Dn0>V[J`3YZf/0
1`3YZf/308QU?PX0e9YR00<0R6Dn0<6<FP31S5X02031S5X00`28ICh0^HIF0;V6EP090;V6EP0308QU
?P2mREP0_HUH00P0_HUH00<0R6Dn0<fFG`3=UUl02@3=UUl00`28ICh0lK=`0?6cL0040?6cL00308QU
?P3a/g00lK=`00D0lK=`00H0R6Dn0?FcK`3e/fl0R6Dn0?o2M`28ICh40?nmM00508QU?P3k^740nkQa
0?^hL@28ICh0103d/Vh01@28ICh0k:a[0>b/J`3/[6/0R6Dn00D0hZEW00@0R6Dn0=VNH`3IWV<0R6Dn
1P39TUd208QU?P/0a8eJ00<0R6Dn0;b9F02lREP00`28ICh/03>QbP@0R6Dn1P2_QEP208QU?P030;n=
F`28ICh0eIeT00/0eIeT00<0R6Dn0?2aK`3`/Fl01P3`/Fl01028ICh0olIi08QU?P28IChn03>QbP03
0<30`00cXLX0`<300040oooo00000`0cXLX0`<3003>QbP0J03>QbP<0`<304@0cXLX00`28ICh0ijU[
0>NYJ`090>NYJ`80R6Dn2P2fSUd00`28ICh0/XEG0;:5E`070;:5E`0308QU?P2bPeD0/X=E00H0/X=E
1@28ICh80;V6EP0308QU?P2oRUT0_hYI00L0_hYI00<0R6Dn0<^CGP3;Teh00P3;Teh208QU?P@0ciIO
00<0R6Dn0=jQI@3NXFD01`3NXFD01@28ICh0hjEW0>>UI`3SYFL0R6Dn00P0m[=_00<0R6Dn0?6`K@3a
/6d01P3a/6d00`28ICh0jJ][0>V[J`080>V[J`0308QU?P3FWF@0eYeT0080R6Dn1`3DVV800`28ICh0
`HaJ0<6<FP090<6<FP0308QU?P2iQUH0^HIF00P0^HIF00<0R6Dn0;f9F02mREP02@2mREP00`28ICh0
cIIO0<fFG`090<fFG`0308QU?P3a/g00lK=`0080lK=`0P28ICh70?6cL00308QU?P3e/fl0mK=_0080
mK=_00<0R6Dn0?nmM03o_G@00P3o_G@00`28ICh0nkQa0?^hL@020?^hL@0508QU?P3d/Vh0m;9^0?Bb
KP28ICh0103/[6/00`28ICh0hZEW0>:UI`030>:UI`0408QU?P3IWV<0fIiS08QU?PD0bI9M00<0R6Dn
0<B=FP34SEX03034SEX208QU?S40<j7:00<0R6Dn07mYB028ICh02@28ICh;0=FMI00308QU?P3`/Fl0
l;5_00L0l;5_0`28ICi003>QbP80`<300@3oool0000303>QbP30`<00<j7:01L0<j7:0`30`<0D03>Q
bP0308QU?P3WZF/0ijU[00L0ijU[0P28ICh00`3FY6T0R6Dn0;J>G@090;J>G@0308QU?P2bQEL0/XEG
00L0/XEG00<0R6Dn0;:3E@2bPeD0202bPeD00`28ICh0^HIG0;V6E`0608QU?P80^HIF00<0R6Dn0;n:
F@2oRUT01`2oRUT00`28ICh0bi=N08QU?P0208QU?PL0ciIO00<0R6Dn0=jQI@3NXFD01@3NXFD00`28
ICh0hjEW0>>UI`020>>UI`0308QU?P3f/fl0m[=_00D0m[=_00<0R6Dn0?6`K@3a/6d01`3a/6d00`28
ICh0jJ][0>V[J`070>V[J`0308QU?P3FWF@0eYeT00<0eYeT0`28ICh40=BJHP0308QU?P31S5X0`HaJ
00P0`HaJ00<0R6Dn0;V6EP2iQUH02@2iQUH00`28ICh0_HUH0;f9F0090;f9F00308QU?P3=UUl0cIIO
00T0cIIO00D0R6Dn0?6cL03a/g00lK=`08QU?P080?6cL00308QU?P3e/fl0mK=_0080mK=_00<0R6Dn
0?FcK`28ICh00P3o_G@00`28ICh0nkQa0?^hL@020?^hL@0508QU?P3d/Vh0m;9^0?BbKP28ICh0103/
[6/00`28ICh0hZEW0>:UI`030>:UI`0308QU?P3IWV<0fIiS0080fIiS00D0R6Dn0<VBG@39TUd0bI9M
08QU?P0=0<B=FP80R6Dn=00cXLX408QU?PL0cieV1028ICh70=FMI00308QU?P3`/Fl0l;5_00@0l;5_
1028ICi203>QbP80`<300@3oool0000303>QbP30`<00<j7:01@0<j7:0`30`<0G03>QbP0308QU?P3W
ZF/0ijU[00D0ijU[0P28ICh30=JTJ@0308QU?P2fSUd0]XiM00P0]XiM00<0R6Dn0;:5E`2bQEL0202b
QEL00`28ICh0/X=E0;:3E@070;:3E@0308QU?P2iQUL0^HIG00H0^HIG3P28ICh:0<nFG`0308QU?P3N
XFD0gZ5U00@0gZ5U00<0R6Dn0>>UI`3SYFL0103SYFL00`28ICh0m[=_0?JcK`040?JcK`0308QU?P3a
/6d0lK1]00H0lK1]00<0R6Dn0>V[J`3YZf/0203YZf/00`28ICh0eYeT0=JMI0060=JMI080R6Dn00<0
e9YR08QU?P31S5X02P31S5X00`28ICh0^HIF0;V6EP090;V6EP0308QU?P2mREP0_HUH00T0_HUH00<0
R6Dn0<fFG`3=UUl02@3=UUl01028ICh0lK=`0?6cL028ICh80?6cL00308QU?P3e/fl0mK=_00<0mK=_
00H0R6Dn0?FcK`3e/fl0R6Dn0?nmM028ICh30?^hL@0308QU?P3d/Vh0m;9^0080m;9^00D0R6Dn0>b/
J`3/[6/0k:a[08QU?P050>:UI`0308QU?P3IWV<0fIiS00<0fIiS00@0R6Dn0<VBG@28ICh0R6Dn3034
SEX208QU?SP0<j7:1028ICh90<nMIP@0R6Dn0P3EWF@00`28ICh0l;5_08QU?P0808QU?T<0<j7:0P30
`<010?ooo`0000<0<j7:0<30`00cXLX04@0cXLX30<30`1/0<j7:00<0R6Dn0>NYJ`3WZF/00P3WZF/2
08QU?PH0eZAY00<0R6Dn0;J>G@2fSUd01`2fSUd00`28ICh0/XEG0;:5E`080;:5E`0308QU?P2bPeD0
/X=E00L0/X=E00<0R6Dn0;V6E`2iQUL0202iQUL00`28ICh0`heJ0<>=FP070<>=FP0308QU?P3?UUl0
ciIO00T0ciIO00<0R6Dn0=jQI@3NXFD00`3NXFD00`28ICh0hjEW0>>UI`050>>UI`0308QU?P3f/fl0
m[=_00<0m[=_00<0R6Dn0?6`K@3a/6d01P3a/6d00`28ICh0jJ][0>V[J`080>V[J`0308QU?P3FWF@0
eYeT00T0eYeT0`28ICh:0<6<FP0308QU?P2iQUH0^HIF00T0^HIF00<0R6Dn0;f9F02mREP02@2mREP0
0`28ICh0cIIO0<fFG`090<fFG`<0R6Dn203a/g000`28ICh0mK=_0?FcK`030?FcK`0308QU?P3e/fl0
mK=_0080mK=_00<0R6Dn0?^hL@3k^7400P3k^7401@28ICh0m;9^0?BbKP3d/Vh0R6Dn00@0k:a[00<0
R6Dn0>:UI`3RYFL00P3RYFL00`28ICh0fIiS0=VNH`050=VNH`0308QU?P34SEX0a8eJ00/0a8eJ00<0
R6Dn03>QbP0cXLX0>P0cXLX408QU?P/0cieV1028ICh40?RmM`<0R6Dn@@0cXLX40<30`080<j7:0@3o
ool0000303>QbP30`<00<j7:00h0<j7:0`30`<0N03>QbP0308QU?P3WZF/0ijU[0080R6Dn2@3FY6T0
0`28ICh0]XiM0;J>G@070;J>G@0308QU?P2bQEL0/XEG00L0/XEG00<0R6Dn0;:3E@2bPeD01`2bPeD0
0`28ICh0^HIG0;V6E`080;V6E`0308QU?P33SEX0`heJ00L0`heJ00<0R6Dn0<nFG`3?UUl02@3?UUl0
0`28ICh0gZ5U0=jQI@020=jQI@0308QU?P3SYFL0hjEW00D0hjEW00<0R6Dn0>f]J`28ICh00`3f/fl0
0`28ICh0lK1]0?6`K@070?6`K@0308QU?P3YZf/0jJ][00L0jJ][00<0R6Dn0=JMI03FWF@02P3FWF@0
0`28ICh0`hiK0<>>F`0208QU?PL0`HaJ00<0R6Dn0;V6EP2iQUH02@2iQUH00`28ICh0_HUH0;f9F009
0;f9F00308QU?P3=UUl0cIIO00T0cIIO0P28ICh90?6cL00308QU?P3e/fl0mK=_00<0mK=_00<0R6Dn
0?FcK`3e/fl00P3e/fl00`28ICh0mK=^08QU?P020?^hL@0508QU?P3d/Vh0m;9^0?BbKP28ICh0103/
[6/00`28ICh0hZEW0>:UI`020>:UI`0308QU?P3IWV<0fIiS00D0fIiS00<0R6Dn0=:IH028ICh02P34
SEX208QU?Sl0<j7:1028ICh70<nMIP80R6Dn1P3h_GL308QU?T00<j7:0`30`<0603>QbP40oooo0000
0`0cXLX0`<3003>QbP0;03>QbP<0`<308@0cXLX:08QU?P@0eZAY00<0R6Dn0;J>G@2fSUd01`2fSUd0
0`28ICh0/XEG0;:5E`070;:5E`0308QU?P2bPeD0/X=E00L0/X=E00<0R6Dn0;V6E`2iQUL0202iQUL0
0`28ICh0`heJ0<>=FP070<>=FP0308QU?P3?UUl0ciIO00T0ciIO00D0R6Dn0=jQI@3NXFD0gZ5U08QU
?P070>>UI`0408QU?P3][F/0kJe[08QU?P<0m[=_00<0R6Dn0?6`K@3a/6d01P3a/6d00`28ICh0jJ][
0>V[J`070>V[J`0308QU?P3FWF@0eYeT00X0eYeT00<0R6Dn0<>>F`33SU/00`33SU/308QU?P@0`HaJ
00<0R6Dn0;V6EP2iQUH02@2iQUH00`28ICh0_HUH0;f9F0090;f9F00308QU?P3=UUl0cIIO00L0cIIO
0P28ICh00`3:Teh0R6Dn0?6cL0070?6cL00308QU?P3e/fl0mK=_00<0mK=_00<0R6Dn0?FcK`3e/fl0
0`3e/fl01P28ICh0mK=^0?FcKP28ICh0nkQa08QU?P<0m;9^00D0R6Dn0>b/J`3/[6/0k:a[08QU?P04
0>:UI`0308QU?P3IWV<0fIiS00D0fIiS00@0R6Dn0=:IH03BVF00R6Dn2034SEX208QU?T@0<j7:0`28
ICh20<nMIP<0R6Dn1P3h_GL308QU?Sh0<j7:1030`<0903>QbP40oooo00000`30`<00<j7:03>QbP08
03>QbP<0`<30900cXLX308QU?PL0<j7:1`28ICh70;J>G@0308QU?P2bQEL0/XEG00L0/XEG00<0R6Dn
0;:3E@2bPeD01`2bPeD00`28ICh0^HIG0;V6E`080;V6E`0308QU?P33SEX0`heJ00P0`heJ00<0R6Dn
0<nFG`3?UUl02@3?UUl00`28ICh0gZ5U08QU?P080>>UI`0708QU?P3][F/0kJe[0>f]J`28ICh0m[=_
08QU?P090?6`K@0308QU?P3YZf/0jJ][00H0jJ][00<0R6Dn0=JMI03FWF@02P3FWF@00`28ICh0`hiK
0<>>F`070<>>F`80R6Dn00<0`HaJ08QU?P2iQUH02`2iQUH00`28ICh0_HUH0;f9F0090;f9F00308QU
?P3=UUl0cIIO00@0cIIO0`28ICh30<ZCGP0308QU?P3a/g00lK=`00D0lK=`0P28ICh50?FcK`0308QU
?P3e/fl0mK=_0080mK=_00<0R6Dn0?FcKP3e/fh00P3e/fh01@28ICh0m;9^0?BbKP3d/Vh0R6Dn00@0
k:a[00<0R6Dn0>:UI`3RYFL00P3RYFL00`28ICh0fIiS0=VNH`040=VNH`0308QU?P3BVF00dYUP0080
dYUP00<0R6Dn0<B=FP34SEX01034SEX00`28ICh0<j7:03>QbP1603>QbPd0R6Dn?@0cXLX30<30`0d0
<j7:0@3oool000030<30`00cXLX0<j7:00D0<j7:0`30`<0h03>QbP<0R6Dn102fSUd00`28ICh0/XEG
0;:5E`070;:5E`0308QU?P2bPeD0/X=E00L0/X=E00<0R6Dn0;V6E`2iQUL0202iQUL00`28ICh0`heJ
0<>=FP080<>=FP0308QU?P3?UUl0ciIO00T0ciIO0P28ICh80>>UI`0308QU?P3][F/0kJe[0080kJe[
00<0R6Dn0?JcK`28ICh0203a/6d00`28ICh0jJ][0>V[J`070>V[J`0308QU?P3FWF@0eYeT00T0eYeT
00<0R6Dn0<>>F`33SU/02P33SU/308QU?P/0^HIF00<0R6Dn0;f9F02mREP02@2mREP01028ICh0cIIO
0<fFG`3=UUl308QU?PH0bY=N00<0R6Dn0?6cL03a/g00103a/g001028ICh0hjIX0>>VJ028ICh30?Fc
K`0308QU?P3e/fl0mK=_0080mK=_00<0R6Dn0?FcKP3e/fh00P3e/fh01@28ICh0mK=^08QU?P3d/Vh0
R6Dn00@0k:a[00<0R6Dn0>:UI`3RYFL00P3RYFL00`28ICh0fIiS0=VNH`040=VNH`0308QU?P3BVF00
dYUP00@0dYUP00@0R6Dn0<B=FP34SEX0a8eJ0P28ICj?03>QbP@0`<30400cXLX10?ooo`0000<0`<30
03>QbP0cXLX00P0cXLX30<30`3`0<j7:0P1O>B8408QU?P030;J>G@28ICh0/XEG00L0/XEG00<0R6Dn
0;:3E@2bPeD01`2bPeD00`28ICh0^HIG0;V6E`080;V6E`0308QU?P33SEX0`heJ00P0`heJ00<0R6Dn
0<nFG`3?UUl02@3?UUl00`28ICh0hjEW0>>UI`060>>UI`0308QU?P3][F/0kJe[00@0kJe[00<0R6Dn
0?6`K@3a/6d01P3a/6d00`28ICh0jJ][0>V[J`070>V[J`0308QU?P3FWF@0eYeT00X0eYeT00<0R6Dn
0<>>F`33SU/02`33SU/00`28ICh0^XMG08QU?P0308QU?PH0^HIF00<0R6Dn0;f9F02mREP02P2mREP0
1028ICh0cIIO08QU?P28ICh90<ZCGP0308QU?P3a/g00lK=`00<0lK=`00D0R6Dn0>>VJ03SYVP0hjIX
08QU?P020?FcK`0308QU?P3e/fl0mK=_0080mK=_00<0R6Dn0?FcKP3e/fh00`3e/fh01@28ICh0mK=^
08QU?P3d/Vh0R6Dn00@0k:a[00D0R6Dn0>:UI`3RYFL0hZEW08QU?P060=VNH`0308QU?P3BVF00dYUP
00D0dYUP00@0R6Dn0<B=FP28ICh0R6DnSP0cXLX30<30`1@0<j7:0@3oool000030<30`00cXLX0`<30
0080`<30@00cXLX505li8P<0R6Dn1`2bQEL00`28ICh0/X=E0;:3E@080;:3E@0308QU?P2iQUL0^HIG
00L0^HIG00<0R6Dn0<>=FP33SEX02033SEX00`28ICh0ciIO0<nFG`070<nFG`<0R6Dn1`3SYFL00`28
ICh0kJe[0>f]J`040>f]J`0408QU?P3j^740R6Dn08QU?PH0lK1]00<0R6Dn0>V[J`3YZf/0103YZf/5
08QU?PX0eYeT00<0R6Dn0<>>F`33SU/02`33SU/00`28ICh0^XMG0;Z7E`040;Z7E`@0R6Dn0P2iQUH0
0`28ICh0_HUH0;f9F0040;f9F0P0R6Dn303:Teh00`28ICh0lK=`0?6cL00208QU?P@0hjIX00<0R6Dn
0?FcK`28ICh01@3e/fl00`28ICh0mK=^0?FcKP020?FcKP0508QU?P3e/fh0mK=^0?FcKP28ICh0103/
[6/01@28ICh0hZEW0>:UI`3RYFL0R6Dn00H0fIiS00<0R6Dn0=:IH03BVF001`3BVF000`28ICh0<j7:
03>QbP2:03>QbP@0`<305`0cXLX10?ooo`000P30`<1503>QbP@0GcTR00@0R6Dn06YE?@28ICh0R6Dn
1P2bQEL00`28ICh0/X=E0;:3E@070;:3E@0308QU?P2iQUL0^HIG00L0^HIG00<0R6Dn0<>=FP33SEX0
2033SEX00`28ICh0ciIO0<nFG`060<nFG`0408QU?P3HWF<0f9eS08QU?PH0hjEW00<0R6Dn0>f]J`3]
[F/0103][F/00`28ICh0n[Qa0?ZhL@020?ZhL@d0R6Dn00<0olIi08QU?P3oa7X00P3oa7X608QU?P<0
eYeT00<0R6Dn0<>>F`33SU/03033SU/00`28ICh0^XMG0;Z7E`080;Z7E`T0R6Dn1P2lR5P00`28ICh0
bY=N0<ZCGP0;0<ZCGP0308QU?P3a/g00R6Dn00L0hjIX0P28ICh40?FcK`0308QU?P3e/fh0mK=^0080
mK=^00L0R6Dn0?FcKP3e/fh0mK=^08QU?P3e/fl0R6Dn0080k:a[00D0R6Dn0>:UI`3RYFL0hZEW08QU
?P060=VNH`0308QU?P3BVF00dYUP00H0dYUP0P28ICj:03>QbP<0`<306`0cXLX10?ooo`0000<0<j7:
0<30`00cXLX0A@0cXLX405li8P0308QU?P1ZECd0JUDm00<0R6Dn0`2bQEL00`28ICh0/X=E0;:3E@07
0;:3E@0308QU?P2iQUL0^HIG00P0^HIG00<0R6Dn0<>=FP33SEX01`33SEX00`28ICh0ciIO0<nFG`04
0<nFG`80R6Dn103HWF<00`28ICh0hjEW0>>UI`030>>UI`0308QU?P3][F/0kJe[00@0kJe[00D0R6Dn
0?ZhL@3j^740n[Qa08QU?P040?o4N00308QU?P3ob7X0olQj0080olQj00D0R6Dn0?o6N@3oaWT0olIi
08QU?P060?o4NP0408QU?P3^]780k[Ab0>jdLP@0R6Dn3@33SU/00`28ICh0^XMG0;Z7E`0;0;Z7E`03
08QU?P2lR5P0_8QH00X0_8QH00<0R6Dn0<ZCGP3:Teh02`3:Teh208QU?PP0hjIX00<0R6Dn0?FcK`3e
/fl00P3e/fl00`28ICh0mK=^0?FcKP030?FcKP0508QU?P3e/fh0mK=^0?FcKP28ICh00P3e/fl00`28
ICh0k:a[08QU?P020>:UI`0308QU?P3IWV<0fIiS00@0fIiS00<0R6Dn0=:IH03BVF001P3BVF000`28
ICh0<j7:03>QbP2603>QbP@0`<307P0cXLX10?ooo`000P0cXLX00`30`<00<j7:03>QbP1403>QbP<0
GcTR00<0R6Dn06YE?@1ZECd00`1ZECd208QU?P030;:5E`28ICh0/X=E00P0/X=E00<0R6Dn0;V6E`2i
QUL0202iQUL00`28ICh0`heJ0<>=FP080<>=FP0408QU?P3?UUl0ciIO0<nFG`80R6Dn1P3HWF<00`28
ICh0hjEW0>>UI`020>>UI`0308QU?P3][F/0kJe[00@0kJe[00<0R6Dn0?ZhL@3j^7400P3j^7400`28
ICh0olAh0?o4N0020?o4N00508QU?P3ob7X0olQj0?o8NP28ICh00`3oaWT00`28ICh0olAj0?o4NP03
0?o4NP0308QU?P3^]780k[Ab00<0k[Ab0P28ICh20<nKI0<0R6Dn2P33SU/00`28ICh0^XMG0;Z7E`0:
0;Z7E`0308QU?P2lR5P0_8QH00/0_8QH00<0R6Dn0<ZCGP3:Teh02`3:Teh00`28ICh0hjIX0>>VJ006
0>>VJ080R6Dn103e/fl00`28ICh0mK=^0?FcKP020?FcKP0508QU?P3e/fh0mK=^0?FcKP28ICh0103e
/fl01@28ICh0hZEW0>:UI`3RYFL0R6Dn00D0fIiS00<0R6Dn0=:IH03BVF001P3BVF000`28ICh0<j7:
03>QbP2403>QbP<0`<308P0cXLX10?ooo`000`0cXLX20<30`4D0<j7:0`1O>B800`28ICh0JUDm06YE
?@0406YE?@<0R6Dn202bPeD00`28ICh0^HIG0;V6E`080;V6E`0308QU?P33SEX0`heJ00P0`heJ00@0
R6Dn0<nFG`3?UUl0R6Dn203HWF<01@28ICh0hjEW0>>UI`3SYFL0R6Dn00H0kJe[00<0R6Dn0?ZhL@3j
^7400P3j^7400`28ICh0olAh0?o4N0020?o4N00308QU?P3ob7X0olQj0080olQj00@0R6Dn0?o6N@3o
aWT0R6Dn1@3oa7X00`28ICh0k[Ab0>jdLP030>jdLP0308QU?P3?Vf@0ci]T00D0ci]T0`28ICh60<>>
F`0308QU?P2jQeL0^XMG00/0^XMG00<0R6Dn0;b8F02lR5P02`2lR5P00`28ICh0bY=N0<ZCGP0:0<ZC
GP80R6Dn1`3SYVP00`28ICh0ijQY08QU?P030?FcK`0308QU?P3e/fh0mK=^0080mK=^00<0R6Dn0?Fc
KP3e/fh00P3e/fh02@28ICh0mK=_0?FcK`3e/fl0R6Dn0?FdK`28ICh0hZEW08QU?P050=VNH`0308QU
?P3BVF00dYUP00D0dYUP0P28ICj303>QbP@0`<309@0cXLX10?ooo`001@0cXLX00`30`<00<j7:03>Q
bP1303>QbP0308QU?P1O>B80R6Dn00L0JUDm00@0R6Dn0:=jD@28ICh0R6Dn1P2bPeD00`28ICh0^HIG
0;V6E`080;V6E`0308QU?P33SEX0`heJ00P0`heJ0`28ICh90=RMH`0408QU?P3SYFL0hjEW08QU?PH0
kJe[00<0R6Dn0?ZhL@3j^7400P3j^7400`28ICh0olAh0?o4N0020?o4N00308QU?P3ob7X0olQj0080
olQj00D0R6Dn0?o6N@3oaWT0olIi08QU?P030?o4NP80R6Dn103^]78208QU?PP0ci]T00<0R6Dn0;^;
FP2kReX00P28ICh40<>>F`0308QU?P2jQeL0^XMG00/0^XMG00<0R6Dn0;b8F02lR5P02`2lR5P00`28
ICh0bY=N0<ZCGP080<ZCGP80R6Dn00<0e9YQ08QU?P3SYVP01@3SYVP01028ICh0ijQY0>NXJ@28ICh2
0?FcK`0308QU?P3e/fh0mK=^00<0mK=^00D0R6Dn0?FcKP3e/fh0mK=^08QU?P040?FcK`0408QU?P3e
]6l0mKA_08QU?PD0fIiS00<0R6Dn0=:IH03BVF001@3BVF000`28ICh0<j7:03>QbP2003>QbP<0`<30
:@0cXLX10?ooo`001P0cXLX00`30`<00<j7:03>QbP1203>QbP0408QU?P1^FCl0GcTR08QU?PL0JUDm
00<0R6Dn0:=jD@2SNU400`28ICh30;:3E@0308QU?P2iQUL0^HIG00P0^HIG00<0R6Dn0<>=FP33SEX0
1`33SEX208QU?P`0f9eS00<0R6Dn0>>UI`28ICh01@3][F/00`28ICh0n[Qa0?ZhL@030?ZhL@0308QU
?P3oa7P0olAh0080olAh00D0R6Dn0?o8NP3ob7X0olQj08QU?P030?o6N@0308QU?P3oa7X0olAj00T0
R6Dn1`3?Vf@208QU?PD0^h]J0P28ICh00`33SU/0R6Dn0;Z7E`0=0;Z7E`0308QU?P2lR5P0_8QH00X0
_8QH00<0R6Dn0<ZCGP3:Teh0203:Teh01@28ICh0e9YQ0=BJH@3DVV40R6Dn00D0hjIX00<0R6Dn0>NX
J@3WZ6T00P3WZ6T208QU?PD0mK=^00D0R6Dn0?FcKP3e/fh0mK=^08QU?P040?FcK`0608QU?P3e]6l0
mKA_08QU?P3d]700R6Dn0`3IWV<00`28ICh0dYUP0=:IH0050=:IH00308QU?P0cXLX0<j7:07h0<j7:
0`30`<0/03>QbP40oooo000703>QbP030<30`00cXLX0<j7:0480<j7:00<0R6Dn06iI?`28ICh01`1Z
ECd00`28ICh0XgYA0:=jD@030:=jD@80R6Dn00<0/X=E08QU?P2iQUL02@2iQUL00`28ICh0`heJ0<>=
FP030<>=FP@0R6Dn00<0biAN08QU?P3HWF<02`3HWF<208QU?PH0kJe[00<0R6Dn0?ZhL@3j^7400P3j
^7400`28ICh0olAh0?o4N0020?o4N00508QU?P3ob7X0olQj0?o8NP28ICh00`3oaWT408QU?P807Q@=
00D0^hmN08QU?P28ICh0W81D08QU?P0209b0E0@0R6Dn0P3?Vf@00`28ICh0^h]J0;^;FP070;^;FP80
R6Dn3@2jQeL00`28ICh0_8QH0;b8F00;0;b8F00308QU?P3:Teh0bY=N00L0bY=N00<0R6Dn0=BJH@3D
VV400P3DVV400`28ICh0hjIX0>>VJ0020>>VJ00308QU?P3WZ6T0ijQY00<0ijQY0P28ICh50?FcKP05
08QU?P3e/fh0mK=^0?FcKP28ICh00`3e/fl01028ICh0mKA_0?FdK`28ICh30?BdL00308QU?P3IWV<0
R6Dn00H0dYUP0P28ICim03>QbP@0`<30;`0cXLX10?ooo`00200cXLX00`30`<00<j7:03>QbP1103>Q
bP@0R6Dn1P1ZECd00`28ICh0XgYA0:=jD@050:=jD@L0R6Dn1@2iQUL00`28ICh0`heJ08QU?P0308QU
?PD0biAN00<0R6Dn0=RMH`3HWF<02P3HWF<00`28ICh0kJe[0>f]J`040>f]J`0308QU?P3j^740n[Qa
0080n[Qa00<0R6Dn0?o4N03oa7P00P3oa7P01@28ICh0olQj0?o8NP3ob7X0R6Dn00<0olIi0P28ICh0
102mReX0R6Dn08QU?P28ICh40;^?GPX0R6Dn2P2kReX01028ICh0/X=E08QU?P28ICh;0;Z7E`0308QU
?P2lR5P0_8QH00/0_8QH00<0R6Dn0<ZCGP3:Teh01@3:Teh208QU?PH0e9YQ00D0R6Dn0>>VJ03SYVP0
hjIX08QU?P050>NXJ@0308QU?P3e/fh0mK=^00<0mK=^00D0R6Dn0?FcKP3e/fh0mK=^08QU?P030?Fc
K`0508QU?P3e]6l0mKA_0?FdK`28ICh0103d]7000`28ICh0dYUP0=:IH0040=:IH00308QU?P0cXLX0
<j7:07X0<j7:0`30`<0c03>QbP40oooo000903>QbP80`<30@P0cXLX01028ICh0b9IQ08QU?P28ICh6
06YE?@0308QU?P2SNU40XgYA00D0XgYA00<0R6Dn0;^9F@2kRET00`2kRET708QU?PX0biAN00<0R6Dn
0=RMH`3HWF<0203HWF<00`28ICh0ijUZ08QU?P040>f]J`0308QU?P3j^740n[Qa00<0n[Qa00D0R6Dn
0?o4N03oa7P0olAh08QU?P040?o8NP0308QU?P3oaWT0R6Dn0080R6Dn1@2mReX208QU?PL0^hmN0P28
ICh30:F0E@80R6Dn1`2kReX00`28ICh0/X=E0;:3E@020;:3E@80R6Dn2@2jQeL00`28ICh0_8QH0;b8
F00;0;b8F00308QU?P3:Teh0bY=N00<0bY=N0P28ICh80=BJH@0408QU?P3SYVP0hjIX08QU?PD0ijQY
0P28ICh40?FcKP0508QU?P3e/fh0mK=^0?FcKP28ICh0103e/fl01028ICh0mKA_0?FdK`28ICh40?Bd
L00308QU?P3d]700R6Dn00@0dYUP00<0R6Dn03>QbP0cXLX0M`0cXLX40<30`3H0<j7:0@3oool000/0
<j7:00<0`<3003>QbP0cXLX0?`0cXLX00`28ICh0b9IQ0<RFH@0308QU?P@0JUDm00<0R6Dn0:=jD@2S
NU401@2SNU400`28ICh0^hUI0;^9F@080;^9F@0308QU?P3;U5h0biAN00T0biAN00<0R6Dn0=RMH`3H
WF<01P3HWF<208QU?P80ijUZ00D0R6Dn0>f]J`3][F/0kJe[08QU?P050?ZhL@0308QU?P3oa7P0olAh
0080olAh00@0R6Dn0?o8NP3ob7X0olQj0`28ICh00`3DW6<0R6Dn0;f;FP070;f;FP<0R6Dn0`2kSeh2
08QU?P0307]TA@28ICh0YH1E00<0YH1E0P28ICh40;^;FP0308QU?P2bPeD0/X=E00D0/X=E0`28ICh6
0;Z7E`0308QU?P2lR5P0_8QH00/0_8QH00@0R6Dn0<ZCGP3:Teh0bY=N0P28ICh00`36T5`0R6Dn0=BJ
H@070=BJH@0308QU?P3SYVP0R6Dn00D0ijQY00@0R6Dn0>b/J`3/[6/0R6Dn0`3e/fh01@28ICh0mK=^
0?FcKP3e/fh0R6Dn00<0mK=_00@0R6Dn0?FdK`3e]6l0R6Dn103d]7001P28ICh0m;A`0?BdL03d]700
R6Dn0=:IH080R6DnM`0cXLX30<30`3X0<j7:0@3oool000`0<j7:00<0`<3003>QbP0cXLX0?`0cXLX0
1P28ICh0b9IQ0<RFH@38UV40?RhT08QU?P<0JUDm00<0R6Dn0:=jD@2SNU401P2SNU400`28ICh0^hUI
0;^9F@070;^9F@0308QU?P3;U5h0biAN00T0biAN00<0R6Dn0=RMH`3HWF<01@3HWF<00`28ICh0ijUZ
0>NYJP030>NYJP0408QU?P3][F/0kJe[08QU?PD0n[Qa00D0R6Dn0?o4N03oa7P0olAh08QU?P030?o8
NP80R6Dn0P3DW6<00`28ICh0_H]J0;f;FP0:0;f;FP<0R6Dn101kI4D208QU?P@0YH1E0P28ICh00`2k
ReX0R6Dn0;:3E@070;:3E@0308QU?P2aPE@0/H5D00@0R6Dn00<0^XMG08QU?P2lR5P03@2lR5P01028
ICh0bY=N08QU?P28ICh30<J@G00308QU?P3DVV40e9YQ00H0e9YQ0P28ICh60>NXJ@0408QU?P3/[6/0
k:a[08QU?P80mK=^00D0R6Dn0?FcKP3e/fh0mK=^08QU?P030?FcK`0408QU?P3e]6l0mKA_08QU?P@0
m;A`00<0R6Dn0?BdL03d]7000`3d]7000`28ICh0<j7:03>QbP1c03>QbP@0`<30?@0cXLX10?ooo`00
3@0cXLX00`30`<00<j7:03>QbP0n03>QbP0308QU?P38UV40b9IQ0080b9IQ00<0?RhT08QU?P1ZECd0
0P1ZECd00`28ICh0XgYA0:=jD@050:=jD@0308QU?P2kRET0^hUI00P0^hUI00<0R6Dn0<^DGP3;U5h0
203;U5h00`28ICh0f9eS0=RMH`040=RMH`0308QU?P3WZFX0ijUZ00@0ijUZ00<0R6Dn0>f]J`28ICh0
1@3j^7401@28ICh0olAh0?o4N03oa7P0R6Dn0080olQj0P28ICh40=BLH`0308QU?P2mReX0_H]J00X0
_H]J00@0R6Dn0:MmD`28ICh0R6Dn101kI4D308QU?P<0YH1E0P28ICh90;:3E@0308QU?P2aPE@0/H5D
00@0/H5D1@28ICh80;b8F0D0R6Dn1@36T5`00`28ICh0e9YQ0=BJH@060=BJH@0308QU?P3WZ6T0ijQY
00@0ijQY00L0R6Dn0>b/J`3/[6/0k:a[08QU?P3e/fh0R6Dn00@0mK=^00@0R6Dn0?FcK`3e/fl0R6Dn
0`3e]6l01@28ICh0m;A`0?BdL03d]700R6Dn00D0m;A`00<0R6Dn03>QbP0cXLX0L@0cXLX30<30`440
<j7:0@3oool000h0<j7:00<0`<3003>QbP0cXLX0?P0cXLX00`28ICh0b9IQ0<RFH@020<RFH@0503h^
9028ICh0JUDm06YE?@28ICh01`2SNU400`28ICh0^hUI0;^9F@080;^9F@0308QU?P3;U5h0biAN00P0
biAN00<0R6Dn0=RMH`3HWF<00`3HWF<00`28ICh0ijUZ0>NYJP060>NYJP80R6Dn103j^7400`28ICh0
olAh0?o4N0020?o4N0<0R6Dn1@3DW6<00`28ICh0_H]J0;f;FP0;0;f;FP0508QU?P2WOE<0YgeC0:Mm
D`28ICh0101kI4D00`28ICh0JUHm08QU?P0208QU?P80XWYA0P28ICh60;:3E@0308QU?P2aPE@0/H5D
00H0/H5D00@0R6Dn0;B3E@2dPeD0]8=E2028ICh30;^8F00308QU?P36T5`0aY1L00@0aY1L00<0R6Dn
0=BJH@3DVV401@3DVV4208QU?PD0ijQY00<0R6Dn0>b/J`3/[6/00`3/[6/208QU?P<0mK=^00D0R6Dn
0?FcK`3e/fl0mK=_08QU?P020?FdK`0508QU?P3d]700m;A`0?BdL028ICh01@3d]71a03>QbP@0`<30
A00cXLX10?ooo`003`0cXLX20<30`3h0<j7:00<0R6Dn0<RFH@38UV400`38UV40100n;R@0R6Dn08QU
?P28ICh70:=jD@0308QU?P2kRET0^hUI00P0^hUI00<0R6Dn0<^DGP3;U5h0203;U5h00`28ICh0f9eS
0=RMH`020=RMH`0308QU?P3WZFX0ijUZ00H0ijUZ00<0R6Dn0?nnMP3o_WH00P28ICh20?ZhL@0308QU
?P3oa7P0R6Dn00<0R6Dn00<05Q0:0=BLH`3DW6<0103DW6<00`28ICh0_H]J0;f;FP0:0;f;FP0308QU
?P2WOE<0YgeC00<0YgeC0P28ICh307]TA@<0R6Dn1@2RNU4208QU?P@0/X=E00<0R6Dn0;61E02aPE@0
1@2aPE@00`28ICh0]8=E0;B3E@050;B3E@0308QU?P2kR5P0^hQH00D0^hQH00<0R6Dn0<J@G036T5`0
1036T5`00`28ICh0e9YQ0=BJH@030=BJH@80R6Dn00<0f9eS08QU?P3WZ6T00`3WZ6T00`28ICh0k:a[
0>b/J`040>b/J`0508QU?P3e/fh0mK=^0?FcKP28ICh00`3e/fl01028ICh0mKA_0?FdK`28ICh30?Bd
L00308QU?P3d]700m;A`0080m;A`00<0R6Dn03>QbP0cXLX0K@0cXLX30<30`4P0<j7:0@3oool00140
<j7:00<0`<3003>QbP0cXLX0?00cXLX00`28ICh0b9IQ0<RFH@030<RFH@80?RhT0P28ICh70:=jD@03
08QU?P2kRET0^hUI00L0^hUI00<0R6Dn0<^DGP3;U5h02@3;U5h01028ICh0f9eS08QU?P28ICh80>NY
JP0308QU?P3o_WH0okif00<0okif1028ICh00`3o`gH0R6Dn01H@2P060=BLH`D0R6Dn2P2mReX00`28
ICh0YgeC0:MmD`050:MmD`0308QU?P1kI4D0NfA50080NfA50`28ICh50:9jD@80R6Dn00<0/X=E08QU
?P2aPE@01`2aPE@00`28ICh0]8=E0;B3E@050;B3E@0308QU?P2kR5P0^hQH00D0^hQH00<0R6Dn0<J@
G036T5`01036T5`00`28ICh0e9YQ0=BJH@020=BJH@0508QU?P3HWF<0f9eS0=RMH`28ICh0103WZ6T0
0`28ICh0k:a[0>b/J`030>b/J`80R6Dn0`3e/fh01028ICh0mK=_0?FcK`28ICh20?FdK`0508QU?P3d
]700m;A`0?BdL028ICh0103d]71]03>QbP@0`<30B`0cXLX10?ooo`004P0cXLX00`30`<00<j7:03>Q
bP0k03>QbP0308QU?P38UV40b9IQ00@0b9IQ0P0n;R@00`28ICh0XgYA0:=jD@050:=jD@0308QU?P2k
RET0^hUI00P0^hUI00<0R6Dn0<^DGP3;U5h0203;U5h208QU?PT0ijUZ00<0R6Dn0?nnMP3o_WH0103o
_WH01P28ICh0ol=f0?o3MP3o`gH0R6Dn01H@2P<0e9aS1028ICh503>QbPH0R6Dn0`2mReX00`28ICh0
YgeC0:MmD`070:MmD`80R6Dn0`1kI4D00`28ICh0JUHm08QU?P060:9jD@80R6Dn1`2aPE@00`28ICh0
]8=E0;B3E@050;B3E@0308QU?P2kR5P0^hQH00H0^hQH00<0R6Dn0<J@G036T5`01036T5`01@28ICh0
e9YQ0=BJH@3DVV40R6Dn00@0f9eS00D0R6Dn0>NXJ@3WZ6T0ijQY08QU?P050>b/J`0608QU?P3c/Vl0
lk9_08QU?P3e/fh0R6Dn0`3e/fl01028ICh0mKA_0?FdK`28ICh30?BdL00408QU?P3d]700m;A`08QU
?V/0<j7:0`30`<1?03>QbP40oooo000C03>QbP030<30`00cXLX0<j7:03/0<j7:00<0R6Dn0<RFH@38
UV401038UV4203h^9080R6Dn1@2SNU400`28ICh0^hUI0;^9F@080;^9F@0308QU?P3;U5h0biAN00P0
biAN00<0R6Dn0>NYJP3WZFX01`3WZFX00`28ICh0okif0?nnMP040?nnMP0608QU?P3o`gH0ol=f0?o3
MP28ICh05Q0:1028ICh903>QbP<0`<300`0cXLX508QU?PX0YgeC00L0R6Dn07]TA@1kI4D0NfA508QU
?P1ZESd0R6Dn00D0XWYA00@0R6Dn0:EjD@28ICh0R6Dn1@2aPE@00`28ICh0]8=E0;B3E@050;B3E@03
08QU?P2kR5P0^hQH00H0^hQH00<0R6Dn0<J@G036T5`01036T5`01028ICh0e9YQ08QU?P28ICh60=RM
H`0308QU?P3WZ6T0R6Dn00D0k:a[00L0R6Dn0?>bK`3c/Vl0lk9_08QU?P3e/fh0R6Dn0080mK=_00@0
R6Dn0?FdK`3e]6l0R6Dn0`3d]7001028ICh0m;A`0?BdL028ICiX03>QbP@0`<30DP0cXLX10?ooo`00
500cXLX00`30`<00<j7:03>QbP0j03>QbP0308QU?P38UV40b9IQ00D0b9IQ00<0?RhT08QU?P1kHdD0
0P28ICh30:=jD@0308QU?P2kRET0^hUI00P0^hUI00<0R6Dn0<^DGP3;U5h01P3;U5h208QU?P030=fS
I`28ICh0ijUZ00H0ijUZ00<0R6Dn0?nnMP3o_WH0103o_WH01`28ICh0ol=f0?o3MP3o`gH0R6Dn01H@
2P28ICh02P0cXLX30<30`0/0<j7:0P28ICh90:MmD`80R6Dn0P1kI4D408QU?P030:9jD@28ICh0R6Dn
00@0YGYA0P28ICh30;61E00308QU?P2dPeD0]8=E00D0]8=E00<0R6Dn0;^8F02kR5P01@2kR5P00`28
ICh0aY1L0<J@G0050<J@G080R6Dn203HWF<208QU?PH0k:a[00<0R6Dn0?>bK`3c/Vl00P3c/Vl01028
ICh0mK=_0?FcK`28ICh20?FdK`0508QU?P3d]700m;A`0?BdL028ICh00P3d]71W03>QbP<0`<30EP0c
XLX10?ooo`005@0cXLX00`30`<00<j7:03>QbP0j03>QbP0308QU?P38UV40b9IQ00D0b9IQ00@0?RhT
08QU?P1kHdD0Nf=50P28ICh20:=jD@0308QU?P2kRET0^hUI00L0^hUI00<0R6Dn0<^DGP3;U5h0103;
U5h208QU?P<0gJ=W00<0R6Dn0>NYJP3WZFX01@3WZFX00`28ICh0okif0?nnMP030?nnMP0508QU?P3o
`gH0ol=f0?o3MP28ICh02P0cXLX30<30`100<j7:0P28ICh90:MmD`L0R6Dn202UNU4308QU?PP0]8=E
00<0R6Dn0;^8F02kR5P01@2kR5P00`28ICh0aY1L0<J@G0050<J@G00308QU?P3HWF<0f9eS00L0f9eS
0P28ICh50>b/J`0308QU?P3c/Vl0lk9_0080lk9_0P28ICh01@3e/fl0R6Dn0?FdK`3e]6l0R6Dn00<0
m;A`00<0R6Dn0?BdL028ICh0I00cXLX40<30`5T0<j7:0@3oool001H0<j7:0P30`<0j03>QbP0308QU
?P38UV40b9IQ00D0b9IQ00<0R6Dn03h^9028ICh00`1kHdD308QU?PX0^hUI00@0R6Dn0<^DGP3;U5h0
biAN0P28ICh60=fSI`0308QU?P3WZFX0ijUZ00<0ijUZ00<0R6Dn0?nnMP3o_WH00`3o_WH01@28ICh0
ol=f0?o3MP3o`gH0R6Dn00L0<j7:1030`<0E03>QbP80R6Dn1P2WOE<00`28ICh0NF5407UQA00204X/
6`0408QU?P23IDH0PfE608QU?PT0YGYA0P28ICh70;B3E@0308QU?P2kR5P0^hQH00D0^hQH00<0R6Dn
0<J@G036T5`00`36T5`308QU?PT0f9eS00<0R6Dn0>b/J`3/[6/00`3/[6/00`28ICh0lk9_0?>bK`02
0?>bK`0308QU?P3m^g@0oK]d0080R6Dn0P3e]6l01@28ICh0m;A`0?BdL028ICh0m;A`06<0<j7:0`30
`<1M03>QbP40oooo000H03>QbP030<30`00cXLX0<j7:03P0<j7:00<0R6Dn0<RFH@38UV401@38UV40
0`28ICh0?RhT08QU?P0407]SA@H0R6Dn1@2kRET01028ICh0biAN08QU?P28ICh80=fSI`0308QU?P3W
ZFX0ijUZ0080ijUZ00<0R6Dn0?nnMP3o_WH0103o_WH01028ICh0ol=f0?o3MP28ICh503>QbP<0`<30
6`0cXLX208QU?P@0YgeC00@0R6Dn07UQA01iHD@0NF540P1:;1/00`28ICh0PfE608=UAP0208QU?PH0
YGYA00<0R6Dn0:eoD`2]Oe<00P28ICh40;B3E@0308QU?P2kR5P0^hQH00H0^hQH00@0R6Dn0<J@G036
T5`0aY1L0P28ICh20<RBG@0308QU?P3HWF<0f9eS00H0f9eS0P28ICh40>b/J`0308QU?P3c/Vl0lk9_
0080lk9_00D0R6Dn0?fkM03m^g@0oK]d08QU?P020?FdK`0308QU?P3d]700m;A`0080R6DnH00cXLX4
0<30`600<j7:0@3oool001T0<j7:00<0`<3003>QbP0cXLX0=`0cXLX00`28ICh0b9IQ0<RFH@030<RF
H@D0R6Dn1@1kHdD00`28ICh0aIAP0<FDH0020<FDH0L0R6Dn2`3MXfL01028ICh0ijUZ0>NYJP28ICh6
0?nnMP0408QU?P3o`gH0ol=f08QU?P<0<j7:0`30`<0P03>QbP80R6Dn00<0YgeC08QU?P1iHD@0101i
HD@01028ICh0BR`K08QU?P28ICh208=UAP0308QU?P2UNU40YGYA00<0YGYA00<0R6Dn0:eoD`2]Oe<0
0P2]Oe<308QU?P030;B3E@28ICh0^hQH00L0^hQH00@0R6Dn0<J@G028ICh0R6Dn1038TUd00`28ICh0
f9eS0=RMH`040=RMH`80R6Dn00<0gZ=V08QU?P3/[6/00P3/[6/00`28ICh0lk9_0?>bK`030?>bK`05
08QU?P3m^g@0oK]d08QU?P3oaWX00P28ICh20?BdL00308QU?P0cXLX0<j7:05d0<j7:0`30`<1T03>Q
bP40oooo000J03>QbP030<30`00cXLX0<j7:03L0<j7:1@28ICh40>>WJ@80R6Dn101kHdD00`28ICh0
aIAP0<FDH0070<FDH00308QU?P3MXfL0gJ=W00X0gJ=W00<0R6Dn0>NYJP28ICh01P3o_WH01@28ICh0
ol=f0?o3MP28ICh0<j7:00<0`<309@0cXLX308QU?PD0NF5400@0R6Dn04X/6`28ICh0R6Dn0P23IDH0
1@28ICh0YGYA0:EjD@2UNU40R6Dn00P0[GmC3028ICh60<RBG@0308QU?P3HWF<0f9eS00<0f9eS00D0
R6Dn0=jSIP3NXfH0gZ=V08QU?P020>b/J`0308QU?P3c/Vl0lk9_00<0lk9_00@0R6Dn0?fkM03m^g@0
R6Dn0P3oaWX01028ICh0nl5f08QU?P28ICiL03>QbP@0`<30I`0cXLX10?ooo`006`0cXLX00`30`<00
<j7:03>QbP0g03>QbP0308QU?P3SYfT0hjMY00L0hjMY0P28ICh307]SA@0308QU?P35U600aIAP00L0
aIAP00<0R6Dn0=fSI`3MXfL02P3MXfL208QU?PD0okif00@0R6Dn0?o3MP28ICh0R6Dn0P30`<0[03>Q
bP80R6Dn1@1iHD@00`1:;1/0R6Dn08QU?P0208=UAP80R6Dn00<0YGYA08QU?P2]Oe<0202]Oe<00`28
ICh0^HMH0;V7F0060;V7F00308QU?P38TUd0b99M00D0b99M00<0R6Dn0=RMH`3HWF<00P3HWF<00`28
ICh0gZ=V0=jSIP020=jSIP0408QU?P3/[6/0k:a[08QU?P@0lk9_00@0R6Dn0?fkM03m^g@0R6Dn0P3o
aWX01028ICh0nl5f08QU?P28ICiJ03>QbP<0`<30J`0cXLX10?ooo`00700cXLX20<30`3P0<j7:00<0
R6Dn0>>WJ@3SYfT0203SYfT01028ICh0Nf=507]SA@28ICh90<FDH00308QU?P3MXfL0gJ=W00P0gJ=W
0P28ICh20?k1N080R6Dn0P3o_WH308QU?S40<j7:0P28ICh407UQA0<0R6Dn0P23IDH208QU?PT0[GmC
00<0R6Dn0;V7F02iQeP01P2iQeP00`28ICh0b99M0<RBG@060<RBG@0508QU?P3HWF<0f9eS0=RMH`28
ICh01@3NXfH00`28ICh0k:a[08QU?P040?>bK`0908QU?P3m^g@0oK]d0?fkM028ICh0olIj08QU?P3k
`GH0R6Dn05P0<j7:1030`<1^03>QbP40oooo000N03>QbP030<30`00cXLX0<j7:03D0<j7:00<0R6Dn
0>>WJ@3SYfT02@3SYfT208QU?P0307]SA@28ICh0aIAP00P0aIAP00<0R6Dn0=fSI`3MXfL01@3MXfL2
08QU?PH0o/5h0`28IChe03>QbP80R6Dn101iHD@308QU?P80W7E>0P28ICh70:eoD`0308QU?P2iQeP0
^HMH00H0^HMH00<0R6Dn0<RBG@38TUd01P38TUd01028ICh0f9eS08QU?P28ICh60=jSIP80R6Dn103c
/Vl01P28ICh0oK]d0?fkM03m^g@0R6Dn0?o6NP<0R6DnEP0cXLX30<30`780<j7:0@3oool001l0<j7:
00<0`<3003>QbP0cXLX0=@0cXLX00`28ICh0hjMY0>>WJ@0:0>>WJ@0308QU?P1kHdD0R6Dn00P0aIAP
00<0R6Dn0=fSI`3MXfL0103MXfL00`28ICh0o/5h0?k1N0050?k1N080R6Dn>@0cXLX208QU?P<0NF54
0P28ICh409aeCP80R6Dn1@2]Oe<00`28ICh0^HMH0;V7F0060;V7F00308QU?P38TUd0b99M00H0b99M
0P28ICh80=jSIP0308QU?P3c/Vl0lk9_0080lk9_00H0R6Dn0?fkM03m^g@0oK]d08QU?P3oaWX208QU
?U@0<j7:1030`<1e03>QbP40oooo000P03>QbP030<30`00cXLX0<j7:03D0<j7:00<0R6Dn0>>WJ@3S
YfT02P3SYfT208QU?PT0aIAP00@0R6Dn0=fSI`3MXfL0gJ=W0P28ICh60?k1N080R6Dn?@0cXLX208QU
?P80NF540`28ICh409aeCP80R6Dn0`2]Oe<00`28ICh0^HMH0;V7F0060;V7F00308QU?P38TUd0b99M
00D0b99M0P28ICh80=jSIP80R6Dn0`3c/Vl01P28ICh0oK]d0?fkM03m^g@0R6Dn0?o6NP80R6DnDP0c
XLX30<30`7T0<j7:0@3oool00240<j7:00<0`<3003>QbP0cXLX0=@0cXLX00`28ICh0hjMY0>>WJ@09
0>>WJ@0308QU?P3a/6h0R6Dn00@0R6Dn1035U6001028ICh0gJ=W08QU?P28ICh60?k1N080R6Dn@@0c
XLX408QU?P0306YE?@28ICh0W7E>00@0W7E>0`28ICh80;V7F00308QU?P38TUd0b99M00<0b99M0`28
ICh00`3;UEl0R6Dn0=jSIP050=jSIP80R6Dn00<0jZe]08QU?P3c/Vl00P3c/Vl00`28ICh0oK]d0?fk
M00308QU?U00<j7:1030`<1l03>QbP40oooo000R03>QbP80`<30=@0cXLX00`28ICh0hjMY0>>WJ@08
0>>WJ@0308QU?P3a/6h0lK1^0080lK1^2`28ICh40?k1N0<0R6DnA00cXLX00`28ICh0F38O08QU?P02
08QU?PH0W7E>1@28ICh40;V7F00308QU?P38TUd0R6Dn00<0R6Dn103;UEl00`28ICh0gZ=V0=jSIP03
0=jSIP0308QU?P3Z[Fd0jZe]0080jZe]00<0R6Dn0?>bK`28ICh00P3m^g@308QU?Th0<j7:0`30`<20
03>QbP40oooo000T03>QbP030<30`00cXLX0<j7:03<0<j7:00<0R6Dn0>>WJ@3SYfT01P3SYfT00`28
ICh0lK1^0?6`KP070?6`KP`0R6DnB@0cXLX308QU?P@0W7E>00<0R6Dn0;B5E`2dQEL00`2dQEL608QU
?PP0biEO00<0R6Dn0=jSIP3NXfH00P3NXfH00`28ICh0jZe]0>Z]K@030>Z]K@80R6Dn0P3m^g@208QU
?Td0<j7:0`30`<2303>QbP40oooo000U03>QbP030<30`00cXLX0<j7:03<0<j7:00<0R6Dn0>>WJ@3S
YfT0103SYfT00`28ICh0lK1^0?6`KP080?6`KP0308QU?P3h]W00n;I`00D0n;I`00<0R6Dn0?JdL028
ICh0B`0cXLX408QU?P80W7E>00<0R6Dn0;B5E`2dQEL01`2dQEL00`28ICh0biEO0<^EG`070<^EG`05
08QU?P3NXfH0gZ=V0=jSIP28ICh01P3Z[Fd01@28ICh0oK]d0?fkM03m^g@0R6Dn04X0<j7:1030`<26
03>QbP40oooo000V03>QbP030<30`00cXLX0<j7:03<0<j7:00<0R6Dn0>>WJ@3SYfT00P3SYfT00`28
ICh0lK1^0?6`KP080?6`KP0308QU?P3h]W00n;I`00D0n;I`0`28ICi=03>QbP0306QD?028ICh0JUDm
0080R6Dn2P2dQEL00`28ICh0biEO0<^EG`070<^EG`0408QU?P3NXfH0R6Dn08QU?PD0jZe]0`28ICh2
0?fkM00308QU?P0cXLX0<j7:04H0<j7:0`30`<2:03>QbP40oooo000W03>QbP030<30`00cXLX0<j7:
0380<j7:00D0R6Dn0>>WJ@3SYfT0hjMY08QU?P0:0?6`KP0308QU?P3h]W00n;I`00D0n;I`0P28ICiA
03>QbP@0R6Dn202dQEL00`28ICh0biEO0<^EG`080<^EG`80R6Dn1P3Z[Fd01028ICh0nkeg0?^mM`3k
_GL208QU?TD0<j7:1030`<2=03>QbP40oooo000X03>QbP80`<30<`0cXLX00`28ICh0hjMY08QU?P0;
0?6`KP0308QU?P3h]W00n;I`00<0n;I`0P28ICiD03>QbP80R6Dn00@0XG]C08QU?P28ICh0R6Dn1@2d
QEL00`28ICh0biEO0<^EG`060<^EG`<0R6Dn1@3Z[Fd208QU?P<0nkeg0P28ICi303>QbP<0`<30T@0c
XLX10?ooo`00:P0cXLX00`30`<00<j7:03>QbP0a03>QbP80R6Dn2P3a/6h00`28ICh0n;I`0?RfL002
0?RfL080R6DnF00cXLX208QU?P80XG]C1028ICh0102dQEL0R6Dn0<^EG`3;UEl608QU?P80d9]T00<0
R6Dn0>Z]K@3Z[Fd00P3Z[Fd01028ICh0nkeg0?^mM`3k_GL308QU?T00<j7:1030`<2D03>QbP40oooo
000[03>QbP030<30`00cXLX0<j7:0380<j7:0`28ICh60?6`KP0308QU?P3h]W00n;I`00<0R6Dn00<0
`<3003>QbP0cXLX0F@0cXLX208QU?P@0XG]C1028ICh80=2KI00308QU?P3Z[Fd0jZe]0080R6Dn0P3k
_GL308QU?Sl0<j7:0`30`<2H03>QbP40oooo000/03>QbP030<30`00cXLX0<j7:03@0<j7:1028ICh2
0?6`KP<0R6Dn0`0cXLX00`30`<00<j7:03>QbP1K03>QbP80R6Dn0`2QNe<00`28ICh0d9]T0=2KI007
0=2KI00408QU?P3Z[Fd0jZe]08QU?P80nkeg0`28IChm03>QbP@0`<30V`0cXLX10?ooo`00;@0cXLX0
0`30`<00<j7:03>QbP0g03>QbP<0R6Dn100cXLX00`30`<00<j7:03>QbP1M03>QbP@0R6Dn2P3@Vf@3
08QU?P040?^mM`28ICh0R6Dn08QU?S`0<j7:0`30`<2O03>QbP40oooo000^03>QbP030<30`00cXLX0
<j7:03d0<j7:00<0`<3003>QbP0cXLX0G`0cXLX=08QU?P040?^mM`28ICh0R6Dn08QU?SX0<j7:1030
`<2R03>QbP40oooo000_03>QbP80`<30?@0cXLX00`30`<00<j7:03>QbP1U03>QbPP0R6Dn>P0cXLX3
0<30`:H0<j7:0@3oool00340<j7:00<0`<3003>QbP0cXLX0>P0cXLX00`30`<00<j7:03>QbP2S03>Q
bP@0`<30Z@0cXLX10?ooo`00<P0cXLX00`30`<00<j7:03>QbP0i03>QbP030<30`00cXLX0<j7:0:00
<j7:0`30`<2]03>QbP40oooo000c03>QbP030<30`00cXLX0<j7:03P0<j7:00<0`<3003>QbP0cXLX0
W00cXLX40<30`;00<j7:0@3oool003@0<j7:00<0`<3003>QbP0cXLX0=`0cXLX00`30`<00<j7:03>Q
bP2I03>QbP<0`<30]00cXLX10?ooo`00=@0cXLX20<30`3L0<j7:00<0`<3003>QbP0cXLX0U@0cXLX4
0<30`;L0<j7:0@3oool003L0<j7:00<0`<3003>QbP0cXLX0=00cXLX00`30`<00<j7:03>QbP2B03>Q
bP<0`<30^`0cXLX10?ooo`00>00cXLX00`30`<00<j7:03>QbP0c03>QbP030<30`00cXLX0<j7:08h0
<j7:1030`<2n03>QbP40oooo000i03>QbP030<30`00cXLX0<j7:0380<j7:00<0`<3003>QbP0cXLX0
R`0cXLX30<30`<80<j7:0@3oool003X0<j7:00<0`<3003>QbP0cXLX0<@0cXLX00`30`<00<j7:03>Q
bP2703>QbP@0`<30a@0cXLX10?ooo`00>`0cXLX20<30`340<j7:00<0`<3003>QbP0cXLX0Q00cXLX3
0<30`<T0<j7:0@3oool003d0<j7:00<0`<3003>QbP0cXLX0;P0cXLX00`30`<00<j7:03>QbP2003>Q
bP@0`<30c00cXLX10?ooo`00?P0cXLX00`30`<00<j7:03>QbP0]03>QbP030<30`00cXLX0<j7:07d0
<j7:0`30`<3@03>QbP40oooo000o03>QbP030<30`00cXLX0<j7:02/0<j7:00<0`<3003>QbP0cXLX0
N`0cXLX30<30`=<0<j7:0@3oool00400<j7:00<0`<3003>QbP0cXLX0:P0cXLX00`30`<00<j7:03>Q
bP1g03>QbP@0`<30eP0cXLX10?ooo`00@@0cXLX00`30`<00<j7:03>QbP0Y03>QbP030<30`00cXLX0
<j7:07@0<j7:0`30`<3J03>QbP40oooo001203>QbP80`<30:@0cXLX00`30`<00<j7:03>QbP1`03>Q
bP@0`<30g@0cXLX10?ooo`00A00cXLX00`30`<00<j7:03>QbP0V03>QbP030<30`00cXLX0<j7:06d0
<j7:0`30`<3Q03>QbP40oooo001503>QbP030<30`00cXLX0<j7:02D0<j7:00<0`<3003>QbP0cXLX0
J@0cXLX40<30`>@0<j7:0@3oool004H0<j7:00<0`<3003>QbP0cXLX0900cXLX00`30`<00<j7:03>Q
bP1V03>QbP<0`<30j00cXLX10?ooo`00A`0cXLX00`30`<00<j7:03>QbP0S03>QbP030<30`00cXLX0
<j7:0680<j7:1030`<3[03>QbP40oooo001803>QbP80`<308`0cXLX00`30`<00<j7:03>QbP1O03>Q
bP<0`<30k`0cXLX10?ooo`00BP0cXLX00`30`<00<j7:03>QbP0P03>QbP030<30`00cXLX0<j7:05/0
<j7:1030`<3b03>QbP40oooo001;03>QbP030<30`00cXLX0<j7:01l0<j7:00<0`<3003>QbP0cXLX0
F00cXLX30<30`?H0<j7:0@3oool004`0<j7:00<0`<3003>QbP0cXLX07P0cXLX00`30`<00<j7:03>Q
bP1D03>QbP@0`<30n@0cXLX10?ooo`00C@0cXLX00`30`<00<j7:03>QbP0M03>QbP030<30`00cXLX0
<j7:0540<j7:0`30`<3m03>QbP40oooo001>03>QbP80`<307@0cXLX00`30`<00<j7:03>QbP1=03>Q
bP@0`<30o`0cXLX103>QbP40oooo001@03>QbP030<30`00cXLX0<j7:01X0<j7:00<0`<3003>QbP0c
XLX0BP0cXLX30<30`?l0<j7:1@0cXLX10?ooo`00D@0cXLX00`30`<00<j7:03>QbP0H03>QbP030<30
`00cXLX0<j7:04L0<j7:1030`<3o03>QbPP0<j7:0@3oool00580<j7:00<0`<3003>QbP0cXLX05`0c
XLX00`30`<00<j7:03>QbP1403>QbP<0`<30o`0cXLX<03>QbP40oooo001C03>QbP030<30`00cXLX0
<j7:01H0<j7:00<0`<3003>QbP0cXLX0@00cXLX40<30`?l0<j7:3`0cXLX10?ooo`00E00cXLX20<30
`1H0<j7:00<0`<3003>QbP0cXLX0?@0cXLX30<30`?l0<j7:4`0cXLX10?ooo`00EP0cXLX00`30`<00
<j7:03>QbP0C03>QbP030<30`00cXLX0<j7:03T0<j7:1030`<3o03>QbQH0<j7:0@3oool005L0<j7:
00<0`<3003>QbP0cXLX04P0cXLX00`30`<00<j7:03>QbP0f03>QbP<0`<30o`0cXLXJ03>QbP40oooo
001H03>QbP030<30`00cXLX0<j7:0140<j7:00<0`<3003>QbP0cXLX0<P0cXLX40<30`?l0<j7:7@0c
XLX10?ooo`00F@0cXLX00`30`<00<j7:03>QbP0@03>QbP030<30`00cXLX0<j7:02l0<j7:0`30`<3o
03>QbR40<j7:0@3oool005X0<j7:00<0`<3003>QbP0cXLX03`0cXLX00`30`<00<j7:03>QbP0[03>Q
bP@0`<30o`0cXLXT03>QbP40oooo001K03>QbP80`<303`0cXLX00`30`<00<j7:03>QbP0X03>QbP<0
`<30o`0cXLXX03>QbP40oooo001M03>QbP030<30`00cXLX0<j7:00`0<j7:00<0`<3003>QbP0cXLX0
9@0cXLX30<30`?l0<j7::`0cXLX10?ooo`00GP0cXLX00`30`<00<j7:03>QbP0;03>QbP030<30`00c
XLX0<j7:0240<j7:1030`<3o03>QbRh0<j7:0@3oool005l0<j7:00<0`<3003>QbP0cXLX02P0cXLX0
0`30`<00<j7:03>QbP0N03>QbP<0`<30o`0cXLXb03>QbP40oooo001P03>QbP030<30`00cXLX0<j7:
00T0<j7:00<0`<3003>QbP0cXLX06P0cXLX40<30`?l0<j7:=@0cXLX10?ooo`00H@0cXLX20<30`0T0
<j7:00<0`<3003>QbP0cXLX05`0cXLX30<30`?l0<j7:>@0cXLX10?ooo`00H`0cXLX00`30`<00<j7:
03>QbP0503>QbP030<30`00cXLX0<j7:01@0<j7:1030`<3o03>QbS`0<j7:0@3oool006@0<j7:00<0
`<3003>QbP0cXLX0100cXLX00`30`<00<j7:03>QbP0A03>QbP<0`<30o`0cXLY003>QbP40oooo001U
03>QbP030<30`00cXLX0<j7:00<0<j7:00<0`<3003>QbP0cXLX03@0cXLX40<30`?l0<j7:@`0cXLX1
0?ooo`00IP0cXLX00`30`<00<j7:03>QbP0203>QbP030<30`00cXLX0<j7:00X0<j7:0`30`<3o03>Q
bTL0<j7:0@3oool006L0<j7:0P30`<0203>QbP030<30`00cXLX0<j7:00H0<j7:1030`<3o03>QbTX0
<j7:0@3oool006T0<j7:00<0`<3003>QbP30`<001@0cXLX30<30`?l0<j7:CP0cXLX10?ooo`00JP0c
XLX20<30`00303>QbP30`<00`<300080`<30o`0cXLYA03>QbP40oooo001[03>QbP80`<30o`0cXLYE
03>QbP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 449}, {279.375, 0}} -> {0.00372061, 0.16139, \
0.00222046, 0.00222046}}]
}, Open  ]],

Cell["The following creates a true star-like grid.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(grid = 
        HollisGrid[
          Table[\((1 +  .33  Cos[8  t])\) {Cos[t], Sin[t]}, {t, 0, 
              2  \[Pi], \[Pi]/8}], PlotPoints \[Rule] 64];\)\), "\n", 
    \(\(Draw2D[\[IndentingNewLine]{CadetBlue, 
          Polygon /@ grid, \[IndentingNewLine]Black, 
          Line /@ grid}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Background \[Rule] 
          Linen];\)\)}], "Input",
  CellLabel->"In[319]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.358038 0.5 0.358038 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.372 .62 .628 r
.86098 .52008 m
.90275 .5 L
.97619 .5 L
.91255 .52295 L
F
.80529 .54016 m
.86098 .52008 L
.91255 .52295 L
.84891 .5459 L
F
.74961 .56024 m
.80529 .54016 L
.84891 .5459 L
.78527 .56885 L
F
.70403 .58451 m
.74961 .56024 L
.78527 .56885 L
.72163 .5918 L
F
.7191 .6339 m
.70403 .58451 L
.72163 .5918 L
.7504 .65303 L
F
.74427 .68748 m
.7191 .6339 L
.7504 .65303 L
.77917 .71426 L
F
.76945 .74105 m
.74427 .68748 L
.77917 .71426 L
.80794 .77549 L
F
.78478 .78478 m
.76945 .74105 L
.80794 .77549 L
.83672 .83672 L
F
.74105 .76945 m
.78478 .78478 L
.83672 .83672 L
.77549 .80794 L
F
.68748 .74427 m
.74105 .76945 L
.77549 .80794 L
.71426 .77917 L
F
.6339 .7191 m
.68748 .74427 L
.71426 .77917 L
.65303 .7504 L
F
.58451 .70403 m
.6339 .7191 L
.65303 .7504 L
.5918 .72163 L
F
.56024 .74961 m
.58451 .70403 L
.5918 .72163 L
.56885 .78527 L
F
.54016 .80529 m
.56024 .74961 L
.56885 .78527 L
.5459 .84891 L
F
.52008 .86098 m
.54016 .80529 L
.5459 .84891 L
.52295 .91255 L
F
.5 .90275 m
.52008 .86098 L
.52295 .91255 L
.5 .97619 L
F
.47992 .86098 m
.5 .90275 L
.5 .97619 L
.47705 .91255 L
F
.45984 .80529 m
.47992 .86098 L
.47705 .91255 L
.4541 .84891 L
F
.43976 .74961 m
.45984 .80529 L
.4541 .84891 L
.43115 .78527 L
F
.41549 .70403 m
.43976 .74961 L
.43115 .78527 L
.4082 .72163 L
F
.3661 .7191 m
.41549 .70403 L
.4082 .72163 L
.34697 .7504 L
F
.31252 .74427 m
.3661 .7191 L
.34697 .7504 L
.28574 .77917 L
F
.25895 .76945 m
.31252 .74427 L
.28574 .77917 L
.22451 .80794 L
F
.21522 .78478 m
.25895 .76945 L
.22451 .80794 L
.16328 .83672 L
F
.23055 .74105 m
.21522 .78478 L
.16328 .83672 L
.19206 .77549 L
F
.25573 .68748 m
.23055 .74105 L
.19206 .77549 L
.22083 .71426 L
F
.2809 .6339 m
.25573 .68748 L
.22083 .71426 L
.2496 .65303 L
F
.29597 .58451 m
.2809 .6339 L
.2496 .65303 L
.27837 .5918 L
F
.25039 .56024 m
.29597 .58451 L
.27837 .5918 L
.21473 .56885 L
F
.19471 .54016 m
.25039 .56024 L
.21473 .56885 L
.15109 .5459 L
F
.13902 .52008 m
.19471 .54016 L
.15109 .5459 L
.08745 .52295 L
F
.09725 .5 m
.13902 .52008 L
.08745 .52295 L
.02381 .5 L
F
.13902 .47992 m
.09725 .5 L
.02381 .5 L
.08745 .47705 L
F
.19471 .45984 m
.13902 .47992 L
.08745 .47705 L
.15109 .4541 L
F
.25039 .43976 m
.19471 .45984 L
.15109 .4541 L
.21473 .43115 L
F
.29597 .41549 m
.25039 .43976 L
.21473 .43115 L
.27837 .4082 L
F
.2809 .3661 m
.29597 .41549 L
.27837 .4082 L
.2496 .34697 L
F
.25573 .31252 m
.2809 .3661 L
.2496 .34697 L
.22083 .28574 L
F
.23055 .25895 m
.25573 .31252 L
.22083 .28574 L
.19206 .22451 L
F
.21522 .21522 m
.23055 .25895 L
.19206 .22451 L
.16328 .16328 L
F
.25895 .23055 m
.21522 .21522 L
.16328 .16328 L
.22451 .19206 L
F
.31252 .25573 m
.25895 .23055 L
.22451 .19206 L
.28574 .22083 L
F
.3661 .2809 m
.31252 .25573 L
.28574 .22083 L
.34697 .2496 L
F
.41549 .29597 m
.3661 .2809 L
.34697 .2496 L
.4082 .27837 L
F
.43976 .25039 m
.41549 .29597 L
.4082 .27837 L
.43115 .21473 L
F
.45984 .19471 m
.43976 .25039 L
.43115 .21473 L
.4541 .15109 L
F
.47992 .13902 m
.45984 .19471 L
.4541 .15109 L
.47705 .08745 L
F
.5 .09725 m
.47992 .13902 L
.47705 .08745 L
.5 .02381 L
F
.52008 .13902 m
.5 .09725 L
.5 .02381 L
.52295 .08745 L
F
.54016 .19471 m
.52008 .13902 L
.52295 .08745 L
.5459 .15109 L
F
.56024 .25039 m
.54016 .19471 L
.5459 .15109 L
.56885 .21473 L
F
.58451 .29597 m
.56024 .25039 L
.56885 .21473 L
.5918 .27837 L
F
.6339 .2809 m
.58451 .29597 L
.5918 .27837 L
.65303 .2496 L
F
.68748 .25573 m
.6339 .2809 L
.65303 .2496 L
.71426 .22083 L
F
.74105 .23055 m
.68748 .25573 L
.71426 .22083 L
.77549 .19206 L
F
.78478 .21522 m
.74105 .23055 L
.77549 .19206 L
.83672 .16328 L
F
.76945 .25895 m
.78478 .21522 L
.83672 .16328 L
.80794 .22451 L
F
.74427 .31252 m
.76945 .25895 L
.80794 .22451 L
.77917 .28574 L
F
.7191 .3661 m
.74427 .31252 L
.77917 .28574 L
.7504 .34697 L
F
.70403 .41549 m
.7191 .3661 L
.7504 .34697 L
.72163 .4082 L
F
.74961 .43976 m
.70403 .41549 L
.72163 .4082 L
.78527 .43115 L
F
.80529 .45984 m
.74961 .43976 L
.78527 .43115 L
.84891 .4541 L
F
.86098 .47992 m
.80529 .45984 L
.84891 .4541 L
.91255 .47705 L
F
.90275 .5 m
.86098 .47992 L
.91255 .47705 L
.97619 .5 L
F
.84521 .5 m
.90275 .5 L
.86098 .52008 L
.80941 .51721 L
F
.80941 .51721 m
.86098 .52008 L
.80529 .54016 L
.76168 .53443 L
F
.76168 .53443 m
.80529 .54016 L
.74961 .56024 L
.71395 .55164 L
F
.71395 .55164 m
.74961 .56024 L
.70403 .58451 L
.67488 .57244 L
F
.67488 .57244 m
.70403 .58451 L
.7191 .6339 L
.6878 .61477 L
F
.6878 .61477 m
.7191 .6339 L
.74427 .68748 L
.70938 .66069 L
F
.70938 .66069 m
.74427 .68748 L
.76945 .74105 L
.73096 .70662 L
F
.73096 .70662 m
.76945 .74105 L
.78478 .78478 L
.7441 .7441 L
F
.7441 .7441 m
.78478 .78478 L
.74105 .76945 L
.70662 .73096 L
F
.70662 .73096 m
.74105 .76945 L
.68748 .74427 L
.66069 .70938 L
F
.66069 .70938 m
.68748 .74427 L
.6339 .7191 L
.61477 .6878 L
F
.61477 .6878 m
.6339 .7191 L
.58451 .70403 L
.57244 .67488 L
F
.57244 .67488 m
.58451 .70403 L
.56024 .74961 L
.55164 .71395 L
F
.55164 .71395 m
.56024 .74961 L
.54016 .80529 L
.53443 .76168 L
F
.53443 .76168 m
.54016 .80529 L
.52008 .86098 L
.51721 .80941 L
F
.51721 .80941 m
.52008 .86098 L
.5 .90275 L
.5 .84521 L
F
.5 .84521 m
.5 .90275 L
.47992 .86098 L
.48279 .80941 L
F
.48279 .80941 m
.47992 .86098 L
.45984 .80529 L
.46557 .76168 L
F
.46557 .76168 m
.45984 .80529 L
.43976 .74961 L
.44836 .71395 L
F
.44836 .71395 m
.43976 .74961 L
.41549 .70403 L
.42756 .67488 L
F
.42756 .67488 m
.41549 .70403 L
.3661 .7191 L
.38523 .6878 L
F
.38523 .6878 m
.3661 .7191 L
.31252 .74427 L
.33931 .70938 L
F
.33931 .70938 m
.31252 .74427 L
.25895 .76945 L
.29338 .73096 L
F
.29338 .73096 m
.25895 .76945 L
.21522 .78478 L
.2559 .7441 L
F
.2559 .7441 m
.21522 .78478 L
.23055 .74105 L
.26904 .70662 L
F
.26904 .70662 m
.23055 .74105 L
.25573 .68748 L
.29062 .66069 L
F
.29062 .66069 m
.25573 .68748 L
.2809 .6339 L
.3122 .61477 L
F
.3122 .61477 m
.2809 .6339 L
.29597 .58451 L
.32512 .57244 L
F
.32512 .57244 m
.29597 .58451 L
.25039 .56024 L
.28605 .55164 L
F
.28605 .55164 m
.25039 .56024 L
.19471 .54016 L
.23832 .53443 L
F
.23832 .53443 m
.19471 .54016 L
.13902 .52008 L
.19059 .51721 L
F
.19059 .51721 m
.13902 .52008 L
.09725 .5 L
.15479 .5 L
F
.15479 .5 m
.09725 .5 L
.13902 .47992 L
.19059 .48279 L
F
.19059 .48279 m
.13902 .47992 L
.19471 .45984 L
.23832 .46557 L
F
.23832 .46557 m
.19471 .45984 L
.25039 .43976 L
.28605 .44836 L
F
.28605 .44836 m
.25039 .43976 L
.29597 .41549 L
.32512 .42756 L
F
.32512 .42756 m
.29597 .41549 L
.2809 .3661 L
.3122 .38523 L
F
.3122 .38523 m
.2809 .3661 L
.25573 .31252 L
.29062 .33931 L
F
.29062 .33931 m
.25573 .31252 L
.23055 .25895 L
.26904 .29338 L
F
.26904 .29338 m
.23055 .25895 L
.21522 .21522 L
.2559 .2559 L
F
.2559 .2559 m
.21522 .21522 L
.25895 .23055 L
.29338 .26904 L
F
.29338 .26904 m
.25895 .23055 L
.31252 .25573 L
.33931 .29062 L
F
.33931 .29062 m
.31252 .25573 L
.3661 .2809 L
.38523 .3122 L
F
.38523 .3122 m
.3661 .2809 L
.41549 .29597 L
.42756 .32512 L
F
.42756 .32512 m
.41549 .29597 L
.43976 .25039 L
.44836 .28605 L
F
.44836 .28605 m
.43976 .25039 L
.45984 .19471 L
.46557 .23832 L
F
.46557 .23832 m
.45984 .19471 L
.47992 .13902 L
.48279 .19059 L
F
.48279 .19059 m
.47992 .13902 L
.5 .09725 L
.5 .15479 L
F
.5 .15479 m
.5 .09725 L
.52008 .13902 L
.51721 .19059 L
F
.51721 .19059 m
.52008 .13902 L
.54016 .19471 L
.53443 .23832 L
F
.53443 .23832 m
.54016 .19471 L
.56024 .25039 L
.55164 .28605 L
F
.55164 .28605 m
.56024 .25039 L
.58451 .29597 L
.57244 .32512 L
F
.57244 .32512 m
.58451 .29597 L
.6339 .2809 L
.61477 .3122 L
F
.61477 .3122 m
.6339 .2809 L
.68748 .25573 L
.66069 .29062 L
F
.66069 .29062 m
.68748 .25573 L
.74105 .23055 L
.70662 .26904 L
F
.70662 .26904 m
.74105 .23055 L
.78478 .21522 L
.7441 .2559 L
F
.7441 .2559 m
.78478 .21522 L
.76945 .25895 L
.73096 .29338 L
F
.73096 .29338 m
.76945 .25895 L
.74427 .31252 L
.70938 .33931 L
F
.70938 .33931 m
.74427 .31252 L
.7191 .3661 L
.6878 .38523 L
F
.6878 .38523 m
.7191 .3661 L
.70403 .41549 L
.67488 .42756 L
F
.67488 .42756 m
.70403 .41549 L
.74961 .43976 L
.71395 .44836 L
F
.71395 .44836 m
.74961 .43976 L
.80529 .45984 L
.76168 .46557 L
F
.76168 .46557 m
.80529 .45984 L
.86098 .47992 L
.80941 .48279 L
F
.80941 .48279 m
.86098 .47992 L
.90275 .5 L
.84521 .5 L
F
.78768 .5 m
.84521 .5 L
.80941 .51721 L
.75784 .51434 L
F
.75784 .51434 m
.80941 .51721 L
.76168 .53443 L
.71807 .52869 L
F
.71807 .52869 m
.76168 .53443 L
.71395 .55164 L
.67829 .54303 L
F
.67829 .54303 m
.71395 .55164 L
.67488 .57244 L
.64574 .56037 L
F
.64574 .56037 m
.67488 .57244 L
.6878 .61477 L
.6565 .59564 L
F
.6565 .59564 m
.6878 .61477 L
.70938 .66069 L
.67448 .63391 L
F
.67448 .63391 m
.70938 .66069 L
.73096 .70662 L
.69247 .67218 L
F
.69247 .67218 m
.73096 .70662 L
.7441 .7441 L
.70342 .70342 L
F
.70342 .70342 m
.7441 .7441 L
.70662 .73096 L
.67218 .69247 L
F
.67218 .69247 m
.70662 .73096 L
.66069 .70938 L
.63391 .67448 L
F
.63391 .67448 m
.66069 .70938 L
.61477 .6878 L
.59564 .6565 L
F
.59564 .6565 m
.61477 .6878 L
.57244 .67488 L
.56037 .64574 L
F
.56037 .64574 m
.57244 .67488 L
.55164 .71395 L
.54303 .67829 L
F
.54303 .67829 m
.55164 .71395 L
.53443 .76168 L
.52869 .71807 L
F
.52869 .71807 m
.53443 .76168 L
.51721 .80941 L
.51434 .75784 L
F
.51434 .75784 m
.51721 .80941 L
.5 .84521 L
.5 .78768 L
F
.5 .78768 m
.5 .84521 L
.48279 .80941 L
.48566 .75784 L
F
.48566 .75784 m
.48279 .80941 L
.46557 .76168 L
.47131 .71807 L
F
.47131 .71807 m
.46557 .76168 L
.44836 .71395 L
.45697 .67829 L
F
.45697 .67829 m
.44836 .71395 L
.42756 .67488 L
.43963 .64574 L
F
.43963 .64574 m
.42756 .67488 L
.38523 .6878 L
.40436 .6565 L
F
.40436 .6565 m
.38523 .6878 L
.33931 .70938 L
.36609 .67448 L
F
.36609 .67448 m
.33931 .70938 L
.29338 .73096 L
.32782 .69247 L
F
.32782 .69247 m
.29338 .73096 L
.2559 .7441 L
.29658 .70342 L
F
.29658 .70342 m
.2559 .7441 L
.26904 .70662 L
.30753 .67218 L
F
.30753 .67218 m
.26904 .70662 L
.29062 .66069 L
.32552 .63391 L
F
.32552 .63391 m
.29062 .66069 L
.3122 .61477 L
.3435 .59564 L
F
.3435 .59564 m
.3122 .61477 L
.32512 .57244 L
.35426 .56037 L
F
.35426 .56037 m
.32512 .57244 L
.28605 .55164 L
.32171 .54303 L
F
.32171 .54303 m
.28605 .55164 L
.23832 .53443 L
.28193 .52869 L
F
.28193 .52869 m
.23832 .53443 L
.19059 .51721 L
.24216 .51434 L
F
.24216 .51434 m
.19059 .51721 L
.15479 .5 L
.21232 .5 L
F
.21232 .5 m
.15479 .5 L
.19059 .48279 L
.24216 .48566 L
F
.24216 .48566 m
.19059 .48279 L
.23832 .46557 L
.28193 .47131 L
F
.28193 .47131 m
.23832 .46557 L
.28605 .44836 L
.32171 .45697 L
F
.32171 .45697 m
.28605 .44836 L
.32512 .42756 L
.35426 .43963 L
F
.35426 .43963 m
.32512 .42756 L
.3122 .38523 L
.3435 .40436 L
F
.3435 .40436 m
.3122 .38523 L
.29062 .33931 L
.32552 .36609 L
F
.32552 .36609 m
.29062 .33931 L
.26904 .29338 L
.30753 .32782 L
F
.30753 .32782 m
.26904 .29338 L
.2559 .2559 L
.29658 .29658 L
F
.29658 .29658 m
.2559 .2559 L
.29338 .26904 L
.32782 .30753 L
F
.32782 .30753 m
.29338 .26904 L
.33931 .29062 L
.36609 .32552 L
F
.36609 .32552 m
.33931 .29062 L
.38523 .3122 L
.40436 .3435 L
F
.40436 .3435 m
.38523 .3122 L
.42756 .32512 L
.43963 .35426 L
F
.43963 .35426 m
.42756 .32512 L
.44836 .28605 L
.45697 .32171 L
F
.45697 .32171 m
.44836 .28605 L
.46557 .23832 L
.47131 .28193 L
F
.47131 .28193 m
.46557 .23832 L
.48279 .19059 L
.48566 .24216 L
F
.48566 .24216 m
.48279 .19059 L
.5 .15479 L
.5 .21232 L
F
.5 .21232 m
.5 .15479 L
.51721 .19059 L
.51434 .24216 L
F
.51434 .24216 m
.51721 .19059 L
.53443 .23832 L
.52869 .28193 L
F
.52869 .28193 m
.53443 .23832 L
.55164 .28605 L
.54303 .32171 L
F
.54303 .32171 m
.55164 .28605 L
.57244 .32512 L
.56037 .35426 L
F
.56037 .35426 m
.57244 .32512 L
.61477 .3122 L
.59564 .3435 L
F
.59564 .3435 m
.61477 .3122 L
.66069 .29062 L
.63391 .32552 L
F
.63391 .32552 m
.66069 .29062 L
.70662 .26904 L
.67218 .30753 L
F
.67218 .30753 m
.70662 .26904 L
.7441 .2559 L
.70342 .29658 L
F
.70342 .29658 m
.7441 .2559 L
.73096 .29338 L
.69247 .32782 L
F
.69247 .32782 m
.73096 .29338 L
.70938 .33931 L
.67448 .36609 L
F
.67448 .36609 m
.70938 .33931 L
.6878 .38523 L
.6565 .40436 L
F
.6565 .40436 m
.6878 .38523 L
.67488 .42756 L
.64574 .43963 L
F
.64574 .43963 m
.67488 .42756 L
.71395 .44836 L
.67829 .45697 L
F
.67829 .45697 m
.71395 .44836 L
.76168 .46557 L
.71807 .47131 L
F
.71807 .47131 m
.76168 .46557 L
.80941 .48279 L
.75784 .48566 L
F
.75784 .48566 m
.80941 .48279 L
.84521 .5 L
.78768 .5 L
F
.73014 .5 m
.78768 .5 L
.75784 .51434 L
.70627 .51148 L
F
.70627 .51148 m
.75784 .51434 L
.71807 .52869 L
.67445 .52295 L
F
.67445 .52295 m
.71807 .52869 L
.67829 .54303 L
.64263 .53443 L
F
.64263 .53443 m
.67829 .54303 L
.64574 .56037 L
.61659 .54829 L
F
.61659 .54829 m
.64574 .56037 L
.6565 .59564 L
.6252 .57651 L
F
.6252 .57651 m
.6565 .59564 L
.67448 .63391 L
.63959 .60713 L
F
.63959 .60713 m
.67448 .63391 L
.69247 .67218 L
.65397 .63774 L
F
.65397 .63774 m
.69247 .67218 L
.70342 .70342 L
.66273 .66273 L
F
.66273 .66273 m
.70342 .70342 L
.67218 .69247 L
.63774 .65397 L
F
.63774 .65397 m
.67218 .69247 L
.63391 .67448 L
.60713 .63959 L
F
.60713 .63959 m
.63391 .67448 L
.59564 .6565 L
.57651 .6252 L
F
.57651 .6252 m
.59564 .6565 L
.56037 .64574 L
.54829 .61659 L
F
.54829 .61659 m
.56037 .64574 L
.54303 .67829 L
.53443 .64263 L
F
.53443 .64263 m
.54303 .67829 L
.52869 .71807 L
.52295 .67445 L
F
.52295 .67445 m
.52869 .71807 L
.51434 .75784 L
.51148 .70627 L
F
.51148 .70627 m
.51434 .75784 L
.5 .78768 L
.5 .73014 L
F
.5 .73014 m
.5 .78768 L
.48566 .75784 L
.48852 .70627 L
F
.48852 .70627 m
.48566 .75784 L
.47131 .71807 L
.47705 .67445 L
F
.47705 .67445 m
.47131 .71807 L
.45697 .67829 L
.46557 .64263 L
F
.46557 .64263 m
.45697 .67829 L
.43963 .64574 L
.45171 .61659 L
F
.45171 .61659 m
.43963 .64574 L
.40436 .6565 L
.42349 .6252 L
F
.42349 .6252 m
.40436 .6565 L
.36609 .67448 L
.39287 .63959 L
F
.39287 .63959 m
.36609 .67448 L
.32782 .69247 L
.36226 .65397 L
F
.36226 .65397 m
.32782 .69247 L
.29658 .70342 L
.33727 .66273 L
F
.33727 .66273 m
.29658 .70342 L
.30753 .67218 L
.34603 .63774 L
F
.34603 .63774 m
.30753 .67218 L
.32552 .63391 L
.36041 .60713 L
F
.36041 .60713 m
.32552 .63391 L
.3435 .59564 L
.3748 .57651 L
F
.3748 .57651 m
.3435 .59564 L
.35426 .56037 L
.38341 .54829 L
F
.38341 .54829 m
.35426 .56037 L
.32171 .54303 L
.35737 .53443 L
F
.35737 .53443 m
.32171 .54303 L
.28193 .52869 L
.32555 .52295 L
F
.32555 .52295 m
.28193 .52869 L
.24216 .51434 L
.29373 .51148 L
F
.29373 .51148 m
.24216 .51434 L
.21232 .5 L
.26986 .5 L
F
.26986 .5 m
.21232 .5 L
.24216 .48566 L
.29373 .48852 L
F
.29373 .48852 m
.24216 .48566 L
.28193 .47131 L
.32555 .47705 L
F
.32555 .47705 m
.28193 .47131 L
.32171 .45697 L
.35737 .46557 L
F
.35737 .46557 m
.32171 .45697 L
.35426 .43963 L
.38341 .45171 L
F
.38341 .45171 m
.35426 .43963 L
.3435 .40436 L
.3748 .42349 L
F
.3748 .42349 m
.3435 .40436 L
.32552 .36609 L
.36041 .39287 L
F
.36041 .39287 m
.32552 .36609 L
.30753 .32782 L
.34603 .36226 L
F
.34603 .36226 m
.30753 .32782 L
.29658 .29658 L
.33727 .33727 L
F
.33727 .33727 m
.29658 .29658 L
.32782 .30753 L
.36226 .34603 L
F
.36226 .34603 m
.32782 .30753 L
.36609 .32552 L
.39287 .36041 L
F
.39287 .36041 m
.36609 .32552 L
.40436 .3435 L
.42349 .3748 L
F
.42349 .3748 m
.40436 .3435 L
.43963 .35426 L
.45171 .38341 L
F
.45171 .38341 m
.43963 .35426 L
.45697 .32171 L
.46557 .35737 L
F
.46557 .35737 m
.45697 .32171 L
.47131 .28193 L
.47705 .32555 L
F
.47705 .32555 m
.47131 .28193 L
.48566 .24216 L
.48852 .29373 L
F
.48852 .29373 m
.48566 .24216 L
.5 .21232 L
.5 .26986 L
F
.5 .26986 m
.5 .21232 L
.51434 .24216 L
.51148 .29373 L
F
.51148 .29373 m
.51434 .24216 L
.52869 .28193 L
.52295 .32555 L
F
.52295 .32555 m
.52869 .28193 L
.54303 .32171 L
.53443 .35737 L
F
.53443 .35737 m
.54303 .32171 L
.56037 .35426 L
.54829 .38341 L
F
.54829 .38341 m
.56037 .35426 L
.59564 .3435 L
.57651 .3748 L
F
.57651 .3748 m
.59564 .3435 L
.63391 .32552 L
.60713 .36041 L
F
.60713 .36041 m
.63391 .32552 L
.67218 .30753 L
.63774 .34603 L
F
.63774 .34603 m
.67218 .30753 L
.70342 .29658 L
.66273 .33727 L
F
.66273 .33727 m
.70342 .29658 L
.69247 .32782 L
.65397 .36226 L
F
.65397 .36226 m
.69247 .32782 L
.67448 .36609 L
.63959 .39287 L
F
.63959 .39287 m
.67448 .36609 L
.6565 .40436 L
.6252 .42349 L
F
.6252 .42349 m
.6565 .40436 L
.64574 .43963 L
.61659 .45171 L
F
.61659 .45171 m
.64574 .43963 L
.67829 .45697 L
.64263 .46557 L
F
.64263 .46557 m
.67829 .45697 L
.71807 .47131 L
.67445 .47705 L
F
.67445 .47705 m
.71807 .47131 L
.75784 .48566 L
.70627 .48852 L
F
.70627 .48852 m
.75784 .48566 L
.78768 .5 L
.73014 .5 L
F
.63084 .51721 m
.66366 .5 L
.73014 .5 L
.70627 .51148 L
.67445 .52295 L
F
.59394 .53891 m
.63084 .51721 L
.67445 .52295 L
.64263 .53443 L
.61659 .54829 L
F
.60469 .58035 m
.59394 .53891 L
.61659 .54829 L
.6252 .57651 L
.63959 .60713 L
F
.61572 .61572 m
.60469 .58035 L
.63959 .60713 L
.65397 .63774 L
.66273 .66273 L
F
.58035 .60469 m
.61572 .61572 L
.66273 .66273 L
.63774 .65397 L
.60713 .63959 L
F
.53891 .59394 m
.58035 .60469 L
.60713 .63959 L
.57651 .6252 L
.54829 .61659 L
F
.51721 .63084 m
.53891 .59394 L
.54829 .61659 L
.53443 .64263 L
.52295 .67445 L
F
.5 .66366 m
.51721 .63084 L
.52295 .67445 L
.51148 .70627 L
.5 .73014 L
F
.48279 .63084 m
.5 .66366 L
.5 .73014 L
.48852 .70627 L
.47705 .67445 L
F
.46109 .59394 m
.48279 .63084 L
.47705 .67445 L
.46557 .64263 L
.45171 .61659 L
F
.41965 .60469 m
.46109 .59394 L
.45171 .61659 L
.42349 .6252 L
.39287 .63959 L
F
.38428 .61572 m
.41965 .60469 L
.39287 .63959 L
.36226 .65397 L
.33727 .66273 L
F
.39531 .58035 m
.38428 .61572 L
.33727 .66273 L
.34603 .63774 L
.36041 .60713 L
F
.40606 .53891 m
.39531 .58035 L
.36041 .60713 L
.3748 .57651 L
.38341 .54829 L
F
.36916 .51721 m
.40606 .53891 L
.38341 .54829 L
.35737 .53443 L
.32555 .52295 L
F
.33634 .5 m
.36916 .51721 L
.32555 .52295 L
.29373 .51148 L
.26986 .5 L
F
.36916 .48279 m
.33634 .5 L
.26986 .5 L
.29373 .48852 L
.32555 .47705 L
F
.40606 .46109 m
.36916 .48279 L
.32555 .47705 L
.35737 .46557 L
.38341 .45171 L
F
.39531 .41965 m
.40606 .46109 L
.38341 .45171 L
.3748 .42349 L
.36041 .39287 L
F
.38428 .38428 m
.39531 .41965 L
.36041 .39287 L
.34603 .36226 L
.33727 .33727 L
F
.41965 .39531 m
.38428 .38428 L
.33727 .33727 L
.36226 .34603 L
.39287 .36041 L
F
.46109 .40606 m
.41965 .39531 L
.39287 .36041 L
.42349 .3748 L
.45171 .38341 L
F
.48279 .36916 m
.46109 .40606 L
.45171 .38341 L
.46557 .35737 L
.47705 .32555 L
F
.5 .33634 m
.48279 .36916 L
.47705 .32555 L
.48852 .29373 L
.5 .26986 L
F
.51721 .36916 m
.5 .33634 L
.5 .26986 L
.51148 .29373 L
.52295 .32555 L
F
.53891 .40606 m
.51721 .36916 L
.52295 .32555 L
.53443 .35737 L
.54829 .38341 L
F
.58035 .39531 m
.53891 .40606 L
.54829 .38341 L
.57651 .3748 L
.60713 .36041 L
F
.61572 .38428 m
.58035 .39531 L
.60713 .36041 L
.63774 .34603 L
.66273 .33727 L
F
.60469 .41965 m
.61572 .38428 L
.66273 .33727 L
.65397 .36226 L
.63959 .39287 L
F
.59394 .46109 m
.60469 .41965 L
.63959 .39287 L
.6252 .42349 L
.61659 .45171 L
F
.63084 .48279 m
.59394 .46109 L
.61659 .45171 L
.64263 .46557 L
.67445 .47705 L
F
.66366 .5 m
.63084 .48279 L
.67445 .47705 L
.70627 .48852 L
.73014 .5 L
F
.6091 .5 m
.66366 .5 L
.63084 .51721 L
.58723 .51148 L
F
.58723 .51148 m
.63084 .51721 L
.59394 .53891 L
.56263 .52594 L
F
.56263 .52594 m
.59394 .53891 L
.60469 .58035 L
.56979 .55356 L
F
.56979 .55356 m
.60469 .58035 L
.61572 .61572 L
.57715 .57715 L
F
.57715 .57715 m
.61572 .61572 L
.58035 .60469 L
.55356 .56979 L
F
.55356 .56979 m
.58035 .60469 L
.53891 .59394 L
.52594 .56263 L
F
.52594 .56263 m
.53891 .59394 L
.51721 .63084 L
.51148 .58723 L
F
.51148 .58723 m
.51721 .63084 L
.5 .66366 L
.5 .6091 L
F
.5 .6091 m
.5 .66366 L
.48279 .63084 L
.48852 .58723 L
F
.48852 .58723 m
.48279 .63084 L
.46109 .59394 L
.47406 .56263 L
F
.47406 .56263 m
.46109 .59394 L
.41965 .60469 L
.44644 .56979 L
F
.44644 .56979 m
.41965 .60469 L
.38428 .61572 L
.42285 .57715 L
F
.42285 .57715 m
.38428 .61572 L
.39531 .58035 L
.43021 .55356 L
F
.43021 .55356 m
.39531 .58035 L
.40606 .53891 L
.43737 .52594 L
F
.43737 .52594 m
.40606 .53891 L
.36916 .51721 L
.41277 .51148 L
F
.41277 .51148 m
.36916 .51721 L
.33634 .5 L
.3909 .5 L
F
.3909 .5 m
.33634 .5 L
.36916 .48279 L
.41277 .48852 L
F
.41277 .48852 m
.36916 .48279 L
.40606 .46109 L
.43737 .47406 L
F
.43737 .47406 m
.40606 .46109 L
.39531 .41965 L
.43021 .44644 L
F
.43021 .44644 m
.39531 .41965 L
.38428 .38428 L
.42285 .42285 L
F
.42285 .42285 m
.38428 .38428 L
.41965 .39531 L
.44644 .43021 L
F
.44644 .43021 m
.41965 .39531 L
.46109 .40606 L
.47406 .43737 L
F
.47406 .43737 m
.46109 .40606 L
.48279 .36916 L
.48852 .41277 L
F
.48852 .41277 m
.48279 .36916 L
.5 .33634 L
.5 .3909 L
F
.5 .3909 m
.5 .33634 L
.51721 .36916 L
.51148 .41277 L
F
.51148 .41277 m
.51721 .36916 L
.53891 .40606 L
.52594 .43737 L
F
.52594 .43737 m
.53891 .40606 L
.58035 .39531 L
.55356 .43021 L
F
.55356 .43021 m
.58035 .39531 L
.61572 .38428 L
.57715 .42285 L
F
.57715 .42285 m
.61572 .38428 L
.60469 .41965 L
.56979 .44644 L
F
.56979 .44644 m
.60469 .41965 L
.59394 .46109 L
.56263 .47406 L
F
.56263 .47406 m
.59394 .46109 L
.63084 .48279 L
.58723 .48852 L
F
.58723 .48852 m
.63084 .48279 L
.66366 .5 L
.6091 .5 L
F
.53528 .51462 m
.54908 .5 L
.6091 .5 L
.58723 .51148 L
.56263 .52594 L
F
.53471 .53471 m
.53528 .51462 L
.56263 .52594 L
.56979 .55356 L
.57715 .57715 L
F
.51462 .53528 m
.53471 .53471 L
.57715 .57715 L
.55356 .56979 L
.52594 .56263 L
F
.5 .54908 m
.51462 .53528 L
.52594 .56263 L
.51148 .58723 L
.5 .6091 L
F
.48538 .53528 m
.5 .54908 L
.5 .6091 L
.48852 .58723 L
.47406 .56263 L
F
.46529 .53471 m
.48538 .53528 L
.47406 .56263 L
.44644 .56979 L
.42285 .57715 L
F
.46472 .51462 m
.46529 .53471 L
.42285 .57715 L
.43021 .55356 L
.43737 .52594 L
F
.45092 .5 m
.46472 .51462 L
.43737 .52594 L
.41277 .51148 L
.3909 .5 L
F
.46472 .48538 m
.45092 .5 L
.3909 .5 L
.41277 .48852 L
.43737 .47406 L
F
.46529 .46529 m
.46472 .48538 L
.43737 .47406 L
.43021 .44644 L
.42285 .42285 L
F
.48538 .46472 m
.46529 .46529 L
.42285 .42285 L
.44644 .43021 L
.47406 .43737 L
F
.5 .45092 m
.48538 .46472 L
.47406 .43737 L
.48852 .41277 L
.5 .3909 L
F
.51462 .46472 m
.5 .45092 L
.5 .3909 L
.51148 .41277 L
.52594 .43737 L
F
.53471 .46529 m
.51462 .46472 L
.52594 .43737 L
.55356 .43021 L
.57715 .42285 L
F
.53528 .48538 m
.53471 .46529 L
.57715 .42285 L
.56979 .44644 L
.56263 .47406 L
F
.54908 .5 m
.53528 .48538 L
.56263 .47406 L
.58723 .48852 L
.6091 .5 L
F
.5 .5 m
.5 .5 L
.54908 .5 L
.53528 .51462 L
.53471 .53471 L
F
.5 .5 m
.5 .5 L
.53471 .53471 L
.51462 .53528 L
.5 .54908 L
F
.5 .5 m
.5 .5 L
.5 .54908 L
.48538 .53528 L
.46529 .53471 L
F
.5 .5 m
.5 .5 L
.46529 .53471 L
.46472 .51462 L
.45092 .5 L
F
.5 .5 m
.5 .5 L
.45092 .5 L
.46472 .48538 L
.46529 .46529 L
F
.5 .5 m
.5 .5 L
.46529 .46529 L
.48538 .46472 L
.5 .45092 L
F
.5 .5 m
.5 .5 L
.5 .45092 L
.51462 .46472 L
.53471 .46529 L
F
.5 .5 m
.5 .5 L
.53471 .46529 L
.53528 .48538 L
.54908 .5 L
F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
.86098 .52008 m
.90275 .5 L
.97619 .5 L
.91255 .52295 L
s
.80529 .54016 m
.86098 .52008 L
.91255 .52295 L
.84891 .5459 L
s
.74961 .56024 m
.80529 .54016 L
.84891 .5459 L
.78527 .56885 L
s
.70403 .58451 m
.74961 .56024 L
.78527 .56885 L
.72163 .5918 L
s
.7191 .6339 m
.70403 .58451 L
.72163 .5918 L
.7504 .65303 L
s
.74427 .68748 m
.7191 .6339 L
.7504 .65303 L
.77917 .71426 L
s
.76945 .74105 m
.74427 .68748 L
.77917 .71426 L
.80794 .77549 L
s
.78478 .78478 m
.76945 .74105 L
.80794 .77549 L
.83672 .83672 L
s
.74105 .76945 m
.78478 .78478 L
.83672 .83672 L
.77549 .80794 L
s
.68748 .74427 m
.74105 .76945 L
.77549 .80794 L
.71426 .77917 L
s
.6339 .7191 m
.68748 .74427 L
.71426 .77917 L
.65303 .7504 L
s
.58451 .70403 m
.6339 .7191 L
.65303 .7504 L
.5918 .72163 L
s
.56024 .74961 m
.58451 .70403 L
.5918 .72163 L
.56885 .78527 L
s
.54016 .80529 m
.56024 .74961 L
.56885 .78527 L
.5459 .84891 L
s
.52008 .86098 m
.54016 .80529 L
.5459 .84891 L
.52295 .91255 L
s
.5 .90275 m
.52008 .86098 L
.52295 .91255 L
.5 .97619 L
s
.47992 .86098 m
.5 .90275 L
.5 .97619 L
.47705 .91255 L
s
.45984 .80529 m
.47992 .86098 L
.47705 .91255 L
.4541 .84891 L
s
.43976 .74961 m
.45984 .80529 L
.4541 .84891 L
.43115 .78527 L
s
.41549 .70403 m
.43976 .74961 L
.43115 .78527 L
.4082 .72163 L
s
.3661 .7191 m
.41549 .70403 L
.4082 .72163 L
.34697 .7504 L
s
.31252 .74427 m
.3661 .7191 L
.34697 .7504 L
.28574 .77917 L
s
.25895 .76945 m
.31252 .74427 L
.28574 .77917 L
.22451 .80794 L
s
.21522 .78478 m
.25895 .76945 L
.22451 .80794 L
.16328 .83672 L
s
.23055 .74105 m
.21522 .78478 L
.16328 .83672 L
.19206 .77549 L
s
.25573 .68748 m
.23055 .74105 L
.19206 .77549 L
.22083 .71426 L
s
.2809 .6339 m
.25573 .68748 L
.22083 .71426 L
.2496 .65303 L
s
.29597 .58451 m
.2809 .6339 L
.2496 .65303 L
.27837 .5918 L
s
.25039 .56024 m
.29597 .58451 L
.27837 .5918 L
.21473 .56885 L
s
.19471 .54016 m
.25039 .56024 L
.21473 .56885 L
.15109 .5459 L
s
.13902 .52008 m
.19471 .54016 L
.15109 .5459 L
.08745 .52295 L
s
.09725 .5 m
.13902 .52008 L
.08745 .52295 L
.02381 .5 L
s
.13902 .47992 m
.09725 .5 L
.02381 .5 L
.08745 .47705 L
s
.19471 .45984 m
.13902 .47992 L
.08745 .47705 L
.15109 .4541 L
s
.25039 .43976 m
.19471 .45984 L
.15109 .4541 L
.21473 .43115 L
s
.29597 .41549 m
.25039 .43976 L
.21473 .43115 L
.27837 .4082 L
s
.2809 .3661 m
.29597 .41549 L
.27837 .4082 L
.2496 .34697 L
s
.25573 .31252 m
.2809 .3661 L
.2496 .34697 L
.22083 .28574 L
s
.23055 .25895 m
.25573 .31252 L
.22083 .28574 L
.19206 .22451 L
s
.21522 .21522 m
.23055 .25895 L
.19206 .22451 L
.16328 .16328 L
s
.25895 .23055 m
.21522 .21522 L
.16328 .16328 L
.22451 .19206 L
s
.31252 .25573 m
.25895 .23055 L
.22451 .19206 L
.28574 .22083 L
s
.3661 .2809 m
.31252 .25573 L
.28574 .22083 L
.34697 .2496 L
s
.41549 .29597 m
.3661 .2809 L
.34697 .2496 L
.4082 .27837 L
s
.43976 .25039 m
.41549 .29597 L
.4082 .27837 L
.43115 .21473 L
s
.45984 .19471 m
.43976 .25039 L
.43115 .21473 L
.4541 .15109 L
s
.47992 .13902 m
.45984 .19471 L
.4541 .15109 L
.47705 .08745 L
s
.5 .09725 m
.47992 .13902 L
.47705 .08745 L
.5 .02381 L
s
.52008 .13902 m
.5 .09725 L
.5 .02381 L
.52295 .08745 L
s
.54016 .19471 m
.52008 .13902 L
.52295 .08745 L
.5459 .15109 L
s
.56024 .25039 m
.54016 .19471 L
.5459 .15109 L
.56885 .21473 L
s
.58451 .29597 m
.56024 .25039 L
.56885 .21473 L
.5918 .27837 L
s
.6339 .2809 m
.58451 .29597 L
.5918 .27837 L
.65303 .2496 L
s
.68748 .25573 m
.6339 .2809 L
.65303 .2496 L
.71426 .22083 L
s
.74105 .23055 m
.68748 .25573 L
.71426 .22083 L
.77549 .19206 L
s
.78478 .21522 m
.74105 .23055 L
.77549 .19206 L
.83672 .16328 L
s
.76945 .25895 m
.78478 .21522 L
.83672 .16328 L
.80794 .22451 L
s
.74427 .31252 m
.76945 .25895 L
.80794 .22451 L
.77917 .28574 L
s
.7191 .3661 m
.74427 .31252 L
.77917 .28574 L
.7504 .34697 L
s
.70403 .41549 m
.7191 .3661 L
.7504 .34697 L
.72163 .4082 L
s
.74961 .43976 m
.70403 .41549 L
.72163 .4082 L
.78527 .43115 L
s
.80529 .45984 m
.74961 .43976 L
.78527 .43115 L
.84891 .4541 L
s
.86098 .47992 m
.80529 .45984 L
.84891 .4541 L
.91255 .47705 L
s
.90275 .5 m
.86098 .47992 L
.91255 .47705 L
.97619 .5 L
s
.84521 .5 m
.90275 .5 L
.86098 .52008 L
.80941 .51721 L
s
.80941 .51721 m
.86098 .52008 L
.80529 .54016 L
.76168 .53443 L
s
.76168 .53443 m
.80529 .54016 L
.74961 .56024 L
.71395 .55164 L
s
.71395 .55164 m
.74961 .56024 L
.70403 .58451 L
.67488 .57244 L
s
.67488 .57244 m
.70403 .58451 L
.7191 .6339 L
.6878 .61477 L
s
.6878 .61477 m
.7191 .6339 L
.74427 .68748 L
.70938 .66069 L
s
.70938 .66069 m
.74427 .68748 L
.76945 .74105 L
.73096 .70662 L
s
.73096 .70662 m
.76945 .74105 L
.78478 .78478 L
.7441 .7441 L
s
.7441 .7441 m
.78478 .78478 L
.74105 .76945 L
.70662 .73096 L
s
.70662 .73096 m
.74105 .76945 L
.68748 .74427 L
.66069 .70938 L
s
.66069 .70938 m
.68748 .74427 L
.6339 .7191 L
.61477 .6878 L
s
.61477 .6878 m
.6339 .7191 L
.58451 .70403 L
.57244 .67488 L
s
.57244 .67488 m
.58451 .70403 L
.56024 .74961 L
.55164 .71395 L
s
.55164 .71395 m
.56024 .74961 L
.54016 .80529 L
.53443 .76168 L
s
.53443 .76168 m
.54016 .80529 L
.52008 .86098 L
.51721 .80941 L
s
.51721 .80941 m
.52008 .86098 L
.5 .90275 L
.5 .84521 L
s
.5 .84521 m
.5 .90275 L
.47992 .86098 L
.48279 .80941 L
s
.48279 .80941 m
.47992 .86098 L
.45984 .80529 L
.46557 .76168 L
s
.46557 .76168 m
.45984 .80529 L
.43976 .74961 L
.44836 .71395 L
s
.44836 .71395 m
.43976 .74961 L
.41549 .70403 L
.42756 .67488 L
s
.42756 .67488 m
.41549 .70403 L
.3661 .7191 L
.38523 .6878 L
s
.38523 .6878 m
.3661 .7191 L
.31252 .74427 L
.33931 .70938 L
s
.33931 .70938 m
.31252 .74427 L
.25895 .76945 L
.29338 .73096 L
s
.29338 .73096 m
.25895 .76945 L
.21522 .78478 L
.2559 .7441 L
s
.2559 .7441 m
.21522 .78478 L
.23055 .74105 L
.26904 .70662 L
s
.26904 .70662 m
.23055 .74105 L
.25573 .68748 L
.29062 .66069 L
s
.29062 .66069 m
.25573 .68748 L
.2809 .6339 L
.3122 .61477 L
s
.3122 .61477 m
.2809 .6339 L
.29597 .58451 L
.32512 .57244 L
s
.32512 .57244 m
.29597 .58451 L
.25039 .56024 L
.28605 .55164 L
s
.28605 .55164 m
.25039 .56024 L
.19471 .54016 L
.23832 .53443 L
s
.23832 .53443 m
.19471 .54016 L
.13902 .52008 L
.19059 .51721 L
s
.19059 .51721 m
.13902 .52008 L
.09725 .5 L
.15479 .5 L
s
.15479 .5 m
.09725 .5 L
.13902 .47992 L
.19059 .48279 L
s
.19059 .48279 m
.13902 .47992 L
.19471 .45984 L
.23832 .46557 L
s
.23832 .46557 m
.19471 .45984 L
.25039 .43976 L
.28605 .44836 L
s
.28605 .44836 m
.25039 .43976 L
.29597 .41549 L
.32512 .42756 L
s
.32512 .42756 m
.29597 .41549 L
.2809 .3661 L
.3122 .38523 L
s
.3122 .38523 m
.2809 .3661 L
.25573 .31252 L
.29062 .33931 L
s
.29062 .33931 m
.25573 .31252 L
.23055 .25895 L
.26904 .29338 L
s
.26904 .29338 m
.23055 .25895 L
.21522 .21522 L
.2559 .2559 L
s
.2559 .2559 m
.21522 .21522 L
.25895 .23055 L
.29338 .26904 L
s
.29338 .26904 m
.25895 .23055 L
.31252 .25573 L
.33931 .29062 L
s
.33931 .29062 m
.31252 .25573 L
.3661 .2809 L
.38523 .3122 L
s
.38523 .3122 m
.3661 .2809 L
.41549 .29597 L
.42756 .32512 L
s
.42756 .32512 m
.41549 .29597 L
.43976 .25039 L
.44836 .28605 L
s
.44836 .28605 m
.43976 .25039 L
.45984 .19471 L
.46557 .23832 L
s
.46557 .23832 m
.45984 .19471 L
.47992 .13902 L
.48279 .19059 L
s
.48279 .19059 m
.47992 .13902 L
.5 .09725 L
.5 .15479 L
s
.5 .15479 m
.5 .09725 L
.52008 .13902 L
.51721 .19059 L
s
.51721 .19059 m
.52008 .13902 L
.54016 .19471 L
.53443 .23832 L
s
.53443 .23832 m
.54016 .19471 L
.56024 .25039 L
.55164 .28605 L
s
.55164 .28605 m
.56024 .25039 L
.58451 .29597 L
.57244 .32512 L
s
.57244 .32512 m
.58451 .29597 L
.6339 .2809 L
.61477 .3122 L
s
.61477 .3122 m
.6339 .2809 L
.68748 .25573 L
.66069 .29062 L
s
.66069 .29062 m
.68748 .25573 L
.74105 .23055 L
.70662 .26904 L
s
.70662 .26904 m
.74105 .23055 L
.78478 .21522 L
.7441 .2559 L
s
.7441 .2559 m
.78478 .21522 L
.76945 .25895 L
.73096 .29338 L
s
.73096 .29338 m
.76945 .25895 L
.74427 .31252 L
.70938 .33931 L
s
.70938 .33931 m
.74427 .31252 L
.7191 .3661 L
.6878 .38523 L
s
.6878 .38523 m
.7191 .3661 L
.70403 .41549 L
.67488 .42756 L
s
.67488 .42756 m
.70403 .41549 L
.74961 .43976 L
.71395 .44836 L
s
.71395 .44836 m
.74961 .43976 L
.80529 .45984 L
.76168 .46557 L
s
.76168 .46557 m
.80529 .45984 L
.86098 .47992 L
.80941 .48279 L
s
.80941 .48279 m
.86098 .47992 L
.90275 .5 L
.84521 .5 L
s
.78768 .5 m
.84521 .5 L
.80941 .51721 L
.75784 .51434 L
s
.75784 .51434 m
.80941 .51721 L
.76168 .53443 L
.71807 .52869 L
s
.71807 .52869 m
.76168 .53443 L
.71395 .55164 L
.67829 .54303 L
s
.67829 .54303 m
.71395 .55164 L
.67488 .57244 L
.64574 .56037 L
s
.64574 .56037 m
.67488 .57244 L
.6878 .61477 L
.6565 .59564 L
s
.6565 .59564 m
.6878 .61477 L
.70938 .66069 L
.67448 .63391 L
s
.67448 .63391 m
.70938 .66069 L
.73096 .70662 L
.69247 .67218 L
s
.69247 .67218 m
.73096 .70662 L
.7441 .7441 L
.70342 .70342 L
s
.70342 .70342 m
.7441 .7441 L
.70662 .73096 L
.67218 .69247 L
s
.67218 .69247 m
.70662 .73096 L
.66069 .70938 L
.63391 .67448 L
s
.63391 .67448 m
.66069 .70938 L
.61477 .6878 L
.59564 .6565 L
s
.59564 .6565 m
.61477 .6878 L
.57244 .67488 L
.56037 .64574 L
s
.56037 .64574 m
.57244 .67488 L
.55164 .71395 L
.54303 .67829 L
s
.54303 .67829 m
.55164 .71395 L
.53443 .76168 L
.52869 .71807 L
s
.52869 .71807 m
.53443 .76168 L
.51721 .80941 L
.51434 .75784 L
s
.51434 .75784 m
.51721 .80941 L
.5 .84521 L
.5 .78768 L
s
.5 .78768 m
.5 .84521 L
.48279 .80941 L
.48566 .75784 L
s
.48566 .75784 m
.48279 .80941 L
.46557 .76168 L
.47131 .71807 L
s
.47131 .71807 m
.46557 .76168 L
.44836 .71395 L
.45697 .67829 L
s
.45697 .67829 m
.44836 .71395 L
.42756 .67488 L
.43963 .64574 L
s
.43963 .64574 m
.42756 .67488 L
.38523 .6878 L
.40436 .6565 L
s
.40436 .6565 m
.38523 .6878 L
.33931 .70938 L
.36609 .67448 L
s
.36609 .67448 m
.33931 .70938 L
.29338 .73096 L
.32782 .69247 L
s
.32782 .69247 m
.29338 .73096 L
.2559 .7441 L
.29658 .70342 L
s
.29658 .70342 m
.2559 .7441 L
.26904 .70662 L
.30753 .67218 L
s
.30753 .67218 m
.26904 .70662 L
.29062 .66069 L
.32552 .63391 L
s
.32552 .63391 m
.29062 .66069 L
.3122 .61477 L
.3435 .59564 L
s
.3435 .59564 m
.3122 .61477 L
.32512 .57244 L
.35426 .56037 L
s
.35426 .56037 m
.32512 .57244 L
.28605 .55164 L
.32171 .54303 L
s
.32171 .54303 m
.28605 .55164 L
.23832 .53443 L
.28193 .52869 L
s
.28193 .52869 m
.23832 .53443 L
.19059 .51721 L
.24216 .51434 L
s
.24216 .51434 m
.19059 .51721 L
.15479 .5 L
.21232 .5 L
s
.21232 .5 m
.15479 .5 L
.19059 .48279 L
.24216 .48566 L
s
.24216 .48566 m
.19059 .48279 L
.23832 .46557 L
.28193 .47131 L
s
.28193 .47131 m
.23832 .46557 L
.28605 .44836 L
.32171 .45697 L
s
.32171 .45697 m
.28605 .44836 L
.32512 .42756 L
.35426 .43963 L
s
.35426 .43963 m
.32512 .42756 L
.3122 .38523 L
.3435 .40436 L
s
.3435 .40436 m
.3122 .38523 L
.29062 .33931 L
.32552 .36609 L
s
.32552 .36609 m
.29062 .33931 L
.26904 .29338 L
.30753 .32782 L
s
.30753 .32782 m
.26904 .29338 L
.2559 .2559 L
.29658 .29658 L
s
.29658 .29658 m
.2559 .2559 L
.29338 .26904 L
.32782 .30753 L
s
.32782 .30753 m
.29338 .26904 L
.33931 .29062 L
.36609 .32552 L
s
.36609 .32552 m
.33931 .29062 L
.38523 .3122 L
.40436 .3435 L
s
.40436 .3435 m
.38523 .3122 L
.42756 .32512 L
.43963 .35426 L
s
.43963 .35426 m
.42756 .32512 L
.44836 .28605 L
.45697 .32171 L
s
.45697 .32171 m
.44836 .28605 L
.46557 .23832 L
.47131 .28193 L
s
.47131 .28193 m
.46557 .23832 L
.48279 .19059 L
.48566 .24216 L
s
.48566 .24216 m
.48279 .19059 L
.5 .15479 L
.5 .21232 L
s
.5 .21232 m
.5 .15479 L
.51721 .19059 L
.51434 .24216 L
s
.51434 .24216 m
.51721 .19059 L
.53443 .23832 L
.52869 .28193 L
s
.52869 .28193 m
.53443 .23832 L
.55164 .28605 L
.54303 .32171 L
s
.54303 .32171 m
.55164 .28605 L
.57244 .32512 L
.56037 .35426 L
s
.56037 .35426 m
.57244 .32512 L
.61477 .3122 L
.59564 .3435 L
s
.59564 .3435 m
.61477 .3122 L
.66069 .29062 L
.63391 .32552 L
s
.63391 .32552 m
.66069 .29062 L
.70662 .26904 L
.67218 .30753 L
s
.67218 .30753 m
.70662 .26904 L
.7441 .2559 L
.70342 .29658 L
s
.70342 .29658 m
.7441 .2559 L
.73096 .29338 L
.69247 .32782 L
s
.69247 .32782 m
.73096 .29338 L
.70938 .33931 L
.67448 .36609 L
s
.67448 .36609 m
.70938 .33931 L
.6878 .38523 L
.6565 .40436 L
s
.6565 .40436 m
.6878 .38523 L
.67488 .42756 L
.64574 .43963 L
s
.64574 .43963 m
.67488 .42756 L
.71395 .44836 L
.67829 .45697 L
s
.67829 .45697 m
.71395 .44836 L
.76168 .46557 L
.71807 .47131 L
s
.71807 .47131 m
.76168 .46557 L
.80941 .48279 L
.75784 .48566 L
s
.75784 .48566 m
.80941 .48279 L
.84521 .5 L
.78768 .5 L
s
.73014 .5 m
.78768 .5 L
.75784 .51434 L
.70627 .51148 L
s
.70627 .51148 m
.75784 .51434 L
.71807 .52869 L
.67445 .52295 L
s
.67445 .52295 m
.71807 .52869 L
.67829 .54303 L
.64263 .53443 L
s
.64263 .53443 m
.67829 .54303 L
.64574 .56037 L
.61659 .54829 L
s
.61659 .54829 m
.64574 .56037 L
.6565 .59564 L
.6252 .57651 L
s
.6252 .57651 m
.6565 .59564 L
.67448 .63391 L
.63959 .60713 L
s
.63959 .60713 m
.67448 .63391 L
.69247 .67218 L
.65397 .63774 L
s
.65397 .63774 m
.69247 .67218 L
.70342 .70342 L
.66273 .66273 L
s
.66273 .66273 m
.70342 .70342 L
.67218 .69247 L
.63774 .65397 L
s
.63774 .65397 m
.67218 .69247 L
.63391 .67448 L
.60713 .63959 L
s
.60713 .63959 m
.63391 .67448 L
.59564 .6565 L
.57651 .6252 L
s
.57651 .6252 m
.59564 .6565 L
.56037 .64574 L
.54829 .61659 L
s
.54829 .61659 m
.56037 .64574 L
.54303 .67829 L
.53443 .64263 L
s
.53443 .64263 m
.54303 .67829 L
.52869 .71807 L
.52295 .67445 L
s
.52295 .67445 m
.52869 .71807 L
.51434 .75784 L
.51148 .70627 L
s
.51148 .70627 m
.51434 .75784 L
.5 .78768 L
.5 .73014 L
s
.5 .73014 m
.5 .78768 L
.48566 .75784 L
.48852 .70627 L
s
.48852 .70627 m
.48566 .75784 L
.47131 .71807 L
.47705 .67445 L
s
.47705 .67445 m
.47131 .71807 L
.45697 .67829 L
.46557 .64263 L
s
.46557 .64263 m
.45697 .67829 L
.43963 .64574 L
.45171 .61659 L
s
.45171 .61659 m
.43963 .64574 L
.40436 .6565 L
.42349 .6252 L
s
.42349 .6252 m
.40436 .6565 L
.36609 .67448 L
.39287 .63959 L
s
.39287 .63959 m
.36609 .67448 L
.32782 .69247 L
.36226 .65397 L
s
.36226 .65397 m
.32782 .69247 L
.29658 .70342 L
.33727 .66273 L
s
.33727 .66273 m
.29658 .70342 L
.30753 .67218 L
.34603 .63774 L
s
.34603 .63774 m
.30753 .67218 L
.32552 .63391 L
.36041 .60713 L
s
.36041 .60713 m
.32552 .63391 L
.3435 .59564 L
.3748 .57651 L
s
.3748 .57651 m
.3435 .59564 L
.35426 .56037 L
.38341 .54829 L
s
.38341 .54829 m
.35426 .56037 L
.32171 .54303 L
.35737 .53443 L
s
.35737 .53443 m
.32171 .54303 L
.28193 .52869 L
.32555 .52295 L
s
.32555 .52295 m
.28193 .52869 L
.24216 .51434 L
.29373 .51148 L
s
.29373 .51148 m
.24216 .51434 L
.21232 .5 L
.26986 .5 L
s
.26986 .5 m
.21232 .5 L
.24216 .48566 L
.29373 .48852 L
s
.29373 .48852 m
.24216 .48566 L
.28193 .47131 L
.32555 .47705 L
s
.32555 .47705 m
.28193 .47131 L
.32171 .45697 L
.35737 .46557 L
s
.35737 .46557 m
.32171 .45697 L
.35426 .43963 L
.38341 .45171 L
s
.38341 .45171 m
.35426 .43963 L
.3435 .40436 L
.3748 .42349 L
s
.3748 .42349 m
.3435 .40436 L
.32552 .36609 L
.36041 .39287 L
s
.36041 .39287 m
.32552 .36609 L
.30753 .32782 L
.34603 .36226 L
s
.34603 .36226 m
.30753 .32782 L
.29658 .29658 L
.33727 .33727 L
s
.33727 .33727 m
.29658 .29658 L
.32782 .30753 L
.36226 .34603 L
s
.36226 .34603 m
.32782 .30753 L
.36609 .32552 L
.39287 .36041 L
s
.39287 .36041 m
.36609 .32552 L
.40436 .3435 L
.42349 .3748 L
s
.42349 .3748 m
.40436 .3435 L
.43963 .35426 L
.45171 .38341 L
s
.45171 .38341 m
.43963 .35426 L
.45697 .32171 L
.46557 .35737 L
s
.46557 .35737 m
.45697 .32171 L
.47131 .28193 L
.47705 .32555 L
s
.47705 .32555 m
.47131 .28193 L
.48566 .24216 L
.48852 .29373 L
s
.48852 .29373 m
.48566 .24216 L
.5 .21232 L
.5 .26986 L
s
.5 .26986 m
.5 .21232 L
.51434 .24216 L
.51148 .29373 L
s
.51148 .29373 m
.51434 .24216 L
.52869 .28193 L
.52295 .32555 L
s
.52295 .32555 m
.52869 .28193 L
.54303 .32171 L
.53443 .35737 L
s
.53443 .35737 m
.54303 .32171 L
.56037 .35426 L
.54829 .38341 L
s
.54829 .38341 m
.56037 .35426 L
.59564 .3435 L
.57651 .3748 L
s
.57651 .3748 m
.59564 .3435 L
.63391 .32552 L
.60713 .36041 L
s
.60713 .36041 m
.63391 .32552 L
.67218 .30753 L
.63774 .34603 L
s
.63774 .34603 m
.67218 .30753 L
.70342 .29658 L
.66273 .33727 L
s
.66273 .33727 m
.70342 .29658 L
.69247 .32782 L
.65397 .36226 L
s
.65397 .36226 m
.69247 .32782 L
.67448 .36609 L
.63959 .39287 L
s
.63959 .39287 m
.67448 .36609 L
.6565 .40436 L
.6252 .42349 L
s
.6252 .42349 m
.6565 .40436 L
.64574 .43963 L
.61659 .45171 L
s
.61659 .45171 m
.64574 .43963 L
.67829 .45697 L
.64263 .46557 L
s
.64263 .46557 m
.67829 .45697 L
.71807 .47131 L
.67445 .47705 L
s
.67445 .47705 m
.71807 .47131 L
.75784 .48566 L
.70627 .48852 L
s
.70627 .48852 m
.75784 .48566 L
.78768 .5 L
.73014 .5 L
s
.63084 .51721 m
.66366 .5 L
.73014 .5 L
.70627 .51148 L
.67445 .52295 L
s
.59394 .53891 m
.63084 .51721 L
.67445 .52295 L
.64263 .53443 L
.61659 .54829 L
s
.60469 .58035 m
.59394 .53891 L
.61659 .54829 L
.6252 .57651 L
.63959 .60713 L
s
.61572 .61572 m
.60469 .58035 L
.63959 .60713 L
.65397 .63774 L
.66273 .66273 L
s
.58035 .60469 m
.61572 .61572 L
.66273 .66273 L
.63774 .65397 L
.60713 .63959 L
s
.53891 .59394 m
.58035 .60469 L
.60713 .63959 L
.57651 .6252 L
.54829 .61659 L
s
.51721 .63084 m
.53891 .59394 L
.54829 .61659 L
.53443 .64263 L
.52295 .67445 L
s
.5 .66366 m
.51721 .63084 L
.52295 .67445 L
.51148 .70627 L
.5 .73014 L
s
.48279 .63084 m
.5 .66366 L
.5 .73014 L
.48852 .70627 L
.47705 .67445 L
s
.46109 .59394 m
.48279 .63084 L
.47705 .67445 L
.46557 .64263 L
.45171 .61659 L
s
.41965 .60469 m
.46109 .59394 L
.45171 .61659 L
.42349 .6252 L
.39287 .63959 L
s
.38428 .61572 m
.41965 .60469 L
.39287 .63959 L
.36226 .65397 L
.33727 .66273 L
s
.39531 .58035 m
.38428 .61572 L
.33727 .66273 L
.34603 .63774 L
.36041 .60713 L
s
.40606 .53891 m
.39531 .58035 L
.36041 .60713 L
.3748 .57651 L
.38341 .54829 L
s
.36916 .51721 m
.40606 .53891 L
.38341 .54829 L
.35737 .53443 L
.32555 .52295 L
s
.33634 .5 m
.36916 .51721 L
.32555 .52295 L
.29373 .51148 L
.26986 .5 L
s
.36916 .48279 m
.33634 .5 L
.26986 .5 L
.29373 .48852 L
.32555 .47705 L
s
.40606 .46109 m
.36916 .48279 L
.32555 .47705 L
.35737 .46557 L
.38341 .45171 L
s
.39531 .41965 m
.40606 .46109 L
.38341 .45171 L
.3748 .42349 L
.36041 .39287 L
s
.38428 .38428 m
.39531 .41965 L
.36041 .39287 L
.34603 .36226 L
.33727 .33727 L
s
.41965 .39531 m
.38428 .38428 L
.33727 .33727 L
.36226 .34603 L
.39287 .36041 L
s
.46109 .40606 m
.41965 .39531 L
.39287 .36041 L
.42349 .3748 L
.45171 .38341 L
s
.48279 .36916 m
.46109 .40606 L
.45171 .38341 L
.46557 .35737 L
.47705 .32555 L
s
.5 .33634 m
.48279 .36916 L
.47705 .32555 L
.48852 .29373 L
.5 .26986 L
s
.51721 .36916 m
.5 .33634 L
.5 .26986 L
.51148 .29373 L
.52295 .32555 L
s
.53891 .40606 m
.51721 .36916 L
.52295 .32555 L
.53443 .35737 L
.54829 .38341 L
s
.58035 .39531 m
.53891 .40606 L
.54829 .38341 L
.57651 .3748 L
.60713 .36041 L
s
.61572 .38428 m
.58035 .39531 L
.60713 .36041 L
.63774 .34603 L
.66273 .33727 L
s
.60469 .41965 m
.61572 .38428 L
.66273 .33727 L
.65397 .36226 L
.63959 .39287 L
s
.59394 .46109 m
.60469 .41965 L
.63959 .39287 L
.6252 .42349 L
.61659 .45171 L
s
.63084 .48279 m
.59394 .46109 L
.61659 .45171 L
.64263 .46557 L
.67445 .47705 L
s
.66366 .5 m
.63084 .48279 L
.67445 .47705 L
.70627 .48852 L
.73014 .5 L
s
.6091 .5 m
.66366 .5 L
.63084 .51721 L
.58723 .51148 L
s
.58723 .51148 m
.63084 .51721 L
.59394 .53891 L
.56263 .52594 L
s
.56263 .52594 m
.59394 .53891 L
.60469 .58035 L
.56979 .55356 L
s
.56979 .55356 m
.60469 .58035 L
.61572 .61572 L
.57715 .57715 L
s
.57715 .57715 m
.61572 .61572 L
.58035 .60469 L
.55356 .56979 L
s
.55356 .56979 m
.58035 .60469 L
.53891 .59394 L
.52594 .56263 L
s
.52594 .56263 m
.53891 .59394 L
.51721 .63084 L
.51148 .58723 L
s
.51148 .58723 m
.51721 .63084 L
.5 .66366 L
.5 .6091 L
s
.5 .6091 m
.5 .66366 L
.48279 .63084 L
.48852 .58723 L
s
.48852 .58723 m
.48279 .63084 L
.46109 .59394 L
.47406 .56263 L
s
.47406 .56263 m
.46109 .59394 L
.41965 .60469 L
.44644 .56979 L
s
.44644 .56979 m
.41965 .60469 L
.38428 .61572 L
.42285 .57715 L
s
.42285 .57715 m
.38428 .61572 L
.39531 .58035 L
.43021 .55356 L
s
.43021 .55356 m
.39531 .58035 L
.40606 .53891 L
.43737 .52594 L
s
.43737 .52594 m
.40606 .53891 L
.36916 .51721 L
.41277 .51148 L
s
.41277 .51148 m
.36916 .51721 L
.33634 .5 L
.3909 .5 L
s
.3909 .5 m
.33634 .5 L
.36916 .48279 L
.41277 .48852 L
s
.41277 .48852 m
.36916 .48279 L
.40606 .46109 L
.43737 .47406 L
s
.43737 .47406 m
.40606 .46109 L
.39531 .41965 L
.43021 .44644 L
s
.43021 .44644 m
.39531 .41965 L
.38428 .38428 L
.42285 .42285 L
s
.42285 .42285 m
.38428 .38428 L
.41965 .39531 L
.44644 .43021 L
s
.44644 .43021 m
.41965 .39531 L
.46109 .40606 L
.47406 .43737 L
s
.47406 .43737 m
.46109 .40606 L
.48279 .36916 L
.48852 .41277 L
s
.48852 .41277 m
.48279 .36916 L
.5 .33634 L
.5 .3909 L
s
.5 .3909 m
.5 .33634 L
.51721 .36916 L
.51148 .41277 L
s
.51148 .41277 m
.51721 .36916 L
.53891 .40606 L
.52594 .43737 L
s
.52594 .43737 m
.53891 .40606 L
.58035 .39531 L
.55356 .43021 L
s
.55356 .43021 m
.58035 .39531 L
.61572 .38428 L
.57715 .42285 L
s
.57715 .42285 m
.61572 .38428 L
.60469 .41965 L
.56979 .44644 L
s
.56979 .44644 m
.60469 .41965 L
.59394 .46109 L
.56263 .47406 L
s
.56263 .47406 m
.59394 .46109 L
.63084 .48279 L
.58723 .48852 L
s
.58723 .48852 m
.63084 .48279 L
.66366 .5 L
.6091 .5 L
s
.53528 .51462 m
.54908 .5 L
.6091 .5 L
.58723 .51148 L
.56263 .52594 L
s
.53471 .53471 m
.53528 .51462 L
.56263 .52594 L
.56979 .55356 L
.57715 .57715 L
s
.51462 .53528 m
.53471 .53471 L
.57715 .57715 L
.55356 .56979 L
.52594 .56263 L
s
.5 .54908 m
.51462 .53528 L
.52594 .56263 L
.51148 .58723 L
.5 .6091 L
s
.48538 .53528 m
.5 .54908 L
.5 .6091 L
.48852 .58723 L
.47406 .56263 L
s
.46529 .53471 m
.48538 .53528 L
.47406 .56263 L
.44644 .56979 L
.42285 .57715 L
s
.46472 .51462 m
.46529 .53471 L
.42285 .57715 L
.43021 .55356 L
.43737 .52594 L
s
.45092 .5 m
.46472 .51462 L
.43737 .52594 L
.41277 .51148 L
.3909 .5 L
s
.46472 .48538 m
.45092 .5 L
.3909 .5 L
.41277 .48852 L
.43737 .47406 L
s
.46529 .46529 m
.46472 .48538 L
.43737 .47406 L
.43021 .44644 L
.42285 .42285 L
s
.48538 .46472 m
.46529 .46529 L
.42285 .42285 L
.44644 .43021 L
.47406 .43737 L
s
.5 .45092 m
.48538 .46472 L
.47406 .43737 L
.48852 .41277 L
.5 .3909 L
s
.51462 .46472 m
.5 .45092 L
.5 .3909 L
.51148 .41277 L
.52594 .43737 L
s
.53471 .46529 m
.51462 .46472 L
.52594 .43737 L
.55356 .43021 L
.57715 .42285 L
s
.53528 .48538 m
.53471 .46529 L
.57715 .42285 L
.56979 .44644 L
.56263 .47406 L
s
.54908 .5 m
.53528 .48538 L
.56263 .47406 L
.58723 .48852 L
.6091 .5 L
s
.5 .5 m
.5 .5 L
.54908 .5 L
.53528 .51462 L
.53471 .53471 L
s
.5 .5 m
.5 .5 L
.53471 .53471 L
.51462 .53528 L
.5 .54908 L
s
.5 .5 m
.5 .5 L
.5 .54908 L
.48538 .53528 L
.46529 .53471 L
s
.5 .5 m
.5 .5 L
.46529 .53471 L
.46472 .51462 L
.45092 .5 L
s
.5 .5 m
.5 .5 L
.45092 .5 L
.46472 .48538 L
.46529 .46529 L
s
.5 .5 m
.5 .5 L
.46529 .46529 L
.48538 .46472 L
.5 .45092 L
s
.5 .5 m
.5 .5 L
.5 .45092 L
.51462 .46472 L
.53471 .46529 L
s
.5 .5 m
.5 .5 L
.53471 .46529 L
.53528 .48538 L
.54908 .5 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[319]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3j
l>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00S`3jl>H00`000000
n_3V0?[`iP2=0?[`iP40oooo002?0?[`iP030000003jl>H0n_3V08d0n_3V0@3oool008h0n_3V0`00
002>0?[`iP40oooo002>0?[`iP<00000SP3jl>H10?ooo`00SP3jl>H3000008h0n_3V0@3oool008d0
n_3V00D0000005nNX0000000GijP0000002=0?[`iP40oooo002=0?[`iP050000001OWZ00000005nN
X0000000S@3jl>H10?ooo`00S03jl>H010000000GijP05nNX000000205nNX0030000003jl>H0n_3V
08X0n_3V0@3oool008`0n_3V00@0000005nNX01OWZ0000000P1OWZ000`000000n_3V0?[`iP2:0?[`
iP40oooo002<0?[`iP040000001OWZ00GijP00000080GijP00<000000?[`iP3jl>H0RP3jl>H10?oo
o`00R`3jl>H01@000000GijP05nNX01OWZ00000000<0GijP00<000000?[`iP3jl>H0R@3jl>H10?oo
o`00R`3jl>H01@000000GijP05nNX01OWZ00000000<0GijP00<000000?[`iP3jl>H0R@3jl>H10?oo
o`00R`3jl>H01@000000GijP05nNX01OWZ00000000<0GijP00<000000?[`iP3jl>H0R@3jl>H10?oo
o`00RP3jl>H00`000000GijP05nNX00205nNX0030000001OWZ00GijP0080GijP00<000000?[`iP3j
l>H0R03jl>H10?ooo`00RP3jl>H00`000000GijP05nNX00205nNX0030000001OWZ00GijP0080GijP
00<000000?[`iP3jl>H0R03jl>H10?ooo`00R@3jl>H00`000000GijP05nNX00305nNX0030000001O
WZ00GijP00<0GijP00<000000?[`iP3jl>H0Q`3jl>H10?ooo`00R@3jl>H00`000000GijP05nNX003
05nNX0030000001OWZ00GijP00<0GijP00<000000?[`iP3jl>H0Q`3jl>H10?ooo`00R@3jl>H00`00
0000GijP05nNX00305nNX0030000001OWZ00GijP00<0GijP00<000000?[`iP3jl>H0Q`3jl>H10?oo
o`00R03jl>H00`000000GijP05nNX00405nNX0030000001OWZ00GijP00@0GijP00<000000?[`iP3j
l>H0QP3jl>H10?ooo`00R03jl>H00`000000GijP05nNX00405nNX0030000001OWZ00GijP00@0GijP
00<000000?[`iP3jl>H0QP3jl>H10?ooo`00R03jl>H00`000000GijP05nNX00405nNX0030000001O
WZ00GijP00@0GijP00<000000?[`iP3jl>H0QP3jl>H10?ooo`00Q`3jl>H2000000H0GijP00<00000
05nNX01OWZ00101OWZ02000008L0n_3V0@3oool008L0n_3V0P00000505nNX08000001P1OWZ020000
08L0n_3V0@3oool008L0n_3V0P00000505nNX0<000001@1OWZ02000008L0n_3V0@3oool008H0n_3V
00<0000005nNX0000000101OWZ0010000000GijP00000000000505nNX0030000001OWZ00000008H0
n_3V0@3oool008H0n_3V00<0000005nNX0000000101OWZ001@000000GijP0000001OWZ00000000@0
GijP00<0000005nNX0000000QP3jl>H10?ooo`00QP3jl>H00`000000GijP0000000305nNX0060000
001OWZ00GijP0000001OWZ0000000`1OWZ0010000000GijP05nNX00000260?[`iP40oooo00250?[`
iP050000001OWZ00GijP05nNX00000000P1OWZ0010000000GijP05nNX000000205nNX0040000001O
WZ00GijP000000<0GijP00<000000?[`iP3jl>H0P`3jl>H10?ooo`00Q@3jl>H01`000000GijP05nN
X01OWZ00000005nNX00000000`1OWZ0010000000GijP05nNX000000205nNX0050000001OWZ00GijP
05nNX0000000Q@3jl>H10?ooo`00Q@3jl>H01`000000GijP05nNX01OWZ00000005nNX00000000`1O
WZ001`000000GijP05nNX01OWZ00000005nNX00000000`1OWZ000`000000n_3V0?[`iP230?[`iP40
oooo00240?[`iP030000001OWZ00GijP0080GijP0P00000405nNX0070000001OWZ00GijP05nNX000
0000GijP0000000405nNX0030000003jl>H0n_3V0880n_3V0@3oool008@0n_3V00<0000005nNX01O
WZ000P1OWZ02000000@0GijP00<0000005nNX01OWZ000P1OWZ02000000@0GijP00<000000?[`iP3j
l>H0PP3jl>H10?ooo`00Q03jl>H00`000000GijP05nNX00205nNX0030000001OWZ00GijP00<0GijP
00<0000005nNX01OWZ000P1OWZ02000000@0GijP00<000000?[`iP3jl>H0PP3jl>H10?ooo`00P`3j
l>H00`000000GijP05nNX00305nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000`1O
WZ000`000000GijP05nNX00305nNX0030000003jl>H0n_3V0840n_3V0@3oool008<0n_3V00<00000
05nNX01OWZ000`1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP00<0GijP00<00000
05nNX01OWZ000`1OWZ000`000000n_3V0?[`iP210?[`iP40oooo00230?[`iP030000001OWZ00GijP
0080GijP0P00000505nNX0030000001OWZ00GijP00<0GijP0P00000405nNX0030000003jl>H0n_3V
0840n_3V0@3oool00880n_3V00<0000005nNX01OWZ000`1OWZ02000000D0GijP00<0000005nNX01O
WZ000`1OWZ02000000D0GijP00<000000?[`iP3jl>H0P03jl>H10?ooo`00PP3jl>H00`000000GijP
05nNX00205nNX0030000001OWZ00000000D0GijP00<0000005nNX01OWZ000`1OWZ02000000D0GijP
00<000000?[`iP3jl>H0P03jl>H10?ooo`00PP3jl>H00`000000GijP05nNX00205nNX0030000001O
WZ00000000D0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP0000000405nNX0030000003j
l>H0n_3V0800n_3V0@3oool00840n_3V0P00000405nNX0030000001OWZ00000000@0GijP0P000005
05nNX0030000001OWZ00000000@0GijP0P0000210?[`iP40oooo000^0?[`iP030000003jl>H0n_3V
0500n_3V0P00000305nNX0040000001OWZ00GijP000000@0GijP0`00000405nNX0040000001OWZ00
GijP000000<0GijP0P00001B0?[`iP030000003jl>H0n_3V02`0n_3V0@3oool002h0n_3V0`00001?
0?[`iP030000001OWZ00000000<0GijP00D0000005nNX01OWZ00GijP0000000205nNX0040000001O
WZ000000000000<0GijP00D0000005nNX01OWZ00GijP0000000305nNX0030000001OWZ00000004l0
n_3V0P00000_0?[`iP40oooo000_0?[`iP@00000C@3jl>H00`000000GijP0000000305nNX0050000
001OWZ00GijP05nNX00000000P1OWZ001@000000GijP0000001OWZ0000000080GijP00D0000005nN
X01OWZ00GijP0000000305nNX0030000001OWZ00000004d0n_3V1000000_0?[`iP40oooo000_0?[`
iP040000001OWZ00000005nNX0800000B`3jl>H00`000000GijP0000000205nNX0030000001OWZ00
GijP0080GijP00<0000005nNX00000000P1OWZ000`000000GijP0000000205nNX0030000001OWZ00
GijP0080GijP00<0000005nNX00000000P1OWZ000`000000n_3V0?[`iP190?[`iP80000000<0GijP
000000000000<03jl>H10?ooo`00<03jl>H00`000000GijP0000000205nNX0800000B03jl>H01`00
0000GijP05nNX01OWZ00000005nNX0000000101OWZ000`000000GijP0000000205nNX0060000001O
WZ00GijP0000001OWZ000000101OWZ000`000000GijP0000000305nNX0030000003jl>H0n_3V04H0
n_3V0P00000205nNX0030000001OWZ0000000300n_3V0@3oool00300n_3V00@0000005nNX01OWZ00
00000`1OWZ02000004H0n_3V00@0000005nNX01OWZ00GijP0P00000505nNX08000000`1OWZ001P00
0000GijP05nNX0000000GijP000000@0GijP00<0000005nNX00000000`1OWZ000`000000n_3V0?[`
iP140?[`iP8000000`1OWZ000`000000GijP0000000a0?[`iP40oooo000a0?[`iP040000001OWZ00
GijP000000@0GijP0P0000130?[`iP030000001OWZ00GijP0080GijP0P00000505nNX08000000`1O
WZ0010000000GijP05nNX01OWZ02000000D0GijP0P00000305nNX0030000003jl>H0n_3V0480n_3V
0P00000405nNX0040000001OWZ00GijP00000340n_3V0@3oool00340n_3V00D0000005nNX01OWZ00
GijP0000000505nNX0800000@@3jl>H00`000000GijP05nNX00205nNX08000001@1OWZ000`000000
GijP05nNX00205nNX0040000001OWZ00GijP05nNX08000001@1OWZ02000000@0GijP00<000000?[`
iP3jl>H0?`3jl>H2000000D0GijP00@0000005nNX01OWZ000000<P3jl>H10?ooo`00<P3jl>H01@00
0000GijP05nNX01OWZ00000000H0GijP0P00000o0?[`iP030000001OWZ00GijP0080GijP00<00000
05nNX01OWZ00101OWZ000`000000GijP05nNX00205nNX0030000001OWZ00GijP0080GijP00<00000
05nNX01OWZ00101OWZ000`000000GijP05nNX00205nNX0030000003jl>H0n_3V03d0n_3V0P000006
05nNX0050000001OWZ00GijP05nNX0000000<P3jl>H10?ooo`00<P3jl>H00`000000GijP05nNX002
05nNX0030000001OWZ00GijP00D0GijP0`00000k0?[`iP030000001OWZ00GijP00<0GijP00<00000
05nNX01OWZ00101OWZ000`000000GijP05nNX00205nNX0030000001OWZ00GijP0080GijP00<00000
05nNX01OWZ00101OWZ000`000000GijP05nNX00305nNX0030000003jl>H0n_3V03T0n_3V0`000007
05nNX0050000001OWZ00GijP05nNX0000000<`3jl>H10?ooo`00<`3jl>H00`000000GijP05nNX002
05nNX0030000001OWZ00GijP00H0GijP0`00000i0?[`iP030000001OWZ00GijP00<0GijP00<00000
05nNX01OWZ000`1OWZ02000000@0GijP00<0000005nNX01OWZ000P1OWZ02000000D0GijP00<00000
05nNX01OWZ000`1OWZ000`000000n_3V0?[`iP0g0?[`iP<00000201OWZ000`000000GijP05nNX002
05nNX0030000003jl>H0n_3V0340n_3V0@3oool003<0n_3V00<0000005nNX01OWZ000`1OWZ000`00
0000GijP05nNX00605nNX0040000001OWZ000000000003L0n_3V00<0000005nNX01OWZ000P1OWZ02
000000D0GijP0P00000405nNX0030000001OWZ00GijP0080GijP0P00000505nNX0800000101OWZ00
0`000000n_3V0?[`iP0e0?[`iP80000000<0GijP0000001OWZ001`1OWZ000`000000GijP05nNX002
05nNX0030000003jl>H0n_3V0380n_3V0@3oool003@0n_3V00<0000005nNX01OWZ000`1OWZ000`00
0000GijP05nNX00605nNX0030000001OWZ00GijP00800000=03jl>H00`000000GijP05nNX00305nN
X08000001@1OWZ02000000@0GijP00<0000005nNX01OWZ000P1OWZ02000000D0GijP0P00000505nN
X0030000003jl>H0n_3V0380n_3V0P00000205nNX0030000001OWZ00GijP00H0GijP00<0000005nN
X01OWZ000`1OWZ000`000000n_3V0?[`iP0b0?[`iP40oooo000d0?[`iP030000001OWZ00GijP00@0
GijP00<0000005nNX01OWZ001P1OWZ0010000000GijP05nNX01OWZ0300000340n_3V00<0000005nN
X01OWZ000`1OWZ000`000000GijP0000000305nNX0030000001OWZ00000000@0GijP00<0000005nN
X01OWZ000P1OWZ000`000000GijP0000000305nNX0030000001OWZ00000000D0GijP00<000000?[`
iP3jl>H0;`3jl>H3000000<0GijP00<0000005nNX01OWZ001P1OWZ000`000000GijP05nNX00305nN
X0030000003jl>H0n_3V03<0n_3V0@3oool003D0n_3V00<0000005nNX01OWZ00101OWZ000`000000
GijP05nNX00605nNX0030000001OWZ00GijP00<0GijP0P00000^0?[`iP030000001OWZ00GijP00<0
GijP00@0000005nNX01OWZ0000000`1OWZ000`000000GijP0000000405nNX0030000001OWZ00GijP
0080GijP00<0000005nNX00000000`1OWZ0010000000GijP05nNX000000505nNX0030000003jl>H0
n_3V02`0n_3V0P00000505nNX0030000001OWZ00GijP00H0GijP00<0000005nNX01OWZ00101OWZ00
0`000000n_3V0?[`iP0c0?[`iP40oooo000e0?[`iP030000001OWZ00GijP00D0GijP0P00000605nN
X0030000001OWZ00GijP00D0GijP0P00000/0?[`iP030000001OWZ00GijP00<0GijP00@0000005nN
X01OWZ0000000P1OWZ0010000000GijP05nNX000000405nNX0030000001OWZ00GijP0080GijP00<0
000005nNX00000000`1OWZ0010000000GijP05nNX000000505nNX0030000003jl>H0n_3V02X0n_3V
0P00000705nNX0030000001OWZ00GijP00@0GijP0P00000605nNX0030000003jl>H0n_3V03@0n_3V
0@3oool003H0n_3V00<0000005nNX01OWZ00101OWZ04000000D0GijP00<0000005nNX01OWZ001P1O
WZ02000002X0n_3V00<0000005nNX01OWZ000`1OWZ0010000000GijP05nNX000000205nNX0050000
001OWZ00GijP05nNX00000000P1OWZ0300000080GijP00D0000005nNX01OWZ00GijP0000000205nN
X0040000001OWZ00GijP000000D0GijP00<000000?[`iP3jl>H0:03jl>H2000000P0GijP00<00000
05nNX01OWZ000`1OWZ04000000H0GijP00<000000?[`iP3jl>H0=03jl>H10?ooo`00=P3jl>H00`00
0000GijP05nNX00505nNX080000000@0GijP00000000000000000`1OWZ000`000000GijP05nNX007
05nNX0<000009P3jl>H00`000000GijP0000000305nNX0050000001OWZ00GijP05nNX00000000P1O
WZ001@000000GijP05nNX01OWZ0000000080GijP0`00000205nNX0050000001OWZ00GijP05nNX000
00000P1OWZ0010000000GijP05nNX000000405nNX0030000001OWZ00000002H0n_3V0`00000905nN
X0040000001OWZ00GijP05nNX0<0000000<0GijP0000000000001P1OWZ000`000000n_3V0?[`iP0e
0?[`iP40oooo000g0?[`iP030000001OWZ00GijP00@0GijP00<0000005nNX00000000`1OWZ030000
000305nNX0000000GijP00T0GijP0`00000T0?[`iP030000001OWZ00000000<0GijP00L0000005nN
X01OWZ00GijP0000001OWZ00000000@0GijP00T0000005nNX0000000GijP0000001OWZ00000005nN
X0000000101OWZ000`000000GijP0000000305nNX0070000001OWZ00GijP05nNX0000000GijP0000
000T0?[`iP<000002P1OWZ000`000000GijP00000002000000<0GijP00<0000005nNX00000001P1O
WZ000`000000n_3V0?[`iP0e0?[`iP40oooo000g0?[`iP8000001P1OWZ000`000000GijP00000005
05nNX0<000002@1OWZ000`000000GijP05nNX00200000280n_3V00<0000005nNX00000000`1OWZ00
0`000000GijP05nNX00205nNX0800000101OWZ002@000000GijP0000001OWZ00000005nNX0000000
GijP0000000405nNX0800000101OWZ001`000000GijP05nNX01OWZ00000005nNX00000008P3jl>H2
00000080GijP00<0000005nNX01OWZ001`1OWZ03000000D0GijP00<0000005nNX00000001P1OWZ02
000003L0n_3V0@3oool003P0n_3V0P00000505nNX0040000001OWZ00GijP000000H0GijP0`000008
05nNX0040000001OWZ00GijP05nNX08000007`3jl>H010000000GijP05nNX000000305nNX0030000
001OWZ00GijP0080GijP0P00000405nNX08000000P1OWZ000`000000GijP05nNX002000000@0GijP
0P00000405nNX0040000001OWZ00GijP000000<0GijP00<000000?[`iP3jl>H07@3jl>H2000000<0
GijP00<0000005nNX01OWZ001P1OWZ03000000H0GijP00@0000005nNX01OWZ0000001@1OWZ020000
03P0n_3V0@3oool003P0n_3V00<0000005nNX0000000101OWZ001@000000GijP05nNX01OWZ000000
00L0GijP0`00000705nNX0030000001OWZ00GijP0080GijP0P00000M0?[`iP070000001OWZ00GijP
05nNX0000000GijP0000000505nNX0030000001OWZ00GijP00<0GijP0P00000205nNX0030000001O
WZ00GijP008000001@1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00000000<0GijP00<0
00000?[`iP3jl>H06`3jl>H2000000@0GijP00<0000005nNX01OWZ001@1OWZ03000000L0GijP00D0
000005nNX01OWZ00GijP0000000405nNX0030000001OWZ00000003P0n_3V0@3oool003T0n_3V00<0
000005nNX0000000101OWZ001@000000GijP05nNX01OWZ00000000L0GijP00@0000005nNX0000000
00001@1OWZ000`000000GijP05nNX00405nNX08000006`3jl>H01`000000GijP05nNX01OWZ000000
05nNX00000001@1OWZ000`000000GijP05nNX00305nNX0050000001OWZ00GijP05nNX00000000`1O
WZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP00<0GijP00<0000005nNX00000000`1O
WZ000`000000n_3V0?[`iP0I0?[`iP8000001@1OWZ000`000000GijP05nNX00405nNX080000000<0
GijP0000001OWZ001P1OWZ001@000000GijP05nNX01OWZ00000000@0GijP00<0000005nNX0000000
>@3jl>H10?ooo`00>@3jl>H00`000000GijP05nNX00200000080GijP00<0000005nNX01OWZ000P1O
WZ000`000000GijP05nNX00505nNX0030000001OWZ00GijP00800000101OWZ000`000000GijP05nN
X00505nNX0800000603jl>H00`000000GijP05nNX00205nNX0030000001OWZ00000000D0GijP00<0
000005nNX01OWZ000`1OWZ001@000000GijP05nNX01OWZ00000000<0GijP00<0000005nNX01OWZ00
0`1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00000000@0GijP00<000000?[`iP3jl>H0
5P3jl>H2000000L0GijP00<0000005nNX01OWZ000P1OWZ0200000080GijP00<0000005nNX01OWZ00
1@1OWZ000`000000GijP05nNX00205nNX0030000001OWZ00GijP008000000P1OWZ000`000000n_3V
0?[`iP0g0?[`iP40oooo000j0?[`iP070000001OWZ00GijP05nNX0000000GijP0000000505nNX003
0000001OWZ00GijP00D0GijP00@0000005nNX01OWZ00GijP0P00000305nNX0030000001OWZ00GijP
00H0GijP0P00000F0?[`iP030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000`1OWZ020000
00D0GijP00D0000005nNX01OWZ00GijP0000000305nNX0030000001OWZ00GijP00<0GijP0P000005
05nNX0030000001OWZ00GijP00<0GijP00<000000?[`iP3jl>H0503jl>H2000000P0GijP00@00000
05nNX01OWZ00GijP0P00000305nNX0030000001OWZ00GijP00D0GijP00<0000005nNX01OWZ000`1O
WZ000`000000GijP0000000305nNX0030000003jl>H0n_3V03P0n_3V0@3oool003X0n_3V00<00000
05nNX01OWZ000P1OWZ000`000000GijP0000000505nNX0030000001OWZ00GijP00D0GijP00<00000
05nNX01OWZ000P1OWZ0200000080GijP00<0000005nNX01OWZ001`1OWZ03000001<0n_3V00<00000
05nNX01OWZ000`1OWZ000`000000GijP05nNX00305nNX0800000101OWZ02000000<0GijP00@00000
05nNX01OWZ00GijP0P00000305nNX0030000001OWZ00000000D0GijP00<0000005nNX01OWZ000`1O
WZ000`000000n_3V0?[`iP0A0?[`iP<000002@1OWZ000`000000GijP05nNX002000000@0GijP00<0
000005nNX01OWZ001@1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00000000@0GijP00<0
00000?[`iP3jl>H0>03jl>H10?ooo`00>`3jl>H00`000000GijP05nNX00205nNX08000001P1OWZ00
0`000000GijP05nNX00405nNX0030000001OWZ00GijP00@0GijP0`00000;05nNX0<00000403jl>H0
0`000000GijP05nNX00305nNX08000001@1OWZ000`000000GijP0000000305nNX08000000`1OWZ00
10000000GijP05nNX01OWZ02000000<0GijP00<0000005nNX00000001@1OWZ02000000D0GijP00<0
00000?[`iP3jl>H03P3jl>H3000000/0GijP0`00000605nNX0030000001OWZ00GijP00@0GijP00<0
000005nNX01OWZ00101OWZ02000000@0GijP00<000000?[`iP3jl>H0>@3jl>H10?ooo`00>`3jl>H0
0`000000GijP05nNX00305nNX08000001P1OWZ02000000D0GijP00<0000005nNX01OWZ001@1OWZ03
000000T0GijP00<0000005nNX01OWZ000P00000>0?[`iP030000001OWZ00GijP00<0GijP0P000004
05nNX0040000001OWZ00GijP000000<0GijP0P00000305nNX0040000001OWZ00GijP05nNX0800000
0`1OWZ0010000000GijP05nNX000000405nNX08000001@1OWZ000`000000n_3V0?[`iP0<0?[`iP80
00000P1OWZ000`000000GijP05nNX00705nNX0<000001`1OWZ000`000000GijP05nNX00305nNX080
00001P1OWZ02000000D0GijP00<000000?[`iP3jl>H0>@3jl>H10?ooo`00>`3jl>H00`000000GijP
05nNX00405nNX0030000001OWZ00GijP00@0GijP1@00000305nNX0030000001OWZ00GijP00H0GijP
0`00000805nNX0040000001OWZ00GijP05nNX0800000303jl>H00`000000GijP05nNX00205nNX004
0000001OWZ00GijP000000<0GijP00@0000005nNX01OWZ0000000P1OWZ000`000000GijP00000003
05nNX0070000001OWZ00GijP05nNX0000000GijP0000000205nNX0040000001OWZ00GijP000000<0
GijP00@0000005nNX01OWZ000000101OWZ000`000000n_3V0?[`iP0:0?[`iP8000000`1OWZ000`00
0000GijP05nNX00605nNX0<00000201OWZ0010000000GijP05nNX01OWZ05000000H0GijP00<00000
05nNX01OWZ00101OWZ000`000000n_3V0?[`iP0i0?[`iP40oooo000l0?[`iP030000001OWZ00GijP
00<0GijP0P00000605nNX08000000P1OWZ0200000080GijP00<0000005nNX01OWZ001P1OWZ001000
0000GijP00000000000705nNX0030000001OWZ00GijP0080GijP0`0000080?[`iP030000001OWZ00
GijP00<0GijP00@0000005nNX01OWZ0000000P1OWZ001@000000GijP05nNX01OWZ0000000080GijP
00<0000005nNX00000000`1OWZ001`000000GijP05nNX01OWZ00000005nNX00000000P1OWZ001000
0000GijP05nNX000000305nNX0040000001OWZ00GijP000000D0GijP00<000000?[`iP3jl>H01P3j
l>H3000000@0GijP00<0000005nNX01OWZ001@1OWZ020000000305nNX0000000GijP00L0GijP00<0
000005nNX01OWZ000P00000205nNX08000001P1OWZ02000000D0GijP00<000000?[`iP3jl>H0>P3j
l>H10?ooo`00?03jl>H00`000000GijP05nNX00405nNX08000001@1OWZ000`000000GijP00000003
05nNX0@000001`1OWZ0010000000GijP05nNX01OWZ02000000D0GijP00<0000005nNX01OWZ001@1O
WZ02000000H0n_3V00<0000005nNX01OWZ000P1OWZ001@000000GijP05nNX01OWZ0000000080GijP
00L0000005nNX01OWZ00GijP0000001OWZ0000000080GijP00D0000005nNX01OWZ00GijP00000003
05nNX0060000001OWZ00GijP0000001OWZ0000000`1OWZ0010000000GijP05nNX000000305nNX003
0000001OWZ00GijP0080GijP00<000000?[`iP3jl>H0103jl>H2000000L0GijP00<0000005nNX01O
WZ000`1OWZ02000000<0GijP00<0000005nNX01OWZ001@1OWZ04000000<0GijP00<0000005nNX000
00001@1OWZ02000000H0GijP00<000000?[`iP3jl>H0>P3jl>H10?ooo`00?@3jl>H00`000000GijP
05nNX00305nNX0030000001OWZ00000000@0GijP00@0000005nNX01OWZ0000001@1OWZ03000000H0
GijP00<0000005nNX01OWZ000P1OWZ03000000<0GijP00<0000005nNX01OWZ001P1OWZ02000000@0
n_3V00<0000005nNX01OWZ000P1OWZ001@000000GijP05nNX01OWZ0000000080GijP00L0000005nN
X01OWZ00GijP0000001OWZ00000000<0GijP00@0000005nNX01OWZ0000000P1OWZ0010000000GijP
05nNX01OWZ02000000@0GijP00@0000005nNX01OWZ0000000`1OWZ000`000000GijP05nNX00205nN
X0030000003jl>H0n_3V0080n_3V0P00000805nNX0040000001OWZ00GijP05nNX0<00000101OWZ00
0`000000GijP05nNX00405nNX0<000001@1OWZ0010000000GijP05nNX000000405nNX0030000001O
WZ00000000D0GijP00<000000?[`iP3jl>H0>`3jl>H10?ooo`00?@3jl>H00`000000GijP05nNX004
05nNX0030000001OWZ00000000@0GijP00@0000005nNX01OWZ0000001P1OWZ03000000D0GijP00<0
000005nNX01OWZ00101OWZ0200000080GijP00<0000005nNX01OWZ001`1OWZ02000000030?[`iP00
0000GijP00<0GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP0000000505nNX08000000`1O
WZ0010000000GijP05nNX000000205nNX0040000001OWZ00GijP05nNX08000001@1OWZ000`000000
GijP0000000405nNX0030000001OWZ00GijP0080GijP00@000000?[`iP00000000002@1OWZ000`00
0000GijP05nNX002000000H0GijP00<0000005nNX01OWZ000`1OWZ03000000H0GijP00@0000005nN
X01OWZ000000101OWZ000`000000GijP0000000605nNX0030000003jl>H0n_3V03/0n_3V0@3oool0
03h0n_3V00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00200000080GijP00D0000005nN
X01OWZ00GijP0000000605nNX0040000001OWZ000000000000@0GijP00<0000005nNX01OWZ001@1O
WZ03000000/0GijP0P00000405nNX0030000001OWZ00GijP0080GijP00<0000005nNX00000001@1O
WZ000`000000GijP05nNX00205nNX0030000001OWZ0000000080000000<0GijP0000001OWZ000`1O
WZ000`000000GijP05nNX00305nNX0030000001OWZ00000000@0GijP00<0000005nNX01OWZ000P1O
WZ02000000/0GijP0`00000705nNX0030000001OWZ00GijP0080GijP0P0000000`1OWZ00000005nN
X00505nNX0050000001OWZ00GijP05nNX00000000P1OWZ0200000080GijP00<0000005nNX01OWZ00
0`1OWZ000`000000n_3V0?[`iP0l0?[`iP40oooo000n0?[`iP030000001OWZ00GijP00@0GijP00D0
000005nNX01OWZ00GijP0000000205nNX0050000001OWZ00GijP05nNX00000001P1OWZ000`000000
GijP05nNX002000000<0GijP00<0000005nNX01OWZ001P1OWZ03000000X0GijP00D0000005nNX01O
WZ00GijP0000000605nNX08000001@1OWZ000`000000GijP05nNX00205nNX0030000001OWZ000000
0080000000<0GijP0000001OWZ000`1OWZ000`000000GijP05nNX00305nNX08000001P1OWZ001@00
0000GijP05nNX01OWZ00000000X0GijP0`00000805nNX0040000001OWZ00GijP05nNX08000000P1O
WZ000`000000GijP05nNX00405nNX0050000001OWZ00GijP05nNX00000000P1OWZ001@000000GijP
05nNX01OWZ00000000H0GijP00<000000?[`iP3jl>H0?03jl>H10?ooo`00?`3jl>H00`000000GijP
05nNX00305nNX0030000001OWZ00GijP0080GijP00<0000005nNX0000000101OWZ000`000000GijP
05nNX00405nNX0040000001OWZ00GijP05nNX080000000<0GijP0000001OWZ002@1OWZ05000000L0
GijP00@0000005nNX01OWZ0000001P1OWZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP
0080GijP0P0000000`1OWZ00000005nNX002000000@0GijP00<0000005nNX01OWZ00101OWZ000`00
0000GijP05nNX00405nNX0040000001OWZ00GijP000000L0GijP1@00000:05nNX0040000001OWZ00
0000000000<0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00205nNX0030000001O
WZ00000000@0GijP00<0000005nNX01OWZ000`1OWZ000`000000n_3V0?[`iP0m0?[`iP40oooo000o
0?[`iP030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ000P1OWZ02000000D0GijP00<00000
05nNX01OWZ00101OWZ000`000000GijP05nNX00205nNX0<000002@1OWZ000`000000GijP05nNX002
05nNX0<00000101OWZ000`000000GijP0000000705nNX0030000001OWZ00GijP00<0GijP0P000004
05nNX080000000<0GijP0000001OWZ000P00000405nNX08000001@1OWZ000`000000GijP05nNX005
05nNX0030000001OWZ00000000@0GijP0`00000405nNX0030000001OWZ00GijP00L0GijP0`000004
05nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ000`1OWZ02000000@0GijP00<00000
05nNX01OWZ00101OWZ000`000000n_3V0?[`iP0m0?[`iP40oooo000o0?[`iP<00000101OWZ000`00
0000GijP05nNX00305nNX08000001@1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP
00@0GijP0`00000805nNX0030000001OWZ00GijP00@0GijP100000000`1OWZ0000000000000605nN
X08000001@1OWZ02000000@0GijP00@0000005nNX01OWZ0000000P1OWZ000`000000GijP05nNX002
05nNX08000001@1OWZ02000000H0GijP0P0000000`1OWZ00000000000002000000H0GijP00<00000
05nNX01OWZ001P1OWZ03000000H0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX003
05nNX08000001@1OWZ000`000000GijP05nNX00205nNX0<00000?`3jl>H10?ooo`00@03jl>H00`00
0000GijP0000000405nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ00101OWZ000`00
0000GijP05nNX00305nNX0030000001OWZ00GijP00D0GijP0`00000605nNX0030000001OWZ00GijP
00P0GijP0P00000705nNX0030000001OWZ00000000@0GijP0P00000405nNX0040000001OWZ00GijP
00000080GijP00<0000005nNX01OWZ000P1OWZ02000000@0GijP00<0000005nNX00000001`1OWZ02
000000X0GijP00<0000005nNX01OWZ00101OWZ03000000L0GijP00<0000005nNX01OWZ000`1OWZ00
0`000000GijP05nNX00405nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000P1OWZ00
0`000000GijP000000100?[`iP40oooo00100?[`iP040000001OWZ00GijP000000<0GijP00<00000
05nNX01OWZ000`1OWZ02000000H0GijP0P00000405nNX0030000001OWZ00GijP00D0GijP00@00000
05nNX000000000001@1OWZ000`000000GijP05nNX00805nNX0030000001OWZ00GijP00@0GijP00@0
000005nNX01OWZ0000000`1OWZ000`000000GijP0000000405nNX0040000001OWZ00GijP00000080
GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP0000000305nNX0040000001OWZ00GijP0000
00H0GijP00<0000005nNX01OWZ00201OWZ000`000000GijP05nNX00305nNX080000000<0GijP0000
001OWZ001P1OWZ000`000000GijP05nNX00205nNX08000001P1OWZ02000000D0GijP00D0000005nN
X01OWZ00GijP0000000205nNX0030000003jl>H0n_3V03h0n_3V0@3oool00440n_3V00<0000005nN
X01OWZ000P00000205nNX0030000001OWZ00GijP00<0GijP0P00000505nNX0D000000P1OWZ000`00
0000GijP05nNX00405nNX0040000001OWZ00GijP05nNX08000000`1OWZ000`000000GijP05nNX009
05nNX0030000001OWZ00GijP00<0GijP00@0000005nNX01OWZ0000000`1OWZ000`000000GijP0000
000305nNX0050000001OWZ00GijP05nNX00000000`1OWZ001`000000GijP05nNX01OWZ00000005nN
X00000000`1OWZ0010000000GijP05nNX000000505nNX0030000001OWZ00GijP00T0GijP00@00000
05nNX01OWZ00GijP0P00000305nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ001@00
000505nNX08000001@1OWZ000`000000GijP05nNX00200000080GijP00<000000?[`iP3jl>H0?`3j
l>H10?ooo`00@@3jl>H00`000000GijP05nNX00205nNX0030000001OWZ00000000D0GijP00<00000
05nNX00000001@1OWZ0200000080GijP1000000605nNX0030000001OWZ00GijP0080GijP0P000002
05nNX0030000001OWZ00GijP00P0GijP00<0000005nNX01OWZ000P1OWZ001@000000GijP05nNX01O
WZ00000000<0GijP00@0000005nNX01OWZ0000000P1OWZ001@000000GijP05nNX01OWZ00000000<0
GijP00@0000005nNX01OWZ0000000P1OWZ0010000000GijP05nNX000000405nNX0030000001OWZ00
GijP0080GijP00<0000005nNX01OWZ00201OWZ000`000000GijP05nNX002000000@0GijP00<00000
05nNX01OWZ00101OWZ0400000080GijP0P00000505nNX0030000001OWZ00000000D0GijP00<00000
05nNX0000000101OWZ000`000000n_3V0?[`iP0o0?[`iP40oooo00120?[`iP030000001OWZ00GijP
0080GijP0`00000505nNX0030000001OWZ00000000@0GijP00<0000005nNX0000000101OWZ030000
00D0GijP00<0000005nNX01OWZ000`1OWZ03000000X0GijP00<0000005nNX01OWZ000P1OWZ000`00
0000GijP05nNX00205nNX0030000001OWZ00000000<0GijP00<0000005nNX0000000101OWZ000`00
0000GijP05nNX00205nNX0030000001OWZ00000000<0GijP00<0000005nNX0000000101OWZ000`00
0000GijP05nNX00205nNX0030000001OWZ00GijP00P0GijP0`00000505nNX0030000001OWZ00GijP
00<0GijP0`00000405nNX0030000001OWZ00000000@0GijP00<0000005nNX00000001@1OWZ030000
00@0GijP00<000000?[`iP3jl>H0@03jl>H10?ooo`00@P3jl>H00`000000GijP05nNX00405nNX003
0000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000P00000205nNX0040000001OWZ00GijP0000
00D0GijP0`00000405nNX0030000001OWZ00GijP00@0GijP0`00000905nNX0040000001OWZ00GijP
000000D0GijP00<0000005nNX00000000`1OWZ000`000000GijP0000000405nNX0030000001OWZ00
GijP0080GijP00<0000005nNX00000000`1OWZ000`000000GijP0000000505nNX0040000001OWZ00
GijP000000T0GijP0`00000605nNX0030000001OWZ00GijP0080GijP0`00000505nNX0040000001O
WZ00GijP00000080GijP0P00000205nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ00
101OWZ000`000000n_3V0?[`iP100?[`iP40oooo00130?[`iP030000001OWZ00GijP00<0GijP0P00
000505nNX0050000001OWZ00GijP05nNX00000000P1OWZ0010000000GijP05nNX000000505nNX004
0000001OWZ000000000000<0GijP00<0000005nNX01OWZ001@1OWZ04000000H0GijP00@0000005nN
X01OWZ0000001@1OWZ000`000000GijP0000000305nNX08000001@1OWZ000`000000GijP05nNX003
05nNX08000000`1OWZ000`000000GijP0000000505nNX0040000001OWZ00GijP000000H0GijP1000
000705nNX0040000001OWZ00GijP05nNX080000000<0GijP0000001OWZ00101OWZ0010000000GijP
05nNX000000205nNX0050000001OWZ00GijP05nNX00000001@1OWZ02000000D0GijP00<000000?[`
iP3jl>H0@@3jl>H10?ooo`00@`3jl>H00`000000GijP05nNX00405nNX0<000000`1OWZ000`000000
GijP05nNX00205nNX0030000001OWZ00000000<0GijP00<0000005nNX01OWZ000P1OWZ0010000000
GijP05nNX01OWZ020000000305nNX0000000GijP00H0GijP00@0000005nNX01OWZ00GijP0`000003
05nNX0030000001OWZ00000000L0GijP00<0000005nNX01OWZ000P1OWZ02000000D0GijP00<00000
05nNX01OWZ000`1OWZ02000000@0GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP00000003
05nNX0<000000`1OWZ000`000000GijP05nNX00505nNX0040000001OWZ000000000000<0GijP00<0
000005nNX01OWZ000P1OWZ001`000000GijP05nNX01OWZ00000005nNX0000000101OWZ0010000000
GijP05nNX01OWZ03000000H0GijP00<000000?[`iP3jl>H0@@3jl>H10?ooo`00A03jl>H00`000000
GijP05nNX00305nNX0040000001OWZ00GijP000000<0GijP00<0000005nNX01OWZ000P1OWZ020000
00@0GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00205nNX0<000001`1OWZ000`00
0000GijP05nNX00305nNX0<0000000<0GijP0000000000001`1OWZ000`000000GijP05nNX00205nN
X0030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00205nN
X0030000001OWZ00GijP00D0GijP0P000000101OWZ00000000000000000505nNX0030000001OWZ00
GijP00D0GijP0`00000405nNX0030000001OWZ00GijP0080GijP00<0000005nNX01OWZ000P1OWZ02
000000@0GijP00D0000005nNX01OWZ00GijP0000000205nNX0030000001OWZ00GijP00<0GijP00<0
00000?[`iP3jl>H0@P3jl>H10?ooo`00A03jl>H00`000000GijP05nNX00405nNX0040000001OWZ00
GijP00000080GijP00<0000005nNX01OWZ000`1OWZ02000000@0GijP00<0000005nNX01OWZ000P1O
WZ000`000000GijP05nNX00305nNX0<000001P1OWZ000`000000GijP05nNX00505nNX08000001`1O
WZ02000000@0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00405nNX0030000001O
WZ00GijP0080GijP0P00000705nNX08000001`1OWZ000`000000GijP05nNX00405nNX0<000001@1O
WZ000`000000GijP05nNX00205nNX0030000001OWZ00GijP0080GijP0P00000505nNX0040000001O
WZ00GijP00000080GijP00<0000005nNX01OWZ00101OWZ000`000000n_3V0?[`iP120?[`iP40oooo
00150?[`iP030000001OWZ00GijP00<0GijP00D0000005nNX01OWZ00GijP0000000205nNX0030000
001OWZ00GijP00<0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00205nNX0030000
001OWZ00GijP00@0GijP0`00000405nNX0030000001OWZ00GijP00H0GijP00<0000005nNX01OWZ00
1@1OWZ02000000@0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00405nNX0030000
001OWZ00GijP0080GijP0P00000605nNX0030000001OWZ00GijP00L0GijP00<0000005nNX01OWZ00
0P1OWZ03000000H0GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00305nNX0030000
001OWZ00GijP00<0GijP00@0000005nNX01OWZ0000000`1OWZ000`000000GijP05nNX00305nNX003
0000003jl>H0n_3V04<0n_3V0@3oool004D0n_3V00<0000005nNX01OWZ00101OWZ0010000000GijP
05nNX01OWZ03000000D0GijP0P00000505nNX0030000001OWZ00GijP0080GijP00<0000005nNX01O
WZ000`1OWZ000`000000GijP05nNX002000000<0GijP00<0000005nNX01OWZ001P1OWZ000`000000
GijP05nNX00305nNX0040000001OWZ00GijP00000080GijP0P00000605nNX0030000001OWZ00GijP
00@0GijP0P00000205nNX0040000001OWZ00GijP000000D0GijP00<0000005nNX01OWZ001P1OWZ00
10000000GijP05nNX01OWZ0200000080GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nN
X00205nNX0030000001OWZ00GijP00<0GijP0P00000505nNX0<000000`1OWZ000`000000GijP05nN
X00405nNX0030000003jl>H0n_3V04<0n_3V0@3oool004H0n_3V00<0000005nNX01OWZ000`1OWZ00
0`000000GijP05nNX00305nNX08000001@1OWZ03000000@0GijP0P00000305nNX0030000001OWZ00
GijP00<0GijP00@0000005nNX01OWZ00GijP0P00000205nNX0030000001OWZ00GijP00D0GijP00<0
000005nNX01OWZ000`1OWZ0010000000GijP05nNX000000205nNX08000001P1OWZ000`000000GijP
05nNX00305nNX0030000001OWZ0000000080GijP00@0000005nNX01OWZ000000101OWZ000`000000
GijP05nNX00605nNX0030000001OWZ00GijP008000000`1OWZ000`000000GijP05nNX00305nNX004
0000001OWZ00GijP05nNX0800000101OWZ03000000D0GijP0P00000505nNX0030000001OWZ00GijP
00<0GijP00<000000?[`iP3jl>H0A03jl>H10?ooo`00AP3jl>H00`000000GijP05nNX00305nNX003
0000001OWZ00GijP00@0GijP00<0000005nNX01OWZ000`1OWZ0010000000GijP05nNX000000305nN
X0@0000000<0GijP0000001OWZ001@1OWZ000`000000GijP05nNX00205nNX0<00000201OWZ001@00
0000GijP05nNX01OWZ00000000<0GijP00H0000005nNX01OWZ00000005nNX000000405nNX0<00000
101OWZ000`000000GijP0000000205nNX0050000001OWZ00GijP05nNX00000000`1OWZ000`000000
GijP05nNX00605nNX0<00000101OWZ000`000000GijP05nNX00405nNX0030000001OWZ00000000<0
00000`1OWZ0010000000GijP05nNX000000505nNX0030000001OWZ00GijP00<0GijP00<0000005nN
X01OWZ00101OWZ000`000000n_3V0?[`iP140?[`iP40oooo00170?[`iP030000001OWZ00GijP00<0
GijP00<0000005nNX01OWZ000`1OWZ02000000D0GijP00@0000005nNX01OWZ0000000`1OWZ020000
000405nNX00000000000000000D0GijP00<0000005nNX01OWZ00101OWZ03000000H0GijP00D00000
05nNX01OWZ00GijP0000000305nNX0030000001OWZ0000000080GijP00<0000005nNX01OWZ000P1O
WZ03000000@0GijP00H0000005nNX01OWZ00000005nNX000000305nNX0040000001OWZ00GijP0000
00L0GijP0`00000505nNX0030000001OWZ00GijP00@0GijP0`0000000`1OWZ0000000000000305nN
X0040000001OWZ00GijP000000D0GijP0P00000505nNX0030000001OWZ00GijP00<0GijP00<00000
0?[`iP3jl>H0A@3jl>H10?ooo`00A`3jl>H00`000000GijP05nNX00305nNX0030000001OWZ00GijP
00@0GijP0`00000305nNX0050000001OWZ00GijP05nNX00000000P1OWZ000`000000GijP00000002
05nNX0<00000101OWZ000`000000GijP05nNX00505nNX0@00000101OWZ000`000000GijP00000004
05nNX0030000001OWZ0000000080GijP00T0000005nNX01OWZ00GijP0000001OWZ00000005nNX000
00000`1OWZ001P000000GijP05nNX0000000GijP000000@0GijP00<0000005nNX0000000101OWZ04
000000L0GijP00<0000005nNX01OWZ000P1OWZ0300000080GijP00<0000005nNX00000000P1OWZ00
1@000000GijP05nNX01OWZ00000000<0GijP0`00000605nNX0030000001OWZ00GijP00<0GijP00<0
00000?[`iP3jl>H0A@3jl>H10?ooo`00A`3jl>H3000000@0GijP00<0000005nNX01OWZ000`1OWZ00
10000000GijP05nNX000000305nNX0050000001OWZ00GijP05nNX00000000P1OWZ000`000000GijP
0000000405nNX08000000`1OWZ000`000000GijP05nNX00405nNX0040000001OWZ00GijP05nNX0D0
000000<0GijP0000001OWZ00101OWZ0200000080GijP00T0000005nNX01OWZ00GijP0000001OWZ00
000005nNX00000000`1OWZ000`000000GijP05nNX002000000D0GijP0P0000000`1OWZ0000000000
0002000000<0GijP00<0000005nNX01OWZ00101OWZ0010000000GijP05nNX01OWZ02000000@0GijP
00<0000005nNX00000000P1OWZ001@000000GijP05nNX01OWZ00000000<0GijP00@0000005nNX01O
WZ0000001@1OWZ000`000000GijP05nNX00205nNX0<00000A`3jl>H10?ooo`00B03jl>H00`000000
GijP0000000305nNX0030000001OWZ00GijP00@0GijP00@0000005nNX01OWZ0000000P1OWZ000`00
0000GijP05nNX00205nNX0<000000P1OWZ000`000000GijP05nNX00305nNX08000000P1OWZ000`00
0000GijP05nNX00405nNX0030000001OWZ00GijP00@0GijP0P00000605nNX0050000001OWZ00GijP
05nNX00000000P1OWZ0010000000GijP05nNX000000205nNX0040000001OWZ00GijP000000<0GijP
00<0000005nNX01OWZ00101OWZ02000000H0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP
05nNX002000000D0GijP00<0000005nNX01OWZ000`00000405nNX0040000001OWZ00GijP00000080
GijP00<0000005nNX01OWZ00101OWZ001`000000GijP05nNX01OWZ00000005nNX0000000B03jl>H1
0?ooo`00B03jl>H00`000000GijP05nNX00200000080GijP00<0000005nNX01OWZ000`1OWZ001@00
0000GijP05nNX01OWZ0000000080GijP00<0000005nNX01OWZ000`1OWZ0200000080GijP00<00000
05nNX01OWZ00101OWZ03000000H0GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX004
05nNX0050000001OWZ00GijP05nNX00000000P1OWZ0010000000GijP05nNX000000205nNX0030000
001OWZ00000000@0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00505nNX0030000
001OWZ00GijP00@0GijP0`00000605nNX0030000001OWZ00GijP008000001@1OWZ0010000000GijP
05nNX000000305nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000P00000205nNX003
0000003jl>H0n_3V04H0n_3V0@3oool004T0n_3V00L0000005nNX01OWZ00GijP0000001OWZ000000
00H0GijP00@0000005nNX01OWZ00GijP0`00000605nNX0050000001OWZ00GijP05nNX00000001`1O
WZ03000000D0GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX00205nNX0030000001O
WZ00GijP00<0GijP0P00000305nNX0040000001OWZ00GijP05nNX0800000101OWZ000`000000GijP
05nNX00305nNX0030000001OWZ00GijP00D0GijP00<0000005nNX01OWZ000`1OWZ03000000L0GijP
00D0000005nNX01OWZ00GijP0000000605nNX0<000000`1OWZ000`000000GijP05nNX00405nNX003
0000001OWZ00000000<0GijP00<000000?[`iP3jl>H0A`3jl>H10?ooo`00B@3jl>H00`000000GijP
05nNX00205nNX0<000001@1OWZ000`000000GijP05nNX00305nNX08000001@1OWZ000`000000GijP
05nNX00205nNX0030000001OWZ00GijP00H0GijP0`00000305nNX0030000001OWZ00GijP00D0GijP
00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00305nNX08000000`1OWZ0010000000GijP
05nNX01OWZ02000000D0GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00505nNX004
0000001OWZ00GijP05nNX0<00000201OWZ000`000000GijP05nNX00205nNX0030000001OWZ00GijP
00<0GijP0P00000505nNX0030000001OWZ00GijP00<0GijP0`00000405nNX0030000003jl>H0n_3V
04L0n_3V0@3oool004X0n_3V00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00405nNX003
0000001OWZ00GijP00<0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00205nNX003
0000001OWZ00GijP00H0GijP00@0000005nNX000000000000P1OWZ000`000000GijP05nNX00405nN
X0050000001OWZ00GijP05nNX00000001P1OWZ000`000000GijP05nNX00205nNX0030000001OWZ00
GijP0080GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00205nNX0030000001OWZ00
GijP00@0GijP00<0000005nNX01OWZ000P0000000`1OWZ00000005nNX00705nNX0030000001OWZ00
GijP0080GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00305nNX0030000001OWZ00
GijP00@0GijP00<0000005nNX01OWZ000`1OWZ000`000000n_3V0?[`iP180?[`iP40oooo001:0?[`
iP030000001OWZ00GijP00<0GijP0`00000405nNX0030000001OWZ00GijP00<0GijP0`00000405nN
X0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ001@1OWZ0010000000GijP05nNX01OWZ03
000000L0GijP00@0000005nNX01OWZ0000001@1OWZ02000000@0GijP00<0000005nNX01OWZ000P1O
WZ02000000D0GijP00@0000005nNX01OWZ0000001`1OWZ03000000<0GijP00<0000005nNX01OWZ00
1@1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP0080GijP0`00000505nNX0030000
001OWZ00GijP0080GijP0`00000505nNX0030000003jl>H0n_3V04P0n_3V0@3oool004/0n_3V00<0
000005nNX01OWZ000`1OWZ0010000000GijP00000000000305nNX0030000001OWZ00GijP00<0GijP
00<0000005nNX0000000101OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP00D0GijP
00<0000005nNX01OWZ000P1OWZ03000000D0GijP00<0000005nNX00000001P1OWZ02000000@0GijP
00<0000005nNX01OWZ000P1OWZ02000000D0GijP00@0000005nNX01OWZ0000001@1OWZ03000000@0
GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP0080
GijP00<0000005nNX00000001@1OWZ0010000000GijP05nNX01OWZ020000000305nNX0000000GijP
00@0GijP00<000000?[`iP3jl>H0B@3jl>H10?ooo`00B`3jl>H00`000000GijP05nNX00305nNX004
0000001OWZ00GijP05nNX080000000<0GijP0000001OWZ00101OWZ0010000000GijP05nNX0000003
05nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX004
05nNX08000000`1OWZ000`000000GijP0000000505nNX0030000001OWZ00000000@0GijP00<00000
05nNX01OWZ000P1OWZ000`000000GijP0000000505nNX0030000001OWZ00000000<0GijP0P000006
05nNX0030000001OWZ00GijP00D0GijP00<0000005nNX01OWZ00101OWZ001@000000GijP05nNX01O
WZ0000000080GijP00<0000005nNX01OWZ000`1OWZ0010000000GijP00000000000305nNX0030000
001OWZ00GijP00<0GijP00<000000?[`iP3jl>H0B@3jl>H10?ooo`00B`3jl>H00`000000GijP05nN
X00305nNX0030000001OWZ00GijP00<0GijP0`00000505nNX0030000001OWZ00GijP008000000P1O
WZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP00D0GijP00<0000005nNX01OWZ001@1O
WZ030000000305nNX0000000GijP00D0GijP00@0000005nNX01OWZ0000000`1OWZ001@000000GijP
05nNX01OWZ0000000080GijP00<0000005nNX01OWZ000`1OWZ020000000405nNX000000000000000
00L0GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP
008000000P1OWZ000`000000GijP05nNX00305nNX0<000001@1OWZ000`000000GijP05nNX00305nN
X0030000003jl>H0n_3V04T0n_3V0@3oool004`0n_3V00<0000005nNX01OWZ000P1OWZ000`000000
GijP05nNX00505nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000P1OWZ000`000000
GijP0000000705nNX08000001P1OWZ000`000000GijP05nNX00705nNX08000001@1OWZ001@000000
GijP05nNX01OWZ00000000<0GijP00D0000005nNX01OWZ00GijP0000000305nNX0030000001OWZ00
GijP00<0GijP0P00000905nNX0030000001OWZ00GijP00@0GijP0P00000705nNX0030000001OWZ00
000000@0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00505nNX0030000001OWZ00
GijP0080GijP00<000000?[`iP3jl>H0BP3jl>H10?ooo`00C03jl>H00`000000GijP05nNX00305nN
X0030000001OWZ00GijP00@0GijP0`00000405nNX0030000001OWZ00GijP0080GijP0`00000605nN
X0D000000`1OWZ000`000000GijP05nNX00805nNX0030000001OWZ00GijP00<0GijP00D0000005nN
X01OWZ00GijP0000000305nNX0050000001OWZ00GijP05nNX00000000`1OWZ000`000000GijP05nN
X00205nNX0030000001OWZ00GijP00T0GijP00@0000005nNX01OWZ00GijP1@00000605nNX0<00000
101OWZ000`000000GijP05nNX00205nNX0<000001P1OWZ000`000000GijP05nNX00305nNX0030000
003jl>H0n_3V04X0n_3V0@3oool004d0n_3V00<0000005nNX01OWZ000P1OWZ000`000000GijP05nN
X00505nNX0030000001OWZ00000000<0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nN
X00505nNX08000000P1OWZ05000000X0GijP00D0000005nNX01OWZ00GijP0000000405nNX0050000
001OWZ00GijP05nNX00000000`1OWZ000`000000GijP05nNX00205nNX0050000001OWZ00GijP05nN
X00000002P1OWZ0500000080GijP0P00000705nNX0030000001OWZ00GijP00@0GijP00L0000005nN
X01OWZ00GijP0000001OWZ00000000L0GijP00<0000005nNX01OWZ000P1OWZ000`000000n_3V0?[`
iP1;0?[`iP40oooo001=0?[`iP030000001OWZ00GijP0080GijP00<0000005nNX01OWZ001@1OWZ00
0`000000GijP05nNX00200000080GijP00<0000005nNX01OWZ000`1OWZ02000000H0GijP00<00000
05nNX00000001@1OWZ03000000P0GijP00D0000005nNX01OWZ00GijP0000000405nNX0030000001O
WZ00GijP008000000`1OWZ000`000000GijP05nNX00205nNX0040000001OWZ00GijP000000T0GijP
0`00000505nNX0030000001OWZ00000000H0GijP0P00000505nNX0030000001OWZ00GijP00800000
0P1OWZ000`000000GijP05nNX00505nNX0030000001OWZ00GijP0080GijP00<000000?[`iP3jl>H0
B`3jl>H10?ooo`00CP3jl>H00`000000GijP05nNX00205nNX0030000001OWZ00GijP00@0GijP00<0
000005nNX01OWZ000P1OWZ000`000000GijP0000000605nNX0<00000101OWZ0010000000GijP05nN
X000000605nNX0D000001@1OWZ000`000000GijP0000000505nNX0030000001OWZ00GijP00<00000
0P1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00000000D0GijP1@00000605nNX0040000
001OWZ00GijP000000@0GijP0`00000605nNX0030000001OWZ00000000@0GijP00<0000005nNX01O
WZ00101OWZ000`000000GijP05nNX00205nNX0030000003jl>H0n_3V04`0n_3V0@3oool004h0n_3V
00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00505nNX0030000001OWZ00GijP0080GijP
0`00000505nNX0040000001OWZ00GijP000000<0GijP00D0000005nNX01OWZ00GijP0000000605nN
X0040000001OWZ00GijP05nNX0@0000000@0GijP0000001OWZ0000001P1OWZ020000000505nNX000
0000000005nNX00000001P1OWZ0200000080GijP1000000305nNX0030000001OWZ00GijP00@0GijP
00@0000005nNX01OWZ000000101OWZ0010000000GijP05nNX000000505nNX0<00000101OWZ000`00
0000GijP05nNX00505nNX0030000001OWZ00GijP0080GijP00<000000?[`iP3jl>H0C03jl>H10?oo
o`00C`3jl>H01@000000GijP05nNX01OWZ00000000L0GijP00<0000005nNX01OWZ00101OWZ000`00
0000GijP05nNX00405nNX0040000001OWZ00GijP000000<0GijP00D0000005nNX01OWZ00GijP0000
000505nNX0030000001OWZ00GijP00D0GijP0`00000705nNX080000000<0GijP0000001OWZ000P00
000705nNX0<000001`1OWZ000`000000GijP05nNX00305nNX0050000001OWZ00GijP05nNX0000000
0`1OWZ0010000000GijP05nNX000000605nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01O
WZ001@1OWZ001@000000GijP05nNX01OWZ00000004l0n_3V0@3oool004h0n_3V0`00000205nNX003
0000001OWZ00GijP00D0GijP00<0000005nNX01OWZ00101OWZ03000000@0GijP00D0000005nNX01O
WZ00GijP0000000205nNX0030000001OWZ00GijP0080GijP00<0000005nNX01OWZ000`1OWZ000`00
0000GijP05nNX00605nNX0030000001OWZ00GijP00D0GijP00D0000005nNX01OWZ00000005nNX002
000000L0GijP00<0000005nNX01OWZ001P1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00
GijP0080GijP00@0000005nNX01OWZ0000000`1OWZ000`000000GijP05nNX00205nNX0<000001P1O
WZ000`000000GijP05nNX00505nNX0030000001OWZ00GijP00<00000CP3jl>H10?ooo`00B`3jl>H3
000000<0GijP0P0000000`1OWZ00000005nNX00605nNX0030000001OWZ00GijP00@0GijP00@00000
05nNX000000000000`1OWZ0010000000GijP05nNX01OWZ03000000D0GijP00<0000005nNX01OWZ00
0`1OWZ000`000000GijP05nNX00605nNX0030000001OWZ00GijP00@0GijP00@0000005nNX01OWZ00
00000P1OWZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP00H0GijP00<0000005nNX01O
WZ000`1OWZ000`000000GijP05nNX00305nNX0<000000`1OWZ0010000000GijP05nNX01OWZ020000
000305nNX0000000GijP00D0GijP00<0000005nNX01OWZ001@1OWZ0010000000GijP000000000003
05nNX0<00000B`3jl>H10?ooo`00B03jl>H3000000P0GijP0`00000605nNX0030000001OWZ00GijP
00@0GijP00@0000005nNX01OWZ00GijP0P0000000`1OWZ00000005nNX00405nNX08000001@1OWZ00
0`000000GijP05nNX00305nNX0030000001OWZ00GijP00D0GijP00<0000005nNX01OWZ000`1OWZ00
1@000000GijP05nNX01OWZ00000000<0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nN
X00505nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000`1OWZ02000000D0GijP00@0
000005nNX000000000000`1OWZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP00@0GijP
0`00000805nNX0<00000B03jl>H10?ooo`00A@3jl>H3000000X0GijP0P00000205nNX0<000000`1O
WZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP00<0GijP0`00000505nNX0030000001O
WZ00GijP00@0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00505nNX0030000001O
WZ00GijP0080GijP00D0000005nNX01OWZ00GijP0000000305nNX0030000001OWZ00GijP0080GijP
00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP00@0GijP
00<0000005nNX01OWZ000`1OWZ03000000D0GijP00<0000005nNX01OWZ00101OWZ0010000000GijP
05nNX01OWZ0300000080GijP0P00000:05nNX0<00000A@3jl>H10?ooo`00@P3jl>H3000000/0GijP
0P00000705nNX0<0000000<0GijP0000001OWZ00101OWZ000`000000GijP05nNX00505nNX0030000
001OWZ00GijP00<0GijP0P00000605nNX08000000`1OWZ000`000000GijP05nNX00505nNX0050000
001OWZ00GijP05nNX0000000101OWZ000`000000GijP05nNX00205nNX0050000001OWZ00GijP05nN
X00000001`1OWZ0010000000GijP05nNX01OWZ02000000H0GijP0P00000505nNX0030000001OWZ00
GijP00@0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP00000002000000L0GijP0P00000;
05nNX0<00000@P3jl>H10?ooo`00?`3jl>H3000000`0GijP0P00000<05nNX08000001P1OWZ000`00
0000GijP05nNX00405nNX0030000001OWZ00GijP00<0GijP00@0000005nNX00000000000101OWZ07
000000L0GijP00@0000005nNX01OWZ000000101OWZ000`000000GijP05nNX00205nNX0040000001O
WZ00GijP000000L0GijP1`00000405nNX0<000001P1OWZ000`000000GijP05nNX00405nNX0030000
001OWZ00GijP00@0GijP0P00000<05nNX0800000301OWZ03000003l0n_3V0@3oool003`0n_3V0`00
000=05nNX08000003@1OWZ020000000305nNX0000000000000@0GijP00<0000005nNX01OWZ001@1O
WZ000`000000GijP05nNX00305nNX0040000001OWZ00GijP000000@0GijP0P00000305nNX0<00000
1@1OWZ000`000000GijP0000000505nNX0030000001OWZ00GijP00<0GijP00<0000005nNX0000000
1@1OWZ03000000<0GijP0P00000405nNX0040000001OWZ00GijP000000D0GijP00<0000005nNX01O
WZ001@1OWZ000`000000GijP05nNX00205nNX080000000<0GijP0000000000003@1OWZ02000000d0
GijP0`00000l0?[`iP40oooo000j0?[`iP8000000`1OWZ03000000P0GijP0P00000=05nNX0800000
1@1OWZ0200000080GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX00305nNX0050000
001OWZ00GijP05nNX00000000`1OWZ000`000000GijP0000000505nNX0@000000P1OWZ02000000D0
GijP00<0000005nNX01OWZ000`1OWZ0200000080GijP1000000505nNX0030000001OWZ00000000<0
GijP00D0000005nNX01OWZ00GijP0000000505nNX0030000001OWZ00GijP00D0GijP00<0000005nN
X01OWZ000P00000505nNX08000003@1OWZ02000000P0GijP0`00000305nNX0800000>P3jl>H10?oo
o`00=`3jl>H3000000P0GijP1000000205nNX08000003@1OWZ02000000T0GijP0P0000000`1OWZ00
000005nNX00505nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000P1OWZ0010000000
GijP05nNX000000205nNX0030000001OWZ00GijP00H0GijP0`00000605nNX0030000001OWZ00GijP
00@0GijP0`00000805nNX0040000001OWZ00GijP00000080GijP00<0000005nNX01OWZ000P1OWZ00
0`000000GijP05nNX00205nNX0030000001OWZ00GijP00D0GijP00@0000005nNX000000000002@1O
WZ02000000d0GijP0P00000205nNX0@00000201OWZ03000003L0n_3V0@3oool003D0n_3V0P00000?
05nNX0@000002`1OWZ02000000d0GijP0`00000605nNX0030000001OWZ00GijP0080GijP00<00000
05nNX01OWZ000`1OWZ03000000<0GijP00<0000005nNX01OWZ001`1OWZ000`000000GijP05nNX004
05nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ001`1OWZ0010000000GijP05nNX01O
WZ03000000@0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00405nNX0<000003@1O
WZ02000000/0GijP1000000?05nNX0800000=@3jl>H10?ooo`00<P3jl>H3000000h0GijP0`000004
05nNX0H000000`1OWZ02000000h0GijP0P00000205nNX0<000000`1OWZ000`000000GijP05nNX003
05nNX0030000001OWZ00GijP00@0GijP0P00000305nNX0030000001OWZ00GijP00L0GijP00<00000
05nNX01OWZ000`1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP00L0GijP00@00000
05nNX01OWZ00GijP0P00000605nNX0030000001OWZ00GijP00<0GijP00@0000005nNX01OWZ00GijP
0`00000205nNX08000003P1OWZ02000000<0GijP1P00000405nNX0<000003P1OWZ0300000380n_3V
0@3oool002l0n_3V0`00000>05nNX0<000003@1OWZ04000000d0GijP0P00000705nNX0<0000000<0
GijP0000001OWZ000`1OWZ000`000000GijP05nNX00505nNX0030000001OWZ00GijP0080GijP00<0
000005nNX01OWZ001P1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP00<0GijP00<0
000005nNX01OWZ001P1OWZ000`000000GijP05nNX00205nNX0030000001OWZ00GijP00D0GijP00<0
000005nNX01OWZ000P1OWZ000`000000GijP00000002000000L0GijP0P00000=05nNX0@000003@1O
WZ03000000h0GijP0`00000_0?[`iP40oooo000]0?[`iP8000003@1OWZ04000000h0GijP0`000003
05nNX0<00000201OWZ02000000`0GijP0P00000405nNX0030000001OWZ00GijP00D0GijP00<00000
05nNX01OWZ000`1OWZ000`000000GijP05nNX00505nNX0030000001OWZ00GijP00<0GijP00<00000
05nNX01OWZ000P1OWZ000`000000GijP05nNX00605nNX0030000001OWZ00GijP00<0GijP00<00000
05nNX01OWZ001@1OWZ000`000000GijP05nNX00205nNX0800000301OWZ02000000P0GijP0`000003
05nNX0<000003P1OWZ04000000d0GijP0P00000]0?[`iP40oooo000Z0?[`iPL00000201OWZ030000
0100GijP0P00000905nNX0@000000P1OWZ02000000d0GijP0P0000000`1OWZ0000000000000205nN
X0030000001OWZ00GijP00D0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00505nN
X0040000001OWZ00GijP05nNX0<000000`1OWZ000`000000GijP05nNX00505nNX0030000001OWZ00
GijP00<0GijP00<0000005nNX01OWZ001@1OWZ0010000000GijP05nNX01OWZ020000000305nNX000
0000000000d0GijP0P00000205nNX0@000002@1OWZ0200000100GijP0`00000805nNX0L00000:P3j
l>H10?ooo`009`3jl>H3000000L0GijP2P00000>05nNX0<000003`1OWZ04000000/0GijP0P000005
05nNX080000000<0GijP0000001OWZ001P1OWZ000`000000GijP05nNX00405nNX0030000001OWZ00
GijP00@0GijP00P0000005nNX01OWZ00000005nNX0000000GijP00000080GijP00<0000005nNX01O
WZ00101OWZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP00D0GijP00@0000005nNX000
000000001@1OWZ02000000/0GijP1000000?05nNX0<000003P1OWZ0:000000L0GijP0`00000W0?[`
iP40oooo000T0?[`iP<000003@1OWZ02000000D0GijP1P00000505nNX0<000003`1OWZ03000000@0
GijP1@00000405nNX08000002@1OWZ03000000H0GijP00<0000005nNX01OWZ001@1OWZ000`000000
GijP05nNX00405nNX08000000P1OWZ000`000000GijP05nNX002000000H0GijP00<0000005nNX01O
WZ001@1OWZ000`000000GijP05nNX00405nNX0<000002@1OWZ02000000@0GijP1@00000405nNX0<0
00003`1OWZ03000000D0GijP1P00000505nNX08000003@1OWZ03000002@0n_3V0@3oool00240n_3V
0`00000=05nNX0<000003@1OWZ06000000h0GijP0`00000<05nNX0@000002P1OWZ0200000080GijP
0P00000405nNX0030000001OWZ00GijP00H0GijP1`00000305nNX0040000001OWZ00GijP05nNX0L0
0000201OWZ000`000000GijP05nNX00205nNX08000000P1OWZ02000000X0GijP1000000<05nNX0<0
00003P1OWZ06000000d0GijP0`00000=05nNX0<000008@3jl>H10?ooo`007P3jl>H3000000d0GijP
0`00000?05nNX0<00000101OWZ06000000D0GijP0`00000=05nNX0<000002`1OWZ02000000H0GijP
0P00000205nNX0030000001OWZ00GijP00H0GijP0P00000805nNX0030000001OWZ00GijP00H0GijP
0P00000705nNX0040000001OWZ00GijP05nNX08000001P1OWZ02000000/0GijP0`00000=05nNX0<0
00001@1OWZ06000000@0GijP0`00000?05nNX0<000003@1OWZ03000001h0n_3V0@3oool001/0n_3V
0`00000>05nNX0800000401OWZ02000000d0GijP2P00000805nNX0<00000301OWZ02000000X0GijP
0P0000000`1OWZ00000005nNX00605nNX0030000001OWZ00000000L0GijP00<0000005nNX01OWZ00
1@1OWZ000`000000GijP0000000705nNX0040000001OWZ000000000000X0GijP0P00000<05nNX0<0
0000201OWZ0:000000d0GijP0P00000@05nNX08000003P1OWZ03000001/0n_3V0@3oool001P0n_3V
2000000905nNX0<000003`1OWZ03000000h0GijP0`00000805nNX0T00000301OWZ02000000h0GijP
0`00000605nNX0040000001OWZ00GijP000000H0GijP00<0000005nNX01OWZ00101OWZ0010000000
GijP05nNX000000605nNX0<000003P1OWZ02000000`0GijP2@00000805nNX0<000003P1OWZ030000
00l0GijP0`00000905nNX0P00000603jl>H10?ooo`005@3jl>H3000000P0GijP3`00000905nNX0<0
00003`1OWZ02000000h0GijP0P00000405nNX0H00000101OWZ02000000l0GijP0P00000205nNX080
0000101OWZ001@000000GijP05nNX01OWZ00000000D0GijP00<0000005nNX01OWZ000`1OWZ001@00
0000GijP05nNX01OWZ00000000@0GijP0P00000205nNX08000003`1OWZ02000000@0GijP1P000004
05nNX08000003P1OWZ02000000l0GijP0`00000905nNX0l00000201OWZ03000001D0n_3V0@3oool0
01<0n_3V0P00000@05nNX0800000201OWZ0?000000T0GijP0`00000>05nNX0800000301OWZ070000
00`0GijP0P00000605nNX0<0000000<0GijP0000001OWZ000`1OWZ000`000000GijP05nNX00205nN
X0030000001OWZ00GijP0080GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP000000020000
00H0GijP0P00000<05nNX0L00000301OWZ02000000h0GijP0`00000905nNX0l00000201OWZ020000
0100GijP0P00000C0?[`iP40oooo000@0?[`iP<00000401OWZ02000000l0GijP0P00000805nNX0l0
00002@1OWZ02000000l0GijP0P00000405nNX0H00000101OWZ02000000/0GijP0P00000505nNX005
0000001OWZ00GijP05nNX00000000`1OWZ000`000000GijP05nNX00305nNX08000002`1OWZ020000
00@0GijP1P00000405nNX08000003`1OWZ02000000T0GijP3`00000805nNX08000003`1OWZ020000
0100GijP0`00000@0?[`iP40oooo000=0?[`iP<000004@1OWZ02000000l0GijP0P00000>05nNX080
00002@1OWZ09000000l0GijP0P00000<05nNX0@000003@1OWZ000`000000GijP05nNX00505nNX004
0000001OWZ00GijP00000080GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX00;05nN
X0@00000301OWZ02000000l0GijP2@00000905nNX08000003P1OWZ02000000l0GijP0P00000A05nN
X0<000003@3jl>H10?ooo`002`3jl>H200000180GijP0P00000?05nNX08000003P1OWZ02000000l0
GijP0P00000@05nNX08000003`1OWZ02000000d0GijP00<0000005nNX01OWZ001`1OWZ001@000000
GijP0000001OWZ00000000T0GijP00<0000005nNX01OWZ002`1OWZ02000000l0GijP0P00000@05nN
X08000003`1OWZ02000000h0GijP0P00000?05nNX08000004P1OWZ02000000/0n_3V0@3oool000P0
n_3V0`00000B05nNX08000003`1OWZ02000000h0GijP0P00000?05nNX0800000401OWZ02000000l0
GijP0P00000>05nNX0030000001OWZ00GijP00T0GijP0`00000;05nNX0030000001OWZ00GijP00`0
GijP0P00000?05nNX0800000401OWZ02000000l0GijP0P00000>05nNX08000003`1OWZ0200000180
GijP0`0000080?[`iP40oooo00060?[`i_l00000500000060?[`iP40oooo00080?[`iP<000004@1O
WZ02000000l0GijP0P00000?05nNX08000003`1OWZ0200000100GijP0P00000>05nNX08000003`1O
WZ000`000000GijP05nNX00905nNX0<000002`1OWZ000`000000GijP05nNX00=05nNX08000003P1O
WZ0200000100GijP0P00000?05nNX08000003`1OWZ02000000l0GijP0P00000A05nNX0<00000203j
l>H10?ooo`002`3jl>H200000140GijP0P00000?05nNX08000003`1OWZ02000000l0GijP0P00000@
05nNX08000003P1OWZ02000000h0GijP00<0000005nNX01OWZ001`1OWZ001@000000GijP0000001O
WZ00000000T0GijP00<0000005nNX01OWZ00301OWZ02000000h0GijP0P00000@05nNX08000003`1O
WZ02000000l0GijP0P00000?05nNX08000004@1OWZ02000000/0n_3V0@3oool000d0n_3V0`00000@
05nNX08000003`1OWZ02000000l0GijP0P00000905nNX0T000003`1OWZ02000000`0GijP1000000=
05nNX0030000001OWZ00GijP00D0GijP00@0000005nNX01OWZ0000000P1OWZ000`000000GijP05nN
X00505nNX0030000001OWZ00GijP00/0GijP1000000<05nNX08000003`1OWZ09000000T0GijP0P00
000?05nNX08000003`1OWZ0200000100GijP0`00000=0?[`iP40oooo000@0?[`iP<000003`1OWZ02
000000l0GijP0P00000905nNX0l000002@1OWZ02000000l0GijP0P00000405nNX0H00000101OWZ02
000000/0GijP0P00000505nNX0050000001OWZ00GijP05nNX00000000`1OWZ000`000000GijP05nN
X00305nNX08000002`1OWZ02000000@0GijP1P00000405nNX08000003`1OWZ02000000T0GijP3`00
000905nNX08000003`1OWZ02000000l0GijP0`00000@0?[`iP40oooo000C0?[`iP8000003`1OWZ02
000000T0GijP3`00000905nNX0<000003P1OWZ02000000d0GijP1P00000<05nNX08000001`1OWZ02
0000000305nNX0000000GijP00<0GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX002
05nNX0030000001OWZ00GijP0080GijP00@0000005nNX000000000001`1OWZ02000000`0GijP1P00
000=05nNX08000003P1OWZ03000000T0GijP3`00000905nNX08000003`1OWZ02000001<0n_3V0@3o
ool001D0n_3V0`00000905nNX0h000002@1OWZ03000000l0GijP0P00000>05nNX08000001@1OWZ06
000000<0GijP0P00000?05nNX08000000P1OWZ03000000<0GijP00D0000005nNX01OWZ00GijP0000
000505nNX0030000001OWZ00GijP00<0GijP00D0000005nNX01OWZ00GijP0000000305nNX0<00000
0P1OWZ02000000l0GijP0P00000305nNX0H000001@1OWZ02000000h0GijP0P00000?05nNX0<00000
2@1OWZ0>000000T0GijP0`00000E0?[`iP40oooo000H0?[`iPT00000201OWZ0200000100GijP0P00
000?05nNX0<00000201OWZ0:000000/0GijP0P00000>05nNX0<000001P1OWZ0010000000GijP05nN
X000000605nNX0030000001OWZ00GijP00@0GijP00@0000005nNX01OWZ0000001P1OWZ03000000h0
GijP0P00000;05nNX0X00000201OWZ03000000l0GijP0P00000@05nNX0800000201OWZ09000001P0
n_3V0@3oool001/0n_3V0`00000=05nNX0<000003`1OWZ03000000h0GijP2@00000805nNX0<00000
301OWZ02000000X0GijP0P0000000`1OWZ00000005nNX00605nNX0030000001OWZ00000000L0GijP
00<0000005nNX01OWZ001@1OWZ000`000000GijP0000000705nNX0040000001OWZ000000000000X0
GijP0P00000<05nNX0<00000201OWZ09000000h0GijP0`00000?05nNX0<000003@1OWZ03000001/0
n_3V0@3oool001h0n_3V0`00000=05nNX0<000003`1OWZ03000000D0GijP1P00000405nNX0<00000
3@1OWZ03000000/0GijP0P00000605nNX08000000P1OWZ000`000000GijP05nNX00605nNX0800000
201OWZ000`000000GijP05nNX00605nNX08000001`1OWZ0010000000GijP05nNX01OWZ02000000H0
GijP0P00000;05nNX0<000003@1OWZ03000000@0GijP1P00000505nNX0<000003`1OWZ03000000d0
GijP0`00000N0?[`iP40oooo000Q0?[`iP<000003@1OWZ02000000h0GijP1`00000=05nNX0<00000
301OWZ03000000/0GijP0P00000205nNX0800000101OWZ000`000000GijP05nNX00605nNX0L00000
0`1OWZ0010000000GijP05nNX01OWZ07000000P0GijP00<0000005nNX01OWZ000P1OWZ0200000080
GijP0P00000;05nNX0<00000301OWZ03000000d0GijP1`00000>05nNX08000003@1OWZ0300000240
n_3V0@3oool002@0n_3V0`00000<05nNX0<000001@1OWZ06000000D0GijP0`00000?05nNX0<00000
101OWZ05000000<0GijP0P00000;05nNX08000001P1OWZ000`000000GijP05nNX00505nNX0030000
001OWZ00GijP00@0GijP0P00000205nNX0030000001OWZ00GijP008000001P1OWZ000`000000GijP
05nNX00505nNX0030000001OWZ00GijP00@0GijP0P00000;05nNX08000000`1OWZ05000000@0GijP
0`00000?05nNX0<000001@1OWZ06000000D0GijP0`00000<05nNX0<00000903jl>H10?ooo`009`3j
l>H3000000P0GijP2@00000>05nNX0800000401OWZ04000000X0GijP0P00000705nNX0<000001`1O
WZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP00@0GijP00P0000005nNX01OWZ000000
05nNX0000000GijP00000080GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00405nN
X0030000001OWZ00GijP00D0GijP0`00000705nNX08000002P1OWZ0400000100GijP0P00000>05nN
X0T00000201OWZ03000002L0n_3V0@3oool002X0n_3V2000000705nNX0<000003`1OWZ03000000X0
GijP0`00000205nNX0800000301OWZ02000000<0GijP0P0000000`1OWZ00000005nNX00605nNX003
0000001OWZ00GijP00@0GijP00<0000005nNX01OWZ001@1OWZ0010000000GijP05nNX01OWZ030000
00<0GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP
00D0GijP00<0000005nNX01OWZ000P00000305nNX0800000301OWZ0200000080GijP0`00000:05nN
X0<000003`1OWZ03000000L0GijP2000000Z0?[`iP40oooo000]0?[`iP8000003@1OWZ03000000l0
GijP0`00000305nNX0@000001`1OWZ02000000`0GijP0`00000305nNX0030000001OWZ00GijP00D0
GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00505nNX0030000001OWZ00GijP00<0
GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00605nNX0030000001OWZ00GijP00<0
GijP00<0000005nNX01OWZ001@1OWZ0010000000GijP05nNX01OWZ03000000`0GijP0P00000705nN
X0@000000`1OWZ03000000l0GijP0`00000=05nNX0800000;@3jl>H10?ooo`00;`3jl>H3000000d0
GijP1000000=05nNX0@000003@1OWZ02000000L0GijP0`0000000`1OWZ00000005nNX00305nNX003
0000001OWZ00GijP00D0GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00605nNX003
0000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00605nNX003
0000001OWZ00GijP0080GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX00205nNX003
0000001OWZ000000008000001`1OWZ02000000d0GijP1000000=05nNX0@000003@1OWZ03000002l0
n_3V0@3oool00380n_3V0P00000?05nNX0<00000101OWZ06000000<0GijP0P00000>05nNX0800000
0P1OWZ03000000<0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00405nNX0800000
0`1OWZ000`000000GijP05nNX00705nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ00
0`1OWZ000`000000GijP05nNX00705nNX0040000001OWZ00GijP05nNX08000001P1OWZ000`000000
GijP05nNX00305nNX0040000001OWZ00GijP05nNX0<000000P1OWZ02000000h0GijP0P00000305nN
X0H00000101OWZ03000000l0GijP0P00000b0?[`iP40oooo000d0?[`iP<000003`1OWZ04000000/0
GijP0P00000>05nNX08000001P1OWZ000`000000GijP05nNX00205nNX0030000001OWZ00GijP00<0
GijP0`00000305nNX0030000001OWZ00GijP00L0GijP00<0000005nNX01OWZ00101OWZ000`000000
GijP05nNX00405nNX0030000001OWZ00GijP00L0GijP00@0000005nNX01OWZ00GijP0`00000405nN
X0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ00101OWZ02000000h0GijP0P00000;05nN
X0@000003`1OWZ03000003@0n_3V0@3oool003L0n_3V0`00000905nNX0<000000P1OWZ02000000d0
GijP0P00000:05nNX0<000001P1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP0080
GijP00@0000005nNX01OWZ0000000P1OWZ000`000000GijP05nNX00705nNX08000001P1OWZ000`00
0000GijP05nNX00405nNX08000002@1OWZ0010000000GijP05nNX000000205nNX0030000001OWZ00
GijP0080GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00505nNX0<000002P1OWZ02
000000d0GijP0P00000205nNX0<000002@1OWZ03000003L0n_3V0@3oool003X0n_3V0P00000305nN
X0@000001`1OWZ02000000d0GijP0P00000605nNX080000000<0GijP0000001OWZ001P1OWZ000`00
0000GijP05nNX00305nNX0050000001OWZ00GijP05nNX00000000`1OWZ000`000000GijP00000006
05nNX0@0000000<0GijP0000000000001@1OWZ000`000000GijP05nNX00305nNX080000000<0GijP
0000000000000P00000605nNX0030000001OWZ00000000<0GijP00D0000005nNX01OWZ00GijP0000
000505nNX0030000001OWZ00GijP00D0GijP00@0000005nNX000000000001P1OWZ02000000d0GijP
0P00000705nNX0@000000`1OWZ02000003X0n_3V0@3oool003`0n_3V0`00000=05nNX08000003@1O
WZ0200000080GijP0P00000305nNX0030000001OWZ00GijP00D0GijP00<0000005nNX01OWZ000`1O
WZ0010000000GijP05nNX000000405nNX08000000`1OWZ04000000@0GijP00<0000005nNX0000000
1@1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00000000@0GijP1000000305nNX0800000
101OWZ0010000000GijP05nNX000000505nNX0030000001OWZ00GijP00D0GijP00@0000005nNX01O
WZ00GijP0P00000205nNX08000003@1OWZ02000000d0GijP0`00000l0?[`iP40oooo000o0?[`iP<0
0000301OWZ02000000`0GijP0`00000505nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01O
WZ000`1OWZ0010000000GijP00000000000405nNX0L000001`1OWZ0010000000GijP05nNX0000004
05nNX0030000001OWZ00GijP0080GijP00@0000005nNX01OWZ0000001`1OWZ07000000@0GijP0`00
000605nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ000`1OWZ03000000`0GijP0P00
000<05nNX0<00000?`3jl>H10?ooo`00@P3jl>H3000000/0GijP0P00000705nNX0<0000000<0GijP
0000001OWZ00101OWZ000`000000GijP05nNX00505nNX0030000001OWZ00GijP00<0GijP0P000006
05nNX08000000`1OWZ000`000000GijP05nNX00505nNX0050000001OWZ00GijP05nNX0000000101O
WZ000`000000GijP05nNX00205nNX0050000001OWZ00GijP05nNX00000001`1OWZ0010000000GijP
05nNX01OWZ02000000H0GijP0P00000505nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01O
WZ00101OWZ000`000000GijP00000002000000L0GijP0P00000;05nNX0<00000@P3jl>H10?ooo`00
A@3jl>H3000000X0GijP0P00000205nNX0<000000`1OWZ000`000000GijP05nNX00405nNX0030000
001OWZ00GijP00<0GijP0`00000505nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ00
0`1OWZ000`000000GijP05nNX00505nNX0030000001OWZ00GijP0080GijP00D0000005nNX01OWZ00
GijP0000000305nNX0030000001OWZ00GijP0080GijP00<0000005nNX01OWZ001@1OWZ000`000000
GijP05nNX00305nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ000`1OWZ03000000D0
GijP00<0000005nNX01OWZ00101OWZ0010000000GijP05nNX01OWZ0300000080GijP0P00000:05nN
X0<00000A@3jl>H10?ooo`00B03jl>H3000000P0GijP0`00000605nNX0030000001OWZ00GijP00@0
GijP00@0000005nNX01OWZ00GijP0P0000000`1OWZ00000005nNX00405nNX08000001@1OWZ000`00
0000GijP05nNX00305nNX0030000001OWZ00GijP00D0GijP00<0000005nNX01OWZ000`1OWZ001@00
0000GijP05nNX01OWZ00000000<0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX005
05nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000`1OWZ02000000D0GijP00@00000
05nNX000000000000`1OWZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP00@0GijP0`00
000805nNX0<00000B03jl>H10?ooo`00B`3jl>H3000000<0GijP0P0000000`1OWZ00000005nNX006
05nNX0030000001OWZ00GijP00@0GijP00@0000005nNX000000000000`1OWZ0010000000GijP05nN
X01OWZ03000000D0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00605nNX0030000
001OWZ00GijP00@0GijP00@0000005nNX01OWZ0000000P1OWZ000`000000GijP05nNX00405nNX003
0000001OWZ00GijP00H0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00305nNX0<0
00000`1OWZ0010000000GijP05nNX01OWZ020000000305nNX0000000GijP00D0GijP00<0000005nN
X01OWZ001@1OWZ0010000000GijP00000000000305nNX0<00000B`3jl>H10?ooo`00CP3jl>H30000
0080GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX00405nNX0<00000101OWZ001@00
0000GijP05nNX01OWZ0000000080GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX003
05nNX0030000001OWZ00GijP00H0GijP00<0000005nNX01OWZ001@1OWZ001@000000GijP05nNX000
0000GijP008000001`1OWZ000`000000GijP05nNX00605nNX0030000001OWZ00GijP00<0GijP00<0
000005nNX01OWZ000P1OWZ0010000000GijP05nNX000000305nNX0030000001OWZ00GijP0080GijP
0`00000605nNX0030000001OWZ00GijP00D0GijP00<0000005nNX01OWZ000`00001>0?[`iP40oooo
001?0?[`iP050000001OWZ00GijP05nNX00000001`1OWZ000`000000GijP05nNX00405nNX0030000
001OWZ00GijP00@0GijP00@0000005nNX01OWZ0000000`1OWZ001@000000GijP05nNX01OWZ000000
00D0GijP00<0000005nNX01OWZ001P1OWZ02000000L0GijP0P0000000`1OWZ00000005nNX0020000
00L0GijP0P00000805nNX0030000001OWZ00GijP00<0GijP00D0000005nNX01OWZ00GijP00000003
05nNX0040000001OWZ00GijP000000H0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nN
X00505nNX0050000001OWZ00GijP05nNX0000000C`3jl>H10?ooo`00CP3jl>H00`000000GijP05nN
X00205nNX0030000001OWZ00GijP00D0GijP00<0000005nNX01OWZ000P1OWZ03000000D0GijP00@0
000005nNX01OWZ0000000`1OWZ001@000000GijP05nNX01OWZ00000000H0GijP00<0000005nNX01O
WZ000P1OWZ050000000305nNX0000000GijP00D0GijP0P0000001@1OWZ0000000000001OWZ000000
00H0GijP0P0000000`1OWZ00000000000002000000@0GijP00<0000005nNX01OWZ00101OWZ001000
0000GijP05nNX000000405nNX0040000001OWZ00GijP000000D0GijP0`00000405nNX0030000001O
WZ00GijP00D0GijP00<0000005nNX01OWZ000P1OWZ000`000000n_3V0?[`iP1<0?[`iP40oooo001>
0?[`iP030000001OWZ00GijP0080GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX002
05nNX0030000001OWZ00000000H0GijP0`00000405nNX0040000001OWZ00GijP000000H0GijP00<0
000005nNX00000000`00000405nNX0030000001OWZ00000000D0GijP00<0000005nNX01OWZ000`00
000205nNX0030000001OWZ00GijP00<0GijP00<0000005nNX0000000101OWZ040000000305nNX000
0000GijP00D0GijP00@0000005nNX01OWZ000000101OWZ03000000H0GijP00<0000005nNX0000000
101OWZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP0080GijP00<000000?[`iP3jl>H0
C03jl>H10?ooo`00C@3jl>H00`000000GijP05nNX00205nNX0030000001OWZ00GijP00D0GijP00<0
000005nNX01OWZ000P00000205nNX0030000001OWZ00GijP00<0GijP0P00000605nNX0030000001O
WZ00000000D0GijP1000000705nNX0050000001OWZ00GijP05nNX0000000101OWZ000`000000GijP
05nNX002000000<0GijP00<0000005nNX01OWZ000P1OWZ0010000000GijP05nNX000000805nNX0@0
00001@1OWZ000`000000GijP0000000605nNX08000001@1OWZ000`000000GijP05nNX00200000080
GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX00205nNX0030000003jl>H0n_3V04/0
n_3V0@3oool004d0n_3V00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00505nNX0030000
001OWZ00000000<0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00505nNX0800000
0`1OWZ04000000X0GijP00D0000005nNX01OWZ00GijP0000000405nNX0050000001OWZ00GijP05nN
X00000000`1OWZ000`000000GijP05nNX00205nNX0050000001OWZ00GijP05nNX00000002P1OWZ04
000000<0GijP0P00000705nNX0030000001OWZ00GijP00@0GijP00L0000005nNX01OWZ00GijP0000
001OWZ00000000L0GijP00<0000005nNX01OWZ000P1OWZ000`000000n_3V0?[`iP1;0?[`iP40oooo
001<0?[`iP030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ00101OWZ03000000@0GijP00<0
000005nNX01OWZ000P1OWZ03000000H0GijP1P00000205nNX0030000001OWZ00GijP00P0GijP00<0
000005nNX01OWZ000`1OWZ001@000000GijP05nNX01OWZ00000000<0GijP00D0000005nNX01OWZ00
GijP0000000305nNX0030000001OWZ00GijP0080GijP00<0000005nNX01OWZ002@1OWZ000`000000
GijP05nNX006000000H0GijP0`00000405nNX0030000001OWZ00GijP0080GijP0`00000605nNX003
0000001OWZ00GijP00<0GijP00<000000?[`iP3jl>H0BP3jl>H10?ooo`00C03jl>H00`000000GijP
05nNX00205nNX0030000001OWZ00GijP00D0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP
05nNX00205nNX0030000001OWZ00000000L0GijP0P00000605nNX0030000001OWZ00GijP00L0GijP
0P00000505nNX0050000001OWZ00GijP05nNX00000000`1OWZ001@000000GijP05nNX01OWZ000000
00<0GijP00<0000005nNX01OWZ000`1OWZ02000000T0GijP00<0000005nNX01OWZ00101OWZ020000
00L0GijP00<0000005nNX0000000101OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP
00D0GijP00<0000005nNX01OWZ000P1OWZ000`000000n_3V0?[`iP1:0?[`iP40oooo001;0?[`iP03
0000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000`1OWZ03000000D0GijP00D0000005nNX01O
WZ00GijP0000000205nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ001@1OWZ000`00
0000GijP05nNX00605nNX080000000<0GijP0000001OWZ001@1OWZ0010000000GijP05nNX0000003
05nNX0050000001OWZ00GijP05nNX00000000P1OWZ000`000000GijP05nNX00305nNX080000000<0
GijP000000000000201OWZ000`000000GijP05nNX00505nNX0030000001OWZ00GijP00@0GijP00@0
000005nNX01OWZ0000000`1OWZ000`000000GijP05nNX00305nNX0<000001@1OWZ000`000000GijP
05nNX00305nNX0030000003jl>H0n_3V04T0n_3V0@3oool004/0n_3V00<0000005nNX01OWZ000`1O
WZ0010000000GijP05nNX01OWZ020000000305nNX0000000GijP00@0GijP00<0000005nNX01OWZ00
0P00000205nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP
05nNX00405nNX0<000000P1OWZ000`000000GijP0000000505nNX0030000001OWZ00000000@0GijP
00<0000005nNX01OWZ000P1OWZ000`000000GijP0000000505nNX0030000001OWZ0000000080GijP
0`00000605nNX0030000001OWZ00GijP00D0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP
05nNX00200000080GijP00<0000005nNX01OWZ000`1OWZ0010000000GijP00000000000305nNX003
0000001OWZ00GijP00<0GijP00<000000?[`iP3jl>H0B@3jl>H10?ooo`00B`3jl>H00`000000GijP
05nNX00305nNX0040000001OWZ000000000000<0GijP00<0000005nNX01OWZ000`1OWZ000`000000
GijP0000000405nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ001@1OWZ000`000000
GijP05nNX00205nNX0<000001@1OWZ000`000000GijP0000000605nNX0800000101OWZ000`000000
GijP05nNX00205nNX08000001@1OWZ0010000000GijP05nNX000000505nNX0<00000101OWZ000`00
0000GijP05nNX00505nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000P1OWZ000`00
0000GijP0000000505nNX0040000001OWZ00GijP05nNX080000000<0GijP0000001OWZ00101OWZ00
0`000000n_3V0?[`iP190?[`iP40oooo001:0?[`iP030000001OWZ00GijP00<0GijP0`00000405nN
X0030000001OWZ00GijP00<0GijP0`00000405nNX0030000001OWZ00GijP00<0GijP00<0000005nN
X01OWZ001@1OWZ0010000000GijP05nNX01OWZ03000000L0GijP00@0000005nNX01OWZ0000001@1O
WZ02000000@0GijP00<0000005nNX01OWZ000P1OWZ02000000D0GijP00@0000005nNX01OWZ000000
1`1OWZ03000000<0GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX00305nNX0030000
001OWZ00GijP0080GijP0`00000505nNX0030000001OWZ00GijP0080GijP0`00000505nNX0030000
003jl>H0n_3V04P0n_3V0@3oool004X0n_3V00<0000005nNX01OWZ000`1OWZ000`000000GijP05nN
X00405nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nN
X00205nNX0030000001OWZ00GijP00H0GijP00@0000005nNX000000000000P1OWZ000`000000GijP
05nNX00405nNX0050000001OWZ00GijP05nNX00000001P1OWZ000`000000GijP05nNX00205nNX003
0000001OWZ00GijP0080GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00205nNX003
0000001OWZ00GijP00@0GijP00<0000005nNX01OWZ000P0000000`1OWZ00000005nNX00705nNX003
0000001OWZ00GijP0080GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00305nNX003
0000001OWZ00GijP00@0GijP00<0000005nNX01OWZ000`1OWZ000`000000n_3V0?[`iP180?[`iP40
oooo00190?[`iP030000001OWZ00GijP0080GijP0`00000505nNX0030000001OWZ00GijP00<0GijP
0P00000505nNX0030000001OWZ00GijP0080GijP00<0000005nNX01OWZ001P1OWZ03000000<0GijP
00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX00205nNX0030000001OWZ00GijP00<0GijP
0P00000305nNX0040000001OWZ00GijP05nNX08000001@1OWZ000`000000GijP05nNX00205nNX003
0000001OWZ00GijP00D0GijP00@0000005nNX01OWZ00GijP0`00000805nNX0030000001OWZ00GijP
0080GijP00<0000005nNX01OWZ000`1OWZ02000000D0GijP00<0000005nNX01OWZ000`1OWZ030000
00@0GijP00<000000?[`iP3jl>H0A`3jl>H10?ooo`00B@3jl>H01`000000GijP05nNX01OWZ000000
05nNX00000001P1OWZ0010000000GijP05nNX01OWZ03000000H0GijP00D0000005nNX01OWZ00GijP
0000000705nNX0<000001@1OWZ000`000000GijP05nNX00505nNX0030000001OWZ00GijP0080GijP
00<0000005nNX01OWZ000`1OWZ02000000<0GijP00@0000005nNX01OWZ00GijP0P00000405nNX003
0000001OWZ00GijP00<0GijP00<0000005nNX01OWZ001@1OWZ000`000000GijP05nNX00305nNX0<0
00001`1OWZ001@000000GijP05nNX01OWZ00000000H0GijP0`00000305nNX0030000001OWZ00GijP
00@0GijP00<0000005nNX00000000`1OWZ000`000000n_3V0?[`iP170?[`iP40oooo00180?[`iP03
0000001OWZ00GijP008000000P1OWZ000`000000GijP05nNX00305nNX0050000001OWZ00GijP05nN
X00000000P1OWZ000`000000GijP05nNX00305nNX08000000P1OWZ000`000000GijP05nNX00405nN
X0<000001P1OWZ000`000000GijP05nNX00505nNX0030000001OWZ00GijP00@0GijP00D0000005nN
X01OWZ00GijP0000000205nNX0040000001OWZ00GijP00000080GijP00<0000005nNX0000000101O
WZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP00D0GijP00<0000005nNX01OWZ00101O
WZ03000000H0GijP00<0000005nNX01OWZ000P00000505nNX0040000001OWZ00GijP000000<0GijP
00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00200000080GijP00<000000?[`iP3jl>H0
AP3jl>H10?ooo`00B03jl>H00`000000GijP0000000305nNX0030000001OWZ00GijP00@0GijP00@0
000005nNX01OWZ0000000P1OWZ000`000000GijP05nNX00205nNX0<000000P1OWZ000`000000GijP
05nNX00305nNX08000000P1OWZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP00@0GijP
0P00000605nNX0050000001OWZ00GijP05nNX00000000P1OWZ0010000000GijP05nNX000000205nN
X0040000001OWZ00GijP000000<0GijP00<0000005nNX01OWZ00101OWZ02000000H0GijP00<00000
05nNX01OWZ00101OWZ000`000000GijP05nNX002000000D0GijP00<0000005nNX01OWZ000`000004
05nNX0040000001OWZ00GijP00000080GijP00<0000005nNX01OWZ00101OWZ001`000000GijP05nN
X01OWZ00000005nNX0000000B03jl>H10?ooo`00A`3jl>H3000000@0GijP00<0000005nNX01OWZ00
0`1OWZ0010000000GijP05nNX000000305nNX0050000001OWZ00GijP05nNX00000000P1OWZ000`00
0000GijP0000000405nNX08000000`1OWZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP
0080GijP100000000`1OWZ00000005nNX00405nNX08000000P1OWZ002@000000GijP05nNX01OWZ00
000005nNX0000000GijP0000000305nNX0030000001OWZ00GijP008000001@1OWZ020000000405nN
X00000000000000000@0GijP00<0000005nNX01OWZ00101OWZ0010000000GijP05nNX01OWZ020000
00@0GijP00<0000005nNX00000000P1OWZ001@000000GijP05nNX01OWZ00000000<0GijP00@00000
05nNX01OWZ0000001@1OWZ000`000000GijP05nNX00205nNX0<00000A`3jl>H10?ooo`00A`3jl>H0
0`000000GijP05nNX00305nNX0030000001OWZ00GijP00@0GijP0`00000305nNX0050000001OWZ00
GijP05nNX00000000P1OWZ000`000000GijP0000000205nNX0<00000101OWZ000`000000GijP05nN
X00505nNX0D000000`1OWZ000`000000GijP0000000405nNX0030000001OWZ0000000080GijP00T0
000005nNX01OWZ00GijP0000001OWZ00000005nNX00000000`1OWZ001P000000GijP05nNX0000000
GijP000000@0GijP00<0000005nNX00000000`1OWZ05000000L0GijP00<0000005nNX01OWZ000P1O
WZ0300000080GijP00<0000005nNX00000000P1OWZ001@000000GijP05nNX01OWZ00000000<0GijP
0`00000605nNX0030000001OWZ00GijP00<0GijP00<000000?[`iP3jl>H0A@3jl>H10?ooo`00A`3j
l>H00`000000GijP05nNX00305nNX0030000001OWZ00GijP00<0GijP0P00000505nNX0040000001O
WZ00GijP000000<0GijP0P000000101OWZ00000000000000000505nNX0030000001OWZ00GijP00@0
GijP0`00000605nNX0050000001OWZ00GijP05nNX00000000`1OWZ000`000000GijP0000000205nN
X0030000001OWZ00GijP0080GijP0`00000405nNX0060000001OWZ00GijP0000001OWZ0000000`1O
WZ0010000000GijP05nNX000000705nNX0<000001@1OWZ000`000000GijP05nNX00405nNX0<00000
00<0GijP0000000000000`1OWZ0010000000GijP05nNX000000505nNX08000001@1OWZ000`000000
GijP05nNX00305nNX0030000003jl>H0n_3V04D0n_3V0@3oool004H0n_3V00<0000005nNX01OWZ00
0`1OWZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP00<0GijP00@0000005nNX01OWZ00
00000`1OWZ040000000305nNX0000000GijP00D0GijP00<0000005nNX01OWZ000P1OWZ03000000P0
GijP00D0000005nNX01OWZ00GijP0000000305nNX0060000001OWZ00GijP0000001OWZ000000101O
WZ03000000@0GijP00<0000005nNX00000000P1OWZ001@000000GijP05nNX01OWZ00000000<0GijP
00<0000005nNX01OWZ001P1OWZ03000000@0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP
00000003000000<0GijP00@0000005nNX01OWZ0000001@1OWZ000`000000GijP05nNX00305nNX003
0000001OWZ00GijP00@0GijP00<000000?[`iP3jl>H0A03jl>H10?ooo`00AP3jl>H00`000000GijP
05nNX00305nNX0030000001OWZ00GijP00<0GijP0P00000505nNX0<00000101OWZ02000000<0GijP
00<0000005nNX01OWZ000`1OWZ0010000000GijP05nNX01OWZ0200000080GijP00<0000005nNX01O
WZ001@1OWZ000`000000GijP05nNX00305nNX0040000001OWZ00GijP00000080GijP0P00000605nN
X0030000001OWZ00GijP00<0GijP00<0000005nNX00000000P1OWZ0010000000GijP05nNX0000004
05nNX0030000001OWZ00GijP00H0GijP00<0000005nNX01OWZ000P00000305nNX0030000001OWZ00
GijP00<0GijP00@0000005nNX01OWZ00GijP0P00000405nNX0<000001@1OWZ02000000D0GijP00<0
000005nNX01OWZ000`1OWZ000`000000n_3V0?[`iP140?[`iP40oooo00150?[`iP030000001OWZ00
GijP00@0GijP00@0000005nNX01OWZ00GijP0`00000505nNX08000001@1OWZ000`000000GijP05nN
X00205nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000P00000305nNX0030000001O
WZ00GijP00H0GijP00<0000005nNX01OWZ000`1OWZ0010000000GijP05nNX000000205nNX0800000
1P1OWZ000`000000GijP05nNX00405nNX08000000P1OWZ0010000000GijP05nNX000000505nNX003
0000001OWZ00GijP00H0GijP00@0000005nNX01OWZ00GijP0P00000205nNX0030000001OWZ00GijP
00<0GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00305nNX08000001@1OWZ030000
00<0GijP00<0000005nNX01OWZ00101OWZ000`000000n_3V0?[`iP130?[`iP40oooo00150?[`iP03
0000001OWZ00GijP00<0GijP00D0000005nNX01OWZ00GijP0000000205nNX0030000001OWZ00GijP
00<0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00205nNX0030000001OWZ00GijP
00@0GijP0`00000405nNX0030000001OWZ00GijP00H0GijP00<0000005nNX01OWZ001@1OWZ020000
00@0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00405nNX0030000001OWZ00GijP
0080GijP0P00000605nNX0030000001OWZ00GijP00L0GijP00<0000005nNX01OWZ000P1OWZ030000
00H0GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP
00<0GijP00@0000005nNX01OWZ0000000`1OWZ000`000000GijP05nNX00305nNX0030000003jl>H0
n_3V04<0n_3V0@3oool004@0n_3V00<0000005nNX01OWZ00101OWZ0010000000GijP05nNX0000002
05nNX0030000001OWZ00GijP00<0GijP0P00000405nNX0030000001OWZ00GijP0080GijP00<00000
05nNX01OWZ000`1OWZ03000000H0GijP00<0000005nNX01OWZ001@1OWZ02000000L0GijP0P000004
05nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX002
05nNX08000001`1OWZ02000000L0GijP00<0000005nNX01OWZ00101OWZ03000000D0GijP00<00000
05nNX01OWZ000P1OWZ000`000000GijP05nNX00205nNX08000001@1OWZ0010000000GijP05nNX000
000205nNX0030000001OWZ00GijP00@0GijP00<000000?[`iP3jl>H0@P3jl>H10?ooo`00A03jl>H0
0`000000GijP05nNX00305nNX0040000001OWZ00GijP000000<0GijP00<0000005nNX01OWZ000P1O
WZ02000000@0GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00205nNX0<000001`1O
WZ000`000000GijP05nNX00305nNX0<0000000<0GijP0000000000001`1OWZ000`000000GijP05nN
X00205nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ00101OWZ000`000000GijP05nN
X00205nNX0030000001OWZ00GijP00D0GijP0P000000101OWZ00000000000000000505nNX0030000
001OWZ00GijP00D0GijP0`00000405nNX0030000001OWZ00GijP0080GijP00<0000005nNX01OWZ00
0P1OWZ02000000@0GijP00D0000005nNX01OWZ00GijP0000000205nNX0030000001OWZ00GijP00<0
GijP00<000000?[`iP3jl>H0@P3jl>H10?ooo`00@`3jl>H00`000000GijP05nNX00405nNX0<00000
0`1OWZ000`000000GijP05nNX00205nNX0030000001OWZ00000000<0GijP00<0000005nNX01OWZ00
0P1OWZ0010000000GijP05nNX01OWZ020000000305nNX0000000GijP00H0GijP00@0000005nNX01O
WZ00GijP0`00000305nNX0030000001OWZ00000000L0GijP00<0000005nNX01OWZ000P1OWZ020000
00D0GijP00<0000005nNX01OWZ000`1OWZ02000000@0GijP00<0000005nNX01OWZ001@1OWZ000`00
0000GijP0000000305nNX0<000000`1OWZ000`000000GijP05nNX00505nNX0040000001OWZ000000
000000<0GijP00<0000005nNX01OWZ000P1OWZ001`000000GijP05nNX01OWZ00000005nNX0000000
101OWZ0010000000GijP05nNX01OWZ03000000H0GijP00<000000?[`iP3jl>H0@@3jl>H10?ooo`00
@`3jl>H00`000000GijP05nNX00305nNX08000001@1OWZ001@000000GijP05nNX01OWZ0000000080
GijP00@0000005nNX01OWZ0000001@1OWZ0010000000GijP00000000000305nNX0030000001OWZ00
GijP00D0GijP1000000605nNX0040000001OWZ00GijP000000D0GijP00<0000005nNX00000000`1O
WZ02000000D0GijP00<0000005nNX01OWZ000`1OWZ02000000<0GijP00<0000005nNX00000001@1O
WZ0010000000GijP05nNX000000605nNX0@000001`1OWZ0010000000GijP05nNX01OWZ0200000003
05nNX0000000GijP00@0GijP00@0000005nNX01OWZ0000000P1OWZ001@000000GijP05nNX01OWZ00
000000D0GijP0P00000505nNX0030000003jl>H0n_3V0440n_3V0@3oool00480n_3V00<0000005nN
X01OWZ00101OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP008000000P1OWZ001000
0000GijP05nNX000000505nNX0<00000101OWZ000`000000GijP05nNX00405nNX0<000002@1OWZ00
10000000GijP05nNX000000505nNX0030000001OWZ00000000<0GijP00<0000005nNX0000000101O
WZ000`000000GijP05nNX00205nNX0030000001OWZ00000000<0GijP00<0000005nNX00000001@1O
WZ0010000000GijP05nNX000000905nNX0<000001P1OWZ000`000000GijP05nNX00205nNX0<00000
1@1OWZ0010000000GijP05nNX000000205nNX08000000P1OWZ000`000000GijP05nNX00305nNX003
0000001OWZ00GijP00@0GijP00<000000?[`iP3jl>H0@03jl>H10?ooo`00@P3jl>H00`000000GijP
05nNX00205nNX0<000001@1OWZ000`000000GijP0000000405nNX0030000001OWZ00000000@0GijP
0`00000505nNX0030000001OWZ00GijP00<0GijP0`00000:05nNX0030000001OWZ00GijP0080GijP
00<0000005nNX01OWZ000P1OWZ000`000000GijP0000000305nNX0030000001OWZ00000000@0GijP
00<0000005nNX01OWZ000P1OWZ000`000000GijP0000000305nNX0030000001OWZ00000000@0GijP
00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00805nNX0<000001@1OWZ000`000000GijP
05nNX00305nNX0<00000101OWZ000`000000GijP0000000405nNX0030000001OWZ00000000D0GijP
0`00000405nNX0030000003jl>H0n_3V0400n_3V0@3oool00440n_3V00<0000005nNX01OWZ000P1O
WZ000`000000GijP0000000505nNX0030000001OWZ00000000D0GijP0P00000205nNX0@000001P1O
WZ000`000000GijP05nNX00205nNX08000000P1OWZ000`000000GijP05nNX00805nNX0030000001O
WZ00GijP0080GijP00D0000005nNX01OWZ00GijP0000000305nNX0040000001OWZ00GijP00000080
GijP00D0000005nNX01OWZ00GijP0000000305nNX0040000001OWZ00GijP00000080GijP00@00000
05nNX01OWZ000000101OWZ000`000000GijP05nNX00205nNX0030000001OWZ00GijP00P0GijP00<0
000005nNX01OWZ000P00000405nNX0030000001OWZ00GijP00@0GijP1000000205nNX08000001@1O
WZ000`000000GijP0000000505nNX0030000001OWZ00000000@0GijP00<000000?[`iP3jl>H0?`3j
l>H10?ooo`00@@3jl>H01@000000GijP05nNX01OWZ0000000080GijP00<0000005nNX01OWZ000`1O
WZ02000000D0GijP1@00000205nNX0030000001OWZ00GijP00@0GijP00@0000005nNX01OWZ00GijP
0P00000305nNX0030000001OWZ00GijP00T0GijP00<0000005nNX01OWZ000`1OWZ0010000000GijP
05nNX000000305nNX0030000001OWZ00000000<0GijP00D0000005nNX01OWZ00GijP0000000305nN
X0070000001OWZ00GijP05nNX0000000GijP0000000305nNX0040000001OWZ00GijP000000D0GijP
00<0000005nNX01OWZ002@1OWZ0010000000GijP05nNX01OWZ02000000<0GijP00<0000005nNX01O
WZ00101OWZ000`000000GijP05nNX005000000D0GijP0P00000505nNX0040000001OWZ00GijP0000
00<0GijP00<000000?[`iP3jl>H0?`3jl>H10?ooo`00@03jl>H00`000000GijP05nNX00200000080
GijP00<0000005nNX01OWZ000`1OWZ02000000H0GijP0P00000405nNX0030000001OWZ00GijP00D0
GijP00@0000005nNX000000000001@1OWZ000`000000GijP05nNX00805nNX0030000001OWZ00GijP
00@0GijP00@0000005nNX01OWZ0000000`1OWZ000`000000GijP0000000405nNX0040000001OWZ00
GijP00000080GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP0000000305nNX0040000001O
WZ00GijP000000H0GijP00<0000005nNX01OWZ00201OWZ000`000000GijP05nNX00305nNX0800000
00<0GijP0000001OWZ001P1OWZ000`000000GijP05nNX00205nNX08000001P1OWZ02000000D0GijP
00<0000005nNX01OWZ000P00000205nNX0030000003jl>H0n_3V03h0n_3V0@3oool00400n_3V00<0
000005nNX0000000101OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP00@0GijP00<0
000005nNX01OWZ000`1OWZ000`000000GijP05nNX00505nNX0<000001P1OWZ000`000000GijP05nN
X00805nNX08000001`1OWZ000`000000GijP0000000405nNX0800000101OWZ0010000000GijP05nN
X000000205nNX0030000001OWZ00GijP0080GijP0P00000405nNX0030000001OWZ00000000L0GijP
0P00000:05nNX0030000001OWZ00GijP00@0GijP0`00000705nNX0030000001OWZ00GijP00<0GijP
00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00305nNX0030000001OWZ00GijP0080GijP
00<0000005nNX0000000@03jl>H10?ooo`00?`3jl>H3000000@0GijP00<0000005nNX01OWZ000`1O
WZ02000000D0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00405nNX0<00000201O
WZ000`000000GijP05nNX00405nNX0@0000000<0GijP0000000000001P1OWZ02000000D0GijP0P00
000405nNX0040000001OWZ00GijP00000080GijP00<0000005nNX01OWZ000P1OWZ02000000D0GijP
0P00000605nNX080000000<0GijP0000000000000P00000605nNX0030000001OWZ00GijP00H0GijP
0`00000605nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000`1OWZ02000000D0GijP
00<0000005nNX01OWZ000P1OWZ03000003l0n_3V0@3oool003l0n_3V00<0000005nNX01OWZ00101O
WZ000`000000GijP05nNX00205nNX08000001@1OWZ000`000000GijP05nNX00405nNX0030000001O
WZ00GijP0080GijP0`00000905nNX0030000001OWZ00GijP0080GijP0`00000405nNX0030000001O
WZ00000000L0GijP00<0000005nNX01OWZ000`1OWZ02000000@0GijP0P0000000`1OWZ00000005nN
X002000000@0GijP0P00000505nNX0030000001OWZ00GijP00D0GijP00<0000005nNX0000000101O
WZ03000000@0GijP00<0000005nNX01OWZ001`1OWZ03000000@0GijP00<0000005nNX01OWZ00101O
WZ000`000000GijP05nNX00305nNX0800000101OWZ000`000000GijP05nNX00405nNX0030000003j
l>H0n_3V03d0n_3V0@3oool003l0n_3V00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX002
05nNX0030000001OWZ00000000@0GijP00<0000005nNX01OWZ00101OWZ0010000000GijP05nNX01O
WZ020000000305nNX0000000GijP00T0GijP1@00000705nNX0040000001OWZ00GijP000000H0GijP
00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00205nNX080000000<0GijP0000001OWZ00
0P00000405nNX0030000001OWZ00GijP00@0GijP00<0000005nNX01OWZ00101OWZ0010000000GijP
05nNX000000705nNX0D000002P1OWZ0010000000GijP00000000000305nNX0030000001OWZ00GijP
00@0GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP0000000405nNX0030000001OWZ00GijP
00<0GijP00<000000?[`iP3jl>H0?@3jl>H10?ooo`00?P3jl>H00`000000GijP05nNX00405nNX005
0000001OWZ00GijP05nNX00000000P1OWZ001@000000GijP05nNX01OWZ00000000H0GijP00<00000
05nNX01OWZ000P00000305nNX0030000001OWZ00GijP00H0GijP0`00000:05nNX0050000001OWZ00
GijP05nNX00000001P1OWZ02000000D0GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP0000
00020000000305nNX0000000GijP00<0GijP00<0000005nNX01OWZ000`1OWZ02000000H0GijP00D0
000005nNX01OWZ00GijP0000000:05nNX0<00000201OWZ0010000000GijP05nNX01OWZ0200000080
GijP00<0000005nNX01OWZ00101OWZ001@000000GijP05nNX01OWZ0000000080GijP00D0000005nN
X01OWZ00GijP0000000605nNX0030000003jl>H0n_3V03`0n_3V0@3oool003h0n_3V00<0000005nN
X01OWZ000`1OWZ000`000000GijP05nNX00200000080GijP00D0000005nNX01OWZ00GijP00000006
05nNX0040000001OWZ000000000000@0GijP00<0000005nNX01OWZ001@1OWZ03000000/0GijP0P00
000405nNX0030000001OWZ00GijP0080GijP00<0000005nNX00000001@1OWZ000`000000GijP05nN
X00205nNX0030000001OWZ0000000080000000<0GijP0000001OWZ000`1OWZ000`000000GijP05nN
X00305nNX0030000001OWZ00000000@0GijP00<0000005nNX01OWZ000P1OWZ02000000/0GijP0`00
000705nNX0030000001OWZ00GijP0080GijP0P0000000`1OWZ00000005nNX00505nNX0050000001O
WZ00GijP05nNX00000000P1OWZ0200000080GijP00<0000005nNX01OWZ000`1OWZ000`000000n_3V
0?[`iP0l0?[`iP40oooo000m0?[`iP030000001OWZ00GijP00@0GijP00<0000005nNX0000000101O
WZ0010000000GijP05nNX000000605nNX0<000001@1OWZ000`000000GijP05nNX00405nNX0800000
0P1OWZ000`000000GijP05nNX00705nNX080000000<0n_3V0000001OWZ000`1OWZ000`000000GijP
05nNX00205nNX0030000001OWZ00000000D0GijP0P00000305nNX0040000001OWZ00GijP00000080
GijP00@0000005nNX01OWZ00GijP0P00000505nNX0030000001OWZ00000000@0GijP00<0000005nN
X01OWZ000P1OWZ0010000000n_3V00000000000905nNX0030000001OWZ00GijP008000001P1OWZ00
0`000000GijP05nNX00305nNX0<000001P1OWZ0010000000GijP05nNX000000405nNX0030000001O
WZ00000000H0GijP00<000000?[`iP3jl>H0>`3jl>H10?ooo`00?@3jl>H00`000000GijP05nNX003
05nNX0030000001OWZ00000000@0GijP00@0000005nNX01OWZ0000001@1OWZ03000000H0GijP00<0
000005nNX01OWZ000`1OWZ02000000<0GijP00<0000005nNX01OWZ001P1OWZ02000000@0n_3V00<0
000005nNX01OWZ000P1OWZ001@000000GijP05nNX01OWZ0000000080GijP00L0000005nNX01OWZ00
GijP0000001OWZ00000000<0GijP00@0000005nNX01OWZ0000000P1OWZ0010000000GijP05nNX01O
WZ02000000@0GijP00@0000005nNX01OWZ0000000`1OWZ000`000000GijP05nNX00205nNX0030000
003jl>H0n_3V0080n_3V0P00000805nNX0040000001OWZ00GijP05nNX08000001@1OWZ000`000000
GijP05nNX00405nNX0<000001@1OWZ0010000000GijP05nNX000000405nNX0030000001OWZ000000
00D0GijP00<000000?[`iP3jl>H0>`3jl>H10?ooo`00?03jl>H00`000000GijP05nNX00405nNX080
00001@1OWZ000`000000GijP0000000305nNX0@000001`1OWZ0010000000GijP05nNX01OWZ030000
00@0GijP00<0000005nNX01OWZ001@1OWZ02000000H0n_3V00<0000005nNX01OWZ000P1OWZ001@00
0000GijP05nNX01OWZ0000000080GijP00L0000005nNX01OWZ00GijP0000001OWZ0000000080GijP
00D0000005nNX01OWZ00GijP0000000305nNX0060000001OWZ00GijP0000001OWZ0000000`1OWZ00
10000000GijP05nNX000000305nNX0030000001OWZ00GijP0080GijP00<000000?[`iP3jl>H0103j
l>H2000000L0GijP00<0000005nNX01OWZ000P1OWZ03000000<0GijP00<0000005nNX01OWZ001@1O
WZ04000000<0GijP00<0000005nNX00000001@1OWZ02000000H0GijP00<000000?[`iP3jl>H0>P3j
l>H10?ooo`00?03jl>H00`000000GijP05nNX00305nNX08000001P1OWZ0200000080GijP0P000002
05nNX0030000001OWZ00GijP00H0GijP00@0000005nNX000000000001`1OWZ000`000000GijP05nN
X00205nNX0<00000203jl>H00`000000GijP05nNX00305nNX0040000001OWZ00GijP00000080GijP
00D0000005nNX01OWZ00GijP0000000205nNX0030000001OWZ00000000<0GijP00L0000005nNX01O
WZ00GijP0000001OWZ0000000080GijP00@0000005nNX01OWZ0000000`1OWZ0010000000GijP05nN
X000000505nNX0030000003jl>H0n_3V00H0n_3V0`00000405nNX0030000001OWZ00GijP00D0GijP
0P0000000`1OWZ00000005nNX00705nNX0030000001OWZ00GijP008000000P1OWZ02000000H0GijP
0P00000505nNX0030000003jl>H0n_3V03X0n_3V0@3oool003/0n_3V00<0000005nNX01OWZ00101O
WZ000`000000GijP05nNX00405nNX0D000000`1OWZ000`000000GijP05nNX00605nNX0<00000201O
WZ0010000000GijP05nNX01OWZ02000000`0n_3V00<0000005nNX01OWZ000P1OWZ0010000000GijP
05nNX000000305nNX0040000001OWZ00GijP00000080GijP00<0000005nNX00000000`1OWZ001`00
0000GijP05nNX01OWZ00000005nNX00000000P1OWZ0010000000GijP05nNX000000305nNX0040000
001OWZ00GijP000000@0GijP00<000000?[`iP3jl>H02P3jl>H2000000<0GijP00<0000005nNX01O
WZ001P1OWZ03000000P0GijP00@0000005nNX01OWZ00GijP1@00000605nNX0030000001OWZ00GijP
00@0GijP00<000000?[`iP3jl>H0>@3jl>H10?ooo`00>`3jl>H00`000000GijP05nNX00305nNX080
00001P1OWZ02000000D0GijP00<0000005nNX01OWZ001@1OWZ03000000T0GijP00<0000005nNX01O
WZ000P00000>0?[`iP030000001OWZ00GijP00<0GijP0P00000405nNX0040000001OWZ00GijP0000
00<0GijP0P00000305nNX0040000001OWZ00GijP05nNX08000000`1OWZ0010000000GijP05nNX000
000405nNX08000001@1OWZ000`000000n_3V0?[`iP0<0?[`iP8000000P1OWZ000`000000GijP05nN
X00705nNX0<000001`1OWZ000`000000GijP05nNX00305nNX08000001P1OWZ02000000D0GijP00<0
00000?[`iP3jl>H0>@3jl>H10?ooo`00>`3jl>H00`000000GijP05nNX00205nNX08000001P1OWZ00
0`000000GijP05nNX00405nNX0030000001OWZ00GijP00@0GijP0`00000;05nNX0<00000403jl>H0
0`000000GijP05nNX00305nNX08000001@1OWZ000`000000GijP0000000305nNX08000000`1OWZ00
10000000GijP05nNX01OWZ02000000<0GijP00<0000005nNX00000001@1OWZ02000000D0GijP00<0
00000?[`iP3jl>H03P3jl>H3000000/0GijP0`00000605nNX0030000001OWZ00GijP00@0GijP00<0
000005nNX01OWZ00101OWZ02000000@0GijP00<000000?[`iP3jl>H0>@3jl>H10?ooo`00>P3jl>H0
0`000000GijP05nNX00205nNX0030000001OWZ00000000D0GijP00<0000005nNX01OWZ001@1OWZ00
0`000000GijP05nNX00205nNX08000000P1OWZ000`000000GijP05nNX00705nNX0<000004`3jl>H0
0`000000GijP05nNX00305nNX0030000001OWZ00GijP00<0GijP0P00000405nNX08000000`1OWZ00
10000000GijP05nNX01OWZ02000000<0GijP00<0000005nNX00000001@1OWZ000`000000GijP05nN
X00305nNX0030000003jl>H0n_3V0140n_3V0`00000905nNX0030000001OWZ00GijP00800000101O
WZ000`000000GijP05nNX00505nNX0030000001OWZ00GijP00<0GijP00<0000005nNX0000000101O
WZ000`000000n_3V0?[`iP0h0?[`iP40oooo000j0?[`iP070000001OWZ00GijP05nNX0000000GijP
0000000505nNX0030000001OWZ00GijP00D0GijP00@0000005nNX01OWZ00GijP0P00000305nNX003
0000001OWZ00GijP00H0GijP0P00000F0?[`iP030000001OWZ00GijP00<0GijP00<0000005nNX01O
WZ000`1OWZ02000000D0GijP00D0000005nNX01OWZ00GijP0000000305nNX0030000001OWZ00GijP
00<0GijP0P00000505nNX0030000001OWZ00GijP00<0GijP00<000000?[`iP3jl>H0503jl>H20000
00P0GijP00@0000005nNX01OWZ00GijP0P00000305nNX0030000001OWZ00GijP00D0GijP00<00000
05nNX01OWZ000`1OWZ000`000000GijP0000000305nNX0030000003jl>H0n_3V03P0n_3V0@3oool0
03T0n_3V00<0000005nNX01OWZ000P00000205nNX0030000001OWZ00GijP0080GijP00<0000005nN
X01OWZ001@1OWZ000`000000GijP05nNX002000000@0GijP00<0000005nNX01OWZ001@1OWZ020000
01P0n_3V00<0000005nNX01OWZ000P1OWZ000`000000GijP0000000505nNX0030000001OWZ00GijP
00<0GijP00D0000005nNX01OWZ00GijP0000000305nNX0030000001OWZ00GijP00<0GijP00<00000
05nNX01OWZ000`1OWZ000`000000GijP0000000405nNX0030000003jl>H0n_3V01H0n_3V0P000007
05nNX0030000001OWZ00GijP0080GijP0P00000205nNX0030000001OWZ00GijP00D0GijP00<00000
05nNX01OWZ000P1OWZ000`000000GijP05nNX00200000080GijP00<000000?[`iP3jl>H0=`3jl>H1
0?ooo`00>@3jl>H00`000000GijP0000000405nNX0050000001OWZ00GijP05nNX00000001`1OWZ00
10000000GijP00000000000505nNX0030000001OWZ00GijP00@0GijP0P00000K0?[`iP070000001O
WZ00GijP05nNX0000000GijP0000000505nNX0030000001OWZ00GijP00<0GijP00D0000005nNX01O
WZ00GijP0000000305nNX0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000`1OWZ000`00
0000GijP0000000305nNX0030000003jl>H0n_3V01T0n_3V0P00000505nNX0030000001OWZ00GijP
00@0GijP0P0000000`1OWZ00000005nNX00605nNX0050000001OWZ00GijP05nNX0000000101OWZ00
0`000000GijP0000000i0?[`iP40oooo000h0?[`iP030000001OWZ00000000@0GijP00D0000005nN
X01OWZ00GijP0000000705nNX0<000001`1OWZ000`000000GijP05nNX00205nNX08000007@3jl>H0
1`000000GijP05nNX01OWZ00000005nNX00000001@1OWZ000`000000GijP05nNX00305nNX0800000
0P1OWZ000`000000GijP05nNX002000000D0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP
0000000305nNX0030000003jl>H0n_3V01/0n_3V0P00000405nNX0030000001OWZ00GijP00D0GijP
0`00000705nNX0050000001OWZ00GijP05nNX0000000101OWZ000`000000GijP0000000h0?[`iP40
oooo000h0?[`iP8000001@1OWZ0010000000GijP05nNX000000605nNX0<00000201OWZ0010000000
GijP05nNX01OWZ02000001l0n_3V00@0000005nNX01OWZ0000000`1OWZ000`000000GijP05nNX002
05nNX0800000101OWZ0200000080GijP00<0000005nNX01OWZ000P00000405nNX0800000101OWZ00
10000000GijP05nNX000000305nNX0030000003jl>H0n_3V01d0n_3V0P00000305nNX0030000001O
WZ00GijP00H0GijP0`00000605nNX0040000001OWZ00GijP000000D0GijP0P00000h0?[`iP40oooo
000g0?[`iP8000001P1OWZ000`000000GijP0000000505nNX0<000002@1OWZ000`000000GijP05nN
X00200000280n_3V00<0000005nNX00000000`1OWZ000`000000GijP05nNX00205nNX0800000101O
WZ002@000000GijP0000001OWZ00000005nNX0000000GijP0000000405nNX0800000101OWZ001`00
0000GijP05nNX01OWZ00000005nNX00000008P3jl>H200000080GijP00<0000005nNX01OWZ001`1O
WZ03000000D0GijP00<0000005nNX00000001P1OWZ02000003L0n_3V0@3oool003L0n_3V00<00000
05nNX01OWZ00101OWZ000`000000GijP0000000305nNX0<0000000<0GijP0000001OWZ002@1OWZ03
000002@0n_3V00<0000005nNX00000000`1OWZ001`000000GijP05nNX01OWZ00000005nNX0000000
101OWZ002@000000GijP0000001OWZ00000005nNX0000000GijP0000000405nNX0030000001OWZ00
000000<0GijP00L0000005nNX01OWZ00GijP0000001OWZ00000002@0n_3V0`00000:05nNX0030000
001OWZ000000008000000`1OWZ000`000000GijP0000000605nNX0030000003jl>H0n_3V03D0n_3V
0@3oool003H0n_3V00<0000005nNX01OWZ001@1OWZ020000000405nNX00000000000000000<0GijP
00<0000005nNX01OWZ001`1OWZ03000002H0n_3V00<0000005nNX00000000`1OWZ001@000000GijP
05nNX01OWZ0000000080GijP00D0000005nNX01OWZ00GijP0000000205nNX0<000000P1OWZ001@00
0000GijP05nNX01OWZ0000000080GijP00@0000005nNX01OWZ000000101OWZ000`000000GijP0000
000V0?[`iP<000002@1OWZ0010000000GijP05nNX01OWZ030000000305nNX0000000000000H0GijP
00<000000?[`iP3jl>H0=@3jl>H10?ooo`00=P3jl>H00`000000GijP05nNX00405nNX0@000001@1O
WZ000`000000GijP05nNX00605nNX0800000:P3jl>H00`000000GijP05nNX00305nNX0040000001O
WZ00GijP00000080GijP00D0000005nNX01OWZ00GijP0000000205nNX0<000000P1OWZ001@000000
GijP05nNX01OWZ0000000080GijP00@0000005nNX01OWZ0000001@1OWZ000`000000n_3V0?[`iP0X
0?[`iP800000201OWZ000`000000GijP05nNX00305nNX0@000001P1OWZ000`000000n_3V0?[`iP0d
0?[`iP40oooo000e0?[`iP030000001OWZ00GijP00D0GijP0P00000605nNX0030000001OWZ00GijP
00D0GijP0P00000/0?[`iP030000001OWZ00GijP00<0GijP00@0000005nNX01OWZ0000000P1OWZ00
10000000GijP05nNX000000405nNX0030000001OWZ00GijP0080GijP00<0000005nNX00000000`1O
WZ0010000000GijP05nNX000000505nNX0030000003jl>H0n_3V02X0n_3V0P00000705nNX0030000
001OWZ00GijP00@0GijP0P00000605nNX0030000003jl>H0n_3V03@0n_3V0@3oool003D0n_3V00<0
000005nNX01OWZ00101OWZ000`000000GijP05nNX00605nNX0030000001OWZ00GijP00<0GijP0P00
000^0?[`iP030000001OWZ00GijP00<0GijP00@0000005nNX01OWZ0000000`1OWZ000`000000GijP
0000000405nNX0030000001OWZ00GijP0080GijP00<0000005nNX00000000`1OWZ0010000000GijP
05nNX000000505nNX0030000003jl>H0n_3V02`0n_3V0P00000505nNX0030000001OWZ00GijP00H0
GijP00<0000005nNX01OWZ00101OWZ000`000000n_3V0?[`iP0c0?[`iP40oooo000d0?[`iP030000
001OWZ00GijP00@0GijP00<0000005nNX01OWZ001P1OWZ0010000000GijP05nNX01OWZ0300000340
n_3V00<0000005nNX01OWZ000`1OWZ000`000000GijP0000000305nNX0030000001OWZ00000000@0
GijP00<0000005nNX01OWZ000P1OWZ000`000000GijP0000000305nNX0030000001OWZ00000000D0
GijP00<000000?[`iP3jl>H0;`3jl>H3000000<0GijP00<0000005nNX01OWZ001P1OWZ000`000000
GijP05nNX00305nNX0030000003jl>H0n_3V03<0n_3V0@3oool003@0n_3V00<0000005nNX01OWZ00
0`1OWZ000`000000GijP05nNX00605nNX0030000001OWZ00GijP00800000=03jl>H00`000000GijP
05nNX00305nNX08000001@1OWZ02000000@0GijP00<0000005nNX01OWZ000P1OWZ02000000D0GijP
0P00000505nNX0030000003jl>H0n_3V0380n_3V0P00000205nNX0030000001OWZ00GijP00H0GijP
00<0000005nNX01OWZ000`1OWZ000`000000n_3V0?[`iP0b0?[`iP40oooo000c0?[`iP030000001O
WZ00GijP00<0GijP00<0000005nNX01OWZ001P1OWZ0010000000GijP00000000000g0?[`iP030000
001OWZ00GijP0080GijP0P00000505nNX0800000101OWZ000`000000GijP05nNX00205nNX0800000
1@1OWZ02000000@0GijP00<000000?[`iP3jl>H0=@3jl>H20000000305nNX0000000GijP00L0GijP
00<0000005nNX01OWZ000P1OWZ000`000000n_3V0?[`iP0b0?[`iP40oooo000c0?[`iP030000001O
WZ00GijP0080GijP00<0000005nNX01OWZ001P1OWZ03000003T0n_3V00<0000005nNX01OWZ000`1O
WZ000`000000GijP05nNX00305nNX0800000101OWZ000`000000GijP05nNX00205nNX08000001@1O
WZ000`000000GijP05nNX00305nNX0030000003jl>H0n_3V03L0n_3V0`00000805nNX0030000001O
WZ00GijP0080GijP00<000000?[`iP3jl>H0<@3jl>H10?ooo`00<P3jl>H00`000000GijP05nNX002
05nNX0030000001OWZ00GijP00H0GijP0P00000k0?[`iP030000001OWZ00GijP00<0GijP00<00000
05nNX01OWZ00101OWZ000`000000GijP05nNX00205nNX0030000001OWZ00GijP0080GijP00<00000
05nNX01OWZ00101OWZ000`000000GijP05nNX00305nNX0030000003jl>H0n_3V03T0n_3V0P000008
05nNX0050000001OWZ00GijP05nNX0000000<`3jl>H10?ooo`00<P3jl>H01@000000GijP05nNX01O
WZ00000000L0GijP0P00000n0?[`iP030000001OWZ00GijP0080GijP00<0000005nNX01OWZ00101O
WZ000`000000GijP05nNX00205nNX0030000001OWZ00GijP0080GijP00<0000005nNX01OWZ00101O
WZ000`000000GijP05nNX00205nNX0030000003jl>H0n_3V03`0n_3V0P00000705nNX0050000001O
WZ00GijP05nNX0000000<P3jl>H10?ooo`00<@3jl>H01@000000GijP05nNX01OWZ00000000H0GijP
0P0000100?[`iP030000001OWZ00GijP0080GijP0P00000505nNX0030000001OWZ00GijP0080GijP
00@0000005nNX01OWZ00GijP0P00000505nNX0800000101OWZ000`000000n_3V0?[`iP0n0?[`iP80
00001P1OWZ0010000000GijP05nNX000000b0?[`iP40oooo000a0?[`iP040000001OWZ00GijP0000
00D0GijP0P0000120?[`iP030000001OWZ00GijP0080GijP0P00000505nNX08000000`1OWZ001000
0000GijP05nNX01OWZ02000000D0GijP0P00000305nNX0030000003jl>H0n_3V0440n_3V0P000005
05nNX0040000001OWZ00GijP00000340n_3V0@3oool00300n_3V00@0000005nNX01OWZ000000101O
WZ02000004D0n_3V00@0000005nNX01OWZ00GijP0P00000505nNX08000000`1OWZ001P000000GijP
05nNX0000000GijP000000@0GijP00<0000005nNX00000000`1OWZ000`000000n_3V0?[`iP130?[`
iP800000101OWZ000`000000GijP0000000a0?[`iP40oooo000`0?[`iP030000001OWZ00000000<0
GijP0P0000170?[`iP070000001OWZ00GijP05nNX0000000GijP0000000405nNX0030000001OWZ00
00000080GijP00H0000005nNX01OWZ00000005nNX000000405nNX0030000001OWZ00000000<0GijP
00<000000?[`iP3jl>H0A@3jl>H2000000<0GijP00<0000005nNX0000000<03jl>H10?ooo`00;`3j
l>H00`000000GijP0000000205nNX0800000BP3jl>H00`000000GijP0000000205nNX0030000001O
WZ00GijP0080GijP00<0000005nNX00000000P1OWZ000`000000GijP0000000205nNX0030000001O
WZ00GijP0080GijP00<0000005nNX00000000P1OWZ000`000000n_3V0?[`iP180?[`iP8000000P1O
WZ0200000300n_3V0@3oool002l0n_3V0P0000000`1OWZ0000000000001<0?[`iP030000001OWZ00
000000<0GijP00D0000005nNX01OWZ00GijP0000000205nNX0050000001OWZ00000005nNX0000000
0P1OWZ001@000000GijP05nNX01OWZ00000000<0GijP00<0000005nNX0000000C03jl>H200000003
05nNX0000000000002l0n_3V0@3oool002h0n_3V1000001>0?[`iP030000001OWZ00000000<0GijP
00D0000005nNX01OWZ00GijP0000000205nNX0040000001OWZ000000000000<0GijP00D0000005nN
X01OWZ00GijP0000000305nNX0030000001OWZ00000004h0n_3V0`00000_0?[`iP40oooo000^0?[`
iP800000D@3jl>H2000000<0GijP00@0000005nNX01OWZ000000101OWZ03000000@0GijP00@00000
05nNX01OWZ0000000`1OWZ0200000540n_3V0P00000^0?[`iP40oooo00210?[`iP800000101OWZ00
0`000000GijP0000000405nNX08000001@1OWZ000`000000GijP0000000405nNX0800000P@3jl>H1
0?ooo`00PP3jl>H00`000000GijP05nNX00205nNX0030000001OWZ00000000D0GijP00<0000005nN
X01OWZ000`1OWZ000`000000GijP0000000405nNX0030000003jl>H0n_3V0800n_3V0@3oool00880
n_3V00<0000005nNX01OWZ000P1OWZ000`000000GijP0000000505nNX0030000001OWZ00GijP00<0
GijP0P00000505nNX0030000003jl>H0n_3V0800n_3V0@3oool00880n_3V00<0000005nNX01OWZ00
0`1OWZ02000000D0GijP00<0000005nNX01OWZ000`1OWZ02000000D0GijP00<000000?[`iP3jl>H0
P03jl>H10?ooo`00P`3jl>H00`000000GijP05nNX00205nNX08000001@1OWZ000`000000GijP05nN
X00305nNX0800000101OWZ000`000000n_3V0?[`iP210?[`iP40oooo00230?[`iP030000001OWZ00
GijP00<0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00305nNX0030000001OWZ00
GijP00<0GijP00<000000?[`iP3jl>H0P@3jl>H10?ooo`00P`3jl>H00`000000GijP05nNX00305nN
X0030000001OWZ00GijP00<0GijP00<0000005nNX01OWZ000`1OWZ000`000000GijP05nNX00305nN
X0030000003jl>H0n_3V0840n_3V0@3oool008@0n_3V00<0000005nNX01OWZ000P1OWZ000`000000
GijP05nNX00305nNX0030000001OWZ00GijP0080GijP0P00000405nNX0030000003jl>H0n_3V0880
n_3V0@3oool008@0n_3V00<0000005nNX01OWZ000P1OWZ02000000@0GijP00<0000005nNX01OWZ00
0P1OWZ02000000@0GijP00<000000?[`iP3jl>H0PP3jl>H10?ooo`00Q03jl>H00`000000GijP05nN
X00205nNX0800000101OWZ001`000000GijP05nNX01OWZ00000005nNX0000000101OWZ000`000000
n_3V0?[`iP220?[`iP40oooo00250?[`iP070000001OWZ00GijP05nNX0000000GijP0000000305nN
X0070000001OWZ00GijP05nNX0000000GijP0000000305nNX0030000003jl>H0n_3V08<0n_3V0@3o
ool008D0n_3V00L0000005nNX01OWZ00GijP0000001OWZ00000000<0GijP00@0000005nNX01OWZ00
00000P1OWZ001@000000GijP05nNX01OWZ00000008D0n_3V0@3oool008D0n_3V00D0000005nNX01O
WZ00GijP0000000205nNX0040000001OWZ00GijP00000080GijP00@0000005nNX01OWZ0000000`1O
WZ000`000000n_3V0?[`iP230?[`iP40oooo00260?[`iP030000001OWZ00000000<0GijP00H00000
05nNX01OWZ00000005nNX000000305nNX0040000001OWZ00GijP000008H0n_3V0@3oool008H0n_3V
00<0000005nNX0000000101OWZ001@000000GijP0000001OWZ00000000@0GijP00<0000005nNX000
0000QP3jl>H10?ooo`00QP3jl>H00`000000GijP0000000405nNX0040000001OWZ000000000000D0
GijP00<0000005nNX0000000QP3jl>H10?ooo`00Q`3jl>H2000000D0GijP0`00000505nNX0800000
Q`3jl>H10?ooo`00Q`3jl>H2000000D0GijP0P00000605nNX0800000Q`3jl>H10?ooo`00Q`3jl>H2
000000H0GijP00<0000005nNX01OWZ00101OWZ02000008L0n_3V0@3oool008P0n_3V00<0000005nN
X01OWZ00101OWZ000`000000GijP05nNX00405nNX0030000003jl>H0n_3V08H0n_3V0@3oool008P0
n_3V00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00405nNX0030000003jl>H0n_3V08H0
n_3V0@3oool008P0n_3V00<0000005nNX01OWZ00101OWZ000`000000GijP05nNX00405nNX0030000
003jl>H0n_3V08H0n_3V0@3oool008T0n_3V00<0000005nNX01OWZ000`1OWZ000`000000GijP05nN
X00305nNX0030000003jl>H0n_3V08L0n_3V0@3oool008T0n_3V00<0000005nNX01OWZ000`1OWZ00
0`000000GijP05nNX00305nNX0030000003jl>H0n_3V08L0n_3V0@3oool008T0n_3V00<0000005nN
X01OWZ000`1OWZ000`000000GijP05nNX00305nNX0030000003jl>H0n_3V08L0n_3V0@3oool008X0
n_3V00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00205nNX0030000003jl>H0n_3V08P0
n_3V0@3oool008X0n_3V00<0000005nNX01OWZ000P1OWZ000`000000GijP05nNX00205nNX0030000
003jl>H0n_3V08P0n_3V0@3oool008/0n_3V00D0000005nNX01OWZ00GijP0000000305nNX0030000
003jl>H0n_3V08T0n_3V0@3oool008/0n_3V00D0000005nNX01OWZ00GijP0000000305nNX0030000
003jl>H0n_3V08T0n_3V0@3oool008/0n_3V00D0000005nNX01OWZ00GijP0000000305nNX0030000
003jl>H0n_3V08T0n_3V0@3oool008`0n_3V00@0000005nNX01OWZ0000000P1OWZ000`000000n_3V
0?[`iP2:0?[`iP40oooo002<0?[`iP040000001OWZ00GijP00000080GijP00<000000?[`iP3jl>H0
RP3jl>H10?ooo`00S03jl>H010000000GijP05nNX000000205nNX0030000003jl>H0n_3V08X0n_3V
0@3oool008d0n_3V00D0000005nNX0000000GijP0000002=0?[`iP40oooo002=0?[`iP050000001O
WZ00000005nNX0000000S@3jl>H10?ooo`00SP3jl>H3000008h0n_3V0@3oool008h0n_3V0`00002>
0?[`iP40oooo002>0?[`iP<00000SP3jl>H10?ooo`00S`3jl>H00`000000n_3V0?[`iP2=0?[`iP40
oooo002?0?[`iP030000003jl>H0n_3V08d0n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP
0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo
003o0?[`iR00n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.39651, -1.39651, 0.0097318, \
0.0097318}}]
}, Open  ]],

Cell["\<\
The following raises it to a 3D surface and also draws the grid at the level \
of the tips.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{SurfaceColor[Melon], 
          EdgeForm[\(ColorMix[Melon, Black]\)[
              0.3]], \[IndentingNewLine]Polygon /@ grid // 
            RaiseTo3D[1 - #1\^2 - #2\^2 &], \[IndentingNewLine]SurfaceColor[
            CobaltGreen], 
          EdgeForm[\(ColorMix[CobaltGreen, White]\)[
              0.2]], \[IndentingNewLine]Polygon /@ grid // 
            RaiseTo3D[\(-0.7689\) &]}, \[IndentingNewLine]NeutralLighting[
          0.3, 0.5, 
          0.1], \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            0.5}, \[IndentingNewLine]Boxed \[Rule] 
          False, \[IndentingNewLine]ViewPoint -> {1.917, \ \(-2.677\), \ 
            0.779}, \[IndentingNewLine]Background \[Rule] \(ColorMix[Peacock, 
              White]\)[0.5], \[IndentingNewLine]ImageSize \[Rule] 
          450];\)\)], "Input",
  CellLabel->"In[321]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .58831 
%%ImageSize: 450 264.738 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.6 .815 .895 r
MFill
% Scaling calculations
8.9013e-017 1.03377 -0.168714 1.03377 [
[ 0 0 0 0 ]
[ 1 .58831 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .58831 L
0 .58831 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.753 .53 .33 r
.46938 .27266 m .46056 .33293 L .4667 .37738 L p F P
.623 .462 .287 r
s
.753 .53 .33 r
.4667 .37738 m .47563 .34296 L .46938 .27266 L p F P
.623 .462 .287 r
s
.695 .488 .307 r
.48896 .33404 m .46938 .27266 L .47563 .34296 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.46938 .27266 m .46096 .26187 L .46731 .25344 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.46731 .25344 m .47596 .26089 L .46938 .27266 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.48916 .2631 m .46938 .27266 L .47596 .26089 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47596 .26089 m .4923 .25455 L .48916 .2631 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.50954 .25325 m .48916 .2631 L .4923 .25455 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.46096 .26187 m .45225 .2507 L .45971 .24343 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45971 .24343 m .46731 .25344 L .46096 .26187 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4813 .25135 m .47596 .26089 L .46731 .25344 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47596 .26089 m .4813 .25135 L .49553 .24577 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.49553 .24577 m .4923 .25455 L .47596 .26089 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.68992 .2592 m .65651 .25275 L .64045 .24526 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.64045 .24526 m .66549 .24911 L .68992 .2592 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.68116 .24818 m .68992 .2592 L .66549 .24911 L p F P
.392 .656 .4 r
s
.637 .448 .288 r
.68992 .2592 m .65752 .32475 L .642 .37066 L p F P
.623 .462 .287 r
s
.637 .448 .288 r
.642 .37066 m .66674 .33258 L .68992 .2592 L p F P
.623 .462 .287 r
s
.515 .356 .235 r
.68236 .32066 m .68992 .2592 L .66674 .33258 L p F P
.623 .462 .287 r
s
.695 .488 .307 r
.47563 .34296 m .492 .37829 L .48896 .33404 L p F P
.623 .462 .287 r
s
.671 .468 .295 r
.50944 .3862 m .48896 .33404 L .492 .37829 L p F P
.623 .462 .287 r
s
.749 .526 .325 r
.46056 .33293 m .45138 .38414 L .45871 .41696 L p F P
.623 .462 .287 r
s
.749 .526 .325 r
.45871 .41696 m .4667 .37738 L .46056 .33293 L p F P
.623 .462 .287 r
s
.695 .487 .307 r
.4808 .39081 m .47563 .34296 L .4667 .37738 L p F P
.623 .462 .287 r
s
.711 .497 .31 r
.47563 .34296 m .4808 .39081 L .49517 .41709 L p F P
.623 .462 .287 r
s
.711 .497 .31 r
.49517 .41709 m .492 .37829 L .47563 .34296 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.4923 .25455 m .49553 .24577 L .51125 .238 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51125 .238 m .51038 .24571 L .4923 .25455 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4923 .25455 m .51038 .24571 L .50954 .25325 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47384 .24479 m .46731 .25344 L .45971 .24343 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.46731 .25344 m .47384 .24479 L .4813 .25135 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.53055 .24309 m .50954 .25325 L .51038 .24571 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65651 .25275 m .62244 .24617 L .61019 .23938 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.61019 .23938 m .64045 .24526 L .65651 .25275 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.48679 .24154 m .4813 .25135 L .47384 .24479 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4813 .25135 m .48679 .24154 L .49885 .23675 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.49885 .23675 m .49553 .24577 L .4813 .25135 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45225 .2507 m .44323 .23914 L .45186 .23311 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45186 .23311 m .45971 .24343 L .45225 .2507 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.64582 .24098 m .66549 .24911 L .64045 .24526 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.66549 .24911 m .64582 .24098 L .64272 .23403 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.64272 .23403 m .66215 .24118 L .66549 .24911 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.66549 .24911 m .66215 .24118 L .68116 .24818 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.67211 .23679 m .68116 .24818 L .66215 .24118 L p F P
.392 .656 .4 r
s
.646 .453 .29 r
.65752 .32475 m .62387 .38048 L .61182 .41391 L p F P
.623 .462 .287 r
s
.646 .453 .29 r
.61182 .41391 m .642 .37066 L .65752 .32475 L p F P
.623 .462 .287 r
s
.689 .479 .298 r
.492 .37829 m .49517 .41709 L .51113 .44691 L p F P
.623 .462 .287 r
s
.689 .479 .298 r
.51113 .44691 m .51027 .41867 L .492 .37829 L p F P
.623 .462 .287 r
s
.671 .468 .295 r
.492 .37829 m .51027 .41867 L .50944 .3862 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.62244 .24617 m .58768 .23946 L .57939 .2334 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57939 .2334 m .61019 .23938 L .62244 .24617 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.49553 .24577 m .49885 .23675 L .51213 .23011 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51213 .23011 m .51125 .238 L .49553 .24577 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51038 .24571 m .51125 .238 L .52733 .23005 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52733 .23005 m .52896 .23663 L .51038 .24571 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51038 .24571 m .52896 .23663 L .53055 .24309 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62401 .23761 m .64045 .24526 L .61019 .23938 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.64045 .24526 m .62401 .23761 L .64582 .24098 L p F P
.392 .656 .4 r
s
.694 .485 .303 r
.4731 .41636 m .4667 .37738 L .45871 .41696 L p F P
.623 .462 .287 r
s
.695 .487 .307 r
.4667 .37738 m .4731 .41636 L .4808 .39081 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.48053 .23591 m .47384 .24479 L .46733 .236 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47384 .24479 m .48053 .23591 L .48679 .24154 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45971 .24343 m .46733 .236 L .47384 .24479 L p F P
.392 .656 .4 r
s
.629 .435 .275 r
.5308 .42836 m .50944 .3862 L .51027 .41867 L p F P
.623 .462 .287 r
s
.522 .361 .237 r
.64766 .38251 m .66674 .33258 L .642 .37066 L p F P
.623 .462 .287 r
s
.583 .405 .262 r
.66674 .33258 m .64766 .38251 L .64493 .40823 L p F P
.623 .462 .287 r
s
.583 .405 .262 r
.64493 .40823 m .66399 .3673 L .66674 .33258 L p F P
.623 .462 .287 r
s
.515 .356 .235 r
.66674 .33258 m .66399 .3673 L .68236 .32066 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.46733 .236 m .45971 .24343 L .45186 .23311 L p F P
.392 .656 .4 r
s
.477 .326 .216 r
.67424 .37289 m .68236 .32066 L .66399 .3673 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.55222 .23261 m .53055 .24309 L .52896 .23663 L p F P
.392 .656 .4 r
s
.667 .465 .293 r
.48621 .43174 m .4808 .39081 L .4731 .41636 L p F P
.623 .462 .287 r
s
.686 .476 .295 r
.4808 .39081 m .48621 .43174 L .49846 .45007 L p F P
.623 .462 .287 r
s
.686 .476 .295 r
.49846 .45007 m .49517 .41709 L .4808 .39081 L p F P
.623 .462 .287 r
s
.727 .506 .312 r
.45138 .38414 m .44186 .42545 L .45045 .44856 L p F P
.623 .462 .287 r
s
.727 .506 .312 r
.45045 .44856 m .45871 .41696 L .45138 .38414 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.49244 .23142 m .48679 .24154 L .48053 .23591 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.48679 .24154 m .49244 .23142 L .50226 .22748 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.50226 .22748 m .49885 .23675 L .48679 .24154 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.66215 .24118 m .64272 .23403 L .63531 .22515 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.63531 .22515 m .65387 .23102 L .66215 .24118 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.66215 .24118 m .65387 .23102 L .67211 .23679 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62567 .23266 m .64582 .24098 L .62401 .23761 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.64582 .24098 m .62567 .23266 L .62288 .22673 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62288 .22673 m .64272 .23403 L .64582 .24098 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.26828 .24038 m .2896 .23042 L .31654 .22536 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.31654 .22536 m .30424 .23276 L .26828 .24038 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.30908 .23712 m .26828 .24038 L .30424 .23276 L p F P
.392 .656 .4 r
s
.726 .5 .29 r
.26828 .24038 m .28791 .30472 L .31394 .3543 L p F P
.623 .462 .287 r
s
.726 .5 .29 r
.31394 .3543 m .30241 .31818 L .26828 .24038 L p F P
.623 .462 .287 r
s
.753 .523 .317 r
.30755 .31073 m .26828 .24038 L .30241 .31818 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.58768 .23946 m .55222 .23261 L .54957 .22925 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.54957 .22925 m .57939 .2334 L .58768 .23946 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.59768 .23246 m .61019 .23938 L .57939 .2334 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.61019 .23938 m .59768 .23246 L .62401 .23761 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.44323 .23914 m .4339 .22717 L .44016 .22419 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.44016 .22419 m .45186 .23311 L .44323 .23914 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51125 .238 m .51213 .23011 L .52568 .22335 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52568 .22335 m .52733 .23005 L .51125 .238 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60719 .22978 m .62401 .23761 L .59768 .23246 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62401 .23761 m .60719 .22978 L .62567 .23266 L p F P
.392 .656 .4 r
s
.633 .441 .282 r
.62387 .38048 m .58901 .42569 L .58075 .44876 L p F P
.623 .462 .287 r
s
.633 .441 .282 r
.58075 .44876 m .61182 .41391 L .62387 .38048 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.30424 .23276 m .33349 .23132 L .30908 .23712 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.35028 .23384 m .30908 .23712 L .33349 .23132 L p F P
.392 .656 .4 r
s
.543 .375 .244 r
.62588 .41093 m .642 .37066 L .61182 .41391 L p F P
.623 .462 .287 r
s
.522 .361 .237 r
.642 .37066 m .62588 .41093 L .64766 .38251 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.66274 .22499 m .67211 .23679 L .65387 .23102 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.49885 .23675 m .50226 .22748 L .51304 .22204 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51304 .22204 m .51213 .23011 L .49885 .23675 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52896 .23663 m .52733 .23005 L .54513 .22361 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.54513 .22361 m .54957 .22925 L .52896 .23663 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52896 .23663 m .54957 .22925 L .55222 .23261 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47512 .22841 m .46733 .236 L .46065 .22698 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.46733 .236 m .47512 .22841 L .48053 .23591 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45186 .23311 m .46065 .22698 L .46733 .236 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.48741 .22679 m .48053 .23591 L .47512 .22841 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.48053 .23591 m .48741 .22679 L .49244 .23142 L p F P
.392 .656 .4 r
s
.659 .453 .281 r
.49517 .41709 m .49846 .45007 L .51202 .47066 L p F P
.623 .462 .287 r
s
.659 .453 .281 r
.51202 .47066 m .51113 .44691 L .49517 .41709 L p F P
.623 .462 .287 r
s
.638 .439 .274 r
.51027 .41867 m .51113 .44691 L .52759 .47053 L p F P
.623 .462 .287 r
s
.638 .439 .274 r
.52759 .47053 m .52922 .45102 L .51027 .41867 L p F P
.623 .462 .287 r
s
.629 .435 .275 r
.51027 .41867 m .52922 .45102 L .5308 .42836 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.64272 .23403 m .62288 .22673 L .61643 .21919 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.61643 .21919 m .63531 .22515 L .64272 .23403 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.33349 .23132 m .36994 .2284 L .35028 .23384 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39189 .23052 m .35028 .23384 L .36994 .2284 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57095 .22723 m .57939 .2334 L .54957 .22925 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57939 .2334 m .57095 .22723 L .59768 .23246 L p F P
.392 .656 .4 r
s
.662 .459 .287 r
.47975 .44948 m .4731 .41636 L .46629 .4455 L p F P
.623 .462 .287 r
s
.667 .465 .293 r
.4731 .41636 m .47975 .44948 L .48621 .43174 L p F P
.623 .462 .287 r
s
.694 .485 .303 r
.45871 .41696 m .46629 .4455 L .4731 .41636 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.46065 .22698 m .45186 .23311 L .44016 .22419 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.33298 .22667 m .30424 .23276 L .31654 .22536 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.30424 .23276 m .33298 .22667 L .35833 .22542 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.35833 .22542 m .33349 .23132 L .30424 .23276 L p F P
.392 .656 .4 r
s
.561 .387 .25 r
.66399 .3673 m .64493 .40823 L .63785 .43785 L p F P
.623 .462 .287 r
s
.561 .387 .25 r
.63785 .43785 m .6563 .4076 L .66399 .3673 L p F P
.623 .462 .287 r
s
.477 .326 .216 r
.66399 .3673 m .6563 .4076 L .67424 .37289 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.60501 .22412 m .62567 .23266 L .60719 .22978 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62567 .23266 m .60501 .22412 L .6026 .21927 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.6026 .21927 m .62288 .22673 L .62567 .23266 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58492 .22539 m .59768 .23246 L .57095 .22723 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.59768 .23246 m .58492 .22539 L .60719 .22978 L p F P
.392 .656 .4 r
s
.753 .523 .317 r
.30241 .31818 m .33114 .3592 L .30755 .31073 L p F P
.623 .462 .287 r
s
.717 .494 .298 r
.34799 .3705 m .30755 .31073 L .33114 .3592 L p F P
.623 .462 .287 r
s
.677 .469 .291 r
.46629 .4455 m .45871 .41696 L .45045 .44856 L p F P
.623 .462 .287 r
s
.476 .325 .215 r
.62777 .42525 m .64766 .38251 L .62588 .41093 L p F P
.623 .462 .287 r
s
.561 .386 .249 r
.64766 .38251 m .62777 .42525 L .62519 .44307 L p F P
.623 .462 .287 r
s
.561 .386 .249 r
.62519 .44307 m .64493 .40823 L .64766 .38251 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.49244 .23142 m .48741 .22679 L p .49125 .21269 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.49125 .21269 m .49919 .21935 L .49244 .23142 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.50226 .22748 m .49244 .23142 L .49919 .21935 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.33349 .23132 m .35833 .22542 L .38991 .22287 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.38991 .22287 m .36994 .2284 L .33349 .23132 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65387 .23102 m .63531 .22515 L .62771 .21604 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62771 .21604 m .64534 .22055 L .65387 .23102 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65387 .23102 m .64534 .22055 L .66274 .22499 L p F P
.392 .656 .4 r
s
.566 .386 .245 r
.55302 .45971 m .5308 .42836 L .52922 .45102 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.36994 .2284 m .4067 .22545 L .39189 .23052 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4339 .22717 m .39189 .23052 L .4067 .22545 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.2896 .23042 m .31157 .22016 L .33622 .21627 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.33622 .21627 m .31654 .22536 L .2896 .23042 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51213 .23011 m .51304 .22204 L .52399 .2165 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52399 .2165 m .52568 .22335 L .51213 .23011 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52733 .23005 m .52568 .22335 L .54062 .21788 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.54062 .21788 m .54513 .22361 L .52733 .23005 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58998 .22176 m .60719 .22978 L .58492 .22539 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60719 .22978 m .58998 .22176 L .60501 .22412 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.54957 .22925 m .54513 .22361 L .57095 .22723 L p F P
.392 .656 .4 r
s
.625 .431 .271 r
.49187 .46521 m .48621 .43174 L .47975 .44948 L p F P
.623 .462 .287 r
s
.646 .443 .274 r
.48621 .43174 m .49187 .46521 L .50189 .47682 L p F P
.623 .462 .287 r
s
.646 .443 .274 r
.50189 .47682 m .49846 .45007 L .48621 .43174 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.4831 .22064 m .47512 .22841 L .46959 .22073 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47512 .22841 m .4831 .22064 L .48741 .22679 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.46065 .22698 m .46959 .22073 L .47512 .22841 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.36994 .2284 m .38991 .22287 L .42173 .2203 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.42173 .2203 m .4067 .22545 L .36994 .2284 L p F P
.392 .656 .4 r
s
.544 .373 .241 r
.59939 .443 m .61182 .41391 L .58075 .44876 L p F P
.623 .462 .287 r
s
.543 .375 .244 r
.61182 .41391 m .59939 .443 L .62588 .41093 L p F P
.623 .462 .287 r
s
.391 .258 .174 r
.66553 .41503 m .67424 .37289 L .6563 .4076 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.51304 .22204 m .50226 .22748 L p .49919 .21935 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.56235 .22095 m .57095 .22723 L .54513 .22361 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57095 .22723 m .56235 .22095 L .58492 .22539 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4067 .22545 m .44016 .22419 L .4339 .22717 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.46959 .22073 m .46065 .22698 L .45064 .21921 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.44016 .22419 m .45064 .21921 L .46065 .22698 L p F P
.392 .656 .4 r
s
.743 .515 .31 r
.33031 .37106 m .30241 .31818 L .31394 .3543 L p F P
.623 .462 .287 r
s
.665 .45 .261 r
.30241 .31818 m .33031 .37106 L .35552 .40171 L p F P
.623 .462 .287 r
s
.665 .45 .261 r
.35552 .40171 m .33114 .3592 L .30241 .31818 L p F P
.623 .462 .287 r
s
.598 .413 .263 r
.58901 .42569 m .55302 .45971 L .55036 .46954 L p F P
.623 .462 .287 r
s
.598 .413 .263 r
.55036 .46954 m .58075 .44876 L .58901 .42569 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.48741 .22679 m .4831 .22064 L .49125 .21269 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62288 .22673 m .6026 .21927 L .59722 .21311 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.59722 .21311 m .61643 .21919 L .62288 .22673 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.36225 .22048 m .33298 .22667 L .34387 .22023 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.33298 .22667 m .36225 .22048 L .3836 .21941 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.3836 .21941 m .35833 .22542 L .33298 .22667 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.31654 .22536 m .34387 .22023 L .33298 .22667 L p F P
.392 .656 .4 r
s
.685 .472 .289 r
.44186 .42545 m .43199 .45601 L .43829 .46619 L p F P
.623 .462 .287 r
s
.685 .472 .289 r
.43829 .46619 m .45045 .44856 L .44186 .42545 L p F P
.623 .462 .287 r
s
.497 .338 .221 r
.60915 .4452 m .62588 .41093 L .59939 .443 L p F P
.623 .462 .287 r
s
.476 .325 .215 r
.62588 .41093 m .60915 .4452 L .62777 .42525 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.4067 .22545 m .42173 .2203 L .45064 .21921 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45064 .21921 m .44016 .22419 L .4067 .22545 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.35833 .22542 m .3836 .21941 L .41021 .21725 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.41021 .21725 m .38991 .22287 L .35833 .22542 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57188 .21817 m .58492 .22539 L .56235 .22095 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58492 .22539 m .57188 .21817 L .58998 .22176 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.34387 .22023 m .31654 .22536 L .33622 .21627 L p F P
.392 .656 .4 r
s
.605 .406 .226 r
.28791 .30472 m .30869 .35943 L .33294 .39648 L p F P
.623 .462 .287 r
s
.605 .406 .226 r
.33294 .39648 m .31394 .3543 L .28791 .30472 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.63531 .22515 m .61643 .21919 L .60984 .21147 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60984 .21147 m .62771 .21604 L .63531 .22515 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65304 .21278 m .66274 .22499 L .64534 .22055 L p F P
.392 .656 .4 r
s
.717 .494 .298 r
.33114 .3592 m .36732 .40563 L .34799 .3705 L p F P
.623 .462 .287 r
s
.675 .461 .278 r
.38952 .4191 m .34799 .3705 L .36732 .40563 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.60501 .22412 m .58998 .22176 L p .55857 .2108 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.55857 .2108 m .58047 .21399 L .60501 .22412 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.6026 .21927 m .60501 .22412 L .58047 .21399 L p F P
.392 .656 .4 r
s
.599 .407 .253 r
.51113 .44691 m .51202 .47066 L .52591 .48677 L p F P
.623 .462 .287 r
s
.599 .407 .253 r
.52591 .48677 m .52759 .47053 L .51113 .44691 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.54513 .22361 m .54062 .21788 L .56235 .22095 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52568 .22335 m .52399 .2165 L .53603 .21205 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.53603 .21205 m .54062 .21788 L .52568 .22335 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.38991 .22287 m .41021 .21725 L .43699 .21507 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.43699 .21507 m .42173 .2203 L .38991 .22287 L p F P
.392 .656 .4 r
s
.602 .401 .229 r
.33114 .3592 m .35552 .40171 L .38718 .43624 L p F P
.623 .462 .287 r
s
.602 .401 .229 r
.38718 .43624 m .36732 .40563 L .33114 .3592 L p F P
.623 .462 .287 r
s
.611 .414 .255 r
.49846 .45007 m .50189 .47682 L .51293 .4897 L p F P
.623 .462 .287 r
s
.611 .414 .255 r
.51293 .4897 m .51202 .47066 L .49846 .45007 L p F P
.623 .462 .287 r
s
.534 .364 .235 r
.64493 .40823 m .62519 .44307 L .61888 .46342 L p F P
.623 .462 .287 r
s
.534 .364 .235 r
.61888 .46342 m .63785 .43785 L .64493 .40823 L p F P
.623 .462 .287 r
s
.56 .379 .239 r
.52922 .45102 m .52759 .47053 L .54587 .48387 L p F P
.623 .462 .287 r
s
.56 .379 .239 r
.54587 .48387 m .55036 .46954 L .52922 .45102 L p F P
.623 .462 .287 r
s
.566 .386 .245 r
.52922 .45102 m .55036 .46954 L .55302 .45971 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.49919 .21935 m .51396 .21376 L .51304 .22204 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52399 .2165 m .51304 .22204 L .51396 .21376 L p F P
.392 .656 .4 r
s
.638 .437 .271 r
.47411 .46953 m .46629 .4455 L .45928 .4685 L p F P
.623 .462 .287 r
s
.662 .459 .287 r
.46629 .4455 m .47411 .46953 L .47975 .44948 L p F P
.623 .462 .287 r
s
.677 .469 .291 r
.45045 .44856 m .45928 .4685 L .46629 .4455 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.58998 .22176 m .57188 .21817 L .55857 .2108 L p F P
.392 .656 .4 r
s
.613 .419 .262 r
.48667 .47637 m .47975 .44948 L .47411 .46953 L p F P
.623 .462 .287 r
s
.625 .431 .271 r
.47975 .44948 m .48667 .47637 L .49187 .46521 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.5536 .21455 m .56235 .22095 L .54062 .21788 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.56235 .22095 m .5536 .21455 L .57188 .21817 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4787 .21437 m .46959 .22073 L .46128 .21415 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.46959 .22073 m .4787 .21437 L .4831 .22064 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45064 .21921 m .46128 .21415 L .46959 .22073 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4831 .22064 m .4787 .21437 L p .48057 .20498 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.48057 .20498 m .49125 .21269 L .4831 .22064 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.64534 .22055 m .62771 .21604 L .62512 .20764 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62512 .20764 m .64258 .21086 L .64534 .22055 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.64534 .22055 m .64258 .21086 L .65304 .21278 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39204 .21416 m .36225 .22048 L .37162 .21501 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.36225 .22048 m .39204 .21416 L .40931 .21329 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.40931 .21329 m .3836 .21941 L .36225 .22048 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.34387 .22023 m .37162 .21501 L .36225 .22048 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.42173 .2203 m .43699 .21507 L .46128 .21415 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.46128 .21415 m .45064 .21921 L .42173 .2203 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.37162 .21501 m .34387 .22023 L .36115 .21233 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.33622 .21627 m .36115 .21233 L .34387 .22023 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.31157 .22016 m .3342 .20959 L .35643 .20693 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.35643 .20693 m .33622 .21627 L .31157 .22016 L p F P
.392 .656 .4 r
s
.405 .268 .179 r
.6071 .4603 m .62777 .42525 L .60915 .4452 L p F P
.623 .462 .287 r
s
.528 .359 .231 r
.62777 .42525 m .6071 .4603 L .60478 .47147 L p F P
.623 .462 .287 r
s
.528 .359 .231 r
.60478 .47147 m .62519 .44307 L .62777 .42525 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.3836 .21941 m .40931 .21329 L .43084 .21154 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.43084 .21154 m .41021 .21725 L .3836 .21941 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.50492 .20912 m .49919 .21935 L .49125 .21269 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.49919 .21935 m .50492 .20912 L .51491 .20529 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51491 .20529 m .51396 .21376 L .49919 .21935 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.59722 .21311 m .6026 .21927 L p .58047 .21399 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.61643 .21919 m .59722 .21311 L .59174 .20685 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.59174 .20685 m .60984 .21147 L .61643 .21919 L p F P
.392 .656 .4 r
s
.473 .318 .208 r
.6563 .4076 m .63785 .43785 L .63044 .46124 L p F P
.623 .462 .287 r
s
.473 .318 .208 r
.63044 .46124 m .64817 .4398 L .6563 .4076 L p F P
.623 .462 .287 r
s
.391 .258 .174 r
.6563 .4076 m .64817 .4398 L .66553 .41503 L p F P
.623 .462 .287 r
s
.531 .36 .232 r
.57226 .46866 m .58075 .44876 L .55036 .46954 L p F P
.623 .462 .287 r
s
.544 .373 .241 r
.58075 .44876 m .57226 .46866 L .59939 .443 L p F P
.623 .462 .287 r
s
.641 .438 .27 r
.45928 .4685 m .45045 .44856 L .43829 .46619 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.57188 .21817 m .5536 .21455 L p .53242 .20745 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.53242 .20745 m .55857 .2108 L .57188 .21817 L p F P
.392 .656 .4 r
s
.496 .335 .217 r
.58658 .46753 m .59939 .443 L .57226 .46866 L p F P
.623 .462 .287 r
s
.497 .338 .221 r
.59939 .443 m .58658 .46753 L .60915 .4452 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.54062 .21788 m .53603 .21205 L .5536 .21455 L p F P
.392 .656 .4 r
s
.675 .461 .278 r
.36732 .40563 m .40428 .44322 L .38952 .4191 L p F P
.623 .462 .287 r
s
.63 .427 .259 r
.43199 .45601 m .38952 .4191 L .40428 .44322 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.41021 .21725 m .43084 .21154 L .45248 .20977 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45248 .20977 m .43699 .21507 L .41021 .21725 L p F P
.392 .656 .4 r
s
.704 .483 .291 r
.3592 .41636 m .33031 .37106 L .34078 .39779 L p F P
.623 .462 .287 r
s
.579 .383 .217 r
.33031 .37106 m .3592 .41636 L .38067 .43795 L p F P
.623 .462 .287 r
s
.579 .383 .217 r
.38067 .43795 m .35552 .40171 L .33031 .37106 L p F P
.623 .462 .287 r
s
.743 .515 .31 r
.31394 .3543 m .34078 .39779 L .33031 .37106 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.53603 .21205 m .52399 .2165 L p .51396 .21376 L F P
.392 .656 .4 r
s
.697 .476 .282 r
.34078 .39779 m .31394 .3543 L .33294 .39648 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.36115 .21233 m .33622 .21627 L .35643 .20693 L p F P
.392 .656 .4 r
s
.584 .386 .224 r
.36732 .40563 m .38718 .43624 L .41939 .46407 L p F P
.623 .462 .287 r
s
.584 .386 .224 r
.41939 .46407 m .40428 .44322 L .36732 .40563 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.62771 .21604 m .60984 .21147 L .60749 .2044 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60749 .2044 m .62512 .20764 L .62771 .21604 L p F P
.392 .656 .4 r
s
.615 .414 .252 r
.49187 .46521 m .48667 .47637 L p .4905 .50313 L F P
.623 .462 .287 r
s
.615 .414 .252 r
.4905 .50313 m .49871 .4939 L .49187 .46521 L p F P
.623 .462 .287 r
s
.458 .297 .186 r
.50189 .47682 m .49187 .46521 L .49871 .4939 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.43699 .21507 m .45248 .20977 L .47207 .20902 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47207 .20902 m .46128 .21415 L .43699 .21507 L p F P
.392 .656 .4 r
s
.424 .28 .185 r
.59183 .47309 m .60915 .4452 L .58658 .46753 L p F P
.623 .462 .287 r
s
.405 .268 .179 r
.60915 .4452 m .59183 .47309 L .6071 .4603 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.39979 .20972 m .37162 .21501 L .38637 .20834 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.37162 .21501 m .39979 .20972 L .39204 .21416 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.36115 .21233 m .38637 .20834 L .37162 .21501 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.5536 .21455 m .53603 .21205 L .53242 .20745 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4787 .21437 m .47207 .20902 L .48057 .20498 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.46128 .21415 m .47207 .20902 L .4787 .21437 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39204 .21416 m .39979 .20972 L p .43767 .20024 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.43767 .20024 m .42716 .20672 L .39204 .21416 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.40931 .21329 m .39204 .21416 L .42716 .20672 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.5598 .20544 m .58047 .21399 L .55857 .2108 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58047 .21399 m .5598 .20544 L .55777 .20064 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.55777 .20064 m .57767 .20693 L .58047 .21399 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58047 .21399 m .57767 .20693 L .59722 .21311 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51396 .21376 m .51491 .20529 L .52733 .20099 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52733 .20099 m .53242 .20745 L .51396 .21376 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51396 .21376 m .53242 .20745 L .53603 .21205 L p F P
.392 .656 .4 r
s
.539 .358 .221 r
.51202 .47066 m .51293 .4897 L .52419 .49958 L p F P
.623 .462 .287 r
s
.539 .358 .221 r
.52419 .49958 m .52591 .48677 L .51202 .47066 L p F P
.623 .462 .287 r
s
.51 .338 .213 r
.52759 .47053 m .52591 .48677 L .54129 .49568 L p F P
.623 .462 .287 r
s
.51 .338 .213 r
.54129 .49568 m .54587 .48387 L .52759 .47053 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.43084 .21154 m .40931 .21329 L p .42716 .20672 L F P
.392 .656 .4 r
s
.525 .34 .194 r
.35552 .40171 m .38067 .43795 L .40758 .46213 L p F P
.623 .462 .287 r
s
.525 .34 .194 r
.40758 .46213 m .38718 .43624 L .35552 .40171 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.59174 .20685 m .59722 .21311 L .57767 .20693 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.69813 .21043 m .65304 .21278 L .64258 .21086 L p F P
.392 .656 .4 r
s
.531 .36 .232 r
.55036 .46954 m .54587 .48387 L .57226 .46866 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.4996 .20456 m .49125 .21269 L .48057 .20498 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.49125 .21269 m .4996 .20456 L .50492 .20912 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.38637 .20834 m .36115 .21233 L .37883 .20425 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.35643 .20693 m .37883 .20425 L .36115 .21233 L p F P
.392 .656 .4 r
s
.257 .164 .111 r
.65624 .44621 m .66553 .41503 L .64817 .4398 L p F P
.623 .462 .287 r
s
.578 .389 .241 r
.48218 .48882 m .47411 .46953 L .46833 .48511 L p F P
.623 .462 .287 r
s
.613 .419 .262 r
.47411 .46953 m .48218 .48882 L .48667 .47637 L p F P
.623 .462 .287 r
s
.638 .437 .271 r
.45928 .4685 m .46833 .48511 L .47411 .46953 L p F P
.623 .462 .287 r
s
.495 .332 .214 r
.62519 .44307 m .60478 .47147 L .59941 .48409 L p F P
.623 .462 .287 r
s
.495 .332 .214 r
.59941 .48409 m .61888 .46342 L .62519 .44307 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.42716 .20672 m .45182 .20573 L .43084 .21154 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45248 .20977 m .43084 .21154 L .45182 .20573 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60984 .21147 m .59174 .20685 L .58971 .20112 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58971 .20112 m .60749 .2044 L .60984 .21147 L p F P
.392 .656 .4 r
s
.63 .427 .259 r
.40428 .44322 m .43829 .46619 L .43199 .45601 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.64258 .21086 m .62512 .20764 L .65389 .20489 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65389 .20489 m .6761 .20767 L .64258 .21086 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.64258 .21086 m .6761 .20767 L .69813 .21043 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.54497 .20327 m .55857 .2108 L .53242 .20745 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.55857 .2108 m .54497 .20327 L .5598 .20544 L p F P
.392 .656 .4 r
s
.479 .319 .205 r
.56356 .48525 m .57226 .46866 L .54587 .48387 L p F P
.623 .462 .287 r
s
.496 .335 .217 r
.57226 .46866 m .56356 .48525 L .58658 .46753 L p F P
.623 .462 .287 r
s
.515 .336 .191 r
.30869 .35943 m .33063 .40367 L .35282 .43029 L p F P
.623 .462 .287 r
s
.515 .336 .191 r
.35282 .43029 m .33294 .39648 L .30869 .35943 L p F P
.623 .462 .287 r
s
.434 .286 .187 r
.63785 .43785 m .61888 .46342 L .61235 .47924 L p F P
.623 .462 .287 r
s
.434 .286 .187 r
.61235 .47924 m .63044 .46124 L .63785 .43785 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.74352 .20807 m .69813 .21043 L .6761 .20767 L p F P
.392 .656 .4 r
s
.581 .386 .231 r
.40428 .44322 m .41939 .46407 L .44889 .48106 L p F P
.623 .462 .287 r
s
.581 .386 .231 r
.44889 .48106 m .43829 .46619 L .40428 .44322 L p F P
.623 .462 .287 r
s
.59 .397 .244 r
.46833 .48511 m .45928 .4685 L .44889 .48106 L p F P
.623 .462 .287 r
s
.641 .438 .27 r
.43829 .46619 m .44889 .48106 L .45928 .4685 L p F P
.623 .462 .287 r
s
.458 .297 .186 r
.51293 .4897 m .50189 .47682 L p .49871 .4939 L F P
.623 .462 .287 r
s
.238 .591 .266 r
.47207 .20902 m .45248 .20977 L p .45182 .20573 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.39979 .20972 m .41187 .20431 L .43767 .20024 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.38637 .20834 m .41187 .20431 L .39979 .20972 L p F P
.392 .656 .4 r
s
.615 .414 .252 r
.48667 .47637 m .48218 .48882 L .4905 .50313 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.3342 .20959 m .35754 .19869 L .37002 .19783 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.37002 .19783 m .35643 .20693 L .3342 .20959 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.50492 .20912 m .4996 .20456 L p .50304 .1943 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.50304 .1943 m .51141 .1975 L .50492 .20912 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51491 .20529 m .50492 .20912 L .51141 .1975 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45182 .20573 m .48057 .20498 L .47207 .20902 L p F P
.392 .656 .4 r
s
.421 .275 .18 r
.57337 .48727 m .58658 .46753 L .56356 .48525 L p F P
.623 .462 .287 r
s
.424 .28 .185 r
.58658 .46753 m .57337 .48727 L .59183 .47309 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.41187 .20431 m .38637 .20834 L .4014 .20155 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.37883 .20425 m .4014 .20155 L .38637 .20834 L p F P
.392 .656 .4 r
s
.502 .322 .185 r
.38718 .43624 m .40758 .46213 L .43484 .48153 L p F P
.623 .462 .287 r
s
.502 .322 .185 r
.43484 .48153 m .41939 .46407 L .38718 .43624 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.6761 .20767 m .71589 .20559 L .74352 .20807 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.78922 .20569 m .74352 .20807 L .71589 .20559 L p F P
.392 .656 .4 r
s
.646 .435 .257 r
.3684 .43487 m .34078 .39779 L .35776 .42881 L p F P
.623 .462 .287 r
s
.704 .483 .291 r
.34078 .39779 m .3684 .43487 L .3592 .41636 L p F P
.623 .462 .287 r
s
.697 .476 .282 r
.33294 .39648 m .35776 .42881 L .34078 .39779 L p F P
.623 .462 .287 r
s
.549 .372 .237 r
.6071 .4603 m .59183 .47309 L p .5598 .50199 L F P
.623 .462 .287 r
s
.549 .372 .237 r
.5598 .50199 m .58224 .49057 L .6071 .4603 L p F P
.623 .462 .287 r
s
.215 .131 .081 r
.60478 .47147 m .6071 .4603 L .58224 .49057 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.6761 .20767 m .65389 .20489 L .68806 .20309 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.68806 .20309 m .71589 .20559 L .6761 .20767 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62512 .20764 m .60749 .2044 L .63151 .20209 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.63151 .20209 m .65389 .20489 L .62512 .20764 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.53242 .20745 m .52733 .20099 L .54497 .20327 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57767 .20693 m .55777 .20064 L .55634 .19498 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.55634 .19498 m .57577 .19856 L .57767 .20693 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58971 .20112 m .59174 .20685 L p .57767 .20693 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.57767 .20693 m .57577 .19856 L .58971 .20112 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.37883 .20425 m .35643 .20693 L .37002 .19783 L p F P
.392 .656 .4 r
s
.648 .438 .263 r
.38903 .45361 m .3592 .41636 L .3684 .43487 L p F P
.623 .462 .287 r
s
.491 .313 .18 r
.3592 .41636 m .38903 .45361 L .40656 .46757 L p F P
.623 .462 .287 r
s
.491 .313 .18 r
.40656 .46757 m .38067 .43795 L .3592 .41636 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.45654 .2005 m .42716 .20672 L .43767 .20024 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.42716 .20672 m .45654 .2005 L .47314 .19983 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47314 .19983 m .45182 .20573 L .42716 .20672 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45182 .20573 m .47314 .19983 L .49248 .19932 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.49248 .19932 m .48057 .20498 L .45182 .20573 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.71589 .20559 m .75592 .20349 L .78922 .20569 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.83522 .2033 m .78922 .20569 L .75592 .20349 L p F P
.392 .656 .4 r
s
.479 .319 .205 r
.54587 .48387 m .54129 .49568 L .56356 .48525 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.71589 .20559 m .68806 .20309 L .72241 .20128 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.72241 .20128 m .75592 .20349 L .71589 .20559 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.5598 .20544 m .54497 .20327 L p .52282 .19526 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.52282 .19526 m .53645 .1958 L .5598 .20544 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.55777 .20064 m .5598 .20544 L .53645 .1958 L p F P
.392 .656 .4 r
s
.288 .181 .122 r
.64817 .4398 m .63044 .46124 L .62802 .47368 L p F P
.623 .462 .287 r
s
.288 .181 .122 r
.62802 .47368 m .6457 .45733 L .64817 .4398 L p F P
.623 .462 .287 r
s
.257 .164 .111 r
.64817 .4398 m .6457 .45733 L .65624 .44621 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.52733 .20099 m .51491 .20529 L p .51141 .1975 L F P
.392 .656 .4 r
s
.435 .278 .174 r
.52591 .48677 m .52419 .49958 L .5366 .50488 L p F P
.623 .462 .287 r
s
.435 .278 .174 r
.5366 .50488 m .54129 .49568 L .52591 .48677 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.48057 .20498 m .49248 .19932 L .4996 .20456 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65389 .20489 m .63151 .20209 L .66004 .20057 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.66004 .20057 m .68806 .20309 L .65389 .20489 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4996 .20456 m .49248 .19932 L .50304 .1943 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60749 .2044 m .58971 .20112 L .60895 .19926 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60895 .19926 m .63151 .20209 L .60749 .2044 L p F P
.392 .656 .4 r
s
.549 .372 .237 r
.59183 .47309 m .57337 .48727 L .5598 .50199 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.41187 .20431 m .42414 .19882 L p .44875 .19241 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.44875 .19241 m .43767 .20024 L .41187 .20431 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4014 .20155 m .42414 .19882 L .41187 .20431 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4014 .20155 m .37883 .20425 L .39075 .19641 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.37002 .19783 m .39075 .19641 L .37883 .20425 L p F P
.392 .656 .4 r
s
.43 .266 .157 r
.38067 .43795 m .40656 .46757 L .42849 .4831 L p F P
.623 .462 .287 r
s
.43 .266 .157 r
.42849 .4831 m .40758 .46213 L .38067 .43795 L p F P
.623 .462 .287 r
s
.589 .39 .223 r
.35776 .42881 m .33294 .39648 L .35282 .43029 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.75592 .20349 m .72241 .20128 L .74903 .19908 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.74903 .19908 m .78702 .20094 L .75592 .20349 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.75592 .20349 m .78702 .20094 L .83522 .2033 L p F P
.392 .656 .4 r
s
.458 .297 .186 r
.49871 .4939 m .51388 .50378 L .51293 .4897 L p F P
.623 .462 .287 r
s
.303 .177 .11 r
.52419 .49958 m .51293 .4897 L .51388 .50378 L p F P
.623 .462 .287 r
s
.502 .324 .191 r
.41939 .46407 m .43484 .48153 L .45971 .49338 L p F P
.623 .462 .287 r
s
.502 .324 .191 r
.45971 .49338 m .44889 .48106 L .41939 .46407 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.79778 .19676 m .83522 .2033 L .78702 .20094 L p F P
.392 .656 .4 r
s
.275 .177 .124 r
.70167 .40429 m .65624 .44621 L .65558 .4469 L p F P
.623 .462 .287 r
s
.275 .177 .124 r
.65558 .4469 m .6457 .45733 L p .67193 .43247 L F P
.623 .462 .287 r
s
.275 .177 .124 r
.67193 .43247 m .70167 .40429 L .65558 .4469 L F
.6457 .45733 m .67968 .43081 L .70167 .40429 L p F P
.623 .462 .287 r
s
.319 .209 .148 r
.74675 .34964 m .70167 .40429 L .6958 .41137 L p F P
.623 .462 .287 r
s
.319 .209 .148 r
.6958 .41137 m .67968 .43081 L p .71635 .38643 L F P
.623 .462 .287 r
s
.319 .209 .148 r
.71635 .38643 m .74675 .34964 L .6958 .41137 L F
.71956 .38843 m .74675 .34964 L p .69548 .41169 L F P
.623 .462 .287 r
s
.319 .209 .148 r
.67968 .43081 m .70841 .40027 L p .69548 .41169 L F P
.623 .462 .287 r
s
.319 .209 .148 r
.70841 .40027 m .71956 .38843 L p .69548 .41169 L F P
.623 .462 .287 r
s
.325 .216 .153 r
.71956 .38843 m .75912 .3363 L .763 .32981 L p F P
.623 .462 .287 r
s
.325 .216 .153 r
.79132 .28252 m .74675 .34964 L .73934 .36022 L p F P
.623 .462 .287 r
s
.325 .216 .153 r
.73934 .36022 m .71956 .38843 L p .76023 .32841 L F P
.623 .462 .287 r
s
.325 .216 .153 r
.76023 .32841 m .79132 .28252 L .73934 .36022 L F
.763 .32981 m .79132 .28252 L p .74202 .35528 L F P
.623 .462 .287 r
s
.325 .216 .153 r
.71956 .38843 m .763 .32981 L .74202 .35528 L F
.269 .181 .131 r
.75912 .3363 m .78945 .29011 L .80601 .25871 L p F P
.623 .462 .287 r
s
.269 .181 .131 r
.83522 .2033 m .79132 .28252 L .75912 .3363 L p F P
.623 .462 .287 r
s
.269 .181 .131 r
.80601 .25871 m .83522 .2033 L p .78667 .28815 L F P
.623 .462 .287 r
s
.269 .181 .131 r
.75912 .3363 m .80601 .25871 L .78667 .28815 L F
.089 .066 .041 r
.79999 .27449 m .83522 .2033 L .78945 .29011 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.54497 .20327 m .52733 .20099 L .52282 .19526 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.68806 .20309 m .66004 .20057 L .68869 .19906 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.68869 .19906 m .72241 .20128 L .68806 .20309 L p F P
.392 .656 .4 r
s
.399 .255 .165 r
.55465 .49839 m .56356 .48525 L .54129 .49568 L p F P
.623 .462 .287 r
s
.421 .275 .18 r
.56356 .48525 m .55465 .49839 L .57337 .48727 L p F P
.623 .462 .287 r
s
.513 .335 .205 r
.47761 .49829 m .46833 .48511 L .45971 .49338 L p F P
.623 .462 .287 r
s
.578 .389 .241 r
.46833 .48511 m .47761 .49829 L .48218 .48882 L p F P
.623 .462 .287 r
s
.59 .397 .244 r
.44889 .48106 m .45971 .49338 L .46833 .48511 L p F P
.623 .462 .287 r
s
.377 .24 .157 r
.61888 .46342 m .59941 .48409 L .59391 .4937 L p F P
.623 .462 .287 r
s
.377 .24 .157 r
.59391 .4937 m .61235 .47924 L .61888 .46342 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.63151 .20209 m .60895 .19926 L .63182 .19804 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.63182 .19804 m .66004 .20057 L .63151 .20209 L p F P
.392 .656 .4 r
s
.49 .315 .187 r
.48218 .48882 m .47761 .49829 L p .47946 .50872 L F P
.623 .462 .287 r
s
.49 .315 .187 r
.47946 .50872 m .4905 .50313 L .48218 .48882 L p F P
.623 .462 .287 r
s
.215 .131 .081 r
.59941 .48409 m .60478 .47147 L p .58224 .49057 L F P
.623 .462 .287 r
s
.238 .591 .266 r
.42414 .19882 m .4014 .20155 L .41156 .19497 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39075 .19641 m .41156 .19497 L .4014 .20155 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.72241 .20128 m .68869 .19906 L .71085 .19721 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.71085 .19721 m .74903 .19908 L .72241 .20128 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60895 .19926 m .58971 .20112 L .57577 .19856 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51141 .1975 m .52282 .19526 L .52733 .20099 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.78702 .20094 m .74903 .19908 L .72822 .19452 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.72822 .19452 m .76306 .19564 L .78702 .20094 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.78702 .20094 m .76306 .19564 L .79778 .19676 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.55634 .19498 m .55777 .20064 L p .53645 .1958 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.66004 .20057 m .63182 .19804 L .65476 .19682 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65476 .19682 m .68869 .19906 L .66004 .20057 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45654 .2005 m .46377 .19611 L p .49119 .18949 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.49119 .18949 m .48947 .19353 L .45654 .2005 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47314 .19983 m .45654 .2005 L .48947 .19353 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.43767 .20024 m .46377 .19611 L .45654 .2005 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.46377 .19611 m .43767 .20024 L .44875 .19241 L p F P
.392 .656 .4 r
s
.41 .258 .161 r
.50456 .5089 m .49871 .4939 L .4905 .50313 L p F P
.623 .462 .287 r
s
.378 .228 .137 r
.49871 .4939 m .50456 .5089 L .51485 .51266 L p F P
.623 .462 .287 r
s
.378 .228 .137 r
.51485 .51266 m .51388 .50378 L .49871 .4939 L p F P
.623 .462 .287 r
s
.416 .253 .151 r
.40758 .46213 m .42849 .4831 L .45063 .49548 L p F P
.623 .462 .287 r
s
.416 .253 .151 r
.45063 .49548 m .43484 .48153 L .40758 .46213 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.49248 .19932 m .47314 .19983 L p .48947 .19353 L F P
.392 .656 .4 r
s
.575 .38 .222 r
.39678 .46524 m .3684 .43487 L .38311 .45623 L p F P
.623 .462 .287 r
s
.648 .438 .263 r
.3684 .43487 m .39678 .46524 L .38903 .45361 L p F P
.623 .462 .287 r
s
.646 .435 .257 r
.35776 .42881 m .38311 .45623 L .3684 .43487 L p F P
.623 .462 .287 r
s
.399 .255 .165 r
.54129 .49568 m .5366 .50488 L .55465 .49839 L p F P
.623 .462 .287 r
s
.463 .303 .192 r
.55465 .49839 m .5366 .50488 L .53289 .51017 L p F P
.623 .462 .287 r
s
.463 .303 .192 r
.57337 .48727 m .55465 .49839 L p .53289 .51017 L F P
.623 .462 .287 r
s
.463 .303 .192 r
.53289 .51017 m .5598 .50199 L .57337 .48727 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.48947 .19353 m .50304 .1943 L .49248 .19932 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.63182 .19804 m .60895 .19926 L p .57577 .19856 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.74903 .19908 m .71085 .19721 L .69327 .1934 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.69327 .1934 m .72822 .19452 L .74903 .19908 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.68869 .19906 m .65476 .19682 L .67247 .19533 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.67247 .19533 m .71085 .19721 L .68869 .19906 L p F P
.392 .656 .4 r
s
.246 .153 .099 r
.63044 .46124 m .61235 .47924 L .61008 .48736 L p F P
.623 .462 .287 r
s
.246 .153 .099 r
.61008 .48736 m .62802 .47368 L .63044 .46124 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.42414 .19882 m .43245 .19353 L .44875 .19241 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.41156 .19497 m .43245 .19353 L .42414 .19882 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.35754 .19869 m .31542 .19207 L .34047 .19153 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.34047 .19153 m .37002 .19783 L .35754 .19869 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57577 .19856 m .55634 .19498 L .57476 .19292 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57476 .19292 m .60339 .19549 L .57577 .19856 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57577 .19856 m .60339 .19549 L .63182 .19804 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65476 .19682 m .63182 .19804 L .60339 .19549 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39075 .19641 m .37002 .19783 L .34047 .19153 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51688 .18772 m .51141 .1975 L .50304 .1943 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52282 .19526 m .51141 .1975 L .51688 .18772 L p F P
.392 .656 .4 r
s
.428 .265 .156 r
.40656 .46757 m .38903 .45361 L .42463 .48607 L p F P
.623 .462 .287 r
s
.428 .265 .156 r
.42849 .4831 m .40656 .46757 L p .42463 .48607 L F P
.623 .462 .287 r
s
.428 .265 .156 r
.42463 .48607 m .44989 .49894 L .42849 .4831 L p F P
.623 .462 .287 r
s
.373 .221 .135 r
.45469 .50381 m .42463 .48607 L .43531 .49564 L p F P
.623 .462 .287 r
s
.333 .193 .12 r
.45063 .49548 m .42849 .4831 L .44989 .49894 L p F P
.623 .462 .287 r
s
.333 .193 .12 r
.47074 .50306 m .45063 .49548 L p .44989 .49894 L F P
.623 .462 .287 r
s
.333 .193 .12 r
.44989 .49894 m .47946 .50872 L .47074 .50306 L p F P
.623 .462 .287 r
s
.236 .142 .088 r
.44989 .49894 m .47178 .50948 L .49171 .51377 L p F P
.623 .462 .287 r
s
.236 .142 .088 r
.47946 .50872 m .44989 .49894 L p .47938 .5094 L F P
.623 .462 .287 r
s
.401 .328 .228 r
.47178 .50948 m .45268 .50029 L .45841 .50284 L F
.44989 .49894 m .42463 .48607 L p .45841 .50284 L F P
.623 .462 .287 r
s
.401 .328 .228 r
.45268 .50029 m .44989 .49894 L .45841 .50284 L F
.45469 .50381 m .47178 .50948 L p .45575 .50152 L F P
.623 .462 .287 r
s
.146 .096 .059 r
.49171 .51377 m .47178 .50948 L p .48859 .51365 L F P
.623 .462 .287 r
s
.146 .096 .059 r
.47178 .50948 m .46872 .50846 L p .48859 .51365 L F P
.623 .462 .287 r
s
.146 .096 .059 r
.46872 .50846 m .45469 .50381 L .47515 .50975 L p F P
.623 .462 .287 r
s
.146 .096 .059 r
.47515 .50975 m .48859 .51365 L p .46872 .50846 L F P
.623 .462 .287 r
s
.236 .142 .088 r
.49171 .51377 m .48841 .51241 L p .47938 .5094 L F P
.623 .462 .287 r
s
.236 .142 .088 r
.48841 .51241 m .47946 .50872 L p .47938 .5094 L F P
.623 .462 .287 r
s
.327 .19 .118 r
.47946 .50872 m .49171 .51377 L .49906 .51223 L p F P
.623 .462 .287 r
s
.514 .431 .289 r
.49035 .51275 m .48859 .51365 L .45469 .50381 L p F P
.623 .462 .287 r
s
.514 .431 .289 r
.4621 .50731 m .4699 .50889 L .48668 .51206 L p F P
.623 .462 .287 r
s
.514 .431 .289 r
.48668 .51206 m .49035 .51275 L p .48484 .51169 L F P
.623 .462 .287 r
s
.514 .431 .289 r
.48484 .51169 m .4621 .50731 L .48668 .51206 L F
.45469 .50381 m .4621 .50731 L p .47326 .50946 L F P
.623 .462 .287 r
s
.514 .431 .289 r
.49035 .51275 m .46815 .50718 L .47326 .50946 L F
.46815 .50718 m .45469 .50381 L .47326 .50946 L F
.401 .328 .228 r
.42463 .48607 m .4444 .49773 L p .45575 .50152 L F P
.623 .462 .287 r
s
.401 .328 .228 r
.4444 .49773 m .45469 .50381 L p .45575 .50152 L F P
.623 .462 .287 r
s
.272 .207 .159 r
.43531 .49564 m .42463 .48607 L .40263 .46601 L p F P
.623 .462 .287 r
s
.272 .207 .159 r
.40263 .46601 m .38903 .45361 L p .40939 .4721 L F P
.623 .462 .287 r
s
.272 .207 .159 r
.43531 .49564 m .40263 .46601 L .40939 .4721 L F
.38903 .45361 m .39678 .46524 L p .43531 .49564 L F P
.623 .462 .287 r
s
.272 .207 .159 r
.39678 .46524 m .40897 .47856 L .43531 .49564 L p F P
.623 .462 .287 r
s
.242 .146 .09 r
.4621 .50731 m .43531 .49564 L .44663 .50133 L p F P
.623 .462 .287 r
s
.373 .221 .135 r
.43531 .49564 m .4621 .50731 L .45469 .50381 L p F P
.623 .462 .287 r
s
.391 .316 .224 r
.44663 .50133 m .43531 .49564 L .40897 .47856 L p F P
.623 .462 .287 r
s
.391 .316 .224 r
.40897 .47856 m .42143 .4888 L p .43595 .49602 L F P
.623 .462 .287 r
s
.391 .316 .224 r
.44663 .50133 m .43207 .49253 L .43595 .49602 L F
.43207 .49253 m .40897 .47856 L .43595 .49602 L F
.238 .591 .266 r
.71085 .19721 m .67247 .19533 L .65822 .19227 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65822 .19227 m .69327 .1934 L .71085 .19721 L p F P
.392 .656 .4 r
s
.527 .341 .194 r
.38311 .45623 m .35776 .42881 L .37536 .45341 L p F P
.623 .462 .287 r
s
.589 .39 .223 r
.35282 .43029 m .37536 .45341 L .35776 .42881 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.67247 .19533 m .65476 .19682 L p .60339 .19549 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.75965 .1901 m .79778 .19676 L .76306 .19564 L p F P
.392 .656 .4 r
s
.303 .177 .11 r
.5366 .50488 m .52419 .49958 L p .51388 .50378 L F P
.623 .462 .287 r
s
.238 .591 .266 r
.41156 .19497 m .39075 .19641 L .36556 .19099 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.34047 .19153 m .36556 .19099 L .39075 .19641 L p F P
.392 .656 .4 r
s
.411 .251 .149 r
.43484 .48153 m .45063 .49548 L .47074 .50306 L p F P
.623 .462 .287 r
s
.411 .251 .149 r
.47074 .50306 m .45971 .49338 L .43484 .48153 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.46377 .19611 m .47136 .19085 L .49119 .18949 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.44875 .19241 m .47136 .19085 L .46377 .19611 L p F P
.392 .656 .4 r
s
.427 .268 .157 r
.33063 .40367 m .35372 .4366 L .3663 .44868 L p F P
.623 .462 .287 r
s
.427 .268 .157 r
.3663 .44868 m .35282 .43029 L .33063 .40367 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.51688 .18772 m .53645 .1958 L .52282 .19526 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.53921 .19183 m .53645 .1958 L .51688 .18772 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.53645 .1958 m .53921 .19183 L .55634 .19498 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.76306 .19564 m .72822 .19452 L .69911 .18951 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.69911 .18951 m .72939 .1898 L .76306 .19564 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.76306 .19564 m .72939 .1898 L .75965 .1901 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60339 .19549 m .57476 .19292 L .59105 .19135 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.59105 .19135 m .62786 .19315 L .60339 .19549 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60339 .19549 m .62786 .19315 L .67247 .19533 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65822 .19227 m .67247 .19533 L .62786 .19315 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57476 .19292 m .55634 .19498 L .53921 .19183 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.43245 .19353 m .41156 .19497 L .39069 .19044 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.36556 .19099 m .39069 .19044 L .41156 .19497 L p F P
.392 .656 .4 r
s
.208 .128 .079 r
.5611 .50673 m .58224 .49057 L .5598 .50199 L p F P
.623 .462 .287 r
s
.31 .184 .117 r
.58224 .49057 m .5611 .50673 L .55905 .50995 L p F P
.623 .462 .287 r
s
.31 .184 .117 r
.55905 .50995 m .57946 .49967 L .58224 .49057 L p F P
.623 .462 .287 r
s
.215 .131 .081 r
.58224 .49057 m .57946 .49967 L .59941 .48409 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.75254 .34896 m .78945 .29011 L .75912 .3363 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.75912 .3363 m .72618 .38345 L .75254 .34896 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.71481 .39935 m .75254 .34896 L .72618 .38345 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.72618 .38345 m .69258 .42371 L .71481 .39935 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.69258 .42371 m .72618 .38345 L .69185 .42229 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.69185 .42229 m .66366 .45107 L .69258 .42371 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.65838 .45682 m .69258 .42371 L .66366 .45107 L p F P
.623 .462 .287 r
s
.777 .604 .355 r
.69258 .42371 m .65838 .45682 L .67632 .44094 L p F P
.623 .462 .287 r
s
.777 .604 .355 r
.71481 .39935 m .69258 .42371 L p .67705 .44016 L F P
.623 .462 .287 r
s
.777 .604 .355 r
.67632 .44094 m .67852 .43856 L p .67705 .44016 L F P
.623 .462 .287 r
s
.777 .604 .355 r
.67852 .43856 m .71481 .39935 L p .67705 .44016 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.62802 .47368 m .61008 .48736 L .63464 .47329 L p F P
.623 .462 .287 r
s
.096 .07 .043 r
.63464 .47329 m .65733 .45384 L .62802 .47368 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.66366 .45107 m .69185 .42229 L .65733 .45384 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.65733 .45384 m .63464 .47329 L .66366 .45107 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.61008 .48736 m .59189 .49833 L .61164 .48906 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.61164 .48906 m .63464 .47329 L .61008 .48736 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.63502 .47461 m .66366 .45107 L .63464 .47329 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.66366 .45107 m .63502 .47461 L .65838 .45682 L p F P
.623 .462 .287 r
s
.228 .145 .097 r
.67632 .44094 m .65838 .45682 L p .64146 .46843 L F P
.623 .462 .287 r
s
.203 .125 .078 r
.61235 .47924 m .59391 .4937 L .59189 .49833 L p F P
.623 .462 .287 r
s
.203 .125 .078 r
.59189 .49833 m .61008 .48736 L .61235 .47924 L p F P
.623 .462 .287 r
s
.129 .087 .054 r
.59189 .49833 m .59391 .4937 L p .57946 .49967 L F P
.623 .462 .287 r
s
.129 .087 .054 r
.57946 .49967 m .57759 .50494 L .59189 .49833 L p F P
.623 .462 .287 r
s
.174 .11 .069 r
.61164 .48906 m .59189 .49833 L .58567 .50121 L p F P
.623 .462 .287 r
s
.174 .11 .069 r
.58567 .50121 m .57759 .50494 L p .59196 .49824 L F P
.623 .462 .287 r
s
.174 .11 .069 r
.59196 .49824 m .61164 .48906 L .58567 .50121 L F
.089 .066 .041 r
.63464 .47329 m .61164 .48906 L .63502 .47461 L p F P
.623 .462 .287 r
s
.174 .11 .069 r
.63502 .47461 m .61553 .48666 L p .62305 .48118 L F P
.623 .462 .287 r
s
.174 .11 .069 r
.59955 .49335 m .63502 .47461 L .59196 .49824 L F
.59196 .49824 m .62305 .48118 L .61164 .48906 L F
.61553 .48666 m .61164 .48906 L p .62305 .48118 L F P
.623 .462 .287 r
s
.174 .11 .069 r
.57759 .50494 m .59955 .49335 L .59196 .49824 L F
.57759 .50494 m .60599 .49278 L .63502 .47461 L p F P
.623 .462 .287 r
s
.228 .145 .097 r
.65838 .45682 m .63502 .47461 L .60599 .49278 L p F P
.623 .462 .287 r
s
.897 .699 .425 r
.66195 .45385 m .66794 .44847 L p .63104 .47764 L F P
.623 .462 .287 r
s
.897 .699 .425 r
.66794 .44847 m .67632 .44094 L .65894 .45502 L p F P
.623 .462 .287 r
s
.897 .699 .425 r
.65894 .45502 m .63104 .47764 L p .66794 .44847 L F P
.623 .462 .287 r
s
.228 .145 .097 r
.61231 .48844 m .64819 .46267 L .64146 .46843 L F
.60599 .49278 m .64819 .46267 L .61231 .48844 L F
.60599 .49278 m .65649 .45555 L .64819 .46267 L F
.65649 .45555 m .67632 .44094 L .64146 .46843 L F
.63104 .47764 m .65894 .45502 L p .61031 .48959 L F P
.623 .462 .287 r
s
.228 .145 .097 r
.65894 .45502 m .67632 .44094 L p .64502 .46401 L F P
.623 .462 .287 r
s
.228 .145 .097 r
.61031 .48959 m .65894 .45502 L .64502 .46401 L F
.60599 .49278 m .61465 .48754 L p .61031 .48959 L F P
.623 .462 .287 r
s
.228 .145 .097 r
.61465 .48754 m .63104 .47764 L p .61031 .48959 L F P
.623 .462 .287 r
s
.107 .075 .047 r
.67632 .44094 m .66195 .45385 L p .69425 .42054 L F P
.623 .462 .287 r
s
.107 .075 .047 r
.69425 .42054 m .69509 .41967 L .69474 .42008 L F
.69425 .42054 m .69474 .42008 L .67632 .44094 L F
.71481 .39935 m .67852 .43856 L p .69509 .41967 L F P
.623 .462 .287 r
s
.107 .075 .047 r
.67852 .43856 m .67632 .44094 L p .69509 .41967 L F P
.623 .462 .287 r
s
.107 .075 .047 r
.6973 .41974 m .71481 .39935 L p .67901 .43625 L F P
.623 .462 .287 r
s
.107 .075 .047 r
.66195 .45385 m .68952 .42725 L p .67901 .43625 L F P
.623 .462 .287 r
s
.107 .075 .047 r
.68952 .42725 m .6973 .41974 L p .67901 .43625 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.6973 .41974 m .66195 .45385 L .65517 .45893 L p F P
.623 .462 .287 r
s
.096 .07 .043 r
.65517 .45893 m .6419 .46886 L p .66407 .44921 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.66407 .44921 m .6671 .44693 L .65517 .45893 L F
.67053 .44348 m .6973 .41974 L .65517 .45893 L F
.66407 .44921 m .67053 .44348 L .6671 .44693 L F
.6419 .46886 m .65524 .45789 L p .66727 .44637 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.65524 .45789 m .6727 .44352 L p .66727 .44637 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.6727 .44352 m .6419 .46886 L .6332 .47391 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.63553 .47052 m .64609 .46286 L .63954 .46847 L F
.64609 .46286 m .6727 .44352 L .6332 .47391 L F
.6476 .46242 m .6727 .44352 L p .64134 .46631 L F P
.623 .462 .287 r
s
.127 .086 .054 r
.6457 .45733 m .62802 .47368 L .65733 .45384 L p F P
.623 .462 .287 r
s
.909 .708 .431 r
.62754 .47249 m .6476 .46242 L p .61748 .47976 L F P
.623 .462 .287 r
s
.909 .708 .431 r
.60534 .48675 m .61128 .48294 L p .61748 .47976 L F P
.623 .462 .287 r
s
.909 .708 .431 r
.61128 .48294 m .62754 .47249 L p .61748 .47976 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.6332 .47391 m .62156 .48068 L p .63553 .47052 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.63553 .47052 m .63954 .46847 L .6332 .47391 L F
.096 .07 .043 r
.6727 .44352 m .6973 .41974 L p .66727 .44637 L F P
.623 .462 .287 r
s
.126 .089 .059 r
.75254 .34896 m .72285 .3886 L p .72018 .39177 L F P
.623 .462 .287 r
s
.126 .089 .059 r
.72285 .3886 m .71481 .39935 L p .72018 .39177 L F P
.623 .462 .287 r
s
.126 .089 .059 r
.71481 .39935 m .71185 .40279 L p .72018 .39177 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.72618 .38345 m .75912 .3363 L .71956 .38843 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.71956 .38843 m .69185 .42229 L .72618 .38345 L p F P
.623 .462 .287 r
s
.126 .089 .059 r
.71185 .40279 m .6973 .41974 L p .72883 .37934 L F P
.623 .462 .287 r
s
.126 .089 .059 r
.72883 .37934 m .72958 .37839 L .72923 .37886 L F
.72883 .37934 m .72923 .37886 L .71185 .40279 L F
.72958 .37839 m .75254 .34896 L .71185 .40279 L F
.73214 .37833 m .73505 .37414 L p .70614 .40842 L F P
.623 .462 .287 r
s
.126 .089 .059 r
.70614 .40842 m .73505 .37414 L .71554 .39637 L F
.71454 .39925 m .73214 .37833 L p .70614 .40842 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.6973 .41974 m .6727 .44352 L p .69454 .41957 L F P
.623 .462 .287 r
s
.126 .089 .059 r
.6973 .41974 m .71454 .39925 L p .70614 .40842 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.73214 .37833 m .70816 .40683 L p .69709 .41718 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.70075 .41276 m .73214 .37833 L .69709 .41718 L F
.70816 .40683 m .6973 .41974 L p .69454 .41957 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.71466 .3991 m .73214 .37833 L p .70336 .4099 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.70042 .41342 m .71466 .3991 L .70336 .4099 L F
.70321 .4127 m .71466 .3991 L p .70178 .41273 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.6727 .44352 m .70321 .4127 L p .70178 .41273 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.69454 .41957 m .70075 .41276 L .69709 .41718 L F
.6727 .44352 m .71466 .3991 L .6971 .41676 L F
.126 .089 .059 r
.73505 .37414 m .75254 .34896 L p .71554 .39637 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.75254 .34896 m .73214 .37833 L p .76283 .33109 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.78945 .29011 m .77326 .31593 L p .76283 .33109 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.77326 .31593 m .75254 .34896 L p .76283 .33109 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.76639 .32983 m .77254 .31924 L p .76495 .33034 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.73214 .37833 m .76639 .32983 L p .76495 .33034 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.73214 .37833 m .77254 .31924 L .75348 .34548 L F
.114 .083 .055 r
.73214 .37833 m .70321 .4127 L p .72465 .38458 L F P
.623 .462 .287 r
s
.114 .083 .055 r
.76639 .32983 m .73956 .36783 L p .72465 .38458 L F P
.623 .462 .287 r
s
.114 .083 .055 r
.73956 .36783 m .73214 .37833 L p .72465 .38458 L F P
.623 .462 .287 r
s
.114 .083 .055 r
.70321 .4127 m .7334 .37651 L .74934 .35396 L p F P
.623 .462 .287 r
s
.114 .083 .055 r
.70321 .4127 m .74934 .35396 L .73202 .37491 L F
.089 .066 .041 r
.67179 .44079 m .70321 .4127 L .65911 .45375 L F
.68705 .4277 m .70321 .4127 L p .67271 .43997 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.67229 .44037 m .68705 .4277 L .67271 .43997 L F
.096 .07 .043 r
.6971 .41676 m .70042 .41342 L .70336 .4099 L F
.127 .086 .054 r
.65733 .45384 m .67968 .43081 L .6457 .45733 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.67968 .43081 m .65733 .45384 L .69185 .42229 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.65911 .45375 m .6476 .46242 L p .66142 .45006 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.66142 .45006 m .67179 .44079 L .66476 .44798 L F
.66142 .45006 m .66476 .44798 L .65911 .45375 L F
.67353 .44024 m .68705 .4277 L p .6642 .44781 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.6476 .46242 m .67353 .44024 L p .6642 .44781 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.6476 .46242 m .68705 .4277 L .6718 .44078 L F
.919 .712 .431 r
.64973 .45525 m .67353 .44024 L p .64408 .46089 L F P
.623 .462 .287 r
s
.919 .712 .431 r
.62754 .47249 m .63587 .46602 L p .64408 .46089 L F P
.623 .462 .287 r
s
.919 .712 .431 r
.63587 .46602 m .64973 .45525 L p .64408 .46089 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.69185 .42229 m .71956 .38843 L .67968 .43081 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.68716 .42573 m .7334 .37651 L .697 .41846 L F
.697 .41846 m .67353 .44024 L p .68716 .42573 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.67353 .44024 m .68936 .42424 L .70315 .40874 L F
.67353 .44024 m .70315 .40874 L .70233 .40958 L F
.68936 .42424 m .69932 .41417 L p .70374 .40808 L F P
.623 .462 .287 r
s
.922 .711 .428 r
.67191 .43502 m .69932 .41417 L p .67057 .43799 L F P
.623 .462 .287 r
s
.922 .711 .428 r
.64973 .45525 m .66051 .44542 L p .67057 .43799 L F P
.623 .462 .287 r
s
.922 .711 .428 r
.66051 .44542 m .67191 .43502 L p .67057 .43799 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.7334 .37651 m .70321 .4127 L .697 .41846 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.70233 .40958 m .70315 .40874 L .70374 .40808 L F
.70321 .4127 m .6727 .44352 L .65911 .45375 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.69932 .41417 m .7334 .37651 L p .70374 .40808 L F P
.623 .462 .287 r
s
.114 .083 .055 r
.74934 .35396 m .76639 .32983 L p .73877 .36606 L F P
.623 .462 .287 r
s
.114 .083 .055 r
.73202 .37491 m .73596 .37015 L .73877 .36606 L F
.73596 .37015 m .74934 .35396 L .73877 .36606 L F
.089 .066 .041 r
.6718 .44078 m .67229 .44037 L .67271 .43997 L F
.62156 .48068 m .63144 .47375 L p .64134 .46631 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.63144 .47375 m .6476 .46242 L p .64134 .46631 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.77254 .31924 m .78945 .29011 L p .75348 .34548 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.78945 .29011 m .76639 .32983 L .79999 .27449 L p F P
.623 .462 .287 r
s
.513 .335 .205 r
.45971 .49338 m .47074 .50306 L .47761 .49829 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.72822 .19452 m .69327 .1934 L .6688 .18921 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.6688 .18921 m .69911 .18951 L .72822 .19452 L p F P
.392 .656 .4 r
s
.49 .315 .187 r
.47761 .49829 m .47074 .50306 L .47946 .50872 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.50304 .1943 m .48947 .19353 L .51688 .18772 L p F P
.392 .656 .4 r
s
.129 .087 .054 r
.59391 .4937 m .59941 .48409 L .57946 .49967 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.43245 .19353 m .41585 .1899 L p .42543 .18682 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.42543 .18682 m .44875 .19241 L .43245 .19353 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39069 .19044 m .41585 .1899 L .43245 .19353 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51688 .18772 m .48947 .19353 L .49119 .18949 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.69327 .1934 m .65822 .19227 L .63847 .18891 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.63847 .18891 m .6688 .18921 L .69327 .1934 L p F P
.392 .656 .4 r
s
.288 .169 .105 r
.51388 .50378 m .51485 .51266 L .52766 .51474 L p F P
.623 .462 .287 r
s
.288 .169 .105 r
.52766 .51474 m .53289 .51017 L .51388 .50378 L p F P
.623 .462 .287 r
s
.303 .177 .11 r
.51388 .50378 m .53289 .51017 L .5366 .50488 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.62786 .19315 m .59105 .19135 L .57773 .18831 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57773 .18831 m .60811 .18861 L .62786 .19315 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.63847 .18891 m .65822 .19227 L p .62786 .19315 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.62786 .19315 m .60811 .18861 L .63847 .18891 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.59105 .19135 m .57476 .19292 L p .53921 .19183 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.47136 .19085 m .44875 .19241 L .42543 .18682 L p F P
.392 .656 .4 r
s
.327 .19 .118 r
.49906 .51223 m .4905 .50313 L .47946 .50872 L p F P
.623 .462 .287 r
s
.41 .258 .161 r
.4905 .50313 m .49906 .51223 L .50456 .5089 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.31542 .19207 m .27251 .18532 L .30315 .18562 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.30315 .18562 m .34047 .19153 L .31542 .19207 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51688 .18772 m .55034 .18936 L .53921 .19183 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.53921 .19183 m .55034 .18936 L .59105 .19135 L p F P
.392 .656 .4 r
s
.575 .38 .222 r
.38311 .45623 m .40897 .47856 L .39678 .46524 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.36556 .19099 m .34047 .19153 L .30315 .18562 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57773 .18831 m .59105 .19135 L .55034 .18936 L p F P
.392 .656 .4 r
s
.089 .066 .041 r
.76639 .32983 m .7334 .37651 L .7632 .33507 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.7632 .33507 m .79999 .27449 L .76639 .32983 L p F P
.623 .462 .287 r
s
.463 .292 .17 r
.37536 .45341 m .35282 .43029 L .3663 .44868 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.39069 .19044 m .36556 .19099 L .33376 .18592 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.30315 .18562 m .33376 .18592 L .36556 .19099 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47136 .19085 m .45594 .18712 L p .48327 .18607 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.48327 .18607 m .49119 .18949 L .47136 .19085 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.42543 .18682 m .45594 .18712 L .47136 .19085 L p F P
.392 .656 .4 r
s
.462 .29 .169 r
.40897 .47856 m .38311 .45623 L .39824 .47295 L p F P
.623 .462 .287 r
s
.527 .341 .194 r
.37536 .45341 m .39824 .47295 L .38311 .45623 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.41585 .1899 m .39069 .19044 L .36434 .18622 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.33376 .18592 m .36434 .18622 L .39069 .19044 L p F P
.392 .656 .4 r
s
.242 .145 .09 r
.54585 .51148 m .55604 .50455 L p .53289 .51017 L F P
.623 .462 .287 r
s
.208 .128 .079 r
.5598 .50199 m .54585 .51148 L .5611 .50673 L p F P
.623 .462 .287 r
s
.242 .145 .09 r
.53289 .51017 m .52766 .51474 L .54585 .51148 L p F P
.623 .462 .287 r
s
.25 .15 .093 r
.54585 .51148 m .52766 .51474 L .52463 .51559 L p F P
.623 .462 .287 r
s
.25 .15 .093 r
.52463 .51559 m .52301 .51604 L p .52634 .51538 L F P
.623 .462 .287 r
s
.25 .15 .093 r
.52634 .51538 m .54585 .51148 L .52463 .51559 L F
.56022 .507 m .54585 .51148 L p .52301 .51604 L F P
.623 .462 .287 r
s
.25 .15 .093 r
.5611 .50673 m .56022 .507 L p .52301 .51604 L F P
.623 .462 .287 r
s
.25 .15 .093 r
.52301 .51604 m .53708 .51495 L .56049 .50694 L p F P
.623 .462 .287 r
s
.629 .519 .325 r
.55905 .50995 m .5611 .50673 L .53708 .51495 L p F P
.623 .462 .287 r
s
.853 .672 .425 r
.53994 .51408 m .53708 .51495 L .53192 .51469 L p F P
.623 .462 .287 r
s
.25 .15 .093 r
.52301 .51604 m .56049 .50694 L .56041 .5069 L F
.139 .092 .057 r
.52766 .51474 m .51485 .51266 L p .51124 .51593 L F P
.623 .462 .287 r
s
.853 .672 .425 r
.53192 .51469 m .51688 .51391 L p .53698 .51406 L F P
.623 .462 .287 r
s
.853 .672 .425 r
.53698 .51406 m .53994 .51408 L .53192 .51469 L F
.25 .15 .093 r
.56049 .50694 m .5611 .50673 L p .56041 .5069 L F P
.623 .462 .287 r
s
.242 .145 .09 r
.55604 .50455 m .5598 .50199 L .55437 .50364 L p F P
.623 .462 .287 r
s
.242 .145 .09 r
.55437 .50364 m .53289 .51017 L p .55604 .50455 L F P
.623 .462 .287 r
s
.238 .591 .266 r
.7208 .18331 m .75965 .1901 L .72939 .1898 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.41585 .1899 m .3949 .18652 L .42543 .18682 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.36434 .18622 m .3949 .18652 L .41585 .1899 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.72939 .1898 m .69911 .18951 L .66959 .18442 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.66959 .18442 m .69517 .18387 L .72939 .1898 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.72939 .1898 m .69517 .18387 L .7208 .18331 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.69911 .18951 m .6688 .18921 L .64404 .18497 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.64404 .18497 m .66959 .18442 L .69911 .18951 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.49119 .18949 m .48327 .18607 L .51688 .18772 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.54271 .18594 m .55034 .18936 L .51688 .18772 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.5628 .18456 m .57773 .18831 L p .55034 .18936 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.55034 .18936 m .54271 .18594 L .5628 .18456 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.6688 .18921 m .63847 .18891 L .61853 .18552 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.61853 .18552 m .64404 .18497 L .6688 .18921 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.61853 .18552 m .63847 .18891 L .60811 .18861 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60811 .18861 m .57773 .18831 L .5628 .18456 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.5628 .18456 m .58591 .18296 L .60811 .18861 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60269 .18181 m .61853 .18552 L p .60811 .18861 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.60811 .18861 m .58591 .18296 L .60269 .18181 L p F P
.392 .656 .4 r
s
.274 .162 .101 r
.50456 .5089 m .49906 .51223 L p .50259 .51549 L F P
.623 .462 .287 r
s
.274 .162 .101 r
.50259 .51549 m .51124 .51593 L .50456 .5089 L p F P
.623 .462 .287 r
s
.139 .092 .057 r
.51485 .51266 m .50456 .5089 L .51124 .51593 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.53099 .18101 m .54474 .18182 L .51688 .18772 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51688 .18772 m .52251 .17766 L .53099 .18101 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51082 .18002 m .52251 .17766 L .51688 .18772 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51688 .18772 m .49687 .17945 L .51082 .18002 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4943 .18356 m .49687 .17945 L .51688 .18772 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51688 .18772 m .48327 .18607 L .4943 .18356 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51688 .18772 m .54474 .18182 L .54271 .18594 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45594 .18712 m .44196 .18405 L .48327 .18607 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.40422 .1822 m .44196 .18405 L .45594 .18712 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45594 .18712 m .42543 .18682 L .40422 .1822 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.40422 .1822 m .42543 .18682 L .3949 .18652 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.3949 .18652 m .37375 .18311 L p .40422 .1822 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.33768 .18195 m .37375 .18311 L .3949 .18652 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.3949 .18652 m .36434 .18622 L .33768 .18195 L p F P
.392 .656 .4 r
s
.396 .24 .144 r
.39824 .47295 m .37536 .45341 L .38731 .4665 L p F P
.623 .462 .287 r
s
.463 .292 .17 r
.3663 .44868 m .38731 .4665 L .37536 .45341 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.3015 .18079 m .33768 .18195 L .36434 .18622 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.36434 .18622 m .33376 .18592 L .3015 .18079 L p F P
.392 .656 .4 r
s
.179 .112 .07 r
.57946 .49967 m .55905 .50995 L .5576 .51127 L p F P
.623 .462 .287 r
s
.179 .112 .07 r
.5576 .51127 m .57759 .50494 L .57946 .49967 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.4943 .18356 m .48327 .18607 L .44196 .18405 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57126 .17913 m .5628 .18456 L .54271 .18594 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57944 .17447 m .57126 .17913 L p .54271 .18594 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.54271 .18594 m .54474 .18182 L .57944 .17447 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.2652 .17962 m .3015 .18079 L .33376 .18592 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.33376 .18592 m .30315 .18562 L .2652 .17962 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.2652 .17962 m .30315 .18562 L .27251 .18532 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.64404 .18497 m .61853 .18552 L .60269 .18181 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.27251 .18532 m .22879 .17845 L .2652 .17962 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60269 .18181 m .62436 .18032 L .64404 .18497 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.66959 .18442 m .64404 .18497 L .62436 .18032 L p F P
.392 .656 .4 r
s
.462 .29 .169 r
.39824 .47295 m .42143 .4888 L .40897 .47856 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.58591 .18296 m .5628 .18456 L .57126 .17913 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62436 .18032 m .64612 .17882 L .66959 .18442 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.69517 .18387 m .66959 .18442 L .64612 .17882 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.44196 .18405 m .45816 .18244 L p .4943 .18356 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.42848 .17978 m .45816 .18244 L .44196 .18405 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.44196 .18405 m .40422 .1822 L .42848 .17978 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.64612 .17882 m .66797 .17731 L .69517 .18387 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.68121 .1764 m .7208 .18331 L .69517 .18387 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.69517 .18387 m .66797 .17731 L .68121 .1764 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.49687 .17945 m .4943 .18356 L .47662 .18031 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45816 .18244 m .47662 .18031 L .4943 .18356 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.37375 .18311 m .35796 .17994 L .40422 .1822 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.31769 .17797 m .35796 .17994 L .37375 .18311 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.37375 .18311 m .33768 .18195 L .31769 .17797 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57126 .17913 m .59893 .17475 L .58591 .18296 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.61256 .17626 m .60269 .18181 L .58591 .18296 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62694 .17033 m .61256 .17626 L p .58591 .18296 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.58591 .18296 m .59893 .17475 L .62694 .17033 L p F P
.392 .656 .4 r
s
.274 .162 .101 r
.49906 .51223 m .49171 .51377 L .50259 .51549 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.45618 .17654 m .47662 .18031 L .45816 .18244 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45816 .18244 m .42848 .17978 L .45618 .17654 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.42848 .17978 m .40422 .1822 L .35796 .17994 L p F P
.392 .656 .4 r
s
.324 .188 .117 r
.42143 .4888 m .39824 .47295 L .40851 .48155 L p F P
.623 .462 .287 r
s
.396 .24 .144 r
.38731 .4665 m .40851 .48155 L .39824 .47295 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.27721 .17599 m .31769 .17797 L .33768 .18195 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.33768 .18195 m .3015 .18079 L .27721 .17599 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.56214 .17519 m .57944 .17447 L .54474 .18182 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.5421 .17573 m .56214 .17519 L p .54474 .18182 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.54474 .18182 m .53099 .18101 L .5421 .17573 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62436 .18032 m .60269 .18181 L .61256 .17626 L p F P
.392 .656 .4 r
s
.266 .201 .156 r
.35372 .4366 m .31138 .39074 L .33641 .41953 L p F P
.623 .462 .287 r
s
.266 .201 .156 r
.33641 .41953 m .3663 .44868 L .35372 .4366 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.53501 .17005 m .5421 .17573 L .53099 .18101 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.5296 .16497 m .53501 .17005 L p .53099 .18101 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.53099 .18101 m .52251 .17766 L .5296 .16497 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.23651 .174 m .27721 .17599 L .3015 .18079 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.3015 .18079 m .2652 .17962 L .23651 .174 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.61256 .17626 m .63696 .17334 L .62436 .18032 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.64612 .17882 m .62436 .18032 L .63696 .17334 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47662 .18031 m .47448 .17432 L p .49687 .17945 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.45269 .16743 m .47448 .17432 L .47662 .18031 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47662 .18031 m .45618 .17654 L .45269 .16743 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52251 .17766 m .51082 .18002 L .50604 .17394 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.48753 .17146 m .50604 .17394 L .51082 .18002 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47176 .16908 m .48753 .17146 L p .51082 .18002 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.51082 .18002 m .49687 .17945 L .47176 .16908 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.35796 .17994 m .37545 .17838 L p .42848 .17978 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.33952 .17601 m .37545 .17838 L .35796 .17994 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.35796 .17994 m .31769 .17797 L .33952 .17601 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45618 .17654 m .42848 .17978 L .39858 .17709 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.37545 .17838 m .39858 .17709 L .42848 .17978 L p F P
.392 .656 .4 r
s
.382 .305 .22 r
.38731 .4665 m .3663 .44868 L .33641 .41953 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.23651 .174 m .2652 .17962 L .22879 .17845 L p F P
.392 .656 .4 r
s
.852 .656 .387 r
.72494 .38428 m .7632 .33507 L .7334 .37651 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.47448 .17432 m .47176 .16908 L .49687 .17945 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.59893 .17475 m .57126 .17913 L .57944 .17447 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.63696 .17334 m .66154 .1704 L .64612 .17882 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.66797 .17731 m .64612 .17882 L .66154 .1704 L p F P
.392 .656 .4 r
s
.139 .092 .057 r
.51124 .51593 m .52301 .51604 L .52766 .51474 L p F P
.623 .462 .287 r
s
.629 .519 .325 r
.5576 .51127 m .55905 .50995 L p .53708 .51495 L F P
.623 .462 .287 r
s
.238 .591 .266 r
.22879 .17845 m .18423 .17144 L .23651 .174 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.36846 .17439 m .39858 .17709 L .37545 .17838 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.37545 .17838 m .33952 .17601 L .36846 .17439 L p F P
.392 .656 .4 r
s
.391 .316 .224 r
.42143 .4888 m .4299 .49379 L .44663 .50133 L p F P
.623 .462 .287 r
s
.324 .188 .117 r
.40851 .48155 m .4299 .49379 L .42143 .4888 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.30336 .17363 m .33952 .17601 L .31769 .17797 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.31769 .17797 m .27721 .17599 L .30336 .17363 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51895 .16925 m .5296 .16497 L .52251 .17766 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.50604 .17394 m .51895 .16925 L p .52251 .17766 L F P
.392 .656 .4 r
s
.319 .247 .186 r
.31138 .39074 m .26891 .3312 L .29909 .37335 L p F P
.623 .462 .287 r
s
.319 .247 .186 r
.29909 .37335 m .33641 .41953 L .31138 .39074 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.66154 .1704 m .68633 .16743 L .66797 .17731 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.71132 .16444 m .68121 .1764 L .66797 .17731 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.66797 .17731 m .68633 .16743 L .71132 .16444 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39858 .17709 m .42178 .1758 L p .45618 .17654 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.39752 .17276 m .42178 .1758 L .39858 .17709 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39858 .17709 m .36846 .17439 L .39752 .17276 L p F P
.392 .656 .4 r
s
.382 .305 .22 r
.33641 .41953 m .36169 .4446 L .38731 .4665 L p F P
.623 .462 .287 r
s
.431 .35 .247 r
.40851 .48155 m .38731 .4665 L .36169 .4446 L p F P
.623 .462 .287 r
s
.146 .096 .059 r
.48859 .51365 m .50259 .51549 L .49171 .51377 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.45269 .16743 m .45618 .17654 L .44126 .1738 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.42178 .1758 m .44126 .1738 L .45618 .17654 L p F P
.392 .656 .4 r
s
.089 .066 .041 r
.57759 .50494 m .5576 .51127 L .57659 .50545 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.57659 .50545 m .60599 .49278 L .57759 .50494 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.63696 .17334 m .61256 .17626 L .62694 .17033 L p F P
.392 .656 .4 r
s
.852 .656 .387 r
.7334 .37651 m .69932 .41417 L .72494 .38428 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.33811 .17166 m .36846 .17439 L .33952 .17601 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.33952 .17601 m .30336 .17363 L .33811 .17166 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.26696 .17122 m .30336 .17363 L .27721 .17599 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.27721 .17599 m .23651 .174 L .26696 .17122 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4219 .17023 m .44126 .1738 L .42178 .1758 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.42178 .1758 m .39752 .17276 L .4219 .17023 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58536 .16876 m .56214 .17519 L .5421 .17573 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.5421 .17573 m .55502 .16959 L .58536 .16876 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.55502 .16959 m .5421 .17573 L .53501 .17005 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.61158 .16766 m .57944 .17447 L .56214 .17519 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.56214 .17519 m .58536 .16876 L .61158 .16766 L p F P
.392 .656 .4 r
s
.508 .402 .278 r
.36169 .4446 m .33641 .41953 L .29909 .37335 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.57944 .17447 m .61158 .16766 L .59893 .17475 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.64156 .16429 m .62694 .17033 L .59893 .17475 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65157 .15919 m .64156 .16429 L p .59893 .17475 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.59893 .17475 m .61158 .16766 L .65157 .15919 L p F P
.392 .656 .4 r
s
.326 .252 .19 r
.26891 .3312 m .22647 .25804 L .26172 .31663 L p F P
.623 .462 .287 r
s
.326 .252 .19 r
.26172 .31663 m .29909 .37335 L .26891 .3312 L p F P
.623 .462 .287 r
s
.623 .516 .329 r
.51688 .51391 m .51124 .51593 L .50259 .51549 L p F P
.623 .462 .287 r
s
.741 .598 .379 r
.52301 .51604 m .51124 .51593 L .51688 .51391 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.37305 .16969 m .39752 .17276 L .36846 .17439 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.36846 .17439 m .33811 .17166 L .37305 .16969 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.44832 .15939 m .47176 .16908 L .47448 .17432 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47448 .17432 m .45269 .16743 L .44832 .15939 L p F P
.392 .656 .4 r
s
.431 .35 .247 r
.36169 .4446 m .38718 .4659 L .40851 .48155 L p F P
.623 .462 .287 r
s
.48 .396 .273 r
.4299 .49379 m .40851 .48155 L .38718 .4659 L p F P
.623 .462 .287 r
s
.872 .684 .417 r
.60599 .49278 m .57659 .50545 L .59335 .4984 L p F P
.623 .462 .287 r
s
.872 .684 .417 r
.59335 .4984 m .63104 .47764 L .60599 .49278 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.26696 .17122 m .23651 .174 L .18423 .17144 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52003 .15965 m .51895 .16925 L .50604 .17394 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.50604 .17394 m .50046 .16685 L .52003 .15965 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.50046 .16685 m .50604 .17394 L .48753 .17146 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.44126 .1738 m .43785 .16752 L p .45269 .16743 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.4174 .16229 m .43785 .16752 L .44126 .1738 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.44126 .1738 m .4219 .17023 L .4174 .16229 L p F P
.392 .656 .4 r
s
.242 .146 .09 r
.44663 .50133 m .4699 .50889 L .4621 .50731 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.30754 .16892 m .33811 .17166 L .30336 .17363 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.30336 .17363 m .26696 .17122 L .30754 .16892 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62694 .17033 m .65529 .16585 L .63696 .17334 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.66154 .1704 m .63696 .17334 L .65529 .16585 L p F P
.392 .656 .4 r
s
.897 .699 .425 r
.6419 .46886 m .66195 .45385 L p .63104 .47764 L F P
.623 .462 .287 r
s
.238 .591 .266 r
.40235 .16663 m .4219 .17023 L .39752 .17276 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39752 .17276 m .37305 .16969 L .40235 .16663 L p F P
.392 .656 .4 r
s
.741 .598 .379 r
.51688 .51391 m .53708 .51495 L .52301 .51604 L p F P
.623 .462 .287 r
s
.629 .519 .325 r
.53708 .51495 m .53994 .51408 L .5576 .51127 L p F P
.623 .462 .287 r
s
.291 .219 .171 r
.22647 .25804 m .18423 .17144 L .23389 .26633 L p F P
.623 .462 .287 r
s
.291 .219 .171 r
.23389 .26633 m .26172 .31663 L .22647 .25804 L p F P
.623 .462 .287 r
s
.508 .402 .278 r
.29909 .37335 m .32961 .41017 L .36169 .4446 L p F P
.623 .462 .287 r
s
.562 .443 .302 r
.38718 .4659 m .36169 .4446 L .32961 .41017 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.59335 .4984 m .57659 .50545 L p .56204 .50888 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.53994 .51408 m .57298 .50438 L .56204 .50888 L F
.57298 .50438 m .59335 .4984 L .56204 .50888 L F
.53994 .51408 m .55143 .51127 L .59335 .4984 L p F P
.623 .462 .287 r
s
.895 .702 .44 r
.57966 .50277 m .59335 .4984 L .55143 .51127 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.59335 .4984 m .57966 .50277 L p .59709 .49424 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.63104 .47764 m .60621 .49132 L p .59709 .49424 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.60621 .49132 m .59335 .4984 L p .59709 .49424 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.61087 .48863 m .63104 .47764 L p .5942 .49565 L F P
.623 .462 .287 r
s
.794 .633 .39 r
.58809 .49577 m .61087 .48863 L p .57799 .50037 L F P
.623 .462 .287 r
s
.794 .633 .39 r
.56429 .50526 m .57064 .50273 L p .57799 .50037 L F P
.623 .462 .287 r
s
.794 .633 .39 r
.57064 .50273 m .58809 .49577 L p .57799 .50037 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.57966 .50277 m .60686 .49045 L p .5942 .49565 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.60686 .49045 m .61087 .48863 L p .5942 .49565 L F P
.623 .462 .287 r
s
.897 .699 .425 r
.63104 .47764 m .61087 .48863 L .6419 .46886 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.57659 .50545 m .5576 .51127 L .53994 .51408 L p F P
.623 .462 .287 r
s
.566 .435 .297 r
.32961 .41017 m .29909 .37335 L .26172 .31663 L p F P
.623 .462 .287 r
s
.48 .396 .273 r
.38718 .4659 m .41286 .48335 L .4299 .49379 L p F P
.623 .462 .287 r
s
.488 .405 .276 r
.4299 .49379 m .41286 .48335 L p .42266 .48755 L F P
.623 .462 .287 r
s
.488 .405 .276 r
.42266 .48755 m .44663 .50133 L .4299 .49379 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.34838 .1666 m .37305 .16969 L .33811 .17166 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.33811 .17166 m .30754 .16892 L .34838 .1666 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.48753 .17146 m .47236 .16306 L .50046 .16685 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47236 .16306 m .48753 .17146 L .47176 .16908 L p F P
.392 .656 .4 r
s
.53 .402 .276 r
.26346 .30971 m .23389 .26633 L .216 .23215 L p F P
.623 .462 .287 r
s
.53 .402 .276 r
.216 .23215 m .18423 .17144 L p .23475 .25962 L F P
.623 .462 .287 r
s
.53 .402 .276 r
.26346 .30971 m .216 .23215 L .23475 .25962 L F
.18423 .17144 m .22798 .24938 L .26346 .30971 L p F P
.623 .462 .287 r
s
.611 .459 .308 r
.22798 .24938 m .27311 .31565 L .28143 .328 L p F P
.623 .462 .287 r
s
.611 .459 .308 r
.28143 .328 m .30348 .36073 L p .26069 .29762 L F P
.623 .462 .287 r
s
.611 .459 .308 r
.26069 .29762 m .22798 .24938 L .28143 .328 L F
.238 .591 .266 r
.18423 .17144 m .23032 .1688 L .26696 .17122 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.30754 .16892 m .26696 .17122 L .23032 .1688 L p F P
.392 .656 .4 r
s
.623 .516 .329 r
.50259 .51549 m .48859 .51365 L .51688 .51391 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.65529 .16585 m .68398 .16131 L .66154 .1704 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.68633 .16743 m .66154 .1704 L .68398 .16131 L p F P
.392 .656 .4 r
s
.562 .443 .302 r
.32961 .41017 m .36041 .44153 L .38718 .4659 L p F P
.623 .462 .287 r
s
.618 .486 .327 r
.41286 .48335 m .38718 .4659 L .36041 .44153 L p F P
.623 .462 .287 r
s
.614 .509 .328 r
.51688 .51391 m .48859 .51365 L .49035 .51275 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.65529 .16585 m .62694 .17033 L .64156 .16429 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39665 .15699 m .4174 .16229 L .4219 .17023 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4219 .17023 m .40235 .16663 L .39665 .15699 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.53501 .17005 m .54442 .16089 L .55502 .16959 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.54442 .16089 m .53501 .17005 L .5296 .16497 L p F P
.392 .656 .4 r
s
.673 .537 .355 r
.4699 .50889 m .44663 .50133 L .42266 .48755 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.38261 .163 m .40235 .16663 L .37305 .16969 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.37305 .16969 m .34838 .1666 L .38261 .163 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58536 .16876 m .55502 .16959 L .5645 .16508 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.5581 .15894 m .5645 .16508 L .55502 .16959 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.55405 .1515 m .5581 .15894 L p .55502 .16959 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.55502 .16959 m .54442 .16089 L .55405 .1515 L p F P
.392 .656 .4 r
s
.566 .435 .297 r
.26172 .31663 m .29743 .36793 L .32961 .41017 L p F P
.623 .462 .287 r
s
.609 .468 .316 r
.36041 .44153 m .32961 .41017 L .29743 .36793 L p F P
.623 .462 .287 r
s
.533 .41 .282 r
.29743 .36793 m .26172 .31663 L .23389 .26633 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.53627 .15306 m .5296 .16497 L .51895 .16925 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.51895 .16925 m .52003 .15965 L .53627 .15306 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47176 .16908 m .44832 .15939 L .47236 .16306 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.34838 .1666 m .30754 .16892 L .27674 .16615 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.23032 .1688 m .27674 .16615 L .30754 .16892 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.61158 .16766 m .58536 .16876 L .60899 .16222 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58547 .16424 m .60899 .16222 L .58536 .16876 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.5645 .16508 m .58547 .16424 L p .58536 .16876 L F P
.392 .656 .4 r
s
.999 .761 .46 r
.68528 .42138 m .72494 .38428 L .69932 .41417 L p F P
.623 .462 .287 r
s
.618 .486 .327 r
.36041 .44153 m .39144 .46736 L .41286 .48335 L p F P
.623 .462 .287 r
s
.488 .405 .276 r
.41286 .48335 m .39144 .46736 L .42266 .48755 L p F P
.623 .462 .287 r
s
.951 .738 .455 r
.62156 .48068 m .6419 .46886 L .61087 .48863 L p F P
.623 .462 .287 r
s
.853 .672 .425 r
.51688 .51391 m .55143 .51127 L .53994 .51408 L p F P
.623 .462 .287 r
s
.673 .537 .355 r
.42266 .48755 m .454 .50207 L .4699 .50889 L p F P
.623 .462 .287 r
s
.632 .518 .339 r
.4699 .50889 m .454 .50207 L p .48218 .50939 L F P
.623 .462 .287 r
s
.632 .518 .339 r
.48218 .50939 m .49035 .51275 L .4699 .50889 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.63264 .1602 m .65157 .15919 L .61158 .16766 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60899 .16222 m .63264 .1602 L p .61158 .16766 L F P
.392 .656 .4 r
s
.609 .468 .316 r
.29743 .36793 m .33352 .41172 L .36041 .44153 L p F P
.623 .462 .287 r
s
.656 .505 .337 r
.39144 .46736 m .36041 .44153 L .33352 .41172 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.43785 .16752 m .43048 .16041 L .45269 .16743 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.40785 .15325 m .43048 .16041 L .43785 .16752 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.43785 .16752 m .4174 .16229 L .40785 .15325 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.68398 .16131 m .71302 .15672 L .68633 .16743 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.74242 .15208 m .71132 .16444 L .68633 .16743 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.68633 .16743 m .71302 .15672 L .74242 .15208 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.44832 .15939 m .45269 .16743 L .43048 .16041 L p F P
.392 .656 .4 r
s
.533 .41 .282 r
.23389 .26633 m .27347 .33044 L .29743 .36793 L p F P
.623 .462 .287 r
s
.327 .253 .191 r
.27347 .33044 m .23389 .26633 L .26346 .30971 L p F P
.623 .462 .287 r
s
.58 .446 .303 r
.33352 .41172 m .29743 .36793 L .27347 .33044 L p F P
.623 .462 .287 r
s
.922 .711 .428 r
.69932 .41417 m .67353 .44024 L .64973 .45525 L p F P
.623 .462 .287 r
s
.999 .761 .46 r
.69932 .41417 m .67191 .43502 L .68528 .42138 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.52003 .15965 m .50046 .16685 L .49635 .16163 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47723 .15874 m .49635 .16163 L .50046 .16685 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45683 .15446 m .47723 .15874 L p .50046 .16685 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.50046 .16685 m .47236 .16306 L .45683 .15446 L p F P
.392 .656 .4 r
s
.794 .633 .39 r
.61087 .48863 m .57966 .50277 L .56429 .50526 L p F P
.623 .462 .287 r
s
.951 .738 .455 r
.60534 .48675 m .62156 .48068 L p .61087 .48863 L F P
.623 .462 .287 r
s
.951 .738 .455 r
.61087 .48863 m .58809 .49577 L .60534 .48675 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.37561 .15162 m .39665 .15699 L .40235 .16663 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.40235 .16663 m .38261 .163 L .37561 .15162 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.38261 .163 m .34838 .1666 L .3235 .16348 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.27674 .16615 m .3235 .16348 L .34838 .1666 L p F P
.392 .656 .4 r
s
.656 .505 .337 r
.33352 .41172 m .36992 .44787 L .39144 .46736 L p F P
.623 .462 .287 r
s
.475 .392 .271 r
.39144 .46736 m .36992 .44787 L p .40093 .47084 L F P
.623 .462 .287 r
s
.475 .392 .271 r
.40093 .47084 m .42266 .48755 L .39144 .46736 L p F P
.623 .462 .287 r
s
.614 .509 .328 r
.49035 .51275 m .48218 .50939 L .51688 .51391 L p F P
.623 .462 .287 r
s
.885 .69 .438 r
.54355 .51073 m .55143 .51127 L .51688 .51391 L p F P
.623 .462 .287 r
s
.895 .702 .44 r
.56429 .50526 m .57966 .50277 L p .55143 .51127 L F P
.623 .462 .287 r
s
.895 .702 .44 r
.55143 .51127 m .54355 .51073 L .56429 .50526 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.64156 .16429 m .674 .1582 L .65529 .16585 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.68398 .16131 m .65529 .16585 L .674 .1582 L p F P
.392 .656 .4 r
s
.919 .712 .431 r
.67353 .44024 m .6476 .46242 L .62754 .47249 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.60331 .15812 m .58547 .16424 L .5645 .16508 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.5645 .16508 m .57687 .1592 L .60331 .15812 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57687 .1592 m .5645 .16508 L .5581 .15894 L p F P
.392 .656 .4 r
s
.58 .446 .303 r
.27347 .33044 m .31352 .38526 L .33352 .41172 L p F P
.623 .462 .287 r
s
.632 .485 .325 r
.36992 .44787 m .33352 .41172 L .31352 .38526 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.5296 .16497 m .53627 .15306 L .54442 .16089 L p F P
.392 .656 .4 r
s
.753 .58 .38 r
.454 .50207 m .42668 .48942 L p .43913 .49332 L F P
.623 .462 .287 r
s
.753 .58 .38 r
.42266 .48755 m .40093 .47084 L p .43913 .49332 L F P
.623 .462 .287 r
s
.753 .58 .38 r
.42668 .48942 m .42266 .48755 L p .43913 .49332 L F P
.623 .462 .287 r
s
.753 .58 .38 r
.40093 .47084 m .43962 .49408 L .454 .50207 L p F P
.623 .462 .287 r
s
.797 .616 .4 r
.49356 .50937 m .48218 .50939 L .43962 .49408 L p F P
.623 .462 .287 r
s
.797 .616 .4 r
.43962 .49408 m .45628 .49934 L p .4711 .50333 L F P
.623 .462 .287 r
s
.797 .616 .4 r
.49356 .50937 m .46017 .49991 L .4711 .50333 L F
.46017 .49991 m .43962 .49408 L .4711 .50333 L F
.909 .708 .431 r
.6476 .46242 m .62156 .48068 L .60534 .48675 L p F P
.623 .462 .287 r
s
.351 .275 .204 r
.31352 .38526 m .27347 .33044 L .29928 .3625 L p F P
.623 .462 .287 r
s
.327 .253 .191 r
.26346 .30971 m .29928 .3625 L .27347 .33044 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.674 .1582 m .64156 .16429 L .65157 .15919 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.63304 .15556 m .60899 .16222 L .58547 .16424 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58547 .16424 m .60331 .15812 L .63304 .15556 L p F P
.392 .656 .4 r
s
.632 .518 .339 r
.454 .50207 m .43962 .49408 L .48218 .50939 L p F P
.623 .462 .287 r
s
.862 .672 .43 r
.53145 .50791 m .54566 .50695 L .51688 .51391 L p F P
.623 .462 .287 r
s
.862 .672 .43 r
.51688 .51391 m .52269 .50457 L .53145 .50791 L p F P
.623 .462 .287 r
s
.803 .634 .408 r
.51062 .50735 m .52269 .50457 L .51688 .51391 L p F P
.623 .462 .287 r
s
.803 .634 .408 r
.51688 .51391 m .49621 .50559 L .51062 .50735 L p F P
.623 .462 .287 r
s
.706 .571 .369 r
.49356 .50937 m .49621 .50559 L .51688 .51391 L p F P
.623 .462 .287 r
s
.706 .571 .369 r
.51688 .51391 m .48218 .50939 L .49356 .50937 L p F P
.623 .462 .287 r
s
.885 .69 .438 r
.51688 .51391 m .54566 .50695 L .54355 .51073 L p F P
.623 .462 .287 r
s
.632 .485 .325 r
.31352 .38526 m .35393 .43057 L .36992 .44787 L p F P
.623 .462 .287 r
s
.475 .392 .271 r
.36992 .44787 m .35393 .43057 L .40093 .47084 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.3235 .16348 m .37059 .16079 L .38261 .163 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4362 .15014 m .45683 .15446 L .47236 .16306 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.41891 .14724 m .4362 .15014 L p .47236 .16306 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.47236 .16306 m .44832 .15939 L .41891 .14724 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.37561 .15162 m .38261 .163 L .37059 .16079 L p F P
.392 .656 .4 r
s
.611 .459 .308 r
.30348 .36073 m .26346 .30971 L .22798 .24938 L p F P
.623 .462 .287 r
s
.377 .3 .218 r
.35393 .43057 m .31352 .38526 L .33537 .40756 L p F P
.623 .462 .287 r
s
.351 .275 .204 r
.29928 .3625 m .33537 .40756 L .31352 .38526 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.38479 .14596 m .40785 .15325 L .4174 .16229 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4174 .16229 m .39665 .15699 L .38479 .14596 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.66296 .15299 m .63264 .1602 L .60899 .16222 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60899 .16222 m .63304 .15556 L .66296 .15299 L p F P
.392 .656 .4 r
s
.946 .734 .456 r
.57301 .49741 m .56429 .50526 L .54355 .51073 L p F P
.623 .462 .287 r
s
.946 .734 .456 r
.58142 .48841 m .57301 .49741 L p .54355 .51073 L F P
.623 .462 .287 r
s
.946 .734 .456 r
.54355 .51073 m .54566 .50695 L .58142 .48841 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.49635 .16163 m .50917 .15645 L p .52003 .15965 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.50713 .1482 m .50917 .15645 L .49635 .16163 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.49635 .16163 m .49099 .15482 L .50713 .1482 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.49099 .15482 m .49635 .16163 L .47723 .15874 L p F P
.392 .656 .4 r
s
.72 .545 .358 r
.42577 .48331 m .40093 .47084 L .35393 .43057 L p F P
.623 .462 .287 r
s
.72 .545 .358 r
.35393 .43057 m .37164 .44478 L p .42577 .48331 L F P
.623 .462 .287 r
s
.377 .3 .218 r
.33537 .40756 m .37164 .44478 L .35393 .43057 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.674 .1582 m .70697 .152 L .68398 .16131 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.71302 .15672 m .68398 .16131 L .70697 .152 L p F P
.392 .656 .4 r
s
.525 .431 .293 r
.42577 .48331 m .45628 .49934 L .43962 .49408 L p F P
.623 .462 .287 r
s
.525 .431 .293 r
.43962 .49408 m .40093 .47084 L .42577 .48331 L p F P
.623 .462 .287 r
s
1 .764 .476 r
.58809 .49577 m .56429 .50526 L .57301 .49741 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.54992 .14391 m .55405 .1515 L .54442 .16089 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.54468 .13801 m .54992 .14391 L p .54442 .16089 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.54442 .16089 m .53627 .15306 L .54468 .13801 L p F P
.392 .656 .4 r
s
.434 .343 .244 r
.29928 .3625 m .26346 .30971 L .30348 .36073 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.37059 .16079 m .35427 .14616 L .37561 .15162 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.43048 .16041 m .42298 .15316 L p .44832 .15939 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.39808 .14399 m .42298 .15316 L .43048 .16041 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.43048 .16041 m .40785 .15325 L .39808 .14399 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.68691 .1517 m .65157 .15919 L .63264 .1602 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.63264 .1602 m .66296 .15299 L .68691 .1517 L p F P
.392 .656 .4 r
s
1 .764 .476 r
.57301 .49741 m .60147 .48028 L .58809 .49577 L p F P
.623 .462 .287 r
s
.987 .758 .463 r
.61545 .47501 m .60534 .48675 L .58809 .49577 L p F P
.623 .462 .287 r
s
.987 .758 .463 r
.63014 .45715 m .61545 .47501 L p .58809 .49577 L F P
.623 .462 .287 r
s
.987 .758 .463 r
.58809 .49577 m .60147 .48028 L .63014 .45715 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.53627 .15306 m .52003 .15965 L .52113 .14981 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.50917 .15645 m .52113 .14981 L .52003 .15965 L p F P
.392 .656 .4 r
s
.811 .633 .409 r
.49621 .50559 m .49356 .50937 L .47531 .50281 L p F P
.623 .462 .287 r
s
.797 .616 .4 r
.45628 .49934 m .47531 .50281 L .49356 .50937 L p F P
.623 .462 .287 r
s
.451 .36 .254 r
.33537 .40756 m .29928 .3625 L .33398 .40009 L p F P
.623 .462 .287 r
s
.434 .343 .244 r
.30348 .36073 m .33398 .40009 L .29928 .3625 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.42298 .15316 m .41891 .14724 L .44832 .15939 L p F P
.392 .656 .4 r
s
1 .781 .481 r
.62754 .47249 m .60534 .48675 L .61545 .47501 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.5581 .15894 m .56892 .15139 L .57687 .1592 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62145 .15191 m .60331 .15812 L .57687 .1592 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57687 .1592 m .58944 .15323 L .62145 .15191 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58944 .15323 m .57687 .1592 L .56892 .15139 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65157 .15919 m .68691 .1517 L .674 .1582 L p F P
.392 .656 .4 r
s
.707 .555 .366 r
.45424 .49199 m .47531 .50281 L .45628 .49934 L p F P
.623 .462 .287 r
s
.707 .555 .366 r
.45628 .49934 m .42577 .48331 L .45424 .49199 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.56892 .15139 m .5581 .15894 L .55405 .1515 L p F P
.392 .656 .4 r
s
.467 .377 .264 r
.37164 .44478 m .33537 .40756 L .36456 .43366 L p F P
.623 .462 .287 r
s
.451 .36 .254 r
.33398 .40009 m .36456 .43366 L .33537 .40756 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.47723 .15874 m .46682 .15113 L .49099 .15482 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.46682 .15113 m .47723 .15874 L .45683 .15446 L p F P
.392 .656 .4 r
s
1 .781 .481 r
.61545 .47501 m .64038 .45503 L .62754 .47249 L p F P
.623 .462 .287 r
s
1 .785 .482 r
.64973 .45525 m .62754 .47249 L .64038 .45503 L p F P
.623 .462 .287 r
s
.72 .545 .358 r
.37164 .44478 m .39518 .46141 L .42577 .48331 L p F P
.623 .462 .287 r
s
.467 .377 .264 r
.36456 .43366 m .39518 .46141 L .37164 .44478 L p F P
.623 .462 .287 r
s
1 .785 .482 r
.64038 .45503 m .66536 .43091 L .64973 .45525 L p F P
.623 .462 .287 r
s
1 .785 .48 r
.67191 .43502 m .64973 .45525 L .66536 .43091 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.70697 .152 m .674 .1582 L .68691 .1517 L p F P
.392 .656 .4 r
s
1 .77 .464 r
.71537 .37032 m .68528 .42138 L .67191 .43502 L p F P
.623 .462 .287 r
s
1 .785 .48 r
.66536 .43091 m .69036 .40267 L .67191 .43502 L p F P
.623 .462 .287 r
s
1 .77 .464 r
.67191 .43502 m .69036 .40267 L .71537 .37032 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.65752 .14879 m .63304 .15556 L .60331 .15812 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60331 .15812 m .62145 .15191 L .65752 .14879 L p F P
.392 .656 .4 r
s
.937 .72 .455 r
.5636 .49511 m .58142 .48841 L .54566 .50695 L p F P
.623 .462 .287 r
s
.937 .72 .455 r
.54292 .50017 m .5636 .49511 L p .54566 .50695 L F P
.623 .462 .287 r
s
.937 .72 .455 r
.54566 .50695 m .53145 .50791 L .54292 .50017 L p F P
.623 .462 .287 r
s
.758 .576 .377 r
.45424 .49199 m .42577 .48331 L .39518 .46141 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.36128 .13853 m .38479 .14596 L .39665 .15699 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39665 .15699 m .37561 .15162 L .36128 .13853 L p F P
.392 .656 .4 r
s
.965 .732 .461 r
.53561 .49211 m .54292 .50017 L .53145 .50791 L p F P
.623 .462 .287 r
s
.965 .732 .461 r
.53001 .48278 m .53561 .49211 L p .53145 .50791 L F P
.623 .462 .287 r
s
.965 .732 .461 r
.53145 .50791 m .52269 .50457 L .53001 .48278 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.70697 .152 m .74049 .1457 L .71302 .15672 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.77457 .1393 m .74242 .15208 L .71302 .15672 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.71302 .15672 m .74049 .1457 L .77457 .1393 L p F P
.392 .656 .4 r
s
.811 .633 .409 r
.47531 .50281 m .47311 .4946 L p .49621 .50559 L F P
.623 .462 .287 r
s
.846 .645 .416 r
.45069 .47585 m .47311 .4946 L .47531 .50281 L p F P
.623 .462 .287 r
s
.846 .645 .416 r
.47531 .50281 m .45424 .49199 L .45069 .47585 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.52227 .1397 m .52113 .14981 L .50917 .15645 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.50917 .15645 m .50713 .1482 L .52227 .1397 L p F P
.392 .656 .4 r
s
.758 .576 .377 r
.39518 .46141 m .41891 .47473 L p .45424 .49199 L F P
.623 .462 .287 r
s
.598 .469 .317 r
.39412 .45466 m .41891 .47473 L .39518 .46141 L p F P
.623 .462 .287 r
s
.598 .469 .317 r
.39518 .46141 m .36456 .43366 L .39412 .45466 L p F P
.623 .462 .287 r
s
.893 .686 .438 r
.52269 .50457 m .51062 .50735 L .50568 .49913 L p F P
.623 .462 .287 r
s
.895 .678 .433 r
.48658 .49293 m .50568 .49913 L .51062 .50735 L p F P
.623 .462 .287 r
s
.895 .678 .433 r
.47032 .48521 m .48658 .49293 L p .51062 .50735 L F P
.623 .462 .287 r
s
.895 .678 .433 r
.51062 .50735 m .49621 .50559 L .47032 .48521 L p F P
.623 .462 .287 r
s
.996 .75 .468 r
.60147 .48028 m .57301 .49741 L .58142 .48841 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.69388 .14564 m .66296 .15299 L .63304 .15556 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.63304 .15556 m .65752 .14879 L .69388 .14564 L p F P
.392 .656 .4 r
s
.811 .633 .409 r
.47311 .4946 m .47032 .48521 L .49621 .50559 L p F P
.623 .462 .287 r
s
.58 .451 .307 r
.36926 .43044 m .39412 .45466 L .36456 .43366 L p F P
.623 .462 .287 r
s
.58 .451 .307 r
.36456 .43366 m .33398 .40009 L .36926 .43044 L p F P
.623 .462 .287 r
s
.654 .491 .327 r
.27311 .31565 m .31947 .36962 L .34436 .40209 L p F P
.623 .462 .287 r
s
.654 .491 .327 r
.34436 .40209 m .30348 .36073 L .27311 .31565 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.50505 .13977 m .50713 .1482 L .49099 .15482 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.49099 .15482 m .48552 .14787 L .50505 .13977 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.48552 .14787 m .49099 .15482 L .46682 .15113 L p F P
.392 .656 .4 r
s
.561 .434 .296 r
.34436 .40209 m .36926 .43044 L .33398 .40009 L p F P
.623 .462 .287 r
s
.561 .434 .296 r
.33398 .40009 m .30348 .36073 L .34436 .40209 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.45683 .15446 m .44094 .14567 L .46682 .15113 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.44094 .14567 m .45683 .15446 L .4362 .15014 L p F P
.392 .656 .4 r
s
1 .774 .478 r
.64038 .45503 m .61545 .47501 L .63014 .45715 L p F P
.623 .462 .287 r
s
.758 .576 .377 r
.41891 .47473 m .4389 .48195 L .45424 .49199 L p F P
.623 .462 .287 r
s
.689 .533 .354 r
.41905 .46626 m .4389 .48195 L .41891 .47473 L p F P
.623 .462 .287 r
s
.689 .533 .354 r
.41891 .47473 m .39412 .45466 L .41905 .46626 L p F P
.623 .462 .287 r
s
.893 .686 .438 r
.51902 .49164 m .53001 .48278 L .52269 .50457 L p F P
.623 .462 .287 r
s
.893 .686 .438 r
.50568 .49913 m .51902 .49164 L p .52269 .50457 L F P
.623 .462 .287 r
s
.238 .591 .266 r
.37258 .13461 m .39808 .14399 L .40785 .15325 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.40785 .15325 m .38479 .14596 L .37258 .13461 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.56892 .15139 m .57996 .14368 L .58944 .15323 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.6399 .1456 m .62145 .15191 L .58944 .15323 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58944 .15323 m .60221 .14716 L .6399 .1456 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60221 .14716 m .58944 .15323 L .57996 .14368 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39268 .13641 m .41891 .14724 L .42298 .15316 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.42298 .15316 m .39808 .14399 L .39268 .13641 L p F P
.392 .656 .4 r
s
.792 .607 .395 r
.45069 .47585 m .45424 .49199 L .4389 .48195 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.53331 .14305 m .54468 .13801 L .53627 .15306 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52113 .14981 m .53331 .14305 L p .53627 .15306 L F P
.392 .656 .4 r
s
.238 .591 .266 r
.72297 .14406 m .68691 .1517 L .66296 .15299 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.66296 .15299 m .69388 .14564 L .72297 .14406 L p F P
.392 .656 .4 r
s
1 .774 .478 r
.63014 .45715 m .65896 .42798 L .64038 .45503 L p F P
.623 .462 .287 r
s
1 .776 .477 r
.66536 .43091 m .64038 .45503 L .65896 .42798 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.68691 .1517 m .72297 .14406 L .70697 .152 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.74049 .1457 m .70697 .152 L .72297 .14406 L p F P
.392 .656 .4 r
s
.996 .75 .468 r
.58142 .48841 m .6144 .46179 L .60147 .48028 L p F P
.623 .462 .287 r
s
1 .77 .467 r
.64498 .43556 m .63014 .45715 L .60147 .48028 L p F P
.623 .462 .287 r
s
1 .77 .467 r
.65508 .41657 m .64498 .43556 L p .60147 .48028 L F P
.623 .462 .287 r
s
1 .77 .467 r
.60147 .48028 m .6144 .46179 L .65508 .41657 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.68244 .14189 m .65752 .14879 L .62145 .15191 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.62145 .15191 m .6399 .1456 L .68244 .14189 L p F P
.392 .656 .4 r
s
.669 .515 .343 r
.39909 .44744 m .41905 .46626 L .39412 .45466 L p F P
.623 .462 .287 r
s
.669 .515 .343 r
.39412 .45466 m .36926 .43044 L .39909 .44744 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.36128 .13853 m .37561 .15162 L .35427 .14616 L p F P
.392 .656 .4 r
s
.986 .752 .471 r
.58749 .47666 m .5636 .49511 L .54292 .50017 L p F P
.623 .462 .287 r
s
.986 .752 .471 r
.54292 .50017 m .55625 .48789 L .58749 .47666 L p F P
.623 .462 .287 r
s
.94 .708 .447 r
.55625 .48789 m .54292 .50017 L .53561 .49211 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.55405 .1515 m .56393 .14187 L .56892 .15139 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.56393 .14187 m .55405 .1515 L .54992 .14391 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57996 .14368 m .56892 .15139 L .56393 .14187 L p F P
.392 .656 .4 r
s
1 .767 .474 r
.6144 .46179 m .58142 .48841 L .5636 .49511 L p F P
.623 .462 .287 r
s
1 .767 .474 r
.5636 .49511 m .58749 .47666 L .6144 .46179 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.46682 .15113 m .45619 .14336 L .48552 .14787 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45619 .14336 m .46682 .15113 L .44094 .14567 L p F P
.392 .656 .4 r
s
1 .776 .477 r
.65896 .42798 m .68789 .39276 L .66536 .43091 L p F P
.623 .462 .287 r
s
1 .775 .475 r
.69036 .40267 m .66536 .43091 L .68789 .39276 L p F P
.623 .462 .287 r
s
.792 .607 .395 r
.4389 .48195 m .43543 .46966 L p .45069 .47585 L F P
.623 .462 .287 r
s
.793 .602 .391 r
.41452 .448 m .43543 .46966 L .4389 .48195 L p F P
.623 .462 .287 r
s
.793 .602 .391 r
.4389 .48195 m .41905 .46626 L .41452 .448 L p F P
.623 .462 .287 r
s
.873 .657 .42 r
.44625 .45664 m .47032 .48521 L .47311 .4946 L p F P
.623 .462 .287 r
s
.873 .657 .42 r
.47311 .4946 m .45069 .47585 L .44625 .45664 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.4362 .15014 m .4147 .14013 L .44094 .14567 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.4147 .14013 m .4362 .15014 L .41891 .14724 L p F P
.392 .656 .4 r
s
.65 .498 .333 r
.37904 .42549 m .39909 .44744 L .36926 .43044 L p F P
.623 .462 .287 r
s
.65 .498 .333 r
.36926 .43044 m .34436 .40209 L .37904 .42549 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.53774 .13101 m .53331 .14305 L .52113 .14981 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52113 .14981 m .52227 .1397 L .53774 .13101 L p F P
.392 .656 .4 r
s
1 .775 .475 r
.68789 .39276 m .71689 .3515 L .69036 .40267 L p F P
.623 .462 .287 r
s
1 .761 .456 r
.7459 .30422 m .71537 .37032 L .69036 .40267 L p F P
.623 .462 .287 r
s
1 .761 .456 r
.69036 .40267 m .71689 .3515 L .7459 .30422 L p F P
.623 .462 .287 r
s
.926 .7 .444 r
.52013 .47116 m .51902 .49164 L .50568 .49913 L p F P
.623 .462 .287 r
s
.926 .7 .444 r
.50568 .49913 m .49993 .48628 L .52013 .47116 L p F P
.623 .462 .287 r
s
.857 .649 .417 r
.49993 .48628 m .50568 .49913 L .48658 .49293 L p F P
.623 .462 .287 r
s
.681 .514 .34 r
.37904 .42549 m .34436 .40209 L .31947 .36962 L p F P
.623 .462 .287 r
s
1 .757 .468 r
.65896 .42798 m .63014 .45715 L .64498 .43556 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.7254 .13814 m .69388 .14564 L .65752 .14879 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65752 .14879 m .68244 .14189 L .7254 .13814 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52343 .12932 m .52227 .1397 L .50713 .1482 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.50713 .1482 m .50505 .13977 L .52343 .12932 L p F P
.392 .656 .4 r
s
.774 .585 .381 r
.39343 .42199 m .41452 .448 L .41905 .46626 L p F P
.623 .462 .287 r
s
.774 .585 .381 r
.41905 .46626 m .39909 .44744 L .39343 .42199 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.50292 .13116 m .50505 .13977 L .48552 .14787 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.48552 .14787 m .47996 .1408 L .50292 .13116 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47996 .1408 m .48552 .14787 L .45619 .14336 L p F P
.392 .656 .4 r
s
.681 .514 .34 r
.31947 .36962 m .36689 .41071 L .37904 .42549 L p F P
.623 .462 .287 r
s
.857 .649 .417 r
.48658 .49293 m .47096 .47322 L .49993 .48628 L p F P
.623 .462 .287 r
s
.807 .612 .397 r
.47096 .47322 m .48658 .49293 L .47032 .48521 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.41891 .14724 m .39268 .13641 L .4147 .14013 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57996 .14368 m .59123 .13581 L .60221 .14716 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.6399 .1456 m .60221 .14716 L .61002 .14344 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60273 .12778 m .61002 .14344 L .60221 .14716 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.60221 .14716 m .59123 .13581 L .60273 .12778 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.35427 .14616 m .33731 .13095 L .36128 .13853 L p F P
.392 .656 .4 r
s
1 .757 .468 r
.64498 .43556 m .67777 .39506 L .65896 .42798 L p F P
.623 .462 .287 r
s
1 .758 .467 r
.68789 .39276 m .65896 .42798 L .67777 .39506 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.34644 .12499 m .37258 .13461 L .38479 .14596 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.38479 .14596 m .36128 .13853 L .34644 .12499 L p F P
.392 .656 .4 r
s
.94 .708 .447 r
.53561 .49211 m .54528 .47191 L .55625 .48789 L p F P
.623 .462 .287 r
s
.904 .677 .43 r
.54528 .47191 m .53561 .49211 L .53001 .48278 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.72297 .14406 m .75976 .13627 L .74049 .1457 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.80782 .12609 m .77457 .1393 L .74049 .1457 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.74049 .1457 m .75976 .13627 L .80782 .12609 L p F P
.392 .656 .4 r
s
.976 .737 .463 r
.58749 .47666 m .55625 .48789 L .566 .47671 L p F P
.623 .462 .287 r
s
.974 .728 .456 r
.55938 .46441 m .566 .47671 L .55625 .48789 L p F P
.623 .462 .287 r
s
.974 .728 .456 r
.55516 .44526 m .55938 .46441 L p .55625 .48789 L F P
.623 .462 .287 r
s
.974 .728 .456 r
.55625 .48789 m .54528 .47191 L .55516 .44526 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.44094 .14567 m .42469 .13667 L .45619 .14336 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.42469 .13667 m .44094 .14567 L .4147 .14013 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.75976 .13627 m .72297 .14406 L .69388 .14564 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.69388 .14564 m .7254 .13814 L .75976 .13627 L p F P
.392 .656 .4 r
s
.993 .745 .465 r
.6144 .46179 m .58749 .47666 L .61169 .45203 L p F P
.623 .462 .287 r
s
.976 .737 .463 r
.58757 .46765 m .61169 .45203 L .58749 .47666 L p F P
.623 .462 .287 r
s
.976 .737 .463 r
.566 .47671 m .58757 .46765 L p .58749 .47666 L F P
.623 .462 .287 r
s
.238 .591 .266 r
.68244 .14189 m .6399 .1456 L .65865 .13918 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.61002 .14344 m .65865 .13918 L .6399 .1456 L p F P
.392 .656 .4 r
s
.993 .745 .465 r
.63583 .43288 m .65508 .41657 L .6144 .46179 L p F P
.623 .462 .287 r
s
.993 .745 .465 r
.61169 .45203 m .63583 .43288 L p .6144 .46179 L F P
.623 .462 .287 r
s
.757 .57 .372 r
.37218 .39159 m .39343 .42199 L .39909 .44744 L p F P
.623 .462 .287 r
s
.757 .57 .372 r
.39909 .44744 m .37904 .42549 L .37218 .39159 L p F P
.623 .462 .287 r
s
.807 .612 .397 r
.47032 .48521 m .44625 .45664 L .47096 .47322 L p F P
.623 .462 .287 r
s
.96 .721 .454 r
.53686 .45269 m .53001 .48278 L .51902 .49164 L p F P
.623 .462 .287 r
s
.96 .721 .454 r
.51902 .49164 m .52013 .47116 L .53686 .45269 L p F P
.623 .462 .287 r
s
.792 .607 .395 r
.43543 .46966 m .42794 .45089 L .45069 .47585 L p F P
.623 .462 .287 r
s
.824 .617 .397 r
.40491 .41959 m .42794 .45089 L .43543 .46966 L p F P
.623 .462 .287 r
s
.824 .617 .397 r
.43543 .46966 m .41452 .448 L .40491 .41959 L p F P
.623 .462 .287 r
s
.792 .6 .39 r
.44625 .45664 m .45069 .47585 L .42794 .45089 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.36569 .12526 m .39268 .13641 L .39808 .14399 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39808 .14399 m .37258 .13461 L .36569 .12526 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.54992 .14391 m .55882 .13212 L .56393 .14187 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.55882 .13212 m .54992 .14391 L .54468 .13801 L p F P
.392 .656 .4 r
s
.995 .738 .458 r
.67777 .39506 m .64498 .43556 L .65508 .41657 L p F P
.623 .462 .287 r
s
1 .758 .467 r
.67777 .39506 m .71071 .34609 L .68789 .39276 L p F P
.623 .462 .287 r
s
1 .757 .465 r
.71689 .3515 m .68789 .39276 L .71071 .34609 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.56393 .14187 m .57407 .132 L .57996 .14368 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.59123 .13581 m .57996 .14368 L .57407 .132 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.45619 .14336 m .44535 .13544 L .47996 .1408 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.44535 .13544 m .45619 .14336 L .42469 .13667 L p F P
.392 .656 .4 r
s
.72 .544 .358 r
.37218 .39159 m .37904 .42549 L .36689 .41071 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.55224 .1245 m .54468 .13801 L .53331 .14305 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.53331 .14305 m .53774 .13101 L .55224 .1245 L p F P
.392 .656 .4 r
s
.894 .673 .429 r
.52013 .47116 m .49993 .48628 L .4957 .47464 L p F P
.623 .462 .287 r
s
.875 .653 .416 r
.47601 .46429 m .4957 .47464 L .49993 .48628 L p F P
.623 .462 .287 r
s
.875 .653 .416 r
.45505 .44713 m .47601 .46429 L p .49993 .48628 L F P
.623 .462 .287 r
s
.875 .653 .416 r
.49993 .48628 m .47096 .47322 L .45505 .44713 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.7254 .13814 m .68244 .14189 L .70782 .13486 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.65865 .13918 m .70782 .13486 L .68244 .14189 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57407 .132 m .56393 .14187 L .55882 .13212 L p F P
.392 .656 .4 r
s
1 .757 .465 r
.71071 .34609 m .74373 .28867 L .71689 .3515 L p F P
.623 .462 .287 r
s
1 .762 .456 r
.77676 .22285 m .7459 .30422 L .71689 .3515 L p F P
.623 .462 .287 r
s
1 .762 .456 r
.71689 .3515 m .74373 .28867 L .77676 .22285 L p F P
.623 .462 .287 r
s
.72 .544 .358 r
.36689 .41071 m .3508 .3568 L .37218 .39159 L p F P
.623 .462 .287 r
s
.991 .744 .465 r
.60583 .44534 m .58757 .46765 L .566 .47671 L p F P
.623 .462 .287 r
s
.991 .744 .465 r
.566 .47671 m .5787 .45943 L .60583 .44534 L p F P
.623 .462 .287 r
s
.942 .703 .443 r
.5787 .45943 m .566 .47671 L .55938 .46441 L p F P
.623 .462 .287 r
s
1 .773 .478 r
.63616 .42113 m .61169 .45203 L .58757 .46765 L p F P
.623 .462 .287 r
s
1 .773 .478 r
.58757 .46765 m .60583 .44534 L .63616 .42113 L p F P
.623 .462 .287 r
s
.904 .677 .43 r
.53001 .48278 m .53686 .45269 L .54528 .47191 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.50292 .13116 m .47996 .1408 L .47655 .13647 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.43427 .12735 m .47655 .13647 L .47996 .1408 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47996 .1408 m .44535 .13544 L .43427 .12735 L p F P
.392 .656 .4 r
s
.806 .601 .388 r
.38163 .3819 m .40491 .41959 L .41452 .448 L p F P
.623 .462 .287 r
s
.806 .601 .388 r
.41452 .448 m .39343 .42199 L .38163 .3819 L p F P
.623 .462 .287 r
s
1 .785 .481 r
.66649 .3914 m .63583 .43288 L .61169 .45203 L p F P
.623 .462 .287 r
s
1 .785 .481 r
.61169 .45203 m .63616 .42113 L .66649 .3914 L p F P
.623 .462 .287 r
s
.995 .738 .458 r
.65508 .41657 m .69061 .36601 L .67777 .39506 L p F P
.623 .462 .287 r
s
.997 .737 .456 r
.71071 .34609 m .67777 .39506 L .69061 .36601 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.4147 .14013 m .39263 .12985 L .42469 .13667 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39263 .12985 m .4147 .14013 L .39268 .13641 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52462 .11866 m .52343 .12932 L .50505 .13977 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.50505 .13977 m .50292 .13116 L .52462 .11866 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.54231 .11858 m .53774 .13101 L .52227 .1397 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52227 .1397 m .52343 .12932 L .54231 .11858 L p F P
.392 .656 .4 r
s
1 .784 .48 r
.69061 .36601 m .65508 .41657 L .63583 .43288 L p F P
.623 .462 .287 r
s
.854 .633 .404 r
.43394 .42629 m .45505 .44713 L .47096 .47322 L p F P
.623 .462 .287 r
s
.854 .633 .404 r
.41631 .4085 m .43394 .42629 L p .47096 .47322 L F P
.623 .462 .287 r
s
.854 .633 .404 r
.47096 .47322 m .44625 .45664 L .41631 .4085 L p F P
.623 .462 .287 r
s
1 .784 .48 r
.63583 .43288 m .66649 .3914 L .69061 .36601 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.34644 .12499 m .36128 .13853 L .33731 .13095 L p F P
.392 .656 .4 r
s
.792 .6 .39 r
.42794 .45089 m .42036 .42827 L p .44625 .45664 L F P
.623 .462 .287 r
s
.83 .617 .396 r
.39518 .38509 m .42036 .42827 L .42794 .45089 L p F P
.623 .462 .287 r
s
.83 .617 .396 r
.42794 .45089 m .40491 .41959 L .39518 .38509 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.75976 .13627 m .7254 .13814 L .75754 .1305 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.70782 .13486 m .75754 .1305 L .7254 .13814 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.54468 .13801 m .55224 .1245 L .55882 .13212 L p F P
.392 .656 .4 r
s
.894 .673 .429 r
.4957 .47464 m .50893 .46288 L p .52013 .47116 L F P
.623 .462 .287 r
s
.896 .67 .426 r
.50684 .43902 m .50893 .46288 L .4957 .47464 L p F P
.623 .462 .287 r
s
.896 .67 .426 r
.4957 .47464 m .49019 .45671 L .50684 .43902 L p F P
.623 .462 .287 r
s
.846 .633 .406 r
.49019 .45671 m .4957 .47464 L .47601 .46429 L p F P
.623 .462 .287 r
s
.961 .713 .446 r
.55086 .42221 m .55516 .44526 L .54528 .47191 L p F P
.623 .462 .287 r
s
.961 .713 .446 r
.54543 .40226 m .55086 .42221 L p .54528 .47191 L F P
.623 .462 .287 r
s
.961 .713 .446 r
.54528 .47191 m .53686 .45269 L .54543 .40226 L p F P
.623 .462 .287 r
s
.997 .737 .456 r
.69061 .36601 m .72633 .30481 L .71071 .34609 L p F P
.623 .462 .287 r
s
.997 .735 .453 r
.74373 .28867 m .71071 .34609 L .72633 .30481 L p F P
.623 .462 .287 r
s
.792 .6 .39 r
.42036 .42827 m .41631 .4085 L .44625 .45664 L p F P
.623 .462 .287 r
s
.79 .588 .38 r
.35813 .33773 m .38163 .3819 L .39343 .42199 L p F P
.623 .462 .287 r
s
.79 .588 .38 r
.39343 .42199 m .37218 .39159 L .35813 .33773 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.42469 .13667 m .40804 .12745 L .44535 .13544 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.40804 .12745 m .42469 .13667 L .39263 .12985 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.47655 .13647 m .50075 .12235 L .50292 .13116 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.39268 .13641 m .36569 .12526 L .39263 .12985 L p F P
.392 .656 .4 r
s
.942 .703 .443 r
.55938 .46441 m .57045 .44105 L .5787 .45943 L p F P
.623 .462 .287 r
s
.989 .739 .461 r
.62428 .4186 m .60583 .44534 L .5787 .45943 L p F P
.623 .462 .287 r
s
.989 .739 .461 r
.5787 .45943 m .59154 .43885 L .62428 .4186 L p F P
.623 .462 .287 r
s
.938 .697 .438 r
.59154 .43885 m .5787 .45943 L .57045 .44105 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.75754 .1305 m .80782 .12609 L .75976 .13627 L p F P
.392 .656 .4 r
s
1 .769 .475 r
.66087 .3839 m .63616 .42113 L .60583 .44534 L p F P
.623 .462 .287 r
s
1 .769 .475 r
.60583 .44534 m .62428 .4186 L .66087 .3839 L p F P
.623 .462 .287 r
s
.895 .669 .425 r
.53686 .45269 m .52013 .47116 L .52126 .44419 L p F P
.623 .462 .287 r
s
.894 .673 .429 r
.50893 .46288 m .52126 .44419 L .52013 .47116 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.57407 .132 m .58447 .12187 L .59123 .13581 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.59514 .11147 m .60273 .12778 L .59123 .13581 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.59123 .13581 m .58447 .12187 L .59514 .11147 L p F P
.392 .656 .4 r
s
.918 .682 .43 r
.57045 .44105 m .55938 .46441 L .55516 .44526 L p F P
.623 .462 .287 r
s
.846 .633 .406 r
.47601 .46429 m .46535 .44089 L .49019 .45671 L p F P
.623 .462 .287 r
s
.817 .61 .393 r
.46535 .44089 m .47601 .46429 L .45505 .44713 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.39099 .11801 m .43427 .12735 L .44535 .13544 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.44535 .13544 m .40804 .12745 L .39099 .11801 L p F P
.392 .656 .4 r
s
1 .781 .478 r
.69739 .34126 m .66649 .3914 L .63616 .42113 L p F P
.623 .462 .287 r
s
1 .781 .478 r
.63616 .42113 m .66087 .3839 L .69739 .34126 L p F P
.623 .462 .287 r
s
1 .778 .475 r
.72633 .30481 m .69061 .36601 L .66649 .3914 L p F P
.623 .462 .287 r
s
1 .778 .475 r
.66649 .3914 m .69739 .34126 L .72633 .30481 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.33792 .11379 m .36569 .12526 L .37258 .13461 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.37258 .13461 m .34644 .12499 L .33792 .11379 L p F P
.392 .656 .4 r
s
.997 .735 .453 r
.72633 .30481 m .76214 .233 L .74373 .28867 L p F P
.623 .462 .287 r
s
1 .764 .461 r
.80782 .12609 m .77676 .22285 L .74373 .28867 L p F P
.623 .462 .287 r
s
1 .764 .461 r
.74373 .28867 m .76214 .233 L .80782 .12609 L p F P
.623 .462 .287 r
s
.737 .551 .36 r
.35813 .33773 m .37218 .39159 L .3508 .3568 L p F P
.623 .462 .287 r
s
.922 .686 .433 r
.52241 .41056 m .52126 .44419 L .50893 .46288 L p F P
.623 .462 .287 r
s
.922 .686 .433 r
.50893 .46288 m .50684 .43902 L .52241 .41056 L p F P
.623 .462 .287 r
s
.813 .602 .387 r
.36967 .33288 m .39518 .38509 L .40491 .41959 L p F P
.623 .462 .287 r
s
.813 .602 .387 r
.40491 .41959 m .38163 .3819 L .36967 .33288 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.55882 .13212 m .56799 .11996 L .57407 .132 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.56799 .11996 m .55882 .13212 L .55224 .1245 L p F P
.392 .656 .4 r
s
.817 .61 .393 r
.45505 .44713 m .43887 .41454 L .46535 .44089 L p F P
.623 .462 .287 r
s
.785 .586 .38 r
.43887 .41454 m .45505 .44713 L .43394 .42629 L p F P
.623 .462 .287 r
s
.821 .609 .391 r
.38992 .35479 m .41631 .4085 L .42036 .42827 L p F P
.623 .462 .287 r
s
.821 .609 .391 r
.42036 .42827 m .39518 .38509 L .38992 .35479 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.58447 .12187 m .57407 .132 L .56799 .11996 L p F P
.392 .656 .4 r
s
.885 .658 .419 r
.50473 .41051 m .50684 .43902 L .49019 .45671 L p F P
.623 .462 .287 r
s
.885 .658 .419 r
.49019 .45671 m .48461 .43541 L .50473 .41051 L p F P
.623 .462 .287 r
s
.836 .623 .399 r
.48461 .43541 m .49019 .45671 L .46535 .44089 L p F P
.623 .462 .287 r
s
1 .771 .47 r
.76214 .233 m .72633 .30481 L .69739 .34126 L p F P
.623 .462 .287 r
s
1 .763 .471 r
.68577 .34027 m .66087 .3839 L .62428 .4186 L p F P
.623 .462 .287 r
s
1 .763 .471 r
.62428 .4186 m .64291 .38738 L .68577 .34027 L p F P
.623 .462 .287 r
s
.984 .733 .457 r
.64291 .38738 m .62428 .4186 L .59154 .43885 L p F P
.623 .462 .287 r
s
.938 .697 .438 r
.57045 .44105 m .58169 .41311 L .59154 .43885 L p F P
.623 .462 .287 r
s
.984 .733 .457 r
.59154 .43885 m .60453 .41492 L .64291 .38738 L p F P
.623 .462 .287 r
s
.934 .691 .434 r
.60453 .41492 m .59154 .43885 L .58169 .41311 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.52462 .11866 m .50292 .13116 L .50075 .12235 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.56006 .11051 m .55224 .1245 L .53774 .13101 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.53774 .13101 m .54231 .11858 L .56006 .11051 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.33731 .13095 m .31965 .11513 L .34644 .12499 L p F P
.392 .656 .4 r
s
1 .775 .474 r
.72845 .28243 m .69739 .34126 L .66087 .3839 L p F P
.623 .462 .287 r
s
1 .775 .474 r
.66087 .3839 m .68577 .34027 L .72845 .28243 L p F P
.623 .462 .287 r
s
1 .771 .47 r
.69739 .34126 m .72845 .28243 L .76214 .233 L p F P
.623 .462 .287 r
s
.895 .669 .425 r
.53378 .42165 m .54543 .40226 L .53686 .45269 L p F P
.623 .462 .287 r
s
.895 .669 .425 r
.52126 .44419 m .53378 .42165 L p .53686 .45269 L F P
.623 .462 .287 r
s
.238 .591 .266 r
.39263 .12985 m .36996 .11929 L .40804 .12745 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.36996 .11929 m .39263 .12985 L .36569 .12526 L p F P
.392 .656 .4 r
s
.737 .551 .36 r
.3508 .3568 m .33446 .28706 L .35813 .33773 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.54703 .10575 m .54231 .11858 L .52343 .12932 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.52343 .12932 m .52462 .11866 L .54703 .10575 L p F P
.392 .656 .4 r
s
.918 .682 .43 r
.55516 .44526 m .56522 .41201 L .57045 .44105 L p F P
.623 .462 .287 r
s
.914 .676 .426 r
.58169 .41311 m .57045 .44105 L .56522 .41201 L p F P
.623 .462 .287 r
s
.895 .662 .419 r
.56522 .41201 m .55516 .44526 L .55086 .42221 L p F P
.623 .462 .287 r
s
.785 .586 .38 r
.43394 .42629 m .41219 .38237 L .43887 .41454 L p F P
.623 .462 .287 r
s
.755 .564 .368 r
.41219 .38237 m .43394 .42629 L .41631 .4085 L p F P
.623 .462 .287 r
s
.836 .623 .399 r
.46535 .44089 m .45453 .4129 L .48461 .43541 L p F P
.623 .462 .287 r
s
.807 .6 .387 r
.45453 .4129 m .46535 .44089 L .43887 .41454 L p F P
.623 .462 .287 r
s
.989 .728 .45 r
.7596 .21493 m .80782 .12609 L .76214 .233 L p F P
.623 .462 .287 r
s
.989 .728 .45 r
.76214 .233 m .72845 .28243 L .7596 .21493 L p F P
.623 .462 .287 r
s
.798 .59 .38 r
.3439 .27157 m .36967 .33288 L .38163 .3819 L p F P
.623 .462 .287 r
s
.798 .59 .38 r
.38163 .3819 m .35813 .33773 L .3439 .27157 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.34667 .10845 m .39099 .11801 L .40804 .12745 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.40804 .12745 m .36996 .11929 L .34667 .10845 L p F P
.392 .656 .4 r
s
.934 .692 .435 r
.53826 .37596 m .53378 .42165 L .52126 .44419 L p F P
.623 .462 .287 r
s
.934 .692 .435 r
.52126 .44419 m .52241 .41056 L .53826 .37596 L p F P
.623 .462 .287 r
s
.755 .564 .368 r
.41631 .4085 m .38992 .35479 L .41219 .38237 L p F P
.623 .462 .287 r
s
.982 .727 .452 r
.68577 .34027 m .64291 .38738 L .6617 .35163 L p F P
.623 .462 .287 r
s
.964 .715 .447 r
.61243 .39884 m .6617 .35163 L .64291 .38738 L p F P
.623 .462 .287 r
s
.964 .715 .447 r
.64291 .38738 m .60453 .41492 L .61243 .39884 L p F P
.623 .462 .287 r
s
.992 .732 .453 r
.71083 .29024 m .7596 .21493 L .72845 .28243 L p F P
.623 .462 .287 r
s
.992 .732 .453 r
.72845 .28243 m .68577 .34027 L .71083 .29024 L p F P
.623 .462 .287 r
s
.934 .691 .434 r
.58169 .41311 m .59308 .38051 L .60453 .41492 L p F P
.623 .462 .287 r
s
.948 .7 .438 r
.60461 .34319 m .61243 .39884 L .60453 .41492 L p F P
.623 .462 .287 r
s
.948 .7 .438 r
.60453 .41492 m .59308 .38051 L .60461 .34319 L p F P
.623 .462 .287 r
s
.982 .727 .452 r
.6617 .35163 m .71083 .29024 L .68577 .34027 L p F P
.623 .462 .287 r
s
.91 .674 .426 r
.52359 .3701 m .52241 .41056 L .50684 .43902 L p F P
.623 .462 .287 r
s
.91 .674 .426 r
.50684 .43902 m .50473 .41051 L .52359 .3701 L p F P
.623 .462 .287 r
s
.874 .649 .413 r
.50258 .37725 m .50473 .41051 L .48461 .43541 L p F P
.623 .462 .287 r
s
.874 .649 .413 r
.48461 .43541 m .47895 .41068 L .50258 .37725 L p F P
.623 .462 .287 r
s
.827 .614 .394 r
.47895 .41068 m .48461 .43541 L .45453 .4129 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.36569 .12526 m .33792 .11379 L .36996 .11929 L p F P
.392 .656 .4 r
s
.803 .593 .382 r
.36316 .2897 m .38992 .35479 L .39518 .38509 L p F P
.623 .462 .287 r
s
.803 .593 .382 r
.39518 .38509 m .36967 .33288 L .36316 .2897 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.33792 .11379 m .34644 .12499 L .31965 .11513 L p F P
.392 .656 .4 r
s
.807 .6 .387 r
.43887 .41454 m .42245 .37531 L .45453 .4129 L p F P
.623 .462 .287 r
s
.777 .577 .373 r
.42245 .37531 m .43887 .41454 L .41219 .38237 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.55224 .1245 m .56006 .11051 L .56799 .11996 L p F P
.392 .656 .4 r
s
.738 .548 .358 r
.3439 .27157 m .35813 .33773 L .33446 .28706 L p F P
.623 .462 .287 r
s
.914 .676 .426 r
.56522 .41201 m .57546 .372 L .58169 .41311 L p F P
.623 .462 .287 r
s
.91 .671 .422 r
.59308 .38051 m .58169 .41311 L .57546 .372 L p F P
.623 .462 .287 r
s
.827 .614 .394 r
.45453 .4129 m .44357 .38025 L .47895 .41068 L p F P
.623 .462 .287 r
s
.799 .592 .381 r
.44357 .38025 m .45453 .4129 L .42245 .37531 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.50075 .12235 m .52585 .1077 L .52462 .11866 L p F P
.392 .656 .4 r
s
.895 .662 .419 r
.55086 .42221 m .55986 .37674 L .56522 .41201 L p F P
.623 .462 .287 r
s
.874 .646 .41 r
.55986 .37674 m .55086 .42221 L .54543 .40226 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.56799 .11996 m .57745 .10741 L .58447 .12187 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58722 .09446 m .59514 .11147 L .58447 .12187 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.58447 .12187 m .57745 .10741 L .58722 .09446 L p F P
.392 .656 .4 r
s
.927 .685 .431 r
.55303 .34604 m .54543 .40226 L .53378 .42165 L p F P
.623 .462 .287 r
s
.927 .685 .431 r
.53378 .42165 m .53826 .37596 L .55303 .34604 L p F P
.623 .462 .287 r
s
.777 .577 .373 r
.41219 .38237 m .39011 .32927 L .42245 .37531 L p F P
.623 .462 .287 r
s
.746 .555 .361 r
.39011 .32927 m .41219 .38237 L .38992 .35479 L p F P
.623 .462 .287 r
s
.891 .657 .415 r
.57546 .372 m .56522 .41201 L .55986 .37674 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.57745 .10741 m .56799 .11996 L .56006 .11051 L p F P
.392 .656 .4 r
s
.854 .633 .404 r
.50258 .37725 m .47895 .41068 L .47549 .39406 L p F P
.623 .462 .287 r
s
.836 .617 .394 r
.43246 .34287 m .47549 .39406 L .47895 .41068 L p F P
.623 .462 .287 r
s
.836 .617 .394 r
.47895 .41068 m .44357 .38025 L .43246 .34287 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.30126 .09865 m .34667 .10845 L .36996 .11929 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.36996 .11929 m .33792 .11379 L .30126 .09865 L p F P
.392 .656 .4 r
s
.746 .555 .361 r
.38992 .35479 m .36316 .2897 L .39011 .32927 L p F P
.623 .462 .287 r
s
.788 .581 .374 r
.33611 .21312 m .36316 .2897 L .36967 .33288 L p F P
.623 .462 .287 r
s
.788 .581 .374 r
.36967 .33288 m .3439 .27157 L .33611 .21312 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.54703 .10575 m .52462 .11866 L .52585 .1077 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.56817 .09601 m .56006 .11051 L .54231 .11858 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.54231 .11858 m .54703 .10575 L .56817 .09601 L p F P
.392 .656 .4 r
s
.738 .548 .358 r
.33446 .28706 m .31793 .2011 L .3439 .27157 L p F P
.623 .462 .287 r
s
.899 .664 .42 r
.52479 .32268 m .52359 .3701 L .50473 .41051 L p F P
.623 .462 .287 r
s
.899 .664 .42 r
.50473 .41051 m .50258 .37725 L .52479 .32268 L p F P
.623 .462 .287 r
s
.921 .68 .427 r
.54284 .3207 m .53826 .37596 L .52241 .41056 L p F P
.623 .462 .287 r
s
.921 .68 .427 r
.52241 .41056 m .52359 .3701 L .54284 .3207 L p F P
.623 .462 .287 r
s
.799 .592 .381 r
.42245 .37531 m .40581 .32934 L .44357 .38025 L p F P
.623 .462 .287 r
s
.77 .569 .368 r
.40581 .32934 m .42245 .37531 L .39011 .32927 L p F P
.623 .462 .287 r
s
.874 .646 .41 r
.54543 .40226 m .55303 .34604 L .55986 .37674 L p F P
.623 .462 .287 r
s
.91 .671 .422 r
.57546 .372 m .58586 .32511 L .59308 .38051 L p F P
.623 .462 .287 r
s
.939 .691 .431 r
.59641 .27122 m .60461 .34319 L .59308 .38051 L p F P
.623 .462 .287 r
s
.939 .691 .431 r
.59308 .38051 m .58586 .32511 L .59641 .27122 L p F P
.623 .462 .287 r
s
.854 .633 .404 r
.47549 .39406 m .5004 .33916 L .50258 .37725 L p F P
.623 .462 .287 r
s
.823 .605 .387 r
.38896 .27654 m .43246 .34287 L .44357 .38025 L p F P
.623 .462 .287 r
s
.823 .605 .387 r
.44357 .38025 m .40581 .32934 L .38896 .27654 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.31965 .11513 m .30126 .09865 L .33792 .11379 L p F P
.392 .656 .4 r
s
.77 .569 .368 r
.39011 .32927 m .36775 .26686 L .40581 .32934 L p F P
.623 .462 .287 r
s
.739 .546 .356 r
.36775 .26686 m .39011 .32927 L .36316 .2897 L p F P
.623 .462 .287 r
s
.728 .539 .351 r
.33611 .21312 m .3439 .27157 L .31793 .2011 L p F P
.623 .462 .287 r
s
.891 .657 .415 r
.55986 .37674 m .56904 .32175 L .57546 .372 L p F P
.623 .462 .287 r
s
.887 .652 .411 r
.58586 .32511 m .57546 .372 L .56904 .32175 L p F P
.623 .462 .287 r
s
.869 .64 .405 r
.56904 .32175 m .55986 .37674 L .55303 .34604 L p F P
.623 .462 .287 r
s
.739 .546 .356 r
.36316 .2897 m .33611 .21312 L .36775 .26686 L p F P
.623 .462 .287 r
s
.863 .637 .405 r
.52479 .32268 m .50258 .37725 L .5004 .33916 L p F P
.623 .462 .287 r
s
.914 .673 .423 r
.5608 .27783 m .55303 .34604 L .53826 .37596 L p F P
.623 .462 .287 r
s
.914 .673 .423 r
.53826 .37596 m .54284 .3207 L .5608 .27783 L p F P
.623 .462 .287 r
s
.806 .591 .379 r
.34517 .19509 m .38896 .27654 L .40581 .32934 L p F P
.623 .462 .287 r
s
.806 .591 .379 r
.40581 .32934 m .36775 .26686 L .34517 .19509 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.56006 .11051 m .56817 .09601 L .57745 .10741 L p F P
.392 .656 .4 r
s
.91 .67 .421 r
.54749 .25568 m .54284 .3207 L .52359 .3701 L p F P
.623 .462 .287 r
s
.91 .67 .421 r
.52359 .3701 m .52479 .32268 L .54749 .25568 L p F P
.623 .462 .287 r
s
.728 .539 .351 r
.31793 .2011 m .30126 .09865 L .33611 .21312 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.52585 .1077 m .5519 .0925 L .54703 .10575 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57896 .07672 m .58722 .09446 L .57745 .10741 L p F P
.392 .656 .4 r
s
.238 .591 .266 r
.57745 .10741 m .56817 .09601 L .57896 .07672 L p F P
.392 .656 .4 r
s
.783 .574 .369 r
.30126 .09865 m .34517 .19509 L .36775 .26686 L p F P
.623 .462 .287 r
s
.783 .574 .369 r
.36775 .26686 m .33611 .21312 L .30126 .09865 L p F P
.623 .462 .287 r
s
.869 .64 .405 r
.55303 .34604 m .5608 .27783 L .56904 .32175 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.56817 .09601 m .54703 .10575 L .5519 .0925 L p F P
.392 .656 .4 r
s
.887 .652 .411 r
.56904 .32175 m .57838 .25705 L .58586 .32511 L p F P
.623 .462 .287 r
s
.924 .677 .423 r
.58785 .18251 m .59641 .27122 L .58586 .32511 L p F P
.623 .462 .287 r
s
.924 .677 .423 r
.58586 .32511 m .57838 .25705 L .58785 .18251 L p F P
.623 .462 .287 r
s
.863 .637 .405 r
.5004 .33916 m .526 .26816 L .52479 .32268 L p F P
.623 .462 .287 r
s
.865 .635 .402 r
.57838 .25705 m .56904 .32175 L .5608 .27783 L p F P
.623 .462 .287 r
s
.903 .663 .417 r
.5687 .1974 m .5608 .27783 L .54284 .3207 L p F P
.623 .462 .287 r
s
.903 .663 .417 r
.54284 .3207 m .54749 .25568 L .5687 .1974 L p F P
.623 .462 .287 r
s
.864 .636 .403 r
.54749 .25568 m .52479 .32268 L .526 .26816 L p F P
.623 .462 .287 r
s
.865 .635 .402 r
.5608 .27783 m .5687 .1974 L .57838 .25705 L p F P
.623 .462 .287 r
s
.238 .591 .266 r
.5519 .0925 m .57896 .07672 L .56817 .09601 L p F P
.392 .656 .4 r
s
.902 .66 .414 r
.57896 .07672 m .58785 .18251 L .57838 .25705 L p F P
.623 .462 .287 r
s
.902 .66 .414 r
.57838 .25705 m .5687 .1974 L .57896 .07672 L p F P
.623 .462 .287 r
s
.864 .636 .403 r
.526 .26816 m .55222 .18074 L .54749 .25568 L p F P
.623 .462 .287 r
s
.858 .629 .399 r
.5687 .1974 m .54749 .25568 L .55222 .18074 L p F P
.623 .462 .287 r
s
.858 .629 .399 r
.55222 .18074 m .57896 .07672 L .5687 .1974 L p F P
.623 .462 .287 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[321]:=",
  ImageSize->{450, 264.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400072000122000`400?l00000o`00003oo`2Id>G2
09W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo
003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80
VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool0
0?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2I
d>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00
o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@
i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o
09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U
0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0
VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@i@@0VM3U00<0WgI909W@i@2Id>D0^`2I
d>D10?ooo`00o`2Id>D209W@i@80I:MV00<0WgI909W@i@2Id>D0^`2Id>D10?ooo`00o`2Id>D206BW
IP0403bGA02OMTT0WgI906BWI[`0VM3U0@3oool00?h0VM3U00@0I:MV03bGA00lUd@0?9M40P2OMTT0
0`1TYfH0VM3U09W@i@2j09W@i@40oooo003l09W@i@80I:MV0`0lUd@01@1TYfH0WgI909mfB@0lUd@0
I:MV0;/0VM3U0@3oool00?X0VM3U0P1TYfH503bGA00506BWIP2OMTT0WgI903bGA01TYfH0^`2Id>D1
0?ooo`00n02Id>D206BWIPH0?9M400@0I:MV09mfB@3KXFH0WgI90P0lUd@00`1TYfH0VM3U09W@i@2h
09W@i@40oooo003g09W@i@0306BWIP0lUd@0?9M400H0?9M400L0I:MV09mfB@2OMTT0iZQY09mfB@0l
Ud@0I:MV0;X0VM3U0@3oool00?D0VM3U0`1TYfH703bGA00606BWIP0lUd@0WgI909mfB@3VZ6T0WgI9
0P0lUd@00`1TYfH0VM3U09W@i@2g09W@i@40oooo003d09W@i@0306BWIP0lUd@0I:MV00L0?9M40P1T
YfH01P0lUd@0WgI909mfB@3VZ6T0WgI903bGA080I:MV^@2Id>D10?ooo`00Q`2Id>D00`2OMTT0I:MV
06BWIP1X09W@i@80I:MV0P0lUd@00`1TYfH0?9M403bGA00303bGA0<0I:MV00X0?9M409mfB@3KXFH0
WgI90>JXJ@2OMTT0?9M406BWIP0lUd@0I:MV^02Id>D10?ooo`00Q`2Id>D00`2OMTT0I:MV06BWIP05
06BWIV40VM3U0P1TYfH403bGA00306BWIP0lUd@0?9M400<0I:MV0P0lUd@0201TYfH0?9M409mfB@3K
XFH0WgI90>JXJ@2OMTT0I:MV0P0lUd@00`1TYfH0VM3U09W@i@2f09W@i@40oooo002709W@i@80WgI9
00@0I:MV03bGA01TYfH0I:MV0P0lUd@506BWIU/0VM3U00<0I:MV03bGA00lUd@00`0lUd@0101TYfH0
?9M406BWIP1TYfH403bGA00806BWIP0lUd@0?9M409mfB@3KXFH0WgI90>JXJ@2OMTT403bGA00306BW
IP2Id>D0VM3U0;D0VM3U0@3oool008L0VM3U0P2OMTT0102Id>D0I:MV03bGA00lUd@206BWIPD0?9M4
1@1TYfID09W@i@80I:MV1P0lUd@206BWIPD0?9M400T0I:MV03bGA00lUd@0?9M409mfB@3KXFH0WgI9
0>JXJ@2OMTT0100lUd@00`1TYfH0VM3U09W@i@2e09W@i@40oooo002809W@i@80WgI900<0VM3U06BW
IP1TYfH00P0lUd@306BWIPL0?9M4101TYfI?09W@i@0306BWIP0lUd@0?9M400@0?9M40`1TYfH603bG
A00406BWIP0lUd@0?9M409mfB@80fj5V00<0WgI90>JXJ@2OMTT01@0lUd@00`1TYfH0VM3U09W@i@2d
09W@i@40oooo002809W@i@80WgI90`2Id>D00`1TYfH0?9M403bGA00203bGA080I:MV2@0lUd@406BW
ITT0VM3U0`1TYfH403bGA080I:MV00<0?9M406BWIP0lUd@01@0lUd@01@1TYfH0?9M403bGA00lUd@0
WgI90080fj5V00<0WgI90>JXJ@2OMTT01@0lUd@00`1TYfH0VM3U09W@i@2d09W@i@40oooo002809W@
i@<0WgI90`2Id>D00`1TYfH0?9M403bGA00303bGA080I:MV2@0lUd@206BWIP0403bGA01TYfH0I:MV
06BWIT<0VM3U0P1TYfH203bGA00506BWIP0lUd@0?9M403bGA01TYfH00`0lUd@00`1TYfH0?9M403bG
A00203bGA080I:MV00D0?9M406BWIP0lUd@0?9M409mfB@020=^QIP0309mfB@3VZ6T0WgI900H0?9M4
00<0I:MV09W@i@2Id>D0/`2Id>D10?ooo`00R02Id>D309mfB@@0VM3U00<0I:MV03bGA00lUd@0100l
Ud@506BWIPH0?9M40P1TYfH203bGA0@0I:MV?P2Id>D01@1TYfH0?9M403bGA00lUd@0I:MV0080?9M4
0P1TYfH403bGA00306BWIP0lUd@0?9M40080I:MV00@0?9M406BWIP0lUd@0I:MV0P0lUd@01P2OMTT0
fj5V0=^QIP2OMTT0iZQY09mfB@D0?9M40P1TYfJe09W@i@40oooo002809W@i@0409mfB@2jRET0WgI9
09mfB@@0VM3U0`1TYfH503bGA0d0I:MV100lUd@406BWISP0VM3U0P1TYfH403bGA0<0I:MV1@0lUd@0
101TYfH0?9M406BWIP1TYfH203bGA00606BWIP0lUd@0?9M403bGA01TYfH0WgI90`3KXFH0102OMTT0
iZQY09mfB@1TYfH203bGA080I:MV0P0lUd@00`1TYfH0VM3U09W@i@2b09W@i@40oooo002809W@i@04
09mfB@2jRET0WgI909mfB@D0VM3U00@0I:MV03bGA01TYfH0I:MV100lUd@00`1TYfH0?9M406BWIP02
06BWIPD0?9M41P1TYfH403bGA0D0I:MV<@2Id>D206BWIPH0?9M400<0I:MV03bGA00lUd@01@0lUd@2
06BWIP@0?9M400H0I:MV03bGA00lUd@0?9M406BWIP2OMTT30=^QIP0609mfB@3VZ6T0iZQY09mfB@0l
Ud@0I:MV100lUd@00`1TYfH0VM3U09W@i@2b09W@i@40oooo002909W@i@80WgI900<0b99N09mfB@2I
d>D0102Id>D00`1TYfH0?9M403bGA00306BWIP0303bGA01TYfH0?9M400<0?9M40`1TYfH603bGA0H0
I:MV0`0lUd@206BWIP0303bGA01TYfH0I:MV0080I:MV:P2Id>D206BWIPH0?9M40`1TYfH503bGA0<0
I:MV100lUd@00`1TYfH0?9M403bGA00303bGA00509mfB@3KXFH0fj5V0=^QIP2OMTT00P3VZ6T00`2O
MTT0I:MV03bGA00503bGA00306BWIP2Id>D0VM3U0;40VM3U0@3oool008T0VM3U0P2OMTT00`38TUh0
WgI909W@i@0509W@i@0306BWIP0lUd@0?9M40080?9M40`1TYfH603bGA080I:MV1P0lUd@206BWIP80
?9M4101TYfH00`0lUd@0I:MV06BWIP0303bGA0D0I:MV902Id>D00`1TYfH0?9M403bGA00403bGA080
I:MV0P0lUd@00`1TYfH0?9M403bGA00203bGA00306BWIP0lUd@0I:MV00D0?9M400<0I:MV03bGA00l
Ud@00P0lUd@01@1TYfH0WgI90=^QIP3KXFH0WgI900<0iZQY00<0WgI906BWIP0lUd@01@0lUd@00`1T
YfH0VM3U09W@i@2a09W@i@40oooo002909W@i@0509mfB@2jRET0WgI90<RBGP2OMTT01P2Id>D00`1T
YfH0?9M403bGA00303bGA0<0I:MV1P0lUd@406BWIP@0?9M40P1TYfH403bGA0D0I:MV1P0lUd@506BW
IQd0VM3U0`1TYfH503bGA00306BWIP0lUd@0?9M40080?9M400<0I:MV03bGA00lUd@00P1TYfH203bG
A00306BWIP0lUd@0?9M40080?9M400<0I:MV03bGA00lUd@00P0lUd@00`1TYfH0WgI90=^QIP020=^Q
IP0709mfB@3VZ6T0iZQY0>JXJ@2OMTT0?9M406BWIP0603bGA00306BWIP2Id>D0VM3U05@0VM3U1@1T
YfH00`2OMTT0VM3U09W@i@1D09W@i@40oooo002909W@i@0509mfB@2jRET0WgI90<RBGP2OMTT01`2I
d>D00`1TYfH0?9M403bGA00403bGA0@0I:MV1@0lUd@:06BWIPH0?9M41@1TYfH703bGA0D0I:MV5P2I
d>D206BWIP80?9M400@0I:MV03bGA00lUd@0?9M40P1TYfH503bGA0<0I:MV100lUd@00`1TYfH0?9M4
03bGA00206BWIP0303bGA01TYfH0?9M40080?9M400<0I:MV09mfB@3KXFH00P3KXFH01`2OMTT0iZQY
0>JXJ@3VZ6T0WgI903bGA01TYfH01P0lUd@00`1TYfH0VM3U09W@i@1809W@iA00I:MV0P2OMTUF09W@
i@40oooo002909W@i@0309mfB@2jRET0WgI90080b99N00<0WgI909W@i@2Id>D01@2Id>D00`1TYfH0
?9M403bGA00403bGA00306BWIP0lUd@0?9M400<0I:MV0P0lUd@00`1TYfH0?9M403bGA00206BWIP<0
?9M41P1TYfH503bGA0H0I:MV1P0lUd@00`1TYfH0?9M403bGA00306BWIQ00VM3U0P1TYfH503bGA0<0
I:MV1P0lUd@206BWIPD0?9M400H0I:MV03bGA01TYfH0I:MV03bGA01TYfH203bGA00506BWIP0lUd@0
I:MV03bGA02OMTT00`3KXFH01@2OMTT0iZQY0>JXJ@3VZ6T0WgI90080?9M400<0I:MV03bGA00lUd@0
0P0lUd@206BWISl0VM3U2`1TYfH703bGA0L0I:MV0P2Id>D00`2OMTT0VM3U09W@i@1E09W@i@40oooo
002909W@i@0609mfB@2jRET0^XUI09mfB@38TUh0WgI9202Id>D206BWIPD0?9M40P1TYfH303bGA0@0
I:MV0`0lUd@306BWIP@0?9M41P1TYfH303bGA080I:MV0P0lUd@406BWIP<0?9M40P1TYfH303bGA0D0
I:MV2@2Id>D206BWIPL0?9M400<0I:MV03bGA00lUd@0100lUd@206BWIP0303bGA01TYfH0?9M400<0
?9M40`1TYfH203bGA00306BWIP0lUd@0?9M40080?9M400@0I:MV03bGA00lUd@0WgI90`3KXFH01@2O
MTT0iZQY0>JXJ@3VZ6T0WgI90080?9M400<0I:MV03bGA00lUd@00P1TYfH203bGA00306BWIP2Id>D0
VM3U0340VM3U3`1TYfH903bGA0D0I:MV0P0lUd@206BWIP@0VM3U0P2OMTUG09W@i@40oooo002909W@
i@0609mfB@2jRET0^XUI09mfB@38TUh0WgI92@2Id>D506BWIP<0?9M400<0I:MV03bGA00lUd@00`0l
Ud@306BWIP@0?9M40P1TYfH403bGA080I:MV0P0lUd@706BWIP@0?9M4101TYfH00`0lUd@0I:MV03bG
A00603bGA0@0I:MV0`2Id>D206BWIPH0?9M40P1TYfH00`0lUd@0I:MV03bGA00303bGA080I:MV0P0l
Ud@0101TYfH0?9M403bGA00lUd@206BWIP0303bGA01TYfH0?9M40080?9M400P0I:MV03bGA00lUd@0
?9M406BWIP0lUd@0I:MV09mfB@@0fj5V00D0WgI90>JXJ@3VZ6T0iZQY09mfB@0303bGA080I:MV100l
Ud@00`1TYfH0VM3U09W@i@0V09W@i@/0I:MV200lUd@306BWIPT0?9M4101TYfH403bGA0<0I:MV1P2I
d>D209mfBEL0VM3U0@3oool008X0VM3U00<0WgI90;Z9F@2OMTT00P38TUh00`2OMTT0VM3U09W@i@07
09W@i@80I:MV0P0lUd@506BWIPH0?9M4101TYfH303bGA0@0I:MV0P0lUd@206BWIPD0?9M40`1TYfH7
03bGA0H0I:MV1`0lUd@306BWIPD0?9M40`1TYfH403bGA00406BWIP0lUd@0I:MV06BWIP@0?9M400@0
I:MV03bGA01TYfH0I:MV0P0lUd@01@1TYfH0?9M403bGA00lUd@0I:MV00<0?9M400D0I:MV03bGA00l
Ud@0I:MV09mfB@040=^QIP0509mfB@3VZ6T0iZQY0>JXJ@2OMTT00`0lUd@00`1TYfH0?9M403bGA004
03bGA00306BWIP2Id>D0VM3U01X0VM3U3`1TYfH;03bGA0@0I:MV0P0lUd@:06BWIPH0?9M40P1TYfH8
09W@i@80WgI9F02Id>D10?ooo`00RP2Id>D01P2OMTT0^XUI0;Z9F@2OMTT0b99N09mfB@/0VM3U00<0
I:MV03bGA00lUd@00`0lUd@306BWIPD0?9M400<0I:MV03bGA00lUd@00P1TYfH303bGA0P0I:MV1P0l
Ud@606BWIP@0?9M400<0I:MV03bGA00lUd@0201TYfH203bGA00306BWIP0lUd@0?9M40080I:MV1`0l
Ud@206BWIPH0?9M40P1TYfH403bGA00306BWIP0lUd@0?9M40080I:MV0`0lUd@01@1TYfH0?9M403bG
A00lUd@0WgI900@0fj5V00H0WgI90>JXJ@3VZ6T0iZQY09mfB@0lUd@206BWIP0303bGA01TYfH0?9M4
00@0?9M400<0I:MV09W@i@2Id>D03`2Id>D;06BWIPL0?9M4101TYfH403bGA1P0I:MV1@0lUd@406BW
IPX0VM3U0P2OMTUH09W@i@40oooo002:09W@i@0409mfB@2jRET0^XUI09mfB@80b99N00<0WgI909W@
i@2Id>D02@2Id>D00`1TYfH0?9M403bGA00403bGA0@0I:MV0`0lUd@0101TYfH0?9M403bGA00lUd@4
06BWIP80?9M40P1TYfH203bGA0D0I:MV100lUd@206BWIP80?9M41`1TYfH803bGA0D0I:MV1`0lUd@3
06BWIPD0?9M40`1TYfH403bGA00306BWIP0lUd@0I:MV0080I:MV00@0?9M406BWIP0lUd@0I:MV100l
Ud@00`2OMTT0fj5V0=^QIP020=^QIP0609mfB@3VZ6T0iZQY0>JXJ@2OMTT0I:MV100lUd@00`1TYfH0
?9M403bGA00303bGA00306BWIP2Id>D0VM3U00<0VM3U2`1TYfH203bGA080I:MV200lUd@>06BWIP<0
?9M4101TYfH403bGA0H0I:MV0`0lUd@206BWIP80?9M41P1TYfH<09W@i@<0WgI9F02Id>D10?ooo`00
RP2Id>D0102OMTT0^XUI0;Z9F@2OMTT20<RBGP0309mfB@2Id>D0VM3U00X0VM3U0P1TYfH503bGA003
06BWIP0lUd@0?9M400D0I:MV1@0lUd@306BWIP80?9M40`1TYfH303bGA0T0I:MV1@0lUd@606BWIPP0
?9M400<0I:MV03bGA00lUd@00`0lUd@206BWIP80?9M400@0I:MV03bGA00lUd@0?9M40P1TYfH203bG
A00306BWIP0lUd@0?9M40080?9M40P1TYfH203bGA00406BWIP0lUd@0?9M406BWIP@0?9M400<0WgI9
0=^QIP3KXFH00`3KXFH01@2OMTT0iZQY0>JXJ@3VZ6T0WgI900H0?9M400<0I:MV03bGA00lUd@00P0l
Ud@606BWIPX0?9M4401TYfH903bGA0d0I:MV1`0lUd@606BWIP80?9M40P1TYfH>09W@i@80WgI9F@2I
d>D10?ooo`00RP2Id>D01@2OMTT0^XUI0;Z9F@2jRET0WgI90080b99N00<0WgI909W@i@2Id>D02`2I
d>D206BWIP@0?9M400<0I:MV03bGA00lUd@00`0lUd@306BWIPD0?9M4101TYfH203bGA080I:MV0`0l
Ud@206BWIP<0?9M41@1TYfH503bGA00306BWIP0lUd@0?9M400L0I:MV0P0lUd@00`1TYfH0?9M403bG
A00206BWIPD0?9M40`1TYfH303bGA00406BWIP0lUd@0?9M403bGA080I:MV0`0lUd@01@1TYfH0?9M4
03bGA00lUd@0I:MV00@0?9M400<0WgI90=^QIP3KXFH00`3KXFH00`2OMTT0iZQY0>JXJ@020>JXJ@03
09mfB@0lUd@0?9M400@0?9M400@0I:MV03bGA01TYfH0I:MV1P0lUd@=06BWIPP0?9M40P1TYfH603bG
A0X0I:MV00<0?9M406BWIP1TYfH00`1TYfH603bGA0D0I:MV100lUd@306BWIPl0VM3U0`2OMTUI09W@
i@40oooo002:09W@i@0509mfB@2jRET0^XUI0;Z9F@2OMTT00P38TUh00`2OMTT0VM3U09W@i@0<09W@
i@@0I:MV0P0lUd@00`1TYfH0?9M403bGA00403bGA0D0I:MV0P0lUd@206BWIP0303bGA01TYfH0I:MV
0080?9M41`1TYfH503bGA0D0I:MV0P0lUd@206BWIPL0?9M41@1TYfH603bGA080I:MV1@0lUd@0101T
YfH0?9M406BWIP1TYfH403bGA00306BWIP0lUd@0?9M400<0?9M400D0I:MV03bGA00lUd@0I:MV09mf
B@050=^QIP0309mfB@3VZ6T0iZQY0080iZQY00<0WgI903bGA00lUd@0100lUd@:06BWIP@0?9M40`1T
YfH;03bGA0<0I:MV00<0?9M406BWIP1TYfH01P1TYfH603bGA0@0I:MV00<0?9M406BWIP1TYfH00`0l
Ud@606BWIPH0?9M40P1TYfHA09W@i@0409mfB@3m^W<0WgI909mfBET0VM3U0@3oool008X0VM3U00D0
WgI90;Z9F@2jRET0^XUI09mfB@030<RBGP0309mfB@2Id>D0VM3U00`0VM3U00<0I:MV03bGA00lUd@0
101TYfH603bGA00406BWIP0lUd@0?9M403bGA0D0I:MV0P0lUd@406BWIP0303bGA01TYfH0I:MV00H0
I:MV0`0lUd@206BWIP0303bGA01TYfH0I:MV00<0I:MV2P0lUd@00`1TYfH0?9M403bGA00203bGA080
I:MV00<0?9M406BWIP0lUd@0100lUd@206BWIPH0?9M400<0I:MV03bGA00lUd@00`0lUd@01@1TYfH0
?9M406BWIP0lUd@0WgI900D0fj5V00<0WgI90>JXJ@3VZ6T00P3VZ6T0102OMTT0I:MV03bGA00lUd@3
06BWIP/0?9M40`1TYfH403bGA180I:MV1P0lUd@406BWIP<0?9M41`1TYfH0100lUd@0I:MV06BWIP1T
YfH603bGA080I:MV4`2Id>D309mfBEX0VM3U0@3oool008/0VM3U00D0WgI90;Z9F@2jRET0^XUI09mf
B@020<RBGP0309mfB@2Id>D0VM3U00d0VM3U00<0I:MV03bGA00lUd@00P0lUd@406BWIP@0?9M40P1T
YfH503bGA0<0I:MV0`0lUd@206BWIP80?9M40`1TYfH303bGA0L0I:MV0`0lUd@706BWIP@0?9M400<0
I:MV03bGA00lUd@00P1TYfH303bGA00406BWIP0lUd@0?9M403bGA0<0I:MV1@0lUd@206BWIPL0?9M4
00<0I:MV03bGA02OMTT01@3KXFH00`2OMTT0iZQY0>JXJ@030>JXJ@0309mfB@0lUd@0I:MV01H0I:MV
0`0lUd@406BWIP0303bGA01TYfH0I:MV00h0I:MV1P0lUd@306BWIP<0?9M40`1TYfH403bGA0D0I:MV
502Id>D0102OMTT0oKYc09mfB@2OMTUJ09W@i@40oooo002;09W@i@0509mfB@2jRET0^XUI0;Z9F@2O
MTT00`38TUh00`2OMTT0VM3U09W@i@0=09W@i@0306BWIP0lUd@0?9M400<0?9M400<0I:MV03bGA01T
YfH0101TYfH00`0lUd@0I:MV03bGA00503bGA0<0I:MV0`0lUd@00`1TYfH0?9M403bGA00203bGA0<0
I:MV1@0lUd@506BWIP80?9M40P1TYfH303bGA0L0I:MV1P0lUd@306BWIP80?9M400@0I:MV03bGA00l
Ud@0?9M40`1TYfH00`0lUd@0I:MV03bGA00403bGA00406BWIP0lUd@0I:MV09mfB@D0fj5V00<0WgI9
0>JXJ@3VZ6T00`3VZ6T00`2OMTT0I:MV03bGA00:03bGA080I:MV2@0lUd@:06BWIPD0?9M41`1TYfH2
03bGA0H0I:MV1@0lUd@;06BWIQL0VM3U0P2OMTT00`3o`gH0WgI909W@i@1I09W@i@40oooo002;09W@
i@0509mfB@2jRET0^XUI0;Z9F@2OMTT00`38TUh00`2OMTT0VM3U09W@i@0>09W@i@0306BWIP0lUd@0
?9M40080?9M400<0I:MV03bGA00lUd@0100lUd@406BWIPD0?9M400<0I:MV03bGA01TYfH00P1TYfH0
0`0lUd@0I:MV03bGA00503bGA080I:MV1P0lUd@806BWIPL0?9M400<0I:MV03bGA00lUd@00`0lUd@2
06BWIP@0?9M400@0I:MV03bGA01TYfH0I:MV0P0lUd@0101TYfH0?9M403bGA01TYfH303bGA00506BW
IP0lUd@0?9M406BWIP2OMTT01@3KXFH00`2OMTT0iZQY0>JXJ@030>JXJ@0309mfB@0lUd@0?9M400L0
?9M40`1TYfH303bGA0X0I:MV00@0?9M406BWIP1TYfH0I:MV0`0lUd@606BWIP<0?9M41P1TYfH00`0l
Ud@0I:MV06BWIP0303bGA0L0I:MV1@0lUd@206BWIQP0VM3U00D0WgI90?fjL`2OMTT0ol=f09mfB@1J
09W@i@40oooo002;09W@i@0509mfB@2jRET0^XUI0;Z9F@2OMTT01038TUh00`2OMTT0VM3U09W@i@0>
09W@i@0306BWIP0lUd@0?9M40080?9M400<0I:MV03bGA00lUd@01@0lUd@00`1TYfH0?9M406BWIP02
06BWIP80?9M400<0I:MV03bGA00lUd@00P0lUd@306BWIPL0?9M4101TYfH403bGA080I:MV0P0lUd@6
06BWIP<0?9M400<0I:MV03bGA00lUd@00`1TYfH603bGA080I:MV0`0lUd@00`1TYfH0?9M403bGA002
03bGA00306BWIP0lUd@0I:MV00@0?9M400<0WgI90=^QIP3KXFH00`3KXFH00`2OMTT0iZQY0>JXJ@03
0>JXJ@0309mfB@1TYfH0I:MV00d0I:MV00<0?9M406BWIP1TYfH00P1TYfH203bGA0@0I:MV00<0?9M4
06BWIP1TYfH00`1TYfH703bGA0<0I:MV0`0lUd@:06BWIPL0?9M40`1TYfHJ09W@i@80WgI900<0ol=f
09mfB@2Id>D0FP2Id>D10?ooo`00R`2Id>D00`2OMTT0^XUI0;Z9F@020;Z9F@0509mfB@38TUh0b99N
0<RBGP2OMTT01`2Id>D=06BWIP0303bGA01TYfH0?9M400L0?9M400@0I:MV03bGA00lUd@0?9M4101T
YfH503bGA0<0I:MV1P0lUd@;06BWIPH0?9M41P1TYfH603bGA080I:MV00<0?9M406BWIP0lUd@00`0l
Ud@00`1TYfH0?9M403bGA00303bGA00306BWIP0lUd@0?9M40080?9M400<0WgI90=^QIP3KXFH0103K
XFH00`2OMTT0iZQY0>JXJ@030>JXJ@0309mfB@0lUd@0?9M400@0I:MV1P0lUd@J06BWIP<0?9M41P1T
YfH403bGA080I:MV1`0lUd@206BWIQ`0VM3U00D0WgI90?fjL`2OMTT0ol=f09mfB@1K09W@i@40oooo
002709W@i@@0I:MV00<0WgI90;Z9F@2jRET00P2jRET01@2OMTT0b99N0<RBGP38TUh0WgI900L0I:MV
3@0lUd@706BWIP<0?9M400<0I:MV03bGA00lUd@0100lUd@406BWIP@0?9M4101TYfH403bGA00406BW
IP0lUd@0I:MV06BWIP@0?9M41@1TYfH803bGA00306BWIP0lUd@0?9M40080?9M40P1TYfH303bGA005
06BWIP0lUd@0?9M403bGA01TYfH01@0lUd@00`1TYfH0?9M406BWIP0303bGA00309mfB@3KXFH0fj5V
00@0fj5V00<0WgI90>JXJ@3VZ6T00`3VZ6T00`2OMTT0I:MV06BWIP0>06BWIP80?9M41@1TYfH00`0l
Ud@0I:MV06BWIP0206BWIPD0?9M42@1TYfH703bGA080I:MV1`0lUd@206BWIQh0VM3U00D0WgI90?fj
L`2OMTT0ol=f09mfB@1K09W@i@40oooo001b09W@iAD0I:MV1@0lUd@01@2OMTT0^XUI0;Z9F@2jRET0
WgI900@0b99N00<0WgI903bGA01TYfH0301TYfH<03bGA0L0I:MV1@0lUd@00`1TYfH0?9M406BWIP03
06BWIP0403bGA01TYfH0?9M403bGA0D0I:MV0`0lUd@206BWIPD0?9M4201TYfH203bGA00306BWIP0l
Ud@0?9M40080I:MV100lUd@0101TYfH0?9M403bGA00lUd@206BWIP@0?9M400@0I:MV03bGA00lUd@0
?9M40P1TYfH00`0lUd@0WgI90=^QIP050=^QIP0309mfB@3VZ6T0iZQY00<0iZQY00<0WgI903bGA00l
Ud@01P1TYfH603bGA0@0I:MV100lUd@206BWIP@0?9M41`1TYfH203bGA0<0I:MV1`0lUd@206BWIP80
?9M41`1TYfHO09W@i@0509mfB@3m^W<0WgI90?o3MP2OMTT0G02Id>D10?ooo`00HP2Id>D@06BWIPh0
?9M41`1TYfH503bGA00309mfB@2jRET0^XUI0080^XUI00D0WgI90<RBGP38TUh0b99N09mfB@0206BW
IPL0?9M41P1TYfH603bGA0H0I:MV1P0lUd@406BWIP0303bGA01TYfH0?9M400@0?9M40`1TYfH503bG
A0<0I:MV0`0lUd@206BWIPD0?9M400<0I:MV03bGA00lUd@00`0lUd@506BWIPH0?9M400<0I:MV03bG
A01TYfH00P1TYfH01@0lUd@0I:MV06BWIP0lUd@0I:MV00H0?9M400<0I:MV09mfB@3KXFH01@3KXFH0
0`2OMTT0iZQY0>JXJ@030>JXJ@0309mfB@1TYfH0I:MV00`0I:MV1P0lUd@:06BWIPD0?9M40P1TYfH3
03bGA0/0I:MV00@0?9M406BWIP1TYfH0I:MV8P2Id>D01@2OMTT0oKYc09mfB@3o`gH0WgI905`0VM3U
0@3oool005P0VM3U2P1TYfH:03bGA0P0I:MV3P0lUd@:06BWIP0309mfB@2jRET0^XUI0080^XUI00<0
WgI90<RBGP38TUh00P38TUh00`2OMTT0?9M403bGA00703bGA0d0I:MV2`0lUd@806BWIPD0?9M400<0
I:MV03bGA00lUd@00`0lUd@00`1TYfH0?9M406BWIP0206BWIP80?9M41@1TYfH00`0lUd@0I:MV06BW
IP0703bGA00306BWIP0lUd@0?9M400<0?9M40`1TYfH203bGA00506BWIP0lUd@0?9M403bGA01TYfH0
1`0lUd@00`2OMTT0fj5V0=^QIP050=^QIP0309mfB@3VZ6T0iZQY00<0iZQY00<0WgI903bGA00lUd@0
0`0lUd@606BWIP@0?9M41`1TYfH403bGA080I:MV0`0lUd@906BWIP80?9M40P1TYfH603bGA080I:MV
902Id>D00`2OMTT0oKYc09mfB@020?o3MP0309mfB@2Id>D0VM3U05X0VM3U0@3oool00580VM3U1P1T
YfHL03bGA0h0I:MV2P0lUd@00`2OMTT0^XUI0;Z9F@020;Z9F@0309mfB@38TUh0b99N0080b99N00<0
WgI906BWIP1TYfH01`1TYfH<03bGA0`0I:MV200lUd@406BWIP0303bGA01TYfH0?9M400@0?9M400<0
I:MV03bGA00lUd@00P0lUd@?06BWIP<0?9M400<0I:MV03bGA00lUd@00P1TYfH403bGA00306BWIP0l
Ud@0?9M400<0?9M400<0I:MV03bGA00lUd@00`0lUd@00`1TYfH0WgI90=^QIP060=^QIP0309mfB@3V
Z6T0iZQY00@0iZQY00<0WgI906BWIP1TYfH00P1TYfH203bGA0X0I:MV1`0lUd@906BWIPL0?9M40P1T
YfH503bGA0<0I:MV9@2Id>D01P2OMTT0oKYc0?fjL`2OMTT0ol=f09mfBEd0VM3U0@3oool00580VM3U
0P2OMTT209W@i@H0I:MV0P0lUd@E06BWIPd0?9M4301TYfH00`2OMTT0^XUI0;Z9F@030;Z9F@0309mf
B@38TUh0b99N0080b99N00<0WgI903bGA00lUd@0100lUd@>06BWIPT0?9M41P1TYfH703bGA0L0I:MV
0`0lUd@00`1TYfH0?9M403bGA00503bGA080I:MV0P0lUd@306BWIP@0?9M41P1TYfH603bGA00306BW
IP0lUd@0?9M400@0?9M400<0I:MV03bGA00lUd@00P1TYfH00`0lUd@0WgI90=^QIP060=^QIP0309mf
B@3VZ6T0iZQY00@0iZQY00<0WgI903bGA00lUd@00P0lUd@406BWIP@0?9M40P1TYfH203bGA0P0I:MV
100lUd@206BWIPL0?9M40P1TYfH403bGA0<0I:MV:02Id>D00`2OMTT0oKYc09mfB@020?o3MP0309mf
B@2Id>D0VM3U05/0VM3U0@3oool005<0VM3U00<0WgI909W@i@2Id>D01P2Id>D706BWIP/0?9M45`1T
YfH703bGA00309mfB@2jRET0^XUI00<0^XUI00<0WgI90<RBGP38TUh00P38TUh00`2OMTT0I:MV06BW
IP0606BWIP`0?9M45P1TYfH703bGA0H0I:MV1P0lUd@00`1TYfH0?9M403bGA00303bGA0<0I:MV1P0l
Ud@0101TYfH0?9M403bGA00lUd@306BWIPL0?9M41P1TYfH00`2OMTT0fj5V0=^QIP050=^QIP0309mf
B@3VZ6T0iZQY00@0iZQY00D0WgI906BWIP1TYfH0?9M406BWIP0603bGA0H0I:MV0`0lUd@206BWIPD0
?9M40P1TYfH303bGA0d0I:MV:@2Id>D0102OMTT0oKYc0?fjL`2OMTT20?o3MP0309mfB@2Id>D0VM3U
05/0VM3U0@3oool005<0VM3U0P2OMTT>09W@iBT0I:MV00<0WgI90;Z9F@2jRET00`2jRET00`2OMTT0
b99N0<RBGP030<RBGP0309mfB@1TYfH0I:MV01<0I:MV300lUd@=06BWIPP0?9M41@1TYfH203bGA003
06BWIP0lUd@0?9M400D0?9M42P1TYfH203bGA0<0I:MV0`0lUd@206BWIPD0?9M400<0WgI90=^QIP3K
XFH01P3KXFH00`2OMTT0iZQY0>JXJ@040>JXJ@0409mfB@0lUd@0I:MV06BWIPD0?9M40P1TYfH703bG
A080I:MV0P0lUd@:06BWIPH0?9M4101TYfH303bGA0H0I:MV8`2Id>D00`2OMTT0oKYc09mfB@020?o3
MP0309mfB@2Id>D0VM3U05`0VM3U0@3oool005@0VM3U00<0WgI909W@i@2Id>D04`2Id>D606BWIPX0
?9M44`1TYfH00`2OMTT0^XUI0;Z9F@030;Z9F@0309mfB@38TUh0b99N0080b99N00<0WgI906BWIP1T
YfH0101TYfH303bGA0@0I:MV1@0lUd@C06BWIPH0?9M41P1TYfH803bGA0P0I:MV100lUd@00`1TYfH0
?9M403bGA00206BWIPH0?9M400@0I:MV03bGA00lUd@0?9M42P1TYfH00`2OMTT0fj5V0=^QIP060=^Q
IP0309mfB@3VZ6T0iZQY00@0iZQY00@0WgI906BWIP0lUd@0?9M44P1TYfH703bGA0H0I:MV1`0lUd@4
06BWIPD0?9M41P1TYfHL09W@i@0409mfB@3m^W<0oKYc09mfB@80ol=f00<0WgI909W@i@2Id>D0G02I
d>D10?ooo`00E02Id>D209mfBAX0VM3U1`1TYfH903bGA0H0I:MV1@0lUd@206BWIP0309mfB@2jRET0
^XUI00<0^XUI00<0WgI90<RBGP38TUh00`38TUh00`2OMTT0I:MV06BWIP0@06BWIP/0?9M40`1TYfH4
03bGA1@0I:MV200lUd@406BWIPD0?9M40P1TYfH403bGA00306BWIP0lUd@0?9M400<0?9M41@1TYfH3
03bGA00309mfB@3KXFH0fj5V00D0fj5V00<0WgI90>JXJ@3VZ6T01@3VZ6T0102OMTT0I:MV06BWIP1T
YfH503bGA0@0I:MV1`0lUd@406BWIPP0?9M47`1TYfHF09W@i@0409mfB@3m^W<0oKYc09mfB@80ol=f
00<0WgI909W@i@2Id>D0G02Id>D10?ooo`00E@2Id>D00`2OMTT0VM3U09W@i@0O09W@iAH0I:MV00<0
WgI90;Z9F@2jRET00`2jRET00`2OMTT0b99N0<RBGP030<RBGP0309mfB@1TYfH0I:MV01`0I:MV0P0l
Ud@406BWIPX0?9M40`1TYfH503bGA140I:MV100lUd@206BWIP0403bGA01TYfH0?9M403bGA0@0I:MV
100lUd@306BWIP80WgI91`3KXFH00`2OMTT0iZQY0>JXJ@050>JXJ@0309mfB@0lUd@0?9M400@0I:MV
1P0lUd@C06BWIPP0?9M4101TYfH703bGA0D0I:MV1`0lUd@606BWIPl0VM3U00@0WgI90?fjL`3m^W<0
WgI90P3o`gH00`2OMTT0VM3U09W@i@1M09W@i@40oooo001E09W@i@80WgI99`2Id>D606BWIPL0?9M4
0P1TYfH00`2OMTT0^XUI0;Z9F@040;Z9F@0309mfB@38TUh0b99N00<0b99N00<0WgI906BWIP1TYfH0
101TYfH503bGA0H0I:MV200lUd@L06BWIPX0?9M40P1TYfH503bGA0l0I:MV100lUd@206BWIP80WgI9
1`3KXFH00`2OMTT0iZQY0>JXJ@050>JXJ@0309mfB@1TYfH0I:MV01L0I:MV0`0lUd@606BWIPT0?9M4
101TYfH803bGA0H0I:MV1`0lUd@606BWIPT0VM3U00@0WgI90?fjL`3m^W<0WgI90P3o`gH00`2OMTT0
VM3U09W@i@1M09W@i@40oooo001F09W@i@80WgI9;02Id>D606BWIP<0?9M400<0WgI90;Z9F@2jRET0
102jRET00`2OMTT0b99N0<RBGP030<RBGP0309mfB@0lUd@0?9M40080?9M47@1TYfH603bGA0D0I:MV
200lUd@>06BWIPD0?9M4101TYfH00`0lUd@0I:MV03bGA00206BWIPD0?9M41P1TYfH209mfB@L0fj5V
00<0WgI90>JXJ@3VZ6T01@3VZ6T00`2OMTT0?9M403bGA00903bGA0@0I:MV2P0lUd@f06BWIP<0VM3U
00@0WgI90?fjL`3m^W<0WgI90`3o`gH00`2OMTT0VM3U09W@i@1M09W@i@40oooo001F09W@i@80WgI9
<P2Id>D306BWIP0309mfB@2jRET0^XUI00@0^XUI00<0WgI90<RBGP38TUh01038TUh0102OMTT0I:MV
06BWIP1TYfH703bGA0@0I:MV200lUd@406BWIPH0?9M4101TYfH603bGA0T0I:MV0`0lUd@00`1TYfH0
?9M403bGA00603bGA00306BWIP0lUd@0?9M400@0I:MV100lUd@00`1TYfH0?9M403bGA00203bGA080
I:MV1@0lUd@306BWIP0303bGA02OMTT0WgI900L0fj5V00<0WgI90>JXJ@3VZ6T01@3VZ6T00`2OMTT0
I:MV06BWIP0@06BWIP/0?9M4501TYfH403bGA0H0I:MV200lUd@806BWIP@0?9M40P1TYfH01@2OMTT0
oKYc0?fjL`3m^W<0WgI90080ol=f00<0WgI909W@i@2Id>D0GP2Id>D10?ooo`00E`2Id>D209mfBCD0
VM3U00<0WgI90;Z9F@2jRET00`2jRET00`2OMTT0b99N0<RBGP040<RBGP0309mfB@1TYfH0I:MV00D0
I:MV1`0lUd@406BWIPH0?9M44P1TYfH203bGA00306BWIP0lUd@0?9M400H0?9M400<0I:MV03bGA00l
Ud@01@0lUd@:06BWIP<0?9M400<0I:MV03bGA01TYfH01P1TYfH203bGA00706BWIP0lUd@0?9M403bG
A02OMTT0gJ9W09mfB@070=^QIP0309mfB@3VZ6T0iZQY00@0iZQY00<0WgI90>b]K02OMTT02`1TYfH?
03bGA100I:MV1P0lUd@406BWIP80?9M46P1TYfH0102OMTT0oKYc0?fjL`2OMTT30?o3MP0309mfB@1T
YfH0I:MV05h0VM3U0@3oool005L0VM3U0P2OMTTe09W@i@0309mfB@2jRET0^XUI00@0^XUI00<0WgI9
0<RBGP38TUh00`38TUh209mfB@H0?9M44@1TYfH303bGA00306BWIP0lUd@0?9M400H0?9M40P1TYfH4
03bGA080I:MV1P0lUd@306BWIP@0?9M40`1TYfH703bGA080I:MV0P0lUd@506BWIP<0?9M400<0I:MV
03bGA01TYfH00`1TYfH403bGA00309mfB@3MXVL0WgI900L0fj5V00<0WgI90>JXJ@3VZ6T0103VZ6T0
0`2OMTT0k:e/09mfB@0306BWIPH0?9M41P1TYfH903bGA0`0I:MV2@0lUd@B06BWIP0303bGA01TYfH0
I:MV00<0I:MV2P0lUd@01@2OMTT0oKYc0?fjL`3m^W<0WgI900<0ol=f00<0WgI906BWIP1TYfH01@1T
YfII09W@i@40oooo001H09W@i@80WgI9=02Id>D00`2OMTT0^XUI0;Z9F@040;Z9F@0309mfB@38TUh0
b99N00@0b99N00<0WgI906BWIP1TYfH01@1TYfH00`0lUd@0I:MV03bGA00603bGA080I:MV1P0lUd@2
06BWIP<0?9M41P1TYfH503bGA00306BWIP0lUd@0?9M401L0I:MV1@0lUd@00`1TYfH0?9M403bGA004
03bGA00306BWIP0lUd@0?9M400@0?9M40`1TYfH00`2OMTT0gJ9W09mfB@070=^QIP0309mfB@3VZ6T0
iZQY00@0iZQY00<0WgI90>b]K02OMTT03`0lUd@:06BWIP/0?9M4401TYfH;03bGA100I:MV00D0WgI9
0?fjL`3m^W<0oKYc09mfB@020?o3MP0309mfB@0lUd@0?9M400H0?9M41P1TYfIC09W@i@40oooo001H
09W@i@80WgI9=02Id>D00`2OMTT0^XUI0;Z9F@040;Z9F@0309mfB@38TUh0b99N00@0b99N0P2OMTT2
06BWIP@0?9M400<0I:MV03bGA00lUd@0100lUd@206BWIP<0?9M42P1TYfH00`0lUd@0I:MV06BWIP02
03bGA0T0I:MV1@0lUd@606BWIPP0?9M40P1TYfH00`0lUd@0I:MV06BWIP0403bGA00306BWIP0lUd@0
?9M400@0?9M41@1TYfH403bGA00309mfB@3MXVL0WgI900L0fj5V0P2OMTT60>JXJ@0309mfB@3/[F`0
WgI900@0I:MV2@0lUd@I06BWIPh0?9M43`1TYfH;03bGA00509mfB@3m^W<0oKYc0?fjL`2OMTT00`3o
`gH00`2OMTT0I:MV06BWIP0:06BWIP80?9M41P1TYfI=09W@i@40oooo001I09W@i@80WgI9<`2Id>D0
0`2OMTT0^XUI0;Z9F@050;Z9F@0309mfB@38TUh0b99N00<0b99N0P2OMTT403bGA080I:MV100lUd@8
06BWIP0303bGA01TYfH0I:MV00@0?9M4201TYfH203bGA0D0I:MV1P0lUd@406BWIPT0?9M40P1TYfH5
03bGA00406BWIP0lUd@0?9M406BWIPD0?9M40P1TYfH203bGA00306BWIP0lUd@0?9M400@0I:MV00<0
WgI90=fRI`2OMTT01`3KXFH209mfB@H0iZQY00<0WgI90>b]K02OMTT00`0lUd@:06BWIPP0?9M41@1T
YfH:03bGA100I:MV3P0lUd@<06BWIP0509mfB@3m^W<0oKYc0?fjL`2OMTT00`3o`gH00`2OMTT0?9M4
03bGA00:03bGA0X0I:MV00<0WgI909W@i@2Id>D0B02Id>D10?ooo`00F@2Id>D309mfBC80VM3U0P2O
MTT60;Z9F@0309mfB@38TUh0b99N00@0b99N0P2OMTT203bGA00306BWIP0lUd@0I:MV00H0I:MV1@0l
Ud@:06BWIPD0?9M46`1TYfH603bGA00506BWIP0lUd@0I:MV03bGA01TYfH00P0lUd@306BWIPD0?9M4
00<0I:MV03bGA00lUd@00`0lUd@00`2OMTT0gJ9W09mfB@060=^QIP0409mfB@3WZFX0WgI909mfB@D0
iZQY00@0WgI90>b]K02OMTT0I:MV1P0lUd@00`1TYfH0?9M406BWIP0306BWIPT0?9M43P1TYfH<03bG
A180I:MV2`0lUd@01@2OMTT0oKYc0?fjL`3m^W<0WgI900@0ol=f00<0WgI906BWIP1TYfH02`1TYfH8
09W@i@0309mfB@2Id>D0VM3U04T0VM3U0@3oool005X0VM3U0P2OMTTc09W@i@0309mfB@2jRET0^XUI
00@0^XUI00<0WgI90<RBGP38TUh01038TUh209mfB@@0I:MV0`0lUd@206BWIP<0?9M41P1TYfH403bG
A080I:MV0`0lUd@306BWIPT0?9M40`1TYfH703bGA0H0I:MV0P0lUd@206BWIP@0?9M400<0I:MV03bG
A00lUd@00P1TYfH01@0lUd@0I:MV06BWIP0lUd@0I:MV00H0?9M41P1TYfH00`2OMTT0gJ9W09mfB@06
0=^QIP80WgI900<0gJ9V09mfB@3VZ6T0103VZ6T00`2OMTT0k:e/09mfB@0206BWIPD0?9M400<0I:MV
03bGA00lUd@00`0lUd@906BWIPT0?9M44@1TYfH>03bGA0l0I:MV00D0WgI90?fjL`3m^W<0oKYc09mf
B@030?o3MP0309mfB@2Id>D0VM3U01@0VM3U00<0WgI909W@i@2Id>D0B@2Id>D10?ooo`00FP2Id>D3
09mfBC80VM3U00<0WgI90;Z9F@2jRET01@2jRET00`2OMTT0b99N0<RBGP030<RBGP0309mfB@3>Uf40
WgI900@0?9M4201TYfH403bGA0D0I:MV00<0?9M406BWIP1TYfH00P1TYfH903bGA0<0I:MV00<0?9M4
06BWIP1TYfH01`1TYfH203bGA00306BWIP0lUd@0I:MV00D0?9M40P1TYfH00`0lUd@0I:MV03bGA003
03bGA080I:MV0P0lUd@00`1TYfH0?9M403bGA00203bGA0<0I:MV00<0?9M406BWIP0lUd@00P0lUd@0
102OMTT0gJ9W0=fRI`2OMTT60=^QIP80WgI900<0gJ9V09mfB@3VZ6T0103VZ6T00`2OMTT0k:e/09mf
B@0606BWIP80?9M400<0I:MV03bGA00lUd@0100lUd@0101TYfH0?9M403bGA00lUd@<06BWIP`0?9M4
401TYfHA09W@i@0509mfB@3m^W<0oKYc0?fjL`2OMTT0103o`gH00`2OMTT0VM3U09W@i@0C09W@i@03
09mfB@2Id>D0VM3U04X0VM3U0@3oool005/0VM3U0P2OMTTb09W@i@80WgI91P2jRET00`2OMTT0b99N
0<RBGP030<RBGP0309mfB@3>Uf40WgI900D0I:MV0`0lUd@806BWIP0303bGA01TYfH0I:MV01H0I:MV
1`0lUd@206BWIP<0?9M400<0I:MV03bGA00lUd@0100lUd@00`1TYfH0?9M403bGA00203bGA00306BW
IP0lUd@0?9M40080?9M400<0I:MV03bGA01TYfH00P1TYfH503bGA0<0I:MV00@0WgI90=fRI`3MXVL0
WgI91@3KXFH01@2OMTT0ijUZ09mfB@3MXVH0WgI900@0iZQY00D0WgI90>b]K03/[F`0WgI903bGA004
06BWIP0303bGA01TYfH0I:MV0080I:MV1@0lUd@00`1TYfH0?9M403bGA00503bGA00306BWIP0lUd@0
?9M400d0I:MV9@2Id>D01@2OMTT0oKYc0?fjL`3m^W<0WgI900@0ol=f00<0WgI909W@i@2Id>D04`2I
d>D00`2OMTT0VM3U09W@i@1:09W@i@40oooo001K09W@i@<0WgI9<@2Id>D209mfB@H0^XUI0P2OMTT5
0<RBGP0409mfB@3>Uf40WgI906BWIP<0?9M41@1TYfH603bGA0H0I:MV1@0lUd@E06BWIPH0?9M400<0
I:MV03bGA00lUd@00P0lUd@00`1TYfH0?9M406BWIP0303bGA00406BWIP0lUd@0?9M403bGA0<0I:MV
1@0lUd@206BWIP80?9M400<0I:MV03bGA02OMTT00P3MXVL00`2OMTT0fj5V0=^QIP030=^QIP0509mf
B@3WZFX0WgI90=fRIP2OMTT0103VZ6T0102OMTT0k:e/0>b]K02OMTT403bGA0<0I:MV0P0lUd@506BW
IP80?9M400<0I:MV03bGA00lUd@0100lUd@00`1TYfH0?9M403bGA00303bGA00306BWIP2Id>D0VM3U
02/0VM3U00D0WgI90?fjL`3m^W<0oKYc09mfB@040?o3MP0309mfB@2Id>D0VM3U01<0VM3U00<0WgI9
09W@i@2Id>D0B`2Id>D10?ooo`00G02Id>D209mfBC00VM3U00@0I:MV09mfB@2lS5/0WgI91@2jRET2
09mfB@D0b99N00<0WgI90<jGH@2OMTT01@1TYfH403bGA0<0I:MV00<0?9M406BWIP1TYfH00P1TYfH0
0`0lUd@0I:MV06BWIP0:06BWIP80?9M40P1TYfH903bGA080I:MV0P0lUd@00`1TYfH0?9M403bGA002
03bGA00306BWIP0lUd@0I:MV0080?9M400@0I:MV03bGA00lUd@0?9M40`1TYfH01P0lUd@0I:MV06BW
IP1TYfH0?9M406BWIP<0?9M40`1TYfH503bGA00509mfB@3MXVL0gJ9W0=fRI`2OMTT01@3KXFH01@2O
MTT0ijUZ09mfB@3MXVH0WgI900@0iZQY00D0WgI90>b]K03/[F`0k:e/09mfB@0303bGA00306BWIP0l
Ud@0?9M40080I:MV00<0?9M406BWIP0lUd@00P0lUd@406BWIPH0?9M400<0I:MV03bGA00lUd@00P0l
Ud@00`1TYfH0VM3U09W@i@0Z09W@i@80WgI90`3m^W<00`2OMTT0ol=f0?o3MP020?o3MP0309mfB@2I
d>D0VM3U01<0VM3U00<0WgI909W@i@2Id>D0B`2Id>D10?ooo`00G02Id>D309mfBBd0VM3U101TYfH2
09mfB@D0^XUI0`2OMTT40<RBGP0509mfB@3>Uf40cYMQ09mfB@0lUd@0401TYfH0100lUd@0I:MV06BW
IP1TYfH803bGA080I:MV0`0lUd@806BWIPD0?9M400@0I:MV03bGA01TYfH0I:MV0P0lUd@00`1TYfH0
?9M406BWIP0603bGA080I:MV100lUd@01P1TYfH0?9M406BWIP1TYfH0?9M406BWIP@0?9M40P1TYfH0
1@2OMTT0gJ9W0=fRI`3MXVL0WgI900@0fj5V00H0WgI90>NYJP3WZFX0WgI90=fRIP2OMTT40>JXJ@06
09mfB@3/[F`0k:e/0>b]K02OMTT0I:MV0`0lUd@206BWIP<0?9M40`1TYfH403bGA0D0I:MV0P0lUd@0
0`1TYfH0?9M403bGA00303bGA00306BWIP2Id>D0VM3U02T0VM3U00<0WgI90?fjL`3m^W<00P3m^W<0
0`2OMTT0ol=f0?o3MP020?o3MP0309mfB@2Id>D0VM3U0180VM3U00<0WgI909W@i@2Id>D0C02Id>D1
0?ooo`00G@2Id>D309mfBBX0VM3U0P1TYfH403bGA080WgI91@2jRET309mfB@D0b99N00<0WgI90<jG
H@2OMTT02@1TYfH603bGA0<0I:MV0`0lUd@=06BWIP<0?9M40P1TYfH203bGA00306BWIP0lUd@0?9M4
00@0?9M400<0I:MV03bGA00lUd@00`0lUd@00`1TYfH0?9M403bGA00403bGA00306BWIP0lUd@0?9M4
00@0?9M40P1TYfH403bGA00406BWIP0lUd@0I:MV06BWIP80?9M400D0WgI90=fRI`3MXVL0gJ9W09mf
B@040=^QIP0409mfB@3WZFX0ijUZ09mfB@80gJ9V00D0WgI90>JXJ@3VZ6T0iZQY09mfB@030>b]K003
09mfB@1TYfH0I:MV00<0I:MV00@0?9M406BWIP1TYfH0I:MV0P0lUd@406BWIP80?9M400@0I:MV03bG
A00lUd@0?9M4101TYfH503bGA00306BWIP2Id>D0VM3U02L0VM3U0P2OMTT30?fjL`0309mfB@3o`gH0
ol=f0080ol=f00<0WgI909W@i@2Id>D04`2Id>D00`2OMTT0VM3U09W@i@1<09W@i@40oooo001M09W@
i@0309mfB@1:>2/0WgI902P0VM3U0P1TYfH603bGA00309mfB@2lS5/0WgI900D0^XUI0`2OMTT40<RB
GP0409mfB@3>Uf40cYMQ09mfB@@0I:MV0P0lUd@>06BWIP0303bGA01TYfH0I:MV0080I:MV0P0lUd@9
06BWIPD0?9M400<0I:MV03bGA00lUd@00P0lUd@00`1TYfH0?9M406BWIP0303bGA00306BWIP0lUd@0
I:MV00D0?9M400<0I:MV03bGA00lUd@00P0lUd@306BWIP@0?9M40`1TYfH403bGA00509mfB@3MXVL0
gJ9W0=fRI`2OMTT00`3KXFH01@2OMTT0ijUZ0>NYJP3WZFX0WgI90080gJ9V00D0WgI90>JXJ@3VZ6T0
iZQY09mfB@030>b]K00309mfB@1TYfH0?9M400D0I:MV0P0lUd@406BWIP80?9M40P1TYfH00`0lUd@0
I:MV03bGA00403bGA0D0I:MV00<0?9M406BWIP2Id>D09`2Id>D209mfB@@0oKYc00<0WgI90?o3MP3o
`gH00P3o`gH00`2OMTT0VM3U09W@i@0B09W@i@0309mfB@2Id>D0VM3U04d0VM3U0@3oool005h0VM3U
0`2OMTTU09W@i@80I:MV100lUd@406BWIP0309mfB@2lS5/0WgI900D0^XUI0`2OMTT40<RBGP0409mf
B@3>Uf40cYMQ09mfB@X0I:MV0P0lUd@?06BWIPD0?9M40P1TYfH00`0lUd@0I:MV03bGA00503bGA004
06BWIP0lUd@0I:MV06BWIP<0?9M400<0I:MV03bGA01TYfH00`0lUd@01@1TYfH0?9M403bGA00lUd@0
I:MV00<0?9M40P1TYfH00`0lUd@0I:MV03bGA00203bGA080I:MV00<0?9M406BWIP0lUd@00`0lUd@0
0`2OMTT0gJ9W0=fRI`020=fRI`0509mfB@3KXFH0fj5V0=^QIP2OMTT00`3WZFX0102OMTT0gJ9V0=fR
IP2OMTT30>JXJ@0609mfB@3/[F`0k:e/0>b]K02OMTT0?9M40P1TYfH403bGA080I:MV0`0lUd@306BW
IP<0?9M40`1TYfH403bGA00406BWIP0lUd@0?9M403bGA0<0I:MV9`2Id>D209mfB@<0oKYc00<0WgI9
0?o3MP3o`gH00P3o`gH209mfBA@0VM3U00<0WgI909W@i@2Id>D0C@2Id>D10?ooo`00GP2Id>D00`2O
MTT0BSP[09mfB@0S09W@i@X0I:MV00<0?9M406BWIP1TYfH00P2OMTT50;Z9F@80WgI900<0_H]K09mf
B@38TUh00`38TUh0102OMTT0cYMQ0<jGH@2OMTT;06BWIP<0?9M40`1TYfH503bGA0T0I:MV100lUd@2
06BWIPD0?9M400<0I:MV03bGA00lUd@0100lUd@01`1TYfH0?9M403bGA00lUd@0I:MV03bGA01TYfH0
0P0lUd@0101TYfH0?9M403bGA01TYfH303bGA00406BWIP0lUd@0I:MV06BWIP<0?9M400<0I:MV03bG
A01TYfH00P1TYfH00`2OMTT0gJ9W0=fRI`020=fRI`0509mfB@3KXFH0fj5V0=^QIP2OMTT00P3WZFX0
1@2OMTT0gJ9V0=fRIP3MXVH0WgI900<0iZQY00D0WgI90>b]K03/[F`0k:e/09mfB@0506BWIP@0?9M4
0P1TYfH203bGA00406BWIP0lUd@0I:MV06BWIP<0?9M41@1TYfH00`0lUd@0I:MV03bGA00403bGA003
06BWIP2Id>D0VM3U02<0VM3U0P2OMTT40?fjL`0309mfB@3o`gH0ol=f0080ol=f00<0WgI909W@i@2I
d>D04P2Id>D00`2OMTT0VM3U09W@i@1>09W@i@40oooo001O09W@i@<0WgI9802Id>D406BWIP@0?9M4
1`1TYfH00`2OMTT0_8aK09mfB@040;Z9F@0509mfB@39U5l0WgI90;f;F`2OMTT00`38TUh01@2OMTT0
cYMQ0<jGH@2OMTT0I:MV00L0?9M43P1TYfH909W@i@0306BWIP0lUd@0?9M400<0?9M400<0I:MV03bG
A00lUd@00P1TYfH00`0lUd@0I:MV03bGA00303bGA080I:MV0`0lUd@00`1TYfH0?9M403bGA00206BW
IP0303bGA01TYfH0I:MV00@0?9M40P1TYfH403bGA0<0I:MV0`0lUd@00`2OMTT0gJ9W0=fRI`020=fR
I`0409mfB@3KXFH0fj5V09mfB@<0ijUZ00D0WgI90=fRIP3MXVH0gJ9V09mfB@020>JXJ@0309mfB@3/
[F`0k:e/0080k:e/00<0WgI906BWIP0lUd@00P0lUd@606BWIP0503bGA01TYfH0I:MV03bGA01TYfH0
0P0lUd@206BWIP0303bGA01TYfH0?9M400<0?9M4101TYfH403bGA00306BWIP2Id>D0VM3U0240VM3U
00<0WgI90?fkL`2OMTT00`3m^W<00`2OMTT0ol=f0?o3MP020?o3MP80WgI94`2Id>D209mfBE00VM3U
0@3oool005l0VM3U00<0WgI904Xh:`2OMTT07P2Id>D206BWIPD0?9M4201TYfH01@0lUd@0I:MV09mf
B@2lS5/0WgI900@0^XUI00D0WgI90<VDG`2OMTT0_H]K09mfB@030<RBGP0509mfB@3>Uf40cYMQ0<jG
H@2OMTT01`1TYfHH09W@i@0306BWIP0lUd@0?9M400<0?9M40P1TYfH303bGA00506BWIP0lUd@0?9M4
03bGA01TYfH00P0lUd@00`1TYfH0?9M406BWIP0403bGA080I:MV00@0?9M406BWIP0lUd@0?9M40`1T
YfH303bGA080I:MV00<0?9M406BWIP0lUd@00`0lUd@00`2OMTT0gJ9W0=fRI`020=fRI`0409mfB@3K
XFH0fj5V09mfB@<0ijUZ00D0WgI90=fRIP3MXVH0gJ9V09mfB@020>JXJ@0309mfB@3/[F`0k:e/0080
k:e/00<0WgI906BWIP1TYfH00`1TYfH303bGA0P0I:MV0`0lUd@306BWIPH0?9M40`1TYfH203bGA003
06BWIP2Id>D0VM3U0240VM3U0P2OMTT40?fjL`0309mfB@3o`gH0ol=f0080ol=f00<0WgI909W@i@2I
d>D04P2Id>D00`2OMTT0VM3U09W@i@1?09W@i@40oooo001P09W@i@<0WgI96`2Id>D206BWIP<0?9M4
101TYfH503bGA0@0I:MV00D0?9M409mfB@2lS5/0_8aK09mfB@030;Z9F@0309mfB@39U5l0WgI90080
_H]K00D0WgI90<RBGP38TUh0b99N09mfB@020<jGH@0309mfB@2Id>D0VM3U01h0VM3U00L0I:MV03bG
A00lUd@0?9M406BWIP0lUd@0I:MV00@0?9M400<0I:MV03bGA01TYfH00`0lUd@00`1TYfH0?9M406BW
IP0303bGA00506BWIP0lUd@0?9M406BWIP0lUd@00P1TYfH203bGA00406BWIP0lUd@0I:MV06BWIP@0
?9M400@0I:MV03bGA01TYfH0WgI91@3MXVL00`2OMTT0fj5V09mfB@040>NYJP0309mfB@3MXVH0gJ9V
0080gJ9V00<0WgI90>JXJ@2OMTT0103/[F`0102OMTT0I:MV03bGA00lUd@:06BWIP<0?9M40P1TYfH3
03bGA0<0I:MV1@0lUd@00`1TYfH0?9M406BWIP0306BWIR40VM3U00<0WgI90?fkL`2OMTT00`3m^W<2
09mfB@<0ol=f0P2OMTTC09W@i@0304@^8@2OMTT0VM3U0500VM3U0@3oool00600VM3U00@0WgI904Xh
:`2OMTT0WgI9602Id>D206BWIP0303bGA01TYfH0I:MV0080I:MV0`0lUd@;06BWIP0409mfB@2lS5/0
_8aK09mfB@<0^XUI00H0WgI90<VDG`39U5l0WgI90;f;F`2OMTT30<RBGP0509mfB@3>Uf40cYMQ0<jG
H@2OMTT0802Id>D00`1TYfH0?9M406BWIP0303bGA00306BWIP0lUd@0?9M40080?9M400<0I:MV03bG
A00lUd@00`0lUd@01@1TYfH0?9M403bGA00lUd@0I:MV0080?9M40`1TYfH403bGA080I:MV1P0lUd@2
06BWIP0303bGA02OMTT0gJ9W00<0gJ9W00@0WgI90=^QIP3KXFH0WgI9103WZFX00`2OMTT0gJ9V0=fR
IP020=fRIP0309mfB@3VZ6T0WgI900@0k:e/00<0WgI903bGA01TYfH01@1TYfH403bGA0H0I:MV00<0
?9M406BWIP1TYfH00P0lUd@00`1TYfH0?9M406BWIP0206BWIP80?9M400<0I:MV03bGA00lUd@00P0l
Ud@206BWIR00VM3U0P2OMTT40?fjL`0309mfB@3o`gH0ol=f0080ol=f0P2OMTTC09W@i@0309mfB@2I
d>D0VM3U0500VM3U0@3oool00640VM3U0`2OMTTF09W@i@`0I:MV302Id>D00`2OMTT0_8aK09mfB@03
0;Z9F@0409mfB@39U5l0bIAO09mfB@80_H]K00@0WgI90<RBGP38TUh0WgI90`3>Uf400`2OMTT0VM3U
09W@i@0O09W@i@0306BWIP0lUd@0?9M40080?9M400L0I:MV03bGA00lUd@0?9M406BWIP0lUd@0I:MV
00<0?9M400D0I:MV03bGA01TYfH0I:MV03bGA00306BWIP0303bGA01TYfH0?9M40080?9M40`1TYfH5
03bGA0<0I:MV0P0lUd@00`2OMTT0gJ9W0=fRI`020=fRI`0409mfB@3KXFH0fj5V09mfB@@0ijUZ00<0
WgI90=fRIP3MXVH00P3MXVH00`2OMTT0iZQY09mfB@050>b]K00309mfB@0lUd@0?9M40080?9M41@1T
YfH503bGA0L0I:MV00<0?9M406BWIP0lUd@00P0lUd@406BWIPD0?9M400<0I:MV09W@i@2Id>D0702I
d>D00`2OMTT0oK]c09mfB@030?fjL`80WgI90`3o`gH209mfBA<0VM3U00<0A2hQ09mfB@2Id>D0D@2I
d>D10?ooo`00H@2Id>D0102OMTT0BSP[09mfB@2OMTTC09W@i@0309mfB@1TYfH0I:MV0080I:MV5@2I
d>D0102OMTT0_8aK0;b<F`2OMTT20;Z9F@0409mfB@39U5l0bIAO09mfB@<0_H]K00@0WgI90<RBGP38
TUh0WgI90`3>Uf400`2OMTT0VM3U09W@i@0O09W@i@0306BWIP0lUd@0?9M40080?9M400<0I:MV03bG
A01TYfH00P0lUd@0101TYfH0?9M403bGA01TYfH403bGA080I:MV0P0lUd@00`1TYfH0?9M403bGA002
06BWIP80?9M400@0I:MV03bGA00lUd@0?9M40P1TYfH303bGA00306BWIP2OMTT0gJ9W00@0gJ9W00<0
WgI90=^QIP2OMTT01@3WZFX00`2OMTT0gJ9V0=fRIP020=fRIP0309mfB@3VZ6T0WgI900D0k:e/00<0
WgI906BWIP1TYfH00P1TYfH303bGA0H0I:MV0`0lUd@206BWIP80?9M4101TYfH503bGA0<0I:MV100l
Ud@00`1TYfH0VM3U09W@i@0J09W@i@0309mfB@3m^g<0WgI900<0oKYc0`2OMTT30?o3MP80WgI94`2I
d>D00`2OMTT0VM3U09W@i@1A09W@i@40oooo001R09W@i@0309mfB@1:>2/0WgI901<0VM3U0P2OMTTH
09W@i@0409mfB@2lS5/0_8aK09mfB@<0^XUI00@0WgI90<VDG`39U5l0WgI90P2mRe/0102OMTT0b99N
0<RBGP2OMTT30<jGH@0309mfB@2Id>D0VM3U0200VM3U00<0I:MV03bGA00lUd@00P0lUd@00`1TYfH0
?9M403bGA00203bGA00306BWIP0lUd@0I:MV00<0?9M400<0I:MV03bGA00lUd@00P0lUd@306BWIP@0
?9M400@0I:MV03bGA01TYfH0I:MV1@0lUd@00`1TYfH0WgI90=fRI`040=fRI`0309mfB@3KXFH0WgI9
00D0ijUZ00<0WgI90=fRIP3MXVH00P3MXVH00`2OMTT0iZQY09mfB@050>b]K00309mfB@2Id>D0VM3U
0080VM3U1`1TYfH203bGA0L0I:MV100lUd@306BWIP<0?9M400@0I:MV03bGA01TYfH0I:MV0P0lUd@0
0`1TYfH0VM3U09W@i@0J09W@i@0309mfB@3m^g<0WgI900<0oKYc0P2OMTT30?o3MP80WgI94`2Id>D0
0`14;R40WgI909W@i@1B09W@i@40oooo001R09W@i@0409mfB@1:>2/0WgI909mfBA<0VM3U00<0WgI9
09W@i@2Id>D05P2Id>D0102OMTT0_8aK0;b<F`2OMTT30;Z9F@0409mfB@39U5l0bIAO09mfB@<0_H]K
00<0WgI90<RBGP2OMTT0103>Uf400`2OMTT0VM3U09W@i@0O09W@i@0706BWIP0lUd@0?9M403bGA01T
YfH0?9M406BWIP0403bGA00306BWIP0lUd@0?9M40080?9M400@0I:MV03bGA00lUd@0?9M40P1TYfH6
03bGA080I:MV100lUd@206BWIP80VM3U00<0WgI90=fRI`3MXVL00`3MXVL00`2OMTT0fj5V09mfB@05
0>NYJP0309mfB@3MXVH0gJ9V0080gJ9V00<0WgI90>JXJ@2OMTT01@3/[F`00`2OMTT0VM3U09W@i@08
09W@i@D0I:MV0`0lUd@806BWIP0603bGA01TYfH0I:MV06BWIP0lUd@0I:MV0P0lUd@406BWIQX0VM3U
00<0WgI90?fkL`2OMTT00`3m^W<309mfB@<0ol=f0P2OMTTB09W@i@0304@^8@2OMTT0VM3U05<0VM3U
0@3oool006<0VM3U00@0WgI904Xh:`2OMTT0QfI64P2Id>D209mfBAL0VM3U00D0WgI90;b<F`2lS5/0
_8aK09mfB@020;Z9F@0409mfB@39U5l0bIAO09mfB@<0_H]K00<0WgI90<RBGP2OMTT0103>Uf400`2O
MTT0VM3U09W@i@0P09W@i@0306BWIP0lUd@0I:MV0080?9M400H0I:MV03bGA00lUd@0?9M406BWIP0l
Ud@206BWIP0303bGA01TYfH0?9M400<0I:MV00<0?9M406BWIP0lUd@00`0lUd@306BWIP80?9M40`1T
YfH409W@i@0309mfB@3MXVL0gJ9W00<0gJ9W0P2OMTT50>NYJP0309mfB@3MXVH0gJ9V00<0gJ9V0P2O
MTT60>b]K00309mfB@2Id>D0VM3U00d0VM3U1@1TYfH203bGA080I:MV0P0lUd@606BWIPD0?9M40P1T
YfHH09W@i@0409mfB@3m^g<0oK]c09mfB@80oKYc0P2OMTT01`3o_7<0WgI90?o3MP3o`gH0WgI90?o3
M02OMTT04P2Id>D00`14;R40WgI909W@i@1C09W@i@40oooo001S09W@i@0409mfB@1:>2/0WgI909mf
BA80VM3U0P2OMTTH09W@i@0409mfB@2lS5/0_8aK09mfB@80^XUI00D0WgI90<VDG`39U5l0bIAO09mf
B@030;f;F`0309mfB@38TUh0WgI900@0cYMQ00<0WgI909W@i@2Id>D0802Id>D00`1TYfH0?9M403bG
A00203bGA00306BWIP0lUd@0I:MV00@0?9M40`1TYfH303bGA00406BWIP0lUd@0?9M403bGA080I:MV
00<0?9M406BWIP0lUd@00P1TYfH609W@i@0309mfB@3MXVL0gJ9W00@0gJ9W0P2OMTT50>NYJP0309mf
B@3MXVH0gJ9V00@0gJ9V00<0WgI90>b]K03/[F`0103/[F`00`2OMTT0VM3U09W@i@0B09W@i@H0I:MV
1`0lUd@206BWIP@0?9M400<0I:MV09W@i@2Id>D05@2Id>D0102OMTT0oK]c0?fkL`2OMTT20?fjL`<0
WgI90`3o`gH209mfBA80VM3U00<0A2hQ09mfB@2Id>D0E02Id>D10?ooo`00I02Id>D0102OMTT0BSP[
09mfB@2OMTTB09W@i@80WgI95`2Id>D01`2OMTT0_8aK0;b<F`2lS5/0WgI90;Z9F@2OMTT00`39U5l0
1`2OMTT0_H]K0;f;F`2mRe/0WgI90<RBGP2OMTT0103>Uf400`2OMTT0VM3U09W@i@0Q09W@i@0306BW
IP0lUd@0?9M40080?9M400<0I:MV03bGA00lUd@00`0lUd@00`1TYfH0?9M403bGA00303bGA00406BW
IP0lUd@0I:MV06BWIP<0?9M40P1TYfH809W@i@0309mfB@3MXVL0gJ9W00@0gJ9W00<0WgI90>NYJP3W
ZFX0103WZFX00`2OMTT0gJ9V0=fRIP040=fRIP0309mfB@3/[F`0k:e/00@0k:e/00<0WgI909W@i@2I
d>D05`2Id>D506BWIPD0?9M40P1TYfH303bGA00306BWIP2Id>D0VM3U01<0VM3U00@0WgI90?fkL`3m
^g<0WgI90P3m^W<209mfB@070?nlL`2OMTT0ol=f0?o3MP2OMTT0ol=d09mfB@0B09W@i@0304@^8@2O
MTT0VM3U05@0VM3U0@3oool006@0VM3U00@0WgI904Xh:`2OMTT0WgI94P2Id>D209mfBAL0VM3U00L0
WgI90;b<F`2lS5/0_8aK09mfB@2jRET0WgI900@0bIAO00@0WgI90;f;F`2mRe/0_H]K0P2OMTT50<jG
H@0309mfB@2Id>D0VM3U0240VM3U00H0I:MV03bGA00lUd@0I:MV03bGA01TYfH403bGA00306BWIP0l
Ud@0?9M40080?9M40`1TYfH303bGA080I:MV2P2Id>D00`2OMTT0gJ9W0=fRI`040=fRI`0309mfB@3W
ZFX0ijUZ00@0ijUZ00<0WgI90=fRIP3MXVH0103MXVH00`2OMTT0k:e/0>b]K0040>b]K00309mfB@2I
d>D0VM3U01`0VM3U1@1TYfH203bGA080I:MV00<0?9M406BWIP2Id>D04`2Id>D02`2OMTT0oK]c0?fk
L`3m^g<0WgI90?fjL`2OMTT0olEh09mfB@3o_7<0WgI90080ol=f00<0WgI90?o3M02OMTT04@2Id>D0
0`14;R40WgI909W@i@1E09W@i@40oooo001U09W@i@0409mfB@1:>2/0WgI909mfBA40VM3U0`2OMTTF
09W@i@0709mfB@2lS5/0_8aK0;b<F`2OMTT0^XUI09mfB@040<VDG`0309mfB@2mRe/0_H]K0080_H]K
0P2OMTT40<jGH@0309mfB@2Id>D0VM3U0240VM3U00@0I:MV03bGA00lUd@0I:MV0P0lUd@0101TYfH0
?9M403bGA01TYfH303bGA0<0I:MV0`0lUd@206BWIP/0VM3U00<0WgI90=fRI`3MXVL01@3MXVL00`2O
MTT0ijUZ0>NYJP040>NYJP0309mfB@3MXVH0gJ9V00@0gJ9V00<0WgI90>b]K03/[F`0103/[F`00`2O
MTT0VM3U09W@i@0Q09W@i@L0I:MV4`2Id>D02P2OMTT0oK]c0?fkL`2OMTT0oKYc09mfB@3oaGP0WgI9
0?nlL`2OMTT20?o3MP0309mfB@3o`g@0WgI90180VM3U00<0A2hQ09mfB@2Id>D0E@2Id>D10?ooo`00
IP2Id>D409mfBA40VM3U0`2OMTTE09W@i@0309mfB@2lS5/0_8aK0080_8aK0P2OMTT40<VDG`0309mf
B@2mRe/0_H]K0080_H]K0P2OMTT50<jGH@0309mfB@2Id>D0VM3U0240VM3U0P1TYfH403bGA00306BW
IP0lUd@0I:MV00<0I:MV0P0lUd@0101TYfH0?9M406BWIP1TYfH=09W@i@0309mfB@3MXVL0gJ9W00@0
gJ9W0P2OMTT60>NYJP0309mfB@3MXVH0gJ9V00@0gJ9V00<0WgI90>b]K03/[F`0103/[F`00`2OMTT0
VM3U09W@i@0V09W@i@80I:MV00<0WgI909W@i@2Id>D03`2Id>D02`2OMTT0oK]c0?fkL`3m^g<0WgI9
0?fjL`2OMTT0olEh09mfB@3o_7<0WgI90080ol=f00<0WgI90?o3M02OMTT04@2Id>D00`14;R40WgI9
09W@i@1F09W@i@40oooo001V09W@i@0409mfB@1:>2/0WgI909mfBA40VM3U0`2OMTTF09W@i@0409mf
B@2lS5/0_8aK0;b<F`80WgI91@39U5l00`2OMTT0_H]K0;f;F`020;f;F`0309mfB@3>Uf40cYMQ00<0
cYMQ00<0WgI909W@i@2Id>D08P2Id>D00`1TYfH0?9M403bGA00303bGA080I:MV100lUd@306BWIPl0
VM3U00<0WgI90=fRI`3MXVL0103MXVL209mfB@H0ijUZ00<0WgI90=fRIP3MXVH0103MXVH00`2OMTT0
k:e/0>b]K0050>b]K00309mfB@2Id>D0VM3U02L0VM3U00<0WgI909W@i@2Id>D03P2Id>D02@2OMTT0
oK]c0?fkL`3m^g<0WgI90?fjL`2OMTT0olEh09mfB@020?nlL`0509mfB@3o`gH0WgI90?o3M02OMTT0
4@2Id>D204@^8@0309mfB@2Id>D0VM3U05D0VM3U0@3oool006L0VM3U0P2OMTT00`27ITH0WgI909W@
i@0?09W@i@80WgI900<0`8EA09mfB@2Id>D0502Id>D01`2OMTT0_8aK0;b<F`2lS5/0WgI90;Z9F@2O
MTT01039U5l00`2OMTT0_H]K0;f;F`020;f;F`80WgI91@3>Uf400`2OMTT0VM3U09W@i@0R09W@i@05
06BWIP0lUd@0?9M403bGA01TYfH01@0lUd@206BWIQ40VM3U00<0WgI90=fRI`3MXVL0103MXVL209mf
B@H0ijUZ00<0WgI90=fRIP3MXVH0103MXVH00`2OMTT0k:e/0>b]K0050>b]K00309mfB@2Id>D0VM3U
02H0VM3U0P2OMTT@09W@i@0409mfB@3m^g<0oK]c0?fkL`80WgI90P3oaGP0202OMTT0okac0?nlL`2O
MTT0ol=f09mfB@3o`g@0WgI94@2Id>D00`14;R40WgI909W@i@1G09W@i@40oooo001W09W@i@0309mf
B@1:>2/0WgI90080WgI9402Id>D309mfBAD0VM3U00<0WgI90;b<F`2lS5/00P2lS5/209mfB@@0bIAO
00<0WgI90;f;F`2mRe/00`2mRe/00`2OMTT0cYMQ0<jGH@030<jGH@0309mfB@2Id>D0VM3U0280VM3U
00D0I:MV03bGA00lUd@0?9M406BWIP0303bGA080I:MV4P2Id>D00`2OMTT0gJ9W0=fRI`040=fRI`03
09mfB@3XZf/0WgI900H0ijUZ00<0WgI90=fRIP3MXVH00`3MXVH209mfB@L0k:e/00<0WgI909W@i@2I
d>D09P2Id>D209mfB@l0VM3U00T0WgI90?fkL`3m^g<0oK]c09mfB@3m^W<0WgI90?o5N02OMTT00P3o
_7<00`2OMTT0ol=f09mfB@020?o3M00309mfB@2Id>D0VM3U00h0VM3U0P14;R400`2OMTT0VM3U09W@
i@1F09W@i@40oooo001X09W@i@0309mfB@1:>2/0WgI90080WgI93`2Id>D209mfB@030<25D@2OMTT0
VM3U01<0VM3U00<0WgI90;b<F`2lS5/00P2lS5/209mfB@D0bIAO00<0WgI90;f;F`2mRe/00P2mRe/2
09mfB@D0cYMQ00<0WgI909W@i@2Id>D08P2Id>D00`1TYfH0?9M406BWIP0203bGA080I:MV502Id>D0
0`2OMTT0gJ9W0=fRI`040=fRI`0309mfB@3XZf/0WgI900D0ijUZ00<0WgI90=fRIP3MXVH0103MXVH2
09mfB@L0k:e/00<0WgI909W@i@2Id>D09@2Id>D309mfB@h0VM3U00<0WgI90?fkL`3m^g<00P3m^g<2
09mfB@80olEh00P0WgI90?nlL`3o_7<0WgI90?o3MP2OMTT0ol=d09mfBA40VM3U00<0A2hQ09mfB@2I
d>D0F02Id>D10?ooo`00J02Id>D409mfB@0309aeCP2Id>D0VM3U00d0VM3U00D0WgI90;UoBP2OMTT0
`8EA09mfB@0D09W@i@0309mfB@2lS5/0_8aK0080_8aK00<0WgI90<VDG`39U5l00`39U5l00`2OMTT0
_H]K0;f;F`030;f;F`0309mfB@3>Uf40cYMQ00<0cYMQ00<0WgI909W@i@2Id>D08P2Id>D00`1TYfH0
?9M406BWIP0206BWIQH0VM3U00<0WgI90=fRI`3MXVL0103MXVL00`2OMTT0j:][09mfB@050>NYJP03
09mfB@3MXVH0gJ9V00@0gJ9V00<0WgI90>>VJ@2OMTT01P3/[F`00`2OMTT0VM3U09W@i@0U09W@i@80
WgI93`2Id>D0102OMTT0oK]c0?fkL`3m^g<209mfB@80olEh00@0WgI90?nlL`3o_7<0okac0P2OMTT2
0?o3M00309mfB@2Id>D0VM3U00h0VM3U00<0A2hQ09mfB@2OMTT0F@2Id>D10?ooo`00J@2Id>D01@2O
MTT0BSP[09mfB@2OMTT0W7E>00h0VM3U00D0WgI90;UoBP2OMTT0`8EA09mfB@0D09W@i@0309mfB@2l
S5/0_8aK0080_8aK00<0WgI90<VDG`39U5l00`39U5l00`2OMTT0_H]K0;f;F`030;f;F`80WgI91@3>
Uf400`2OMTT0VM3U09W@i@0R09W@i@80I:MV5`2Id>D209mfB@D0gJ9W00<0WgI90>R[J`2OMTT01P3W
ZFX00`2OMTT0gJ9V0=fRIP040=fRIP0309mfB@3SYVT0WgI900H0k:e/00<0WgI909W@i@2Id>D0902I
d>D309mfB@h0VM3U00<0WgI90?fkL`3m^g<00P3m^g<209mfB@80olEh00P0WgI90?nlL`3o_7<0WgI9
0?o3MP2OMTT0ol=d09mfBA40VM3U00<0A2hQ09mfB@2Id>D0F@2Id>D10?ooo`00JP2Id>D509mfB@h0
VM3U00D0WgI90;UoBP2OMTT0`8EA09mfB@0C09W@i@0309mfB@2lS5/0_8aK0080_8aK00<0WgI90<VD
G`39U5l01039U5l00`2OMTT0_H]K0;f;F`020;f;F`80WgI91@3>Uf400`2OMTT0VM3U09W@i@0R09W@
i@0309mfB@2Id>D0VM3U01H0VM3U0P2OMTT50=fRI`0309mfB@3XZf/0WgI900H0ijUZ00<0WgI90=fR
IP3MXVH0103MXVH00`2OMTT0hjIY09mfB@060>b]K00309mfB@2Id>D0VM3U02@0VM3U0`2OMTT>09W@
i@0409mfB@3m^g<0oK]c0?fkL`80WgI90P3oaGP0102OMTT0okac0?nlL`3o_7<209mfB@80ol=d00<0
WgI909W@i@2Id>D03P2Id>D00`14;R40WgI909mfB@1J09W@i@40oooo001Z09W@i@0509mfB@1:>2/0
WgI909mfB@2LMDh03P2Id>D01@2OMTT0^Gm:09mfB@30QE40WgI901<0VM3U00<0WgI90;b<F`2lS5/0
0P2lS5/209mfB@D0bIAO00<0WgI90;f;F`2mRe/00`2mRe/209mfB@D0cYMQ00<0WgI909W@i@2Id>D0
8@2Id>D209mfBAH0VM3U00<0WgI90=bSI`2OMTT01@3MXVL00`2OMTT0j:][09mfB@060>NYJP0309mf
B@3MXVH0gJ9V00@0gJ9V00<0WgI90>>VJ@2OMTT01@3/[F`209mfBBD0VM3U00@0WgI90:=bB@2OMTT0
WgI93@2Id>D00`2OMTT0oK]c0?fkL`020?fkL`0509mfB@3oaGP0olEh0?o5N02OMTT00`3o_7<209mf
B@80ol=d00<0WgI909W@i@2Id>D03@2Id>D204@^8@0309mfB@2Id>D0VM3U05T0VM3U0@3oool006/0
VM3U102OMTT00`2LMDh0VM3U09W@i@0;09W@i@0309mfB@2iOdX0WgI90080`8EA00<0WgI909W@i@2I
d>D0402Id>D00`2OMTT0_8aK0;b<F`030;b<F`0309mfB@39U5l0bIAO00<0bIAO00<0WgI90;f;F`2m
Re/00`2mRe/00`2OMTT0aI5N09mfB@040<jGH@80WgI98P2Id>D209mfBAH0VM3U00<0WgI90=bSI`2O
MTT0103MXVL0102OMTT0j:][0>R[J`2OMTT60>NYJP0309mfB@3MXVH0gJ9V00@0gJ9V00<0WgI90>>V
J@2OMTT01@3/[F`209mfBBD0VM3U0P2OMTT00`23Fc`0WgI909W@i@0;09W@i@0309mfB@3m^g<0oK]c
0080oK]c0P2OMTT20?o5N00409mfB@3o_7<0okac0?nlL`80WgI90P3o`g@00`2OMTT0VM3U09W@i@0>
09W@i@0304@^8@2OMTT0WgI905/0VM3U0@3oool006/0VM3U102OMTT00`2LMDh0WgI909W@i@0<09W@
i@0509mfB@2iOdX0WgI90<25D@2OMTT04`2Id>D00`2OMTT0_8aK0;b<F`020;b<F`80WgI91@39U5l0
0`2OMTT0_H]K0;f;F`020;f;F`0309mfB@35TEh0WgI900D0cYMQ00<0WgI909W@i@2Id>D07`2Id>D3
09mfBAH0VM3U00<0WgI90=bSI`2OMTT0103MXVL0102OMTT0j:][0>R[J`2OMTT50>NYJP80WgI91@3M
XVH0102OMTT0hjIY0>>VJ@2OMTT50>b]K00309mfB@3`/6h0WgI902<0VM3U00D0WgI90:=bB@2OMTT0
Pe/l09mfB@0<09W@i@0309mfB@3m^g<0oK]c0080oK]c00D0WgI90?o5N03oaGP0olEh09mfB@030?nl
L`80WgI90P3o`g@00`2OMTT0VM3U09W@i@0=09W@i@0304@^8@2OMTT0WgI905`0VM3U0@3oool006`0
VM3U102OMTT00`2LMDh0VM3U09W@i@0;09W@i@0309mfB@2iOdX0WgI90080`8EA00<0WgI909W@i@2I
d>D0402Id>D00`2OMTT0_8aK0;b<F`020;b<F`80WgI91@39U5l00`2OMTT0_H]K0;f;F`030;f;F`03
09mfB@35TEh0WgI900@0cYMQ0P2OMTTP09W@i@80WgI900<0/Ga>09mfB@2Id>D04`2Id>D0102OMTT0
g:=W0=bSI`2OMTT40=fRI`0409mfB@3XZf/0j:][09mfB@D0ijUZ0`2OMTT40=fRIP0409mfB@3SYVT0
hjIY09mfB@D0k:e/00<0WgI90?2`KP2OMTT08`2Id>D01@2OMTT0Xg9909mfB@23Fc`0WgI900/0VM3U
00<0WgI90?fkL`3m^g<00P3m^g<01@2OMTT0olEh0?o5N03oaGP0WgI900@0okac00@0WgI90?o3M03o
`g@0WgI9402Id>D00`14;R40WgI909mfB@1L09W@i@40oooo001/09W@i@@0WgI90P2LMDh<09W@i@04
09mfB@2iOdX0^Gm:09mfB@80`8EA00<0WgI909W@i@2Id>D03`2Id>D00`2OMTT0_8aK0;b<F`020;b<
F`0309mfB@3<Uf40WgI900@0bIAO00<0WgI90;f;F`2mRe/00`2mRe/00`2OMTT0aI5N09mfB@040<jG
H@0309mfB@3BVV<0WgI901l0VM3U00@0WgI90<27E02OMTT0WgI9502Id>D0102OMTT0g:=W0=bSI`2O
MTT30=fRI`0509mfB@3XZf/0j:][0>R[J`2OMTT0103WZFX0102OMTT0jJa/09mfB@2OMTT40=fRIP04
09mfB@3SYVT0hjIY09mfB@D0k:e/00<0WgI90?2`KP2OMTT08P2Id>D00`2OMTT0Xg9909mfB@0208=K
?00309mfB@2Id>D0VM3U00P0VM3U00<0WgI90?fkL`3m^g<00`3m^g<01@2OMTT0olEh0?o5N03oaGP0
WgI900<0okac0P2OMTT20?o3M00309mfB@2Id>D0VM3U00d0VM3U00<0A2hQ09mfB@2OMTT0G@2Id>D1
0?ooo`00K@2Id>D409mfB@80W7E>302Id>D00`2OMTT0^Gm:09mfB@020<25D@0309mfB@2Id>D0VM3U
00l0VM3U00<0WgI90;b<F`2lS5/00P2lS5/00`2OMTT0c9MQ09mfB@050<VDG`0309mfB@2mRe/0_H]K
00<0_H]K00<0WgI90<FAGP2OMTT0103>Uf4209mfBAl0VM3U00@0WgI90<27E02OMTT0WgI9502Id>D0
102OMTT0g:=W0=bSI`2OMTT30=fRI`0509mfB@3XZf/0j:][0>R[J`2OMTT0103WZFX0102OMTT0jJa/
09mfB@2OMTT40=fRIP0409mfB@3SYVT0hjIY09mfB@@0k:e/00@0WgI90?2`KP3`/6h0WgI98P2Id>D0
0`2OMTT0Xg9909mfB@0208=K?00309mfB@2Id>D0VM3U00P0VM3U00<0WgI90?fkL`3m^g<00P3m^g<0
1@2OMTT0olEh0?o5N03oaGP0WgI900@0okac00D0WgI90?o3M03o`g@0ol=d09mfB@0>09W@i@80A2hQ
0P2OMTUM09W@i@40oooo001^09W@i@@0WgI900<0W7E>09W@i@2Id>D02P2Id>D0102OMTT0^Gm:0;Uo
BP2OMTT20<25D@0309mfB@2Id>D0VM3U00h0VM3U0P2OMTT40;b<F`0309mfB@3<Uf40WgI900@0bIAO
00<0WgI90;f;F`2mRe/00`2mRe/0102OMTT0aI5N0<FAGP2OMTT30<jGH@0309mfB@3BVV<0WgI901h0
VM3U00D0WgI90<27E02OMTT0/Ga>09mfB@0B09W@i@0509mfB@3LXfL0g:=W0=bSI`2OMTT00`3MXVL0
1@2OMTT0j:][0>R[J`3XZf/0WgI900@0ijUZ0P2OMTT00`3NXfL0WgI90=fRIP030=fRIP0409mfB@3S
YVT0hjIY09mfB@@0k:e/00@0WgI90?2`KP3`/6h0WgI98@2Id>D01P2OMTT0Xg990:=bB@2OMTT0Pe/l
09mfB@X0VM3U00<0WgI90?fkL`3m^g<00P3m^g<209mfB@<0olEh00@0WgI90?nlL`3o_7<0okac0P2O
MTT20?o3M00309mfB@2Id>D0VM3U00d0VM3U00<0A2hQ09mfB@2OMTT0GP2Id>D10?ooo`00KP2Id>D4
09mfB@80W7E>2`2Id>D0102OMTT0^Gm:0;UoBP2OMTT20<25D@0309mfB@2Id>D0VM3U00l0VM3U00<0
WgI90;b<F`2lS5/00P2lS5/00`2OMTT0c9MQ09mfB@040<VDG`80WgI9102mRe/0102OMTT0aI5N0<FA
GP2OMTT30<jGH@0409mfB@3BVV<0dYYS09mfBAd0VM3U00D0WgI90<27E02OMTT0/Ga>09mfB@0B09W@
i@0509mfB@3LXfL0g:=W0=bSI`2OMTT00P3MXVL00`2OMTT0j:][0>R[J`020>R[J`0909mfB@3WZFX0
ijUZ0>NYJP2OMTT0jJa/09mfB@3NXfL0WgI900@0gJ9V00D0WgI90>>VJ@3SYVT0hjIY09mfB@030>b]
K00409mfB@3`/6h0l;1^09mfBB40VM3U00<0WgI90:=bB@2OMTT00P23Fc`00`2OMTT0VM3U09W@i@07
09W@i@0309mfB@3m^g<0oK]c0080oK]c0P2OMTT30?o5N00309mfB@3o_7<0okac0080okac00D0WgI9
0?o3M03o`g@0ol=d09mfB@0>09W@i@0304@^8@2OMTT0WgI905l0VM3U0@3oool006l0VM3U102OMTT2
09aeCP/0VM3U00@0WgI90;UoBP2iOdX0WgI90P30QE400`2OMTT0VM3U09W@i@0>09W@i@80WgI90`2l
S5/00`2OMTT0c9MQ09mfB@040<VDG`80WgI91@2mRe/0102OMTT0aI5N0<FAGP2OMTT30<jGH@0409mf
B@3BVV<0dYYS09mfBA`0VM3U00D0WgI90<27E02OMTT0/Ga>09mfB@0A09W@i@0509mfB@3LXfL0g:=W
0=bSI`2OMTT00`3MXVL00`2OMTT0j:][0>R[J`020>R[J`0709mfB@3WZFX0ijUZ0>NYJP2OMTT0jJa/
09mfB@020=jSI`0509mfB@3MXVH0gJ9V0=fRIP2OMTT00`3SYVT01@2OMTT0k:e/0>b]K03/[F`0WgI9
0080l;1^00<0WgI909W@i@2Id>D07P2Id>D0102OMTT0Xg990:=bB@2OMTT208=K?00309mfB@2Id>D0
VM3U00H0VM3U0P2OMTT40?fkL`80WgI90`3oaGP0102OMTT0okac0?nlL`3o_7<209mfB@<0ol=d00<0
WgI909W@i@2Id>D0302Id>D204@^8@0309mfB@2Id>D0VM3U05d0VM3U0@3oool006l0VM3U102OMTT2
09aeCP/0VM3U00@0WgI90;UoBP2iOdX0WgI90`30QE400`2OMTT0VM3U09W@i@0=09W@i@80WgI90`2l
S5/0102OMTT0c9MQ0<bGH@2OMTT30<VDG`<0WgI9102mRe/0102OMTT0aI5N0<FAGP2OMTT30<jGH@04
09mfB@3BVV<0dYYS09mfBA/0VM3U00@0WgI90<27E030Qe@0WgI90P2aO4h00`2OMTT0VM3U09W@i@0>
09W@i@0509mfB@3LXfL0g:=W0=bSI`2OMTT00`3MXVL00`2OMTT0j:][0>R[J`020>R[J`0409mfB@3W
ZFX0ijUZ09mfB@80jJa/00@0WgI90=jSI`3NXfL0WgI90`3MXVH01@2OMTT0hjIY0>>VJ@3SYVT0WgI9
00<0k:e/00@0WgI90?2`KP3`/6h0WgI9802Id>D0102OMTT0Xg990:=bB@2OMTT208=K?00309mfB@2I
d>D0VM3U00H0VM3U00<0WgI90?fkL`3m^g<00P3m^g<209mfB@<0olEh00<0WgI90?nlL`3o_7<00P3o
_7<01@2OMTT0ol=d0?o3M03o`g@0WgI900h0VM3U00<0A2hQ09mfB@2OMTT0H02Id>D10?ooo`00L02I
d>D409mfB@80W7E>2P2Id>D0102OMTT0^Gm:0;UoBP2OMTT30<25D@0309mfB@2Id>D0VM3U00d0VM3U
00<0WgI90;b=G02OMTT00P2lS5/0102OMTT0c9MQ0<bGH@2OMTT40<VDG`<0WgI90`2mRe/01@2OMTT0
aI5N0<FAGP35TEh0WgI90080cYMQ00D0WgI90=:JH`3BVV<0dYYS09mfB@0J09W@i@0409mfB@30Qe@0
`8MD09mfB@80/Ga>00<0WgI909W@i@2Id>D03P2Id>D01@2OMTT0g:=W0=bSI`3LXfL0WgI90080gJ9W
00<0WgI90>R[J`3XZf/00`3XZf/0102OMTT0ijUZ0>NYJP2OMTT20>V/K00409mfB@3NXfL0gZ=W09mf
B@80gJ9V00<0WgI90>>VJ@3SYVT00P3SYVT0102OMTT0k:e/0>b]K02OMTT40?2`KP0309mfB@2Id>D0
VM3U01`0VM3U00D0WgI90:=bB@2SLTT0Xg9909mfB@0208=K?00309mfB@2Id>D0VM3U00D0VM3U0P2O
MTT30?fkL`0309mfB@3oaWT0WgI900<0olEh00@0WgI90?nlL`3o_7<0okac0P2OMTT30?o3M00309mf
B@2Id>D0VM3U00`0VM3U00<0A2hQ09mfB@2OMTT0H02Id>D10?ooo`00L@2Id>D409mfB@80W7E>2P2I
d>D0102OMTT0^Gm:0;UoBP2OMTT30<25D@0309mfB@2Id>D0VM3U00d0VM3U0P2OMTT30;b<F`0409mf
B@3<Uf40c9MQ09mfB@<0bIAO0P2OMTT00`2nSU`0WgI90;f;F`020;f;F`0509mfB@35TEh0aI5N0<FA
GP2OMTT00P3>Uf401@2OMTT0dYYS0=:JH`3BVV<0WgI901T0VM3U00@0WgI90<27E030Qe@0WgI90P2a
O4h00`2OMTT0VM3U09W@i@0=09W@i@0309mfB@3LXfL0g:=W0080g:=W00@0WgI90=fRI`3MXVL0WgI9
1@3XZf/0102OMTT0ijUZ0>NYJP2OMTT20>V/K00409mfB@3NXfL0gZ=W09mfB@80gJ9V00<0WgI90>>V
J@3SYVT00P3SYVT0102OMTT0k:e/0>b]K02OMTT40?2`KP0309mfB@2Id>D0VM3U01`0VM3U00@0WgI9
0:=bB@2SLTT0WgI90`23Fc`00`2OMTT0VM3U09W@i@0409W@i@80WgI90`3m^g<00`2OMTT0olIi09mf
B@030?o5N00309mfB@3o_7<0okac0080okac00D0WgI90?o3M03o`g@0ol=d09mfB@0>09W@i@0304@^
8@2OMTT0WgI90640VM3U0@3oool00740VM3U102OMTT309aeCPT0VM3U00@0WgI90;UoBP2iOdX0WgI9
0`30QE400`2OMTT0VM3U09W@i@0=09W@i@80WgI90`2lS5/0102OMTT0c9MQ0<bGH@2OMTT30<VDG`80
WgI900<0_XiL09mfB@2mRe/00P2mRe/01@2OMTT0aI5N0<FAGP35TEh0WgI90080cYMQ00D0WgI90=:J
H`3BVV<0dYYS09mfB@0I09W@i@0409mfB@30Qe@0`8MD09mfB@80/Ga>00<0WgI909W@i@2Id>D03@2I
d>D00`2OMTT0g:=W0=bSI`020=bSI`0409mfB@3MXVL0gJ9W09mfB@D0j:][00<0WgI90>NYJP2OMTT0
0`3Y[6`0102OMTT0gZ=W0=jSI`2OMTT20=fRIP0309mfB@3SYVT0hjIY0080hjIY00@0WgI90>b]K03/
[F`0WgI9103`/6h00`2OMTT0VM3U09W@i@0K09W@i@0509mfB@2SLTT0Xg990:=bB@2OMTT00`23Fc`0
0`2OMTT0VM3U09W@i@0309W@i@0309mfB@3k^W<0WgI900<0oK]c00<0WgI90?o6N@2OMTT00`3oaGP0
102OMTT0okac0?nlL`3o_7<209mfB@<0ol=d00<0WgI909W@i@2Id>D0302Id>D209mfBF80VM3U0@3o
ool00780VM3U00@0WgI908QXB02OMTT0WgI90P2LMDh909W@i@80WgI90P2iOdX01@2OMTT0`8EA0<25
D@30QE40WgI900h0VM3U00<0WgI90;b=G02OMTT00P2lS5/01@2OMTT0c9MQ0<bGH@3<Uf40WgI90080
bIAO00D0WgI90<fGH@2OMTT0_XiL09mfB@020;f;F`0309mfB@35TEh0aI5N0080aI5N00@0WgI90<jG
H@3>Uf40WgI90`3BVV<00`2OMTT0VM3U09W@i@0F09W@i@0409mfB@30Qe@0`8MD09mfB@<0/Ga>00<0
WgI909W@i@2Id>D0302Id>D00`2OMTT0g:=W0=bSI`020=bSI`0309mfB@3MXVL0WgI900D0j:][00@0
WgI90>NYJP3WZFX0WgI90`3Y[6`01`2OMTT0gZ=W0=jSI`3NXfL0WgI90=fRIP2OMTT0103SYVT0102O
MTT0k:e/0>b]K02OMTT40?2`KP0309mfB@2Id>D0VM3U01/0VM3U00D0WgI90:=bB@2SLTT0Xg9909mf
B@0308=K?00309mfB@2Id>D0VM3U0080VM3U00<0WgI90?^jL`2OMTT00`3m^g<00`2OMTT0olIi09mf
B@030?o5N080WgI90P3o_7<00`2OMTT0ol5g09mfB@020?o3M080WgI93@2Id>D00`14;R40WgI909mf
B@1R09W@i@40oooo001b09W@i@@0WgI90`2LMDh909W@i@0409mfB@2iOdX0^Gm:09mfB@<0`8EA00<0
WgI909W@i@2Id>D0302Id>D00`2OMTT0_8eL09mfB@020;b<F`0509mfB@3<Uf40c9MQ0<bGH@2OMTT0
0P39U5l00`2OMTT0cIMQ09mfB@020;j>G00409mfB@2mRe/0_H]K09mfB@@0aI5N00<0WgI90<jGH@2O
MTT0103BVV<00`2OMTT0VM3U09W@i@0E09W@i@0409mfB@30Qe@0`8MD09mfB@<0/Ga>00<0WgI909W@
i@2Id>D02`2Id>D00`2OMTT0g:=W0=bSI`030=bSI`0309mfB@3MXVL0WgI900D0j:][00<0WgI90>NY
JP2OMTT0103Y[6`01`2OMTT0gZ=W0=jSI`3NXfL0WgI90=fRIP2OMTT0103SYVT0102OMTT0k:e/0>b]
K02OMTT40?2`KP0309mfB@2Id>D0VM3U01X0VM3U00D0WgI90:=bB@2SLTT0Xg9909mfB@0408=K?005
09mfB@2Id>D0VM3U09W@i@2OMTT00P3k^W<0102OMTT0oK]c0?fkL`2OMTT20?o6N@0309mfB@3oaGP0
olEh0080WgI90`3o_7<209mfB@<0ol=d00<0WgI909W@i@2Id>D02`2Id>D00`1C=bL0WgI909mfB@1S
09W@i@40oooo001c09W@i@0409mfB@28J4P0WgI909mfB@<0W7E>202Id>D209mfB@80^Gm:00D0WgI9
0<25D@30QE40`8EA09mfB@0=09W@i@0409mfB@2lSE`0_8eL09mfB@80_8aK00L0WgI90<bGH@3<Uf40
c9MQ09mfB@39U5l0WgI90080cIMQ00<0WgI90;j>G02OMTT00P2mRe/00`2OMTT0aI5N0<FAGP020<FA
GP0309mfB@3>Uf40WgI900@0dYYS00<0WgI909W@i@2Id>D0502Id>D00`2OMTT0`8MD0<27E0020<27
E00409mfB@2aO4h0/Ga>09mfB@d0VM3U00<0WgI90=bSI`3LXfL00`3LXfL00`2OMTT0gJ9W09mfB@05
0>R[J`0309mfB@3WZFX0WgI900@0jJa/00L0WgI90=jSI`3NXfL0gZ=W09mfB@3MXVH0WgI900@0hjIY
00<0WgI90>b]K02OMTT01@3`/6h00`2OMTT0VM3U09W@i@0J09W@i@0509mfB@2SLTT0Xg990:=bB@2O
MTT01023Fc`01`2OMTT0VM3U09W@i@2Id>D0WgI90?^jL`2OMTT00P3m^g<0102OMTT0olIi0?o6N@2O
MTT30?o5N080WgI90P3o_7<00`2OMTT0ol5g09mfB@020?o3M080WgI9302Id>D0101C=bL0WgI909mf
B@2OMTUS09W@i@40oooo001c09W@i@<0WgI900@0Dd0`09mfB@2LMDh0W7E>202Id>D209mfB@80^Gm:
00@0WgI90<25D@30QE40`8EA0P2OMTT=09W@i@0309mfB@2lSE`0WgI90080_8aK00D0WgI90<bGH@3<
Uf40c9MQ09mfB@020<VDG`0309mfB@3=Uf40WgI90080_XiL00<0WgI90;f;F`2OMTT01@35TEh00`2O
MTT0cYMQ09mfB@040=:JH`0309mfB@2Id>D0VM3U01<0VM3U00<0WgI90<27E030Qe@00P30Qe@01@2O
MTT0/Ga>0;5lCP2aO4h0WgI900/0VM3U00<0WgI90=bSI`3LXfL0103LXfL209mfB@H0j:][00<0WgI9
0>NYJP2OMTT00`3Y[6`00`2OMTT0gZ=W0=jSI`020=jSI`0309mfB@3MXVH0WgI900@0hjIY00<0WgI9
0>b]K02OMTT01@3`/6h00`2OMTT0VM3U09W@i@0I09W@i@0309mfB@2SLTT0Xg990080Xg9900D0WgI9
08=K?023Fc`0Pe/l09mfB@0309W@i@0409mfB@3k^W<0nkYc09mfB@80oK]c00@0WgI90?o6N@3oaWT0
WgI90P3oaGP309mfB@80okac0P2OMTT30?o3M00309mfB@2Id>D0VM3U00/0VM3U00<0A2hQ09mfB@2O
MTT0I02Id>D10?ooo`00M02Id>D00`2OMTT0R6Q809mfB@0209mfB@0309aeCP2OMTT0VM3U00L0VM3U
0P2OMTT20;UoBP0509mfB@30QE40`8EA0<25D@2OMTT03@2Id>D01P2OMTT0_8eL0;b=G02OMTT0_8aK
09mfB@<0c9MQ00@0WgI90<VDG`39U5l0WgI90P3=Uf401P2OMTT0_XiL0;j>G02OMTT0_H]K09mfB@@0
aI5N00<0WgI90<jGH@2OMTT01@3BVV<00`2OMTT0VM3U09W@i@0B09W@i@0309mfB@30Qe@0`8MD0080
`8MD00D0WgI90;5lCP2aO4h0/Ga>09mfB@0;09W@i@0309mfB@3LXfL0g:=W00@0g:=W0P2OMTT60>R[
J`80WgI9103Y[6`00`2OMTT0gZ=W0=jSI`020=jSI`80WgI91P3SYVT209mfB@D0l;1^00<0WgI909W@
i@2Id>D06@2Id>D01@2OMTT0Xg990:=bB@2SLTT0WgI900@0Pe/l00@0WgI909W@i@2Id>D0WgI90P3k
^W<0102OMTT0oK]c0?fkL`2OMTT20?o6N@0309mfB@3oaGP0olEh00<0WgI90P3o_7<00`2OMTT0ol5g
09mfB@020?o3M080WgI9302Id>D00`1C=bL0WgI909mfB@1U09W@i@40oooo001e09W@i@80WgI900D0
Dd0`09mfB@2LMDh0W7E>09mfB@0709W@i@80WgI90P2iOdX0102OMTT0`8EA0<25D@30QE4209mfB@`0
VM3U00H0WgI90;b=G02lSE`0WgI90;b<F`2OMTT40<bGH@0309mfB@39U5l0WgI90080cIMQ00H0WgI9
0;j>G02nSU`0WgI90;f;F`2OMTT50<FAGP80WgI91@3BVV<00`2OMTT0VM3U09W@i@0B09W@i@0309mf
B@30Qe@0`8MD0080`8MD00D0WgI90;5lCP2aO4h0/Ga>09mfB@0;09W@i@0309mfB@3LXfL0g:=W00@0
g:=W0P2OMTT60>R[J`80WgI9103Y[6`00`2OMTT0gZ=W0=jSI`030=jSI`0309mfB@3SYVT0hjIY00@0
hjIY0P2OMTT60?2`KP0309mfB@2Id>D0VM3U01L0VM3U00<0WgI90:=bB@2SLTT00P2SLTT00`2OMTT0
Pe/l08=K?00208=K?00309mfB@2Id>D0WgI900<0nkYc00<0WgI90?fkL`2OMTT00`3oaWT0102OMTT0
olEh09mfB@3oagT209mfB@040?nlL`2OMTT0ol5g09mfB@80ol=d0P2OMTT<09W@i@0405<g9`2OMTT0
WgI909mfBFD0VM3U0@3oool007D0VM3U0`2OMTT00`1C@300WgI909aeCP0209mfB@L0VM3U0P2OMTT0
0`2iOdX0WgI909mfB@030<25D@80WgI92`2Id>D0102OMTT0_8eL0;b=G02lSE`209mfB@@0c9MQ00<0
WgI90<VDG`2OMTT00P3=Uf401`2OMTT0_XiL0;j>G02nSU`0WgI90;f;F`2OMTT01@35TEh209mfB@D0
dYYS00<0WgI909W@i@2Id>D04@2Id>D00`2OMTT0`8MD0<27E0020<27E00309mfB@2aO4h0/Ga>0080
/Ga>00<0WgI909W@i@2Id>D01`2Id>D00`2OMTT0g:=W0=bSI`050=bSI`0309mfB@3XZf/0j:][00D0
j:][00<0WgI90>V/K03Y[6`00`3Y[6`00`2OMTT0gZ=W0=jSI`030=jSI`0309mfB@3SYVT0hjIY00@0
hjIY0P2OMTT60?2`KP0309mfB@2Id>D0VM3U01L0VM3U00<0WgI90:=bB@2SLTT00P2SLTT00`2OMTT0
Pe/l08=K?00208=K?080WgI90`3k^W<0102OMTT0oK]c0?fkL`2OMTT20?o6N@0309mfB@3oaGP0olEh
00<0WgI90P3o_7<00`2OMTT0ol5g09mfB@020?o3M080WgI9302Id>D00`1C=bL0WgI909mfB@1V09W@
i@40oooo001f09W@i@0309mfB@28J4P0WgI90080WgI900<0W7E>09mfB@2OMTT01P2Id>D209mfB@80
^Gm:00@0WgI90<25D@30QE40`8EA0P2OMTT;09W@i@0709mfB@2lSE`0_8eL0;b=G02OMTT0_8aK09mf
B@040<bGH@80WgI90`3=Uf40102OMTT0_XiL0;j>G02nSU`209mfB@D0aI5N0P2OMTT60=:JH`0309mf
B@2Id>D0VM3U0100VM3U00<0WgI90<27E030Qe@00P30Qe@00`2OMTT0/Ga>0;5lCP020;5lCP0309mf
B@2Id>D0VM3U00L0VM3U00<0WgI90=bSI`3LXfL01@3LXfL00`2OMTT0j:][0>R[J`050>R[J`0309mf
B@3Y[6`0jJa/00<0jJa/00<0WgI90=jSI`3NXfL00`3NXfL00`2OMTT0hjIY0>>VJ@040>>VJ@0309mf
B@3`/6h0l;1^00D0l;1^00<0WgI909W@i@2Id>D05P2Id>D00`2OMTT0Xg990:=bB@030:=bB@0309mf
B@23Fc`0Pe/l0080Pe/l0P2OMTT30?^jL`0309mfB@3m^g<0WgI900<0olIi00P0WgI90?o5N02OMTT0
WgI90?nlM02OMTT0okac09mfB@80ol5g00D0WgI90?o3M02OMTT0ol9d09mfB@0;09W@i@0405<g9`2O
MTT0WgI909mfBFH0VM3U0@3oool007H0VM3U0`2OMTT01@1C@300WgI909mfB@2LMDh0WgI900H0VM3U
00@0WgI909YW>@2OMTT0^Gm:0P2OMTT30<25D@80WgI92`2Id>D01P2OMTT0_8eL0;b=G02OMTT0_8aK
09mfB@@0c9MQ0P2OMTT30<fGH@0309mfB@2nSU`0_XiL0080_XiL00<0WgI90<FAGP35TEh01035TEh0
0`2OMTT0dYYS0=:JH`040=:JH`0309mfB@2Id>D0VM3U0100VM3U00<0WgI90<27E030Qe@00P30Qe@0
0`2OMTT0/Ga>0;5lCP020;5lCP0309mfB@2Id>D0VM3U00L0VM3U00<0WgI90=bSI`3LXfL01@3LXfL0
0`2OMTT0j:][0>R[J`050>R[J`0309mfB@3Y[6`0jJa/00<0jJa/00<0WgI90=jSI`3NXfL00`3NXfL0
0`2OMTT0hjIY0>>VJ@040>>VJ@0309mfB@3`/6h0l;1^00D0l;1^00<0WgI909W@i@2Id>D05P2Id>D0
0`2OMTT0Xg990:=bB@020:=bB@0309mfB@23Fc`0Pe/l00<0Pe/l00L0WgI90?^jL`3k^W<0nkYc09mf
B@3m^g<0WgI900<0olIi00l0WgI90?o5N02OMTT0olMi09mfB@3o_7@0WgI90?nlL`2OMTT0ol5g09mf
B@3o`g@0WgI90?o2M02OMTT02`2Id>D205<g9`80WgI9I`2Id>D10?ooo`00M`2Id>D0101C@300WgI9
09mfB@1C@30309mfB@030:MmD`2Id>D0VM3U00@0VM3U0P2OMTT0102iOdX0WgI909mfB@2OMTT20<25
D@0309mfB@2gOT`0WgI900X0VM3U00@0WgI90;b=G02lSE`0_8eL0P2OMTT50<bGH@80WgI90`3=Uf40
102OMTT0_XiL0;j>G02nSU`209mfB@D0aI5N0P2OMTT60=:JH`0309mfB@2Id>D0VM3U00h0VM3U00<0
WgI90<27E030Qe@00`30Qe@00`2OMTT0/Ga>0;5lCP030;5lCP0309mfB@2Id>D0VM3U00D0VM3U00<0
WgI90=bSI`3LXfL01@3LXfL209mfB@H0j:][0P2OMTT50>V/K00309mfB@3NXfL0gZ=W00<0gZ=W00<0
WgI90>>VJ@3SYVT0103SYVT00`2OMTT0l;1^0?2`KP050?2`KP0309mfB@2Id>D0VM3U01D0VM3U0P2O
MTT40:=bB@0309mfB@23Fc`0Pe/l0080Pe/l00<0WgI90?^jL`3k^W<00P3k^W<209mfB@@0olIi0P2O
MTT01P3oagT0WgI90?nlM02OMTT0okac09mfB@80ol5g00D0WgI90?o3M02OMTT0ol9d09mfB@0;09W@
i@0305<g9`2OMTT0WgI906P0VM3U0@3oool007L0VM3U0`2OMTT205=0<0@0WgI91@2Id>D0102OMTT0
VVLi09mfB@2iOdX209mfB@<0`8EA0P2OMTT:09W@i@0409mfB@2lSE`0_8eL0;b=G080WgI91@3<Uf42
09mfB@<0cIMQ00<0WgI90;j>G02nSU`00P2nSU`00`2OMTT0aI5N0<FAGP040<FAGP0309mfB@3BVV<0
dYYS00D0dYYS00<0WgI909W@i@2Id>D03@2Id>D00`2OMTT0`8MD0<27E0030<27E00309mfB@2aO4h0
/Ga>00<0/Ga>00<0WgI909W@i@2Id>D01@2Id>D00`2OMTT0g:=W0=bSI`050=bSI`80WgI91P3XZf/2
09mfB@D0jJa/00<0WgI90=jSI`3NXfL00`3NXfL00`2OMTT0hjIY0>>VJ@040>>VJ@0309mfB@3`/6h0
l;1^00D0l;1^00<0WgI909W@i@2Id>D05@2Id>D00`2OMTT0Xg990:=bB@030:=bB@0509mfB@23Fc`0
Pe/l08=K?02OMTT0103k^W<00`2OMTT0oK]c09mfB@030?o6N@0?09mfB@3oaGP0WgI90?o7N@2OMTT0
okad09mfB@3o_7<0WgI90?o1M`2OMTT0ol=d09mfB@3o`W@0WgI900/0VM3U00@0DcLW09mfB@2OMTT0
WgI9J02Id>D10?ooo`00N02Id>D309mfB@0405=0<02OMTT0WgI909aeCP80WgI9102Id>D0102OMTT0
VVLi09mfB@2iOdX309mfB@80`8EA00<0WgI90;MnC02OMTT02@2Id>D00`2OMTT0_8eL0;b=G0020;b=
G00309mfB@3<Uf40c9MQ00@0c9MQ00D0WgI90<fGH@3=Uf40cIMQ09mfB@040;j>G080WgI91@35TEh2
09mfB@L0dYYS00<0WgI909W@i@2Id>D0302Id>D00`2OMTT0`8MD0<27E0030<27E00309mfB@2aO4h0
/Ga>00<0/Ga>00<0WgI909W@i@2Id>D0102Id>D00`2OMTT0g:=W0=bSI`050=bSI`0309mfB@3VZF/0
WgI900H0j:][0P2OMTT50>V/K00309mfB@3NXfL0gZ=W0080gZ=W00<0WgI90>BXJP2OMTT01@3SYVT0
0`2OMTT0l;1^0?2`KP050?2`KP0309mfB@2Id>D0VM3U01@0VM3U0P2OMTT40:=bB@0509mfB@23Fc`0
Pe/l08=K?02OMTT01@3k^W<209mfB@@0olIi0P2OMTT0103oagT0WgI90?nlM03o_7@209mfB@80ol5g
00D0WgI90?o3M02OMTT0ol9d09mfB@0:09W@i@80DcLW0P2OMTUY09W@i@40oooo001i09W@i@<0WgI9
00@0Dd0`09mfB@2OMTT0W7E>0P2OMTT409W@i@0509mfB@2JIcT0WgI909mfB@2nPdl00P2OMTT20<25
D@0309mfB@2gOT`0WgI900T0VM3U00@0WgI90;b=G02lSE`0_8eL0P2OMTT50<bGH@0309mfB@3=Uf40
cIMQ0080cIMQ00<0WgI90;j>G02nSU`00P2nSU`00`2OMTT0aI5N0<FAGP040<FAGP0309mfB@3BVV<0
dYYS00D0dYYS00<0WgI909W@i@2Id>D0302Id>D00`2OMTT0`8MD0<27E0040<27E00309mfB@2aO4h0
/Ga>00<0/Ga>00<0WgI909W@i@2Id>D00`2Id>D00`2OMTT0g:=W0=bSI`050=bSI`0309mfB@3VZF/0
WgI900D0j:][00<0WgI90>^^K@2OMTT01@3Y[6`00`2OMTT0gZ=W0=jSI`020=jSI`0309mfB@3TZ6X0
WgI900@0hjIY0P2OMTT70?2`KP0309mfB@2Id>D0VM3U01@0VM3U00<0YG=:09mfB@2SLTT00`2SLTT0
1@2OMTT0Pe/l08=K?023Fc`0WgI900@0nkYc0P2OMTT40?o6N@80WgI90P3oagT0102OMTT0okad09mf
B@2OMTT20?o1M`0509mfB@3o`g@0WgI90?o2M02OMTT02P2Id>D205<g9`<0WgI9J@2Id>D10?ooo`00
N@2Id>D409mfB@0605=0<02OMTT0WgI909mfB@2WOE<0WgI90`2Id>D0102OMTT0VVLi09mfB@2iOdX3
09mfB@80`8EA00<0WgI90;MnC02OMTT02@2Id>D00`2OMTT0_8eL0;b=G0020;b=G00309mfB@3<Uf40
c9MQ00<0c9MQ00<0WgI90<fGH@3=Uf400P3=Uf400`2OMTT0_XiL0;j>G0020;j>G080WgI91@35TEh2
09mfB@L0dYYS00<0WgI909W@i@2Id>D02`2Id>D00`2OMTT0`8MD0<27E0040<27E00309mfB@2aO4h0
/Ga>00<0/Ga>00<0WgI909W@i@2Id>D00`2Id>D00`2OMTT0g:=W0=bSI`050=bSI`0309mfB@3VZF/0
WgI900D0j:][0P2OMTT50>V/K00309mfB@3NXfL0gZ=W00<0gZ=W00<0WgI90>BXJP2OMTT0103SYVT0
0`2OMTT0j:]/09mfB@070?2`KP0309mfB@2Id>D0VM3U0180VM3U0P2OMTT40:=bB@80WgI90P23Fc`0
0`2OMTT0nkYc0?^jL`030?^jL`0309mfB@3oaWT0olIi00<0olIi00@0WgI90?o7N@3oagT0WgI90P3o
_7@209mfB@80ol5g0P2OMTT20?o2M00309mfB@2Id>D0VM3U00P0VM3U0P1C=bL209mfBFX0VM3U0@3o
ool007X0VM3U1@2OMTT01@1_Ech0WgI909mfB@2WOE<0WgI90080VM3U00<0WgI909YW>@2JIcT00P2O
MTT01@2nPdl0WgI909mfB@30QE40WgI90080]gi<00<0WgI909W@i@2Id>D01P2Id>D00`2OMTT0_8eL
0;b=G0020;b=G00309mfB@3<Uf40c9MQ00<0c9MQ0P2OMTT40<fGH@0309mfB@2nSU`0_XiL0080_XiL
0P2OMTT40<FAGP0309mfB@3<Uf40WgI900L0dYYS00<0WgI909W@i@2Id>D02P2Id>D00`2OMTT0`8MD
0<27E0040<27E00309mfB@2aO4h0/Ga>00<0/Ga>00<0WgI909W@i@2Id>D00P2Id>D00`2OMTT0g:=W
0=bSI`050=bSI`0409mfB@3VZF/0iZU[09mfB@@0j:][00<0WgI90>^^K@2OMTT01@3Y[6`00`2OMTT0
gZ=W0=jSI`030=jSI`0309mfB@3TZ6X0WgI900@0hjIY00<0WgI90>R[K02OMTT01`3`/6h00`2OMTT0
VM3U09W@i@0A09W@i@0309mfB@2ULdX0WgI900@0Xg990P2OMTT00`23Fc`0WgI90?^jL`040?^jL`80
WgI9103oaWT209mfB@040?o7N@2OMTT0okad0?nlM080WgI90`3o`GL209mfB@030?o2M02OMTT0VM3U
00T0VM3U0P1C=bL209mfBF/0VM3U0@3oool007/0VM3U0`2OMTT00`1C@300WgI906mG?P0209mfB@08
0:MmD`2OMTT0VM3U09W@i@2OMTT0VVLi09mfB@2iOdX209mfB@040:Yc@P2OMTT0`8EA09mfB@80]gi<
00<0WgI909W@i@2Id>D01@2Id>D00`2OMTT0_8eL0;b=G0020;b=G080WgI91@3<Uf400`2OMTT0cIMQ
0<fGH@020<fGH@0309mfB@2nSU`0_XiL0080_XiL0P2OMTT50<FAGP0309mfB@3<Uf40WgI900H0dYYS
00<0WgI909W@i@2Id>D02@2Id>D209mfB@H0`8MD00<0WgI90;5lCP2aO4h00`2aO4h209mfB@<0VM3U
00<0WgI90=bSI`3LXfL01@3LXfL0102OMTT0iZU[0>JYJ`2OMTT40>R[J`0309mfB@3[[Vd0WgI900D0
jJa/00<0WgI90=jSI`3NXfL00`3NXfL00`2OMTT0i:QZ09mfB@040>>VJ@0309mfB@3XZf`0WgI900L0
l;1^00<0WgI909W@i@2Id>D04@2Id>D00`2OMTT0YG=:09mfB@030:=bB@@0WgI91P3k^W<00`2OMTT0
olIi0?o6N@030?o6N@0409mfB@3oagT0olMi09mfB@80okad0P2OMTT20?o1M`80WgI90P3o`W@00`2O
MTT0VM3U09W@i@0709W@i@80DcLW0`2OMTU[09W@i@40oooo001l09W@i@<0WgI900H0Dd0`09mfB@2O
MTT0WgI90:MmD`2OMTT209W@i@0309mfB@2JIcT0VVLi0080WgI900<0_X=?09mfB@2ZLd800P2OMTT2
0;MnC00309mfB@2Id>D0VM3U00D0VM3U00<0WgI90;b=G02lSE`00`2lSE`00`2OMTT0c9MQ0<bGH@03
0<bGH@80WgI9103=Uf401`2OMTT0_XiL0;j>G02nSU`0WgI90<JCG`2OMTT01035TEh00`2OMTT0c9MQ
09mfB@070=:JH`0309mfB@2Id>D0VM3U00P0VM3U00<0WgI90;n6D`2OMTT01@30Qe@00`2OMTT0/Ga>
0;5lCP030;5lCP80WgI90`2Id>D00`2OMTT0g:=W0=bSI`040=bSI`0509mfB@3VZF/0iZU[0>JYJ`2O
MTT0103XZf/00`2OMTT0jji]09mfB@050>V/K00309mfB@3NXfL0gZ=W00<0gZ=W00<0WgI90>BXJP2O
MTT0103SYVT00`2OMTT0j:]/09mfB@070?2`KP0309mfB@2Id>D0VM3U0100VM3U00<0WgI90:EcBP2O
MTT00`2SLTT209mfB@0309EW@`2OMTT0nkYc00D0nkYc00<0WgI90?o6N@3oaWT00`3oaWT0102OMTT0
olMi0?o7N@2OMTT30?nlM00509mfB@3o`GL0ol5g0?o1M`2OMTT00`3o`W@00`2OMTT0VM3U09W@i@07
09W@i@0405<g9`2OMTT0WgI909mfBF`0VM3U0@3oool007`0VM3U1@2OMTT01`1_Ech0WgI909mfB@2W
OE<0WgI909W@i@2OMTT00P2JIcT209mfB@060;j3C`2OMTT0ZW=209mfB@30QE40WgI90P2gOT`00`2O
MTT0VM3U09W@i@0509W@i@0309mfB@2lSE`0_8eL0080_8eL0P2OMTT40<bGH@80WgI9103=Uf400`2O
MTT0_XiL0;j>G0020;j>G00309mfB@36Tel0WgI900<0aI5N00@0WgI90<bGH@3<Uf40WgI91P3BVV<2
09mfB@T0VM3U00<0WgI90;n6D`2OMTT01@30Qe@00`2OMTT0/Ga>0;5lCP030;5lCP0409mfB@2[Md/0
WgI909W@i@80WgI91P3LXfL01@2OMTT0iZU[0>JYJ`3VZF/0WgI900<0j:][00@0WgI90>^^K@3[[Vd0
WgI91@3Y[6`00`2OMTT0gZ=W0=jSI`020=jSI`0409mfB@3TZ6X0i:QZ09mfB@<0hjIY00@0WgI90>R[
K03XZf`0WgI91`3`/6h00`2OMTT0VM3U09W@i@0@09W@i@0309mfB@2ULdX0WgI900<0Xg990`2OMTT6
0?^jL`80WgI9103oaWT01@2OMTT0olMi0?o7N@3oagT0WgI90080okad0P2OMTT20?o1M`80WgI90P3o
`W@00`2OMTT0VM3U09W@i@0709W@i@80DcLW0P2OMTU]09W@i@40oooo001m09W@i@D0WgI900L0KeLn
09mfB@2OMTT0YgeC09mfB@2Id>D0WgI90080VVLi0P2OMTT00`2nPdl0WgI90:Yc@P0209mfB@<0]gi<
00<0WgI909W@i@2Id>D0102Id>D00`2OMTT0_8eL0;b=G0020;b=G080WgI9103<Uf400`2OMTT0d9YS
09mfB@030<fGH@0309mfB@2nSU`0_XiL0080_XiL00<0WgI90<JCG`2OMTT01035TEh0102OMTT0c9MQ
0<bGH@2OMTT60=:JH`80WgI9202Id>D00`2OMTT0_hIC09mfB@050<27E00309mfB@2aO4h0/Ga>00<0
/Ga>00@0WgI90:]gB`2OMTT0VM3U0P2OMTT60=bSI`0509mfB@3VZF/0iZU[0>JYJ`2OMTT00`3XZf/0
102OMTT0jji]0>^^K@2OMTT50>V/K00309mfB@3NXfL0gZ=W0080gZ=W00@0WgI90>BXJP3TZ6X0WgI9
0`3SYVT0102OMTT0j:]/0>R[K02OMTT70?2`KP0309mfB@2Id>D0VM3U00l0VM3U00@0WgI90:EcBP2U
LdX0WgI90P2SLTT0102OMTT0QE`l09mfB@2OMTT50?^jL`80WgI9103oaWT209mfB@80olMi00D0WgI9
0?nlM03o_7@0okad09mfB@030?o1M`0509mfB@3o`W@0ol9d0?o2M02OMTT0202Id>D205<g9`<0WgI9
K@2Id>D10?ooo`00OP2Id>D509mfB@0406mG?P2OMTT0YgeC0:MmD`80WgI90P2JIcT209mfB@80_X=?
00@0WgI90:Yc@P2OMTT0WgI90P2gOT`00`2OMTT0VM3U09W@i@0409W@i@0309mfB@2lSE`0_8eL0080
_8eL00<0WgI90<ZFH@2OMTT0103<Uf4209mfB@@0cIMQ00<0WgI90;j>G02nSU`00P2nSU`00`2OMTT0
aY=O09mfB@030<FAGP0509mfB@3<Uf40c9MQ0<bGH@2OMTT01@3BVV<00`2OMTT0eYeT09W@i@0709W@
i@0309mfB@2oQU<0WgI900@0`8MD0`2OMTT40;5lCP0609mfB@2[Md/0WgI909mfB@3JXVL0WgI91@3L
XfL00`2OMTT0iZU[0>JYJ`020>JYJ`0509mfB@3XZf/0j:][0>R[J`2OMTT00P3[[Vd00`2OMTT0jJa/
0>V/K0020>V/K080WgI9103NXfL01@2OMTT0i:QZ0>BXJP3TZ6X0WgI90080hjIY00D0WgI90>R[K03X
Zf`0j:]/09mfB@050?2`KP80WgI9402Id>D0102OMTT0YG=:0:EcBP2OMTT20:=bB@0409mfB@25G3`0
WgI909mfB@D0nkYc00<0WgI90?o3N02OMTT00`3oaWT209mfB@<0olMi00<0WgI90?nlM03o_7@00P2O
MTT20?o1M`80WgI90P3o`W@00`2OMTT0VM3U09W@i@0709W@i@0405<g9`2OMTT0WgI909mfBFh0VM3U
0@3oool007h0VM3U1P2OMTT0101_Ech0WgI90:MmD`2WOE<209mfB@80VVLi00D0WgI90;j3C`2nPdl0
WgI90:Yc@P0209mfB@<0]gi<00<0WgI909W@i@2Id>D00`2Id>D00`2OMTT0_8eL0;b=G0030;b=G080
WgI9103<Uf400`2OMTT0d9YS09mfB@030<fGH@0309mfB@2nSU`0_XiL0080_XiL00@0WgI90<JCG`36
Tel0WgI90P35TEh01@2OMTT0c9MQ0<bGH@3<Uf40WgI900D0dYYS00<0WgI90=JMI02OMTT01`2Id>D0
0`2OMTT0_hIC09mfB@040<27E0<0WgI9102aO4h01P2OMTT0ZgM;0:]gB`2OMTT0fZ9W09mfB@D0g:=W
00<0WgI90>JYJ`3VZF/00P3VZF/0102OMTT0j:][0>R[J`2OMTT30>^^K@0309mfB@3Y[6`0jJa/0080
jJa/0P2OMTT40=jSI`0509mfB@3TZ6X0i:QZ0>BXJP2OMTT00P3SYVT01@2OMTT0j:]/0>R[K03XZf`0
WgI900D0l;1^0P2OMTT@09W@i@0409mfB@2ULdX0YG=:09mfB@80Xg9900<0WgI908EL?02OMTT01@3k
^W<00`2OMTT0ol=h09mfB@040?o6N@80WgI90P3oagT01@2OMTT0okad0?nlM03o_7@0WgI900<0ol5g
00D0WgI90?o2M03o`W@0ol9d09mfB@0809W@i@0405<g9`2OMTT0WgI909mfBFl0VM3U0@3oool007l0
VM3U0`2OMTT01@1IAS@0WgI906mG?P1_Ech0WgI90080YgeC00<0WgI909YW>@2JIcT00P2OMTT20;j3
C`0409mfB@2ZLd80WgI909mfB@<0]gi<00<0WgI909W@i@2Id>D00`2Id>D00`2OMTT0_8eL0;b=G002
0;b=G00309mfB@3:UV40WgI900<0c9MQ00<0WgI90=2JH`2OMTT0103=Uf400`2OMTT0_XiL0;j>G002
0;j>G00309mfB@36Tel0WgI900<0aI5N00D0WgI90<bGH@3<Uf40c9MQ09mfB@040=:JH`0409mfB@3F
WF@0eYeT09mfB@D0VM3U00@0WgI90;n6D`2oQU<0WgI91030Qe@209mfB@030;IoC`2OMTT0/Ga>0080
/Ga>00<0WgI90:]gB`2OMTT00P3JXVL00`2OMTT0g:=W0=bSI`020=bSI`0309mfB@3VZF/0iZU[00<0
iZU[00@0WgI90>R[J`3XZf/0WgI90`3[[Vd01P2OMTT0jJa/0>V/K03Y[6`0WgI90>f_KP80WgI90`3N
XfL01@2OMTT0i:QZ0>BXJP3TZ6X0WgI90080hjIY00D0WgI90>R[K03XZf`0j:]/09mfB@050?2`KP80
WgI93`2Id>D02@2OMTT0YG=:0:EcBP2ULdX0WgI90:=bB@2OMTT0QE`l09mfB@060?^jL`0309mfB@3o
`gP0WgI900<0olIi0P2OMTT20?o7N@0409mfB@3o_7@0okad0?nlM080WgI90P3o`GL01@2OMTT0ol9d
0?o2M03o`W@0WgI900P0VM3U0P1C=bL309mfBFl0VM3U0@3oool00800VM3U1@2OMTT00`1_Ech0WgI9
09mfB@020:MmD`0409mfB@2JIcT0VVLi09mfB@80_X=?00@0WgI90:Yc@P2ZLd80WgI90`2gOT`00`2O
MTT0VM3U09W@i@0309W@i@0309mfB@2lSE`0_8eL0080_8eL00<0WgI90<ZFH@2OMTT00`3<Uf40102O
MTT0d9YS0=2JH`2OMTT30<fGH@0309mfB@2nSU`0_XiL0080_XiL00@0WgI90<JCG`36Tel0WgI90P35
TEh00`2OMTT0c9MQ0<bGH@020<bGH@0309mfB@3BVV<0dYYS0080dYYS00@0WgI90=JMI03FWF@0WgI9
102Id>D0102OMTT0_hIC0;n6D`2OMTT40<27E080WgI900<0]Wm?09mfB@2aO4h00P2aO4h00`2OMTT0
ZgM;09mfB@020=ZRI`0309mfB@3LXfL0g:=W0080g:=W00<0WgI90>JYJ`3VZF/00`3VZF/0102OMTT0
j:][0>R[J`2OMTT30>^^K@0409mfB@3Y[6`0jJa/0>V/K080WgI900<0gjEX09mfB@3NXfL00P3NXfL0
1@2OMTT0i:QZ0>BXJP3TZ6X0WgI90080hjIY00D0WgI90>R[K03XZf`0j:]/09mfB@040?2`KP0409mf
B@3b/g00l[=`09mfB@h0VM3U00@0WgI90:EcBP2ULdX0WgI90P2SLTT309mfB@D0nkYc00<0WgI90?o3
N02OMTT00`3oaWT209mfB@<0olMi00<0WgI90?nlM03o_7@00P2OMTT30?o1M`0509mfB@3o`W@0ol9d
0?o2M02OMTT01`2Id>D205<g9`<0WgI9L02Id>D10?ooo`00P02Id>D609mfB@0306mG?P2OMTT0YgeC
0080YgeC00@0WgI909YW>@2OMTT0WgI90P2nPdl0102OMTT0ZW=209mfB@2OMTT30;MnC00309mfB@2I
d>D0VM3U0080VM3U00<0WgI90;b=G02lSE`00`2lSE`00`2OMTT0bYIQ09mfB@020<bGH@0409mfB@3@
VV<0d9YS09mfB@<0cIMQ0P2OMTT30;j>G00709mfB@36Tel0aY=O0<JCG`2OMTT0aI5N09mfB@050<bG
H@0509mfB@3BVV<0dYYS0=:JH`2OMTT00`3FWF@01@2OMTT0VM3U09W@i@2Id>D0WgI900<0_hIC00@0
WgI90<27E030Qe@0WgI90P2aO4h00`2OMTT0]Wm?09mfB@030;5lCP0509mfB@3JXVL0fZ9W0=ZRI`2O
MTT0103LXfL00`2OMTT0iZU[0>JYJ`030>JYJ`0309mfB@3XZf/0WgI900@0jji]00P0WgI90>V/K03Y
[6`0WgI90>f_KP2OMTT0gjEX09mfB@80gZ=W00<0WgI90>BXJP3TZ6X00P3TZ6X00`2OMTT0hjIY09mf
B@040>R[K00309mfB@3`/6h0l;1^0080l;1^00@0WgI90?:cL03b/g00WgI93@2Id>D01P2OMTT0YG=:
0:EcBP2ULdX0WgI90:=bB@<0WgI91@3k^W<0102OMTT0ol=h0?o3N02OMTT20?o6N@0309mfB@3oagX0
WgI90080olMi00@0WgI90?nlM03o_7@0okad0P2OMTT20?o1M`0309mfB@3o`W@0ol9d0080ol9d00<0
WgI909W@i@2Id>D01@2Id>D0101C=bL0WgI909mfB@2OMTUa09W@i@40oooo002109W@i@80WgI900<0
U79=09mfB@2OMTT00P1_Ech0102OMTT0YgeC0:MmD`2OMTT209YW>@0409mfB@2nPdl0_X=?09mfB@80
ZW=200<0WgI90;MnC02gOT`00P2gOT`0102OMTT0VM3U09W@i@2Id>D209mfB@@0_8eL00<0WgI90<ZF
H@2OMTT00`3<Uf40102OMTT0d9YS0=2JH`2OMTT20<fGH@<0WgI90`2nSU`0102OMTT0aY=O0<JCG`2O
MTT20<FAGP0309mfB@3<Uf40c9MQ0080c9MQ00D0WgI90=:JH`3BVV<0dYYS09mfB@040=JMI00409mf
B@2Id>D0VM3U09mfB@<0_hIC00@0WgI90<27E030Qe@0WgI90P2aO4h00`2OMTT0]Wm?09mfB@030;5l
CP0309mfB@3JXVL0fZ9W0080fZ9W00@0WgI90=bSI`3LXfL0WgI91P3VZF/00`2OMTT0j:][09mfB@04
0>^^K@0809mfB@3Y[6`0jJa/09mfB@3][fh0WgI90=nUJ02OMTT20=jSI`0309mfB@3TZ6X0i:QZ0080
i:QZ00<0WgI90>>VJ@2OMTT0103XZf`00`2OMTT0l;1^0?2`KP020?2`KP0409mfB@3b/g00l[=`09mf
B@`0VM3U00<0WgI90:EcBP2ULdX00P2ULdX309mfB@030?JgLP2OMTT0nkYc00<0nkYc00@0WgI90?o3
N03o`gP0WgI90P3oaWT00`2OMTT0olMj09mfB@030?o7N@0309mfB@3o_7@0okad0080WgI90P3o`GL2
09mfB@<0ol9d00<0WgI909W@i@2Id>D01@2Id>D0101C=bL0WgI909mfB@2OMTUb09W@i@40oooo0022
09W@i@<0WgI900D0FDHd09mfB@1_Ech0KeLn09mfB@020:MmD`0409mfB@2JIcT0WgI909mfB@80_X=?
00@0WgI90:Yc@P2ZLd80WgI90`2gOT`00`2OMTT0VM3U09W@i@0209W@i@0309mfB@2lSE`0_8eL0080
_8eL00@0WgI90<ZFH@3:UV40WgI90P3<Uf40102OMTT0d9YS0=2JH`2OMTT20<fGH@<0WgI90`2nSU`0
1`2OMTT0aY=O0<JCG`36Tel0WgI90<FAGP2OMTT01@3<Uf401@2OMTT0dYYS0=:JH`3BVV<0WgI900<0
eYeT00@0WgI909W@i@2Id>D0WgI90`2oQU<0102OMTT0`8MD0<27E02OMTT20;5lCP0609mfB@2fOdl0
]Wm?09mfB@2aO4h0WgI91@3JXVL0102OMTT0g:=W0=bSI`2OMTT60>JYJ`80WgI9103[[Vd0102OMTT0
jJa/0>V/K02OMTT20>f_KP0309mfB@3OYFP0WgI90080gZ=W00<0WgI90>BXJP3TZ6X00P3TZ6X00`2O
MTT0hjIY09mfB@050>R[K00409mfB@3`/6h0l;1^09mfB@<0l[=`00<0WgI909W@i@2Id>D02P2Id>D0
2@2OMTT0YG=:0:EcBP2ULdX0WgI90:=bB@2OMTT0m[Mb09mfB@040?^jL`0409mfB@3o`gP0ol=h09mf
B@80olIi00@0WgI90?o7NP3oagX0WgI90P3oagT0102OMTT0okad0?nlM03o_7@209mfB@80ol5g00<0
WgI90?o2M03o`W@00P3o`W@00`2OMTT0VM3U09W@i@0409W@i@0305<g9`2OMTT0WgI90080WgI9LP2I
d>D10?ooo`00P`2Id>D309mfB@0505U6=02OMTT0KeLn06mG?P2OMTT00P2WOE<01P2OMTT0VVLi09mf
B@2OMTT0_X=?09mfB@80ZW=20P2OMTT30;MnC00409mfB@2Id>D0VM3U09W@i@80WgI90`2lSE`01`2O
MTT0bYIQ0<ZFH@3:UV40WgI90<bGH@2OMTT00`3@VV<00`2OMTT0cIMQ0<fGH@0309mfB@<0_XiL00@0
WgI90<JCG`36Tel0aY=O0P2OMTT60<bGH@0409mfB@3BVV<0dYYS09mfB@@0eYeT00<0WgI909W@i@2O
MTT00`2oQU<0102OMTT0`8MD0<27E02OMTT20;5lCP0609mfB@2fOdl0]Wm?09mfB@2aO4h0WgI91@3J
XVL00`2OMTT0g:=W09mfB@070>JYJ`80WgI9103[[Vd0102OMTT0jJa/0>V/K02OMTT20>f_KP0609mf
B@3OYFP0gjEX09mfB@3NXfL0WgI9103TZ6X00`2OMTT0hjIY09mfB@050>R[K00409mfB@3`/6h0l;1^
09mfB@<0l[=`00<0WgI909W@i@2Id>D02@2Id>D00`2OMTT0YG=:0:EcBP020:EcBP80WgI90P3f]g80
1@2OMTT0nkYc0?^jL`3k^W<0WgI900<0ol=h00H0WgI90?o6N@3oaWT0WgI90?o7NP2OMTT30?o7N@03
09mfB@3o_7@0okad0080WgI90P3o`GL209mfB@<0ol9d00<0WgI909W@i@2Id>D01@2Id>D0101C=bL0
WgI909mfB@2OMTUc09W@i@40oooo002309W@i@80WgI900D0U79=09mfB@1IAS@0WgI906mG?P0209mf
B@80YgeC0`2OMTT20;j3C`0409mfB@2ZLd80ZW=209mfB@@0]gi<00H0WgI909W@i@2Id>D0WgI90;R;
F`2OMTT30;b=G00609mfB@3:UV40bYIQ09mfB@3<Uf40WgI90`3@VV<00`2OMTT0cIMQ0<fGH@0209mf
B@050<6@GP2OMTT0_XiL0;j>G02OMTT00`36Tel00`2OMTT0aI5N09mfB@060<bGH@0309mfB@3BVV<0
WgI900D0eYeT00<0WgI90;n6D`2oQU<00P2oQU<00`2OMTT0`8MD09mfB@030;5lCP0509mfB@2fOdl0
]Wm?0;IoC`2OMTT01P3JXVL00`2OMTT0g:=W09mfB@070>JYJ`80WgI9103[[Vd00`2OMTT0jJa/09mf
B@030>f_KP0609mfB@3OYFP0gjEX09mfB@3NXfL0WgI91@3TZ6X209mfB@D0j:]/00@0WgI90?2`KP3`
/6h0WgI90`3b/g000`2OMTT0VM3U09W@i@0909W@i@0309mfB@2ULdX0YG=:0080YG=:00@0WgI90?Jg
LP3f]g80WgI90`3k^W<01@2OMTT0ol=h0?o3N03o`gP0WgI90080olIi00<0WgI90?o7NP2OMTT00`3o
agT01`2OMTT0okad0?nlM02OMTT0ol9g09mfB@3o`GL00P2OMTT40?o2M00309mfB@2Id>D0VM3U00@0
VM3U00@0DcLW09mfB@2OMTT0WgI9M02Id>D10?ooo`00Q02Id>D209mfB@0509AbC@2OMTT0WgI909mf
B@1_Ech00P2OMTT20:MmD`<0WgI900@0_X=?09mfB@2ZLd80ZW=20P2OMTT30;MnC00609mfB@2Id>D0
VM3U09mfB@2hRe/0WgI90`2lSE`01`2OMTT0bYIQ0<ZFH@3:UV40WgI90<bGH@2OMTT00`3@VV<02@2O
MTT0cIMQ09mfB@3BVf@0WgI90<6@GP2OMTT0_XiL09mfB@040<JCG`80WgI91P3<Uf40102OMTT0dYYS
0=:JH`2OMTT50=JMI00709mfB@2oQU<0_hIC0;n6D`2OMTT0`8MD09mfB@030;5lCP0509mfB@2fOdl0
]Wm?0;IoC`2OMTT01P3JXVL00`2OMTT0g:=W09mfB@070>JYJ`0309mfB@3[[Vd0jji]00<0jji]00<0
WgI90>V/K02OMTT00P3][fh01`2OMTT0gjEX0=nUJ03OYFP0WgI90=jSI`2OMTT01@3TZ6X00`2OMTT0
j:]/0>R[K0040>R[K00409mfB@3`/6h0l;1^09mfB@<0l[=`00<0WgI909W@i@2Id>D0202Id>D00`2O
MTT0YG=:0:EcBP020:EcBP0509mfB@3f]g80m[Mb0?JgLP2OMTT00P3k^W<00`2OMTT0ol=h0?o3N002
0?o3N00309mfB@3oaWT0WgI90080olMj00<0WgI90?o7N@3oagT00P2OMTT20?nlM080WgI90P3o`GL2
09mfB@<0ol9d00<0WgI909W@i@2Id>D0102Id>D01@1C=bL0WgI909mfB@3JYf<0WgI907@0VM3U0@3o
ool008D0VM3U0`2OMTT0101IAS@0WgI909mfB@1_Ech209mfB@80YgeC0P2OMTT20;j3C`0309mfB@2Z
Ld80ZW=20080WgI90`2gOT`01P2OMTT0VM3U09W@i@2OMTT0^8]K09mfB@80_8eL00L0WgI90<ZFH@3:
UV40bYIQ09mfB@3<Uf40WgI900<0d9YS00D0WgI90<fGH@2OMTT0dY]T09mfB@020<6@GP0309mfB@2n
SU`0WgI900@0aY=O00<0WgI90<bGH@3<Uf401@3<Uf400`2OMTT0dYYS09mfB@060=JMI00409mfB@2o
QU<0_hIC0;n6D`80WgI90`2aO4h01@2OMTT0]Wm?0;IoC`2fOdl0WgI900H0fZ9W0P2OMTT80>JYJ`03
09mfB@3[[Vd0jji]00<0jji]0P2OMTT30>f_KP0409mfB@3OYFP0gjEX0=nUJ080WgI91P3TZ6X00`2O
MTT0j:]/0>R[K0040>R[K00309mfB@3`/6h0WgI900@0l[=`00<0WgI909W@i@2Id>D01`2Id>D00`2O
MTT0YG=:0:EcBP020:EcBP0509mfB@3f]g80m[Mb0?JgLP2OMTT00P3k^W<00`2OMTT0ol=h0?o3N002
0?o3N00309mfB@3oaWT0WgI90080olMj00<0WgI90?o7N@3oagT00P2OMTT20?nlM00409mfB@3o`WL0
WgI90?o1M`80WgI9103o`W@00`2OMTT0VM3U09W@i@0309W@i@D0WgI9M@2Id>D10?ooo`00Q@2Id>D4
09mfB@0405U6=02OMTT0WgI906mG?P80WgI900D0YgeC09mfB@2OMTT0WgI90;j3C`0209mfB@040:Yc
@P2OMTT0VVHj09mfB@<0]gi<00<0WgI909W@i@2OMTT00P2hRe/0102OMTT0_8eL0;b=G02OMTT30<ZF
H@80WgI9103@VV<209mfB@80dY]T00<0WgI90<6@GP31T5h00P2OMTT40<JCG`80WgI91`3<Uf4209mf
B@L0eYeT00<0WgI90;n6D`2oQU<00P2OMTT30;5lCP0409mfB@2fOdl0]Wm?09mfB@L0fZ9W0P2OMTT7
0>JYJ`80WgI91@3[[Vd209mfB@<0kJm^00<0WgI90=nUJ03OYFP00P3OYFP00`2OMTT0i:QZ0>BXJP04
0>BXJP0309mfB@3XZf`0j:]/00@0j:]/00<0WgI90?2`KP2OMTT01@3b/g000`2OMTT0VM3U09W@i@06
09W@i@0509mfB@2ULdX0YG=:0:EcBP2OMTT0103f]g800`2OMTT0nkYc09mfB@050?o3N080WgI90`3o
agX00`2OMTT0olMi09mfB@0209mfB@080?nlM02OMTT0ol9g09mfB@3o`GL0WgI90?o6N@2OMTT30?o2
M00309mfB@2Id>D0VM3U00<0VM3U0P2OMTT00`0F40X0WgI909mfB@1f09W@i@40oooo002609W@i@@0
WgI900L0FDHd09mfB@2OMTT0WgI908m_B`2OMTT0YgeC00<0WgI900L0_X=?09mfB@2OMTT0ZW=209mf
B@2JISX0WgI90080]gi<0`2OMTT20;R;F`0409mfB@2lSE`0_8eL09mfB@<0bYIQ0P2OMTT40=2JH`80
WgI90P3BVf@01P2OMTT0`I1N0<6@GP2OMTT0_XiL09mfB@@0aY=O00<0WgI90<bGH@3<Uf401P3<Uf40
0`2OMTT0eYeT0=JMI0050=JMI00409mfB@2oQU<0_hIC09mfB@@0/Ga>00@0WgI90;IoC`2fOdl0WgI9
1`3JXVL00`2OMTT0iZU[0>JYJ`060>JYJ`80WgI91@3[[Vd00`2OMTT0kJm^0>f_KP020>f_KP0309mf
B@3OYFP0gjEX0080gjEX00<0WgI90>BXJP3TZ6X0103TZ6X00`2OMTT0j:]/0>R[K0050>R[K080WgI9
1@3b/g000`2OMTT0VM3U09W@i@0509W@i@0509mfB@2ULdX0YG=:0:EcBP2OMTT0103f]g80102OMTT0
nkYc0?^jL`2OMTT40?o3N080WgI90`3oagX00`2OMTT0olMi09mfB@0209mfB@80okad00H0WgI90?o2
M`2OMTT0WgI90?o6N@2OMTT30?o2M080WgI9102Id>D01P2OMTT0DcLW09mfB@2OMTT0fZMS09mfBGH0
VM3U0@3oool008L0VM3U0P2OMTT00`2DLTd0WgI905U6=00309mfB@0308m_B`2OMTT0YgeC0080WgI9
00<0_X=?09mfB@2OMTT00P2ZLd8209mfB@<0]gi<00<0WgI909W@i@2OMTT00P2hRe/00`2OMTT0_8eL
09mfB@040<ZFH@80WgI9103@VV<209mfB@80dY]T00<0WgI90<6@GP31T5h00P2OMTT40<JCG`80WgI9
1`3<Uf4209mfB@L0eYeT00<0WgI90;n6D`2OMTT0102aO4h00`2OMTT0]Wm?09mfB@080=ZRI`0309mf
B@3VZF/0iZU[00D0iZU[00<0WgI90>R/K@2OMTT01@3[[Vd00`2OMTT0kJm^0>f_KP020>f_KP0309mf
B@3OYFP0gjEX0080gjEX00<0WgI90>BXJP3TZ6X00`3TZ6X209mfB@L0j:]/00<0WgI90?:cL03b/g00
103b/g000`2OMTT0VM3U09W@i@0509W@i@0409mfB@2ULdX0YG=:09mfB@D0m[Mb00<0WgI90?^jL`2O
MTT01@3o`gP209mfB@<0olMj0P2OMTT02`3ob7X0WgI909mfB@3o_7@0WgI90?o2M`2OMTT0ol5g09mf
B@3oaWT0WgI90080ol9d0P2OMTT409W@i@@0WgI900<0fZMS09mfB@2Id>D0MP2Id>D10?ooo`00Q`2I
d>D409mfB@0305U6=02OMTT0Lea10080WgI900<0Sfm;09mfB@2WOE<01@2OMTT0102ZLd80WgI909YV
>P2OMTT20;MnC0<0WgI90`2hRe/00`2OMTT0_8eL09mfB@030<ZFH@80WgI9103@VV<209mfB@80dY]T
00@0WgI90<6@GP31T5h0`I1N0P2OMTT40<JCG`80WgI91`3<Uf400`2OMTT0eYeT0=JMI0060=JMI080
WgI91@2aO4h209mfB@L0fZ9W0P2OMTT70>JYJ`0309mfB@3X[6d0WgI900@0jji]0P2OMTT40>f_KP03
09mfB@3OYFP0gjEX0080gjEX00<0WgI90>BXJP3TZ6X00`3TZ6X209mfB@L0j:]/00<0WgI90?:cL03b
/g00103b/g000`2OMTT0VM3U09W@i@0409W@i@0409mfB@2ULdX0YG=:09mfB@D0m[Mb00<0WgI90?^j
L`2OMTT01@3o`gP209mfB@<0olMj00D0WgI90?o7N@2OMTT0WgI90?jlM@0209mfB@80ol9g0P2OMTT0
0`3oaWT0WgI90?o2M0020?o2M080WgI9102Id>D00`1A=BD0WgI909mfB@0209mfBGP0VM3U0@3oool0
08P0VM3U102OMTT0101IAS@0WgI909mfB@1_Ech209mfB@040:MmD`2OMTT0[X=G0:j3E`<0WgI900@0
ZW=209mfB@2JISX0WgI90P2gOT`209mfB@<0^8]K00<0WgI90;b=G02OMTT0103:UV400`2OMTT0d9YS
0=2JH`030=2JH`0409mfB@3BVf@0dY]T09mfB@@0`I1N00<0WgI90<JCG`36Tel00P36Tel00`2OMTT0
cYUS09mfB@060<bGH@80WgI9203FWF@00`2OMTT0/Ga>0;5lCP030;5lCP0309mfB@3JXVL0fZ9W00H0
fZ9W0P2OMTT60>JYJ`0409mfB@3X[6d0j:a]09mfB@@0jji]0P2OMTT30>f_KP0309mfB@3OYFP0gjEX
00<0gjEX00<0WgI90>BXJP3TZ6X00`3TZ6X00`2OMTT0jJe]09mfB@060>R[K00309mfB@3b/g00l[=`
00@0l[=`00<0WgI909W@i@2Id>D00`2Id>D209mfB@030:EcBP2OMTT0m[Mb00D0m[Mb0P2OMTT60?o3
N00609mfB@3oagX0olMj0?o7NP2OMTT0olMi0P2OMTT01@3n_7D0WgI90?nlM02OMTT0ol9g0080WgI9
0P3oaWT00`2OMTT0ol9d0?o2M00209mfB@@0VM3U00<0DCDU09mfB@0F40X00P2OMTUi09W@i@40oooo
002909W@i@@0WgI900@0FDHd09mfB@2OMTT0KeLn0P2OMTT0102WOE<0WgI90:j3E`2^PeL409mfB@80
VVHj00@0WgI90;MnC02OMTT0WgI9102hRe/209mfB@@0bYIQ0P2OMTT40=2JH`0509mfB@3BVf@0dY]T
0=:KI02OMTT01031T5h00`2OMTT0aY=O0<JCG`020<JCG`0309mfB@3>VF<0WgI900H0c9MQ0P2OMTT8
0=JMI00309mfB@2aO4h0/Ga>0080/Ga>00<0WgI90=ZRI`3JXVL01@3JXVL00`2OMTT0gjIY09mfB@06
0>JYJ`0409mfB@3X[6d0j:a]09mfB@<0jji]00<0WgI90>naK`2OMTT00`3][fh00`2OMTT0gjEX0=nU
J0020=nUJ080WgI91@3TZ6X00`2OMTT0jJe]09mfB@050>R[K00309mfB@3_/6l0WgI900D0l[=`00<0
WgI909W@i@2Id>D00P2Id>D209mfB@030:EcBP2OMTT0m[Mb00D0m[Mb0P2OMTT60?o3N00309mfB@3o
agX0olMj0080olMj0P2OMTT00`3ob7X0WgI90?jlM@0209mfB@80ol9g0P2OMTT0103oaWT0WgI90?o2
M03o`W@209mfB@@0VM3U00<0DCDU09mfB@2OMTT00P2OMTUj09W@i@40oooo002:09W@i@05054o;`2O
MTT0WgI909mfB@1IAS@00`2OMTT0102?Kd/0WgI90:MmD`2OMTT20:j3E`80WgI900H0ZW=209mfB@2J
ISX0VVHj09mfB@2gOT`209mfB@@0^8]K00<0WgI90<ZFH@3:UV400`3:UV400`2OMTT0d9YS0=2JH`02
0=2JH`80WgI90P3BVf@00`2OMTT0`I1N0<6@GP020<6@GP80WgI90`36Tel00`2OMTT0cYUS09mfB@06
0<bGH@0309mfB@3CWF@0WgI900P0eYeT00@0WgI90;5lCP2aO4h0WgI91`3JXVL0102OMTT0gjIY0=nV
J@2OMTT50>JYJ`0509mfB@3X[6d0j:a]0>R/K@2OMTT00`3[[Vd00`2OMTT0kk5_09mfB@030>f_KP03
09mfB@3OYFP0gjEX0080gjEX00<0WgI90>FYJ`2OMTT00`3TZ6X0102OMTT0jJe]0>V]K@2OMTT50>R[
K00309mfB@3_/6l0WgI900D0l[=`00<0WgI909W@i@2Id>D00P2Id>D309mfB@L0m[Mb00<0WgI90?o3
N03o`gP0103o`gP00`2OMTT0olMj0?o7NP020?o7NP80WgI900@0olQj09mfB@3n_7D0o[ae0P2OMTT0
0`3o`WL0WgI909mfB@020?o6N@0509mfB@3o`W@0WgI90?o5MP2OMTT00`2Id>D2054e9@<0WgI9N`2I
d>D10?ooo`00RP2Id>D00`2OMTT0DCl_09mfB@0209mfB@0805U6=02OMTT0WgI909mfB@2?Kd/0WgI9
0:MmD`2OMTT20:j3E`80WgI900@0ZW=209mfB@2JISX0VVHj0`2OMTT40;R;F`80WgI9103:UV4209mf
B@<0d9YS0P2OMTT30=:KI00409mfB@31T5h0`I1N0<6@GP80WgI91036Tel00`2OMTT0cYUS09mfB@05
0<bGH@0309mfB@3CWF@0dieT0080WgI91P3FWF@0102OMTT0/Ga>0;5lCP2OMTT70=ZRI`0409mfB@3O
YVT0gjIY09mfB@D0iZU[00D0WgI90>R/K@3X[6d0j:a]09mfB@020>^^K@0309mfB@3_/Fl0WgI900@0
kJm^00<0WgI90=nUJ03OYFP00P3OYFP00`2OMTT0iJU[09mfB@030>BXJP0409mfB@3Y[Fd0jJe]09mf
B@D0j:]/00<0WgI90>n`K`2OMTT01@3b/g00102OMTT0VM3U09W@i@2Id>D309mfB@L0m[Mb00<0WgI9
0?o3N03o`gP0103o`gP209mfB@@0olMj00<0WgI90?o8NP2OMTT00P3n_7D209mfB@80ol9g00P0WgI9
0?o6N@3oaWT0WgI90?o2M02OMTT0olEf09mfB@<0VM3U00<0WgI9054e9@2OMTT00`2OMTUk09W@i@40
oooo002;09W@i@H0WgI900@0Lea109mfB@2OMTT0Sfm;0P2OMTT30:j3E`<0WgI90P2JISX00`2OMTT0
]gi<09mfB@050;R;F`0309mfB@3:UV40bYIQ0080bYIQ0P2OMTT40=2JH`80WgI90P3BVf@00`2OMTT0
`I1N0<6@GP020<6@GP80WgI90`36Tel0102OMTT0cYUS0<jIH`2OMTT50<bGH@0509mfB@3CWF@0dieT
0=>MI02OMTT01P3FWF@209mfB@L0fZ9W00D0WgI90=nVJ@3OYVT0gjIY09mfB@040>JYJ`0509mfB@3X
[6d0j:a]0>R/K@2OMTT00`3[[Vd00`2OMTT0kk5_09mfB@040>f_KP0309mfB@3OYFP0gjEX0080gjEX
00<0WgI90>FYJ`2OMTT00`3TZ6X0102OMTT0jJe]0>V]K@2OMTT40>R[K00509mfB@3_/6l0kk1_0>n`
K`2OMTT01@3b/g001@2OMTT0VM3U09mfB@2RL4P0WgI900H0m[Mb0`2OMTT50?o3N080WgI9103oagX0
102OMTT0olQj0?o8NP2OMTT20?jlM@0309mfB@3o`WL0ol9g0080WgI90P3oaWT209mfB@80olEf00D0
WgI909W@i@2Id>D0WgI9054e9@0409mfBG`0VM3U0@3oool008`0VM3U1P2OMTT0101cG440WgI909mf
B@2?Kd/209mfB@<0[X=G0`2OMTT209YV>P0309mfB@2gOT`0WgI900@0^8]K0P2OMTT30<ZFH@0309mf
B@3>VF<0WgI900<0d9YS0P2OMTT30=:KI00709mfB@31T5h0`I1N0<6@GP2OMTT0b9IQ09mfB@030<JC
G`0409mfB@3>VF<0cYUS09mfB@@0c9MQ00<0WgI90=>MI03CWF@00P3CWF@00`2OMTT0eYeT0=JMI004
0=JMI00309mfB@3JXVL0fZ9W00@0fZ9W00<0WgI90=nVJ@3OYVT00P3OYVT00`2OMTT0iZU[0>JYJ`02
0>JYJ`0509mfB@3X[6d0j:a]0>R/K@2OMTT00P3[[Vd0102OMTT0kk5_0>naK`2OMTT40>f_KP0309mf
B@3OYFP0gjEX0080gjEX00<0WgI90>FYJ`2OMTT00P3TZ6X01@2OMTT0jJe]0>V]K@3Y[Fd0WgI900@0
j:]/00D0WgI90>n`K`3_/6l0kk1_09mfB@050?:cL080WgI900<0XW1809mfB@3f]g801@3f]g800`2O
MTT0nk]d09mfB@050?o3N080WgI9103oagX0102OMTT0olQj0?o8NP2OMTT20?jlM@80WgI90P3o`WL0
0`2OMTT0olIi0?o6N@0209mfB@80olEf00D0WgI909W@i@2Id>D0WgI9054e9@0409mfBGd0VM3U0@3o
ool008d0VM3U1P2OMTT0101cG440WgI908m_B`2?Kd/209mfB@<0[X=G0P2OMTT309YV>P80WgI9102h
Re/209mfB@@0bYIQ00<0WgI90<jIH`2OMTT00P3@VV<00`2OMTT0e9eU09mfB@020=:KI00309mfB@31
T5h0`I1N0080`I1N00<0WgI90<RFH@2OMTT00P36Tel01@2OMTT0cYUS0<jIH`3>VF<0WgI900<0c9MQ
00<0WgI90=>MI03CWF@00`3CWF@00`2OMTT0eYeT0=JMI0030=JMI00309mfB@3JXVL0fZ9W00@0fZ9W
00<0WgI90=nVJ@3OYVT00`3OYVT0102OMTT0iZU[0>JYJ`2OMTT40>R/K@0409mfB@3[[Vd0jji]09mf
B@80kk5_00D0WgI90>f_KP3][fh0kJm^09mfB@040=nUJ00409mfB@3UZF/0iJU[09mfB@80i:QZ00<0
WgI90>V]K@3Y[Fd00P3Y[Fd01@2OMTT0j:]/0>R[K03XZf`0WgI900<0kk1_00<0WgI90?:cL03b/g00
0`3b/g0309mfB@H0m[Mb00@0WgI90?^kM03k^g@0WgI9103o`gP00`2OMTT0olAi09mfB@030?o7NP80
WgI90P3ob7X0102OMTT0o[ae0?jlM@2OMTT20?o2M`0409mfB@3oaWT0olIi0?o6N@80WgI900H0olEf
09mfB@2Id>D0VM3U09mfB@1A=BD409mfBGh0VM3U0@3oool008h0VM3U1P2OMTT0101cG440WgI908m_
B`2?Kd/209mfB@<0[X=G0P2OMTT309YV>P0309mfB@2hRe/0^8]K00<0^8]K0P2OMTT30<ZFH@0309mf
B@3>VF<0WgI90080d9YS00<0WgI90=BMI@2OMTT00`3BVf@01@2OMTT0`I1N0<6@GP31T5h0WgI90080
b9IQ00<0WgI90<JCG`2OMTT0103>VF<01@2OMTT0c9MQ0<bGH@3<Uf40WgI900D0dieT00<0WgI90=JM
I03FWF@00P3FWF@00`2OMTT0fZ9W0=ZRI`030=ZRI`0309mfB@3OYVT0gjIY00@0gjIY00@0WgI90>JY
J`3VZF/0WgI9103X[6d0102OMTT0jji]0>^^K@2OMTT20>naK`0509mfB@3][fh0kJm^0>f_KP2OMTT0
103OYFP0102OMTT0iJU[0>FYJ`2OMTT20>BXJP0309mfB@3Y[Fd0jJe]0080jJe]00@0WgI90>R[K03X
Zf`0WgI9103_/6l00`2OMTT0l[=`0?:cL0030?:cL080WgI91@3f]g8209mfB@80nk]d00<0WgI90?o3
N03o`gP00P3o`gP00`2OMTT0olAi09mfB@030?o7NP80WgI90P3ob7X0102OMTT0o[ae0?jlM@2OMTT2
0?o2M`80WgI90P3oaWT209mfB@80olEf00@0WgI909W@i@2Id>D0DCDU102OMTUo09W@i@40oooo002?
09W@i@H0WgI900D0Lea109mfB@2?Kd/0Sfm;09mfB@040:j3E`80WgI90`2JISX00`2OMTT0^8]K0;R;
F`020;R;F`0309mfB@31TEl0WgI90080bYIQ00@0WgI90<jIH`3>VF<0WgI90P3@VV<00`2OMTT0e9eU
09mfB@020=:KI00309mfB@31T5h0`I1N0080`I1N00<0WgI90<RFH@2OMTT00P36Tel00`2OMTT0cYUS
0<jIH`020<jIH`0409mfB@3<Uf40c9MQ09mfB@H0dieT00<0WgI90=JMI03FWF@00P3FWF@01@2OMTT0
fZ9W0=ZRI`3JXVL0WgI900L0gjIY00<0WgI90>JYJ`2OMTT01@3X[6d00`2OMTT0jji]09mfB@030>na
K`0509mfB@3][fh0kJm^0>f_KP2OMTT0103OYFP01P2OMTT0iJU[0>FYJ`2OMTT0i:QZ09mfB@D0jJe]
00@0WgI90>R[K03XZf`0WgI91@3_/6l00`2OMTT0l[=`0?:cL0020?:cL00309mfB@3f]g80m[Mb00<0
m[Mb00<0WgI90?^kM03k^g@00P3k^g@01`2OMTT0ol=h0?o3N03o`gP0WgI90?o4N@2OMTT00`3oagX2
09mfB@80olQj00<0WgI90?jlM@3n_7D00P2OMTT20?o2M`0509mfB@3oaWT0olIi0?o6N@2OMTT00P3o
aGH00`2OMTT0VM3U09W@i@0509mfBH00VM3U0@3oool00900VM3U1@2OMTT207=L@@0409mfB@2?Kd/0
Sfm;09mfB@D0[X=G00@0WgI909YV>P2JISX0WgI9102hRe/00`2OMTT0`I5O09mfB@020<ZFH@0409mf
B@3>VF<0cYUS09mfB@80d9YS00<0WgI90=BMI@2OMTT00`3BVf@01@2OMTT0`I1N0<6@GP31T5h0WgI9
0080b9IQ00<0WgI90<JCG`2OMTT01@3>VF<00`2OMTT0c9MQ09mfB@070=>MI00509mfB@3FWF@0eYeT
0=JMI02OMTT00`3JXVL00`2OMTT0gjIY0=nVJ@050=nVJ@0309mfB@3VZF/0WgI900D0j:a]00<0WgI9
0>^^K@2OMTT00`3_/Fl01@2OMTT0kJm^0>f_KP3][fh0WgI900@0gjEX00H0WgI90>FYJ`3UZF/0WgI9
0>BXJP2OMTT50>V]K@0409mfB@3XZf`0j:]/09mfB@D0kk1_00<0WgI90?:cL03b/g000P3b/g000`2O
MTT0m[Mb0?JgLP020?JgLP0309mfB@3k^g@0nk]d0080nk]d00<0WgI90?o3N03o`gP00P2OMTT20?o4
N@0309mfB@3oagX0olMj0080WgI90`3ob7X0102OMTT0o[ae09mfB@2OMTT20?o2M`80WgI90P3oaWT0
102OMTT0olEf0?o5MP2OMTT209W@i@D0WgI9P@2Id>D10?ooo`00T@2Id>D509mfB@80Lea100<0WgI9
08m_B`2?Kd/00P2OMTT40:j3E`0309mfB@2JISX0WgI900@0^8]K00@0WgI90<6AG`31TEl0WgI90P3:
UV401P2OMTT0cYUS0<jIH`2OMTT0d9YS09mfB@80e9eU00@0WgI90=:KI03BVf@0WgI90`31T5h01`2O
MTT0b9IQ0<RFH@38UV40WgI90<JCG`2OMTT0103>VF<0102OMTT0c9MQ0<bGH@2OMTT70=>MI080WgI9
00D0eYeT09mfB@3JXVL0fZ9W09mfB@080=nVJ@80WgI91P3X[6d209mfB@@0kk5_00<0WgI90>f_KP3]
[fh00P2OMTT40=nUJ00409mfB@3UZF/0iJU[0>FYJ`80WgI91@3Y[Fd00`2OMTT0j:]/09mfB@060>n`
K`0509mfB@3b/g00l[=`0?:cL02OMTT00`3f]g8209mfB@@0nk]d00@0WgI90?o3N03o`gP0WgI90`3o
a7T01P2OMTT0olMj0?o7NP2OMTT0olQk09mfB@80olQj00<0WgI90?jlM@3n_7D00P2OMTT00`3o`WL0
WgI909mfB@020?o6N@0609mfB@3oaGH0olEf0?o5MP2OMTT0VM3U1@2OMTV209W@i@40oooo002A09W@
i@<0WgI900<0XGaC09mfB@2OMTT00P1cG4400`2OMTT0Sfm;08m_B`0209mfB@@0[X=G0P2OMTT40;R;
F`0409mfB@31TEl0`I5O09mfB@80bYIQ00H0WgI90<jIH`3>VF<0WgI90=2JH`2OMTT20=BMI@0509mf
B@3BVf@0dY]T0=:KI02OMTT00`31T5h0102OMTT0b9IQ0<RFH@38UV4209mfB@D0cYUS00<0WgI90<bG
H@2OMTT02@3CWF@209mfB@030=ZRI`2OMTT0gjIY00P0gjIY0P2OMTT60>R/K@80WgI9103_/Fl00`2O
MTT0kJm^0>f_KP0309mfB@80gjEX00<0WgI90>FYJ`3UZF/00P3UZF/209mfB@D0jJe]00<0WgI90>R[
K02OMTT01`3_/6l0102OMTT0l[=`0?:cL02OMTT20?JgLP0309mfB@3k^g@0nk]d00@0nk]d00<0WgI9
0?o3N02OMTT0103oa7T01@2OMTT0olMj09mfB@3ob7/0WgI90080olQj00<0WgI90?jlM@3n_7D00P2O
MTT00`3o`WL0WgI909mfB@020?o6N@80WgI90P3oaGH0202OMTT0VM3U09mfB@2OMTT0ol9e09mfB@0F
40X0WgI9PP2Id>D10?ooo`00TP2Id>D309mfB@040:5lD`2OMTT0WgI907=L@@80WgI90P2?Kd/309mf
B@<0[X=G0P2OMTT30;R;F`0709mfB@31TEl0`I5O0<6AG`2OMTT0bYIQ09mfB@030<jIH`0309mfB@3@
VV<0WgI90080e9eU00@0WgI90=:KI03BVf@0WgI90`31T5h00`2OMTT0b9IQ0<RFH@020<RFH@80WgI9
1@3>VF<209mfB@X0dieT0`2OMTT90=nVJ@0309mfB@3X[6d0j:a]00D0j:a]00<0WgI90>naK`3_/Fl0
0`3_/Fl0102OMTT0kJm^09mfB@3UZf`209mfB@80gjEX00<0WgI90>FYJ`3UZF/00P3UZF/00`2OMTT0
jJe]0>V]K@050>V]K@80WgI91`3_/6l00`2OMTT0l[=`09mfB@020?JgLP0309mfB@3k^g@0nk]d00@0
nk]d00<0WgI90?o3N02OMTT0103oa7T01@2OMTT0olMj09mfB@3ob7/0WgI900<0olQj00T0WgI90?jl
M@2OMTT0WgI90?o2M`2OMTT0olIj09mfB@3oaWT00P2OMTT30?o5MP<0WgI900@0ol9e09mfB@0F40X0
WgI9P`2Id>D10?ooo`00T`2Id>D309mfB@040:5lD`2OMTT0WgI907=L@@80WgI900D0Sfm;09mfB@2V
OeD0YWmE09mfB@030:j3E`0309mfB@2hRe/0^8]K0080^8]K00L0WgI90<6AG`31TEl0`I5O09mfB@3:
UV40WgI900<0cYUS0P2OMTT30=BMI@0409mfB@3BVf@0WgI909mfB@<0`I1N00@0WgI90<RFH@38UV40
b9IQ0P2OMTT60<jIH`80WgI92P3CWF@00`2OMTT0gjIY0=nVJ@080=nVJ@0309mfB@3X[6d0j:a]00D0
j:a]00<0WgI90>naK`3_/Fl00P3_/Fl00`2OMTT0kJm^0>f_KP0209mfB@050?JfLP2OMTT0gjEX0=nU
J02OMTT0103UZF/00`2OMTT0jJe]0>V]K@050>V]K@0309mfB@3_/6l0kk1_00H0kk1_00<0WgI90?:c
L02OMTT00P2OMTT70?^kM080WgI9103oa7T01@2OMTT0olMj09mfB@3ob7/0WgI900<0olQj00@0WgI9
0?jlM@2OMTT0ol5g0P2OMTT0103oaWX0WgI90?o6N@3oaWT209mfB@80olEf00L0WgI904H]7`2OMTT0
ol9e09mfB@0F40X0WgI908@0VM3U0@3oool009@0VM3U0`2OMTT0102QO5<0WgI909mfB@1cG44209mf
B@0508m_B`2OMTT0YWmE0:IoE@2OMTT00`2^PeL01@2OMTT0^8]K0;R;F`2hRe/0WgI900<0`I5O00<0
WgI90<ZFH@2OMTT00`3>VF<209mfB@<0e9eU00<0WgI90=:KI02OMTT00P2OMTT20<6@GP0309mfB@38
UV40b9IQ0080b9IQ0P2OMTT60<jIH`0309mfB@3CWF@0dieT00P0dieT00<0WgI90=nVJ@3OYVT01`3O
YVT209mfB@H0j:a]0P2OMTT40>naK`0509mfB@3][fh0WgI90>F[K02OMTT00P3f]W800`2OMTT0gjEX
09mfB@040>FYJ`0309mfB@3Y[Fd0jJe]00D0jJe]00<0WgI90>n`K`3_/6l01`3_/6l209mfB@P0nk]d
0P2OMTT50?o4N@80WgI90P3ob7/03@2OMTT0olQj0?o8NP2OMTT0o[ae09mfB@3o`GL0WgI90?o2M`2O
MTT0olIj09mfB@3oaWT00P2OMTT20?o5MP0709mfB@16;Al0WgI90?o2M@2OMTT05Q0:09mfB@2509W@
i@40oooo002E09W@i@<0WgI900@0XGaC09mfB@2OMTT0Lea1102OMTT20:IoE@80WgI90P2^PeL0102O
MTT0^8]K0;R;F`2OMTT40<6AG`80WgI9103>VF<00`2OMTT0e9eU0=BMI@020=BMI@0309mfB@3BVf@0
WgI90080WgI90P31T5h00`2OMTT0b9IQ0<RFH@020<RFH@0309mfB@3>VF<0cYUS00@0cYUS0P2OMTT9
0=>MI00309mfB@3OYVT0gjIY00H0gjIY00<0WgI90>:XJ`2OMTT01P3X[6d209mfB@@0kk5_00D0WgI9
0>f_KP2OMTT0iJ]/09mfB@020?JfLP0309mfB@3OYFP0WgI900<0iJU[0P2OMTT70>V]K@0309mfB@3_
/6l0kk1_00L0kk1_00<0WgI90?^kM03k^g@01`3k^g@00`2OMTT0olAi0?o4N@030?o4N@80WgI90P3o
b7/0102OMTT0olQj0?o8NP3ob7X209mfB@80ol5g0P2OMTT01P3oaWX0WgI90?o6N@2OMTT0olQj09mf
B@80olEf0P2OMTT0103o`WD0WgI909mfB@2OMTV609W@i@40oooo002F09W@i@<0WgI900H0XGaC09mf
B@2OMTT0Lea109mfB@2DLdh209mfB@<0YWmE00H0WgI90:j3E`2^PeL0WgI90;R;F`2OMTT50<6AG`03
09mfB@3>VF<0cYUS0080cYUS0P2OMTT30=BMI@0409mfB@3BVf@0WgI90<ZIH`80WgI900<0`I1N09mf
B@38UV400`38UV4209mfB@H0cYUS0`2OMTT80=>MI00309mfB@3OYVT0gjIY00D0gjIY00<0WgI90>:X
J`2OMTT01@3X[6d00`2OMTT0k:m^09mfB@040>naK`80WgI90P3UZf`00`2OMTT0m[Ib0?JfLP0209mf
B@@0iJU[00<0WgI90>^^KP2OMTT01@3Y[Fd00`2OMTT0l;9`09mfB@070>n`K`0309mfB@3k^g@0nk]d
00L0nk]d00<0WgI90?o4N@3oa7T00`3oa7T209mfB@80olQk00P0WgI90?o8NP3ob7X0olQj09mfB@3n
_7D0WgI90?o1M`80WgI90P3oaWX209mfB@040?o8NP2OMTT0olEf0?o5MP80WgI900@0ol9e09mfB@2O
MTT0WgI9Q`2Id>D10?ooo`00U`2Id>D409mfB@05061<=`2OMTT0WgI909mfB@2DLdh00P2OMTT30:Io
E@<0WgI900<0^8]K09mfB@31TEl01031TEl209mfB@@0cYUS00<0WgI90=BMI@3DWFD00P3DWFD209mf
B@060<ZIH`2OMTT0fZ9W09mfB@31T5h0WgI91038UV4209mfB@D0cYUS00@0WgI90=JOIP3FWfH0WgI9
1`3CWF@00`2OMTT0gjIY0=nVJ@040=nVJ@0409mfB@3RZ6/0hZQ[09mfB@D0j:a]00<0WgI90>b_KP2O
MTT0103_/Fl209mfB@80iJ]/00D0WgI90?JfLP3f]W80m[Ib09mfB@040>FYJ`0309mfB@3[[Vh0WgI9
00D0jJe]00<0WgI90?2bL02OMTT01`3_/6l00`2OMTT0nk]d0?^kM0050?^kM080WgI91P3oa7T0102O
MTT0olQk0?o8N`2OMTT30?o8NP0409mfB@3n_7D0WgI90?o1M`80WgI90P3oaWX209mfB@80olQj00<0
WgI90?o5MP3oaGH01@2OMTV809W@i@40oooo002H09W@i@@0WgI900D0H4`g09mfB@2OMTT0WgI909Ac
CP0209mfB@@0YWmE0P2OMTT00`2hRe/0WgI90<6AG`040<6AG`0309mfB@3>VF<0cYUS0080cYUS0P2O
MTT30=BMI@80WgI90P3:VF<0102OMTT0fZ9W09mfB@2OMTT40<RFH@0309mfB@3AW6@0WgI900@0cYUS
00D0WgI90=JOIP3FWfH0eYmV09mfB@060=>MI00309mfB@3OYVT0gjIY00<0gjIY00D0WgI90>:XJ`3R
Z6/0hZQ[09mfB@040>R/K@0409mfB@3/[fh0k:m^09mfB@@0kk5_00D0WgI90>F[K03UZf`0iJ]/09mf
B@030?JfLP0309mfB@3UZF/0iJU[0080iJU[00<0WgI90>^^KP2OMTT0103Y[Fd0102OMTT0l;9`0?2b
L02OMTT60>n`K`0309mfB@3k^g@0nk]d00D0nk]d0P2OMTT60?o4N@0609mfB@3ob7/0olQk0?o8N`2O
MTT0olQj102OMTT20?o1M`0309mfB@3oaWX0olIj0080WgI90P3ob7X00`2OMTT0olEf0?o5MP0509mf
BHT0VM3U0@3oool009T0VM3U102OMTT01P1PC3L0WgI909mfB@2OMTT0U7=>09mfB@D0YWmE0`2OMTT5
0<6AG`80WgI9103>VF<209mfB@<0e9eU0P2OMTT20<ZIH`0409mfB@3JXVL0WgI909mfB@@0b9IQ00<0
WgI90=6LI02OMTT0103>VF<0102OMTT0eYmV0=JOIP3FWfH209mfB@@0dieT00<0WgI90=nVJ@3OYVT0
0P3OYVT00`2OMTT0hZQ[0>:XJ`020>:XJ`0309mfB@3X[6d0j:a]0080j:a]00@0WgI90>b_KP3/[fh0
WgI90`3_/Fl00`2OMTT0iJ]/0>F[K0020>F[K00509mfB@3f]W80m[Ib0?JfLP2OMTT00`3UZF/0102O
MTT0jji^0>^^KP2OMTT40>V]K@0509mfB@3`/W00l;9`0?2bL02OMTT01@3_/6l00`2OMTT0nk]d0?^k
M0030?^kM080WgI900<0oKef09mfB@3oa7T00`3oa7T209mfB@<0olQk00<0WgI90?o8NP2OMTT00`2O
MTT20?o1M`80WgI90P3oaWX209mfB@80olQj00<0WgI90?o5MP2OMTT0102OMTV:09W@i@40oooo002J
09W@i@D0WgI900D0Mf1309mfB@2DLdh0U7=>09mfB@060:IoE@0309mfB@31TEl0`I5O00@0`I5O0P2O
MTT30<jIH`80WgI90`3DWFD209mfB@80bYUS00@0WgI90=ZRI`3JXVL0WgI91038UV40102OMTT0dIaT
0=6LI02OMTT30<jIH`0309mfB@3FWfH0eYmV00<0eYmV00D0WgI90=>MI03CWF@0dieT09mfB@030=nV
J@0309mfB@3RZ6/0hZQ[00@0hZQ[00@0WgI90>R/K@3X[6d0WgI90`3/[fh01@2OMTT0kk5_0>naK`3_
/Fl0WgI900@0iJ]/00D0WgI90?JfLP3f]W80m[Ib09mfB@030>FYJ`0509mfB@3[[Vh0jji^0>^^KP2O
MTT00P3Y[Fd00`2OMTT0l;9`0?2bL0020?2bL00309mfB@3_/6l0kk1_0080kk1_00<0WgI90?^kM03k
^g@00`3k^g@0102OMTT0oKef0?fmMP2OMTT40?o4N@80WgI90`3ob7/00`2OMTT0olQj09mfB@0309mf
B@<0ol5g00<0WgI90?o6NP3oaWX00P2OMTT20?o8NP0309mfB@3oaGH0WgI900@0WgI9R`2Id>D10?oo
o`00V`2Id>D509mfB@0507MP@`2OMTT0U7=>09AcCP2OMTT01P2VOeD00`2OMTT0`I5O0<6AG`030<6A
G`80WgI9103>VF<209mfB@<0e9eU00D0WgI90<ZIH`3:VF<0bYUS09mfB@020=ZRI`0309mfB@38UV40
b9IQ0080b9IQ00@0WgI90=6LI03AW6@0WgI90P3>VF<00`2OMTT0eYmV0=JOIP040=JOIP0409mfB@3C
WF@0dieT09mfB@80gjIY00<0WgI90>:XJ`3RZ6/01@3RZ6/0102OMTT0j:a]0>R/K@2OMTT30>b_KP04
09mfB@3_/Fl0kk5_09mfB@@0iJ]/00<0WgI90?JfLP3f]W800`3f]W80102OMTT0iJU[0>FYJ`2OMTT3
0>^^KP0409mfB@3Y[Fd0jJe]09mfB@@0l;9`00<0WgI90>n`K`3_/6l00P3_/6l0102OMTT0nk]d0?^k
M03k^g@209mfB@80oKef00<0WgI90?o4N@3oa7T00P3oa7T209mfB@<0olQk102OMTT00`3oaGL0WgI9
0?o1M`020?o1M`0509mfB@3oaWX0olIj0?o6NP2OMTT00`3ob7X309mfB@030>bfK@2OMTT0WgI908`0
VM3U0@3oool009`0VM3U1@2OMTT01@1gH4<0WgI909AcCP2DLdh0WgI900H0YWmE00<0WgI90<6AG`31
TEl00P31TEl00`2OMTT0aYEQ09mfB@030<jIH`0309mfB@3BWFD0WgI90080e9eU00<0WgI90<ZIH`3:
VF<00P3:VF<0102OMTT0fZ9W0=ZRI`2OMTT30<RFH@0509mfB@3AW6@0dIaT0=6LI02OMTT00P3>VF<0
0`2OMTT0eYmV0=JOIP040=JOIP80WgI900@0dieT09mfB@3OYVT0WgI91`3RZ6/00`2OMTT0j:a]09mf
B@040>b_KP0409mfB@3_/Fl0kk5_09mfB@@0iJ]/00<0WgI90?JfLP3f]W800`3f]W80102OMTT0iJU[
0>FYJ`2OMTT30>^^KP0409mfB@3Y[Fd0jJe]09mfB@D0l;9`00@0WgI90>n`K`3_/6l0WgI90`3k^g@0
1@2OMTT0oKef0?fmMP3m_GH0WgI900<0olAi0P2OMTT00`3oaGX0WgI90?o8N`020?o8N`0409mfB@3n
_WL0WgI90?o5M`80WgI90P3o`GL01@2OMTT0olIj0?o6NP3oaWX0WgI900<0olQj0`2OMTT00`3/]Vd0
WgI909mfB@2=09W@i@40oooo002M09W@i@D0WgI900@0Mf1309mfB@2DLdh0U7=>0P2OMTT50:IoE@05
09mfB@31TEl0`I5O0<6AG`2OMTT00P36UF40102OMTT0cYUS0<jIH`2OMTT20=:MI@0409mfB@3DWFD0
e9eU09mfB@<0bYUS00D0WgI90=ZRI`3JXVL0fZ9W09mfB@030<RFH@0709mfB@3AW6@0dIaT0=6LI02O
MTT0cYUS09mfB@080=JOIP<0WgI9203RZ6/00`2OMTT0j:a]09mfB@040>b_KP0309mfB@3_/Fl0WgI9
00D0iJ]/00<0WgI90?JfLP3f]W800`3f]W800`2OMTT0iJU[09mfB@040>^^KP0309mfB@3Y[Fd0WgI9
00H0l;9`00D0WgI90>n`K`3_/6l0WgI90?^kM00209mfB@@0oKef00@0WgI90?o4N@3oa7T0WgI90P3o
aGX01`2OMTT0olQk0?o8N`3ob7/0WgI90?jnM`2OMTT00P3oaGL00`2OMTT0ol5g0?o1M`0209mfB@80
olIj00<0WgI90?o8NP3ob7X00P3ob7X00`2OMTT0k;I]0>bfK@0209mfBHh0VM3U0@3oool009h0VM3U
00<0WgI90:N1EP2OMTT00P2OMTT0101gH4<0WgI909mfB@2DLdh309mfB@@0YWmE00D0WgI90<6AG`31
TEl0`I5O09mfB@020<JEH@0609mfB@3>VF<0cYUS09mfB@3BWFD0WgI90P3DWFD00`2OMTT0bYUS0<ZI
H`020<ZIH`0509mfB@3JXVL0fZ9W0=ZRI`2OMTT00P38UV400`2OMTT0dIaT0=6LI0020=6LI080WgI9
2@3FWfH00`2OMTT0hZQ[0>:XJ`070>:XJ`80WgI91@3/[fh00`2OMTT0kk5_09mfB@050>F[K00309mf
B@3f]W80m[Ib00<0m[Ib00<0WgI90>FYJ`2OMTT01@3[[Vh209mfB@H0l;9`00D0WgI90>n`K`2OMTT0
nk]d09mfB@050?fmMP0409mfB@3oa7T0WgI909mfB@80olEj00<0WgI90?o8N`3ob7/00P2OMTT01@3n
_WL0WgI90?o5M`3oaGL0WgI90080ol5g0P2OMTT20?o6NP80WgI90`3ob7X00`2OMTT0k;I]0>bfK@02
09mfBHl0VM3U0@3oool009l0VM3U00<0WgI90:N1EP2OMTT00P2OMTT01P1gH4<0WgI909mfB@2DLdh0
WgI90:^3E`80WgI90`2VOeD0102OMTT0`I5O0<6AG`2OMTT30<JEH@0309mfB@3>VF<0WgI90080dYeU
00@0WgI90=BMI@3DWFD0WgI9103:VF<0102OMTT0fZ9W0=ZRI`3JXVL209mfB@030<RFH@2OMTT0dIaT
00<0dIaT0P2OMTT80=JOIP0309mfB@3RZ6/0hZQ[00L0hZQ[0P2OMTT50>b_KP80WgI91P3UZf`00`2O
MTT0m[Ib0?JfLP030?JfLP0309mfB@3UZF/0WgI900D0jji^00<0WgI90?2bL03`/W001P3`/W0309mf
B@D0oKef00<0WgI90?o4N@2OMTT00`3oaGX0102OMTT0olQk0?o8N`2OMTT20?jnM`0409mfB@3oaGL0
olEg09mfB@80ol5g0P2OMTT20?o6NP80WgI90`3ob7X00`2OMTT0k;I]0>bfK@0209mfBI00VM3U0@3o
ool00:00VM3U00H0WgI90:N1EP2OMTT0NFA509mfB@1gH4<209mfB@0409AcCP2OMTT0Zh=G0:^3E`80
WgI90P2VOeD00`2OMTT0`I5O09mfB@040<JEH@80WgI90`3BWFD00`2OMTT0e9eU09mfB@040<ZIH`03
09mfB@3JXVL0fZ9W00<0fZ9W0P2OMTT50=6LI00309mfB@3FWfH0eYmV00L0eYmV00<0WgI90>:XJ`3R
Z6/01P3RZ6/00`2OMTT0k:m^0>b_KP040>b_KP80WgI91P3UZf`00`2OMTT0m[Ib0?JfLP040?JfLP80
WgI91@3[[Vh00`2OMTT0l;9`0?2bL0060?2bL00309mfB@3m_GH0oKef00@0oKef00<0WgI90?o4N@2O
MTT00`3oaGX0102OMTT0olQk0?o8N`2OMTT20?jnM`0:09mfB@3oaGL0olEg0?o5M`2OMTT0ol5g09mf
B@3oaWX0WgI90?o6NP80WgI90`3ob7X00`2OMTT0k;I]0>bfK@0209mfBI40VM3U0@3oool00:40VM3U
00H0WgI90:N1EP2OMTT0NFA509mfB@1gH4<409mfB@<0Zh=G0P2OMTT00`2VOeD0WgI90<6AG`040<JE
H@0309mfB@3>VF<0WgI900<0dYeU0P2OMTT50<ZIH`0309mfB@3JXVL0fZ9W00<0fZ9W0P2OMTT40=6L
I0<0WgI91`3FWfH00`2OMTT0hZQ[0>:XJ`050>:XJ`80WgI91P3/[fh00`2OMTT0iJ]/0>F[K0050>F[
K00309mfB@3f]W80m[Ib00@0m[Ib00<0WgI90>^^KP3[[Vh0103[[Vh00`2OMTT0l;9`0?2bL0050?2b
L00309mfB@3m_GH0oKef00D0oKef0P2OMTT30?o5NP0409mfB@3ob7/0WgI909mfB@<0o[ig00`0WgI9
0?o5M`3oaGL0WgI90?o1M`2OMTT0olIj09mfB@3oaWX0WgI90?o8N`2OMTT20?o8NP0309mfB@3/]Vd0
WgI90080WgI9TP2Id>D10?ooo`00XP2Id>D0202OMTT0Yh5F09mfB@1iI4D0WgI907MP@`2OMTT0VGQA
0`2OMTT30:^3E`@0WgI91036UF4209mfB@@0dYeU0P2OMTT50<ZIH`0309mfB@3JXVL0fZ9W00<0fZ9W
00<0WgI90=6LI03AW6@00`3AW6@00`2OMTT0f:9W09mfB@060=JOIP0309mfB@3RZ6/0hZQ[00@0hZQ[
00<0WgI90>F[K@2OMTT01P3/[fh00`2OMTT0iJ]/0>F[K0050>F[K00309mfB@3f]W80m[Ib00@0m[Ib
00<0WgI90>^^KP3[[Vh00`3[[Vh00`2OMTT0lK=a09mfB@060?2bL00309mfB@3m_GH0oKef00@0oKef
00<0WgI90?o5NP3oaGX00`3oaGX209mfB@@0o[ig00`0WgI90?o5M`3oaGL0WgI90?o1M`2OMTT0olIj
09mfB@3oaWX0WgI90?o8N`2OMTT20?o8NP0309mfB@3/]Vd0WgI90080WgI9T`2Id>D10?ooo`00X`2I
d>D309mfB@0507UTA@2OMTT0WgI909mfB@2IN5400`2OMTT40:^3E`80WgI91@36UF4209mfB@<0dYeU
0P2OMTT50<ZIH`0309mfB@3JXVL0fZ9W00@0fZ9W00<0WgI90=6LI03AW6@00P3AW6@00`2OMTT0f:9W
0=RRI`0209mfB@@0eYmV00<0WgI90>:XJ`3RZ6/00`3RZ6/0102OMTT0iJ]]0>F[K@2OMTT50>b_KP80
WgI91P3UZf`00`2OMTT0m[Ib0?JfLP050?JfLP0309mfB@3[[Vh0jji^00<0jji^00<0WgI90?6cL@2O
MTT01@3`/W000`2OMTT0oKef0?fmMP030?fmMP80WgI91@3oaGX209mfB@@0o[ig00H0WgI90?o5M`3o
aGL0WgI90?o1M`2OMTT20?o6NP80WgI90P3ob7/709mfBI@0VM3U0@3oool00:@0VM3U0`2OMTT00`1i
I4D0WgI909mfB@0209mfB@0309UhD@2OMTT0WgI900D0Zh=G00<0WgI90<JEH@36UF400`36UF400`2O
MTT0dYeU0=:MI@020=:MI@80WgI91@3:VF<00`2OMTT0fZ9W0=ZRI`040=ZRI`0309mfB@3AW6@0dIaT
0080dIaT00D0WgI90=RRI`3HXVL0f:9W09mfB@040=JOIP0509mfB@3RZ6/0hZQ[0>:XJ`2OMTT00`3U
Zfd00`2OMTT0k:m^0>b_KP020>b_KP0309mfB@3T[6d0WgI900H0iJ]/00<0WgI90?JfLP3f]W80103f
]W8209mfB@@0jji^00@0WgI90?6cL@3a/g40WgI9103`/W000`2OMTT0oKef0?fmMP020?fmMP<0WgI9
1@3oaGX209mfB@@0o[ig00@0WgI90?o5M`3oaGL0olEg0P2OMTT20?o6NP80WgI90P3ob7/709mfBID0
VM3U0@3oool00:D0VM3U0`2OMTT01P1iI4D0WgI909mfB@1gH4<0WgI909UhD@80WgI91@2[PeL00`2O
MTT0aYEQ0<JEH@020<JEH@80WgI9103BWFD00`2OMTT0bYUS0<ZIH`040<ZIH`0309mfB@3JXVL0fZ9W
00<0fZ9W0P2OMTT30=6LI00309mfB@3HXVL0f:9W0080f:9W0P2OMTT20=JOIP0509mfB@3RZ6/0hZQ[
0>:XJ`2OMTT00`3UZfd00`2OMTT0k:m^0>b_KP020>b_KP0309mfB@3T[6d0WgI900H0iJ]/00<0WgI9
0?JfLP3f]W80103f]W800`2OMTT0nKYd09mfB@030>^^KP0509mfB@3a/g40lK=a0?6cL@2OMTT00`3`
/W001@2OMTT0oKef0?fmMP3m_GH0WgI90080oKig00<0WgI90?o5NP3oaGX00P3oaGX00`2OMTT0o[ig
0?jnM`030?jnM`0409mfB@3oaGL0olEg0?o5M`80WgI90P3oaWX209mfB@80olQk0`2OMTT0103[]Vh0
WgI909mfB@2OMTVF09W@i@40oooo002V09W@i@<0WgI90P1iI4D309mfB@0309UhD@2OMTT0WgI900D0
Zh=G00L0WgI90<JEH@36UF40aYEQ09mfB@3;VV@0WgI900<0dYeU0P2OMTT50<ZIH`0309mfB@3JXVL0
fZ9W00@0fZ9W0P2OMTT30=6LI00309mfB@3HXVL0f:9W00<0f:9W00<0WgI90=JOIP2OMTT00P3RZ6/0
0`2OMTT0iJ]]0>F[K@030>F[K@0409mfB@3/[fh0k:m^09mfB@80i:a]00<0WgI90>F[K03UZf`0103U
Zf`00`2OMTT0m[Ib0?JfLP030?JfLP0409mfB@3i^W@0nKYd09mfB@80jji^00<0WgI90?6cL@3a/g40
0P3a/g40102OMTT0l;9`0?2bL02OMTT20?fmMP80WgI90P3m_WL0102OMTT0olEj0?o5NP3oaGX209mf
B@D0o[ig00@0WgI90?o5M`3oaGL0olEg0P2OMTT30?o6NP0409mfB@3ob7/0olQk0?o8N`80WgI900@0
jkI^09mfB@2OMTT0WgI9U`2Id>D10?ooo`00Y`2Id>D309mfB@80NFA50`2OMTT209UhD@80WgI9102[
PeL01`2OMTT0aYEQ0<JEH@36UF40WgI90<^JI02OMTT00`3BWFD209mfB@D0bYUS00<0WgI90=ZRI`3J
XVL00`3JXVL01P2OMTT0gjMZ09mfB@2OMTT0dIaT09mfB@H0f:9W102OMTT60>F[K@0309mfB@3/[fh0
WgI900<0i:a]00<0WgI90>F[K03UZf`00`3UZf`209mfB@D0m[Ib00@0WgI90?VjM03i^W@0WgI90P3[
[Vh00`2OMTT0lK=a0?6cL@020?6cL@0409mfB@3`/W00WgI90?fmMP80WgI90`3m_WL0102OMTT0olEj
0?o5NP3oaGX209mfB@D0o[ig00<0WgI90?o5M`3oaGL00P3oaGL01@2OMTT0olIj0?o6NP3oaWX0WgI9
00<0olQk00<0WgI9020F3@3[]Vh00`2OMTVH09W@i@40oooo002X09W@i@@0WgI900@0NFA509mfB@2O
MTT0WgI90P2IN54309mfB@<0Zh=G00@0WgI90<JEH@36UF40WgI90P3;VV@01P2OMTT0dYeU0=:MI@2O
MTT0bY]U09mfB@@0bYUS0`2OMTT40=ZRI`0609mfB@3OYfX0gjMZ09mfB@3AW6@0WgI91`3HXVL00`2O
MTT0iJ]]0>F[K@050>F[K@80WgI90`3T[6d00`2OMTT0iJ]/0>F[K0030>F[K080WgI900<0ije^09mf
B@3f]W800P3f]W801`2OMTT0nKYd0?VjM03i^W@0WgI90>^^KP2OMTT01P3a/g4309mfB@@0oKig00<0
WgI90?o5NP3oaGX00`2OMTT50?jnM`0309mfB@3oaGL0olEg0080olEg00D0WgI90?o6NP3oaWX0olIj
09mfB@030?o8N`0309mfB@3[]Vh0WgI900<0WgI9V@2Id>D10?ooo`00ZP2Id>D309mfB@0407UTA@2O
MTT0WgI909mfB@80VGQA102OMTT20:^3E`0309mfB@36UF40WgI900<0biYT00<0WgI90=:MI@2OMTT0
0P3:VfD01P2OMTT0bYUS0<ZIH`3:VF<0WgI90=nXJ`80WgI90`3JXVL0102OMTT0gjMZ0=nWJP3OYfX2
09mfB@L0f:9W00<0WgI90>F[K@3UZfd01@3UZfd209mfB@<0i:a]00<0WgI90>F[K03UZf`00P3UZf`0
1@2OMTT0mKQd09mfB@3W[Fh0WgI900<0m[Ib00<0WgI90?VjM03i^W@00P3i^W@209mfB@H0lK=a00<0
WgI90?fnM`3m_WL00`3m_WL01P2OMTT0olEj09mfB@2OMTT0nKaf09mfB@D0o[ig00<0WgI90?o5M`3o
aGL00P3oaGL00`2OMTT0olIj0?o6NP0209mfB@80olQk0P2OMTT00`3[]Vh0WgI909mfB@0209mfBIX0
VM3U0@3oool00:/0VM3U0`2OMTT0101iI4D0WgI90;R;F`2OMTT309UhD@0509mfB@2`R5X0WgI909mf
B@2[PeL00P2OMTT40<^JI00309mfB@3BWFD0WgI90080bY]U00H0WgI90<ZIH`3:VF<0bYUS09mfB@3O
Z6/209mfB@<0fZ9W00@0WgI90=nWJP3OYfX0gjMZ0P2OMTT60=RRI`0309mfB@3UZfd0iJ]]00D0iJ]]
00<0WgI90>B/K@3T[6d00P3T[6d01@2OMTT0iJ]/0>F[K03UZf`0WgI90080mKQd00<0WgI90>N]KP2O
MTT00`3f]W800`2OMTT0nKYd0?VjM0020?VjM00309mfB@3a/g40lK=a00@0lK=a00<0WgI90?fnM`3m
_WL0103m_WL209mfB@80nKaf00<0WgI90?jnM`3n_WL00`3n_WL0102OMTT0olEg0?o5M`3oaGL209mf
B@80olIj00D0WgI90?o7N`2OMTT0olQk09mfB@020>^fKP@0WgI9V`2Id>D10?ooo`00[02Id>D0102O
MTT0WWaC09mfB@1iI4D409mfB@80VGQA00<0WgI90;28FP2`R5X0102OMTT40<^JI080WgI90P3:VfD0
202OMTT0bYUS0<ZIH`3:VF<0WgI90=nXJ`2OMTT0cYaU0P2OMTT20=ZRI`0509mfB@3OYfX0gjMZ0=nW
JP2OMTT01`3HXVL00`2OMTT0iJ]]0>F[K@030>F[K@0309mfB@3T[6d0i:a]00<0i:a]00@0WgI90>F[
K03UZf`0WgI90P3e^7@01`2OMTT0ije^0>N]KP3W[Fh0WgI90?JfLP2OMTT01@3i^W@00`2OMTT0lK=a
0?6cL@040?6cL@0309mfB@3m_WL0oKig00<0oKig0P2OMTT20?VlMP0309mfB@3n_WL0o[ig0080o[ig
0P2OMTT30?o5M`0:09mfB@3l`WH0WgI90?o6NP2OMTT0olMk09mfB@3ob7/0WgI90>^fKP@0WgI9W@2I
d>D10?ooo`00[@2Id>D00`2OMTT0WWaC09mfB@0207UTA@0609mfB@2hRe/0WgI909mfB@2IN540WgI9
0`2`R5X209mfB@D0biYT0P2OMTT20<ZKI@0409mfB@3:VF<0bYUS09mfB@80gjQ[00H0WgI90<jLI@3>
W6D0WgI90=ZRI`2OMTT40=nWJP80WgI91@3HXVL00`2OMTT0iJ]]0>F[K@020>F[K@0309mfB@3T[6d0
i:a]00@0i:a]00<0WgI90>F[K02OMTT00`3e^7@01`2OMTT0ije^0>N]KP3W[Fh0WgI90?JfLP2OMTT0
1P3i^W@00`2OMTT0lK=a0?6cL@020?6cL@0309mfB@3m_WL0oKig0080oKig0P2OMTT30?VlMP0409mf
B@3n_WL0o[ig0?jnM`<0WgI90`3oaGL0202OMTT0o<9f09mfB@3oaWX0WgI90?o7N`2OMTT0olQk0`2O
MTT00`0F40X0WgI909mfB@2N09W@i@40oooo002^09W@i@@0WgI900<0NFA509mfB@2hRe/0102OMTT4
0;28FP0309mfB@3;VV@0biYT00<0biYT00L0WgI90<ZKI@3:VfD0bY]U09mfB@3:VF<0WgI900<0gjQ[
00H0WgI90<jLI@3>W6D0WgI90=ZRI`2OMTT50=nWJP80WgI90`3HXVL01@2OMTT0iJ]]0>F[K@3UZfd0
WgI900L0i:a]0P2OMTT40?FhM00309mfB@3W[Fh0ije^0080ije^00<0WgI90?VjM03i^W@01@3i^W@0
1@2OMTT0lK=a0?6cL@3a/g40WgI900<0oKig0P2OMTT40?VlMP0309mfB@3n_WL0o[ig00<0WgI900<0
o[mg09mfB@3oaGL00P2OMTT01@3l`WH0WgI90?o6NP2OMTT0olMk00D0WgI900<05Q0:09mfB@2OMTT0
W`2Id>D10?ooo`00/02Id>D309mfB@0407UTA@2OMTT0WgI90;R;F`@0WgI90`2`R5X209mfB@<0biYT
00<0WgI90<ZKI@3:VfD00P3:VfD00`2OMTT0bYUS09mfB@030=nXJ`0309mfB@3>W6D0cYaU0080WgI9
1`3OYfX209mfB@050=RRI`2OMTT0iJ]]0>F[K@2OMTT0203T[6d00`2OMTT0mKQd0?FhM0030?FhM003
09mfB@3W[Fh0ije^0080ije^00<0WgI90?VjM03i^W@01P3i^W@00`2OMTT0lK=a09mfB@020?fnM`80
WgI91@3i_7H02P2OMTT0o[ig09mfB@2OMTT0olAi09mfB@3n_gL0WgI90?o5M`2OMTT20?c2MP<0WgI9
0P3oag/709mfBJ00VM3U0@3oool00;40VM3U2`2OMTT40;28FP0509mfB@3;VV@0biYT0<^JI02OMTT0
103:VfD209mfB@@0gjQ[00@0WgI90<jLI@3>W6D0cYaU0P2OMTT70=nWJP@0WgI9203T[6d209mfB@@0
mKQd00<0WgI90>N]KP3W[Fh00`3W[Fh209mfB@L0nKYd00<0WgI90?6cL@2OMTT00P2OMTT60?VlMP<0
WgI90P3oa7T01@2OMTT0o[mg09mfB@3oaGL0WgI900<0o<9f00@0WgI90?o7N`3oag/0olMk1P2OMTVR
09W@i@40oooo002b09W@i@`0WgI90`2`R5X0102OMTT0biYT0<^JI02OMTT50<ZKI@0309mfB@3OZ6/0
gjQ[00<0gjQ[00@0WgI90<jLI@3>W6D0cYaU0`2OMTT70=nWJP0309mfB@3T[6d0i:a]00D0i:a]0P2O
MTT00`3]/g40WgI90?FhM0030?FhM00309mfB@3W[Fh0ije^0080ije^00<0WgI90?2eLP2OMTT0203i
^W@209mfB@L0nKaf0P2OMTT20?o4N@80WgI900@0o[mg09mfB@2OMTT0WgI90`3l`WH00`2OMTT0olMk
0?o7N`0709mfBJ<0VM3U0@3oool00;@0VM3U2@2OMTT01@32Tf00WgI909mfB@2OMTT0/8QJ00<0WgI9
1@3:VfD209mfB@@0gjQ[00<0WgI90<jLI@3>W6D00P3>W6D0102OMTT0fjIZ09mfB@2OMTT50=nWJP03
09mfB@3T[6d0i:a]00@0i:a]00D0WgI90>fcL@3]/g40kK=a09mfB@040?FhM00309mfB@3W[Fh0ije^
0080ije^00@0WgI90?2eLP3`]G80WgI91P3i^W@00`2OMTT0nKaf0?VlMP030?VlMP@0WgI90`3oa7T0
1@2OMTT0o[mg0?joM`3n_gL0WgI900@0o<9f00<0WgI90?o7N`2OMTT01`2OMTVT09W@i@40oooo002e
09W@i@X0WgI90P32Tf0509mfB@@0bY]U00@0WgI90=RUJP2OMTT0WgI90`3OZ6/01@2OMTT0cYaU0<jL
I@3>W6D0WgI900<0fjIZ0P2OMTT40=nWJP0309mfB@3T[6d0i:a]0080i:a]00<0WgI90>fcL@3]/g40
0P3]/g401@2OMTT0mKQd0?FhM03e^7@0WgI900@0ije^00<0WgI90?2eLP3`]G800P3`]G800`2OMTT0
nKYd0?VjM0020?VjM00309mfB@3i_7H0nKaf0080nKaf0P2OMTT20?c0N00509mfB@3oa7T0olAi0?o4
N@2OMTT00`3n_gL00`2OMTT0o<9f0?c2MP020?c2MP0309mfB@3oag/0WgI900H0WgI9YP2Id>D10?oo
o`00]`2Id>D00`2OMTT0NVE509mfB@0709mfB@<0`Y=P0P2OMTT40<ZKI@0509mfB@3HYFX0f:EZ0=RU
JP2OMTT00`3OZ6/01@2OMTT0cYaU0<jLI@3>W6D0WgI900@0fjIZ0P2OMTT20=nWJP0309mfB@3T[6d0
i:a]0080WgI91@3]/g401@2OMTT0mKQd0?FhM03e^7@0WgI900@0ije^00<0WgI90?2eLP3`]G800`3`
]G80102OMTT0nKYd0?VjM02OMTT20?VlMP<0WgI90`3l`7P01@2OMTT0olAi0?o4N@3oa7T0WgI90080
o[mg0P2OMTT40?c2MP@0WgI900@0lkad09mfB@2OMTT0WgI9Z02Id>D10?ooo`00^02Id>D509mfB@03
0<2DH@2OMTT0WgI900@0WgI90P32Tf0209mfB@<0bY]U00D0WgI90=RUJP3HYFX0f:EZ09mfB@030=nX
J`0509mfB@3>W6D0cYaU0<jLI@2OMTT01@3KYVX209mfB@030=nWJP2OMTT0WgI900L0kK=a00<0WgI9
0?FhM03e^7@00`2OMTT20>N]KP0309mfB@3`]G80l;Eb00@0l;Eb00<0WgI90?VjM02OMTT00`2OMTT5
0?c0N00309mfB@3oa7T0olAi0080WgI90P3n_gL209mfB@@0o<9f0`2OMTT20?>lM0<0WgI9Z@2Id>D1
0?ooo`00^P2Id>D409mfB@80`9AQ00<0WgI908I^B`2OMTT0102OMTT01@32Tf00WgI90<ZKI@3:VfD0
WgI900@0f:EZ00<0WgI90=nXJ`3OZ6/00`2OMTT20<jLI@0309mfB@3KYVX0fjIZ00@0fjIZ0P2OMTT8
0>fcL@0609mfB@3e^7@0WgI909mfB@3g^gH0WgI90P3W[Fh00`2OMTT0l;Eb0?2eLP050?2eLP80WgI9
1P3l`7P209mfB@80olAi00<0WgI90?joM`3n_gL00`2OMTT40?c2MP80WgI90P3c_7@309mfBJ/0VM3U
0@3oool00;`0VM3U102OMTT01@30U640WgI909mfB@26KT/0WgI90080]8iM1@2OMTT50=RUJP<0WgI9
00<0cj9X09mfB@2OMTT00P2OMTT70=^VJP0309mfB@3]/g40kK=a00H0kK=a0P2OMTT0103T[g00WgI9
0?NkMP3g^gH209mfB@L0l;Eb00<0WgI90?c0N03l`7P01@3l`7P00`2OMTT0olAi0?o4N@0209mfB@80
o[mg00@0WgI90?o3N@3o`gT0WgI90P3l`WH209mfB@80lkad102OMTV/09W@i@40oooo002n09W@i@@0
WgI900<0`9AQ09mfB@2OMTT00P2OMTT30;B>G@80WgI91`3HYFX209mfB@80cj9X0`2OMTT70=^VJP03
09mfB@3]/g40kK=a00D0kK=a00@0WgI90>B_L03T[g00WgI90`3g^gH00`2OMTT0l;Eb0?2eLP040?2e
LP0309mfB@3l`7P0o<1h00D0o<1h00<0WgI90?o4N@2OMTT00P2OMTT00`3n_gL0WgI909mfB@020?o3
N@0309mfB@3l`WH0WgI900L0WgI9[P2Id>D10?ooo`00`02Id>D409mfB@040<2DH@2OMTT0WgI909mf
B@@0]8iM0P2OMTT60=RUJP0609mfB@3?XVP0cj9X0<nRJ02OMTT0iJe^0P2OMTT50=^VJP0309mfB@3]
/g40kK=a00<0kK=a0P2OMTT20>B_L00309mfB@3g^gH0mk]f00<0mk]f00<0WgI90?2eLP3`]G800P3`
]G800`2OMTT0o<1h0?c0N0050?c0N0D0WgI900<0o[mg09mfB@3o`gT00P3o`gT909mfBK00VM3U0@3o
ool00<80VM3U202OMTT40;B>G@80WgI9103HYFX00`2OMTT0cj9X0<nRJ0020<nRJ00309mfB@3U[Fh0
iJe^00<0WgI90`3KYVX01@2OMTT0kK=a0>fcL@3]/g40WgI900@0i:m`00<0WgI90?NkMP3g^gH00`3g
^gH01@2OMTT0l;Eb0?2eLP3`]G80WgI900D0o<1h1@2OMTT20?:kM080WgI90`3o`gT209mfB@030<^R
H`2OMTT0WgI900<0WgI9/P2Id>D10?ooo`00a02Id>D809mfB@@0]8iM0P2OMTT20=RUJP0309mfB@3?
XVP0cj9X00<0cj9X00<0WgI90>F]KP3U[Fh00P3U[Fh409mfB@030>fcL@2OMTT0WgI900D0i:m`00<0
WgI90?NkMP3g^gH0103g^gH0102OMTT0l;Eb09mfB@3l`7P509mfB@030>nhM02OMTT0WgI900<0l[]d
00<0WgI90?o3N@3o`gT00P2OMTT20<^RH`D0WgI9]02Id>D10?ooo`00aP2Id>D;09mfB@050;B>G@2O
MTT0WgI90=RUJP2OMTT01@3?XVP209mfB@D0iJe^0P2OMTT70>B_L00309mfB@3g^gH0mk]f00D0mk]f
0`2OMTT40>nhM080WgI9103b^g@409mfB@80bj9S102OMTVg09W@i@40oooo003809W@i@@0WgI90`2Q
Q5H709mfB@L0cj9X00<0WgI90>F]KP3U[Fh0103U[Fh00`2OMTT0i:m`0>B_L0030>B_L00309mfB@3g
^gH0mk]f00@0mk]f0P2OMTT50>nhM080WgI9103b^g@909mfBKX0VM3U0@3oool00<X0VM3U1@2OMTT3
0:64EP80WgI90`3<WFH209mfB@D0cj9X102OMTT20>F]KP0409mfB@3T[g00i:m`0>B_L0@0WgI90`3g
^gH209mfB@D0kkQd0P2OMTT40?:kM0T0WgI9_02Id>D10?ooo`00cP2Id>D409mfB@80XHAF0`2OMTT2
0<bMIP<0WgI900@0cj9X09mfB@2dTUh0]99N202OMTT0103=XVP0WgI90=b/KP3L[6h:09mfB@<0l[]d
0`2OMTT20>FcL00401H@2P2OMTT0WgI909mfBKl0VM3U0@3oool00=40VM3U1@2OMTT00`2QQ5H0WgI9
09mfB@0509mfB@@0]99N0`2OMTT40<fRJ00309mfB@3L[6h0g:a^00<0g:a^102OMTT0103R/700WgI9
0?:kM03b^g@209mfB@80iK=`00@05Q0:09mfB@2OMTT0WgI9`P2Id>D10?ooo`00eP2Id>D509mfB@03
09f2D`2OMTT0WgI900H0WgI900D0]99N09mfB@2OMTT0cJ9X09mfB@020=b/KP@0WgI91@3R/70809mf
BLD0VM3U0@3oool00=X0VM3U0`2OMTT709f2D``0WgI90P3J[6`509mfBLX0VM3U0@3oool00=h0VM3U
5@2OMTW>09W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@
i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o
09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U
0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0
VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D1
0?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2I
d>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40
oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@
iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3o
ool00?l0VM3U`P2Id>D10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 449}, {263.688, 0}} -> {-0.000855365, 0.1632, \
0.00215823, 0.00215823}}]
}, Open  ]],

Cell["\<\
The following constructs vertical walls by fine graining the points that \
define the star, partitioning the points, and construction the vertices of a \
vertical polygon.\
\>", "Text"],

Cell[BoxData[{
    \(\(Table[\((1 +  .33  Cos[8  t])\) {Cos[t], Sin[t]}, {t, 0, 
          2  \[Pi], \[Pi]/8}];\)\), "\[IndentingNewLine]", 
    \(\(% // FineGrainPoints[0.2, 4];\)\), "\[IndentingNewLine]", 
    \(\(Partition[%, \ 2, 1];\)\), "\[IndentingNewLine]", 
    \(\(walls = \({Flatten[{First[#], \(-0.7689\)}], 
              Flatten[{Last[#], \(-0.7689\)}], 
              Flatten[{Last[#], \(1 - #1\^2 - #2\^2 &\) @@ Last[#]}], 
              Flatten[{First[#], \(1 - #1\^2 - #2\^2 &\) @@ 
                    First[#]}]} &\) /@ %;\)\)}], "Input",
  CellLabel->"In[322]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{SurfaceColor[Melon], 
          EdgeForm[\(ColorMix[Melon, Black]\)[
              0.3]], \[IndentingNewLine]Polygon /@ grid // 
            RaiseTo3D[1 - #1\^2 - #2\^2 &], \[IndentingNewLine]SurfaceColor[
            DodgerBlue], 
          EdgeForm[\(ColorMix[DodgerBlue, White]\)[
              0.2]], \[IndentingNewLine]Polygon /@ 
            walls}, \[IndentingNewLine]NeutralLighting[0.3, 0.5, 
          0.1], \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            0.5}, \[IndentingNewLine]Boxed \[Rule] 
          False, \[IndentingNewLine]ViewPoint -> {1.917, \ \(-2.677\), \ 
            0.779}, \[IndentingNewLine]Background \[Rule] \(ColorMix[Peacock, 
              White]\)[0.5], \[IndentingNewLine]ImageSize \[Rule] 
          450];\)\)], "Input",
  CellLabel->"In[326]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .58831 
%%ImageSize: 450 264.738 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.6 .815 .895 r
MFill
% Scaling calculations
8.9013e-017 1.03377 -0.168714 1.03377 [
[ 0 0 0 0 ]
[ 1 .58831 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .58831 L
0 .58831 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.753 .53 .33 r
.46938 .27266 m .46056 .33293 L .4667 .37738 L p F P
.623 .462 .287 r
s
.753 .53 .33 r
.4667 .37738 m .47563 .34296 L .46938 .27266 L p F P
.623 .462 .287 r
s
.695 .488 .307 r
.48896 .33404 m .46938 .27266 L .47563 .34296 L p F P
.623 .462 .287 r
s
.064 .302 .589 r
.48916 .2631 m .46938 .27266 L .48896 .33404 L closepath p F P
.294 .652 1 r
s
.119 .556 .927 r
.46938 .27266 m .46096 .26187 L .46056 .33293 L closepath p F P
.294 .652 1 r
s
.064 .302 .589 r
.50954 .25325 m .48916 .2631 L .48896 .33404 L p F P
.294 .652 1 r
s
.119 .556 .927 r
.45138 .38414 m .46056 .33293 L .46096 .26187 L p F P
.294 .652 1 r
s
.119 .556 .927 r
.46096 .26187 m .45225 .2507 L .45138 .38414 L p F P
.294 .652 1 r
s
.113 .529 .937 r
.68992 .2592 m .65651 .25275 L .65752 .32475 L closepath p F P
.294 .652 1 r
s
.637 .448 .288 r
.68992 .2592 m .65752 .32475 L .642 .37066 L p F P
.623 .462 .287 r
s
.637 .448 .288 r
.642 .37066 m .66674 .33258 L .68992 .2592 L p F P
.623 .462 .287 r
s
.515 .356 .235 r
.68236 .32066 m .68992 .2592 L .66674 .33258 L p F P
.623 .462 .287 r
s
.118 .549 .915 r
.68116 .24818 m .68992 .2592 L .68236 .32066 L closepath p F P
.294 .652 1 r
s
.695 .488 .307 r
.47563 .34296 m .492 .37829 L .48896 .33404 L p F P
.623 .462 .287 r
s
.671 .468 .295 r
.50944 .3862 m .48896 .33404 L .492 .37829 L p F P
.623 .462 .287 r
s
.064 .302 .589 r
.48896 .33404 m .50944 .3862 L .50954 .25325 L p F P
.294 .652 1 r
s
.749 .526 .325 r
.46056 .33293 m .45138 .38414 L .45871 .41696 L p F P
.623 .462 .287 r
s
.749 .526 .325 r
.45871 .41696 m .4667 .37738 L .46056 .33293 L p F P
.623 .462 .287 r
s
.695 .487 .307 r
.4808 .39081 m .47563 .34296 L .4667 .37738 L p F P
.623 .462 .287 r
s
.711 .497 .31 r
.47563 .34296 m .4808 .39081 L .49517 .41709 L p F P
.623 .462 .287 r
s
.711 .497 .31 r
.49517 .41709 m .492 .37829 L .47563 .34296 L p F P
.623 .462 .287 r
s
.064 .302 .589 r
.53055 .24309 m .50954 .25325 L .50944 .3862 L p F P
.294 .652 1 r
s
.113 .529 .937 r
.62387 .38048 m .65752 .32475 L .65651 .25275 L p F P
.294 .652 1 r
s
.113 .529 .937 r
.65651 .25275 m .62244 .24617 L .62387 .38048 L p F P
.294 .652 1 r
s
.119 .556 .927 r
.44186 .42545 m .45138 .38414 L .45225 .2507 L p F P
.294 .652 1 r
s
.119 .556 .927 r
.45225 .2507 m .44323 .23914 L .44186 .42545 L p F P
.294 .652 1 r
s
.118 .549 .915 r
.67211 .23679 m .68116 .24818 L .68236 .32066 L p F P
.294 .652 1 r
s
.646 .453 .29 r
.65752 .32475 m .62387 .38048 L .61182 .41391 L p F P
.623 .462 .287 r
s
.646 .453 .29 r
.61182 .41391 m .642 .37066 L .65752 .32475 L p F P
.623 .462 .287 r
s
.689 .479 .298 r
.492 .37829 m .49517 .41709 L .51113 .44691 L p F P
.623 .462 .287 r
s
.689 .479 .298 r
.51113 .44691 m .51027 .41867 L .492 .37829 L p F P
.623 .462 .287 r
s
.671 .468 .295 r
.492 .37829 m .51027 .41867 L .50944 .3862 L p F P
.623 .462 .287 r
s
.113 .529 .937 r
.58901 .42569 m .62387 .38048 L .62244 .24617 L p F P
.294 .652 1 r
s
.113 .529 .937 r
.62244 .24617 m .58768 .23946 L .58901 .42569 L p F P
.294 .652 1 r
s
.694 .485 .303 r
.4731 .41636 m .4667 .37738 L .45871 .41696 L p F P
.623 .462 .287 r
s
.695 .487 .307 r
.4667 .37738 m .4731 .41636 L .4808 .39081 L p F P
.623 .462 .287 r
s
.064 .302 .589 r
.50944 .3862 m .5308 .42836 L .53055 .24309 L p F P
.294 .652 1 r
s
.629 .435 .275 r
.5308 .42836 m .50944 .3862 L .51027 .41867 L p F P
.623 .462 .287 r
s
.522 .361 .237 r
.64766 .38251 m .66674 .33258 L .642 .37066 L p F P
.623 .462 .287 r
s
.583 .405 .262 r
.66674 .33258 m .64766 .38251 L .64493 .40823 L p F P
.623 .462 .287 r
s
.583 .405 .262 r
.64493 .40823 m .66399 .3673 L .66674 .33258 L p F P
.623 .462 .287 r
s
.515 .356 .235 r
.66674 .33258 m .66399 .3673 L .68236 .32066 L p F P
.623 .462 .287 r
s
.477 .326 .216 r
.67424 .37289 m .68236 .32066 L .66399 .3673 L p F P
.623 .462 .287 r
s
.118 .549 .915 r
.68236 .32066 m .67424 .37289 L .67211 .23679 L p F P
.294 .652 1 r
s
.064 .302 .589 r
.55222 .23261 m .53055 .24309 L .5308 .42836 L p F P
.294 .652 1 r
s
.667 .465 .293 r
.48621 .43174 m .4808 .39081 L .4731 .41636 L p F P
.623 .462 .287 r
s
.686 .476 .295 r
.4808 .39081 m .48621 .43174 L .49846 .45007 L p F P
.623 .462 .287 r
s
.686 .476 .295 r
.49846 .45007 m .49517 .41709 L .4808 .39081 L p F P
.623 .462 .287 r
s
.727 .506 .312 r
.45138 .38414 m .44186 .42545 L .45045 .44856 L p F P
.623 .462 .287 r
s
.727 .506 .312 r
.45045 .44856 m .45871 .41696 L .45138 .38414 L p F P
.623 .462 .287 r
s
.097 .452 .825 r
.30908 .23712 m .26828 .24038 L .30755 .31073 L closepath p F P
.294 .652 1 r
s
.726 .5 .29 r
.26828 .24038 m .28791 .30472 L .31394 .3543 L p F P
.623 .462 .287 r
s
.726 .5 .29 r
.31394 .3543 m .30241 .31818 L .26828 .24038 L p F P
.623 .462 .287 r
s
.753 .523 .317 r
.30755 .31073 m .26828 .24038 L .30241 .31818 L p F P
.623 .462 .287 r
s
.065 .302 .588 r
.26828 .24038 m .2896 .23042 L .28791 .30472 L closepath p F P
.294 .652 1 r
s
.113 .529 .937 r
.55302 .45971 m .58901 .42569 L .58768 .23946 L p F P
.294 .652 1 r
s
.113 .529 .937 r
.58768 .23946 m .55222 .23261 L .55302 .45971 L p F P
.294 .652 1 r
s
.119 .556 .927 r
.43199 .45601 m .44186 .42545 L .44323 .23914 L p F P
.294 .652 1 r
s
.119 .556 .927 r
.44323 .23914 m .4339 .22717 L .43199 .45601 L p F P
.294 .652 1 r
s
.633 .441 .282 r
.62387 .38048 m .58901 .42569 L .58075 .44876 L p F P
.623 .462 .287 r
s
.633 .441 .282 r
.58075 .44876 m .61182 .41391 L .62387 .38048 L p F P
.623 .462 .287 r
s
.097 .452 .825 r
.35028 .23384 m .30908 .23712 L .30755 .31073 L p F P
.294 .652 1 r
s
.543 .375 .244 r
.62588 .41093 m .642 .37066 L .61182 .41391 L p F P
.623 .462 .287 r
s
.522 .361 .237 r
.642 .37066 m .62588 .41093 L .64766 .38251 L p F P
.623 .462 .287 r
s
.118 .549 .915 r
.66274 .22499 m .67211 .23679 L .67424 .37289 L p F P
.294 .652 1 r
s
.659 .453 .281 r
.49517 .41709 m .49846 .45007 L .51202 .47066 L p F P
.623 .462 .287 r
s
.659 .453 .281 r
.51202 .47066 m .51113 .44691 L .49517 .41709 L p F P
.623 .462 .287 r
s
.638 .439 .274 r
.51027 .41867 m .51113 .44691 L .52759 .47053 L p F P
.623 .462 .287 r
s
.638 .439 .274 r
.52759 .47053 m .52922 .45102 L .51027 .41867 L p F P
.623 .462 .287 r
s
.629 .435 .275 r
.51027 .41867 m .52922 .45102 L .5308 .42836 L p F P
.623 .462 .287 r
s
.097 .452 .825 r
.30755 .31073 m .34799 .3705 L .35028 .23384 L p F P
.294 .652 1 r
s
.097 .452 .825 r
.39189 .23052 m .35028 .23384 L .34799 .3705 L p F P
.294 .652 1 r
s
.662 .459 .287 r
.47975 .44948 m .4731 .41636 L .46629 .4455 L p F P
.623 .462 .287 r
s
.667 .465 .293 r
.4731 .41636 m .47975 .44948 L .48621 .43174 L p F P
.623 .462 .287 r
s
.694 .485 .303 r
.45871 .41696 m .46629 .4455 L .4731 .41636 L p F P
.623 .462 .287 r
s
.561 .387 .25 r
.66399 .3673 m .64493 .40823 L .63785 .43785 L p F P
.623 .462 .287 r
s
.561 .387 .25 r
.63785 .43785 m .6563 .4076 L .66399 .3673 L p F P
.623 .462 .287 r
s
.477 .326 .216 r
.66399 .3673 m .6563 .4076 L .67424 .37289 L p F P
.623 .462 .287 r
s
.064 .302 .589 r
.5308 .42836 m .55302 .45971 L .55222 .23261 L p F P
.294 .652 1 r
s
.753 .523 .317 r
.30241 .31818 m .33114 .3592 L .30755 .31073 L p F P
.623 .462 .287 r
s
.717 .494 .298 r
.34799 .3705 m .30755 .31073 L .33114 .3592 L p F P
.623 .462 .287 r
s
.677 .469 .291 r
.46629 .4455 m .45871 .41696 L .45045 .44856 L p F P
.623 .462 .287 r
s
.476 .325 .215 r
.62777 .42525 m .64766 .38251 L .62588 .41093 L p F P
.623 .462 .287 r
s
.561 .386 .249 r
.64766 .38251 m .62777 .42525 L .62519 .44307 L p F P
.623 .462 .287 r
s
.561 .386 .249 r
.62519 .44307 m .64493 .40823 L .64766 .38251 L p F P
.623 .462 .287 r
s
.566 .386 .245 r
.55302 .45971 m .5308 .42836 L .52922 .45102 L p F P
.623 .462 .287 r
s
.097 .452 .825 r
.34799 .3705 m .38952 .4191 L .39189 .23052 L p F P
.294 .652 1 r
s
.097 .452 .825 r
.4339 .22717 m .39189 .23052 L .38952 .4191 L p F P
.294 .652 1 r
s
.743 .515 .31 r
.33031 .37106 m .30241 .31818 L .31394 .3543 L p F P
.623 .462 .287 r
s
.665 .45 .261 r
.30241 .31818 m .33031 .37106 L .35552 .40171 L p F P
.623 .462 .287 r
s
.665 .45 .261 r
.35552 .40171 m .33114 .3592 L .30241 .31818 L p F P
.623 .462 .287 r
s
.605 .406 .226 r
.28791 .30472 m .30869 .35943 L .33294 .39648 L p F P
.623 .462 .287 r
s
.605 .406 .226 r
.33294 .39648 m .31394 .3543 L .28791 .30472 L p F P
.623 .462 .287 r
s
.065 .302 .588 r
.30869 .35943 m .28791 .30472 L .2896 .23042 L p F P
.294 .652 1 r
s
.065 .302 .588 r
.2896 .23042 m .31157 .22016 L .30869 .35943 L p F P
.294 .652 1 r
s
.625 .431 .271 r
.49187 .46521 m .48621 .43174 L .47975 .44948 L p F P
.623 .462 .287 r
s
.646 .443 .274 r
.48621 .43174 m .49187 .46521 L .50189 .47682 L p F P
.623 .462 .287 r
s
.646 .443 .274 r
.50189 .47682 m .49846 .45007 L .48621 .43174 L p F P
.623 .462 .287 r
s
.544 .373 .241 r
.59939 .443 m .61182 .41391 L .58075 .44876 L p F P
.623 .462 .287 r
s
.543 .375 .244 r
.61182 .41391 m .59939 .443 L .62588 .41093 L p F P
.623 .462 .287 r
s
.391 .258 .174 r
.66553 .41503 m .67424 .37289 L .6563 .4076 L p F P
.623 .462 .287 r
s
.118 .549 .915 r
.67424 .37289 m .66553 .41503 L .66274 .22499 L p F P
.294 .652 1 r
s
.097 .452 .825 r
.38952 .4191 m .43199 .45601 L .4339 .22717 L p F P
.294 .652 1 r
s
.598 .413 .263 r
.58901 .42569 m .55302 .45971 L .55036 .46954 L p F P
.623 .462 .287 r
s
.598 .413 .263 r
.55036 .46954 m .58075 .44876 L .58901 .42569 L p F P
.623 .462 .287 r
s
.685 .472 .289 r
.44186 .42545 m .43199 .45601 L .43829 .46619 L p F P
.623 .462 .287 r
s
.685 .472 .289 r
.43829 .46619 m .45045 .44856 L .44186 .42545 L p F P
.623 .462 .287 r
s
.497 .338 .221 r
.60915 .4452 m .62588 .41093 L .59939 .443 L p F P
.623 .462 .287 r
s
.476 .325 .215 r
.62588 .41093 m .60915 .4452 L .62777 .42525 L p F P
.623 .462 .287 r
s
.118 .549 .915 r
.65304 .21278 m .66274 .22499 L .66553 .41503 L p F P
.294 .652 1 r
s
.717 .494 .298 r
.33114 .3592 m .36732 .40563 L .34799 .3705 L p F P
.623 .462 .287 r
s
.675 .461 .278 r
.38952 .4191 m .34799 .3705 L .36732 .40563 L p F P
.623 .462 .287 r
s
.599 .407 .253 r
.51113 .44691 m .51202 .47066 L .52591 .48677 L p F P
.623 .462 .287 r
s
.599 .407 .253 r
.52591 .48677 m .52759 .47053 L .51113 .44691 L p F P
.623 .462 .287 r
s
.602 .401 .229 r
.33114 .3592 m .35552 .40171 L .38718 .43624 L p F P
.623 .462 .287 r
s
.602 .401 .229 r
.38718 .43624 m .36732 .40563 L .33114 .3592 L p F P
.623 .462 .287 r
s
.611 .414 .255 r
.49846 .45007 m .50189 .47682 L .51293 .4897 L p F P
.623 .462 .287 r
s
.611 .414 .255 r
.51293 .4897 m .51202 .47066 L .49846 .45007 L p F P
.623 .462 .287 r
s
.534 .364 .235 r
.64493 .40823 m .62519 .44307 L .61888 .46342 L p F P
.623 .462 .287 r
s
.534 .364 .235 r
.61888 .46342 m .63785 .43785 L .64493 .40823 L p F P
.623 .462 .287 r
s
.56 .379 .239 r
.52922 .45102 m .52759 .47053 L .54587 .48387 L p F P
.623 .462 .287 r
s
.56 .379 .239 r
.54587 .48387 m .55036 .46954 L .52922 .45102 L p F P
.623 .462 .287 r
s
.566 .386 .245 r
.52922 .45102 m .55036 .46954 L .55302 .45971 L p F P
.623 .462 .287 r
s
.638 .437 .271 r
.47411 .46953 m .46629 .4455 L .45928 .4685 L p F P
.623 .462 .287 r
s
.662 .459 .287 r
.46629 .4455 m .47411 .46953 L .47975 .44948 L p F P
.623 .462 .287 r
s
.677 .469 .291 r
.45045 .44856 m .45928 .4685 L .46629 .4455 L p F P
.623 .462 .287 r
s
.613 .419 .262 r
.48667 .47637 m .47975 .44948 L .47411 .46953 L p F P
.623 .462 .287 r
s
.625 .431 .271 r
.47975 .44948 m .48667 .47637 L .49187 .46521 L p F P
.623 .462 .287 r
s
.743 .515 .31 r
.31394 .3543 m .34078 .39779 L .33031 .37106 L p F P
.623 .462 .287 r
s
.697 .476 .282 r
.34078 .39779 m .31394 .3543 L .33294 .39648 L p F P
.623 .462 .287 r
s
.515 .336 .191 r
.30869 .35943 m .33063 .40367 L .35282 .43029 L p F P
.623 .462 .287 r
s
.515 .336 .191 r
.35282 .43029 m .33294 .39648 L .30869 .35943 L p F P
.623 .462 .287 r
s
.065 .302 .588 r
.33063 .40367 m .30869 .35943 L .31157 .22016 L p F P
.294 .652 1 r
s
.704 .483 .291 r
.3592 .41636 m .33031 .37106 L .34078 .39779 L p F P
.623 .462 .287 r
s
.579 .383 .217 r
.33031 .37106 m .3592 .41636 L .38067 .43795 L p F P
.623 .462 .287 r
s
.579 .383 .217 r
.38067 .43795 m .35552 .40171 L .33031 .37106 L p F P
.623 .462 .287 r
s
.065 .302 .588 r
.31157 .22016 m .3342 .20959 L .33063 .40367 L p F P
.294 .652 1 r
s
.405 .268 .179 r
.6071 .4603 m .62777 .42525 L .60915 .4452 L p F P
.623 .462 .287 r
s
.528 .359 .231 r
.62777 .42525 m .6071 .4603 L .60478 .47147 L p F P
.623 .462 .287 r
s
.528 .359 .231 r
.60478 .47147 m .62519 .44307 L .62777 .42525 L p F P
.623 .462 .287 r
s
.473 .318 .208 r
.6563 .4076 m .63785 .43785 L .63044 .46124 L p F P
.623 .462 .287 r
s
.473 .318 .208 r
.63044 .46124 m .64817 .4398 L .6563 .4076 L p F P
.623 .462 .287 r
s
.391 .258 .174 r
.6563 .4076 m .64817 .4398 L .66553 .41503 L p F P
.623 .462 .287 r
s
.531 .36 .232 r
.57226 .46866 m .58075 .44876 L .55036 .46954 L p F P
.623 .462 .287 r
s
.544 .373 .241 r
.58075 .44876 m .57226 .46866 L .59939 .443 L p F P
.623 .462 .287 r
s
.641 .438 .27 r
.45928 .4685 m .45045 .44856 L .43829 .46619 L p F P
.623 .462 .287 r
s
.496 .335 .217 r
.58658 .46753 m .59939 .443 L .57226 .46866 L p F P
.623 .462 .287 r
s
.497 .338 .221 r
.59939 .443 m .58658 .46753 L .60915 .4452 L p F P
.623 .462 .287 r
s
.675 .461 .278 r
.36732 .40563 m .40428 .44322 L .38952 .4191 L p F P
.623 .462 .287 r
s
.63 .427 .259 r
.43199 .45601 m .38952 .4191 L .40428 .44322 L p F P
.623 .462 .287 r
s
.584 .386 .224 r
.36732 .40563 m .38718 .43624 L .41939 .46407 L p F P
.623 .462 .287 r
s
.584 .386 .224 r
.41939 .46407 m .40428 .44322 L .36732 .40563 L p F P
.623 .462 .287 r
s
.615 .414 .252 r
.49187 .46521 m .48667 .47637 L p .4905 .50313 L F P
.623 .462 .287 r
s
.615 .414 .252 r
.4905 .50313 m .49871 .4939 L .49187 .46521 L p F P
.623 .462 .287 r
s
.458 .297 .186 r
.50189 .47682 m .49187 .46521 L .49871 .4939 L p F P
.623 .462 .287 r
s
.424 .28 .185 r
.59183 .47309 m .60915 .4452 L .58658 .46753 L p F P
.623 .462 .287 r
s
.405 .268 .179 r
.60915 .4452 m .59183 .47309 L .6071 .4603 L p F P
.623 .462 .287 r
s
.539 .358 .221 r
.51202 .47066 m .51293 .4897 L .52419 .49958 L p F P
.623 .462 .287 r
s
.539 .358 .221 r
.52419 .49958 m .52591 .48677 L .51202 .47066 L p F P
.623 .462 .287 r
s
.51 .338 .213 r
.52759 .47053 m .52591 .48677 L .54129 .49568 L p F P
.623 .462 .287 r
s
.51 .338 .213 r
.54129 .49568 m .54587 .48387 L .52759 .47053 L p F P
.623 .462 .287 r
s
.525 .34 .194 r
.35552 .40171 m .38067 .43795 L .40758 .46213 L p F P
.623 .462 .287 r
s
.525 .34 .194 r
.40758 .46213 m .38718 .43624 L .35552 .40171 L p F P
.623 .462 .287 r
s
.257 .164 .111 r
.65624 .44621 m .66553 .41503 L .64817 .4398 L p F P
.623 .462 .287 r
s
.118 .549 .915 r
.66553 .41503 m .65624 .44621 L .65304 .21278 L p F P
.294 .652 1 r
s
.099 .461 .839 r
.69813 .21043 m .65304 .21278 L .65624 .44621 L p F P
.294 .652 1 r
s
.531 .36 .232 r
.55036 .46954 m .54587 .48387 L .57226 .46866 L p F P
.623 .462 .287 r
s
.578 .389 .241 r
.48218 .48882 m .47411 .46953 L .46833 .48511 L p F P
.623 .462 .287 r
s
.613 .419 .262 r
.47411 .46953 m .48218 .48882 L .48667 .47637 L p F P
.623 .462 .287 r
s
.638 .437 .271 r
.45928 .4685 m .46833 .48511 L .47411 .46953 L p F P
.623 .462 .287 r
s
.495 .332 .214 r
.62519 .44307 m .60478 .47147 L .59941 .48409 L p F P
.623 .462 .287 r
s
.495 .332 .214 r
.59941 .48409 m .61888 .46342 L .62519 .44307 L p F P
.623 .462 .287 r
s
.63 .427 .259 r
.40428 .44322 m .43829 .46619 L .43199 .45601 L p F P
.623 .462 .287 r
s
.479 .319 .205 r
.56356 .48525 m .57226 .46866 L .54587 .48387 L p F P
.623 .462 .287 r
s
.496 .335 .217 r
.57226 .46866 m .56356 .48525 L .58658 .46753 L p F P
.623 .462 .287 r
s
.434 .286 .187 r
.63785 .43785 m .61888 .46342 L .61235 .47924 L p F P
.623 .462 .287 r
s
.434 .286 .187 r
.61235 .47924 m .63044 .46124 L .63785 .43785 L p F P
.623 .462 .287 r
s
.099 .461 .839 r
.65624 .44621 m .70167 .40429 L .69813 .21043 L p F P
.294 .652 1 r
s
.099 .461 .839 r
.74352 .20807 m .69813 .21043 L .70167 .40429 L p F P
.294 .652 1 r
s
.581 .386 .231 r
.40428 .44322 m .41939 .46407 L .44889 .48106 L p F P
.623 .462 .287 r
s
.581 .386 .231 r
.44889 .48106 m .43829 .46619 L .40428 .44322 L p F P
.623 .462 .287 r
s
.59 .397 .244 r
.46833 .48511 m .45928 .4685 L .44889 .48106 L p F P
.623 .462 .287 r
s
.641 .438 .27 r
.43829 .46619 m .44889 .48106 L .45928 .4685 L p F P
.623 .462 .287 r
s
.458 .297 .186 r
.51293 .4897 m .50189 .47682 L p .49871 .4939 L F P
.623 .462 .287 r
s
.615 .414 .252 r
.48667 .47637 m .48218 .48882 L .4905 .50313 L p F P
.623 .462 .287 r
s
.646 .435 .257 r
.3684 .43487 m .34078 .39779 L .35776 .42881 L p F P
.623 .462 .287 r
s
.704 .483 .291 r
.34078 .39779 m .3684 .43487 L .3592 .41636 L p F P
.623 .462 .287 r
s
.697 .476 .282 r
.33294 .39648 m .35776 .42881 L .34078 .39779 L p F P
.623 .462 .287 r
s
.589 .39 .223 r
.35776 .42881 m .33294 .39648 L .35282 .43029 L p F P
.623 .462 .287 r
s
.589 .39 .223 r
.35282 .43029 m .37536 .45341 L .35776 .42881 L p F P
.623 .462 .287 r
s
.427 .268 .157 r
.33063 .40367 m .35372 .4366 L .3663 .44868 L p F P
.623 .462 .287 r
s
.427 .268 .157 r
.35282 .43029 m .33063 .40367 L p .36049 .44134 L F P
.623 .462 .287 r
s
.427 .268 .157 r
.3663 .44868 m .36291 .44405 L p .36049 .44134 L F P
.623 .462 .287 r
s
.427 .268 .157 r
.36291 .44405 m .35282 .43029 L p .36049 .44134 L F P
.623 .462 .287 r
s
.463 .292 .17 r
.37536 .45341 m .35282 .43029 L .3663 .44868 L p F P
.623 .462 .287 r
s
.065 .302 .588 r
.35372 .4366 m .33063 .40367 L .3342 .20959 L p F P
.294 .652 1 r
s
.065 .302 .588 r
.3342 .20959 m .35754 .19869 L .35372 .4366 L p F P
.294 .652 1 r
s
.112 .521 .926 r
.31138 .39074 m .35372 .4366 L .35376 .43382 L p F P
.294 .652 1 r
s
.112 .521 .926 r
.35376 .43382 m .35754 .19869 L p .3122 .38733 L F P
.294 .652 1 r
s
.112 .521 .926 r
.3122 .38733 m .31138 .39074 L .35376 .43382 L F
.421 .275 .18 r
.57337 .48727 m .58658 .46753 L .56356 .48525 L p F P
.623 .462 .287 r
s
.424 .28 .185 r
.58658 .46753 m .57337 .48727 L .59183 .47309 L p F P
.623 .462 .287 r
s
.502 .322 .185 r
.38718 .43624 m .40758 .46213 L .43484 .48153 L p F P
.623 .462 .287 r
s
.502 .322 .185 r
.43484 .48153 m .41939 .46407 L .38718 .43624 L p F P
.623 .462 .287 r
s
.099 .461 .839 r
.70167 .40429 m .74675 .34964 L .74352 .20807 L p F P
.294 .652 1 r
s
.099 .461 .839 r
.78922 .20569 m .74352 .20807 L .74675 .34964 L p F P
.294 .652 1 r
s
.549 .372 .237 r
.6071 .4603 m .59183 .47309 L p .5598 .50199 L F P
.623 .462 .287 r
s
.549 .372 .237 r
.5598 .50199 m .58224 .49057 L .6071 .4603 L p F P
.623 .462 .287 r
s
.215 .131 .081 r
.60478 .47147 m .6071 .4603 L .58224 .49057 L p F P
.623 .462 .287 r
s
.648 .438 .263 r
.38903 .45361 m .3592 .41636 L .3684 .43487 L p F P
.623 .462 .287 r
s
.491 .313 .18 r
.3592 .41636 m .38903 .45361 L .40656 .46757 L p F P
.623 .462 .287 r
s
.491 .313 .18 r
.40656 .46757 m .38067 .43795 L .3592 .41636 L p F P
.623 .462 .287 r
s
.099 .461 .839 r
.74675 .34964 m .79132 .28252 L .78922 .20569 L p F P
.294 .652 1 r
s
.099 .461 .839 r
.83522 .2033 m .78922 .20569 L .79132 .28252 L closepath p F P
.294 .652 1 r
s
.479 .319 .205 r
.54587 .48387 m .54129 .49568 L .56356 .48525 L p F P
.623 .462 .287 r
s
.288 .181 .122 r
.64817 .4398 m .63044 .46124 L .62802 .47368 L p F P
.623 .462 .287 r
s
.288 .181 .122 r
.62802 .47368 m .6457 .45733 L .64817 .4398 L p F P
.623 .462 .287 r
s
.257 .164 .111 r
.64817 .4398 m .6457 .45733 L .65624 .44621 L p F P
.623 .462 .287 r
s
.435 .278 .174 r
.52591 .48677 m .52419 .49958 L .5366 .50488 L p F P
.623 .462 .287 r
s
.435 .278 .174 r
.5366 .50488 m .54129 .49568 L .52591 .48677 L p F P
.623 .462 .287 r
s
.549 .372 .237 r
.59183 .47309 m .57337 .48727 L .5598 .50199 L p F P
.623 .462 .287 r
s
.43 .266 .157 r
.38067 .43795 m .40656 .46757 L .42849 .4831 L p F P
.623 .462 .287 r
s
.43 .266 .157 r
.42849 .4831 m .40758 .46213 L .38067 .43795 L p F P
.623 .462 .287 r
s
.458 .297 .186 r
.49871 .4939 m .51388 .50378 L .51293 .4897 L p F P
.623 .462 .287 r
s
.303 .177 .11 r
.52419 .49958 m .51293 .4897 L .51388 .50378 L p F P
.623 .462 .287 r
s
.502 .324 .191 r
.41939 .46407 m .43484 .48153 L .45971 .49338 L p F P
.623 .462 .287 r
s
.502 .324 .191 r
.45971 .49338 m .44889 .48106 L .41939 .46407 L p F P
.623 .462 .287 r
s
.275 .177 .124 r
.70167 .40429 m .65624 .44621 L .65558 .4469 L p F P
.623 .462 .287 r
s
.275 .177 .124 r
.65558 .4469 m .6457 .45733 L p .67193 .43247 L F P
.623 .462 .287 r
s
.275 .177 .124 r
.67193 .43247 m .70167 .40429 L .65558 .4469 L F
.6457 .45733 m .67968 .43081 L .70167 .40429 L p F P
.623 .462 .287 r
s
.319 .209 .148 r
.74675 .34964 m .70167 .40429 L .6958 .41137 L p F P
.623 .462 .287 r
s
.319 .209 .148 r
.6958 .41137 m .67968 .43081 L p .71635 .38643 L F P
.623 .462 .287 r
s
.319 .209 .148 r
.71635 .38643 m .74675 .34964 L .6958 .41137 L F
.71956 .38843 m .74675 .34964 L p .69548 .41169 L F P
.623 .462 .287 r
s
.319 .209 .148 r
.67968 .43081 m .70841 .40027 L p .69548 .41169 L F P
.623 .462 .287 r
s
.319 .209 .148 r
.70841 .40027 m .71956 .38843 L p .69548 .41169 L F P
.623 .462 .287 r
s
.325 .216 .153 r
.71956 .38843 m .75912 .3363 L .763 .32981 L p F P
.623 .462 .287 r
s
.325 .216 .153 r
.79132 .28252 m .74675 .34964 L .73934 .36022 L p F P
.623 .462 .287 r
s
.325 .216 .153 r
.73934 .36022 m .71956 .38843 L p .76023 .32841 L F P
.623 .462 .287 r
s
.325 .216 .153 r
.76023 .32841 m .79132 .28252 L .73934 .36022 L F
.763 .32981 m .79132 .28252 L p .74202 .35528 L F P
.623 .462 .287 r
s
.325 .216 .153 r
.71956 .38843 m .763 .32981 L .74202 .35528 L F
.269 .181 .131 r
.75912 .3363 m .78945 .29011 L .80601 .25871 L p F P
.623 .462 .287 r
s
.269 .181 .131 r
.79132 .28252 m .75912 .3363 L p .83522 .2033 L F P
.623 .462 .287 r
s
.269 .181 .131 r
.80601 .25871 m .83522 .2033 L p .78667 .28815 L F P
.623 .462 .287 r
s
.269 .181 .131 r
.75912 .3363 m .80601 .25871 L .78667 .28815 L F
.089 .066 .041 r
.79999 .27449 m .83522 .2033 L .78945 .29011 L p F P
.623 .462 .287 r
s
.112 .522 .927 r
.79778 .19676 m .83522 .2033 L .79999 .27449 L closepath p F P
.294 .652 1 r
s
.399 .255 .165 r
.55465 .49839 m .56356 .48525 L .54129 .49568 L p F P
.623 .462 .287 r
s
.421 .275 .18 r
.56356 .48525 m .55465 .49839 L .57337 .48727 L p F P
.623 .462 .287 r
s
.513 .335 .205 r
.47761 .49829 m .46833 .48511 L .45971 .49338 L p F P
.623 .462 .287 r
s
.578 .389 .241 r
.46833 .48511 m .47761 .49829 L .48218 .48882 L p F P
.623 .462 .287 r
s
.59 .397 .244 r
.44889 .48106 m .45971 .49338 L .46833 .48511 L p F P
.623 .462 .287 r
s
.377 .24 .157 r
.61888 .46342 m .59941 .48409 L .59391 .4937 L p F P
.623 .462 .287 r
s
.377 .24 .157 r
.59391 .4937 m .61235 .47924 L .61888 .46342 L p F P
.623 .462 .287 r
s
.49 .315 .187 r
.48218 .48882 m .47761 .49829 L p .47946 .50872 L F P
.623 .462 .287 r
s
.49 .315 .187 r
.47946 .50872 m .4905 .50313 L .48218 .48882 L p F P
.623 .462 .287 r
s
.215 .131 .081 r
.59941 .48409 m .60478 .47147 L p .58224 .49057 L F P
.623 .462 .287 r
s
.41 .258 .161 r
.50456 .5089 m .49871 .4939 L .4905 .50313 L p F P
.623 .462 .287 r
s
.378 .228 .137 r
.49871 .4939 m .50456 .5089 L .51485 .51266 L p F P
.623 .462 .287 r
s
.378 .228 .137 r
.51485 .51266 m .51388 .50378 L .49871 .4939 L p F P
.623 .462 .287 r
s
.416 .253 .151 r
.40758 .46213 m .42849 .4831 L .45063 .49548 L p F P
.623 .462 .287 r
s
.416 .253 .151 r
.45063 .49548 m .43484 .48153 L .40758 .46213 L p F P
.623 .462 .287 r
s
.575 .38 .222 r
.39678 .46524 m .3684 .43487 L .38311 .45623 L p F P
.623 .462 .287 r
s
.648 .438 .263 r
.3684 .43487 m .39678 .46524 L .38903 .45361 L p F P
.623 .462 .287 r
s
.646 .435 .257 r
.35776 .42881 m .38311 .45623 L .3684 .43487 L p F P
.623 .462 .287 r
s
.399 .255 .165 r
.54129 .49568 m .5366 .50488 L .55465 .49839 L p F P
.623 .462 .287 r
s
.463 .303 .192 r
.55465 .49839 m .5366 .50488 L .53289 .51017 L p F P
.623 .462 .287 r
s
.463 .303 .192 r
.57337 .48727 m .55465 .49839 L p .53289 .51017 L F P
.623 .462 .287 r
s
.463 .303 .192 r
.53289 .51017 m .5598 .50199 L .57337 .48727 L p F P
.623 .462 .287 r
s
.246 .153 .099 r
.63044 .46124 m .61235 .47924 L .61008 .48736 L p F P
.623 .462 .287 r
s
.246 .153 .099 r
.61008 .48736 m .62802 .47368 L .63044 .46124 L p F P
.623 .462 .287 r
s
.112 .521 .926 r
.35754 .19869 m .31542 .19207 L .31138 .39074 L p F P
.294 .652 1 r
s
.428 .265 .156 r
.40656 .46757 m .38903 .45361 L .42463 .48607 L p F P
.623 .462 .287 r
s
.428 .265 .156 r
.42849 .4831 m .40656 .46757 L p .42463 .48607 L F P
.623 .462 .287 r
s
.428 .265 .156 r
.42463 .48607 m .44989 .49894 L .42849 .4831 L p F P
.623 .462 .287 r
s
.373 .221 .135 r
.45469 .50381 m .42463 .48607 L .43531 .49564 L p F P
.623 .462 .287 r
s
.333 .193 .12 r
.45063 .49548 m .42849 .4831 L .44989 .49894 L p F P
.623 .462 .287 r
s
.333 .193 .12 r
.47074 .50306 m .45063 .49548 L p .44989 .49894 L F P
.623 .462 .287 r
s
.333 .193 .12 r
.44989 .49894 m .47946 .50872 L .47074 .50306 L p F P
.623 .462 .287 r
s
.236 .142 .088 r
.44989 .49894 m .47178 .50948 L .49171 .51377 L p F P
.623 .462 .287 r
s
.236 .142 .088 r
.47946 .50872 m .44989 .49894 L p .47938 .5094 L F P
.623 .462 .287 r
s
.401 .328 .228 r
.47178 .50948 m .45268 .50029 L .45841 .50284 L F
.44989 .49894 m .42463 .48607 L p .45841 .50284 L F P
.623 .462 .287 r
s
.401 .328 .228 r
.45268 .50029 m .44989 .49894 L .45841 .50284 L F
.45469 .50381 m .47178 .50948 L p .45575 .50152 L F P
.623 .462 .287 r
s
.146 .096 .059 r
.49171 .51377 m .47178 .50948 L p .48859 .51365 L F P
.623 .462 .287 r
s
.146 .096 .059 r
.47178 .50948 m .46872 .50846 L p .48859 .51365 L F P
.623 .462 .287 r
s
.146 .096 .059 r
.46872 .50846 m .45469 .50381 L .47515 .50975 L p F P
.623 .462 .287 r
s
.146 .096 .059 r
.47515 .50975 m .48859 .51365 L p .46872 .50846 L F P
.623 .462 .287 r
s
.236 .142 .088 r
.49171 .51377 m .48841 .51241 L p .47938 .5094 L F P
.623 .462 .287 r
s
.236 .142 .088 r
.48841 .51241 m .47946 .50872 L p .47938 .5094 L F P
.623 .462 .287 r
s
.327 .19 .118 r
.47946 .50872 m .49171 .51377 L .49906 .51223 L p F P
.623 .462 .287 r
s
.514 .431 .289 r
.49035 .51275 m .48859 .51365 L .45469 .50381 L p F P
.623 .462 .287 r
s
.514 .431 .289 r
.4621 .50731 m .4699 .50889 L .48668 .51206 L p F P
.623 .462 .287 r
s
.514 .431 .289 r
.48668 .51206 m .49035 .51275 L p .48484 .51169 L F P
.623 .462 .287 r
s
.514 .431 .289 r
.48484 .51169 m .4621 .50731 L .48668 .51206 L F
.45469 .50381 m .4621 .50731 L p .47326 .50946 L F P
.623 .462 .287 r
s
.514 .431 .289 r
.49035 .51275 m .46815 .50718 L .47326 .50946 L F
.46815 .50718 m .45469 .50381 L .47326 .50946 L F
.401 .328 .228 r
.42463 .48607 m .4444 .49773 L p .45575 .50152 L F P
.623 .462 .287 r
s
.401 .328 .228 r
.4444 .49773 m .45469 .50381 L p .45575 .50152 L F P
.623 .462 .287 r
s
.272 .207 .159 r
.43531 .49564 m .42463 .48607 L .40263 .46601 L p F P
.623 .462 .287 r
s
.272 .207 .159 r
.40263 .46601 m .38903 .45361 L p .40939 .4721 L F P
.623 .462 .287 r
s
.272 .207 .159 r
.43531 .49564 m .40263 .46601 L .40939 .4721 L F
.38903 .45361 m .39678 .46524 L p .43531 .49564 L F P
.623 .462 .287 r
s
.272 .207 .159 r
.39678 .46524 m .40897 .47856 L .43531 .49564 L p F P
.623 .462 .287 r
s
.242 .146 .09 r
.4621 .50731 m .43531 .49564 L .44663 .50133 L p F P
.623 .462 .287 r
s
.373 .221 .135 r
.43531 .49564 m .4621 .50731 L .45469 .50381 L p F P
.623 .462 .287 r
s
.391 .316 .224 r
.44663 .50133 m .43531 .49564 L .40897 .47856 L p F P
.623 .462 .287 r
s
.391 .316 .224 r
.40897 .47856 m .42143 .4888 L p .43595 .49602 L F P
.623 .462 .287 r
s
.391 .316 .224 r
.44663 .50133 m .43207 .49253 L .43595 .49602 L F
.43207 .49253 m .40897 .47856 L .43595 .49602 L F
.527 .341 .194 r
.38311 .45623 m .35776 .42881 L .37536 .45341 L p F P
.623 .462 .287 r
s
.112 .522 .927 r
.75965 .1901 m .79778 .19676 L .79999 .27449 L p F P
.294 .652 1 r
s
.303 .177 .11 r
.5366 .50488 m .52419 .49958 L p .51388 .50378 L F P
.623 .462 .287 r
s
.411 .251 .149 r
.43484 .48153 m .45063 .49548 L .47074 .50306 L p F P
.623 .462 .287 r
s
.411 .251 .149 r
.47074 .50306 m .45971 .49338 L .43484 .48153 L p F P
.623 .462 .287 r
s
.208 .128 .079 r
.5611 .50673 m .58224 .49057 L .5598 .50199 L p F P
.623 .462 .287 r
s
.31 .184 .117 r
.58224 .49057 m .5611 .50673 L .55905 .50995 L p F P
.623 .462 .287 r
s
.31 .184 .117 r
.55905 .50995 m .57946 .49967 L .58224 .49057 L p F P
.623 .462 .287 r
s
.215 .131 .081 r
.58224 .49057 m .57946 .49967 L .59941 .48409 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.75254 .34896 m .78945 .29011 L .75912 .3363 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.75912 .3363 m .72618 .38345 L .75254 .34896 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.71481 .39935 m .75254 .34896 L .72618 .38345 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.72618 .38345 m .69258 .42371 L .71481 .39935 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.69258 .42371 m .72618 .38345 L .69185 .42229 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.69185 .42229 m .66366 .45107 L .69258 .42371 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.65838 .45682 m .69258 .42371 L .66366 .45107 L p F P
.623 .462 .287 r
s
.777 .604 .355 r
.69258 .42371 m .65838 .45682 L .67632 .44094 L p F P
.623 .462 .287 r
s
.777 .604 .355 r
.71481 .39935 m .69258 .42371 L p .67705 .44016 L F P
.623 .462 .287 r
s
.777 .604 .355 r
.67632 .44094 m .67852 .43856 L p .67705 .44016 L F P
.623 .462 .287 r
s
.777 .604 .355 r
.67852 .43856 m .71481 .39935 L p .67705 .44016 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.62802 .47368 m .61008 .48736 L .63464 .47329 L p F P
.623 .462 .287 r
s
.096 .07 .043 r
.63464 .47329 m .65733 .45384 L .62802 .47368 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.66366 .45107 m .69185 .42229 L .65733 .45384 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.65733 .45384 m .63464 .47329 L .66366 .45107 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.61008 .48736 m .59189 .49833 L .61164 .48906 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.61164 .48906 m .63464 .47329 L .61008 .48736 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.63502 .47461 m .66366 .45107 L .63464 .47329 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.66366 .45107 m .63502 .47461 L .65838 .45682 L p F P
.623 .462 .287 r
s
.228 .145 .097 r
.67632 .44094 m .65838 .45682 L p .64146 .46843 L F P
.623 .462 .287 r
s
.203 .125 .078 r
.61235 .47924 m .59391 .4937 L .59189 .49833 L p F P
.623 .462 .287 r
s
.203 .125 .078 r
.59189 .49833 m .61008 .48736 L .61235 .47924 L p F P
.623 .462 .287 r
s
.129 .087 .054 r
.59189 .49833 m .59391 .4937 L p .57946 .49967 L F P
.623 .462 .287 r
s
.129 .087 .054 r
.57946 .49967 m .57759 .50494 L .59189 .49833 L p F P
.623 .462 .287 r
s
.174 .11 .069 r
.61164 .48906 m .59189 .49833 L .58567 .50121 L p F P
.623 .462 .287 r
s
.174 .11 .069 r
.58567 .50121 m .57759 .50494 L p .59196 .49824 L F P
.623 .462 .287 r
s
.174 .11 .069 r
.59196 .49824 m .61164 .48906 L .58567 .50121 L F
.089 .066 .041 r
.63464 .47329 m .61164 .48906 L .63502 .47461 L p F P
.623 .462 .287 r
s
.174 .11 .069 r
.63502 .47461 m .61553 .48666 L p .62305 .48118 L F P
.623 .462 .287 r
s
.174 .11 .069 r
.59955 .49335 m .63502 .47461 L .59196 .49824 L F
.59196 .49824 m .62305 .48118 L .61164 .48906 L F
.61553 .48666 m .61164 .48906 L p .62305 .48118 L F P
.623 .462 .287 r
s
.174 .11 .069 r
.57759 .50494 m .59955 .49335 L .59196 .49824 L F
.57759 .50494 m .60599 .49278 L .63502 .47461 L p F P
.623 .462 .287 r
s
.228 .145 .097 r
.65838 .45682 m .63502 .47461 L .60599 .49278 L p F P
.623 .462 .287 r
s
.897 .699 .425 r
.66195 .45385 m .66794 .44847 L p .63104 .47764 L F P
.623 .462 .287 r
s
.897 .699 .425 r
.66794 .44847 m .67632 .44094 L .65894 .45502 L p F P
.623 .462 .287 r
s
.897 .699 .425 r
.65894 .45502 m .63104 .47764 L p .66794 .44847 L F P
.623 .462 .287 r
s
.228 .145 .097 r
.61231 .48844 m .64819 .46267 L .64146 .46843 L F
.60599 .49278 m .64819 .46267 L .61231 .48844 L F
.60599 .49278 m .65649 .45555 L .64819 .46267 L F
.65649 .45555 m .67632 .44094 L .64146 .46843 L F
.63104 .47764 m .65894 .45502 L p .61031 .48959 L F P
.623 .462 .287 r
s
.228 .145 .097 r
.65894 .45502 m .67632 .44094 L p .64502 .46401 L F P
.623 .462 .287 r
s
.228 .145 .097 r
.61031 .48959 m .65894 .45502 L .64502 .46401 L F
.60599 .49278 m .61465 .48754 L p .61031 .48959 L F P
.623 .462 .287 r
s
.228 .145 .097 r
.61465 .48754 m .63104 .47764 L p .61031 .48959 L F P
.623 .462 .287 r
s
.107 .075 .047 r
.67632 .44094 m .66195 .45385 L p .69425 .42054 L F P
.623 .462 .287 r
s
.107 .075 .047 r
.69425 .42054 m .69509 .41967 L .69474 .42008 L F
.69425 .42054 m .69474 .42008 L .67632 .44094 L F
.71481 .39935 m .67852 .43856 L p .69509 .41967 L F P
.623 .462 .287 r
s
.107 .075 .047 r
.67852 .43856 m .67632 .44094 L p .69509 .41967 L F P
.623 .462 .287 r
s
.107 .075 .047 r
.6973 .41974 m .71481 .39935 L p .67901 .43625 L F P
.623 .462 .287 r
s
.107 .075 .047 r
.66195 .45385 m .68952 .42725 L p .67901 .43625 L F P
.623 .462 .287 r
s
.107 .075 .047 r
.68952 .42725 m .6973 .41974 L p .67901 .43625 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.6973 .41974 m .66195 .45385 L .65517 .45893 L p F P
.623 .462 .287 r
s
.096 .07 .043 r
.65517 .45893 m .6419 .46886 L p .66407 .44921 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.66407 .44921 m .6671 .44693 L .65517 .45893 L F
.67053 .44348 m .6973 .41974 L .65517 .45893 L F
.66407 .44921 m .67053 .44348 L .6671 .44693 L F
.6419 .46886 m .65524 .45789 L p .66727 .44637 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.65524 .45789 m .6727 .44352 L p .66727 .44637 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.6727 .44352 m .6419 .46886 L .6332 .47391 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.63553 .47052 m .64609 .46286 L .63954 .46847 L F
.64609 .46286 m .6727 .44352 L .6332 .47391 L F
.6476 .46242 m .6727 .44352 L p .64134 .46631 L F P
.623 .462 .287 r
s
.127 .086 .054 r
.6457 .45733 m .62802 .47368 L .65733 .45384 L p F P
.623 .462 .287 r
s
.909 .708 .431 r
.62754 .47249 m .6476 .46242 L p .61748 .47976 L F P
.623 .462 .287 r
s
.909 .708 .431 r
.60534 .48675 m .61128 .48294 L p .61748 .47976 L F P
.623 .462 .287 r
s
.909 .708 .431 r
.61128 .48294 m .62754 .47249 L p .61748 .47976 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.6332 .47391 m .62156 .48068 L p .63553 .47052 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.63553 .47052 m .63954 .46847 L .6332 .47391 L F
.096 .07 .043 r
.6727 .44352 m .6973 .41974 L p .66727 .44637 L F P
.623 .462 .287 r
s
.126 .089 .059 r
.75254 .34896 m .72285 .3886 L p .72018 .39177 L F P
.623 .462 .287 r
s
.126 .089 .059 r
.72285 .3886 m .71481 .39935 L p .72018 .39177 L F P
.623 .462 .287 r
s
.126 .089 .059 r
.71481 .39935 m .71185 .40279 L p .72018 .39177 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.72618 .38345 m .75912 .3363 L .71956 .38843 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.71956 .38843 m .69185 .42229 L .72618 .38345 L p F P
.623 .462 .287 r
s
.126 .089 .059 r
.71185 .40279 m .6973 .41974 L p .72883 .37934 L F P
.623 .462 .287 r
s
.126 .089 .059 r
.72883 .37934 m .72958 .37839 L .72923 .37886 L F
.72883 .37934 m .72923 .37886 L .71185 .40279 L F
.72958 .37839 m .75254 .34896 L .71185 .40279 L F
.73214 .37833 m .73505 .37414 L p .70614 .40842 L F P
.623 .462 .287 r
s
.126 .089 .059 r
.70614 .40842 m .73505 .37414 L .71554 .39637 L F
.71454 .39925 m .73214 .37833 L p .70614 .40842 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.6973 .41974 m .6727 .44352 L p .69454 .41957 L F P
.623 .462 .287 r
s
.126 .089 .059 r
.6973 .41974 m .71454 .39925 L p .70614 .40842 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.73214 .37833 m .70816 .40683 L p .69709 .41718 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.70075 .41276 m .73214 .37833 L .69709 .41718 L F
.70816 .40683 m .6973 .41974 L p .69454 .41957 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.71466 .3991 m .73214 .37833 L p .70336 .4099 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.70042 .41342 m .71466 .3991 L .70336 .4099 L F
.70321 .4127 m .71466 .3991 L p .70178 .41273 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.6727 .44352 m .70321 .4127 L p .70178 .41273 L F P
.623 .462 .287 r
s
.096 .07 .043 r
.69454 .41957 m .70075 .41276 L .69709 .41718 L F
.6727 .44352 m .71466 .3991 L .6971 .41676 L F
.126 .089 .059 r
.73505 .37414 m .75254 .34896 L p .71554 .39637 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.75254 .34896 m .73214 .37833 L p .76283 .33109 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.78945 .29011 m .77326 .31593 L p .76283 .33109 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.77326 .31593 m .75254 .34896 L p .76283 .33109 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.76639 .32983 m .77254 .31924 L p .76495 .33034 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.73214 .37833 m .76639 .32983 L p .76495 .33034 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.73214 .37833 m .77254 .31924 L .75348 .34548 L F
.114 .083 .055 r
.73214 .37833 m .70321 .4127 L p .72465 .38458 L F P
.623 .462 .287 r
s
.114 .083 .055 r
.76639 .32983 m .73956 .36783 L p .72465 .38458 L F P
.623 .462 .287 r
s
.114 .083 .055 r
.73956 .36783 m .73214 .37833 L p .72465 .38458 L F P
.623 .462 .287 r
s
.114 .083 .055 r
.70321 .4127 m .7334 .37651 L .74934 .35396 L p F P
.623 .462 .287 r
s
.114 .083 .055 r
.70321 .4127 m .74934 .35396 L .73202 .37491 L F
.089 .066 .041 r
.67179 .44079 m .70321 .4127 L .65911 .45375 L F
.68705 .4277 m .70321 .4127 L p .67271 .43997 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.67229 .44037 m .68705 .4277 L .67271 .43997 L F
.096 .07 .043 r
.6971 .41676 m .70042 .41342 L .70336 .4099 L F
.127 .086 .054 r
.65733 .45384 m .67968 .43081 L .6457 .45733 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.67968 .43081 m .65733 .45384 L .69185 .42229 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.65911 .45375 m .6476 .46242 L p .66142 .45006 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.66142 .45006 m .67179 .44079 L .66476 .44798 L F
.66142 .45006 m .66476 .44798 L .65911 .45375 L F
.67353 .44024 m .68705 .4277 L p .6642 .44781 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.6476 .46242 m .67353 .44024 L p .6642 .44781 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.6476 .46242 m .68705 .4277 L .6718 .44078 L F
.919 .712 .431 r
.64973 .45525 m .67353 .44024 L p .64408 .46089 L F P
.623 .462 .287 r
s
.919 .712 .431 r
.62754 .47249 m .63587 .46602 L p .64408 .46089 L F P
.623 .462 .287 r
s
.919 .712 .431 r
.63587 .46602 m .64973 .45525 L p .64408 .46089 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.69185 .42229 m .71956 .38843 L .67968 .43081 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.68716 .42573 m .7334 .37651 L .697 .41846 L F
.697 .41846 m .67353 .44024 L p .68716 .42573 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.67353 .44024 m .68936 .42424 L .70315 .40874 L F
.67353 .44024 m .70315 .40874 L .70233 .40958 L F
.68936 .42424 m .69932 .41417 L p .70374 .40808 L F P
.623 .462 .287 r
s
.922 .711 .428 r
.67191 .43502 m .69932 .41417 L p .67057 .43799 L F P
.623 .462 .287 r
s
.922 .711 .428 r
.64973 .45525 m .66051 .44542 L p .67057 .43799 L F P
.623 .462 .287 r
s
.922 .711 .428 r
.66051 .44542 m .67191 .43502 L p .67057 .43799 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.7334 .37651 m .70321 .4127 L .697 .41846 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.70233 .40958 m .70315 .40874 L .70374 .40808 L F
.70321 .4127 m .6727 .44352 L .65911 .45375 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.69932 .41417 m .7334 .37651 L p .70374 .40808 L F P
.623 .462 .287 r
s
.114 .083 .055 r
.74934 .35396 m .76639 .32983 L p .73877 .36606 L F P
.623 .462 .287 r
s
.114 .083 .055 r
.73202 .37491 m .73596 .37015 L .73877 .36606 L F
.73596 .37015 m .74934 .35396 L .73877 .36606 L F
.089 .066 .041 r
.6718 .44078 m .67229 .44037 L .67271 .43997 L F
.62156 .48068 m .63144 .47375 L p .64134 .46631 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.63144 .47375 m .6476 .46242 L p .64134 .46631 L F P
.623 .462 .287 r
s
.147 .105 .072 r
.77254 .31924 m .78945 .29011 L p .75348 .34548 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.78945 .29011 m .76639 .32983 L .79999 .27449 L p F P
.623 .462 .287 r
s
.513 .335 .205 r
.45971 .49338 m .47074 .50306 L .47761 .49829 L p F P
.623 .462 .287 r
s
.49 .315 .187 r
.47761 .49829 m .47074 .50306 L .47946 .50872 L p F P
.623 .462 .287 r
s
.129 .087 .054 r
.59391 .4937 m .59941 .48409 L .57946 .49967 L p F P
.623 .462 .287 r
s
.288 .169 .105 r
.51388 .50378 m .51485 .51266 L .52766 .51474 L p F P
.623 .462 .287 r
s
.288 .169 .105 r
.52766 .51474 m .53289 .51017 L .51388 .50378 L p F P
.623 .462 .287 r
s
.303 .177 .11 r
.51388 .50378 m .53289 .51017 L .5366 .50488 L p F P
.623 .462 .287 r
s
.327 .19 .118 r
.49906 .51223 m .4905 .50313 L .47946 .50872 L p F P
.623 .462 .287 r
s
.41 .258 .161 r
.4905 .50313 m .49906 .51223 L .50456 .5089 L p F P
.623 .462 .287 r
s
.112 .521 .926 r
.26891 .3312 m .31138 .39074 L .31542 .19207 L p F P
.294 .652 1 r
s
.112 .521 .926 r
.31542 .19207 m .27251 .18532 L .26891 .3312 L p F P
.294 .652 1 r
s
.575 .38 .222 r
.38311 .45623 m .40897 .47856 L .39678 .46524 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.76639 .32983 m .7334 .37651 L .7632 .33507 L p F P
.623 .462 .287 r
s
.112 .522 .927 r
.79999 .27449 m .7632 .33507 L .75965 .1901 L p F P
.294 .652 1 r
s
.089 .066 .041 r
.7632 .33507 m .79999 .27449 L .76639 .32983 L p F P
.623 .462 .287 r
s
.462 .29 .169 r
.40897 .47856 m .38311 .45623 L .39824 .47295 L p F P
.623 .462 .287 r
s
.527 .341 .194 r
.37536 .45341 m .39824 .47295 L .38311 .45623 L p F P
.623 .462 .287 r
s
.242 .145 .09 r
.54585 .51148 m .55604 .50455 L p .53289 .51017 L F P
.623 .462 .287 r
s
.208 .128 .079 r
.5598 .50199 m .54585 .51148 L .5611 .50673 L p F P
.623 .462 .287 r
s
.242 .145 .09 r
.53289 .51017 m .52766 .51474 L .54585 .51148 L p F P
.623 .462 .287 r
s
.25 .15 .093 r
.54585 .51148 m .52766 .51474 L .52463 .51559 L p F P
.623 .462 .287 r
s
.25 .15 .093 r
.52463 .51559 m .52301 .51604 L p .52634 .51538 L F P
.623 .462 .287 r
s
.25 .15 .093 r
.52634 .51538 m .54585 .51148 L .52463 .51559 L F
.56022 .507 m .54585 .51148 L p .52301 .51604 L F P
.623 .462 .287 r
s
.25 .15 .093 r
.5611 .50673 m .56022 .507 L p .52301 .51604 L F P
.623 .462 .287 r
s
.25 .15 .093 r
.52301 .51604 m .53708 .51495 L .56049 .50694 L p F P
.623 .462 .287 r
s
.629 .519 .325 r
.55905 .50995 m .5611 .50673 L .53708 .51495 L p F P
.623 .462 .287 r
s
.853 .672 .425 r
.53994 .51408 m .53708 .51495 L .53192 .51469 L p F P
.623 .462 .287 r
s
.25 .15 .093 r
.52301 .51604 m .56049 .50694 L .56041 .5069 L F
.139 .092 .057 r
.52766 .51474 m .51485 .51266 L p .51124 .51593 L F P
.623 .462 .287 r
s
.853 .672 .425 r
.53192 .51469 m .51688 .51391 L p .53698 .51406 L F P
.623 .462 .287 r
s
.853 .672 .425 r
.53698 .51406 m .53994 .51408 L .53192 .51469 L F
.25 .15 .093 r
.56049 .50694 m .5611 .50673 L p .56041 .5069 L F P
.623 .462 .287 r
s
.242 .145 .09 r
.55604 .50455 m .5598 .50199 L .55437 .50364 L p F P
.623 .462 .287 r
s
.242 .145 .09 r
.55437 .50364 m .53289 .51017 L p .55604 .50455 L F P
.623 .462 .287 r
s
.112 .522 .927 r
.7208 .18331 m .75965 .1901 L .7632 .33507 L p F P
.294 .652 1 r
s
.274 .162 .101 r
.50456 .5089 m .49906 .51223 L p .50259 .51549 L F P
.623 .462 .287 r
s
.274 .162 .101 r
.50259 .51549 m .51124 .51593 L .50456 .5089 L p F P
.623 .462 .287 r
s
.139 .092 .057 r
.51485 .51266 m .50456 .5089 L .51124 .51593 L p F P
.623 .462 .287 r
s
.396 .24 .144 r
.39824 .47295 m .37536 .45341 L .38731 .4665 L p F P
.623 .462 .287 r
s
.463 .292 .17 r
.3663 .44868 m .38731 .4665 L .37536 .45341 L p F P
.623 .462 .287 r
s
.179 .112 .07 r
.57946 .49967 m .55905 .50995 L .5576 .51127 L p F P
.623 .462 .287 r
s
.179 .112 .07 r
.5576 .51127 m .57759 .50494 L .57946 .49967 L p F P
.623 .462 .287 r
s
.112 .521 .926 r
.22647 .25804 m .26891 .3312 L .27251 .18532 L p F P
.294 .652 1 r
s
.112 .521 .926 r
.27251 .18532 m .22879 .17845 L .22647 .25804 L p F P
.294 .652 1 r
s
.462 .29 .169 r
.39824 .47295 m .42143 .4888 L .40897 .47856 L p F P
.623 .462 .287 r
s
.112 .522 .927 r
.7632 .33507 m .72494 .38428 L .7208 .18331 L p F P
.294 .652 1 r
s
.112 .522 .927 r
.68121 .1764 m .7208 .18331 L .72494 .38428 L p F P
.294 .652 1 r
s
.274 .162 .101 r
.49906 .51223 m .49171 .51377 L .50259 .51549 L p F P
.623 .462 .287 r
s
.324 .188 .117 r
.42143 .4888 m .39824 .47295 L .40851 .48155 L p F P
.623 .462 .287 r
s
.396 .24 .144 r
.38731 .4665 m .40851 .48155 L .39824 .47295 L p F P
.623 .462 .287 r
s
.266 .201 .156 r
.35372 .4366 m .31138 .39074 L .33641 .41953 L p F P
.623 .462 .287 r
s
.266 .201 .156 r
.33641 .41953 m .3663 .44868 L .35372 .4366 L p F P
.623 .462 .287 r
s
.382 .305 .22 r
.38731 .4665 m .3663 .44868 L .33641 .41953 L p F P
.623 .462 .287 r
s
.852 .656 .387 r
.72494 .38428 m .7632 .33507 L .7334 .37651 L p F P
.623 .462 .287 r
s
.139 .092 .057 r
.51124 .51593 m .52301 .51604 L .52766 .51474 L p F P
.623 .462 .287 r
s
.629 .519 .325 r
.5576 .51127 m .55905 .50995 L p .53708 .51495 L F P
.623 .462 .287 r
s
.112 .521 .926 r
.22879 .17845 m .18423 .17144 L .22647 .25804 L closepath p F P
.294 .652 1 r
s
.391 .316 .224 r
.42143 .4888 m .4299 .49379 L .44663 .50133 L p F P
.623 .462 .287 r
s
.324 .188 .117 r
.40851 .48155 m .4299 .49379 L .42143 .4888 L p F P
.623 .462 .287 r
s
.319 .247 .186 r
.31138 .39074 m .26891 .3312 L .29909 .37335 L p F P
.623 .462 .287 r
s
.319 .247 .186 r
.29909 .37335 m .33641 .41953 L .31138 .39074 L p F P
.623 .462 .287 r
s
.382 .305 .22 r
.33641 .41953 m .36169 .4446 L .38731 .4665 L p F P
.623 .462 .287 r
s
.431 .35 .247 r
.40851 .48155 m .38731 .4665 L .36169 .4446 L p F P
.623 .462 .287 r
s
.146 .096 .059 r
.48859 .51365 m .50259 .51549 L .49171 .51377 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.57759 .50494 m .5576 .51127 L .57659 .50545 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.57659 .50545 m .60599 .49278 L .57759 .50494 L p F P
.623 .462 .287 r
s
.112 .522 .927 r
.72494 .38428 m .68528 .42138 L .68121 .1764 L p F P
.294 .652 1 r
s
.071 .334 .641 r
.71132 .16444 m .68121 .1764 L .68528 .42138 L p F P
.294 .652 1 r
s
.852 .656 .387 r
.7334 .37651 m .69932 .41417 L .72494 .38428 L p F P
.623 .462 .287 r
s
.508 .402 .278 r
.36169 .4446 m .33641 .41953 L .29909 .37335 L p F P
.623 .462 .287 r
s
.326 .252 .19 r
.26891 .3312 m .22647 .25804 L .26172 .31663 L p F P
.623 .462 .287 r
s
.326 .252 .19 r
.26172 .31663 m .29909 .37335 L .26891 .3312 L p F P
.623 .462 .287 r
s
.623 .516 .329 r
.51688 .51391 m .51124 .51593 L .50259 .51549 L p F P
.623 .462 .287 r
s
.741 .598 .379 r
.52301 .51604 m .51124 .51593 L .51688 .51391 L p F P
.623 .462 .287 r
s
.431 .35 .247 r
.36169 .4446 m .38718 .4659 L .40851 .48155 L p F P
.623 .462 .287 r
s
.48 .396 .273 r
.4299 .49379 m .40851 .48155 L .38718 .4659 L p F P
.623 .462 .287 r
s
.872 .684 .417 r
.60599 .49278 m .57659 .50545 L .59335 .4984 L p F P
.623 .462 .287 r
s
.872 .684 .417 r
.59335 .4984 m .63104 .47764 L .60599 .49278 L p F P
.623 .462 .287 r
s
.242 .146 .09 r
.44663 .50133 m .4699 .50889 L .4621 .50731 L p F P
.623 .462 .287 r
s
.897 .699 .425 r
.6419 .46886 m .66195 .45385 L p .63104 .47764 L F P
.623 .462 .287 r
s
.741 .598 .379 r
.51688 .51391 m .53708 .51495 L .52301 .51604 L p F P
.623 .462 .287 r
s
.629 .519 .325 r
.53708 .51495 m .53994 .51408 L .5576 .51127 L p F P
.623 .462 .287 r
s
.291 .219 .171 r
.22647 .25804 m .18423 .17144 L .23389 .26633 L p F P
.623 .462 .287 r
s
.291 .219 .171 r
.23389 .26633 m .26172 .31663 L .22647 .25804 L p F P
.623 .462 .287 r
s
.508 .402 .278 r
.29909 .37335 m .32961 .41017 L .36169 .4446 L p F P
.623 .462 .287 r
s
.562 .443 .302 r
.38718 .4659 m .36169 .4446 L .32961 .41017 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.59335 .4984 m .57659 .50545 L p .56204 .50888 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.53994 .51408 m .57298 .50438 L .56204 .50888 L F
.57298 .50438 m .59335 .4984 L .56204 .50888 L F
.53994 .51408 m .55143 .51127 L .59335 .4984 L p F P
.623 .462 .287 r
s
.895 .702 .44 r
.57966 .50277 m .59335 .4984 L .55143 .51127 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.59335 .4984 m .57966 .50277 L p .59709 .49424 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.63104 .47764 m .60621 .49132 L p .59709 .49424 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.60621 .49132 m .59335 .4984 L p .59709 .49424 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.61087 .48863 m .63104 .47764 L p .5942 .49565 L F P
.623 .462 .287 r
s
.794 .633 .39 r
.58809 .49577 m .61087 .48863 L p .57799 .50037 L F P
.623 .462 .287 r
s
.794 .633 .39 r
.56429 .50526 m .57064 .50273 L p .57799 .50037 L F P
.623 .462 .287 r
s
.794 .633 .39 r
.57064 .50273 m .58809 .49577 L p .57799 .50037 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.57966 .50277 m .60686 .49045 L p .5942 .49565 L F P
.623 .462 .287 r
s
.089 .066 .041 r
.60686 .49045 m .61087 .48863 L p .5942 .49565 L F P
.623 .462 .287 r
s
.897 .699 .425 r
.63104 .47764 m .61087 .48863 L .6419 .46886 L p F P
.623 .462 .287 r
s
.089 .066 .041 r
.57659 .50545 m .5576 .51127 L .53994 .51408 L p F P
.623 .462 .287 r
s
.566 .435 .297 r
.32961 .41017 m .29909 .37335 L .26172 .31663 L p F P
.623 .462 .287 r
s
.48 .396 .273 r
.38718 .4659 m .41286 .48335 L .4299 .49379 L p F P
.623 .462 .287 r
s
.488 .405 .276 r
.4299 .49379 m .41286 .48335 L p .42266 .48755 L F P
.623 .462 .287 r
s
.488 .405 .276 r
.42266 .48755 m .44663 .50133 L .4299 .49379 L p F P
.623 .462 .287 r
s
.53 .402 .276 r
.26346 .30971 m .23389 .26633 L .216 .23215 L p F P
.623 .462 .287 r
s
.53 .402 .276 r
.216 .23215 m .18423 .17144 L p .23475 .25962 L F P
.623 .462 .287 r
s
.53 .402 .276 r
.26346 .30971 m .216 .23215 L .23475 .25962 L F
.22798 .24938 m .26346 .30971 L p .23475 .25962 L F P
.623 .462 .287 r
s
.53 .402 .276 r
.18423 .17144 m .22798 .24938 L p .23475 .25962 L F P
.623 .462 .287 r
s
.611 .459 .308 r
.22798 .24938 m .27311 .31565 L .28143 .328 L p F P
.623 .462 .287 r
s
.611 .459 .308 r
.28143 .328 m .30348 .36073 L p .26069 .29762 L F P
.623 .462 .287 r
s
.611 .459 .308 r
.26069 .29762 m .22798 .24938 L .28143 .328 L F
.098 .457 .833 r
.18423 .17144 m .23032 .1688 L .22798 .24938 L closepath p F P
.294 .652 1 r
s
.623 .516 .329 r
.50259 .51549 m .48859 .51365 L .51688 .51391 L p F P
.623 .462 .287 r
s
.562 .443 .302 r
.32961 .41017 m .36041 .44153 L .38718 .4659 L p F P
.623 .462 .287 r
s
.618 .486 .327 r
.41286 .48335 m .38718 .4659 L .36041 .44153 L p F P
.623 .462 .287 r
s
.614 .509 .328 r
.51688 .51391 m .48859 .51365 L .49035 .51275 L p F P
.623 .462 .287 r
s
.673 .537 .355 r
.4699 .50889 m .44663 .50133 L .42266 .48755 L p F P
.623 .462 .287 r
s
.566 .435 .297 r
.26172 .31663 m .29743 .36793 L .32961 .41017 L p F P
.623 .462 .287 r
s
.609 .468 .316 r
.36041 .44153 m .32961 .41017 L .29743 .36793 L p F P
.623 .462 .287 r
s
.533 .41 .282 r
.29743 .36793 m .26172 .31663 L .23389 .26633 L p F P
.623 .462 .287 r
s
.098 .457 .833 r
.27311 .31565 m .22798 .24938 L .23032 .1688 L p F P
.294 .652 1 r
s
.098 .457 .833 r
.23032 .1688 m .27674 .16615 L .27311 .31565 L p F P
.294 .652 1 r
s
.999 .761 .46 r
.68528 .42138 m .72494 .38428 L .69932 .41417 L p F P
.623 .462 .287 r
s
.618 .486 .327 r
.36041 .44153 m .39144 .46736 L .41286 .48335 L p F P
.623 .462 .287 r
s
.488 .405 .276 r
.41286 .48335 m .39144 .46736 L .42266 .48755 L p F P
.623 .462 .287 r
s
.951 .738 .455 r
.62156 .48068 m .6419 .46886 L .61087 .48863 L p F P
.623 .462 .287 r
s
.853 .672 .425 r
.51688 .51391 m .55143 .51127 L .53994 .51408 L p F P
.623 .462 .287 r
s
.673 .537 .355 r
.42266 .48755 m .454 .50207 L .4699 .50889 L p F P
.623 .462 .287 r
s
.632 .518 .339 r
.4699 .50889 m .454 .50207 L p .48218 .50939 L F P
.623 .462 .287 r
s
.632 .518 .339 r
.48218 .50939 m .49035 .51275 L .4699 .50889 L p F P
.623 .462 .287 r
s
.609 .468 .316 r
.29743 .36793 m .33352 .41172 L .36041 .44153 L p F P
.623 .462 .287 r
s
.656 .505 .337 r
.39144 .46736 m .36041 .44153 L .33352 .41172 L p F P
.623 .462 .287 r
s
.533 .41 .282 r
.23389 .26633 m .27347 .33044 L .29743 .36793 L p F P
.623 .462 .287 r
s
.327 .253 .191 r
.27347 .33044 m .23389 .26633 L .26346 .30971 L p F P
.623 .462 .287 r
s
.58 .446 .303 r
.33352 .41172 m .29743 .36793 L .27347 .33044 L p F P
.623 .462 .287 r
s
.922 .711 .428 r
.69932 .41417 m .67353 .44024 L .64973 .45525 L p F P
.623 .462 .287 r
s
.999 .761 .46 r
.69932 .41417 m .67191 .43502 L .68528 .42138 L p F P
.623 .462 .287 r
s
.794 .633 .39 r
.61087 .48863 m .57966 .50277 L .56429 .50526 L p F P
.623 .462 .287 r
s
.951 .738 .455 r
.60534 .48675 m .62156 .48068 L p .61087 .48863 L F P
.623 .462 .287 r
s
.951 .738 .455 r
.61087 .48863 m .58809 .49577 L .60534 .48675 L p F P
.623 .462 .287 r
s
.098 .457 .833 r
.31947 .36962 m .27311 .31565 L .27674 .16615 L p F P
.294 .652 1 r
s
.098 .457 .833 r
.27674 .16615 m .3235 .16348 L .31947 .36962 L p F P
.294 .652 1 r
s
.656 .505 .337 r
.33352 .41172 m .36992 .44787 L .39144 .46736 L p F P
.623 .462 .287 r
s
.475 .392 .271 r
.39144 .46736 m .36992 .44787 L p .40093 .47084 L F P
.623 .462 .287 r
s
.475 .392 .271 r
.40093 .47084 m .42266 .48755 L .39144 .46736 L p F P
.623 .462 .287 r
s
.614 .509 .328 r
.49035 .51275 m .48218 .50939 L .51688 .51391 L p F P
.623 .462 .287 r
s
.885 .69 .438 r
.54355 .51073 m .55143 .51127 L .51688 .51391 L p F P
.623 .462 .287 r
s
.895 .702 .44 r
.56429 .50526 m .57966 .50277 L p .55143 .51127 L F P
.623 .462 .287 r
s
.895 .702 .44 r
.55143 .51127 m .54355 .51073 L .56429 .50526 L p F P
.623 .462 .287 r
s
.919 .712 .431 r
.67353 .44024 m .6476 .46242 L .62754 .47249 L p F P
.623 .462 .287 r
s
.58 .446 .303 r
.27347 .33044 m .31352 .38526 L .33352 .41172 L p F P
.623 .462 .287 r
s
.632 .485 .325 r
.36992 .44787 m .33352 .41172 L .31352 .38526 L p F P
.623 .462 .287 r
s
.753 .58 .38 r
.454 .50207 m .42668 .48942 L p .43913 .49332 L F P
.623 .462 .287 r
s
.753 .58 .38 r
.42266 .48755 m .40093 .47084 L p .43913 .49332 L F P
.623 .462 .287 r
s
.753 .58 .38 r
.42668 .48942 m .42266 .48755 L p .43913 .49332 L F P
.623 .462 .287 r
s
.753 .58 .38 r
.40093 .47084 m .43962 .49408 L .454 .50207 L p F P
.623 .462 .287 r
s
.797 .616 .4 r
.49356 .50937 m .48218 .50939 L .43962 .49408 L p F P
.623 .462 .287 r
s
.797 .616 .4 r
.43962 .49408 m .45628 .49934 L p .4711 .50333 L F P
.623 .462 .287 r
s
.797 .616 .4 r
.49356 .50937 m .46017 .49991 L .4711 .50333 L F
.46017 .49991 m .43962 .49408 L .4711 .50333 L F
.909 .708 .431 r
.6476 .46242 m .62156 .48068 L .60534 .48675 L p F P
.623 .462 .287 r
s
.351 .275 .204 r
.31352 .38526 m .27347 .33044 L .29928 .3625 L p F P
.623 .462 .287 r
s
.327 .253 .191 r
.26346 .30971 m .29928 .3625 L .27347 .33044 L p F P
.623 .462 .287 r
s
.071 .334 .641 r
.68528 .42138 m .71537 .37032 L .71132 .16444 L p F P
.294 .652 1 r
s
.071 .334 .641 r
.74242 .15208 m .71132 .16444 L .71537 .37032 L p F P
.294 .652 1 r
s
.632 .518 .339 r
.454 .50207 m .43962 .49408 L .48218 .50939 L p F P
.623 .462 .287 r
s
.862 .672 .43 r
.53145 .50791 m .54566 .50695 L .51688 .51391 L p F P
.623 .462 .287 r
s
.862 .672 .43 r
.51688 .51391 m .52269 .50457 L .53145 .50791 L p F P
.623 .462 .287 r
s
.803 .634 .408 r
.51062 .50735 m .52269 .50457 L .51688 .51391 L p F P
.623 .462 .287 r
s
.803 .634 .408 r
.51688 .51391 m .49621 .50559 L .51062 .50735 L p F P
.623 .462 .287 r
s
.706 .571 .369 r
.49356 .50937 m .49621 .50559 L .51688 .51391 L p F P
.623 .462 .287 r
s
.706 .571 .369 r
.51688 .51391 m .48218 .50939 L .49356 .50937 L p F P
.623 .462 .287 r
s
.885 .69 .438 r
.51688 .51391 m .54566 .50695 L .54355 .51073 L p F P
.623 .462 .287 r
s
.632 .485 .325 r
.31352 .38526 m .35393 .43057 L .36992 .44787 L p F P
.623 .462 .287 r
s
.475 .392 .271 r
.36992 .44787 m .35393 .43057 L .40093 .47084 L p F P
.623 .462 .287 r
s
.098 .457 .833 r
.36689 .41071 m .31947 .36962 L .3235 .16348 L p F P
.294 .652 1 r
s
.098 .457 .833 r
.3235 .16348 m .37059 .16079 L .36689 .41071 L p F P
.294 .652 1 r
s
.611 .459 .308 r
.30348 .36073 m .26346 .30971 L .22798 .24938 L p F P
.623 .462 .287 r
s
.377 .3 .218 r
.35393 .43057 m .31352 .38526 L .33537 .40756 L p F P
.623 .462 .287 r
s
.351 .275 .204 r
.29928 .3625 m .33537 .40756 L .31352 .38526 L p F P
.623 .462 .287 r
s
.946 .734 .456 r
.57301 .49741 m .56429 .50526 L .54355 .51073 L p F P
.623 .462 .287 r
s
.946 .734 .456 r
.58142 .48841 m .57301 .49741 L p .54355 .51073 L F P
.623 .462 .287 r
s
.946 .734 .456 r
.54355 .51073 m .54566 .50695 L .58142 .48841 L p F P
.623 .462 .287 r
s
.72 .545 .358 r
.42577 .48331 m .40093 .47084 L .35393 .43057 L p F P
.623 .462 .287 r
s
.72 .545 .358 r
.35393 .43057 m .37164 .44478 L p .42577 .48331 L F P
.623 .462 .287 r
s
.377 .3 .218 r
.33537 .40756 m .37164 .44478 L .35393 .43057 L p F P
.623 .462 .287 r
s
.525 .431 .293 r
.42577 .48331 m .45628 .49934 L .43962 .49408 L p F P
.623 .462 .287 r
s
.525 .431 .293 r
.43962 .49408 m .40093 .47084 L .42577 .48331 L p F P
.623 .462 .287 r
s
1 .764 .476 r
.58809 .49577 m .56429 .50526 L .57301 .49741 L p F P
.623 .462 .287 r
s
.434 .343 .244 r
.29928 .3625 m .26346 .30971 L .30348 .36073 L p F P
.623 .462 .287 r
s
.123 .574 .971 r
.3508 .3568 m .36689 .41071 L .37059 .16079 L p F P
.294 .652 1 r
s
.123 .574 .971 r
.37059 .16079 m .35427 .14616 L .3508 .3568 L p F P
.294 .652 1 r
s
1 .764 .476 r
.57301 .49741 m .60147 .48028 L .58809 .49577 L p F P
.623 .462 .287 r
s
.987 .758 .463 r
.61545 .47501 m .60534 .48675 L .58809 .49577 L p F P
.623 .462 .287 r
s
.987 .758 .463 r
.63014 .45715 m .61545 .47501 L p .58809 .49577 L F P
.623 .462 .287 r
s
.987 .758 .463 r
.58809 .49577 m .60147 .48028 L .63014 .45715 L p F P
.623 .462 .287 r
s
.811 .633 .409 r
.49621 .50559 m .49356 .50937 L .47531 .50281 L p F P
.623 .462 .287 r
s
.797 .616 .4 r
.45628 .49934 m .47531 .50281 L .49356 .50937 L p F P
.623 .462 .287 r
s
.451 .36 .254 r
.33537 .40756 m .29928 .3625 L .33398 .40009 L p F P
.623 .462 .287 r
s
.434 .343 .244 r
.30348 .36073 m .33398 .40009 L .29928 .3625 L p F P
.623 .462 .287 r
s
1 .781 .481 r
.62754 .47249 m .60534 .48675 L .61545 .47501 L p F P
.623 .462 .287 r
s
.707 .555 .366 r
.45424 .49199 m .47531 .50281 L .45628 .49934 L p F P
.623 .462 .287 r
s
.707 .555 .366 r
.45628 .49934 m .42577 .48331 L .45424 .49199 L p F P
.623 .462 .287 r
s
.467 .377 .264 r
.37164 .44478 m .33537 .40756 L .36456 .43366 L p F P
.623 .462 .287 r
s
.451 .36 .254 r
.33398 .40009 m .36456 .43366 L .33537 .40756 L p F P
.623 .462 .287 r
s
1 .781 .481 r
.61545 .47501 m .64038 .45503 L .62754 .47249 L p F P
.623 .462 .287 r
s
1 .785 .482 r
.64973 .45525 m .62754 .47249 L .64038 .45503 L p F P
.623 .462 .287 r
s
.72 .545 .358 r
.37164 .44478 m .39518 .46141 L .42577 .48331 L p F P
.623 .462 .287 r
s
.467 .377 .264 r
.36456 .43366 m .39518 .46141 L .37164 .44478 L p F P
.623 .462 .287 r
s
1 .785 .482 r
.64038 .45503 m .66536 .43091 L .64973 .45525 L p F P
.623 .462 .287 r
s
1 .785 .48 r
.67191 .43502 m .64973 .45525 L .66536 .43091 L p F P
.623 .462 .287 r
s
1 .77 .464 r
.71537 .37032 m .68528 .42138 L .67191 .43502 L p F P
.623 .462 .287 r
s
1 .785 .48 r
.66536 .43091 m .69036 .40267 L .67191 .43502 L p F P
.623 .462 .287 r
s
1 .77 .464 r
.67191 .43502 m .69036 .40267 L .71537 .37032 L p F P
.623 .462 .287 r
s
.937 .72 .455 r
.5636 .49511 m .58142 .48841 L .54566 .50695 L p F P
.623 .462 .287 r
s
.937 .72 .455 r
.54292 .50017 m .5636 .49511 L p .54566 .50695 L F P
.623 .462 .287 r
s
.937 .72 .455 r
.54566 .50695 m .53145 .50791 L .54292 .50017 L p F P
.623 .462 .287 r
s
.758 .576 .377 r
.45424 .49199 m .42577 .48331 L .39518 .46141 L p F P
.623 .462 .287 r
s
.965 .732 .461 r
.53561 .49211 m .54292 .50017 L .53145 .50791 L p F P
.623 .462 .287 r
s
.965 .732 .461 r
.53001 .48278 m .53561 .49211 L p .53145 .50791 L F P
.623 .462 .287 r
s
.965 .732 .461 r
.53145 .50791 m .52269 .50457 L .53001 .48278 L p F P
.623 .462 .287 r
s
.811 .633 .409 r
.47531 .50281 m .47311 .4946 L p .49621 .50559 L F P
.623 .462 .287 r
s
.846 .645 .416 r
.45069 .47585 m .47311 .4946 L .47531 .50281 L p F P
.623 .462 .287 r
s
.846 .645 .416 r
.47531 .50281 m .45424 .49199 L .45069 .47585 L p F P
.623 .462 .287 r
s
.758 .576 .377 r
.39518 .46141 m .41891 .47473 L p .45424 .49199 L F P
.623 .462 .287 r
s
.598 .469 .317 r
.39412 .45466 m .41891 .47473 L .39518 .46141 L p F P
.623 .462 .287 r
s
.598 .469 .317 r
.39518 .46141 m .36456 .43366 L .39412 .45466 L p F P
.623 .462 .287 r
s
.893 .686 .438 r
.52269 .50457 m .51062 .50735 L .50568 .49913 L p F P
.623 .462 .287 r
s
.895 .678 .433 r
.48658 .49293 m .50568 .49913 L .51062 .50735 L p F P
.623 .462 .287 r
s
.895 .678 .433 r
.47032 .48521 m .48658 .49293 L p .51062 .50735 L F P
.623 .462 .287 r
s
.895 .678 .433 r
.51062 .50735 m .49621 .50559 L .47032 .48521 L p F P
.623 .462 .287 r
s
.996 .75 .468 r
.60147 .48028 m .57301 .49741 L .58142 .48841 L p F P
.623 .462 .287 r
s
.811 .633 .409 r
.47311 .4946 m .47032 .48521 L .49621 .50559 L p F P
.623 .462 .287 r
s
.58 .451 .307 r
.36926 .43044 m .39412 .45466 L .36456 .43366 L p F P
.623 .462 .287 r
s
.58 .451 .307 r
.36456 .43366 m .33398 .40009 L .36926 .43044 L p F P
.623 .462 .287 r
s
.654 .491 .327 r
.27311 .31565 m .31947 .36962 L .34436 .40209 L p F P
.623 .462 .287 r
s
.654 .491 .327 r
.34436 .40209 m .30348 .36073 L .27311 .31565 L p F P
.623 .462 .287 r
s
.561 .434 .296 r
.34436 .40209 m .36926 .43044 L .33398 .40009 L p F P
.623 .462 .287 r
s
.561 .434 .296 r
.33398 .40009 m .30348 .36073 L .34436 .40209 L p F P
.623 .462 .287 r
s
1 .774 .478 r
.64038 .45503 m .61545 .47501 L .63014 .45715 L p F P
.623 .462 .287 r
s
.758 .576 .377 r
.41891 .47473 m .4389 .48195 L .45424 .49199 L p F P
.623 .462 .287 r
s
.689 .533 .354 r
.41905 .46626 m .4389 .48195 L .41891 .47473 L p F P
.623 .462 .287 r
s
.689 .533 .354 r
.41891 .47473 m .39412 .45466 L .41905 .46626 L p F P
.623 .462 .287 r
s
.893 .686 .438 r
.51902 .49164 m .53001 .48278 L .52269 .50457 L p F P
.623 .462 .287 r
s
.893 .686 .438 r
.50568 .49913 m .51902 .49164 L p .52269 .50457 L F P
.623 .462 .287 r
s
.792 .607 .395 r
.45069 .47585 m .45424 .49199 L .4389 .48195 L p F P
.623 .462 .287 r
s
1 .774 .478 r
.63014 .45715 m .65896 .42798 L .64038 .45503 L p F P
.623 .462 .287 r
s
1 .776 .477 r
.66536 .43091 m .64038 .45503 L .65896 .42798 L p F P
.623 .462 .287 r
s
.071 .334 .641 r
.71537 .37032 m .7459 .30422 L .74242 .15208 L p F P
.294 .652 1 r
s
.071 .334 .641 r
.77457 .1393 m .74242 .15208 L .7459 .30422 L p F P
.294 .652 1 r
s
.996 .75 .468 r
.58142 .48841 m .6144 .46179 L .60147 .48028 L p F P
.623 .462 .287 r
s
1 .77 .467 r
.64498 .43556 m .63014 .45715 L .60147 .48028 L p F P
.623 .462 .287 r
s
1 .77 .467 r
.65508 .41657 m .64498 .43556 L p .60147 .48028 L F P
.623 .462 .287 r
s
1 .77 .467 r
.60147 .48028 m .6144 .46179 L .65508 .41657 L p F P
.623 .462 .287 r
s
.669 .515 .343 r
.39909 .44744 m .41905 .46626 L .39412 .45466 L p F P
.623 .462 .287 r
s
.669 .515 .343 r
.39412 .45466 m .36926 .43044 L .39909 .44744 L p F P
.623 .462 .287 r
s
.986 .752 .471 r
.58749 .47666 m .5636 .49511 L .54292 .50017 L p F P
.623 .462 .287 r
s
.986 .752 .471 r
.54292 .50017 m .55625 .48789 L .58749 .47666 L p F P
.623 .462 .287 r
s
.94 .708 .447 r
.55625 .48789 m .54292 .50017 L .53561 .49211 L p F P
.623 .462 .287 r
s
1 .767 .474 r
.6144 .46179 m .58142 .48841 L .5636 .49511 L p F P
.623 .462 .287 r
s
1 .767 .474 r
.5636 .49511 m .58749 .47666 L .6144 .46179 L p F P
.623 .462 .287 r
s
1 .776 .477 r
.65896 .42798 m .68789 .39276 L .66536 .43091 L p F P
.623 .462 .287 r
s
1 .775 .475 r
.69036 .40267 m .66536 .43091 L .68789 .39276 L p F P
.623 .462 .287 r
s
.792 .607 .395 r
.4389 .48195 m .43543 .46966 L p .45069 .47585 L F P
.623 .462 .287 r
s
.793 .602 .391 r
.41452 .448 m .43543 .46966 L .4389 .48195 L p F P
.623 .462 .287 r
s
.793 .602 .391 r
.4389 .48195 m .41905 .46626 L .41452 .448 L p F P
.623 .462 .287 r
s
.873 .657 .42 r
.44625 .45664 m .47032 .48521 L .47311 .4946 L p F P
.623 .462 .287 r
s
.873 .657 .42 r
.47311 .4946 m .45069 .47585 L .44625 .45664 L p F P
.623 .462 .287 r
s
.65 .498 .333 r
.37904 .42549 m .39909 .44744 L .36926 .43044 L p F P
.623 .462 .287 r
s
.65 .498 .333 r
.36926 .43044 m .34436 .40209 L .37904 .42549 L p F P
.623 .462 .287 r
s
1 .775 .475 r
.68789 .39276 m .71689 .3515 L .69036 .40267 L p F P
.623 .462 .287 r
s
1 .761 .456 r
.7459 .30422 m .71537 .37032 L .69036 .40267 L p F P
.623 .462 .287 r
s
1 .761 .456 r
.69036 .40267 m .71689 .3515 L .7459 .30422 L p F P
.623 .462 .287 r
s
.926 .7 .444 r
.52013 .47116 m .51902 .49164 L .50568 .49913 L p F P
.623 .462 .287 r
s
.926 .7 .444 r
.50568 .49913 m .49993 .48628 L .52013 .47116 L p F P
.623 .462 .287 r
s
.857 .649 .417 r
.49993 .48628 m .50568 .49913 L .48658 .49293 L p F P
.623 .462 .287 r
s
.681 .514 .34 r
.37904 .42549 m .34436 .40209 L .31947 .36962 L p F P
.623 .462 .287 r
s
1 .757 .468 r
.65896 .42798 m .63014 .45715 L .64498 .43556 L p F P
.623 .462 .287 r
s
.774 .585 .381 r
.39343 .42199 m .41452 .448 L .41905 .46626 L p F P
.623 .462 .287 r
s
.774 .585 .381 r
.41905 .46626 m .39909 .44744 L .39343 .42199 L p F P
.623 .462 .287 r
s
.681 .514 .34 r
.31947 .36962 m .36689 .41071 L .37904 .42549 L p F P
.623 .462 .287 r
s
.857 .649 .417 r
.48658 .49293 m .47096 .47322 L .49993 .48628 L p F P
.623 .462 .287 r
s
.807 .612 .397 r
.47096 .47322 m .48658 .49293 L .47032 .48521 L p F P
.623 .462 .287 r
s
.123 .574 .971 r
.33446 .28706 m .3508 .3568 L .35427 .14616 L p F P
.294 .652 1 r
s
.123 .574 .971 r
.35427 .14616 m .33731 .13095 L .33446 .28706 L p F P
.294 .652 1 r
s
1 .757 .468 r
.64498 .43556 m .67777 .39506 L .65896 .42798 L p F P
.623 .462 .287 r
s
1 .758 .467 r
.68789 .39276 m .65896 .42798 L .67777 .39506 L p F P
.623 .462 .287 r
s
.94 .708 .447 r
.53561 .49211 m .54528 .47191 L .55625 .48789 L p F P
.623 .462 .287 r
s
.904 .677 .43 r
.54528 .47191 m .53561 .49211 L .53001 .48278 L p F P
.623 .462 .287 r
s
.976 .737 .463 r
.58749 .47666 m .55625 .48789 L .566 .47671 L p F P
.623 .462 .287 r
s
.974 .728 .456 r
.55938 .46441 m .566 .47671 L .55625 .48789 L p F P
.623 .462 .287 r
s
.974 .728 .456 r
.55516 .44526 m .55938 .46441 L p .55625 .48789 L F P
.623 .462 .287 r
s
.974 .728 .456 r
.55625 .48789 m .54528 .47191 L .55516 .44526 L p F P
.623 .462 .287 r
s
.993 .745 .465 r
.6144 .46179 m .58749 .47666 L .61169 .45203 L p F P
.623 .462 .287 r
s
.976 .737 .463 r
.58757 .46765 m .61169 .45203 L .58749 .47666 L p F P
.623 .462 .287 r
s
.976 .737 .463 r
.566 .47671 m .58757 .46765 L p .58749 .47666 L F P
.623 .462 .287 r
s
.993 .745 .465 r
.63583 .43288 m .65508 .41657 L .6144 .46179 L p F P
.623 .462 .287 r
s
.993 .745 .465 r
.61169 .45203 m .63583 .43288 L p .6144 .46179 L F P
.623 .462 .287 r
s
.757 .57 .372 r
.37218 .39159 m .39343 .42199 L .39909 .44744 L p F P
.623 .462 .287 r
s
.757 .57 .372 r
.39909 .44744 m .37904 .42549 L .37218 .39159 L p F P
.623 .462 .287 r
s
.807 .612 .397 r
.47032 .48521 m .44625 .45664 L .47096 .47322 L p F P
.623 .462 .287 r
s
.96 .721 .454 r
.53686 .45269 m .53001 .48278 L .51902 .49164 L p F P
.623 .462 .287 r
s
.96 .721 .454 r
.51902 .49164 m .52013 .47116 L .53686 .45269 L p F P
.623 .462 .287 r
s
.792 .607 .395 r
.43543 .46966 m .42794 .45089 L .45069 .47585 L p F P
.623 .462 .287 r
s
.824 .617 .397 r
.40491 .41959 m .42794 .45089 L .43543 .46966 L p F P
.623 .462 .287 r
s
.824 .617 .397 r
.43543 .46966 m .41452 .448 L .40491 .41959 L p F P
.623 .462 .287 r
s
.792 .6 .39 r
.44625 .45664 m .45069 .47585 L .42794 .45089 L p F P
.623 .462 .287 r
s
.995 .738 .458 r
.67777 .39506 m .64498 .43556 L .65508 .41657 L p F P
.623 .462 .287 r
s
1 .758 .467 r
.67777 .39506 m .71071 .34609 L .68789 .39276 L p F P
.623 .462 .287 r
s
1 .757 .465 r
.71689 .3515 m .68789 .39276 L .71071 .34609 L p F P
.623 .462 .287 r
s
.096 .447 .817 r
.6617 .35163 m .61243 .39884 L .61002 .14344 L p F P
.294 .652 1 r
s
.096 .447 .817 r
.61002 .14344 m .65865 .13918 L .6617 .35163 L p F P
.294 .652 1 r
s
.108 .5 .814 r
.60273 .12778 m .61002 .14344 L .61243 .39884 L p F P
.294 .652 1 r
s
.72 .544 .358 r
.37218 .39159 m .37904 .42549 L .36689 .41071 L p F P
.623 .462 .287 r
s
.894 .673 .429 r
.52013 .47116 m .49993 .48628 L .4957 .47464 L p F P
.623 .462 .287 r
s
.875 .653 .416 r
.47601 .46429 m .4957 .47464 L .49993 .48628 L p F P
.623 .462 .287 r
s
.875 .653 .416 r
.45505 .44713 m .47601 .46429 L p .49993 .48628 L F P
.623 .462 .287 r
s
.875 .653 .416 r
.49993 .48628 m .47096 .47322 L .45505 .44713 L p F P
.623 .462 .287 r
s
1 .757 .465 r
.71071 .34609 m .74373 .28867 L .71689 .3515 L p F P
.623 .462 .287 r
s
.071 .334 .641 r
.7459 .30422 m .77676 .22285 L .77457 .1393 L p F P
.294 .652 1 r
s
1 .762 .456 r
.77676 .22285 m .7459 .30422 L .71689 .3515 L p F P
.623 .462 .287 r
s
1 .762 .456 r
.71689 .3515 m .74373 .28867 L .77676 .22285 L p F P
.623 .462 .287 r
s
.72 .544 .358 r
.36689 .41071 m .3508 .3568 L .37218 .39159 L p F P
.623 .462 .287 r
s
.991 .744 .465 r
.60583 .44534 m .58757 .46765 L .566 .47671 L p F P
.623 .462 .287 r
s
.991 .744 .465 r
.566 .47671 m .5787 .45943 L .60583 .44534 L p F P
.623 .462 .287 r
s
.942 .703 .443 r
.5787 .45943 m .566 .47671 L .55938 .46441 L p F P
.623 .462 .287 r
s
1 .773 .478 r
.63616 .42113 m .61169 .45203 L .58757 .46765 L p F P
.623 .462 .287 r
s
1 .773 .478 r
.58757 .46765 m .60583 .44534 L .63616 .42113 L p F P
.623 .462 .287 r
s
.904 .677 .43 r
.53001 .48278 m .53686 .45269 L .54528 .47191 L p F P
.623 .462 .287 r
s
.806 .601 .388 r
.38163 .3819 m .40491 .41959 L .41452 .448 L p F P
.623 .462 .287 r
s
.806 .601 .388 r
.41452 .448 m .39343 .42199 L .38163 .3819 L p F P
.623 .462 .287 r
s
1 .785 .481 r
.66649 .3914 m .63583 .43288 L .61169 .45203 L p F P
.623 .462 .287 r
s
1 .785 .481 r
.61169 .45203 m .63616 .42113 L .66649 .3914 L p F P
.623 .462 .287 r
s
.995 .738 .458 r
.65508 .41657 m .69061 .36601 L .67777 .39506 L p F P
.623 .462 .287 r
s
.997 .737 .456 r
.71071 .34609 m .67777 .39506 L .69061 .36601 L p F P
.623 .462 .287 r
s
1 .784 .48 r
.69061 .36601 m .65508 .41657 L .63583 .43288 L p F P
.623 .462 .287 r
s
.854 .633 .404 r
.43394 .42629 m .45505 .44713 L .47096 .47322 L p F P
.623 .462 .287 r
s
.854 .633 .404 r
.41631 .4085 m .43394 .42629 L p .47096 .47322 L F P
.623 .462 .287 r
s
.854 .633 .404 r
.47096 .47322 m .44625 .45664 L .41631 .4085 L p F P
.623 .462 .287 r
s
1 .784 .48 r
.63583 .43288 m .66649 .3914 L .69061 .36601 L p F P
.623 .462 .287 r
s
.071 .334 .641 r
.80782 .12609 m .77457 .1393 L .77676 .22285 L closepath p F P
.294 .652 1 r
s
.096 .447 .817 r
.71083 .29024 m .6617 .35163 L .65865 .13918 L p F P
.294 .652 1 r
s
.096 .447 .817 r
.65865 .13918 m .70782 .13486 L .71083 .29024 L p F P
.294 .652 1 r
s
.792 .6 .39 r
.42794 .45089 m .42036 .42827 L p .44625 .45664 L F P
.623 .462 .287 r
s
.83 .617 .396 r
.39518 .38509 m .42036 .42827 L .42794 .45089 L p F P
.623 .462 .287 r
s
.83 .617 .396 r
.42794 .45089 m .40491 .41959 L .39518 .38509 L p F P
.623 .462 .287 r
s
.894 .673 .429 r
.4957 .47464 m .50893 .46288 L p .52013 .47116 L F P
.623 .462 .287 r
s
.896 .67 .426 r
.50684 .43902 m .50893 .46288 L .4957 .47464 L p F P
.623 .462 .287 r
s
.896 .67 .426 r
.4957 .47464 m .49019 .45671 L .50684 .43902 L p F P
.623 .462 .287 r
s
.846 .633 .406 r
.49019 .45671 m .4957 .47464 L .47601 .46429 L p F P
.623 .462 .287 r
s
.961 .713 .446 r
.55086 .42221 m .55516 .44526 L .54528 .47191 L p F P
.623 .462 .287 r
s
.961 .713 .446 r
.54543 .40226 m .55086 .42221 L p .54528 .47191 L F P
.623 .462 .287 r
s
.961 .713 .446 r
.54528 .47191 m .53686 .45269 L .54543 .40226 L p F P
.623 .462 .287 r
s
.997 .737 .456 r
.69061 .36601 m .72633 .30481 L .71071 .34609 L p F P
.623 .462 .287 r
s
.997 .735 .453 r
.74373 .28867 m .71071 .34609 L .72633 .30481 L p F P
.623 .462 .287 r
s
.792 .6 .39 r
.42036 .42827 m .41631 .4085 L .44625 .45664 L p F P
.623 .462 .287 r
s
.79 .588 .38 r
.35813 .33773 m .38163 .3819 L .39343 .42199 L p F P
.623 .462 .287 r
s
.79 .588 .38 r
.39343 .42199 m .37218 .39159 L .35813 .33773 L p F P
.623 .462 .287 r
s
.055 .258 .517 r
.5004 .33916 m .47549 .39406 L .47655 .13647 L p F P
.294 .652 1 r
s
.055 .258 .517 r
.47655 .13647 m .50075 .12235 L .5004 .33916 L p F P
.294 .652 1 r
s
.114 .531 .939 r
.43427 .12735 m .47655 .13647 L .47549 .39406 L p F P
.294 .652 1 r
s
.942 .703 .443 r
.55938 .46441 m .57045 .44105 L .5787 .45943 L p F P
.623 .462 .287 r
s
.989 .739 .461 r
.62428 .4186 m .60583 .44534 L .5787 .45943 L p F P
.623 .462 .287 r
s
.989 .739 .461 r
.5787 .45943 m .59154 .43885 L .62428 .4186 L p F P
.623 .462 .287 r
s
.938 .697 .438 r
.59154 .43885 m .5787 .45943 L .57045 .44105 L p F P
.623 .462 .287 r
s
1 .769 .475 r
.66087 .3839 m .63616 .42113 L .60583 .44534 L p F P
.623 .462 .287 r
s
1 .769 .475 r
.60583 .44534 m .62428 .4186 L .66087 .3839 L p F P
.623 .462 .287 r
s
.895 .669 .425 r
.53686 .45269 m .52013 .47116 L .52126 .44419 L p F P
.623 .462 .287 r
s
.894 .673 .429 r
.50893 .46288 m .52126 .44419 L .52013 .47116 L p F P
.623 .462 .287 r
s
.918 .682 .43 r
.57045 .44105 m .55938 .46441 L .55516 .44526 L p F P
.623 .462 .287 r
s
.846 .633 .406 r
.47601 .46429 m .46535 .44089 L .49019 .45671 L p F P
.623 .462 .287 r
s
.817 .61 .393 r
.46535 .44089 m .47601 .46429 L .45505 .44713 L p F P
.623 .462 .287 r
s
1 .781 .478 r
.69739 .34126 m .66649 .3914 L .63616 .42113 L p F P
.623 .462 .287 r
s
1 .781 .478 r
.63616 .42113 m .66087 .3839 L .69739 .34126 L p F P
.623 .462 .287 r
s
1 .778 .475 r
.72633 .30481 m .69061 .36601 L .66649 .3914 L p F P
.623 .462 .287 r
s
.096 .447 .817 r
.7596 .21493 m .71083 .29024 L .70782 .13486 L p F P
.294 .652 1 r
s
.096 .447 .817 r
.70782 .13486 m .75754 .1305 L .7596 .21493 L p F P
.294 .652 1 r
s
1 .778 .475 r
.66649 .3914 m .69739 .34126 L .72633 .30481 L p F P
.623 .462 .287 r
s
.997 .735 .453 r
.72633 .30481 m .76214 .233 L .74373 .28867 L p F P
.623 .462 .287 r
s
1 .764 .461 r
.80782 .12609 m .77676 .22285 L .74373 .28867 L p F P
.623 .462 .287 r
s
1 .764 .461 r
.74373 .28867 m .76214 .233 L .80782 .12609 L p F P
.623 .462 .287 r
s
.737 .551 .36 r
.35813 .33773 m .37218 .39159 L .3508 .3568 L p F P
.623 .462 .287 r
s
.922 .686 .433 r
.52241 .41056 m .52126 .44419 L .50893 .46288 L p F P
.623 .462 .287 r
s
.922 .686 .433 r
.50893 .46288 m .50684 .43902 L .52241 .41056 L p F P
.623 .462 .287 r
s
.813 .602 .387 r
.36967 .33288 m .39518 .38509 L .40491 .41959 L p F P
.623 .462 .287 r
s
.813 .602 .387 r
.40491 .41959 m .38163 .3819 L .36967 .33288 L p F P
.623 .462 .287 r
s
.817 .61 .393 r
.45505 .44713 m .43887 .41454 L .46535 .44089 L p F P
.623 .462 .287 r
s
.785 .586 .38 r
.43887 .41454 m .45505 .44713 L .43394 .42629 L p F P
.623 .462 .287 r
s
.821 .609 .391 r
.38992 .35479 m .41631 .4085 L .42036 .42827 L p F P
.623 .462 .287 r
s
.821 .609 .391 r
.42036 .42827 m .39518 .38509 L .38992 .35479 L p F P
.623 .462 .287 r
s
.885 .658 .419 r
.50473 .41051 m .50684 .43902 L .49019 .45671 L p F P
.623 .462 .287 r
s
.885 .658 .419 r
.49019 .45671 m .48461 .43541 L .50473 .41051 L p F P
.623 .462 .287 r
s
.836 .623 .399 r
.48461 .43541 m .49019 .45671 L .46535 .44089 L p F P
.623 .462 .287 r
s
1 .771 .47 r
.76214 .233 m .72633 .30481 L .69739 .34126 L p F P
.623 .462 .287 r
s
1 .763 .471 r
.68577 .34027 m .66087 .3839 L .62428 .4186 L p F P
.623 .462 .287 r
s
1 .763 .471 r
.62428 .4186 m .64291 .38738 L .68577 .34027 L p F P
.623 .462 .287 r
s
.984 .733 .457 r
.64291 .38738 m .62428 .4186 L .59154 .43885 L p F P
.623 .462 .287 r
s
.938 .697 .438 r
.57045 .44105 m .58169 .41311 L .59154 .43885 L p F P
.623 .462 .287 r
s
.984 .733 .457 r
.59154 .43885 m .60453 .41492 L .64291 .38738 L p F P
.623 .462 .287 r
s
.934 .691 .434 r
.60453 .41492 m .59154 .43885 L .58169 .41311 L p F P
.623 .462 .287 r
s
.123 .574 .971 r
.31793 .2011 m .33446 .28706 L .33731 .13095 L p F P
.294 .652 1 r
s
.123 .574 .971 r
.33731 .13095 m .31965 .11513 L .31793 .2011 L p F P
.294 .652 1 r
s
1 .775 .474 r
.72845 .28243 m .69739 .34126 L .66087 .3839 L p F P
.623 .462 .287 r
s
1 .775 .474 r
.66087 .3839 m .68577 .34027 L .72845 .28243 L p F P
.623 .462 .287 r
s
.096 .447 .817 r
.75754 .1305 m .80782 .12609 L .7596 .21493 L closepath p F P
.294 .652 1 r
s
1 .771 .47 r
.69739 .34126 m .72845 .28243 L .76214 .233 L p F P
.623 .462 .287 r
s
.895 .669 .425 r
.53378 .42165 m .54543 .40226 L .53686 .45269 L p F P
.623 .462 .287 r
s
.895 .669 .425 r
.52126 .44419 m .53378 .42165 L p .53686 .45269 L F P
.623 .462 .287 r
s
.737 .551 .36 r
.3508 .3568 m .33446 .28706 L .35813 .33773 L p F P
.623 .462 .287 r
s
.918 .682 .43 r
.55516 .44526 m .56522 .41201 L .57045 .44105 L p F P
.623 .462 .287 r
s
.914 .676 .426 r
.58169 .41311 m .57045 .44105 L .56522 .41201 L p F P
.623 .462 .287 r
s
.895 .662 .419 r
.56522 .41201 m .55516 .44526 L .55086 .42221 L p F P
.623 .462 .287 r
s
.785 .586 .38 r
.43394 .42629 m .41219 .38237 L .43887 .41454 L p F P
.623 .462 .287 r
s
.755 .564 .368 r
.41219 .38237 m .43394 .42629 L .41631 .4085 L p F P
.623 .462 .287 r
s
.836 .623 .399 r
.46535 .44089 m .45453 .4129 L .48461 .43541 L p F P
.623 .462 .287 r
s
.807 .6 .387 r
.45453 .4129 m .46535 .44089 L .43887 .41454 L p F P
.623 .462 .287 r
s
.989 .728 .45 r
.7596 .21493 m .80782 .12609 L .76214 .233 L p F P
.623 .462 .287 r
s
.989 .728 .45 r
.76214 .233 m .72845 .28243 L .7596 .21493 L p F P
.623 .462 .287 r
s
.108 .5 .814 r
.61243 .39884 m .60461 .34319 L .60273 .12778 L p F P
.294 .652 1 r
s
.108 .5 .814 r
.59514 .11147 m .60273 .12778 L .60461 .34319 L p F P
.294 .652 1 r
s
.798 .59 .38 r
.3439 .27157 m .36967 .33288 L .38163 .3819 L p F P
.623 .462 .287 r
s
.798 .59 .38 r
.38163 .3819 m .35813 .33773 L .3439 .27157 L p F P
.623 .462 .287 r
s
.114 .531 .939 r
.47549 .39406 m .43246 .34287 L .43427 .12735 L p F P
.294 .652 1 r
s
.114 .531 .939 r
.39099 .11801 m .43427 .12735 L .43246 .34287 L p F P
.294 .652 1 r
s
.934 .692 .435 r
.53826 .37596 m .53378 .42165 L .52126 .44419 L p F P
.623 .462 .287 r
s
.934 .692 .435 r
.52126 .44419 m .52241 .41056 L .53826 .37596 L p F P
.623 .462 .287 r
s
.755 .564 .368 r
.41631 .4085 m .38992 .35479 L .41219 .38237 L p F P
.623 .462 .287 r
s
.982 .727 .452 r
.68577 .34027 m .64291 .38738 L .6617 .35163 L p F P
.623 .462 .287 r
s
.964 .715 .447 r
.61243 .39884 m .6617 .35163 L .64291 .38738 L p F P
.623 .462 .287 r
s
.964 .715 .447 r
.64291 .38738 m .60453 .41492 L .61243 .39884 L p F P
.623 .462 .287 r
s
.992 .732 .453 r
.71083 .29024 m .7596 .21493 L .72845 .28243 L p F P
.623 .462 .287 r
s
.992 .732 .453 r
.72845 .28243 m .68577 .34027 L .71083 .29024 L p F P
.623 .462 .287 r
s
.934 .691 .434 r
.58169 .41311 m .59308 .38051 L .60453 .41492 L p F P
.623 .462 .287 r
s
.948 .7 .438 r
.60461 .34319 m .61243 .39884 L .60453 .41492 L p F P
.623 .462 .287 r
s
.948 .7 .438 r
.60453 .41492 m .59308 .38051 L .60461 .34319 L p F P
.623 .462 .287 r
s
.982 .727 .452 r
.6617 .35163 m .71083 .29024 L .68577 .34027 L p F P
.623 .462 .287 r
s
.91 .674 .426 r
.52359 .3701 m .52241 .41056 L .50684 .43902 L p F P
.623 .462 .287 r
s
.91 .674 .426 r
.50684 .43902 m .50473 .41051 L .52359 .3701 L p F P
.623 .462 .287 r
s
.874 .649 .413 r
.50258 .37725 m .50473 .41051 L .48461 .43541 L p F P
.623 .462 .287 r
s
.874 .649 .413 r
.48461 .43541 m .47895 .41068 L .50258 .37725 L p F P
.623 .462 .287 r
s
.827 .614 .394 r
.47895 .41068 m .48461 .43541 L .45453 .4129 L p F P
.623 .462 .287 r
s
.803 .593 .382 r
.36316 .2897 m .38992 .35479 L .39518 .38509 L p F P
.623 .462 .287 r
s
.803 .593 .382 r
.39518 .38509 m .36967 .33288 L .36316 .2897 L p F P
.623 .462 .287 r
s
.807 .6 .387 r
.43887 .41454 m .42245 .37531 L .45453 .4129 L p F P
.623 .462 .287 r
s
.777 .577 .373 r
.42245 .37531 m .43887 .41454 L .41219 .38237 L p F P
.623 .462 .287 r
s
.738 .548 .358 r
.3439 .27157 m .35813 .33773 L .33446 .28706 L p F P
.623 .462 .287 r
s
.914 .676 .426 r
.56522 .41201 m .57546 .372 L .58169 .41311 L p F P
.623 .462 .287 r
s
.91 .671 .422 r
.59308 .38051 m .58169 .41311 L .57546 .372 L p F P
.623 .462 .287 r
s
.827 .614 .394 r
.45453 .4129 m .44357 .38025 L .47895 .41068 L p F P
.623 .462 .287 r
s
.799 .592 .381 r
.44357 .38025 m .45453 .4129 L .42245 .37531 L p F P
.623 .462 .287 r
s
.055 .258 .517 r
.526 .26816 m .5004 .33916 L .50075 .12235 L p F P
.294 .652 1 r
s
.055 .258 .517 r
.50075 .12235 m .52585 .1077 L .526 .26816 L p F P
.294 .652 1 r
s
.895 .662 .419 r
.55086 .42221 m .55986 .37674 L .56522 .41201 L p F P
.623 .462 .287 r
s
.874 .646 .41 r
.55986 .37674 m .55086 .42221 L .54543 .40226 L p F P
.623 .462 .287 r
s
.927 .685 .431 r
.55303 .34604 m .54543 .40226 L .53378 .42165 L p F P
.623 .462 .287 r
s
.927 .685 .431 r
.53378 .42165 m .53826 .37596 L .55303 .34604 L p F P
.623 .462 .287 r
s
.777 .577 .373 r
.41219 .38237 m .39011 .32927 L .42245 .37531 L p F P
.623 .462 .287 r
s
.746 .555 .361 r
.39011 .32927 m .41219 .38237 L .38992 .35479 L p F P
.623 .462 .287 r
s
.891 .657 .415 r
.57546 .372 m .56522 .41201 L .55986 .37674 L p F P
.623 .462 .287 r
s
.854 .633 .404 r
.50258 .37725 m .47895 .41068 L .47549 .39406 L p F P
.623 .462 .287 r
s
.836 .617 .394 r
.43246 .34287 m .47549 .39406 L .47895 .41068 L p F P
.623 .462 .287 r
s
.836 .617 .394 r
.47895 .41068 m .44357 .38025 L .43246 .34287 L p F P
.623 .462 .287 r
s
.746 .555 .361 r
.38992 .35479 m .36316 .2897 L .39011 .32927 L p F P
.623 .462 .287 r
s
.788 .581 .374 r
.33611 .21312 m .36316 .2897 L .36967 .33288 L p F P
.623 .462 .287 r
s
.788 .581 .374 r
.36967 .33288 m .3439 .27157 L .33611 .21312 L p F P
.623 .462 .287 r
s
.738 .548 .358 r
.33446 .28706 m .31793 .2011 L .3439 .27157 L p F P
.623 .462 .287 r
s
.899 .664 .42 r
.52479 .32268 m .52359 .3701 L .50473 .41051 L p F P
.623 .462 .287 r
s
.899 .664 .42 r
.50473 .41051 m .50258 .37725 L .52479 .32268 L p F P
.623 .462 .287 r
s
.921 .68 .427 r
.54284 .3207 m .53826 .37596 L .52241 .41056 L p F P
.623 .462 .287 r
s
.921 .68 .427 r
.52241 .41056 m .52359 .3701 L .54284 .3207 L p F P
.623 .462 .287 r
s
.114 .531 .939 r
.43246 .34287 m .38896 .27654 L .39099 .11801 L p F P
.294 .652 1 r
s
.114 .531 .939 r
.34667 .10845 m .39099 .11801 L .38896 .27654 L p F P
.294 .652 1 r
s
.799 .592 .381 r
.42245 .37531 m .40581 .32934 L .44357 .38025 L p F P
.623 .462 .287 r
s
.77 .569 .368 r
.40581 .32934 m .42245 .37531 L .39011 .32927 L p F P
.623 .462 .287 r
s
.874 .646 .41 r
.54543 .40226 m .55303 .34604 L .55986 .37674 L p F P
.623 .462 .287 r
s
.91 .671 .422 r
.57546 .372 m .58586 .32511 L .59308 .38051 L p F P
.623 .462 .287 r
s
.939 .691 .431 r
.59641 .27122 m .60461 .34319 L .59308 .38051 L p F P
.623 .462 .287 r
s
.939 .691 .431 r
.59308 .38051 m .58586 .32511 L .59641 .27122 L p F P
.623 .462 .287 r
s
.854 .633 .404 r
.47549 .39406 m .5004 .33916 L .50258 .37725 L p F P
.623 .462 .287 r
s
.823 .605 .387 r
.38896 .27654 m .43246 .34287 L .44357 .38025 L p F P
.623 .462 .287 r
s
.823 .605 .387 r
.44357 .38025 m .40581 .32934 L .38896 .27654 L p F P
.623 .462 .287 r
s
.123 .574 .971 r
.31965 .11513 m .30126 .09865 L .31793 .2011 L closepath p F P
.294 .652 1 r
s
.77 .569 .368 r
.39011 .32927 m .36775 .26686 L .40581 .32934 L p F P
.623 .462 .287 r
s
.739 .546 .356 r
.36775 .26686 m .39011 .32927 L .36316 .2897 L p F P
.623 .462 .287 r
s
.728 .539 .351 r
.33611 .21312 m .3439 .27157 L .31793 .2011 L p F P
.623 .462 .287 r
s
.891 .657 .415 r
.55986 .37674 m .56904 .32175 L .57546 .372 L p F P
.623 .462 .287 r
s
.887 .652 .411 r
.58586 .32511 m .57546 .372 L .56904 .32175 L p F P
.623 .462 .287 r
s
.869 .64 .405 r
.56904 .32175 m .55986 .37674 L .55303 .34604 L p F P
.623 .462 .287 r
s
.739 .546 .356 r
.36316 .2897 m .33611 .21312 L .36775 .26686 L p F P
.623 .462 .287 r
s
.863 .637 .405 r
.52479 .32268 m .50258 .37725 L .5004 .33916 L p F P
.623 .462 .287 r
s
.914 .673 .423 r
.5608 .27783 m .55303 .34604 L .53826 .37596 L p F P
.623 .462 .287 r
s
.914 .673 .423 r
.53826 .37596 m .54284 .3207 L .5608 .27783 L p F P
.623 .462 .287 r
s
.108 .5 .814 r
.60461 .34319 m .59641 .27122 L .59514 .11147 L p F P
.294 .652 1 r
s
.108 .5 .814 r
.58722 .09446 m .59514 .11147 L .59641 .27122 L p F P
.294 .652 1 r
s
.806 .591 .379 r
.34517 .19509 m .38896 .27654 L .40581 .32934 L p F P
.623 .462 .287 r
s
.806 .591 .379 r
.40581 .32934 m .36775 .26686 L .34517 .19509 L p F P
.623 .462 .287 r
s
.91 .67 .421 r
.54749 .25568 m .54284 .3207 L .52359 .3701 L p F P
.623 .462 .287 r
s
.91 .67 .421 r
.52359 .3701 m .52479 .32268 L .54749 .25568 L p F P
.623 .462 .287 r
s
.114 .531 .939 r
.38896 .27654 m .34517 .19509 L .34667 .10845 L p F P
.294 .652 1 r
s
.114 .531 .939 r
.30126 .09865 m .34667 .10845 L .34517 .19509 L closepath p F P
.294 .652 1 r
s
.728 .539 .351 r
.31793 .2011 m .30126 .09865 L .33611 .21312 L p F P
.623 .462 .287 r
s
.055 .258 .517 r
.55222 .18074 m .526 .26816 L .52585 .1077 L p F P
.294 .652 1 r
s
.055 .258 .517 r
.52585 .1077 m .5519 .0925 L .55222 .18074 L p F P
.294 .652 1 r
s
.783 .574 .369 r
.30126 .09865 m .34517 .19509 L .36775 .26686 L p F P
.623 .462 .287 r
s
.783 .574 .369 r
.36775 .26686 m .33611 .21312 L .30126 .09865 L p F P
.623 .462 .287 r
s
.869 .64 .405 r
.55303 .34604 m .5608 .27783 L .56904 .32175 L p F P
.623 .462 .287 r
s
.887 .652 .411 r
.56904 .32175 m .57838 .25705 L .58586 .32511 L p F P
.623 .462 .287 r
s
.924 .677 .423 r
.58785 .18251 m .59641 .27122 L .58586 .32511 L p F P
.623 .462 .287 r
s
.924 .677 .423 r
.58586 .32511 m .57838 .25705 L .58785 .18251 L p F P
.623 .462 .287 r
s
.863 .637 .405 r
.5004 .33916 m .526 .26816 L .52479 .32268 L p F P
.623 .462 .287 r
s
.865 .635 .402 r
.57838 .25705 m .56904 .32175 L .5608 .27783 L p F P
.623 .462 .287 r
s
.903 .663 .417 r
.5687 .1974 m .5608 .27783 L .54284 .3207 L p F P
.623 .462 .287 r
s
.903 .663 .417 r
.54284 .3207 m .54749 .25568 L .5687 .1974 L p F P
.623 .462 .287 r
s
.864 .636 .403 r
.54749 .25568 m .52479 .32268 L .526 .26816 L p F P
.623 .462 .287 r
s
.108 .5 .814 r
.59641 .27122 m .58785 .18251 L .58722 .09446 L p F P
.294 .652 1 r
s
.865 .635 .402 r
.5608 .27783 m .5687 .1974 L .57838 .25705 L p F P
.623 .462 .287 r
s
.902 .66 .414 r
.57896 .07672 m .58785 .18251 L .57838 .25705 L p F P
.623 .462 .287 r
s
.902 .66 .414 r
.57838 .25705 m .5687 .1974 L .57896 .07672 L p F P
.623 .462 .287 r
s
.864 .636 .403 r
.526 .26816 m .55222 .18074 L .54749 .25568 L p F P
.623 .462 .287 r
s
.108 .5 .814 r
.57896 .07672 m .58722 .09446 L .58785 .18251 L closepath p F P
.294 .652 1 r
s
.858 .629 .399 r
.5687 .1974 m .54749 .25568 L .55222 .18074 L p F P
.623 .462 .287 r
s
.055 .258 .517 r
.5519 .0925 m .57896 .07672 L .55222 .18074 L closepath p F P
.294 .652 1 r
s
.858 .629 .399 r
.55222 .18074 m .57896 .07672 L .5687 .1974 L p F P
.623 .462 .287 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[326]:=",
  ImageSize->{450, 264.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400072000122000`400?l00000o`00003oo`2Id>G2
09W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo
003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80
VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool0
0?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2I
d>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00
o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@
i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o
09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U
0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0
VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@i@@0VM3U00<0WgI909W@i@2Id>D0^`2I
d>D10?ooo`00o`2Id>D209W@i@80BjKo00<0WgI909W@i@2Id>D0^`2Id>D10?ooo`00o`2Id>D204^V
o`0400i2Q02OMTT0WgI904^Vok`0VM3U0@3oool00?h0VM3U00@0BjKo00i2Q00>@X@03T:40P2OMTT0
0`1;Y_l0VM3U09W@i@2j09W@i@40oooo003l09W@i@80BjKo100>@X@209mfB@0301]od01;Y_l0VM3U
0;X0VM3U0@3oool00?X0VM3U0P1;Y_l600i2Q080WgI900<06go@04^Vo`2Id>D0^P2Id>D10?ooo`00
n02Id>D204^Vo`L03T:400<0WgI90=^QIP2OMTT00P0KOm000`1;Y_l0VM3U09W@i@2h09W@i@40oooo
003g09W@i@0304^Vo`0>@X@03T:400L03T:40P2OMTT0103VZ6T0BjKo01]od01;Y_nj09W@i@40oooo
003e09W@i@<0BjKo2@0>@X@209mfB@050>JXJ@1;Y_l06go@01]od01;Y_l0^@2Id>D10?ooo`00m02I
d>D0101;Y_l03T:400i2Q01;Y_l900i2Q080WgI900D0iZQY04^Vo`0KOm006go@04^Vo`2i09W@i@40
oooo002709W@i@0309mfB@1;Y_l0BjKo06P0VM3U0P1;Y_l300i2Q00304^Vo`0>@X@03T:400H03T:4
00D0WgI90=^QIP2OMTT0iZQY04^Vo`0201]od080BjKo^02Id>D10?ooo`00Q`2Id>D00`2OMTT07HO`
01f7l00504^Vof40VM3U0P1;Y_l500i2Q00304^Vo`0>@X@03T:400H03T:400D0WgI90=^QIP2OMTT0
iZQY04^Vo`0201]od080BjKo^02Id>D10?ooo`00Q`2Id>D209mfB@H07HO`1@1;Y_mK09W@i@0304^V
o`0>@X@03T:400D03T:400<0BjKo00i2Q00>@X@01P0>@X@01@2OMTT0fj5V09mfB@3VZ6T0BjKo0080
6go@00<0BjKo01]od01;Y_l0]`2Id>D10?ooo`00Q`2Id>D209mfB@/07HO`1@1;Y_mD09W@i@80BjKo
200>@X@00`1;Y_l03T:400i2Q00600i2Q00509mfB@3KXFH0WgI90>JXJ@1;Y_l00P0KOm000`1;Y_l0
6go@04^Vo`2g09W@i@40oooo002809W@i@80WgI93`0MQo0404^Vodl0VM3U00<0BjKo00i2Q00>@X@0
200>@X@00`1;Y_l03T:400i2Q00500i2Q00609mfB@3KXFH0fj5V09mfB@3VZ6T0BjKo0P0KOm00101;
Y_l06go@01]od01;Y_nf09W@i@40oooo002809W@i@80WgI94@0MQo000`1;Y_l07HO`04^Vo`0304^V
odT0VM3U0`1;Y_l:00i2Q00304^Vo`0>@X@03T:400D03T:400H0WgI90=^QIP3KXFH0WgI90>JXJ@1;
Y_l201]od00404^Vo`0KOm006go@04^VokH0VM3U0@3oool008P0VM3U0`2OMTT@01f7l00304^Vo`0M
Qo007HO`00<07HO`101;Y_m309W@i@80BjKo0P0>@X@00`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>
@X@03T:400D03T:400H0WgI90=^QIP3KXFH0WgI90>JXJ@1;Y_l201]od00504^Vo`0KOm006go@01]o
d01;Y_l0]@2Id>D10?ooo`00R02Id>D309mfBA007HO`00<0BjKo01f7l00MQo001`0MQo0404^Voch0
VM3U00<0BjKo00i2Q00>@X@00P0>@X@00`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400D0
3T:400H0WgI90=^QIP3KXFH0WgI90>JXJ@1;Y_l201]od00504^Vo`0KOm006go@01]od01;Y_l0]@2I
d>D10?ooo`00R02Id>D0102OMTT0^XUI09mfB@2OMTT?01f7l00304^Vo`0MQo007HO`00/07HO`101;
Y_lh09W@i@80BjKo1@0>@X@00`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400@03T:400L0
WgI90=^QIP3KXFH0fj5V09mfB@3VZ6T0BjKo00806go@00@0BjKo01]od00KOm006go@0P1;Y_nd09W@
i@40oooo002809W@i@0409mfB@2jRET0WgI909mfB@l07HO`00<0BjKo01f7l00MQo003`0MQo0504^V
oc40VM3U0P1;Y_l700i2Q00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@0100>@X@01@2O
MTT0fj5V0=^QIP3KXFH0WgI90080iZQY00<0BjKo01]od01;Y_l00`0KOm0204^Vok@0VM3U0@3oool0
08T0VM3U0P2OMTT00`38TUh0WgI901f7l00=01f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7
l00MQo001@1;Y_lZ09W@i@80BjKo2@0>@X@00`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:4
00@03T:400D0WgI90=^QIP3KXFH0fj5V09mfB@020>JXJ@0304^Vo`0KOm00BjKo00<06go@00<0BjKo
01]od01;Y_l0/`2Id>D10?ooo`00R@2Id>D209mfB@030<RBGP2OMTT07HO`00d07HO`00<0BjKo01f7
l00MQo004@0MQo000`1;Y_l07HO`01f7l00501f7l0D0BjKo902Id>D00`1;Y_l03T:400i2Q00900i2
Q00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@0100>@X@0102OMTT0fj5V0=^QIP2OMTT3
0>JXJ@0304^Vo`0KOm00BjKo00<06go@00<0BjKo01]od01;Y_l0/`2Id>D10?ooo`00R@2Id>D01@2O
MTT0^XUI09mfB@38TUh0WgI900d07HO`00<0BjKo01f7l00MQo004@0MQo000`1;Y_l07HO`01f7l00:
01f7l0D0BjKo7@2Id>D304^Vo`/03T:400<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q003
00i2Q00509mfB@3KXFH0fj5V0=^QIP2OMTT00`3VZ6T00`1;Y_l06go@04^Vo`0301]od00404^Vo`0K
Om006go@04^VoeH0VM3U1@1;Y_l00`2OMTT0VM3U09W@i@1D09W@i@40oooo002909W@i@0509mfB@2j
RET0WgI90<RBGP2OMTT03@0MQo000`1;Y_l07HO`01f7l00A01f7l00304^Vo`0MQo007HO`00l07HO`
1@1;Y_lF09W@i@80BjKo0P0>@X@00`1;Y_l03T:400i2Q00900i2Q00304^Vo`0>@X@03T:400P03T:4
00<0BjKo00i2Q00>@X@00`0>@X@01@2OMTT0fj5V0=^QIP3KXFH0WgI900<0iZQY00<0BjKo01]od01;
Y_l00`0KOm00101;Y_l06go@01]od01;Y_m:09W@i@`0BjKo100HL]4209mfBEH0VM3U0@3oool008T0
VM3U00<0WgI90;Z9F@2OMTT00P38TUh00`2OMTT07HO`01f7l00:01f7l00304^Vo`0MQo007HO`0140
7HO`00<0BjKo01f7l00MQo004@0MQo000`1;Y_l07HO`01f7l00404^Voa00VM3U0P1;Y_l400i2Q003
04^Vo`0>@X@03T:400T03T:400<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q00300i2Q005
09mfB@3KXFH0fj5V0=^QIP2OMTT00`3VZ6T00`1;Y_l06go@04^Vo`0301]od00404^Vo`0KOm006go@
04^Vocl0VM3U2`1;Y_l@01Qbd@0309mfB@2Id>D0VM3U05D0VM3U0@3oool008T0VM3U00H0WgI90;Z9
F@2jRET0WgI90<RBGP2OMTT<01f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7l00MQo004@0M
Qo000`1;Y_l07HO`01f7l00401f7l0D0BjKo2@2Id>D204^Vo`H03T:400<0BjKo00i2Q00>@X@02@0>
@X@00`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400<03T:400D0WgI90=^QIP3KXFH0fj5V
09mfB@030>JXJ@0304^Vo`0KOm00BjKo00<06go@00<0BjKo01]od00KOm000P1;Y_lc09W@i@/0BjKo
1@0HL]400`1;Y_l067;A01Qbd@0B01Qbd@80WgI9E`2Id>D10?ooo`00R@2Id>D01P2OMTT0^XUI0;Z9
F@2OMTT0b99N09mfB@`07HO`00<0BjKo01f7l00MQo004@0MQo000`1;Y_l07HO`01f7l00A01f7l003
04^Vo`0MQo007HO`00T07HO`101;Y_l309W@i@80BjKo200>@X@00`1;Y_l03T:400i2Q00900i2Q003
04^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@00P0>@X@00`2OMTT0fj5V0=^QIP020=^QIP07
09mfB@3VZ6T0iZQY0>JXJ@1;Y_l06go@04^Vo`0301]od00304^Vo`0KOm006go@0080BjKo:02Id>D;
04^Voa0067;A00<0BjKo01Qbd@0HL]404P0HL]4209mfBEL0VM3U0@3oool008X0VM3U00<0WgI90;Z9
F@2OMTT00P38TUh00`2OMTT07HO`01f7l00901f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7
l00MQo004@0MQo000`1;Y_l07HO`01f7l00=01f7l0<0BjKo2P0>@X@00`1;Y_l03T:400i2Q00900i2
Q00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@00P0>@X@00`2OMTT0fj5V0=^QIP020=^Q
IP0709mfB@3VZ6T0iZQY0>JXJ@1;Y_l06go@04^Vo`0301]od00604^Vo`0KOm006go@04^Vo`0KOm00
BjKo702Id>D;04^Vo`D067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0A01Qbd@80
WgI9F02Id>D10?ooo`00RP2Id>D01P2OMTT0^XUI0;Z9F@2OMTT0b99N09mfB@/07HO`00<0BjKo01f7
l00MQo004@0MQo000`1;Y_l07HO`01f7l00A01f7l00304^Vo`0MQo007HO`00l07HO`00<0BjKo00i2
Q00>@X@0200>@X@00`1;Y_l03T:400i2Q00900i2Q00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2
Q00>@X@00P0>@X@00`2OMTT0fj5V0=^QIP020=^QIP0709mfB@3VZ6T0iZQY0>JXJ@1;Y_l06go@04^V
o`0301]od00604^Vo`0KOm006go@04^Vo`0KOm00BjKo4@2Id>D;04^Voa0067;A00<0BjKo01Qbd@0H
L]404`0HL]400`1;Y_l067;A01Qbd@0A01Qbd@80WgI9F02Id>D10?ooo`00RP2Id>D0102OMTT0^XUI
0;Z9F@2OMTT20<RBGP0309mfB@0MQo007HO`00P07HO`00<0BjKo01f7l00MQo004@0MQo000`1;Y_l0
7HO`01f7l00A01f7l00304^Vo`0MQo007HO`00l07HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l0
3T:400i2Q00900i2Q00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@00P0>@X@00`2OMTT0
fj5V0=^QIP020=^QIP0709mfB@3VZ6T0iZQY0>JXJ@1;Y_l06go@04^Vo`0301]od00404^Vo`0KOm00
6go@04^Vo`806go@00<0BjKo09W@i@2Id>D00`2Id>D;04^Vo`D067;A00<0BjKo01Qbd@0HL]404`0H
L]400`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A010067;A0`2OMTUH09W@i@40oooo002:
09W@i@0409mfB@2jRET0^XUI09mfB@80b99N00<0WgI901f7l00MQo00200MQo000`1;Y_l07HO`01f7
l00A01f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7l00MQo003`0MQo000`1;Y_l03T:400i2
Q00800i2Q00304^Vo`0>@X@03T:400T03T:400<0BjKo00i2Q00>@X@0200>@X@01@1;Y_l03T:400i2
Q00>@X@0WgI900D0fj5V00L0WgI90>JXJ@3VZ6T0iZQY04^Vo`0KOm00BjKo00<06go@00@0BjKo01]o
d00KOm00BjKo0P0KOm0604^Voa0067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0C
01Qbd@0304^Vo`0HL]4067;A010067;A0P2OMTUI09W@i@40oooo002:09W@i@0509mfB@2jRET0^XUI
0;Z9F@2OMTT00P38TUh00`2OMTT07HO`01f7l00701f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo
01f7l00MQo004@0MQo000`1;Y_l07HO`01f7l00?01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo
00i2Q00>@X@02@0>@X@00`1;Y_l03T:400i2Q00800i2Q00504^Vo`0>@X@03T:400i2Q02OMTT01@3K
XFH00`2OMTT0iZQY0>JXJ@020>JXJ@80BjKo0`0KOm00101;Y_l06go@01]od01;Y_l201]od00304^V
o`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0C01Qbd@0304^V
o`0HL]4067;A00l067;A0`2OMTUI09W@i@40oooo002:09W@i@0509mfB@2jRET0^XUI0;Z9F@2OMTT0
0P38TUh00`2OMTT07HO`01f7l00701f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7l00MQo00
4@0MQo000`1;Y_l07HO`01f7l00?01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@0
2@0>@X@00`1;Y_l03T:400i2Q00800i2Q00504^Vo`0>@X@03T:400i2Q02OMTT01@3KXFH00`2OMTT0
iZQY0>JXJ@020>JXJ@80BjKo0`0KOm00101;Y_l06go@01]od01;Y_l201]od00304^Vo`0HL]4067;A
01<067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A
00h067;A00@0WgI90?fjL`2OMTT0WgI9F@2Id>D10?ooo`00RP2Id>D01@2OMTT0^XUI0;Z9F@2jRET0
WgI900<0b99N00<0WgI901f7l00MQo001P0MQo000`1;Y_l07HO`01f7l00A01f7l00304^Vo`0MQo00
7HO`01407HO`00<0BjKo01f7l00MQo003`0MQo000`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@0
3T:400T03T:400<0BjKo00i2Q00>@X@0200>@X@01@1;Y_l03T:400i2Q00>@X@0WgI900D0fj5V00<0
WgI90>JXJ@3VZ6T00P3VZ6T204^Vo`<06go@00@0BjKo01]od00KOm00BjKo0P0KOm000`1;Y_l067;A
01Qbd@0C01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A
01Qbd@0>01Qbd@<0WgI9FP2Id>D10?ooo`00R`2Id>D01@2OMTT0^XUI0;Z9F@2jRET0WgI90080b99N
00<0WgI901f7l00MQo001P0MQo000`1;Y_l07HO`01f7l00A01f7l00304^Vo`0MQo007HO`01407HO`
00<0BjKo01f7l00MQo003`0MQo000`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400T03T:4
00<0BjKo00i2Q00>@X@0200>@X@0101;Y_l03T:400i2Q02OMTT50=^QIP0309mfB@3VZ6T0iZQY00<0
iZQY0P1;Y_l301]od00404^Vo`0KOm006go@04^Vo`806go@00<0BjKo01Qbd@0HL]404`0HL]400`1;
Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]403@0HL]40102O
MTT0oKYc09mfB@2OMTUJ09W@i@40oooo002;09W@i@0509mfB@2jRET0^XUI0;Z9F@2OMTT00`38TUh0
0`2OMTT07HO`01f7l00501f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7l00MQo004@0MQo00
0`1;Y_l07HO`01f7l00?01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@02@0>@X@0
0`1;Y_l03T:400i2Q00800i2Q00404^Vo`0>@X@03T:409mfB@D0fj5V00<0WgI90>JXJ@3VZ6T00`3V
Z6T204^Vo`<06go@00@0BjKo01]od00KOm00BjKo0P0KOm000`1;Y_l067;A01Qbd@0C01Qbd@0304^V
o`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0=01Qbd@80WgI9
00<0ol=f09mfB@2Id>D0F@2Id>D10?ooo`00R`2Id>D01@2OMTT0^XUI0;Z9F@2jRET0WgI900<0b99N
00<0WgI901f7l00MQo001@0MQo000`1;Y_l07HO`01f7l00A01f7l00304^Vo`0MQo007HO`01407HO`
00<0BjKo01f7l00MQo003`0MQo000`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400T03T:4
00<0BjKo00i2Q00>@X@0200>@X@0101;Y_l03T:400i2Q02OMTT50=^QIP0309mfB@3VZ6T0iZQY00<0
iZQY0P1;Y_l301]od00404^Vo`0KOm006go@04^Vo`806go@00<0BjKo01Qbd@0HL]404`0HL]400`1;
Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]40300HL]401@2O
MTT0oKYc09mfB@3o`gH0WgI905X0VM3U0@3oool008/0VM3U00D0WgI90;Z9F@2jRET0^XUI09mfB@04
0<RBGP0309mfB@0MQo007HO`00@07HO`00<0BjKo01f7l00MQo004@0MQo000`1;Y_l07HO`01f7l00A
01f7l00304^Vo`0MQo007HO`00l07HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q009
00i2Q00304^Vo`0>@X@03T:400P03T:400@0BjKo00i2Q00>@X@0WgI91@3KXFH00`2OMTT0iZQY0>JX
J@030>JXJ@80BjKo0`0KOm00101;Y_l06go@01]od01;Y_l201]od00304^Vo`0HL]4067;A01<067;A
00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A00`067;A
0P2OMTT00`3o`gH0WgI909W@i@1J09W@i@40oooo002;09W@i@0309mfB@2jRET0^XUI0080^XUI00D0
WgI90<RBGP38TUh0b99N09mfB@0601f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7l00MQo00
4@0MQo000`1;Y_l07HO`01f7l00?01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@0
2@0>@X@00`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@0WgI900H0fj5V00<0WgI90>JXJ@3VZ6T0
0`3VZ6T204^Vo`<06go@00@0BjKo01]od00KOm00BjKo0P0KOm000`1;Y_l067;A01Qbd@0C01Qbd@03
04^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0;01Qbd@05
09mfB@3m^W<0WgI90?o3MP2OMTT0F`2Id>D10?ooo`00Q`2Id>D404^Vo`0309mfB@2jRET0^XUI0080
^XUI00D0WgI90<RBGP38TUh0b99N09mfB@0601f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7
l00MQo004@0MQo000`1;Y_l07HO`01f7l00?01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2
Q00>@X@02@0>@X@00`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@0WgI900H0fj5V00<0WgI90>JX
J@3VZ6T00`3VZ6T204^Vo`<06go@00@0BjKo01]od00KOm00BjKo0P0KOm000`1;Y_l067;A01Qbd@0C
01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0;
01Qbd@0509mfB@3m^W<0WgI90?o3MP2OMTT0F`2Id>D10?ooo`00LP2Id>DE04^Vo`D06GCE00D0WgI9
0;Z9F@2jRET0^XUI09mfB@040<RBGP0309mfB@0MQo007HO`00<07HO`00<0BjKo01f7l00MQo004@0M
Qo000`1;Y_l07HO`01f7l00A01f7l00304^Vo`0MQo007HO`00l07HO`00<0BjKo00i2Q00>@X@0200>
@X@00`1;Y_l03T:400i2Q00900i2Q00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q02OMTT01P3K
XFH00`2OMTT0iZQY0>JXJ@030>JXJ@80BjKo0`0KOm00101;Y_l06go@01]od01;Y_l201]od00304^V
o`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0C01Qbd@0304^V
o`0HL]4067;A00X067;A00D0WgI90?fjL`2OMTT0ol=f09mfB@1L09W@i@40oooo001R09W@iA00BjKo
2P0IM=D00`1;Y_l06GCE01Ude@0=01Ude@0309mfB@2jRET0^XUI0080^XUI00D0WgI90<RBGP38TUh0
b99N09mfB@0501f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7l00MQo004@0MQo000`1;Y_l0
7HO`01f7l00?01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@02@0>@X@00`1;Y_l0
3T:400i2Q00800i2Q00304^Vo`0>@X@0WgI900H0fj5V00<0WgI90>JXJ@3VZ6T00`3VZ6T204^Vo`<0
6go@00@0BjKo01]od00KOm00BjKo0P0KOm000`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A
01<067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0:01Qbd@0509mfB@3m^W<0WgI9
0?o3MP2OMTT0G02Id>D10?ooo`00F02Id>D:04^Vo`D06GCE00<0BjKo01Ude@0IM=D04P0IM=D00`1;
Y_l06GCE01Ude@0=01Ude@0309mfB@2jRET0^XUI0080^XUI00<0WgI90<RBGP38TUh00P38TUh00`2O
MTT07HO`01f7l00201f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7l00MQo004@0MQo000`1;
Y_l07HO`01f7l00?01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@02@0>@X@00`1;
Y_l03T:400i2Q00800i2Q00304^Vo`2OMTT0fj5V00H0fj5V00<0WgI90>JXJ@3VZ6T00`3VZ6T204^V
o`<06go@00@0BjKo01]od00KOm00BjKo0P0KOm000`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]40
67;A01<067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0901Qbd@0309mfB@3m^W<0
WgI90080ol=f00<0WgI909W@i@2Id>D0FP2Id>D10?ooo`00DP2Id>D604^Vo`l06GCE00<0BjKo01Ud
e@0IM=D04P0IM=D00`1;Y_l06GCE01Ude@0=01Ude@0309mfB@2jRET0^XUI0080^XUI00<0WgI90<RB
GP38TUh00P38TUh00`2OMTT07HO`01f7l00201f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7
l00MQo004@0MQo000`1;Y_l07HO`01f7l00?01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2
Q00>@X@02@0>@X@00`1;Y_l03T:400i2Q00800i2Q00304^Vo`2OMTT0fj5V00H0fj5V00<0WgI90>JX
J@3VZ6T0103VZ6T01@1;Y_l06go@01]od00KOm00BjKo00806go@00@0BjKo01]od00KOm00BjKo5@0H
L]400`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]40200H
L]401P2OMTT0oKYc0?fjL`2OMTT0ol=f09mfBEd0VM3U0@3oool00580VM3U00<0WgI904^Vo`0IM=D0
4P0IM=D00`1;Y_l06GCE01Ude@0B01Ude@0304^Vo`0IM=D06GCE00d06GCE00<0WgI90;Z9F@2jRET0
0`2jRET00`2OMTT0b99N0<RBGP020<RBGP0509mfB@0MQo007HO`01f7l01;Y_l04`0MQo000`1;Y_l0
7HO`01f7l00A01f7l00304^Vo`0MQo007HO`00l07HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l0
3T:400i2Q00900i2Q00304^Vo`0>@X@03T:400P03T:400<0BjKo09mfB@3KXFH01P3KXFH00`2OMTT0
iZQY0>JXJ@040>JXJ@0504^Vo`0KOm006go@01]od01;Y_l00P0KOm00101;Y_l06go@01]od01;Y_lE
01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]40500HL]400`1;Y_l067;A01Qbd@07
01Qbd@0309mfB@3m^W<0WgI90080ol=f00<0WgI909W@i@2Id>D0F`2Id>D10?ooo`00D`2Id>D00`1;
Y_l06GCE01Ude@0A01Ude@0304^Vo`0IM=D06GCE01806GCE00<0BjKo01Ude@0IM=D03@0IM=D00`2O
MTT0^XUI0;Z9F@030;Z9F@0309mfB@38TUh0b99N0080b99N00D0WgI901f7l00MQo007HO`04^Vo`0C
01f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7l00MQo003`0MQo000`1;Y_l03T:400i2Q008
00i2Q00304^Vo`0>@X@03T:400T03T:400<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l0WgI90=^QIP06
0=^QIP0309mfB@3VZ6T0iZQY00@0iZQY00D0BjKo01]od00KOm006go@04^Vo`0201]od00404^Vo`0K
Om006go@04^VoaD067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0D01Qbd@0304^V
o`0HL]4067;A00H067;A00@0WgI90?fjL`3m^W<0WgI90P3o`gH00`2OMTT0VM3U09W@i@1K09W@i@40
oooo001C09W@i@0309mfB@1;Y_l06GCE01406GCE00<0BjKo01Ude@0IM=D04P0IM=D00`1;Y_l06GCE
01Ude@0=01Ude@0309mfB@2jRET0^XUI00<0^XUI00<0WgI90<RBGP38TUh00`38TUh0102OMTT07HO`
01f7l01;Y_lC01f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7l00MQo003`0MQo000`1;Y_l0
3T:400i2Q00800i2Q00304^Vo`0>@X@03T:400T03T:400<0BjKo00i2Q00>@X@0200>@X@00`2OMTT0
fj5V0=^QIP060=^QIP0309mfB@3VZ6T0iZQY00@0iZQY00D0BjKo01]od00KOm006go@04^Vo`0201]o
d00404^Vo`0KOm006go@04^VoaD067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0D
01Qbd@0304^Vo`0HL]4067;A00H067;A00<0WgI90?fjL`2OMTT00P3o`gH00`2OMTT0VM3U09W@i@1L
09W@i@40oooo001D09W@i@0304^Vo`0IM=D06GCE01006GCE00<0BjKo01Ude@0IM=D04P0IM=D00`1;
Y_l06GCE01Ude@0>01Ude@0309mfB@2jRET0^XUI00<0^XUI00<0WgI90<RBGP38TUh00P38TUh0102O
MTT07HO`01f7l01;Y_lC01f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7l00MQo003`0MQo00
0`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400T03T:400<0BjKo00i2Q00>@X@0200>@X@0
0`2OMTT0fj5V0=^QIP060=^QIP0309mfB@3VZ6T0iZQY00@0iZQY00D0BjKo01]od00KOm006go@04^V
o`0201]od00404^Vo`0KOm006go@04^VoaD067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A
01Qbd@0D01Qbd@0304^Vo`0HL]4067;A00D067;A00@0WgI90?fjL`3m^W<0WgI90P3o`gH00`2OMTT0
VM3U09W@i@1L09W@i@40oooo001D09W@i@0309mfB@1;Y_l06GCE01006GCE00<0BjKo01Ude@0IM=D0
4P0IM=D00`1;Y_l06GCE01Ude@0>01Ude@0309mfB@2jRET0^XUI00<0^XUI00<0WgI90<RBGP38TUh0
0`38TUh00`2OMTT07HO`04^Vo`0C01f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7l00MQo00
3`0MQo000`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400T03T:400<0BjKo00i2Q00>@X@0
200>@X@00`2OMTT0fj5V0=^QIP050=^QIP0309mfB@3VZ6T0iZQY00D0iZQY00D0BjKo01]od00KOm00
6go@04^Vo`0201]od00404^Vo`0KOm006go@04^VoaD067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;
Y_l067;A01Qbd@0D01Qbd@0304^Vo`0HL]4067;A00D067;A00@0WgI90?fjL`3m^W<0WgI90P3o`gH0
0`2OMTT0VM3U09W@i@1L09W@i@40oooo001E09W@i@0304^Vo`0IM=D06GCE00l06GCE00<0BjKo01Ud
e@0IM=D04P0IM=D00`1;Y_l06GCE01Ude@0>01Ude@0309mfB@2jRET0^XUI00<0^XUI00<0WgI90<RB
GP38TUh00`38TUh00`2OMTT07HO`04^Vo`0C01f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7
l00MQo003`0MQo000`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400T03T:400<0BjKo00i2
Q00>@X@01`0>@X@209mfB@L0fj5V00<0WgI90>JXJ@3VZ6T01@3VZ6T01@2OMTT06go@01]od00KOm00
BjKo00806go@00@0BjKo01]od00KOm00BjKo5@0HL]400`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0H
L]4067;A01@067;A00<0BjKo01Qbd@0HL]40100HL]40102OMTT0oKYc0?fjL`2OMTT20?o3MP0309mf
B@2Id>D0VM3U05d0VM3U0@3oool005D0VM3U00<0WgI904^Vo`0IM=D03`0IM=D00`1;Y_l06GCE01Ud
e@0B01Ude@0304^Vo`0IM=D06GCE00h06GCE00<0WgI90;Z9F@2jRET0102jRET00`2OMTT0b99N0<RB
GP030<RBGP0309mfB@1;Y_l07HO`01807HO`00<0BjKo01f7l00MQo004@0MQo000`1;Y_l07HO`01f7
l00?01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@02@0>@X@00`1;Y_l03T:400i2
Q00700i2Q080WgI91`3KXFH00`2OMTT0iZQY0>JXJ@050>JXJ@0509mfB@0KOm006go@01]od01;Y_l0
0P0KOm00101;Y_l06go@01]od01;Y_lE01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0H
L]40500HL]400`1;Y_l067;A01Qbd@0401Qbd@0409mfB@3m^W<0oKYc09mfB@80ol=f00<0WgI909W@
i@2Id>D0G@2Id>D10?ooo`00EP2Id>D00`2OMTT0BjKo01Ude@0>01Ude@0304^Vo`0IM=D06GCE0180
6GCE00<0BjKo01Ude@0IM=D03P0IM=D00`2OMTT0^XUI0;Z9F@040;Z9F@0309mfB@38TUh0b99N00<0
b99N00<0WgI904^Vo`0MQo004P0MQo000`1;Y_l07HO`01f7l00A01f7l00304^Vo`0MQo007HO`00l0
7HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q00900i2Q00304^Vo`0>@X@03T:400L0
3T:40P2OMTT70=^QIP0309mfB@3VZ6T0iZQY00D0iZQY00D0WgI901]od00KOm006go@04^Vo`0201]o
d00404^Vo`0KOm006go@04^VoaD067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0D
01Qbd@0304^Vo`0HL]4067;A00<067;A00@0WgI90?fjL`3m^W<0WgI90`3o`gH00`2OMTT0VM3U09W@
i@1M09W@i@40oooo001F09W@i@0309mfB@1;Y_l06GCE00h06GCE00<0BjKo01Ude@0IM=D04P0IM=D0
0`1;Y_l06GCE01Ude@0>01Ude@0309mfB@2jRET0^XUI00@0^XUI00<0WgI90<RBGP38TUh01038TUh0
0`2OMTT07HO`01f7l00A01f7l00304^Vo`0MQo007HO`01407HO`00<0BjKo01f7l00MQo003`0MQo00
0`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400T03T:400<0BjKo00i2Q00>@X@01`0>@X@2
09mfB@L0fj5V00<0WgI90>JXJ@3VZ6T01@3VZ6T01@2OMTT06go@01]od00KOm00BjKo00806go@00@0
BjKo01]od00KOm00BjKo5@0HL]400`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A01@067;A
00<0BjKo01Qbd@0HL]400P0HL]401@2OMTT0oKYc0?fjL`3m^W<0WgI90080ol=f00<0WgI909W@i@2I
d>D0GP2Id>D10?ooo`00E`2Id>D00`2OMTT0BjKo01Ude@0=01Ude@0304^Vo`0IM=D06GCE01806GCE
00<0BjKo01Ude@0IM=D03`0IM=D00`2OMTT0^XUI0;Z9F@030;Z9F@0309mfB@38TUh0b99N00@0b99N
00<0WgI901f7l00MQo004@0MQo000`1;Y_l07HO`01f7l00A01f7l00304^Vo`0MQo007HO`00l07HO`
00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q00900i2Q00304^Vo`0>@X@03T:400H03T:4
00<0WgI90=fRI`2OMTT01`3KXFH00`2OMTT0iZQY0>JXJ@040>JXJ@0309mfB@3/[F`0BjKo00806go@
00@0BjKo01]od00KOm00BjKo0P0KOm000`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A01<0
67;A00<0BjKo01Qbd@0HL]40500HL]400`1;Y_l067;A01Qbd@0201Qbd@0409mfB@3m^W<0oKYc09mf
B@<0ol=f00<0WgI904^Vo`1;Y_l0GP2Id>D10?ooo`00E`2Id>D00`2OMTT0BjKo01Ude@0=01Ude@03
04^Vo`0IM=D06GCE01806GCE00<0BjKo01Ude@0IM=D03`0IM=D00`2OMTT0^XUI0;Z9F@040;Z9F@03
09mfB@38TUh0b99N00<0b99N00<0WgI904^Vo`0MQo004@0MQo000`1;Y_l07HO`01f7l00A01f7l003
04^Vo`0MQo007HO`00l07HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q00900i2Q003
04^Vo`0>@X@03T:400H03T:400<0WgI90=fRI`2OMTT01`3KXFH00`2OMTT0iZQY0>JXJ@040>JXJ@03
09mfB@3/[F`0BjKo00806go@00@0BjKo01]od00KOm00BjKo0P0KOm000`1;Y_l067;A01Qbd@0C01Qb
d@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]40500HL]401@1;Y_l067;A01Qbd@0HL]40
WgI900<0oKYc00D0WgI90?o3MP3o`gH0ol=f09mfB@0201b5k@D0BjKoF@2Id>D10?ooo`00F02Id>D0
0`2OMTT0BjKo01Ude@0<01Ude@0304^Vo`0IM=D06GCE01806GCE00<0BjKo01Ude@0IM=D03`0IM=D0
0`2OMTT0^XUI0;Z9F@040;Z9F@0309mfB@38TUh0b99N00@0b99N00<0WgI901f7l00MQo003`0MQo00
0`1;Y_l07HO`01f7l00B01f7l00304^Vo`0MQo007HO`00l07HO`00<0BjKo00i2Q00>@X@0200>@X@0
0`1;Y_l03T:400i2Q00900i2Q00304^Vo`0>@X@03T:400H03T:400<0WgI90=fRI`2OMTT01`3KXFH0
0`2OMTT0iZQY0>JXJ@040>JXJ@0309mfB@3/[F`0BjKo00806go@00@0BjKo01]od00KOm00BjKo0P0K
Om000`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]40500H
L]401@1;Y_l067;A01Qbd@0HL]40WgI900<0oKYc00@0WgI90?o3MP3o`gH0WgI91@0LQNd00`1;Y_l0
78G]01b5k@0604^Voe<0VM3U0@3oool005P0VM3U00<0WgI904^Vo`0IM=D0300IM=D00`1;Y_l06GCE
01Ude@0B01Ude@0304^Vo`0IM=D06GCE00l06GCE00<0WgI90;Z9F@2jRET0102jRET00`2OMTT0b99N
0<RBGP040<RBGP0309mfB@1;Y_l07HO`00l07HO`00<0BjKo01f7l00MQo004P0MQo000`1;Y_l07HO`
01f7l00?01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@02@0>@X@00`1;Y_l03T:4
00i2Q00500i2Q00309mfB@3MXVL0WgI900L0fj5V0P2OMTT60>JXJ@0309mfB@3/[F`0BjKo00806go@
00@0BjKo01]od00KOm00BjKo0P0KOm000`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A01<0
67;A00<0BjKo01Qbd@0HL]40500HL]40101;Y_l067;A01Qbd@2OMTT30?fjL`0509mfB@3o`gH0ol=f
0?o3MP2OMTT01@0LQNd00`1;Y_l078G]01b5k@0601b5k@H0BjKoC@2Id>D10?ooo`00F@2Id>D00`2O
MTT0BjKo01Ude@0;01Ude@0304^Vo`0IM=D06GCE01406GCE00<0BjKo01Ude@0IM=D0400IM=D00`2O
MTT0^XUI0;Z9F@050;Z9F@0309mfB@38TUh0b99N00<0b99N00<0WgI904^Vo`0MQo003`0MQo000`1;
Y_l07HO`01f7l00B01f7l00304^Vo`0MQo007HO`00l07HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;
Y_l03T:400i2Q00900i2Q00304^Vo`0>@X@03T:400D03T:400<0WgI90=fRI`2OMTT01`3KXFH209mf
B@H0iZQY00<0WgI90>b]K01;Y_l00P0KOm00101;Y_l06go@01]od01;Y_l201]od00304^Vo`0HL]40
67;A01<067;A00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0D01Qbd@0404^Vo`0HL]40
67;A09mfB@<0oKYc00D0WgI90?o3MP3o`gH0ol=f09mfB@0501b5k@0304^Vo`0LQNd078G]00`078G]
0`1;Y_m:09W@i@40oooo001I09W@i@80WgI900<0BjKo01Ude@0IM=D02@0IM=D00`1;Y_l06GCE01Ud
e@0A01Ude@0304^Vo`0IM=D06GCE01006GCE0P2OMTT60;Z9F@0309mfB@38TUh0b99N00@0b99N00<0
WgI904^Vo`0MQo003P0MQo000`1;Y_l07HO`01f7l00B01f7l00304^Vo`0MQo007HO`00l07HO`00<0
BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q00900i2Q00304^Vo`0>@X@03T:400D03T:400<0
WgI90=fRI`2OMTT01P3KXFH0102OMTT0ijUZ09mfB@2OMTT50>JXJ@0309mfB@3/[F`0BjKo00806go@
00@0BjKo01]od00KOm00BjKo0P0KOm000`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A01<0
67;A00<0BjKo01Qbd@0HL]40500HL]400`1;Y_l067;A09mfB@030?fjL`0309mfB@3o`gH0ol=f0080
ol=f00<0WgI901b5k@0LQNd00`0LQNd00`1;Y_l078G]01b5k@0=01b5k@0304^Vo`2Id>D0VM3U04T0
VM3U0@3oool005X0VM3U00<0WgI904^Vo`0IM=D02P0IM=D00`1;Y_l06GCE01Ude@0A01Ude@0304^V
o`0IM=D06GCE01406GCE00<0WgI90;Z9F@2jRET0102jRET00`2OMTT0b99N0<RBGP040<RBGP0309mf
B@1;Y_l07HO`00h07HO`00<0BjKo01f7l00MQo004P0MQo000`1;Y_l07HO`01f7l00?01f7l00304^V
o`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@02@0>@X@00`1;Y_l03T:400i2Q00500i2Q00309mf
B@3MXVL0WgI900H0fj5V0P2OMTT00`3MXVH0WgI90>JXJ@040>JXJ@0309mfB@3/[F`0BjKo00806go@
00@0BjKo01]od00KOm00BjKo0P0KOm000`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A01<0
67;A00<0BjKo01Qbd@0HL]40500HL]400`1;Y_l067;A09mfB@030?fjL`0509mfB@3o`gH0ol=f0?o3
MP2OMTT01P0LQNd00`1;Y_l078G]01b5k@0=01b5k@0304^Vo`2Id>D0VM3U04T0VM3U0@3oool005X0
VM3U0P2OMTT00`1;Y_l06GCE01Ude@0701Ude@0304^Vo`0IM=D06GCE01806GCE00<0BjKo01Ude@0I
M=D04@0IM=D00`2OMTT0^XUI0;Z9F@050;Z9F@0309mfB@38TUh0b99N00<0b99N00<0WgI90<jGH@1;
Y_l03P0MQo000`1;Y_l07HO`01f7l00B01f7l00304^Vo`0MQo007HO`00l07HO`00<0BjKo00i2Q00>
@X@0200>@X@00`1;Y_l03T:400i2Q00900i2Q00304^Vo`0>@X@03T:400@03T:400@0WgI90=fRI`3M
XVL0WgI91P3KXFH209mfB@030=fRIP2OMTT0iZQY00@0iZQY00<0WgI90>b]K01;Y_l00P0KOm00101;
Y_l06go@01]od01;Y_l201]od00304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]404`0HL]40
0`1;Y_l067;A01Qbd@0D01Qbd@0304^Vo`2OMTT0oKYc0080oKYc00<0WgI90?o3MP3o`gH00P3o`gH0
0`2OMTT078G]01b5k@0401b5k@0304^Vo`0LQNd078G]00`078G]00<0BjKo09W@i@2Id>D0BP2Id>D1
0?ooo`00F`2Id>D00`2OMTT0BjKo01Ude@0801Ude@0304^Vo`0IM=D06GCE01806GCE00<0BjKo01Ud
e@0IM=D04@0IM=D209mfB@H0^XUI00<0WgI90<RBGP38TUh00`38TUh00`2OMTT0cYMQ04^Vo`0>01f7
l00304^Vo`0MQo007HO`01807HO`00<0BjKo01f7l00MQo003`0MQo000`1;Y_l03T:400i2Q00800i2
Q00304^Vo`0>@X@03T:400T03T:400<0BjKo00i2Q00>@X@0100>@X@0102OMTT0gJ9W0=fRI`2OMTT5
0=^QIP0509mfB@3WZFX0WgI90=fRIP2OMTT0103VZ6T0102OMTT0k:e/0>b]K01;Y_l201]od00404^V
o`0KOm006go@04^Vo`806go@00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0C01Qbd@03
04^Vo`0HL]4067;A01@067;A00<0BjKo09mfB@3m^W<00P3m^W<00`2OMTT0ol=f0?o3MP020?o3MP03
09mfB@0LQNd078G]00@078G]00<0BjKo01b5k@0LQNd0300LQNd00`1;Y_l0VM3U09W@i@1:09W@i@40
oooo001K09W@i@80WgI900<0BjKo01Ude@0IM=D01P0IM=D00`1;Y_l06GCE01Ude@0B01Ude@0304^V
o`0IM=D06GCE01406GCE0P2OMTT60;Z9F@80WgI91@38TUh00`2OMTT0cYMQ04^Vo`0=01f7l00304^V
o`0MQo007HO`01807HO`00<0BjKo01f7l00MQo003`0MQo000`1;Y_l03T:400i2Q00800i2Q00304^V
o`0>@X@03T:400T03T:400<0BjKo00i2Q00>@X@0100>@X@0102OMTT0gJ9W0=fRI`2OMTT50=^QIP05
09mfB@3WZFX0WgI90=fRIP2OMTT0103VZ6T0102OMTT0k:e/0>b]K01;Y_l201]od00404^Vo`0KOm00
6go@04^Vo`806go@00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0D01Qbd@0304^Vo`0H
L]4067;A01<067;A00D0WgI90?fjL`3m^W<0oKYc09mfB@040?o3MP0309mfB@0LQNd078G]00D078G]
00<0BjKo01b5k@0LQNd02`0LQNd00`1;Y_l0VM3U09W@i@1;09W@i@40oooo001L09W@i@0309mfB@1;
Y_l06GCE00L06GCE00<0BjKo01Ude@0IM=D04P0IM=D00`1;Y_l06GCE01Ude@0A01Ude@0309mfB@2l
S5/0WgI900D0^XUI0P2OMTT50<RBGP0309mfB@3>Uf40BjKo00d07HO`00<0BjKo01f7l00MQo004P0M
Qo000`1;Y_l07HO`01f7l00?01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@02@0>
@X@00`1;Y_l03T:400i2Q00300i2Q00509mfB@3MXVL0gJ9W0=fRI`2OMTT01@3KXFH01@2OMTT0ijUZ
09mfB@3MXVH0WgI900@0iZQY00L0WgI90>b]K03/[F`0k:e/04^Vo`0KOm00BjKo00806go@00@0BjKo
01]od00KOm00BjKo5@0HL]400`1;Y_l067;A01Qbd@0D01Qbd@0304^Vo`0HL]4067;A018067;A0P2O
MTT30?fjL`0309mfB@3o`gH0ol=f0080ol=f00<0WgI901b5k@0LQNd01@0LQNd00`1;Y_l078G]01b5
k@0;01b5k@0304^Vo`2Id>D0VM3U04/0VM3U0@3oool005`0VM3U0P2OMTT00`1;Y_l06GCE01Ude@05
01Ude@0304^Vo`0IM=D06GCE01806GCE00<0BjKo01Ude@0IM=D04P0IM=D209mfB@D0^XUI0`2OMTT4
0<RBGP0409mfB@3>Uf40cYMQ04^Vo``07HO`00<0BjKo01f7l00MQo004P0MQo000`1;Y_l07HO`01f7
l00?01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@02@0>@X@00`1;Y_l03T:400i2
Q00300i2Q00509mfB@3MXVL0gJ9W0=fRI`2OMTT0103KXFH01P2OMTT0ijUZ0>NYJP2OMTT0gJ9V09mf
B@@0iZQY00L0WgI90>b]K03/[F`0k:e/04^Vo`0KOm00BjKo00806go@00@0BjKo01]od00KOm00BjKo
5@0HL]400`1;Y_l067;A01Qbd@0D01Qbd@0304^Vo`0HL]4067;A018067;A00<0WgI90?fjL`3m^W<0
0P3m^W<00`2OMTT0ol=f0?o3MP020?o3MP0309mfB@0LQNd078G]00D078G]00<0BjKo01b5k@0LQNd0
2P0LQNd00`1;Y_l0VM3U09W@i@1<09W@i@40oooo001M09W@i@80WgI900<0BjKo01Ude@0IM=D0100I
M=D00`1;Y_l06GCE01Ude@0B01Ude@0304^Vo`0IM=D06GCE01806GCE0P2OMTT50;Z9F@<0WgI91@38
TUh00`2OMTT0cYMQ04^Vo`0<01f7l00304^Vo`0MQo007HO`01807HO`00<0BjKo01f7l00MQo003`0M
Qo000`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400T03T:400<0BjKo00i2Q00>@X@00`0>
@X@01@2OMTT0gJ9W0=fRI`3MXVL0WgI900@0fj5V00@0WgI90>NYJP3WZFX0WgI90P3MXVH01@2OMTT0
iZQY0>JXJ@3VZ6T0WgI900<0k:e/00<0BjKo01]od01;Y_l00P0KOm00101;Y_l06go@01]od01;Y_lE
01Qbd@0304^Vo`0HL]4067;A01@067;A00<0BjKo01Qbd@0HL]404@0HL]4209mfB@<0oKYc00<0WgI9
0?o3MP3o`gH00P3o`gH00`2OMTT078G]01b5k@0601b5k@0304^Vo`0LQNd078G]00X078G]00<0BjKo
09W@i@2Id>D0C02Id>D10?ooo`00G@2Id>D00`2OMTT0BSP[04^Vo`0601Ude@0304^Vo`0IM=D06GCE
01806GCE00<0BjKo01Ude@0IM=D04P0IM=D00`2OMTT0_8aK09mfB@050;Z9F@<0WgI91038TUh0102O
MTT0cYMQ0<jGH@1;Y_l;01f7l00304^Vo`0MQo007HO`01807HO`00<0BjKo01f7l00MQo003`0MQo00
0`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400T03T:400<0BjKo00i2Q00>@X@00`0>@X@0
1@2OMTT0gJ9W0=fRI`3MXVL0WgI900<0fj5V00D0WgI90>NYJP3WZFX0ijUZ09mfB@020=fRIP0509mf
B@3VZ6T0iZQY0>JXJ@2OMTT00`3/[F`00`1;Y_l06go@04^Vo`0201]od00404^Vo`0KOm006go@04^V
oaD067;A00<0BjKo01Qbd@0HL]40500HL]400`1;Y_l067;A01Qbd@0@01Qbd@80WgI9103m^W<00`2O
MTT0ol=f0?o3MP020?o3MP0309mfB@0LQNd078G]00H078G]00<0BjKo01b5k@0LQNd02@0LQNd00`1;
Y_l0VM3U09W@i@1=09W@i@40oooo001N09W@i@80WgI900<0BjKo01Ude@0IM=D00`0IM=D00`1;Y_l0
6GCE01Ude@0B01Ude@0304^Vo`0IM=D06GCE01806GCE00<0WgI90;b<F`2OMTT01@2jRET309mfB@@0
b99N00@0WgI90<jGH@3>Uf40BjKo2`0MQo000`1;Y_l07HO`01f7l00B01f7l00304^Vo`0MQo007HO`
00l07HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q00900i2Q00304^Vo`0>@X@03T:4
00803T:400<0WgI90=fRI`3MXVL00P3MXVL01@2OMTT0fj5V0=^QIP3KXFH0WgI900<0ijUZ00@0WgI9
0=fRIP3MXVH0WgI90`3VZ6T01`2OMTT0k:e/0>b]K03/[F`0BjKo01]od01;Y_l00P0KOm00101;Y_l0
6go@01]od01;Y_lE01Qbd@0304^Vo`0HL]4067;A01@067;A00<0BjKo01Qbd@0HL]40400HL]4209mf
B@<0oKYc00<0WgI90?o3MP3o`gH00P3o`gH209mfB@P078G]00<0BjKo01b5k@0LQNd02@0LQNd00`1;
Y_l0VM3U09W@i@1=09W@i@40oooo001N09W@i@0309mfB@1:>2/0BjKo00D06GCE00<0BjKo01Ude@0I
M=D04P0IM=D00`1;Y_l06GCE01Ude@0B01Ude@0304^Vo`2OMTT0WgI900D0^XUI0P2OMTT00`2mRe/0
WgI90<RBGP030<RBGP0409mfB@3>Uf40cYMQ04^Vo`X07HO`00<0BjKo01f7l00MQo004P0MQo000`1;
Y_l07HO`01f7l00?01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@02@0>@X@00`1;
Y_l03T:400i2Q00200i2Q00309mfB@3MXVL0gJ9W0080gJ9W00D0WgI90=^QIP3KXFH0fj5V09mfB@02
0>NYJP0509mfB@3MXVH0gJ9V0=fRIP2OMTT00`3VZ6T01`2OMTT0k:e/0>b]K03/[F`0BjKo01]od01;
Y_l00P0KOm00101;Y_l06go@01]od01;Y_lE01Qbd@0304^Vo`0HL]4067;A01@067;A00<0BjKo01Qb
d@0HL]403`0HL]4209mfB@@0oKYc00<0WgI90?o3MP3o`gH00P3o`gH00`2OMTT078G]01b5k@0701b5
k@0304^Vo`0LQNd078G]00P078G]00<0BjKo09W@i@2Id>D0CP2Id>D10?ooo`00G`2Id>D209mfB@03
04^Vo`0IM=D06GCE00806GCE00<0BjKo01Ude@0IM=D04P0IM=D00`1;Y_l06GCE01Ude@0B01Ude@04
04^Vo`2OMTT0_8aK09mfB@@0^XUI00D0WgI90<VDG`2OMTT0_H]K09mfB@030<RBGP0409mfB@3>Uf40
cYMQ04^Vo`X07HO`00<0BjKo01f7l00MQo004P0MQo000`1;Y_l07HO`01f7l00?01f7l00304^Vo`0>
@X@03T:400P03T:400<0BjKo00i2Q00>@X@02@0>@X@00`1;Y_l03T:400i2Q00200i2Q00309mfB@3M
XVL0gJ9W0080gJ9W00@0WgI90=^QIP3KXFH0WgI90`3WZFX01@2OMTT0gJ9V0=fRIP3MXVH0WgI90080
iZQY00<0WgI90>b]K03/[F`00P3/[F`00`1;Y_l06go@04^Vo`0201]od00404^Vo`0KOm006go@04^V
oaD067;A00<0BjKo01Qbd@0HL]40500HL]400`1;Y_l067;A01Qbd@0>01Qbd@0309mfB@3m^g<0WgI9
00<0oKYc00<0WgI90?o3MP3o`gH00P3o`gH209mfB@T078G]00<0BjKo01b5k@0LQNd0200LQNd00`1;
Y_l0VM3U09W@i@1>09W@i@40oooo001O09W@i@0309mfB@1:>2/0BjKo00@06GCE00<0BjKo01Ude@0I
M=D04P0IM=D00`1;Y_l06GCE01Ude@0B01Ude@0404^Vo`2OMTT0_8aK09mfB@@0^XUI00D0WgI90<VD
G`2OMTT0_H]K09mfB@030<RBGP0509mfB@3>Uf40cYMQ0<jGH@1;Y_l02@0MQo000`1;Y_l07HO`01f7
l00B01f7l00304^Vo`0MQo007HO`00l07HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2
Q00900i2Q00304^Vo`0>@X@03T:400803T:400<0WgI90=fRI`3MXVL00P3MXVL0102OMTT0fj5V0=^Q
IP2OMTT30>NYJP0509mfB@3MXVH0gJ9V0=fRIP2OMTT00P3VZ6T00`2OMTT0k:e/0>b]K0020>b]K003
04^Vo`0KOm00BjKo00806go@00@0BjKo01]od00KOm00BjKo5@0HL]400`1;Y_l067;A01Qbd@0D01Qb
d@0304^Vo`0HL]4067;A00h067;A0P2OMTT40?fjL`0309mfB@3o`gH0ol=f0080ol=f00<0WgI901b5
k@0LQNd0200LQNd00`1;Y_l078G]01b5k@0701b5k@0304^Vo`2Id>D0VM3U04l0VM3U0@3oool00600
VM3U0P2OMTT01@1;Y_l06GCE01Ude@0IM=D0BjKo01@06GCE00<0BjKo01Ude@0IM=D04P0IM=D01@1;
Y_l0WgI90;b<F`2lS5/0WgI900<0^XUI00<0WgI90<VDG`2OMTT00P2mRe/01@2OMTT0b99N0<RBGP38
TUh0WgI90080cYMQ00<0BjKo01f7l00MQo001`0MQo000`1;Y_l07HO`01f7l00A01f7l00304^Vo`0M
Qo007HO`01007HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q00900i2Q00504^Vo`0>
@X@03T:400i2Q02OMTT01@3MXVL00`2OMTT0fj5V09mfB@040>NYJP0309mfB@3MXVH0gJ9V0080gJ9V
00<0WgI90>JXJ@2OMTT0103/[F`00`1;Y_l06go@04^Vo`0201]od00404^Vo`0KOm006go@04^VoaD0
67;A00<0BjKo01Qbd@0HL]40500HL]400`1;Y_l067;A01Qbd@0=01Qbd@0309mfB@3m^g<0WgI900<0
oKYc0P2OMTT30?o3MP80WgI92P0LQNd00`1;Y_l078G]01b5k@0701b5k@0304^Vo`2Id>D0VM3U04l0
VM3U0@3oool00600VM3U00@0WgI904Xh:`2OMTT0BjKo0P0IM=D00`1;Y_l06GCE01Ude@0B01Ude@03
04^Vo`0IM=D06GCE01806GCE00D0BjKo09mfB@2lS5/0_8aK09mfB@030;Z9F@0609mfB@39U5l0bIAO
09mfB@2mRe/0WgI90`38TUh01@2OMTT0cYMQ0<jGH@3>Uf40BjKo00P07HO`00<0BjKo01f7l00MQo00
4@0MQo000`1;Y_l07HO`01f7l00@01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@0
2@0>@X@01@1;Y_l03T:400i2Q00>@X@0WgI900@0gJ9W00@0WgI90=^QIP3KXFH0WgI9103WZFX00`2O
MTT0gJ9V0=fRIP020=fRIP0309mfB@3VZ6T0WgI900@0k:e/00<0BjKo01]od01;Y_l00`0KOm000`1;
Y_l06go@04^Vo`0E01Qbd@0304^Vo`0HL]4067;A01@067;A00<0BjKo01Qbd@0HL]403@0HL]4209mf
B@@0oKYc00<0WgI90?o3MP3o`gH00P3o`gH209mfB@/078G]00<0BjKo01b5k@0LQNd01@0LQNd00`1;
Y_l0VM3U09W@i@1@09W@i@40oooo001Q09W@i@80WgI900@0BjKo01Ude@0IM=D0BjKo500IM=D00`1;
Y_l06GCE01Ude@0B01Ude@0504^Vo`0IM=D0WgI90;b<F`2OMTT00`2jRET0102OMTT0bIAO0<VDG`2O
MTT20;f;F`0409mfB@38TUh0b99N09mfB@<0cYMQ00<0BjKo01f7l00MQo001P0MQo000`1;Y_l07HO`
01f7l00A01f7l00304^Vo`0MQo007HO`01007HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:4
00i2Q00900i2Q00504^Vo`0>@X@03T:400i2Q02OMTT0103MXVL0102OMTT0fj5V0=^QIP2OMTT40>NY
JP0309mfB@3MXVH0gJ9V0080gJ9V00<0WgI90>JXJ@2OMTT01@3/[F`204^Vo`<06go@00<0BjKo01]o
d01;Y_l05@0HL]400`1;Y_l067;A01Qbd@0D01Qbd@0304^Vo`0HL]4067;A00`067;A00<0WgI90?fk
L`2OMTT00`3m^W<209mfB@<0ol=f0P2OMTT<01b5k@0304^Vo`0LQNd078G]00D078G]00<0BjKo09W@
i@2Id>D0D02Id>D10?ooo`00H@2Id>D01P2OMTT0BSP[09mfB@1;Y_l06GCE04^Voa@06GCE00<0BjKo
01Ude@0IM=D04P0IM=D00`1;Y_l06GCE09mfB@020;b<F`0409mfB@2jRET0^XUI09mfB@80bIAO00D0
WgI90;f;F`2mRe/0_H]K09mfB@020<RBGP0509mfB@3>Uf40cYMQ0<jGH@1;Y_l01`0MQo000`1;Y_l0
7HO`01f7l00A01f7l00304^Vo`0MQo007HO`01007HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l0
3T:400i2Q00900i2Q00404^Vo`0>@X@03T:409mfB@D0gJ9W00<0WgI90=^QIP2OMTT01@3WZFX00`2O
MTT0gJ9V0=fRIP020=fRIP0309mfB@3VZ6T0WgI900D0k:e/0P1;Y_l301]od00304^Vo`0KOm00BjKo
01D067;A00<0BjKo01Qbd@0HL]40500HL]400`1;Y_l067;A01Qbd@0;01Qbd@0309mfB@3m^g<0WgI9
00<0oKYc0`2OMTT30?o3MP80WgI9300LQNd00`1;Y_l078G]01b5k@0401b5k@0304^Vo`2Id>D0VM3U
0540VM3U0@3oool00680VM3U00D0WgI904Xh:`1;Y_l06GCE04^Vo`0D01Ude@0304^Vo`0IM=D06GCE
01806GCE00<0BjKo01Ude@2OMTT00P2lS5/01@2OMTT0^XUI0;Z9F@2jRET0WgI90080bIAO00@0WgI9
0;f;F`2mRe/0WgI90P38TUh01@2OMTT0cYMQ0<jGH@3>Uf40BjKo00L07HO`00<0BjKo01f7l00MQo00
4@0MQo000`1;Y_l07HO`01f7l00@01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@0
2@0>@X@0101;Y_l03T:400i2Q02OMTT50=fRI`0309mfB@3KXFH0WgI900D0ijUZ00<0WgI90=fRIP3M
XVH00P3MXVH00`2OMTT0iZQY09mfB@050>b]K080BjKo0`0KOm000`1;Y_l06go@04^Vo`0E01Qbd@03
04^Vo`0HL]4067;A01@067;A00<0BjKo01Qbd@0HL]402`0HL]400`2OMTT0oK]c09mfB@030?fjL`80
WgI90`3o`gH209mfB@d078G]00<0BjKo01b5k@0LQNd0100LQNd00`1;Y_l0VM3U09W@i@1A09W@i@40
oooo001R09W@i@0309mfB@1:>2/0WgI90080BjKo500IM=D00`1;Y_l06GCE01Ude@0B01Ude@0304^V
o`0IM=D0WgI90080_8aK00D0WgI90;Z9F@2jRET0^XUI09mfB@020<VDG`0709mfB@2mRe/0_H]K0;f;
F`2OMTT0b99N09mfB@040<jGH@0304^Vo`0MQo007HO`00@07HO`00<0BjKo01f7l00MQo004@0MQo00
0`1;Y_l07HO`01f7l00@01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@02@0>@X@0
101;Y_l03T:400i2Q02OMTT50=fRI`0309mfB@3KXFH0WgI900D0ijUZ00<0WgI90=fRIP3MXVH00P3M
XVH00`2OMTT0iZQY09mfB@050>b]K080BjKo0`0KOm000`1;Y_l06go@04^Vo`0F01Qbd@0304^Vo`0H
L]4067;A01<067;A00<0BjKo01Qbd@0HL]402P0HL]400`2OMTT0oK]c09mfB@030?fjL`<0WgI90`3o
`gH209mfB@d078G]00<0BjKo01b5k@0LQNd00`0LQNd00`1;Y_l0VM3U09W@i@1B09W@i@40oooo001S
09W@i@0409mfB@1:>2/0BjKo04^Voa@06GCE00<0BjKo01Ude@0IM=D04P0IM=D00`1;Y_l06GCE09mf
B@030;b<F`0409mfB@2jRET0^XUI09mfB@80bIAO00L0WgI90;f;F`2mRe/0_H]K09mfB@38TUh0WgI9
00@0cYMQ00<0BjKo01f7l00MQo00100MQo000`1;Y_l07HO`01f7l00A01f7l00304^Vo`0MQo007HO`
01007HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q00900i2Q00404^Vo`0>@X@03T:4
09mfB@D0gJ9W0P2OMTT50>NYJP0309mfB@3MXVH0gJ9V00<0gJ9V0P2OMTT60>b]K080BjKo0`0KOm00
0`1;Y_l06go@04^Vo`0F01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]402@0HL]40
102OMTT0oK]c0?fkL`2OMTT20?fjL`80WgI900L0okac09mfB@3o`gH0ol=f09mfB@3o`g@0WgI900d0
78G]00<0BjKo01b5k@0LQNd00`0LQNd00`1;Y_l0VM3U09W@i@1B09W@i@40oooo001S09W@i@0409mf
B@1:>2/0WgI909mfBA@06GCE00<0BjKo01Ude@0IM=D04P0IM=D0101;Y_l06GCE01Ude@2OMTT20;b<
F`0409mfB@2jRET0^XUI09mfB@<0bIAO00L0WgI90;f;F`2mRe/0_H]K09mfB@38TUh0WgI900@0cYMQ
00<0BjKo01f7l00MQo000`0MQo000`1;Y_l07HO`01f7l00A01f7l00304^Vo`0MQo007HO`01007HO`
00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q00900i2Q00304^Vo`0>@X@0WgI900H0gJ9W
0P2OMTT50>NYJP0309mfB@3MXVH0gJ9V00@0gJ9V00<0WgI90>b]K03/[F`0103/[F`204^Vo`<06go@
00<0BjKo01]od01;Y_l05P0HL]400`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A00T067;A
00@0WgI90?fkL`3m^g<0WgI90P3m^W<309mfB@<0ol=f0P2OMTT>01b5k@0304^Vo`0LQNd078G]0080
78G]00<0BjKo09W@i@2Id>D0D`2Id>D10?ooo`00I02Id>D0102OMTT0BSP[09mfB@2OMTTC01Ude@03
04^Vo`0IM=D06GCE01806GCE00@0BjKo01Ude@0IM=D0WgI90`2lS5/00`2OMTT0^XUI09mfB@030<VD
G`0709mfB@2mRe/0_H]K0;f;F`2OMTT0b99N09mfB@040<jGH@0304^Vo`0MQo007HO`00<07HO`00<0
BjKo01f7l00MQo004@0MQo000`1;Y_l07HO`01f7l00@01f7l00304^Vo`0>@X@03T:400P03T:400<0
BjKo00i2Q00>@X@02@0>@X@00`1;Y_l03T:409mfB@060=fRI`0309mfB@3WZFX0ijUZ00@0ijUZ00<0
WgI90=fRIP3MXVH0103MXVH00`2OMTT0k:e/0>b]K0040>b]K080BjKo0`0KOm000`1;Y_l06go@04^V
o`0F01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]40200HL]40102OMTT0oK]c0?fk
L`2OMTT20?fjL`80WgI900L0okac09mfB@3o`gH0ol=f09mfB@3o`g@0WgI900h078G]00<0BjKo01b5
k@0LQNd00P0LQNd00`1;Y_l0VM3U09W@i@1C09W@i@40oooo001T09W@i@0409mfB@1:>2/0WgI909mf
BA<06GCE00<0BjKo01Ude@0IM=D04P0IM=D0101;Y_l06GCE01Ude@2OMTT30;b<F`0309mfB@2jRET0
WgI900@0bIAO00@0WgI90;f;F`2mRe/0_H]K0P2OMTT50<jGH@0304^Vo`0MQo007HO`00807HO`00<0
BjKo01f7l00MQo004@0MQo000`1;Y_l07HO`01f7l00@01f7l00304^Vo`0>@X@03T:400P03T:400<0
BjKo00i2Q00>@X@02@0>@X@00`1;Y_l03T:409mfB@060=fRI`0309mfB@3WZFX0ijUZ00@0ijUZ00<0
WgI90=fRIP3MXVH0103MXVH00`2OMTT0k:e/0>b]K0040>b]K080BjKo0`0KOm000`1;Y_l06go@04^V
o`0F01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]401`0HL]402`2OMTT0oK]c0?fk
L`3m^g<0WgI90?fjL`2OMTT0olEh09mfB@3o_7<0WgI90080ol=f00<0WgI90?o3M02OMTT03P0LQNd0
1@1;Y_l078G]01b5k@0LQNd0BjKo05H0VM3U0@3oool006D0VM3U00@0WgI904Xh:`2OMTT0WgI94P0I
M=D00`1;Y_l06GCE01Ude@0B01Ude@0404^Vo`0IM=D06GCE09mfB@<0_8aK00<0WgI90;Z9F@2OMTT0
1039U5l00`2OMTT0_H]K0;f;F`020;f;F`80WgI9103>Uf400`1;Y_l07HO`01f7l00201f7l00304^V
o`0MQo007HO`01407HO`00<0BjKo01f7l00MQo00400MQo000`1;Y_l03T:400i2Q00800i2Q00304^V
o`0>@X@03T:400T03T:400<0BjKo09mfB@3MXVL01P3MXVL00`2OMTT0ijUZ0>NYJP040>NYJP0309mf
B@3MXVH0gJ9V00@0gJ9V00<0WgI90>b]K03/[F`0103/[F`204^Vo`<06go@00<0BjKo01]od01;Y_l0
5P0HL]400`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A00L067;A00X0WgI90?fkL`3m^g<0
WgI90?fjL`2OMTT0olEh09mfB@3o_7<0WgI90P3o`gH00`2OMTT0ol=d09mfB@0?01b5k@0504^Vo`0L
QNd078G]01b5k@1;Y_l0EP2Id>D10?ooo`00IP2Id>D309mfB@0304^Vo`0IM=D06GCE00l06GCE00<0
BjKo01Ude@0IM=D04P0IM=D0101;Y_l06GCE01Ude@2OMTT40;b<F`80WgI91039U5l00`2OMTT0_H]K
0;f;F`020;f;F`80WgI91@3>Uf401@1;Y_l07HO`01f7l00MQo00BjKo01<07HO`00<0BjKo01f7l00M
Qo00400MQo000`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400T03T:400<0BjKo09mfB@3M
XVL01@3MXVL209mfB@H0ijUZ00<0WgI90=fRIP3MXVH0103MXVH00`2OMTT0k:e/0>b]K0040>b]K080
BjKo0`0KOm000`1;Y_l06go@04^Vo`0F01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0H
L]401P0HL]402`2OMTT0oK]c0?fkL`3m^g<0WgI90?fjL`2OMTT0olEh09mfB@3o_7<0WgI90080ol=f
00<0WgI90?o3M02OMTT03`0LQNd0101;Y_l078G]01b5k@1;Y_mG09W@i@40oooo001V09W@i@0409mf
B@1:>2/0WgI909mfBA406GCE00<0BjKo01Ude@0IM=D04P0IM=D01@1;Y_l06GCE01Ude@0IM=D0WgI9
00<0_8aK0P2OMTT50<VDG`0309mfB@2mRe/0_H]K0080_H]K00<0WgI90<jGH@3>Uf400`3>Uf401@1;
Y_l07HO`01f7l00MQo00BjKo01<07HO`00<0BjKo01f7l00MQo00400MQo000`1;Y_l03T:400i2Q008
00i2Q00304^Vo`0>@X@03T:400T03T:400<0BjKo09mfB@3MXVL01@3MXVL209mfB@H0ijUZ00<0WgI9
0=fRIP3MXVH0103MXVH00`2OMTT0k:e/0>b]K0050>b]K00704^Vo`0KOm006go@01]od01;Y_l06go@
04^Vo`0F01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]401@0HL]402@2OMTT0oK]c
0?fkL`3m^g<0WgI90?fjL`2OMTT0olEh09mfB@020?nlL`0509mfB@3o`gH0WgI90?o3M02OMTT0400L
QNd0101;Y_l078G]01b5k@1;Y_mG09W@i@40oooo001W09W@i@80WgI900<0QfI609mfB@0IM=D03`0I
M=D00`1;Y_l06GCE01Ude@0B01Ude@0504^Vo`0IM=D06GCE01Ude@2OMTT00`2lS5/00`2OMTT0^XUI
09mfB@040<VDG`0309mfB@2mRe/0_H]K0080_H]K0P2OMTT50<jGH@0404^Vo`0MQo007HO`04^Voa<0
7HO`00<0BjKo01f7l00MQo00400MQo000`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400T0
3T:400<0BjKo09mfB@3MXVL01@3MXVL209mfB@H0ijUZ00<0WgI90=fRIP3MXVH0103MXVH00`2OMTT0
k:e/0>b]K0050>b]K00704^Vo`0KOm006go@01]od01;Y_l06go@04^Vo`0F01Qbd@0304^Vo`0HL]40
67;A01<067;A00<0BjKo01Qbd@0HL]401@0HL]40102OMTT0oK]c0?fkL`3m^g<209mfB@80olEh00P0
WgI90?nlL`3o_7<0WgI90?o3MP2OMTT0ol=d09mfBA0078G]00<0BjKo01b5k@1;Y_l0F02Id>D10?oo
o`00I`2Id>D01@2OMTT0BSP[09mfB@2OMTT0BjKo00l06GCE00<0BjKo01Ude@0IM=D04P0IM=D01@1;
Y_l06GCE01Ude@0IM=D0WgI900@0_8aK0P2OMTT40<VDG`0309mfB@2mRe/0_H]K00<0_H]K00<0WgI9
0<jGH@3>Uf400`3>Uf40101;Y_l07HO`01f7l01;Y_lC01f7l00304^Vo`0MQo007HO`01007HO`00<0
BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q00900i2Q00309mfB@3MXVL0gJ9W00@0gJ9W00<0
WgI90>R[J`2OMTT01P3WZFX00`2OMTT0gJ9V0=fRIP030=fRIP80WgI91`3/[F`01`1;Y_l06go@01]o
d00KOm00BjKo01]od01;Y_l05P0HL]400`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A00@0
67;A00T0WgI90?fkL`3m^g<0oK]c09mfB@3m^W<0WgI90?o5N02OMTT00P3o_7<00`2OMTT0ol=f09mf
B@020?o3M00309mfB@0LQNd078G]00h078G]00<0BjKo01b5k@1;Y_l0F02Id>D10?ooo`00J02Id>D0
1@2OMTT0BSP[09mfB@2OMTT0BjKo00h06GCE00<0BjKo01Ude@0IM=D04P0IM=D01@1;Y_l06GCE01Ud
e@0IM=D0WgI900@0_8aK0P2OMTT50<VDG`0309mfB@2mRe/0_H]K0080_H]K0P2OMTT50<jGH@0304^V
o`0MQo00BjKo01<07HO`00<0BjKo01f7l00MQo00400MQo000`1;Y_l03T:400i2Q00800i2Q00304^V
o`0>@X@03T:400T03T:400<0WgI90=fRI`3MXVL0103MXVL00`2OMTT0j:][09mfB@050>NYJP0309mf
B@3MXVH0gJ9V00@0gJ9V0P2OMTT70>b]K00704^Vo`0KOm006go@01]od01;Y_l06go@04^Vo`0F01Qb
d@0304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]400`0HL]400`2OMTT0oK]c0?fkL`020?fk
L`80WgI90P3oaGP02@2OMTT0okac0?nlL`2OMTT0ol=f09mfB@3o`g@0WgI904^Vo`0@01b5k@80BjKo
F@2Id>D10?ooo`00J02Id>D409mfB@0309aeCP0IM=D06GCE00`06GCE00<0BjKo01Ude@0IM=D04P0I
M=D00`1;Y_l06GCE01Ude@0201Ude@0309mfB@2lS5/0_8aK0080_8aK00<0WgI90<VDG`39U5l00`39
U5l00`2OMTT0_H]K0;f;F`030;f;F`0309mfB@3>Uf40cYMQ00<0cYMQ00<0BjKo01f7l01;Y_l04`0M
Qo000`1;Y_l07HO`01f7l00@01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@02@0>
@X@00`2OMTT0gJ9W0=fRI`040=fRI`0309mfB@3XZf/0WgI900D0ijUZ00<0WgI90=fRIP3MXVH0103M
XVH00`2OMTT0hjIY09mfB@060>b]K00704^Vo`0KOm006go@01]od01;Y_l06go@04^Vo`0F01Qbd@03
04^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]400`0HL]40102OMTT0oK]c0?fkL`3m^g<209mf
B@80olEh00@0WgI90?nlL`3o_7<0okac0P2OMTT20?o3M00309mfB@1;Y_l078G]00l078G]0P1;Y_mI
09W@i@40oooo001Y09W@i@0509mfB@1:>2/0WgI909mfB@1;Y_l03@0IM=D00`1;Y_l06GCE01Ude@0B
01Ude@0304^Vo`0IM=D06GCE00806GCE00<0WgI90;b<F`2lS5/00P2lS5/00`2OMTT0bIAO0<VDG`03
0<VDG`0309mfB@2mRe/0_H]K00<0_H]K0P2OMTT50<jGH@80BjKo4`0MQo000`1;Y_l07HO`01f7l00@
01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@0200>@X@209mfB@D0gJ9W00<0WgI9
0>R[J`2OMTT01P3WZFX00`2OMTT0gJ9V0=fRIP040=fRIP0309mfB@3SYVT0WgI900H0k:e/00D0WgI9
01]od00KOm006go@04^Vo`0201]od00304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]404`0H
L]400`1;Y_l067;A01Qbd@0201Qbd@0309mfB@3m^g<0oK]c0080oK]c0P2OMTT20?o5N00:09mfB@3o
_7<0okac09mfB@3o`gH0WgI90?o3M02OMTT078G]04^Voa0078G]00<0BjKo09W@i@2Id>D0F02Id>D1
0?ooo`00JP2Id>D409mfB@0304^Vo`0IM=D06GCE00X06GCE00<0BjKo01Ude@0IM=D04P0IM=D00`1;
Y_l06GCE01Ude@0201Ude@0309mfB@2lS5/0_8aK0080_8aK00<0WgI90<VDG`39U5l01039U5l00`2O
MTT0_H]K0;f;F`020;f;F`80WgI91@3>Uf4204^Voa<07HO`00<0BjKo01f7l00MQo00400MQo000`1;
Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400P03T:40P2OMTT50=fRI`0309mfB@3XZf/0WgI9
00H0ijUZ00<0WgI90=fRIP3MXVH0103MXVH00`2OMTT0hjIY09mfB@060>b]K00509mfB@0KOm006go@
01]od01;Y_l00P0KOm000`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A01<067;A00<0BjKo
01Qbd@0HL]400P0HL]40102OMTT0oK]c0?fkL`3m^g<209mfB@80olEh00@0WgI90?nlL`3o_7<0okac
0P2OMTT20?o3M00309mfB@0LQNd0BjKo010078G]00<0WgI909W@i@2Id>D0F02Id>D10?ooo`00JP2I
d>D01@2OMTT0BSP[09mfB@2OMTT0W7E>00`06GCE00<0BjKo01Ude@0IM=D04P0IM=D00`1;Y_l06GCE
01Ude@0201Ude@0309mfB@2lS5/0_8aK0080_8aK0P2OMTT50<VDG`0309mfB@2mRe/0_H]K00<0_H]K
0P2OMTT50<jGH@0304^Vo`0MQo007HO`01407HO`00<0BjKo01f7l00MQo00400MQo000`1;Y_l03T:4
00i2Q00800i2Q00304^Vo`0>@X@03T:400L03T:400<0WgI90=bSI`2OMTT01@3MXVL00`2OMTT0j:][
09mfB@060>NYJP0309mfB@3MXVH0gJ9V00@0gJ9V00<0WgI90>>VJ@2OMTT01@3/[F`00`2OMTT0BjKo
01]od00201]od00404^Vo`0KOm006go@04^VoaD067;A00<0BjKo01Qbd@0HL]404`0HL]401@1;Y_l0
67;A01Qbd@0HL]40WgI900@0oK]c00D0WgI90?o5N03oaGP0olEh09mfB@030?nlL`80WgI90P3o`g@0
0`2OMTT078G]04^Vo`0?01b5k@0309mfB@2Id>D0VM3U05T0VM3U0@3oool006/0VM3U102OMTT00`2L
MDh06GCE01Ude@0801Ude@0304^Vo`0IM=D06GCE01<06GCE00<0BjKo01Ude@0IM=D00P0IM=D00`2O
MTT0_8aK0;b<F`030;b<F`0309mfB@39U5l0bIAO00<0bIAO00<0WgI90;f;F`2mRe/00`2mRe/00`2O
MTT0aI5N09mfB@040<jGH@80WgI94P0MQo000`1;Y_l07HO`01f7l00@01f7l00304^Vo`0>@X@03T:4
00P03T:400<0BjKo00i2Q00>@X@01`0>@X@00`2OMTT0g:=W09mfB@040=fRI`0409mfB@3XZf/0j:][
09mfB@H0ijUZ00<0WgI90=fRIP3MXVH0103MXVH00`2OMTT0hjIY09mfB@050>b]K00309mfB@1;Y_l0
6go@00806go@00@0BjKo01]od00KOm00BjKo5@0HL]400`1;Y_l067;A01Qbd@0C01Qbd@0404^Vo`0H
L]4067;A09mfB@@0oK]c0P2OMTT20?o5N00409mfB@3o_7<0okac0?nlL`80WgI90P3o`g@0102OMTT0
78G]01b5k@1;Y_l?01b5k@0309mfB@2Id>D0VM3U05T0VM3U0@3oool006/0VM3U102OMTT00`2LMDh0
BjKo01Ude@0801Ude@0304^Vo`0IM=D06GCE01<06GCE00<0BjKo01Ude@0IM=D00`0IM=D00`2OMTT0
_8aK0;b<F`020;b<F`80WgI91@39U5l00`2OMTT0_H]K0;f;F`020;f;F`0309mfB@35TEh0WgI900D0
cYMQ00<0WgI901f7l00MQo00400MQo000`1;Y_l07HO`01f7l00@01f7l00304^Vo`0>@X@03T:400P0
3T:400<0BjKo00i2Q00>@X@01`0>@X@00`2OMTT0g:=W09mfB@040=fRI`0409mfB@3XZf/0j:][09mf
B@D0ijUZ0P2OMTT50=fRIP0409mfB@3SYVT0hjIY09mfB@D0k:e/00<0WgI90?2`KP1;Y_l00P0KOm00
101;Y_l06go@01]od01;Y_lE01Qbd@0304^Vo`0HL]4067;A01<067;A00@0BjKo01Qbd@0HL]40WgI9
103m^g<01@2OMTT0olEh0?o5N03oaGP0WgI900<0okac0P2OMTT20?o3M00409mfB@0LQNd078G]04^V
o`h078G]00<0WgI909W@i@2Id>D0FP2Id>D10?ooo`00K02Id>D409mfB@0309aeCP0IM=D06GCE00L0
6GCE00<0BjKo01Ude@0IM=D04`0IM=D00`1;Y_l06GCE01Ude@0301Ude@0309mfB@2lS5/0_8aK0080
_8aK0P2OMTT50<VDG`0309mfB@2mRe/0_H]K00<0_H]K00<0WgI90<FAGP2OMTT0103>Uf4209mfBA40
7HO`00<0BjKo01f7l00MQo00400MQo000`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400H0
3T:400@0WgI90=bSI`3LXfL0WgI9103MXVL0102OMTT0j:][0>R[J`2OMTT50>NYJP<0WgI9103MXVH0
102OMTT0hjIY0>>VJ@2OMTT50>b]K00309mfB@3`/6h0BjKo00806go@00@0BjKo01]od00KOm00BjKo
5@0HL]400`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]40WgI900@0oK]c00D0WgI90?o5N03oaGP0
olEh09mfB@040?nlL`0409mfB@3o`g@0ol=d09mfB@<078G]00<0BjKo01b5k@0LQNd0300LQNd00`2O
MTT0VM3U09W@i@1J09W@i@40oooo001/09W@i@@0WgI90P2LMDh801Ude@0304^Vo`0IM=D06GCE01<0
6GCE00<0BjKo01Ude@0IM=D00`0IM=D00`2OMTT0_8aK0;b<F`020;b<F`0309mfB@3<Uf40WgI900@0
bIAO00<0WgI90;f;F`2mRe/00`2mRe/00`2OMTT0aI5N09mfB@040<jGH@0309mfB@3BVV<0WgI90100
7HO`00<0BjKo01f7l00MQo00400MQo000`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400H0
3T:400@0WgI90=bSI`3LXfL0WgI90`3MXVL01@2OMTT0j:][0>R[J`3XZf/0WgI900@0ijUZ00@0WgI9
0>V/K02OMTT0WgI9103MXVH0102OMTT0hjIY0>>VJ@2OMTT50>b]K00309mfB@3`/6h0BjKo00806go@
00@0BjKo01]od00KOm00BjKo5@0HL]400`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`2OMTT0oK]c00@0
oK]c00D0WgI90?o5N03oaGP0olEh09mfB@030?nlL`80WgI90P3o`g@01@2OMTT078G]01b5k@0LQNd0
BjKo00d078G]00<0WgI909W@i@2Id>D0F`2Id>D10?ooo`00K@2Id>D409mfB@0309aeCP1;Y_l06GCE
00H06GCE00<0BjKo01Ude@0IM=D04`0IM=D00`1;Y_l06GCE01Ude@0301Ude@0309mfB@2lS5/0_8aK
0080_8aK00<0WgI90<bGH@2OMTT01@39U5l00`2OMTT0_H]K0;f;F`030;f;F`0309mfB@35TEh0WgI9
00@0cYMQ0P2OMTT@01f7l00304^Vo`0MQo007HO`01007HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;
Y_l03T:400i2Q00600i2Q00409mfB@3LXfL0g:=W09mfB@<0gJ9W00D0WgI90>R[J`3XZf/0j:][09mf
B@040>NYJP0409mfB@3Y[6`0WgI909mfB@@0gJ9V00@0WgI90>>VJ@3SYVT0WgI9103/[F`0102OMTT0
l;1^0?2`KP1;Y_l201]od00404^Vo`0KOm006go@04^VoaD067;A00<0BjKo01Qbd@0HL]404`0HL]40
0`1;Y_l0WgI90?fkL`030?fkL`0509mfB@3oaGP0olEh0?o5N02OMTT0103o_7<01@2OMTT0ol=d0?o3
M03o`g@0WgI900<078G]00<0BjKo01b5k@0LQNd02P0LQNd209mfBEd0VM3U0@3oool006h0VM3U102O
MTT00`2LMDh06GCE01Ude@0501Ude@0304^Vo`0IM=D06GCE01<06GCE00<0BjKo01Ude@0IM=D00`0I
M=D209mfB@@0_8aK00<0WgI90<bGH@2OMTT01039U5l00`2OMTT0_H]K0;f;F`030;f;F`0409mfB@35
TEh0aI5N09mfB@<0cYMQ00<0WgI90=:JH`2OMTT03`0MQo000`1;Y_l07HO`01f7l00@01f7l00304^V
o`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@01@0>@X@01@2OMTT0g:=W0=bSI`3LXfL0WgI900<0
gJ9W00D0WgI90>R[J`3XZf/0j:][09mfB@040>NYJP80WgI900<0gZ=W09mfB@3MXVH00`3MXVH0102O
MTT0hjIY0>>VJ@2OMTT40>b]K00409mfB@3`/6h0l;1^04^Vo`806go@00@0BjKo01]od00KOm00BjKo
5@0HL]400`1;Y_l067;A01Qbd@0C01Qbd@0309mfB@3m^g<0oK]c0080oK]c0P2OMTT30?o5N00409mf
B@3o_7<0okac0?nlL`80WgI90P3o`g@00`2OMTT078G]01b5k@0201b5k@0304^Vo`0LQNd078G]00X0
78G]00<0WgI909W@i@2Id>D0G02Id>D10?ooo`00KP2Id>D409mfB@80W7E>1P0IM=D00`1;Y_l06GCE
01Ude@0C01Ude@0304^Vo`0IM=D06GCE00@06GCE00<0WgI90;b<F`2lS5/00P2lS5/00`2OMTT0c9MQ
09mfB@040<VDG`80WgI9102mRe/0102OMTT0aI5N0<FAGP2OMTT30<jGH@0409mfB@3BVV<0dYYS09mf
B@h07HO`00<0BjKo01f7l00MQo00400MQo000`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:4
00D03T:400D0WgI90=bSI`3LXfL0g:=W09mfB@020=fRI`0309mfB@3XZf/0j:][0080j:][00T0WgI9
0>NYJP3WZFX0ijUZ09mfB@3Y[6`0WgI90=jSI`2OMTT0103MXVH01@2OMTT0hjIY0>>VJ@3SYVT0WgI9
00<0k:e/00@0WgI90?2`KP3`/6h0BjKo0P0KOm00101;Y_l06go@01]od01;Y_lE01Qbd@0304^Vo`0H
L]4067;A018067;A00<0WgI90?fkL`3m^g<00P3m^g<209mfB@<0olEh00<0WgI90?nlL`3o_7<00P3o
_7<01@2OMTT0ol=d0?o3M03o`g@0WgI900@078G]00<0BjKo01b5k@0LQNd02@0LQNd00`2OMTT0VM3U
09W@i@1M09W@i@40oooo001_09W@i@@0WgI900<0W7E>04^Vo`0IM=D0100IM=D00`1;Y_l06GCE01Ud
e@0C01Ude@0304^Vo`0IM=D06GCE00@06GCE0P2OMTT30;b<F`0309mfB@3<Uf40WgI900@0bIAO0P2O
MTT50;f;F`0409mfB@35TEh0aI5N09mfB@<0cYMQ00@0WgI90=:JH`3BVV<0WgI93@0MQo000`1;Y_l0
7HO`01f7l00@01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@0100>@X@01@2OMTT0
g:=W0=bSI`3LXfL0WgI900<0gJ9W00<0WgI90>R[J`3XZf/00P3XZf/01`2OMTT0ijUZ0>NYJP3WZFX0
WgI90>V/K02OMTT00P3NXfL01@2OMTT0gJ9V0=fRIP3MXVH0WgI900<0hjIY00D0WgI90>b]K03/[F`0
k:e/09mfB@020?2`KP0404^Vo`0KOm006go@04^Vo`806go@00<0BjKo01Qbd@0HL]404`0HL]400`1;
Y_l067;A01Qbd@0A01Qbd@80WgI9103m^g<209mfB@<0olEh00@0WgI90?nlL`3o_7<0okac0P2OMTT3
0?o3M00309mfB@0LQNd078G]008078G]00<0BjKo01b5k@0LQNd02@0LQNd00`2OMTT0VM3U09W@i@1M
09W@i@40oooo001_09W@i@@0WgI90P2LMDh501Ude@0304^Vo`0IM=D06GCE01<06GCE00<0BjKo01Ud
e@0IM=D0100IM=D209mfB@<0_8aK00@0WgI90<bGH@3<Uf40WgI90`39U5l309mfB@@0_H]K00@0WgI9
0<FAGP35TEh0WgI90`3>Uf40102OMTT0dYYS0=:JH`2OMTT=01f7l00304^Vo`0MQo007HO`01007HO`
00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q00400i2Q00509mfB@3LXfL0g:=W0=bSI`2O
MTT00`3MXVL00`2OMTT0j:][0>R[J`020>R[J`0409mfB@3WZFX0ijUZ09mfB@80jJa/00@0WgI90=jS
I`3NXfL0WgI90`3MXVH01@2OMTT0hjIY0>>VJ@3SYVT0WgI900<0k:e/00@0WgI90?2`KP3`/6h0BjKo
0P0KOm00101;Y_l06go@01]od01;Y_lE01Qbd@0304^Vo`0HL]4067;A014067;A00<0WgI90?fkL`3m
^g<00P3m^g<209mfB@<0olEh00<0WgI90?nlL`3o_7<00P3o_7<01@2OMTT0ol=d0?o3M03o`g@0WgI9
00D078G]00<0BjKo01b5k@0LQNd0200LQNd00`2OMTT0VM3U09W@i@1N09W@i@40oooo001`09W@i@@0
WgI90P2LMDh401Ude@0304^Vo`0IM=D06GCE01<06GCE00<0BjKo01Ude@0IM=D0100IM=D00`2OMTT0
_8eL09mfB@020;b<F`0409mfB@3<Uf40c9MQ09mfB@@0bIAO0`2OMTT30;f;F`0509mfB@35TEh0aI5N
0<FAGP2OMTT00P3>Uf401@2OMTT0dYYS0=:JH`3BVV<0WgI900`07HO`00<0BjKo01f7l00MQo00400M
Qo000`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400@03T:400D0WgI90=bSI`3LXfL0g:=W
09mfB@020=fRI`0309mfB@3XZf/0j:][00<0j:][00@0WgI90>NYJP3WZFX0WgI90P3Y[6`0102OMTT0
gZ=W0=jSI`2OMTT20=fRIP0309mfB@3SYVT0hjIY0080hjIY00@0WgI90>b]K03/[F`0WgI9103`/6h0
0`1;Y_l06go@04^Vo`0201]od00304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]40400HL]42
09mfB@<0oK]c00<0WgI90?o6N@2OMTT00`3oaGP0102OMTT0okac0?nlL`3o_7<209mfB@<0ol=d00<0
WgI901b5k@0LQNd0100LQNd00`1;Y_l078G]01b5k@0601b5k@80WgI9H02Id>D10?ooo`00L@2Id>D4
09mfB@0309aeCP1;Y_l06GCE00806GCE00<0BjKo01Ude@0IM=D04`0IM=D00`1;Y_l06GCE01Ude@05
01Ude@80WgI90`2lS5/0102OMTT0c9MQ0<bGH@2OMTT30<VDG`80WgI900<0_XiL09mfB@2mRe/00P2m
Re/01@2OMTT0aI5N0<FAGP35TEh0WgI90080cYMQ00D0WgI90=:JH`3BVV<0dYYS09mfB@0;01f7l003
04^Vo`0MQo007HO`01007HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2Q00300i2Q003
09mfB@3LXfL0g:=W0080g:=W00@0WgI90=fRI`3MXVL0WgI91@3XZf/0102OMTT0ijUZ0>NYJP2OMTT2
0>V/K00409mfB@3NXfL0gZ=W09mfB@80gJ9V00<0WgI90>>VJ@3SYVT00P3SYVT0102OMTT0k:e/0>b]
K02OMTT40?2`KP0304^Vo`0KOm00BjKo00806go@00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A
01Qbd@0?01Qbd@80WgI90`3m^g<00`2OMTT0olIi09mfB@030?o5N00309mfB@3o_7<0okac0080okac
00D0WgI90?o3M03o`g@0ol=d09mfB@0701b5k@0304^Vo`0LQNd078G]00H078G]00<0WgI909W@i@2I
d>D0G`2Id>D10?ooo`00L@2Id>D409mfB@80W7E>00@0BjKo01Ude@0IM=D0BjKo5@0IM=D00`1;Y_l0
6GCE01Ude@0501Ude@80WgI90`2lS5/0102OMTT0c9MQ0<bGH@2OMTT30<VDG`80WgI900<0_XiL09mf
B@2mRe/00P2mRe/01@2OMTT0aI5N0<FAGP35TEh0WgI90080cYMQ00D0WgI90=:JH`3BVV<0dYYS09mf
B@0;01f7l00304^Vo`0MQo007HO`01007HO`00<0BjKo00i2Q00>@X@0200>@X@00`1;Y_l03T:400i2
Q00300i2Q00309mfB@3LXfL0g:=W0080g:=W00@0WgI90=fRI`3MXVL0WgI91@3XZf/00`2OMTT0ijUZ
09mfB@030>V/K00409mfB@3NXfL0gZ=W09mfB@80gJ9V00<0WgI90>>VJ@3SYVT00P3SYVT0102OMTT0
k:e/0>b]K02OMTT40?2`KP0304^Vo`0KOm00BjKo00806go@00<0BjKo01Qbd@0HL]404`0HL]400`1;
Y_l067;A01Qbd@0>01Qbd@0309mfB@3k^W<0WgI900<0oK]c00<0WgI90?o6N@2OMTT00`3oaGP0102O
MTT0okac0?nlL`3o_7<209mfB@<0ol=d00<0WgI901b5k@0LQNd01@0LQNd00`1;Y_l078G]01b5k@05
01b5k@0309mfB@2Id>D0VM3U0600VM3U0@3oool00780VM3U00@0WgI908QXB02OMTT0WgI90P2LMDh2
01Ude@0304^Vo`0IM=D06GCE01<06GCE00<0BjKo01Ude@0IM=D01@0IM=D00`2OMTT0_8eL09mfB@02
0;b<F`0509mfB@3<Uf40c9MQ0<bGH@2OMTT00P39U5l01@2OMTT0cIMQ09mfB@2nSU`0WgI90080_H]K
00<0WgI90<FAGP35TEh00P35TEh0102OMTT0cYMQ0<jGH@2OMTT30=:JH`0309mfB@0MQo007HO`00P0
7HO`00<0BjKo01f7l00MQo00400MQo000`1;Y_l03T:400i2Q00800i2Q00304^Vo`0>@X@03T:400<0
3T:400<0WgI90=bSI`3LXfL00P3LXfL00`2OMTT0gJ9W09mfB@050>R[J`0409mfB@3WZFX0ijUZ09mf
B@<0jJa/00L0WgI90=jSI`3NXfL0gZ=W09mfB@3MXVH0WgI900@0hjIY00@0WgI90>b]K03/[F`0WgI9
103`/6h00`1;Y_l06go@04^Vo`0201]od00304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]40
3@0HL]400`2OMTT0nkYc09mfB@030?fkL`0309mfB@3oaWT0WgI900<0olEh0P2OMTT20?nlL`0309mf
B@3o`GL0WgI90080ol=d0P2OMTT701b5k@0304^Vo`0LQNd078G]00D078G]00<0WgI909W@i@2Id>D0
H02Id>D10?ooo`00LP2Id>D409mfB@<0W7E>00<06GCE04^Vo`0IM=D0500IM=D00`1;Y_l06GCE01Ud
e@0501Ude@0309mfB@2lSE`0WgI90080_8aK00D0WgI90<bGH@3<Uf40c9MQ09mfB@020<VDG`0309mf
B@3=Uf40WgI90080_XiL00@0WgI90;f;F`2mRe/0WgI91035TEh00`2OMTT0cYMQ09mfB@040=:JH`03
09mfB@0MQo007HO`00L07HO`00<0BjKo01f7l00MQo00400MQo000`1;Y_l03T:400i2Q00800i2Q003
04^Vo`0>@X@03T:400803T:400<0WgI90=bSI`3LXfL00`3LXfL00`2OMTT0gJ9W09mfB@050>R[J`03
09mfB@3WZFX0WgI900@0jJa/00L0WgI90=jSI`3NXfL0gZ=W09mfB@3MXVH0WgI900@0hjIY00@0WgI9
0>b]K03/[F`0WgI9103`/6h00`1;Y_l06go@04^Vo`0201]od00304^Vo`0HL]4067;A01<067;A00<0
BjKo01Qbd@0HL]40300HL]40102OMTT0nkYc0?^jL`2OMTT20?fkL`0409mfB@3oaWT0olIi09mfB@80
olEh0P2OMTT30?nlL`80WgI90`3o`g@00`2OMTT078G]01b5k@0601b5k@0304^Vo`0LQNd078G]00@0
78G]00<0WgI909W@i@2Id>D0H@2Id>D10?ooo`00L`2Id>D0102OMTT0R6Q809mfB@2OMTT209aeCP80
BjKo5@0IM=D00`1;Y_l06GCE01Ude@0501Ude@0409mfB@2lSE`0_8eL09mfB@80_8aK00L0WgI90<bG
H@3<Uf40c9MQ09mfB@39U5l0WgI90080cIMQ00<0WgI90;j>G02OMTT00P2mRe/00`2OMTT0aI5N0<FA
GP020<FAGP0309mfB@3>Uf40WgI900@0dYYS00<0WgI901f7l00MQo001`0MQo000`1;Y_l07HO`01f7
l00@01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q00>@X@00P0>@X@00`2OMTT0g:=W0=bS
I`030=bSI`0309mfB@3MXVL0WgI900D0j:][00<0WgI90>NYJP2OMTT0103Y[6`01`2OMTT0gZ=W0=jS
I`3NXfL0WgI90=fRIP2OMTT0103SYVT00`2OMTT0k:e/09mfB@050?2`KP0304^Vo`0KOm00BjKo0080
6go@00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0<01Qbd@0309mfB@3k^W<0WgI90080
oK]c00@0WgI90?o6N@3oaWT0WgI90`3oaGP209mfB@80okac00<0WgI90?o1M`2OMTT00P3o`g@209mf
B@P078G]00<0BjKo01b5k@0LQNd00`0LQNd209mfBF<0VM3U0@3oool007<0VM3U0`2OMTT01@1C@300
WgI909aeCP2LMDh0BjKo01D06GCE00<0BjKo01Ude@0IM=D01P0IM=D00`2OMTT0_8eL09mfB@020;b<
F`0509mfB@3<Uf40c9MQ0<bGH@2OMTT00P39U5l00`2OMTT0cIMQ09mfB@020;j>G00309mfB@2mRe/0
WgI900D0aI5N00<0WgI90<jGH@2OMTT0103BVV<00`2OMTT07HO`01f7l00601f7l00304^Vo`0MQo00
7HO`01007HO`00<0BjKo00i2Q00>@X@0200>@X@01@1;Y_l03T:400i2Q00>@X@0WgI900H0g:=W0P2O
MTT60>R[J`0309mfB@3WZFX0WgI900<0jJa/00<0WgI90=jSI`3NXfL00P3NXfL00`2OMTT0gJ9V09mf
B@040>>VJ@0309mfB@3/[F`0WgI900D0l;1^00<0BjKo01]od01;Y_l00P0KOm000`1;Y_l067;A01Qb
d@0C01Qbd@0304^Vo`0HL]4067;A00/067;A00@0WgI90?^jL`3k^W<0WgI90P3m^g<0102OMTT0olIi
0?o6N@2OMTT20?o5N0<0WgI90P3o_7<209mfB@<0ol=d00<0WgI901b5k@0LQNd01`0LQNd00`1;Y_l0
78G]01b5k@0301b5k@0309mfB@2Id>D0VM3U0680VM3U0@3oool007@0VM3U00<0WgI908QXB02OMTT0
0P2OMTT00`2LMDh0WgI901Ude@0D01Ude@0304^Vo`0IM=D06GCE00H06GCE00H0WgI90;b=G02lSE`0
WgI90;b<F`2OMTT30<bGH@0409mfB@39U5l0bIAO09mfB@80cIMQ00H0WgI90;j>G02nSU`0WgI90;f;
F`2OMTT40<FAGP0309mfB@3>Uf40WgI900D0dYYS00<0WgI901f7l00MQo001@0MQo000`1;Y_l07HO`
01f7l00@01f7l00304^Vo`0>@X@03T:400P03T:400D0BjKo00i2Q00>@X@03T:409mfB@060=bSI`80
WgI91P3XZf/209mfB@@0jJa/00<0WgI90=jSI`3NXfL00P3NXfL209mfB@H0hjIY0P2OMTT50?2`KP03
04^Vo`0KOm00BjKo00806go@00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0:01Qbd@04
09mfB@3k^W<0nkYc09mfB@80oK]c00@0WgI90?o6N@3oaWT0WgI90P3oaGP309mfB@80okac00<0WgI9
0?o1M`2OMTT00P3o`g@209mfB@T078G]00<0BjKo01b5k@0LQNd00P0LQNd00`2OMTT0VM3U09W@i@1S
09W@i@40oooo001e09W@i@80WgI900D0Dd0`09mfB@2LMDh0W7E>09mfB@0C01Ude@0304^Vo`0IM=D0
6GCE00L06GCE00H0WgI90;b=G02lSE`0WgI90;b<F`2OMTT40<bGH@0309mfB@39U5l0WgI90080cIMQ
00H0WgI90;j>G02nSU`0WgI90;f;F`2OMTT50<FAGP80WgI91@3BVV<00`2OMTT07HO`01f7l00501f7
l00304^Vo`0MQo007HO`01007HO`00<0BjKo00i2Q00>@X@0200>@X@01@1;Y_l03T:400i2Q00>@X@0
WgI900H0g:=W0P2OMTT60>R[J`80WgI9103Y[6`00`2OMTT0gZ=W0=jSI`030=jSI`0309mfB@3SYVT0
hjIY00@0hjIY0P2OMTT60?2`KP80BjKo0P0KOm000`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]40
67;A00T067;A00L0WgI90?^jL`3k^W<0nkYc09mfB@3m^g<0WgI900<0olIi00@0WgI90?o5N02OMTT0
olMi0P2OMTT0103o_7<0WgI90?o1M`2OMTT20?o3M080WgI92P0LQNd00`1;Y_l078G]01b5k@0201b5
k@0309mfB@2Id>D0VM3U06<0VM3U0@3oool007D0VM3U0`2OMTT00`1C@300WgI909aeCP0209mfBA80
6GCE00<0BjKo01Ude@0IM=D01`0IM=D0102OMTT0_8eL0;b=G02lSE`209mfB@@0c9MQ00<0WgI90<VD
G`2OMTT00P3=Uf401`2OMTT0_XiL0;j>G02nSU`0WgI90;f;F`2OMTT01@35TEh209mfB@D0dYYS00<0
WgI901f7l00MQo00100MQo000`1;Y_l07HO`01f7l00@01f7l00304^Vo`0>@X@03T:400P03T:400@0
BjKo00i2Q00>@X@0WgI91`3LXfL00`2OMTT0j:][0>R[J`050>R[J`0309mfB@3Y[6`0jJa/00<0jJa/
00<0WgI90=jSI`3NXfL00`3NXfL00`2OMTT0hjIY0>>VJ@040>>VJ@80WgI91P3`/6h204^Vo`806go@
00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0801Qbd@0509mfB@3k^W<0nkYc0?^jL`2O
MTT00P3m^g<0102OMTT0olIi0?o6N@2OMTT20?o5N0<0WgI90P3o_7<00`2OMTT0ol5g09mfB@020?o3
M080WgI92P0LQNd01@1;Y_l078G]01b5k@0LQNd0WgI906H0VM3U0@3oool007H0VM3U00<0WgI908QX
B02OMTT00P2OMTT00`2LMDh0WgI909mfB@0A01Ude@0304^Vo`0IM=D06GCE00L06GCE00L0WgI90;b=
G02lSE`0_8eL09mfB@2lS5/0WgI900@0c9MQ0P2OMTT30<fGH@0409mfB@2nSU`0_XiL0;j>G080WgI9
1@35TEh209mfB@H0dYYS00<0WgI901f7l00MQo000`0MQo000`1;Y_l07HO`01f7l00@01f7l00304^V
o`0>@X@03T:400P03T:400@0BjKo00i2Q00>@X@0WgI91`3LXfL00`2OMTT0j:][0>R[J`050>R[J`03
09mfB@3Y[6`0jJa/00<0jJa/00<0WgI90=jSI`3NXfL00`3NXfL00`2OMTT0hjIY0>>VJ@040>>VJ@03
09mfB@3`/6h0l;1^00D0l;1^0P1;Y_l201]od00304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0H
L]40200HL]401`2OMTT0nkYc0?^jL`3k^W<0WgI90?fkL`2OMTT00`3oaWT0202OMTT0olEh09mfB@2O
MTT0okad09mfB@3o_7<0WgI90P3o`GL01@2OMTT0ol=d09mfB@3o`W@0WgI900X078G]00<0BjKo01b5
k@0LQNd00P2OMTUV09W@i@40oooo001f09W@i@<0WgI900D0Dd0`09mfB@2OMTT0W7E>09mfB@0A01Ud
e@0304^Vo`0IM=D06GCE00P06GCE00H0WgI90;b=G02lSE`0WgI90;b<F`2OMTT40<bGH@80WgI90`3=
Uf400`2OMTT0_XiL0;j>G0020;j>G00309mfB@35TEh0aI5N00@0aI5N00<0WgI90=:JH`3BVV<0103B
VV<00`2OMTT07HO`01f7l00301f7l00304^Vo`0MQo007HO`01007HO`00<0BjKo00i2Q00>@X@0200>
@X@0101;Y_l03T:400i2Q02OMTT70=bSI`0309mfB@3XZf/0j:][00D0j:][00<0WgI90>V/K03Y[6`0
0`3Y[6`00`2OMTT0gZ=W0=jSI`030=jSI`0309mfB@3SYVT0hjIY00@0hjIY00<0WgI90?2`KP3`/6h0
1@3`/6h204^Vo`806go@00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0701Qbd@0709mf
B@3k^W<0nkYc0?^jL`2OMTT0oK]c09mfB@030?o6N@0?09mfB@3oaGP0WgI90?o7N@2OMTT0okad09mf
B@3o_7<0WgI90?o1M`2OMTT0ol=d09mfB@3o`W@0WgI900/078G]00@0BjKo01b5k@0LQNd0WgI9I`2I
d>D10?ooo`00M`2Id>D0101C@300WgI909mfB@1C@30309mfB@030:MmD`0IM=D06GCE00h06GCE00<0
BjKo01Ude@0IM=D0200IM=D0102OMTT0_8eL0;b=G02lSE`209mfB@D0c9MQ0P2OMTT30<fGH@0409mf
B@2nSU`0_XiL0;j>G080WgI91@35TEh209mfB@H0dYYS00<0WgI901f7l00MQo000P0MQo000`1;Y_l0
7HO`01f7l00@01f7l00304^Vo`0>@X@03T:400P03T:400<0BjKo00i2Q02OMTT01`3LXfL209mfB@H0
j:][0P2OMTT50>V/K00309mfB@3NXfL0gZ=W00<0gZ=W00<0WgI90>>VJ@3SYVT0103SYVT00`2OMTT0
l;1^0?2`KP050?2`KP80BjKo0P0KOm000`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A00H0
67;A00<0WgI90?^jL`3k^W<00P3k^W<209mfB@@0olIi0P2OMTT01P3oagT0WgI90?nlM02OMTT0okac
09mfB@80ol5g00D0WgI90?o3M02OMTT0ol9d09mfB@0;01b5k@0304^Vo`0LQNd0WgI906P0VM3U0@3o
ool007L0VM3U0`2OMTT205=0<0@0WgI93`0IM=D00`1;Y_l06GCE01Ude@0801Ude@0409mfB@2lSE`0
_8eL0;b=G080WgI91@3<Uf4209mfB@<0cIMQ00<0WgI90;j>G02nSU`00P2nSU`00`2OMTT0aI5N0<FA
GP040<FAGP0309mfB@3BVV<0dYYS00D0dYYS00D0WgI901f7l00MQo007HO`04^Vo`0B01f7l00304^V
o`0>@X@03T:400P03T:400<0BjKo00i2Q02OMTT01`3LXfL209mfB@H0j:][0P2OMTT50>V/K00309mf
B@3NXfL0gZ=W00<0gZ=W00<0WgI90>>VJ@3SYVT0103SYVT00`2OMTT0l;1^0?2`KP050?2`KP80BjKo
0P0KOm000`1;Y_l067;A01Qbd@0C01Qbd@0304^Vo`0HL]4067;A00D067;A00<0WgI90?^jL`3k^W<0
0P3k^W<00`2OMTT0oK]c09mfB@030?o6N@0?09mfB@3oaGP0WgI90?o7N@2OMTT0okad09mfB@3o_7<0
WgI90?o1M`2OMTT0ol=d09mfB@3o`W@0WgI900`078G]00<0BjKo01b5k@2OMTT0J02Id>D10?ooo`00
N02Id>D309mfB@0405=0<02OMTT0WgI909aeCP80WgI93P0IM=D00`1;Y_l06GCE01Ude@0801Ude@03
09mfB@2lSE`0_8eL0080_8eL00<0WgI90<bGH@3<Uf40103<Uf401@2OMTT0cIMQ0<fGH@3=Uf40WgI9
00@0_XiL0P2OMTT50<FAGP80WgI91`3BVV<0102OMTT07HO`01f7l01;Y_lB01f7l00304^Vo`0>@X@0
3T:400P03T:400<0BjKo09mfB@3LXfL01P3LXfL00`2OMTT0iZU[09mfB@060>R[J`80WgI91@3Y[6`0
0`2OMTT0gZ=W0=jSI`020=jSI`0309mfB@3TZ6X0WgI900D0hjIY00<0WgI90?2`KP3`/6h01@3`/6h2
04^Vo`806go@00<0BjKo01Qbd@0HL]404`0HL]400`1;Y_l067;A01Qbd@0401Qbd@0309mfB@3k^W<0
nkYc00<0nkYc0P2OMTT40?o6N@80WgI900@0olMi09mfB@3o_7@0okad0P2OMTT20?o1M`0509mfB@3o
`g@0WgI90?o2M02OMTT0300LQNd00`1;Y_l0WgI909W@i@1X09W@i@40oooo001i09W@i@<0WgI900@0
Dd0`09mfB@2OMTT0W7E>0P2OMTT=01Ude@0304^Vo`0IM=D06GCE00T06GCE00@0WgI90;b=G02lSE`0
_8eL0P2OMTT50<bGH@0309mfB@3=Uf40cIMQ0080cIMQ00<0WgI90;j>G02nSU`00P2nSU`00`2OMTT0
aI5N0<FAGP040<FAGP0309mfB@3BVV<0dYYS00D0dYYS00@0WgI901f7l00MQo00BjKo4P0MQo000`1;
Y_l03T:400i2Q00800i2Q00304^Vo`2OMTT0g:=W00H0g:=W00<0WgI90>JYJ`2OMTT01@3XZf/00`2O
MTT0jji]09mfB@050>V/K00309mfB@3NXfL0gZ=W0080gZ=W00<0WgI90>BXJP2OMTT0103SYVT209mf
B@L0l;1^0P1;Y_l201]od00304^Vo`0HL]4067;A01<067;A00<0BjKo01Qbd@0HL]40100HL]400`2O
MTT0nkYc0?^jL`020?^jL`80WgI9103oaWT209mfB@80olMi00@0WgI90?nlM02OMTT0WgI90P3o`GL0
1@2OMTT0ol=d09mfB@3o`W@0WgI900d078G]00<0BjKo09mfB@2Id>D0J02Id>D10?ooo`00N@2Id>D4
09mfB@0605=0<02OMTT0WgI909mfB@2WOE<0WgI9300IM=D00`1;Y_l06GCE01Ude@0901Ude@0309mf
B@2lSE`0_8eL0080_8eL00<0WgI90<bGH@3<Uf400`3<Uf400`2OMTT0cIMQ0<fGH@020<fGH@0309mf
B@2nSU`0_XiL0080_XiL0P2OMTT50<FAGP80WgI91`3BVV<00`2OMTT07HO`04^Vo`0B01f7l00304^V
o`0>@X@03T:400P03T:400<0BjKo09mfB@3LXfL01P3LXfL00`2OMTT0iZU[09mfB@050>R[J`80WgI9
1@3Y[6`00`2OMTT0gZ=W0=jSI`030=jSI`0309mfB@3TZ6X0WgI900@0hjIY00<0WgI90>R[K02OMTT0
1`3`/6h0101;Y_l06go@01]od01;Y_lE01Qbd@0304^Vo`0HL]4067;A00<067;A00<0WgI90?^jL`3k
^W<00`3k^W<00`2OMTT0olIi0?o6N@030?o6N@0409mfB@3oagT0olMi09mfB@80okad0P2OMTT20?o1
M`80WgI90P3o`W@00`2OMTT078G]01b5k@0;01b5k@0309mfB@2Id>D0VM3U06P0VM3U0@3oool007X0
VM3U1@2OMTT01@1_Ech0WgI909mfB@2WOE<0WgI900/06GCE00<0BjKo01Ude@0IM=D02@0IM=D00`2O
MTT0_8eL0;b=G0020;b=G00309mfB@3<Uf40c9MQ00<0c9MQ0P2OMTT40<fGH@0309mfB@2nSU`0_XiL
0080_XiL0P2OMTT40<FAGP0309mfB@3<Uf40WgI900L0dYYS00<0WgI904^Vo`0MQo004@0MQo000`1;
Y_l03T:400i2Q00800i2Q00309mfB@3LXfL0g:=W00D0g:=W00@0WgI90>JYJ`3VZF/0WgI9103XZf/0
0`2OMTT0jji]09mfB@050>V/K00309mfB@3NXfL0gZ=W00<0gZ=W00<0WgI90>BXJP2OMTT0103SYVT0
0`2OMTT0j:]/09mfB@070?2`KP0404^Vo`0KOm006go@04^VoaD067;A00<0BjKo01Qbd@0HL]400P0H
L]400`2OMTT0nkYc0?^jL`030?^jL`80WgI9103oaWT209mfB@040?o7N@2OMTT0okad0?nlM080WgI9
0`3o`GL209mfB@030?o2M02OMTT078G]00`078G]00<0WgI909W@i@2Id>D0J@2Id>D10?ooo`00N`2I
d>D309mfB@0305=0<02OMTT0KeLn0080WgI900<0YgeC09mfB@0IM=D02@0IM=D00`1;Y_l06GCE01Ud
e@0901Ude@0309mfB@2lSE`0_8eL0080_8eL0P2OMTT50<bGH@0309mfB@3=Uf40cIMQ0080cIMQ00<0
WgI90;j>G02nSU`00P2nSU`209mfB@D0aI5N00<0WgI90<bGH@2OMTT01P3BVV<00`2OMTT0BjKo01f7
l00A01f7l00304^Vo`0>@X@03T:400P03T:400<0WgI90=bSI`3LXfL01@3LXfL0102OMTT0iZU[0>JY
J`2OMTT40>R[J`0309mfB@3[[Vd0WgI900D0jJa/00<0WgI90=jSI`3NXfL00`3NXfL00`2OMTT0i:QZ
09mfB@040>>VJ@0309mfB@3XZf`0WgI900L0l;1^00@0BjKo01]od00KOm00BjKo5@0HL]401@1;Y_l0
67;A01Qbd@0HL]40WgI900H0nkYc00<0WgI90?o6N@3oaWT00`3oaWT0102OMTT0olMi0?o7N@2OMTT2
0?nlM080WgI90P3o`GL209mfB@80ol9d00<0WgI901b5k@0LQNd02P0LQNd209mfBF/0VM3U0@3oool0
07`0VM3U0`2OMTT01P1C@300WgI909mfB@2OMTT0YgeC09mfB@X06GCE00<0BjKo01Ude@0IM=D02@0I
M=D00`2OMTT0_8eL0;b=G0030;b=G00309mfB@3<Uf40c9MQ00<0c9MQ0P2OMTT40<fGH@0709mfB@2n
SU`0_XiL0;j>G02OMTT0aY=O09mfB@040<FAGP0309mfB@3<Uf40WgI900L0dYYS00<0WgI901f7l00M
Qo00400MQo000`1;Y_l03T:400i2Q00800i2Q00309mfB@3LXfL0g:=W00@0g:=W00D0WgI90>JYJ`3V
ZF/0iZU[09mfB@040>R[J`0309mfB@3[[Vd0WgI900D0jJa/00<0WgI90=jSI`3NXfL00`3NXfL00`2O
MTT0i:QZ09mfB@040>>VJ@0309mfB@3XZf`0WgI900L0l;1^00@0BjKo01]od00KOm00BjKo5@0HL]40
101;Y_l067;A01Qbd@2OMTT60?^jL`0309mfB@3oaWT0olIi00<0olIi00@0WgI90?o7N@3oagT0WgI9
0`3o_7@01@2OMTT0ol5g0?o1M`3o`GL0WgI900<0ol9d00<0WgI901b5k@0LQNd02P0LQNd00`2OMTT0
VM3U09W@i@1Z09W@i@40oooo001l09W@i@D0WgI900D0KeLn09mfB@2OMTT0YgeC09mfB@0901Ude@03
04^Vo`0IM=D06GCE00X06GCE00<0WgI90;b=G02lSE`00P2lSE`209mfB@@0c9MQ0P2OMTT40<fGH@03
09mfB@2nSU`0_XiL0080_XiL00<0WgI90<JCG`2OMTT00`35TEh0102OMTT0c9MQ0<bGH@2OMTT60=:J
H`80WgI94@0MQo000`1;Y_l03T:400i2Q00700i2Q080WgI91P3LXfL01@2OMTT0iZU[0>JYJ`3VZF/0
WgI900<0j:][00@0WgI90>^^K@3[[Vd0WgI91@3Y[6`00`2OMTT0gZ=W0=jSI`020=jSI`0409mfB@3T
Z6X0i:QZ09mfB@<0hjIY00@0WgI90>R[K03XZf`0WgI91`3`/6h0101;Y_l06go@01]od01;Y_lE01Qb
d@0304^Vo`0HL]40WgI900H0nkYc0P2OMTT40?o6N@0509mfB@3oagT0olMi0?o7N@2OMTT00P3o_7@2
09mfB@80ol5g0P2OMTT20?o2M00309mfB@0LQNd078G]00X078G]00<0WgI909W@i@2Id>D0J`2Id>D1
0?ooo`00O@2Id>D509mfB@0506mG?P2OMTT0WgI90:MmD`2OMTT0200IM=D00`1;Y_l06GCE01Ude@0:
01Ude@0309mfB@2lSE`0_8eL0080_8eL0P2OMTT40<bGH@0309mfB@3@VV<0WgI900<0cIMQ00<0WgI9
0;j>G02nSU`00P2nSU`00`2OMTT0aY=O09mfB@040<FAGP0409mfB@3<Uf40c9MQ09mfB@H0dYYS0P2O
MTT@01f7l00304^Vo`0>@X@03T:400L03T:40P2OMTT60=bSI`0509mfB@3VZF/0iZU[0>JYJ`2OMTT0
0`3XZf/0102OMTT0jji]0>^^K@2OMTT50>V/K00309mfB@3NXfL0gZ=W0080gZ=W00@0WgI90>BXJP3T
Z6X0WgI90`3SYVT0102OMTT0j:]/0>R[K02OMTT70?2`KP0409mfB@0KOm006go@04^VoaD067;A00<0
BjKo01Qbd@2OMTT01@3k^W<209mfB@@0olIi0P2OMTT20?o7N@0509mfB@3o_7@0okad0?nlM02OMTT0
0`3o`GL01@2OMTT0ol9d0?o2M03o`W@0WgI900/078G]0P2OMTU]09W@i@40oooo001n09W@i@D0WgI9
00D0KeLn09mfB@2WOE<0YgeC09mfB@0701Ude@0304^Vo`0IM=D06GCE00X06GCE00<0WgI90;b=G02l
SE`00P2lSE`00`2OMTT0bYIQ09mfB@040<bGH@80WgI9103=Uf400`2OMTT0_XiL0;j>G0020;j>G003
09mfB@36Tel0WgI900<0aI5N00D0WgI90<bGH@3<Uf40c9MQ09mfB@050=:JH`0309mfB@3FWF@07HO`
00l07HO`00<0BjKo00i2Q00>@X@01P0>@X@00`2OMTT0fZ9W09mfB@050=bSI`0309mfB@3VZF/0iZU[
0080iZU[00D0WgI90>R[J`3XZf/0j:][09mfB@020>^^K@0309mfB@3Y[6`0jJa/0080jJa/0P2OMTT4
0=jSI`0509mfB@3TZ6X0i:QZ0>BXJP2OMTT00P3SYVT01@2OMTT0j:]/0>R[K03XZf`0WgI900D0l;1^
0P2OMTT201]od00304^Vo`0HL]4067;A01<067;A00<0BjKo09mfB@3k^W<0103k^W<00`2OMTT0ol=h
09mfB@030?o6N@80WgI90`3oagT00`2OMTT0okad0?nlM00209mfB@80ol5g0P2OMTT20?o2M00309mf
B@0LQNd078G]00T078G]0P2OMTU^09W@i@40oooo001n09W@i@H0WgI900D0KeLn09mfB@2WOE<0YgeC
09mfB@0601Ude@0304^Vo`0IM=D06GCE00X06GCE00<0WgI90;b=G02lSE`00`2lSE`209mfB@@0c9MQ
00<0WgI90=2JH`2OMTT00`3=Uf400`2OMTT0_XiL0;j>G0020;j>G00409mfB@36Tel0aY=O09mfB@80
aI5N00D0WgI90<bGH@3<Uf40c9MQ09mfB@050=:JH`0309mfB@3FWF@0WgI900l07HO`00<0BjKo00i2
Q00>@X@01P0>@X@00`2OMTT0fZ9W09mfB@050=bSI`0309mfB@3VZF/0iZU[0080iZU[00@0WgI90>R[
J`3XZf/0WgI90`3[[Vd00`2OMTT0jJa/0>V/K0020>V/K080WgI9103NXfL01@2OMTT0i:QZ0>BXJP3T
Z6X0WgI90080hjIY00D0WgI90>R[K03XZf`0j:]/09mfB@050?2`KP80WgI90P0KOm000`1;Y_l067;A
01Qbd@0C01Qbd@0309mfB@3k^W<0nkYc00<0nkYc00<0WgI90?o3N02OMTT0103oaWT209mfB@80olMi
00D0WgI90?nlM03o_7@0okad09mfB@030?o1M`0509mfB@3o`W@0ol9d0?o2M02OMTT02`0LQNd00`2O
MTT0VM3U09W@i@1]09W@i@40oooo001o09W@i@<0WgI900D0FDHd09mfB@1_Ech0KeLn09mfB@020:Mm
D`0309mfB@0IM=D06GCE00<06GCE00<0BjKo01Ude@0IM=D02`0IM=D00`2OMTT0_8eL0;b=G0020;b=
G00309mfB@3:UV40WgI900<0c9MQ00<0WgI90=2JH`2OMTT0103=Uf400`2OMTT0_XiL0;j>G0020;j>
G00309mfB@36Tel0WgI900<0aI5N00D0WgI90<bGH@3<Uf40c9MQ09mfB@040=:JH`0409mfB@3FWF@0
eYeT09mfB@h07HO`00<0BjKo00i2Q00>@X@01@0>@X@0102OMTT0fZ9W0=ZRI`2OMTT40=bSI`0309mf
B@3VZF/0iZU[00<0iZU[00@0WgI90>R[J`3XZf/0WgI90`3[[Vd01P2OMTT0jJa/0>V/K03Y[6`0WgI9
0>f_KP80WgI90`3NXfL01@2OMTT0i:QZ0>BXJP3TZ6X0WgI90080hjIY00D0WgI90>R[K03XZf`0j:]/
09mfB@050?2`KP80WgI90P0KOm000`1;Y_l067;A01Qbd@0B01Qbd@0309mfB@3k^W<0nkYc00@0nkYc
00<0WgI90?o3N02OMTT00`3oaWT209mfB@80olMi00@0WgI90?nlM03o_7@0okad0P2OMTT20?o1M`06
09mfB@3o`W@0ol9d0?o2M02OMTT0BjKo2P0LQNd209mfBFl0VM3U0@3oool00800VM3U1@2OMTT00`1_
Ech0WgI909mfB@020:MmD`0309mfB@0IM=D06GCE00806GCE00<0BjKo01Ude@0IM=D02`0IM=D00`2O
MTT0_8eL0;b=G0020;b=G00309mfB@3:UV40WgI900<0c9MQ00@0WgI90=2JH`3@VV<0WgI90`3=Uf40
0`2OMTT0_XiL0;j>G0020;j>G00409mfB@36Tel0aY=O09mfB@80aI5N00<0WgI90<bGH@3<Uf400P3<
Uf400`2OMTT0dYYS0=:JH`020=:JH`0409mfB@3FWF@0eYeT09mfB@d07HO`00<0BjKo00i2Q00>@X@0
1@0>@X@0102OMTT0fZ9W0=ZRI`2OMTT40=bSI`0309mfB@3VZF/0iZU[00<0iZU[00@0WgI90>R[J`3X
Zf/0WgI90`3[[Vd0102OMTT0jJa/0>V/K03Y[6`209mfB@030=nUJ02OMTT0gZ=W0080gZ=W00D0WgI9
0>BXJP3TZ6X0i:QZ09mfB@020>>VJ@0509mfB@3XZf`0j:]/0>R[K02OMTT0103`/6h01P2OMTT0l[=`
0?:cL02OMTT06go@04^Voa<067;A0P2OMTT50?^jL`0309mfB@3o`gP0WgI900<0olIi0P2OMTT30?o7
N@0309mfB@3o_7@0okad0080WgI90`3o`GL01P2OMTT0ol9d0?o2M03o`W@0WgI904^Vo`T078G]0P2O
MTU`09W@i@40oooo002009W@i@H0WgI900<0KeLn09mfB@2WOE<00P2WOE<01@2OMTT06GCE01Ude@0I
M=D0BjKo00d06GCE00<0WgI90;b=G02lSE`00`2lSE`00`2OMTT0bYIQ09mfB@020<bGH@0409mfB@3@
VV<0d9YS09mfB@<0cIMQ0P2OMTT30;j>G00709mfB@36Tel0aY=O0<JCG`2OMTT0aI5N09mfB@050<bG
H@0509mfB@3BVV<0dYYS0=:JH`2OMTT00`3FWF@00`2OMTT07HO`01f7l00:01f7l00304^Vo`0>@X@0
3T:400@03T:400D0WgI90=ZRI`3JXVL0fZ9W09mfB@040=bSI`0309mfB@3VZF/0iZU[00<0iZU[00<0
WgI90>R[J`2OMTT0103[[Vd0202OMTT0jJa/0>V/K02OMTT0kJm^09mfB@3OYFP0WgI90P3NXfL00`2O
MTT0i:QZ0>BXJP020>BXJP0309mfB@3SYVT0WgI900@0j:]/00<0WgI90?2`KP3`/6h00P3`/6h01P2O
MTT0l[=`0?:cL02OMTT06go@04^Voa8067;A0P2OMTT50?^jL`0409mfB@3o`gP0ol=h09mfB@80olIi
00<0WgI90?o7NP2OMTT00P3oagT0102OMTT0okad0?nlM03o_7@209mfB@80ol5g00<0WgI90?o2M03o
`W@00P3o`W@00`2OMTT0BjKo01b5k@0701b5k@80WgI9L@2Id>D10?ooo`00P@2Id>D209mfB@0309Ab
C@2OMTT0WgI90080KeLn00@0WgI90:MmD`2WOE<0WgI90`0IM=D00`1;Y_l06GCE01Ude@0;01Ude@80
WgI9102lSE`00`2OMTT0bYIQ09mfB@030<bGH@0409mfB@3@VV<0d9YS09mfB@80cIMQ0`2OMTT30;j>
G00409mfB@36Tel0aY=O09mfB@80aI5N00<0WgI90<bGH@3<Uf400P3<Uf401@2OMTT0dYYS0=:JH`3B
VV<0WgI900@0eYeT00<0WgI901f7l00MQo002@0MQo000`1;Y_l03T:400i2Q00400i2Q00309mfB@3J
XVL0fZ9W0080fZ9W00@0WgI90=bSI`3LXfL0WgI91P3VZF/00`2OMTT0j:][09mfB@040>^^K@0809mf
B@3Y[6`0jJa/09mfB@3][fh0WgI90=nUJ02OMTT20=jSI`0309mfB@3TZ6X0i:QZ0080i:QZ00<0WgI9
0>>VJ@2OMTT0103XZf`00`2OMTT0l;1^0?2`KP020?2`KP0609mfB@3b/g00l[=`09mfB@0KOm00BjKo
4@0HL]400`2OMTT0m[Mb09mfB@040?^jL`0409mfB@3o`gP0ol=h09mfB@80olIi00<0WgI90?o7NP2O
MTT00`3oagT00`2OMTT0okad0?nlM00209mfB@80ol5g0P2OMTT30?o2M00309mfB@0LQNd0BjKo00L0
78G]0P2OMTUb09W@i@40oooo002209W@i@<0WgI900D0FDHd09mfB@1_Ech0KeLn09mfB@020:MmD`04
09mfB@0IM=D06GCE04^Vo`h06GCE00<0WgI90;b=G02lSE`00P2lSE`0102OMTT0bYIQ0<ZFH@2OMTT2
0<bGH@0409mfB@3@VV<0d9YS09mfB@80cIMQ0`2OMTT30;j>G00709mfB@36Tel0aY=O0<JCG`2OMTT0
aI5N09mfB@050<bGH@0509mfB@3BVV<0dYYS0=:JH`2OMTT00`3FWF@00`2OMTT07HO`01f7l00901f7
l00304^Vo`0>@X@03T:400<03T:400<0WgI90=ZRI`3JXVL00`3JXVL0102OMTT0g:=W0=bSI`2OMTT6
0>JYJ`80WgI9103[[Vd0102OMTT0jJa/0>V/K02OMTT20>f_KP0309mfB@3OYFP0WgI90080gZ=W00<0
WgI90>BXJP3TZ6X00P3TZ6X00`2OMTT0hjIY09mfB@050>R[K00409mfB@3`/6h0l;1^09mfB@<0l[=`
00<0WgI901]od01;Y_l0400HL]400`2OMTT0m[Mb09mfB@040?^jL`0409mfB@3o`gP0ol=h09mfB@80
olIi00@0WgI90?o7NP3oagX0WgI90P3oagT0102OMTT0okad0?nlM03o_7@209mfB@80ol5g00<0WgI9
0?o2M03o`W@00P3o`W@00`2OMTT078G]04^Vo`0701b5k@80WgI9LP2Id>D10?ooo`00P`2Id>D309mf
B@0505U6=02OMTT0KeLn06mG?P2OMTT00P2WOE<00`2OMTT06GCE04^Vo`0>01Ude@80WgI90`2lSE`0
1`2OMTT0bYIQ0<ZFH@3:UV40WgI90<bGH@2OMTT00`3@VV<00`2OMTT0cIMQ0<fGH@0309mfB@<0_XiL
00@0WgI90<JCG`36Tel0aY=O0P2OMTT60<bGH@0409mfB@3BVV<0dYYS09mfB@@0eYeT00<0WgI901f7
l00MQo00200MQo000`1;Y_l03T:400i2Q00300i2Q00309mfB@3JXVL0fZ9W00<0fZ9W00<0WgI90=bS
I`2OMTT01`3VZF/209mfB@@0jji]00@0WgI90>V/K03Y[6`0WgI90P3][fh01P2OMTT0gjEX0=nUJ02O
MTT0gZ=W09mfB@@0i:QZ00<0WgI90>>VJ@2OMTT01@3XZf`0102OMTT0l;1^0?2`KP2OMTT30?:cL003
09mfB@0KOm00BjKo00l067;A00@0WgI90?JgLP3f]g80WgI90`3k^W<01@2OMTT0ol=h0?o3N03o`gP0
WgI90080olIi00<0WgI90?o7NP2OMTT00`3oagT00`2OMTT0okad0?nlM00209mfB@80ol5g0P2OMTT3
0?o2M00409mfB@0LQNd078G]04^Vo`H078G]0P2OMTUc09W@i@40oooo002309W@i@80WgI900D0U79=
09mfB@1IAS@0WgI906mG?P0209mfB@80YgeC00<0WgI904^Vo`0IM=D03@0IM=D00`2OMTT0^8]K09mf
B@030;b=G00609mfB@3:UV40bYIQ09mfB@3<Uf40WgI90`3@VV<00`2OMTT0cIMQ0<fGH@0209mfB@05
0<6@GP2OMTT0_XiL0;j>G02OMTT00`36Tel00`2OMTT0aI5N09mfB@060<bGH@0309mfB@3BVV<0WgI9
00D0eYeT00<0WgI901f7l00MQo001`0MQo000`1;Y_l03T:400i2Q00200i2Q00309mfB@3JXVL0fZ9W
00@0fZ9W00<0WgI90=bSI`2OMTT01`3VZF/209mfB@@0jji]00<0WgI90>V/K02OMTT00`3][fh01P2O
MTT0gjEX0=nUJ02OMTT0gZ=W09mfB@D0i:QZ0P2OMTT50>R[K00409mfB@3`/6h0l;1^09mfB@<0l[=`
00<0WgI901]od01;Y_l03P0HL]40102OMTT0m[Mb0?JgLP2OMTT30?^jL`0509mfB@3o`gP0ol=h0?o3
N02OMTT00P3oaWT00`2OMTT0olMj09mfB@030?o7N@0709mfB@3o_7@0okad09mfB@3o`WL0WgI90?o1
M`0209mfB@@0ol9d00@0WgI901b5k@0LQNd0BjKo1@0LQNd209mfBG@0VM3U0@3oool008@0VM3U0P2O
MTT01@2DLTd0WgI909mfB@2OMTT0KeLn0080WgI90P2WOE<00`2OMTT06GCE01Ude@0<01Ude@0309mf
B@2hRe/0WgI900<0_8eL00L0WgI90<ZFH@3:UV40bYIQ09mfB@3<Uf40WgI900<0d9YS00T0WgI90<fG
H@2OMTT0dY]T09mfB@31T5h0WgI90;j>G02OMTT01036Tel209mfB@H0c9MQ00@0WgI90=:JH`3BVV<0
WgI91@3FWF@00`2OMTT07HO`01f7l00601f7l00304^Vo`0>@X@03T:400803T:400<0WgI90=ZRI`3J
XVL0103JXVL00`2OMTT0g:=W09mfB@070>JYJ`0309mfB@3[[Vd0jji]00<0jji]00<0WgI90>V/K02O
MTT00P3][fh01`2OMTT0gjEX0=nUJ03OYFP0WgI90=jSI`2OMTT01@3TZ6X00`2OMTT0j:]/0>R[K004
0>R[K00409mfB@3`/6h0l;1^09mfB@<0l[=`00<0WgI901]od01;Y_l03@0HL]401@2OMTT0m[Mb0?Jg
LP3f]g80WgI90080nkYc00<0WgI90?o3N03o`gP00P3o`gP00`2OMTT0olIi09mfB@020?o7NP0309mf
B@3oagT0olMi0080WgI90P3o_7@209mfB@80ol5g0P2OMTT30?o2M00509mfB@0LQNd078G]01b5k@1;
Y_l0100LQNd00`2OMTT0fZMS09mfB@1d09W@i@40oooo002509W@i@<0WgI900@0FDHd09mfB@2OMTT0
KeLn0P2OMTT20:MmD`0309mfB@0IM=D06GCE00`06GCE00<0WgI90;R;F`2OMTT00P2lSE`01`2OMTT0
bYIQ0<ZFH@3:UV40WgI90<bGH@2OMTT00`3@VV<01@2OMTT0cIMQ09mfB@3BVf@0WgI90080`I1N00<0
WgI90;j>G02OMTT01036Tel00`2OMTT0c9MQ0<bGH@050<bGH@0309mfB@3BVV<0WgI900H0eYeT00<0
WgI901f7l00MQo001@0MQo000`1;Y_l03T:400i2Q00200i2Q00309mfB@3JXVL0fZ9W00@0fZ9W0P2O
MTT80>JYJ`0309mfB@3[[Vd0jji]00<0jji]0P2OMTT30>f_KP0409mfB@3OYFP0gjEX0=nUJ080WgI9
1P3TZ6X00`2OMTT0j:]/0>R[K0040>R[K00309mfB@3`/6h0WgI900@0l[=`00<0WgI901]od01;Y_l0
300HL]401@2OMTT0m[Mb0?JgLP3f]g80WgI90080nkYc00<0WgI90?o3N03o`gP00P3o`gP00`2OMTT0
olIi09mfB@020?o7NP0309mfB@3oagT0olMi0080WgI90P3o_7@0102OMTT0ol9g09mfB@3o`GL209mf
B@@0ol9d00D0WgI901b5k@0LQNd078G]04^Vo`0401b5k@80WgI9M@2Id>D10?ooo`00Q@2Id>D409mf
B@0405U6=02OMTT0WgI906mG?P80WgI900<0YgeC09mfB@2OMTT03@0IM=D0102OMTT0^8]K0;R;F`2O
MTT20;b=G00409mfB@3:UV40bYIQ0<ZFH@80WgI9103@VV<209mfB@80dY]T00<0WgI90<6@GP31T5h0
0P2OMTT40<JCG`80WgI91`3<Uf4209mfB@L0eYeT00<0WgI901f7l00MQo00100MQo001@1;Y_l03T:4
00i2Q00>@X@0WgI900L0fZ9W0P2OMTT70>JYJ`80WgI91@3[[Vd209mfB@<0kJm^00<0WgI90=nUJ03O
YFP00P3OYFP00`2OMTT0i:QZ0>BXJP040>BXJP0309mfB@3XZf`0j:]/00@0j:]/00<0WgI90?2`KP2O
MTT01@3b/g000`2OMTT0BjKo01Qbd@0:01Qbd@0309mfB@3f]g80m[Mb0080m[Mb00<0WgI90?^jL`2O
MTT01@3o`gP209mfB@<0olMj00<0WgI90?o7N@2OMTT00P2OMTT0203o_7@0WgI90?o2M`2OMTT0ol5g
09mfB@3oaWT0WgI90`3o`W@00`2OMTT078G]01b5k@0201b5k@0404^Vo`0LQNd078G]01b5k@80WgI9
MP2Id>D10?ooo`00QP2Id>D409mfB@0705U6=02OMTT0WgI909mfB@2?Kd/0WgI90:MmD`0209mfB@`0
6GCE00@0WgI90;R;F`2hRe/0WgI90P2lSE`0102OMTT0bYIQ0<ZFH@3:UV4209mfB@@0d9YS0P2OMTT2
0=:KI00609mfB@31T5h0`I1N09mfB@2nSU`0WgI91036Tel00`2OMTT0c9MQ0<bGH@060<bGH@0309mf
B@3FWF@0eYeT00D0eYeT00<0WgI901f7l00MQo00100MQo001@1;Y_l03T:400i2Q00>@X@0WgI900L0
fZ9W00<0WgI90>JYJ`3VZF/01P3VZF/209mfB@D0jji]00<0WgI90>f_KP3][fh00P3][fh00`2OMTT0
gjEX0=nUJ0020=nUJ00309mfB@3TZ6X0i:QZ00@0i:QZ00<0WgI90>R[K03XZf`01@3XZf`209mfB@D0
l[=`00<0WgI904^Vo`0HL]402@0HL]400`2OMTT0m[Mb0?JgLP020?JgLP0409mfB@3k^W<0nkYc09mf
B@@0ol=h0P2OMTT30?o7NP0309mfB@3oagT0WgI90080WgI90P3o_7@01P2OMTT0ol9g09mfB@2OMTT0
olIi09mfB@<0ol9d0P2OMTT401b5k@0604^Vo`0LQNd078G]09mfB@3JYf<0WgI9MP2Id>D10?ooo`00
Q`2Id>D209mfB@0309AbC@2OMTT0FDHd00<0WgI900<0Sfm;09mfB@2WOE<00P2OMTT<01Ude@0609mf
B@2hRe/0^8]K09mfB@2lSE`0WgI9103:UV4209mfB@@0d9YS0P2OMTT20=:KI00309mfB@31T5h0`I1N
0080WgI91036Tel209mfB@L0c9MQ0P2OMTT70=JMI00309mfB@0MQo007HO`00<07HO`00@0BjKo00i2
Q00>@X@0WgI9203JXVL00`2OMTT0iZU[0>JYJ`050>JYJ`0309mfB@3X[6d0WgI900D0jji]00<0WgI9
0>f_KP3][fh00P3][fh00`2OMTT0gjEX0=nUJ0020=nUJ00309mfB@3TZ6X0i:QZ00<0i:QZ0P2OMTT7
0>R[K00309mfB@3b/g00l[=`00@0l[=`00<0WgI904^Vo`0HL]40200HL]400`2OMTT0m[Mb0?JgLP03
0?JgLP0309mfB@3k^W<0WgI900D0ol=h0P2OMTT30?o7NP80WgI900/0olQj09mfB@2OMTT0okad09mf
B@3o`WL0WgI90?o1M`2OMTT0olIi09mfB@020?o2M080WgI91@0LQNd01@1;Y_l078G]09mfB@3JYf<0
WgI907L0VM3U0@3oool008L0VM3U102OMTT00`1IAS@0WgI907=L@@0209mfB@0308m_B`2OMTT0YgeC
00<0WgI92P0IM=D01`2OMTT0^8]K0;R;F`2hRe/0WgI90;b=G02OMTT00`3:UV4209mfB@@0d9YS0P2O
MTT20=:KI00409mfB@31T5h0`I1N0<6@GP80WgI91036Tel209mfB@L0c9MQ00<0WgI90=JMI03FWF@0
1P3FWF@00`2OMTT07HO`01f7l00201f7l00404^Vo`0>@X@03T:409mfB@L0fZ9W0P2OMTT70>JYJ`03
09mfB@3X[6d0WgI900@0jji]0P2OMTT40>f_KP0309mfB@3OYFP0gjEX0080gjEX00<0WgI90>BXJP3T
Z6X00`3TZ6X209mfB@L0j:]/00<0WgI90?:cL03b/g00103b/g000`2OMTT0BjKo01Qbd@0701Qbd@03
09mfB@3f]g80m[Mb00<0m[Mb00<0WgI90?^jL`2OMTT01@3o`gP209mfB@<0olMj00D0WgI90?o7N@2O
MTT0WgI90?jlM@0209mfB@80ol9g0P2OMTT00`3oaWT0WgI90?o2M0020?o2M080WgI91@0LQNd0101;
Y_l078G]09mfB@2OMTUh09W@i@40oooo002809W@i@@0WgI900@0FDHd09mfB@2OMTT0KeLn0P2OMTT0
1@2WOE<0WgI90:j3E`2^PeL0WgI900T06GCE00L0WgI90;R;F`2hRe/0^8]K09mfB@2lSE`0WgI900@0
bYIQ00<0WgI90=2JH`3@VV<00`3@VV<0102OMTT0dY]T0=:KI02OMTT40<6@GP0309mfB@36Tel0aY=O
0080aY=O00<0WgI90<jIH`2OMTT01P3<Uf4209mfB@P0eYeT00L0WgI901f7l00MQo007HO`04^Vo`0>
@X@0WgI900P0fZ9W0P2OMTT60>JYJ`0409mfB@3X[6d0j:a]09mfB@@0jji]0P2OMTT30>f_KP0309mf
B@3OYFP0gjEX00<0gjEX00<0WgI90>BXJP3TZ6X00`3TZ6X00`2OMTT0jJe]09mfB@060>R[K00309mf
B@3b/g00l[=`00@0l[=`00<0WgI904^Vo`0HL]401P0HL]400`2OMTT0m[Mb0?JgLP040?JgLP80WgI9
1P3o`gP01P2OMTT0olMj0?o7NP3oagX0WgI90?o7N@80WgI900D0o[ae09mfB@3o_7@0WgI90?o2M`02
09mfB@80olIi00<0WgI90?o2M03o`W@00P2OMTT601b5k@0304^Vo`2OMTT0WgI907T0VM3U0@3oool0
08T0VM3U102OMTT0101IAS@0WgI909mfB@1_Ech209mfB@050:MmD`2OMTT0[X=G0:j3E`2OMTT0200I
M=D00`2OMTT0^8]K0;R;F`020;R;F`80WgI9103:UV4209mfB@@0d9YS00D0WgI90=:KI03BVf@0dY]T
09mfB@040<6@GP0309mfB@36Tel0aY=O0080aY=O00<0WgI90<jIH`2OMTT01P3<Uf4209mfB@P0eYeT
00H0WgI901f7l00MQo00BjKo00i2Q02OMTT70=ZRI`0309mfB@3OYVT0WgI900H0iZU[00@0WgI90>R/
K@3X[6d0WgI90`3[[Vd00`2OMTT0kk5_09mfB@030>f_KP0309mfB@3OYFP0gjEX0080gjEX0P2OMTT5
0>BXJP0309mfB@3Y[Fd0WgI900D0j:]/00<0WgI90>n`K`2OMTT01@3b/g000`2OMTT0BjKo01Qbd@05
01Qbd@0309mfB@3f]g80m[Mb00@0m[Mb0P2OMTT60?o3N00309mfB@3oagX0olMj0080olMj0P2OMTT0
0`3ob7X0WgI90?jlM@0209mfB@80ol9g0P2OMTT0103oaWT0WgI90?o2M03o`W@209mfB@L078G]0P2O
MTUj09W@i@40oooo002:09W@i@05054o;`2OMTT0WgI909mfB@1IAS@00`2OMTT0102?Kd/0WgI90:Mm
D`2OMTT20:j3E`0309mfB@0IM=D06GCE00H06GCE00<0WgI90;R;F`2hRe/00P2hRe/00`2OMTT0bYIQ
0<ZFH@030<ZFH@0309mfB@3@VV<0d9YS0080d9YS0P2OMTT20=:KI00309mfB@31T5h0`I1N0080`I1N
0P2OMTT30<JCG`0309mfB@3>VF<0WgI900H0c9MQ00<0WgI90=>MI02OMTT0203FWF@0102OMTT07HO`
04^Vo`2OMTT70=ZRI`0409mfB@3OYVT0gjIY09mfB@D0iZU[00D0WgI90>R/K@3X[6d0j:a]09mfB@03
0>^^K@0309mfB@3_/Fl0WgI900<0kJm^00<0WgI90=nUJ03OYFP00P3OYFP00`2OMTT0iJU[09mfB@03
0>BXJP0409mfB@3Y[Fd0jJe]09mfB@D0j:]/00<0WgI90>n`K`2OMTT01@3b/g000`2OMTT0BjKo01Qb
d@0401Qbd@0309mfB@3f]g80m[Mb00D0m[Mb00<0WgI90?o3N03o`gP0103o`gP00`2OMTT0olMj0?o7
NP020?o7NP80WgI900@0olQj09mfB@3n_7D0o[ae0P2OMTT00`3o`WL0WgI909mfB@020?o6N@0509mf
B@3o`W@0WgI90?o5MP2OMTT01P0LQNd209mfBG/0VM3U0@3oool008X0VM3U00<0WgI9054o;`2OMTT0
0P2OMTT0201IAS@0WgI909mfB@2OMTT0Sfm;09mfB@2WOE<0WgI90P2^PeL00`2OMTT06GCE01Ude@05
01Ude@0309mfB@2hRe/0^8]K0080^8]K0P2OMTT40<ZFH@80WgI90`3@VV<209mfB@<0dY]T00@0WgI9
0<6@GP31T5h0`I1N0P2OMTT40<JCG`0309mfB@3>VF<0WgI900D0c9MQ00<0WgI90=>MI03CWF@00P2O
MTT60=JMI00409mfB@0MQo00BjKo09mfB@L0fZ9W00@0WgI90=nVJ@3OYVT0WgI91@3VZF/01@2OMTT0
j:a]0>R/K@3X[6d0WgI90080jji]00<0WgI90>naK`2OMTT0103][fh00`2OMTT0gjEX0=nUJ0020=nU
J00309mfB@3UZF/0WgI900<0i:QZ00@0WgI90>V]K@3Y[Fd0WgI91@3XZf`00`2OMTT0kk1_09mfB@05
0?:cL00309mfB@1;Y_l067;A00<067;A00<0WgI90?JgLP3f]g801@3f]g800`2OMTT0ol=h0?o3N004
0?o3N080WgI9103oagX00`2OMTT0olQj09mfB@020?jlM@80WgI90P3o`WL0202OMTT0olIi0?o6N@2O
MTT0ol9d09mfB@3oaGH0WgI91P0LQNd309mfBG/0VM3U0@3oool008/0VM3U1P2OMTT0101cG440WgI9
09mfB@2?Kd/209mfB@<0[X=G00<0WgI901Ude@0IM=D0100IM=D00`2OMTT0^8]K0;R;F`030;R;F`03
09mfB@3:UV40bYIQ0080bYIQ0P2OMTT40=2JH`80WgI90P3BVf@00`2OMTT0`I1N0<6@GP020<6@GP80
WgI90`36Tel0102OMTT0cYUS0<jIH`2OMTT50<bGH@0509mfB@3CWF@0dieT0=>MI02OMTT01P3FWF@2
09mfB@L0fZ9W00D0WgI90=nVJ@3OYVT0gjIY09mfB@040>JYJ`0509mfB@3X[6d0j:a]0>R/K@2OMTT0
0`3[[Vd00`2OMTT0kk5_09mfB@040>f_KP0309mfB@3OYFP0gjEX0080gjEX00<0WgI90>FYJ`2OMTT0
0`3TZ6X0102OMTT0jJe]0>V]K@2OMTT40>R[K00509mfB@3_/6l0kk1_0>n`K`2OMTT01@3b/g001@2O
MTT067;A01Qbd@0HL]40WgI900H0m[Mb0`2OMTT50?o3N080WgI9103oagX0102OMTT0olQj0?o8NP2O
MTT20?jlM@0309mfB@3o`WL0ol9g0080WgI90P3oaWT209mfB@80olEf00<0WgI901b5k@0LQNd00`0L
QNd309mfBG`0VM3U0@3oool008`0VM3U1P2OMTT0101cG440WgI909mfB@2?Kd/209mfB@<0[X=G00<0
WgI901Ude@0IM=D0100IM=D00`2OMTT0^8]K0;R;F`020;R;F`80WgI90`3:UV400`2OMTT0cYUS09mf
B@030=2JH`80WgI90`3BVf@01`2OMTT0`I1N0<6@GP31T5h0WgI90<RFH@2OMTT00`36Tel0102OMTT0
cYUS0<jIH`2OMTT40<bGH@0309mfB@3CWF@0dieT0080dieT00<0WgI90=JMI03FWF@0103FWF@00`2O
MTT0fZ9W0=ZRI`040=ZRI`0309mfB@3OYVT0gjIY0080gjIY00<0WgI90>JYJ`3VZF/00P3VZF/01@2O
MTT0j:a]0>R/K@3X[6d0WgI90080jji]00@0WgI90>naK`3_/Fl0WgI9103][fh00`2OMTT0gjEX0=nU
J0020=nUJ00309mfB@3UZF/0WgI90080i:QZ00D0WgI90>V]K@3Y[Fd0jJe]09mfB@040>R[K00509mf
B@3_/6l0kk1_0>n`K`2OMTT01@3b/g00102OMTT067;A01Qbd@2OMTT60?JgLP0309mfB@3k^g@0WgI9
00D0ol=h0P2OMTT40?o7NP0409mfB@3ob7X0olQj09mfB@80o[ae0P2OMTT20?o2M`0309mfB@3oaWT0
olIi0080WgI90P3oaGH00`2OMTT078G]01b5k@0301b5k@<0WgI9O@2Id>D10?ooo`00S@2Id>D609mf
B@0407=L@@2OMTT0Sfm;08m_B`80WgI90`2^PeL00`2OMTT06GCE01Ude@0301Ude@0309mfB@2hRe/0
^8]K0080^8]K0P2OMTT40<ZFH@0309mfB@3>VF<0WgI90080d9YS00<0WgI90=BMI@2OMTT00P3BVf@0
0`2OMTT0`I1N0<6@GP020<6@GP0309mfB@38UV40WgI90080aY=O00D0WgI90<jIH`3>VF<0cYUS09mf
B@030<bGH@0309mfB@3CWF@0dieT00<0dieT00<0WgI90=JMI03FWF@00`3FWF@00`2OMTT0fZ9W0=ZR
I`040=ZRI`0309mfB@3OYVT0gjIY00<0gjIY00@0WgI90>JYJ`3VZF/0WgI9103X[6d0102OMTT0jji]
0>^^K@2OMTT20>naK`0509mfB@3][fh0kJm^0>f_KP2OMTT0103OYFP0102OMTT0iJU[0>FYJ`2OMTT2
0>BXJP0309mfB@3Y[Fd0jJe]0080jJe]00D0WgI90>R[K03XZf`0j:]/09mfB@030>n`K`0309mfB@3b
/g00l[=`00<0l[=`00<0WgI901Qbd@2OMTT01P3f]g80102OMTT0nk]d0?^kM02OMTT40?o3N00309mf
B@3oa7T0WgI900<0olMj0P2OMTT20?o8NP0409mfB@3n_7D0o[ae09mfB@80ol9g00@0WgI90?o6N@3o
aWT0olIi0P2OMTT00`3oaGH0WgI901b5k@0401b5k@<0WgI9OP2Id>D10?ooo`00SP2Id>D609mfB@04
07=L@@2OMTT0Sfm;08m_B`80WgI90`2^PeL00`2OMTT06GCE01Ude@0201Ude@0309mfB@2hRe/0^8]K
00<0^8]K0P2OMTT30<ZFH@0309mfB@3>VF<0WgI90080d9YS00<0WgI90=BMI@2OMTT00`3BVf@01@2O
MTT0`I1N0<6@GP31T5h0WgI90080b9IQ00<0WgI90<JCG`2OMTT0103>VF<01@2OMTT0c9MQ0<bGH@3<
Uf40WgI900D0dieT00<0WgI90=JMI03FWF@00P3FWF@00`2OMTT0fZ9W0=ZRI`030=ZRI`0309mfB@3O
YVT0gjIY00@0gjIY00@0WgI90>JYJ`3VZF/0WgI9103X[6d0102OMTT0jji]0>^^K@2OMTT20>naK`05
09mfB@3][fh0kJm^0>f_KP2OMTT0103OYFP0102OMTT0iJU[0>FYJ`2OMTT20>BXJP0309mfB@3Y[Fd0
jJe]0080jJe]00@0WgI90>R[K03XZf`0WgI9103_/6l00`2OMTT0l[=`0?:cL0030?:cL080WgI91@3f
]g8209mfB@80nk]d00<0WgI90?o3N03o`gP00P3o`gP00`2OMTT0olAi09mfB@030?o7NP80WgI90P3o
b7X0102OMTT0o[ae0?jlM@2OMTT20?o2M`80WgI90P3oaWT209mfB@80olEf00<0WgI901b5k@0LQNd0
0P0LQNd309mfBGl0VM3U0@3oool008l0VM3U1P2OMTT01@1cG440WgI908m_B`2?Kd/0WgI900@0[X=G
0P2OMTT301Ude@0309mfB@2hRe/0^8]K0080^8]K00<0WgI90<6AG`2OMTT00P3:UV40102OMTT0cYUS
0<jIH`2OMTT20=2JH`0309mfB@3DWFD0WgI90080dY]T00<0WgI90<6@GP31T5h00P31T5h00`2OMTT0
b9IQ09mfB@020<JCG`0309mfB@3>VF<0cYUS0080cYUS00@0WgI90<bGH@3<Uf40WgI91P3CWF@00`2O
MTT0eYeT0=JMI0020=JMI00509mfB@3JXVL0fZ9W0=ZRI`2OMTT01`3OYVT00`2OMTT0iZU[09mfB@05
0>R/K@0309mfB@3[[Vd0WgI900<0kk5_00D0WgI90>f_KP3][fh0kJm^09mfB@040=nUJ00609mfB@3U
ZF/0iJU[09mfB@3TZ6X0WgI91@3Y[Fd0102OMTT0j:]/0>R[K02OMTT50>n`K`0309mfB@3b/g00l[=`
0080l[=`00<0WgI90?JgLP3f]g800`3f]g800`2OMTT0nk]d0?^kM0020?^kM00709mfB@3o`gP0ol=h
0?o3N02OMTT0olAi09mfB@030?o7NP80WgI90P3ob7X00`2OMTT0o[ae0?jlM@0209mfB@80ol9g00D0
WgI90?o6N@3oaWT0olIi09mfB@020?o5MP0309mfB@0LQNd078G]008078G]0`2OMTV009W@i@40oooo
002@09W@i@D0WgI90P1cG440102OMTT0Sfm;08m_B`2OMTT50:j3E`0409mfB@0IM=D06GCE09mfB@@0
^8]K00<0WgI90<6AG`2OMTT00P3:UV40102OMTT0cYUS0<jIH`2OMTT20=2JH`0309mfB@3DWFD0WgI9
00<0dY]T00D0WgI90<6@GP31T5h0`I1N09mfB@020<RFH@0309mfB@36Tel0WgI900D0cYUS00<0WgI9
0<bGH@2OMTT01`3CWF@01@2OMTT0eYeT0=JMI03FWF@0WgI900<0fZ9W00<0WgI90=nVJ@3OYVT01@3O
YVT00`2OMTT0iZU[09mfB@050>R/K@0309mfB@3[[Vd0WgI900<0kk5_00D0WgI90>f_KP3][fh0kJm^
09mfB@040=nUJ00609mfB@3UZF/0iJU[09mfB@3TZ6X0WgI91@3Y[Fd0102OMTT0j:]/0>R[K02OMTT5
0>n`K`0309mfB@3b/g00l[=`0080l[=`00<0WgI90?JgLP3f]g800P3f]g800`2OMTT0nk]d0?^kM002
0?^kM00309mfB@3o`gP0ol=h0080WgI90P3oa7T00`2OMTT0olMj0?o7NP0209mfB@<0olQj00@0WgI9
0?jlM@2OMTT0WgI90P3o`WL209mfB@80olIi00@0WgI90?o5MP3oaGH0WgI9100LQNd309mfBH40VM3U
0@3oool00940VM3U1@2OMTT207=L@@0309mfB@2?Kd/0Sfm;0080WgI9102^PeL00`2OMTT06GCE09mf
B@040;R;F`0409mfB@31TEl0`I5O09mfB@80bYIQ00H0WgI90<jIH`3>VF<0WgI90=2JH`2OMTT20=BM
I@0409mfB@3BVf@0dY]T09mfB@<0`I1N00L0WgI90<RFH@38UV40b9IQ09mfB@36Tel0WgI900@0cYUS
00@0WgI90<bGH@3<Uf40WgI91`3CWF@209mfB@050=JMI02OMTT0fZ9W0=ZRI`2OMTT0203OYVT209mf
B@H0j:a]0P2OMTT40>naK`0309mfB@3][fh0kJm^0080WgI9103OYFP0102OMTT0iJU[0>FYJ`3UZF/2
09mfB@D0jJe]00<0WgI90>R[K02OMTT01P3_/6l01@2OMTT0l[=`0?:cL03b/g00WgI900<0m[Mb0P2O
MTT40?^kM00409mfB@3o`gP0ol=h09mfB@<0olAi00H0WgI90?o7NP3oagX0WgI90?o8N`2OMTT20?o8
NP0309mfB@3n_7D0o[ae0080WgI900<0ol9g09mfB@2OMTT00P3oaWT01@2OMTT0olEf0?o5MP3oaGH0
WgI9008078G]102OMTV209W@i@40oooo002A09W@i@<0WgI900<0XGaC09mfB@2OMTT00P1cG4400`2O
MTT0Sfm;08m_B`0209mfB@@0[X=G0P2OMTT40;R;F`0409mfB@31TEl0`I5O09mfB@80bYIQ00H0WgI9
0<jIH`3>VF<0WgI90=2JH`2OMTT20=BMI@0509mfB@3BVf@0dY]T0=:KI02OMTT00`31T5h0102OMTT0
b9IQ0<RFH@38UV4209mfB@D0cYUS00<0WgI90<bGH@2OMTT02@3CWF@209mfB@030=ZRI`2OMTT0gjIY
00P0gjIY0P2OMTT60>R/K@80WgI9103_/Fl00`2OMTT0kJm^0>f_KP0309mfB@80gjEX00<0WgI90>FY
J`3UZF/00P3UZF/209mfB@D0jJe]00<0WgI90>R[K02OMTT01`3_/6l0102OMTT0l[=`0?:cL02OMTT2
0?JgLP0309mfB@3k^g@0nk]d00@0nk]d00<0WgI90?o3N02OMTT0103oa7T01@2OMTT0olMj09mfB@3o
b7/0WgI90080olQj00<0WgI90?jlM@3n_7D00P2OMTT00`3o`WL0WgI909mfB@020?o6N@80WgI90P3o
aGH0202OMTT078G]01b5k@2OMTT0ol9e09mfB@0F40X0WgI9PP2Id>D10?ooo`00TP2Id>D309mfB@04
0:5lD`2OMTT0WgI907=L@@80WgI90P2?Kd/309mfB@<0[X=G0P2OMTT30;R;F`0709mfB@31TEl0`I5O
0<6AG`2OMTT0bYIQ09mfB@030<jIH`0309mfB@3@VV<0WgI90080e9eU00@0WgI90=:KI03BVf@0WgI9
0`31T5h00`2OMTT0b9IQ0<RFH@020<RFH@80WgI91@3>VF<209mfB@X0dieT0`2OMTT90=nVJ@0309mf
B@3X[6d0j:a]00D0j:a]00<0WgI90>naK`3_/Fl00`3_/Fl0102OMTT0kJm^09mfB@3UZf`209mfB@80
gjEX00<0WgI90>FYJ`3UZF/00P3UZF/00`2OMTT0jJe]0>V]K@050>V]K@80WgI91`3_/6l00`2OMTT0
l[=`09mfB@020?JgLP0309mfB@3k^g@0nk]d00@0nk]d00<0WgI90?o3N02OMTT0103oa7T01@2OMTT0
olMj09mfB@3ob7/0WgI900<0olQj00T0WgI90?jlM@2OMTT0WgI90?o2M`2OMTT0olIj09mfB@3oaWT0
0P2OMTT30?o5MP0709mfB@0LQNd0WgI90?o2M@2OMTT05Q0:09mfB@2309W@i@40oooo002C09W@i@<0
WgI900@0XGaC09mfB@2OMTT0Lea10P2OMTT01@2?Kd/0WgI90:IoE@2VOeD0WgI900<0[X=G00<0WgI9
0;R;F`2hRe/00P2hRe/01`2OMTT0`I5O0<6AG`31TEl0WgI90<ZFH@2OMTT00`3>VF<209mfB@<0e9eU
00@0WgI90=:KI02OMTT0WgI90`31T5h0102OMTT0b9IQ0<RFH@38UV4209mfB@H0cYUS0P2OMTT:0=>M
I00309mfB@3OYVT0gjIY00P0gjIY00<0WgI90>R/K@3X[6d01@3X[6d00`2OMTT0kk5_0>naK`020>na
K`0309mfB@3][fh0kJm^0080WgI900D0m[Ib09mfB@3OYFP0gjEX09mfB@040>FYJ`0309mfB@3Y[Fd0
jJe]00D0jJe]00<0WgI90>n`K`3_/6l01P3_/6l00`2OMTT0l[=`09mfB@0209mfB@L0nk]d0P2OMTT4
0?o4N@0509mfB@3oagX0WgI90?o8N`2OMTT00`3ob7X0102OMTT0o[ae09mfB@3o`GL209mfB@040?o6
NP2OMTT0olIi0?o6N@80WgI90P3oaGH01`2OMTT078G]09mfB@3o`WD0WgI901H@2P2OMTT0Q02Id>D1
0?ooo`00U02Id>D309mfB@040:5lD`2OMTT0WgI907=L@@80WgI900D0Sfm;09mfB@2VOeD0YWmE09mf
B@030:j3E`0509mfB@2hRe/0^8]K0;R;F`2OMTT00`31TEl00`2OMTT0bYIQ09mfB@030<jIH`80WgI9
0`3DWFD00`2OMTT0dY]T09mfB@0209mfB@80`I1N00<0WgI90<RFH@38UV400P38UV4209mfB@H0cYUS
00<0WgI90=>MI03CWF@0203CWF@00`2OMTT0gjIY0=nVJ@070=nVJ@80WgI91P3X[6d209mfB@@0kk5_
00D0WgI90>f_KP2OMTT0iJ]/09mfB@020?JfLP0309mfB@3OYFP0WgI900@0iJU[00<0WgI90>V]K@3Y
[Fd01@3Y[Fd00`2OMTT0kk1_0>n`K`070>n`K`80WgI9203k^g@209mfB@D0olAi0P2OMTT20?o8N`0=
09mfB@3ob7X0olQj09mfB@3n_7D0WgI90?o1M`2OMTT0ol9g09mfB@3oaWX0WgI90?o6N@0209mfB@80
olEf00L0WgI901b5k@2OMTT0ol9e09mfB@0F40X0WgI908D0VM3U0@3oool009D0VM3U0`2OMTT0102Q
O5<0WgI909mfB@1cG44409mfB@80YWmE0P2OMTT20:j3E`0409mfB@2hRe/0^8]K09mfB@@0`I5O0P2O
MTT40<jIH`0309mfB@3DWFD0e9eU0080e9eU00<0WgI90=:KI02OMTT00P2OMTT20<6@GP0309mfB@38
UV40b9IQ0080b9IQ00<0WgI90<jIH`3>VF<0103>VF<209mfB@T0dieT00<0WgI90=nVJ@3OYVT01P3O
YVT00`2OMTT0hZQ[09mfB@060>R/K@80WgI9103_/Fl01@2OMTT0kJm^09mfB@3UZf`0WgI90080m[Ib
00<0WgI90=nUJ02OMTT00`3UZF/209mfB@L0jJe]00<0WgI90>n`K`3_/6l01`3_/6l00`2OMTT0nk]d
0?^kM0070?^kM00309mfB@3oa7T0olAi00<0olAi0P2OMTT20?o8N`0409mfB@3ob7X0olQj0?o8NP80
WgI90P3o`GL209mfB@060?o6NP2OMTT0olIi09mfB@3ob7X0WgI90P3oaGH209mfB@040?o2M@2OMTT0
WgI909mfBHH0VM3U0@3oool009H0VM3U0`2OMTT01P2QO5<0WgI909mfB@1cG440WgI909AcCP80WgI9
0`2VOeD01P2OMTT0[X=G0:j3E`2OMTT0^8]K09mfB@D0`I5O00<0WgI90<jIH`3>VF<00P3>VF<209mf
B@<0e9eU00@0WgI90=:KI02OMTT0bYUS0P2OMTT00`31T5h0WgI90<RFH@030<RFH@80WgI91P3>VF<3
09mfB@P0dieT00<0WgI90=nVJ@3OYVT01@3OYVT00`2OMTT0hZQ[09mfB@050>R/K@0309mfB@3/[fh0
WgI900@0kk5_0P2OMTT20>F[K00309mfB@3f]W80m[Ib0080WgI9103UZF/00`2OMTT0jji^09mfB@05
0>V]K@0309mfB@3`/W00WgI900L0kk1_00<0WgI90?^kM03k^g@01`3k^g@00`2OMTT0olAi0?o4N@03
0?o4N@80WgI90P3ob7/0202OMTT0olQj0?o8NP3ob7X0WgI90?jlM@2OMTT0ol5g0P2OMTT20?o6NP80
WgI900@0olQj09mfB@3oaGH0olEf0P2OMTT0103o`WD0WgI909mfB@2OMTV709W@i@40oooo002G09W@
i@@0WgI900D0H4`g09mfB@2OMTT0WgI909AcCP0209mfB@<0YWmE0`2OMTT00`2hRe/0WgI90<6AG`04
0<6AG`80WgI9103>VF<00`2OMTT0e9eU0=BMI@020=BMI@80WgI900H0bYUS09mfB@3JXVL0WgI90<6@
GP2OMTT40<RFH@80WgI91@3>VF<0102OMTT0eYmV0=JOIP2OMTT70=>MI00309mfB@3OYVT0gjIY00@0
gjIY00@0WgI90>:XJ`3RZ6/0WgI91@3X[6d00`2OMTT0k:m^09mfB@040>naK`80WgI90P3UZf`01@2O
MTT0m[Ib0?JfLP3f]W80WgI900@0iJU[00<0WgI90>^^KP2OMTT01@3Y[Fd00`2OMTT0l;9`09mfB@07
0>n`K`0309mfB@3k^g@0nk]d00D0nk]d0P2OMTT60?o4N@0409mfB@3ob7/0olQk09mfB@<0olQj00@0
WgI90?jlM@2OMTT0ol5g0P2OMTT20?o6NP80WgI90P3ob7X00`2OMTT0olEf0?o5MP0509mfBHP0VM3U
0@3oool009P0VM3U102OMTT01@1PC3L0WgI909mfB@2OMTT0U7=>0080WgI9102VOeD209mfB@030;R;
F`2OMTT0`I5O00@0`I5O00<0WgI90<jIH`3>VF<00P3>VF<209mfB@<0e9eU0P2OMTT20<ZIH`0409mf
B@3JXVL0WgI909mfB@@0b9IQ00<0WgI90=6LI02OMTT0103>VF<01@2OMTT0eYmV0=JOIP3FWfH0WgI9
00H0dieT00<0WgI90=nVJ@3OYVT00`3OYVT01@2OMTT0hZQ[0>:XJ`3RZ6/0WgI900@0j:a]00@0WgI9
0>b_KP3/[fh0WgI9103_/Fl01@2OMTT0iJ]/0>F[K03UZf`0WgI900<0m[Ib00<0WgI90>FYJ`3UZF/0
0P3UZF/00`2OMTT0jji^09mfB@040>V]K@0409mfB@3`/W00l;9`09mfB@H0kk1_00<0WgI90?^kM03k
^g@01@3k^g@209mfB@H0olAi00H0WgI90?o8N`3ob7/0olQk09mfB@3ob7X409mfB@80ol5g00<0WgI9
0?o6NP3oaWX00P2OMTT20?o8NP0309mfB@3oaGH0olEf00D0WgI9R@2Id>D10?ooo`00V@2Id>D409mf
B@06061<=`2OMTT0WgI909mfB@2DLdh0WgI91@2VOeD309mfB@D0`I5O0P2OMTT40<jIH`80WgI90`3D
WFD209mfB@80bYUS00@0WgI90=ZRI`2OMTT0WgI91038UV400`2OMTT0dIaT09mfB@040<jIH`0409mf
B@3FWfH0eYmV0=JOIP80WgI9103CWF@00`2OMTT0gjIY0=nVJ@020=nVJ@0309mfB@3RZ6/0hZQ[0080
hZQ[00<0WgI90>R/K@3X[6d00P3X[6d0102OMTT0k:m^0>b_KP2OMTT30>naK`0309mfB@3UZf`0iJ]/
0080iJ]/00D0WgI90?JfLP3f]W80m[Ib09mfB@030>FYJ`0409mfB@3[[Vh0jji^09mfB@@0jJe]00D0
WgI90?2bL03`/W00l;9`09mfB@050>n`K`0309mfB@3k^g@0nk]d00<0nk]d0P2OMTT00`3m_GH0WgI9
0?o4N@030?o4N@80WgI90`3ob7/00`2OMTT0olQj09mfB@0309mfB@80ol5g0P2OMTT20?o6NP80WgI9
0P3ob7X00`2OMTT0olEf09mfB@0409mfBHX0VM3U0@3oool009X0VM3U1@2OMTT01@1gH4<0WgI909Ac
CP2DLdh0WgI900H0YWmE00<0WgI90<6AG`31TEl01031TEl209mfB@<0cYUS0P2OMTT30=BMI@80WgI9
0P3:VF<0102OMTT0fZ9W0=ZRI`2OMTT40<RFH@0409mfB@3AW6@0dIaT09mfB@<0cYUS00<0WgI90=JO
IP3FWfH00`3FWfH01@2OMTT0dieT0=>MI03CWF@0WgI900<0gjIY00<0WgI90>:XJ`3RZ6/0103RZ6/0
102OMTT0j:a]0>R/K@2OMTT30>b_KP0509mfB@3_/Fl0kk5_0>naK`2OMTT0103UZf`01@2OMTT0m[Ib
0?JfLP3f]W80WgI900<0iJU[00D0WgI90>^^KP3[[Vh0jji^09mfB@020>V]K@0309mfB@3`/W00l;9`
0080l;9`00<0WgI90>n`K`3_/6l00P3_/6l00`2OMTT0nk]d0?^kM0030?^kM00409mfB@3m_GH0oKef
09mfB@@0olAi0P2OMTT30?o8N`0309mfB@3ob7X0WgI900<0WgI90`3o`GL00`2OMTT0olIj0?o6NP02
09mfB@80olQj00<0WgI90?o5MP2OMTT0102OMTV;09W@i@40oooo002K09W@i@D0WgI900D0Mf1309mf
B@2DLdh0U7=>09mfB@060:IoE@0309mfB@31TEl0`I5O00<0`I5O0P2OMTT40<jIH`80WgI90`3DWFD0
1@2OMTT0bYUS0<ZIH`3:VF<0WgI90080fZ9W00<0WgI90<RFH@38UV400P38UV40102OMTT0dIaT0=6L
I02OMTT20<jIH`0309mfB@3FWfH0eYmV00@0eYmV00@0WgI90=>MI03CWF@0WgI90P3OYVT00`2OMTT0
hZQ[0>:XJ`050>:XJ`0409mfB@3X[6d0j:a]09mfB@<0k:m^00@0WgI90>naK`3_/Fl0WgI9103UZf`0
0`2OMTT0m[Ib0?JfLP030?JfLP0409mfB@3UZF/0iJU[09mfB@<0jji^00@0WgI90>V]K@3Y[Fd0WgI9
103`/W000`2OMTT0kk1_0>n`K`020>n`K`0409mfB@3k^g@0nk]d0?^kM080WgI90P3m_GH00`2OMTT0
olAi0?o4N@020?o4N@80WgI90`3ob7/409mfB@030?o5M`2OMTT0ol5g0080ol5g00D0WgI90?o6NP3o
aWX0olIj09mfB@030?o8NP<0WgI900<0k;I]09mfB@2OMTT0S02Id>D10?ooo`00W02Id>D509mfB@05
07MP@`2OMTT0U7=>09AcCP2OMTT01P2VOeD00`2OMTT0`I5O0<6AG`020<6AG`0309mfB@36UF40WgI9
00<0cYUS00<0WgI90=:MI@2OMTT00P3DWFD00`2OMTT0bYUS0<ZIH`020<ZIH`0409mfB@3JXVL0fZ9W
09mfB@<0b9IQ00D0WgI90=6LI03AW6@0dIaT09mfB@020<jIH`0309mfB@3FWfH0eYmV00@0eYmV0P2O
MTT0103CWF@0WgI90=nVJ@2OMTT70>:XJ`0309mfB@3X[6d0WgI900@0k:m^00@0WgI90>naK`3_/Fl0
WgI9103UZf`00`2OMTT0m[Ib0?JfLP030?JfLP0409mfB@3UZF/0iJU[09mfB@<0jji^00@0WgI90>V]
K@3Y[Fd0WgI91@3`/W00102OMTT0kk1_0>n`K`2OMTT30?^kM00509mfB@3m_GH0oKef0?fmMP2OMTT0
0`3oa7T209mfB@030?o5NP2OMTT0olQk0080olQk00@0WgI90?jnM`2OMTT0olEg0P2OMTT20?o1M`05
09mfB@3oaWX0olIj0?o6NP2OMTT00`3ob7X309mfB@030>bfK@2OMTT0WgI908d0VM3U0@3oool009d0
VM3U1@2OMTT0101gH4<0WgI909AcCP2DLdh209mfB@D0YWmE00D0WgI90<6AG`31TEl0`I5O09mfB@02
0<JEH@0409mfB@3>VF<0cYUS09mfB@80dYeU00@0WgI90=BMI@3DWFD0WgI90`3:VF<01@2OMTT0fZ9W
0=ZRI`3JXVL0WgI900<0b9IQ00L0WgI90=6LI03AW6@0dIaT09mfB@3>VF<0WgI900P0eYmV0`2OMTT8
0>:XJ`0309mfB@3X[6d0WgI900@0k:m^00<0WgI90>naK`2OMTT01@3UZf`00`2OMTT0m[Ib0?JfLP03
0?JfLP0309mfB@3UZF/0WgI900@0jji^00<0WgI90>V]K@2OMTT01P3`/W001@2OMTT0kk1_0>n`K`2O
MTT0nk]d0080WgI9103m_GH0102OMTT0olAi0?o4N@2OMTT20?o5NP0709mfB@3ob7/0olQk0?o8N`2O
MTT0o[ig09mfB@020?o5M`0309mfB@3o`GL0ol5g0080WgI90P3oaWX00`2OMTT0olQj0?o8NP020?o8
NP0309mfB@3/]Vd0k;I]0080WgI9SP2Id>D10?ooo`00WP2Id>D00`2OMTT0Yh5F09mfB@0209mfB@04
07MP@`2OMTT0WgI909AcCP<0WgI9102VOeD01@2OMTT0`I5O0<6AG`31TEl0WgI90080aYEQ00H0WgI9
0<jIH`3>VF<0WgI90=:MI@2OMTT20=BMI@0309mfB@3:VF<0bYUS0080bYUS00D0WgI90=ZRI`3JXVL0
fZ9W09mfB@020<RFH@0309mfB@3AW6@0dIaT0080dIaT0P2OMTT90=JOIP0309mfB@3RZ6/0hZQ[00L0
hZQ[0P2OMTT50>b_KP0309mfB@3_/Fl0WgI900D0iJ]/00<0WgI90?JfLP3f]W800`3f]W800`2OMTT0
iJU[09mfB@050>^^KP80WgI91P3`/W001@2OMTT0kk1_09mfB@3k^g@0WgI900D0oKef00@0WgI90?o4
N@2OMTT0WgI90P3oaGX00`2OMTT0olQk0?o8N`0209mfB@050?jnM`2OMTT0olEg0?o5M`2OMTT00P3o
`GL209mfB@80olIj0P2OMTT30?o8NP0309mfB@3/]Vd0k;I]0080WgI9S`2Id>D10?ooo`00W`2Id>D0
0`2OMTT0Yh5F09mfB@0209mfB@0607MP@`2OMTT0WgI909AcCP2OMTT0Zh=G0P2OMTT30:IoE@0409mf
B@31TEl0`I5O09mfB@<0aYEQ00<0WgI90<jIH`2OMTT00P3BWFD0102OMTT0e9eU0=BMI@2OMTT40<ZI
H`0409mfB@3JXVL0fZ9W0=ZRI`80WgI900<0b9IQ09mfB@3AW6@00`3AW6@209mfB@P0eYmV00<0WgI9
0>:XJ`3RZ6/01`3RZ6/209mfB@D0k:m^0P2OMTT60>F[K00309mfB@3f]W80m[Ib00<0m[Ib00<0WgI9
0>FYJ`2OMTT01@3[[Vh00`2OMTT0l;9`0?2bL0060?2bL0<0WgI91@3m_GH00`2OMTT0olAi09mfB@03
0?o5NP0409mfB@3ob7/0olQk09mfB@80o[ig00@0WgI90?o5M`3oaGL0WgI90P3o`GL209mfB@80olIj
0P2OMTT30?o8NP0309mfB@3/]Vd0k;I]0080WgI9T02Id>D10?ooo`00X02Id>D01P2OMTT0Yh5F09mf
B@1iI4D0WgI907MP@`80WgI900@0U7=>09mfB@2[PeL0Zh=G0P2OMTT20:IoE@0309mfB@31TEl0WgI9
00@0aYEQ0P2OMTT30=:MI@0309mfB@3DWFD0WgI900@0bYUS00<0WgI90=ZRI`3JXVL00`3JXVL209mf
B@D0dIaT00<0WgI90=JOIP3FWfH01`3FWfH00`2OMTT0hZQ[0>:XJ`060>:XJ`0309mfB@3/[fh0k:m^
00@0k:m^0P2OMTT60>F[K00309mfB@3f]W80m[Ib00@0m[Ib0P2OMTT50>^^KP0309mfB@3`/W00l;9`
00H0l;9`00<0WgI90?fmMP3m_GH0103m_GH00`2OMTT0olAi09mfB@030?o5NP0409mfB@3ob7/0olQk
09mfB@80o[ig00X0WgI90?o5M`3oaGL0olEg09mfB@3o`GL0WgI90?o6NP2OMTT0olIj0P2OMTT30?o8
NP0309mfB@3/]Vd0k;I]0080WgI9T@2Id>D10?ooo`00X@2Id>D01P2OMTT0Yh5F09mfB@1iI4D0WgI9
07MP@`@0WgI90`2[PeL209mfB@030:IoE@2OMTT0`I5O00@0aYEQ00<0WgI90<jIH`2OMTT00`3BWFD2
09mfB@D0bYUS00<0WgI90=ZRI`3JXVL00`3JXVL209mfB@@0dIaT0`2OMTT70=JOIP0309mfB@3RZ6/0
hZQ[00D0hZQ[0P2OMTT60>b_KP0309mfB@3UZf`0iJ]/00D0iJ]/00<0WgI90?JfLP3f]W80103f]W80
0`2OMTT0jji^0>^^KP040>^^KP0309mfB@3`/W00l;9`00D0l;9`00<0WgI90?fmMP3m_GH01@3m_GH2
09mfB@<0olEj00@0WgI90?o8N`2OMTT0WgI90`3n_WL0302OMTT0olEg0?o5M`2OMTT0ol5g09mfB@3o
aWX0WgI90?o6NP2OMTT0olQk09mfB@80olQj00<0WgI90>bfK@2OMTT00P2OMTVB09W@i@40oooo002R
09W@i@0809mfB@2WPEH0WgI907UTA@2OMTT0Mf1309mfB@2IN54309mfB@<0Zh=G102OMTT40<JEH@80
WgI9103BWFD209mfB@D0bYUS00<0WgI90=ZRI`3JXVL00`3JXVL00`2OMTT0dIaT0=6LI0030=6LI003
09mfB@3HXVL0WgI900H0eYmV00<0WgI90>:XJ`3RZ6/0103RZ6/00`2OMTT0iJ]]09mfB@060>b_KP03
09mfB@3UZf`0iJ]/00D0iJ]/00<0WgI90?JfLP3f]W80103f]W800`2OMTT0jji^0>^^KP030>^^KP03
09mfB@3a/g40WgI900H0l;9`00<0WgI90?fmMP3m_GH0103m_GH00`2OMTT0olEj0?o5NP030?o5NP80
WgI9103n_WL0302OMTT0olEg0?o5M`2OMTT0ol5g09mfB@3oaWX0WgI90?o6NP2OMTT0olQk09mfB@80
olQj00<0WgI90>bfK@2OMTT00P2OMTVC09W@i@40oooo002S09W@i@<0WgI900D0NFA509mfB@2OMTT0
WgI909UhD@0309mfB@@0Zh=G0P2OMTT50<JEH@80WgI90`3BWFD209mfB@D0bYUS00<0WgI90=ZRI`3J
XVL0103JXVL00`2OMTT0dIaT0=6LI0020=6LI00309mfB@3HXVL0f:9W0080WgI9103FWfH00`2OMTT0
hZQ[0>:XJ`030>:XJ`0409mfB@3UZfd0iJ]]09mfB@D0k:m^0P2OMTT60>F[K00309mfB@3f]W80m[Ib
00D0m[Ib00<0WgI90>^^KP3[[Vh00`3[[Vh00`2OMTT0lK=a09mfB@050?2bL00309mfB@3m_GH0oKef
00<0oKef0P2OMTT50?o5NP80WgI9103n_WL01P2OMTT0olEg0?o5M`2OMTT0ol5g09mfB@80olIj0P2O
MTT20?o8N`L0WgI9U02Id>D10?ooo`00Y02Id>D309mfB@0307UTA@2OMTT0WgI90080WgI900<0VGQA
09mfB@2OMTT01@2[PeL00`2OMTT0aYEQ0<JEH@030<JEH@0309mfB@3BWFD0dYeU0080dYeU0P2OMTT5
0<ZIH`0309mfB@3JXVL0fZ9W00@0fZ9W00<0WgI90=6LI03AW6@00P3AW6@01@2OMTT0f:9W0=RRI`3H
XVL0WgI900@0eYmV00D0WgI90>:XJ`3RZ6/0hZQ[09mfB@030>F[K@0309mfB@3/[fh0k:m^0080k:m^
00<0WgI90>B/K@2OMTT01P3UZf`00`2OMTT0m[Ib0?JfLP040?JfLP80WgI9103[[Vh0102OMTT0lK=a
0?6cL@2OMTT40?2bL00309mfB@3m_GH0oKef0080oKef0`2OMTT50?o5NP80WgI9103n_WL0102OMTT0
olEg0?o5M`3oaGL209mfB@80olIj0P2OMTT20?o8N`L0WgI9U@2Id>D10?ooo`00Y@2Id>D309mfB@06
07UTA@2OMTT0WgI907MP@`2OMTT0VGQA0P2OMTT50:^3E`0309mfB@36UF40aYEQ0080aYEQ0P2OMTT4
0=:MI@0309mfB@3:VF<0bYUS00@0bYUS00<0WgI90=ZRI`3JXVL00`3JXVL209mfB@<0dIaT00<0WgI9
0=RRI`3HXVL00P3HXVL209mfB@80eYmV00D0WgI90>:XJ`3RZ6/0hZQ[09mfB@030>F[K@0309mfB@3/
[fh0k:m^0080k:m^00<0WgI90>B/K@2OMTT01P3UZf`00`2OMTT0m[Ib0?JfLP040?JfLP0309mfB@3i
^W@0WgI900<0jji^00D0WgI90?6cL@3a/g40lK=a09mfB@030?2bL00509mfB@3m_GH0oKef0?fmMP2O
MTT00P3m_WL00`2OMTT0olEj0?o5NP020?o5NP0309mfB@3n_WL0o[ig00<0o[ig00@0WgI90?o5M`3o
aGL0olEg0P2OMTT20?o6NP80WgI90P3ob7/309mfB@040>^fKP2OMTT0WgI909mfBIH0VM3U0@3oool0
0:H0VM3U0`2OMTT207UTA@<0WgI900<0VGQA09mfB@2OMTT01@2[PeL01`2OMTT0aYEQ0<JEH@36UF40
WgI90<^JI02OMTT00`3BWFD209mfB@D0bYUS00<0WgI90=ZRI`3JXVL0103JXVL209mfB@<0dIaT00<0
WgI90=RRI`3HXVL00`3HXVL00`2OMTT0eYmV09mfB@020>:XJ`0309mfB@3UZfd0iJ]]00<0iJ]]00@0
WgI90>b_KP3/[fh0WgI90P3T[6d00`2OMTT0iJ]/0>F[K0040>F[K00309mfB@3f]W80m[Ib00<0m[Ib
00@0WgI90?VjM03i^W@0WgI90P3[[Vh00`2OMTT0lK=a0?6cL@020?6cL@0409mfB@3`/W00l;9`09mf
B@80oKef0P2OMTT20?fnM`0409mfB@3oaGX0olEj0?o5NP80WgI91@3n_WL0102OMTT0olEg0?o5M`3o
aGL209mfB@<0olIj00@0WgI90?o8N`3ob7/0olQk0P2OMTT0103[]Vh0WgI909mfB@2OMTVG09W@i@40
oooo002W09W@i@<0WgI90P1iI4D309mfB@80VGQA0P2OMTT40:^3E`0709mfB@36UF40aYEQ0<JEH@2O
MTT0biYT09mfB@030=:MI@80WgI91@3:VF<00`2OMTT0fZ9W0=ZRI`030=ZRI`0609mfB@3OYfX0WgI9
09mfB@3AW6@0WgI91P3HXVL409mfB@H0iJ]]00<0WgI90>b_KP2OMTT00`3T[6d00`2OMTT0iJ]/0>F[
K0030>F[K080WgI91@3f]W80102OMTT0nKYd0?VjM02OMTT20>^^KP0309mfB@3a/g40lK=a0080lK=a
00@0WgI90?2bL02OMTT0oKef0P2OMTT30?fnM`0409mfB@3oaGX0olEj0?o5NP80WgI91@3n_WL00`2O
MTT0olEg0?o5M`020?o5M`0509mfB@3oaWX0olIj0?o6NP2OMTT00`3ob7/00`2OMTT081H=0>^fKP03
09mfBIP0VM3U0@3oool00:P0VM3U102OMTT0101iI4D0WgI909mfB@2OMTT209UhD@<0WgI90`2[PeL0
102OMTT0aYEQ0<JEH@2OMTT20<^JI00609mfB@3BWFD0dYeU09mfB@3:VfD0WgI9103:VF<309mfB@@0
fZ9W00H0WgI90=nWJP3OYfX0WgI90=6LI02OMTT70=RRI`0309mfB@3UZfd0iJ]]00D0iJ]]0P2OMTT3
0>B/K@0309mfB@3UZf`0iJ]/00<0iJ]/0P2OMTT00`3W[Fh0WgI90?JfLP020?JfLP0709mfB@3i^W@0
nKYd0?VjM02OMTT0jji^09mfB@060?6cL@<0WgI9103m_WL00`2OMTT0olEj0?o5NP0309mfB@D0o[ig
00<0WgI90?o5M`3oaGL00P3oaGL01@2OMTT0olIj0?o6NP3oaWX0WgI900<0olQk00<0WgI90>^fKP2O
MTT00`2OMTVI09W@i@40oooo002Z09W@i@<0WgI900@0NFA509mfB@2OMTT0WgI90P2IN54409mfB@80
Zh=G00<0WgI90<JEH@2OMTT00`3;VV@00`2OMTT0dYeU09mfB@020<ZKI@0609mfB@3:VF<0bYUS0<ZI
H`2OMTT0gjQ[0P2OMTT30=ZRI`0409mfB@3OYfX0gjMZ0=nWJP80WgI91`3HXVL00`2OMTT0iJ]]0>F[
K@050>F[K@80WgI90`3T[6d00`2OMTT0iJ]/0>F[K0020>F[K00509mfB@3e^7@0WgI90>N]KP2OMTT0
0`3f]W800`2OMTT0nKYd0?VjM0020?VjM080WgI91P3a/g400`2OMTT0oKig0?fnM`030?fnM`0609mf
B@3oaGX0WgI909mfB@3i_7H0WgI91@3n_WL00`2OMTT0olEg0?o5M`020?o5M`0309mfB@3oaWX0olIj
0080WgI90P3ob7/209mfB@030>^fKP2OMTT0WgI90080WgI9VP2Id>D10?ooo`00Z`2Id>D309mfB@04
07UTA@2OMTT0^8]K09mfB@<0VGQA00D0WgI90;28FP2OMTT0WgI90:^3E`0209mfB@@0biYT00<0WgI9
0=:MI@2OMTT00P3:VfD01P2OMTT0bYUS0<ZIH`3:VF<0WgI90=nXJ`80WgI90`3JXVL0102OMTT0gjMZ
0=nWJP3OYfX209mfB@H0f:9W00<0WgI90>F[K@3UZfd01@3UZfd00`2OMTT0i:a]0>B/K@020>B/K@05
09mfB@3UZf`0iJ]/0>F[K02OMTT00P3e^7@00`2OMTT0ije^09mfB@030?JfLP0309mfB@3i^W@0nKYd
0080nKYd00<0WgI90?6cL@3a/g40103a/g400`2OMTT0oKig0?fnM`040?fnM`80WgI90P3i_7H00`2O
MTT0o[ig0?jnM`030?jnM`0409mfB@3oaGL0olEg0?o5M`80WgI90P3oaWX01@2OMTT0olMk09mfB@3o
b7/0WgI90080jkI^102OMTVK09W@i@40oooo002/09W@i@0409mfB@2NO5<0WgI907UTA@@0WgI90P2I
N5400`2OMTT0/8QJ0;28FP0409mfB@@0biYT0P2OMTT20<ZKI@0809mfB@3:VF<0bYUS0<ZIH`2OMTT0
gjQ[09mfB@3>W6D209mfB@80fZ9W00D0WgI90=nWJP3OYfX0gjMZ09mfB@070=RRI`0309mfB@3UZfd0
iJ]]00<0iJ]]00<0WgI90>B/K@3T[6d00`3T[6d0102OMTT0iJ]/0>F[K02OMTT20?FhM00709mfB@3W
[Fh0ije^0>N]KP2OMTT0m[Ib09mfB@050?VjM00309mfB@3a/g40lK=a00@0lK=a00<0WgI90?fnM`3m
_WL00`3m_WL209mfB@80nKaf00<0WgI90?jnM`3n_WL00P3n_WL209mfB@<0olEg00X0WgI90?c2MP2O
MTT0olIj09mfB@3oag/0WgI90?o8N`2OMTT0jkI^102OMTVM09W@i@40oooo002]09W@i@0309mfB@2N
O5<0WgI90080NFA500H0WgI90;R;F`2OMTT0WgI909UhD@2OMTT30;28FP80WgI91@3;VV@209mfB@80
bY]U00@0WgI90<ZIH`3:VF<0WgI90P3OZ6/01P2OMTT0cYaU0<jLI@2OMTT0fZ9W09mfB@@0gjMZ0P2O
MTT50=RRI`0309mfB@3UZfd0iJ]]0080iJ]]00<0WgI90>B/K@3T[6d0103T[6d00`2OMTT0iJ]/09mf
B@030?FhM00709mfB@3W[Fh0ije^0>N]KP2OMTT0m[Ib09mfB@060?VjM00309mfB@3a/g40lK=a0080
lK=a00<0WgI90?fnM`3m_WL00P3m_WL209mfB@<0nKaf00@0WgI90?jnM`3n_WL0o[ig0`2OMTT30?o5
M`0809mfB@3l`WH0WgI90?o6NP2OMTT0olMk09mfB@3ob7/309mfB@0301H@2P2OMTT0WgI909h0VM3U
0@3oool00:h0VM3U102OMTT00`1iI4D0WgI90;R;F`0409mfB@@0/8QJ00<0WgI90<^JI03;VV@00`3;
VV@01`2OMTT0bY]U0<ZKI@3:VfD0WgI90<ZIH`2OMTT00`3OZ6/01P2OMTT0cYaU0<jLI@2OMTT0fZ9W
09mfB@D0gjMZ0P2OMTT30=RRI`0509mfB@3UZfd0iJ]]0>F[K@2OMTT01`3T[6d209mfB@@0mKQd00<0
WgI90>N]KP3W[Fh00P3W[Fh00`2OMTT0nKYd0?VjM0050?VjM00509mfB@3a/g40lK=a0?6cL@2OMTT0
0`3m_WL209mfB@@0nKaf00<0WgI90?jnM`3n_WL00`2OMTT00`3n_gL0WgI90?o5M`0209mfB@050?c2
MP2OMTT0olIj09mfB@3oag/01@2OMTT00`0F40X0WgI909mfB@2O09W@i@40oooo002`09W@i@<0WgI9
00@0NFA509mfB@2OMTT0^8]K102OMTT30;28FP80WgI90`3;VV@00`2OMTT0bY]U0<ZKI@020<ZKI@03
09mfB@3:VF<0WgI900<0gjQ[00<0WgI90<jLI@3>W6D00P2OMTT70=nWJP80WgI900D0f:9W09mfB@3U
Zfd0iJ]]09mfB@080>B/K@0309mfB@3e^7@0mKQd00<0mKQd00<0WgI90>N]KP3W[Fh00P3W[Fh00`2O
MTT0nKYd0?VjM0060?VjM00309mfB@3a/g40WgI90080oKig0P2OMTT50?VlMP0:09mfB@3n_WL0WgI9
09mfB@3oa7T0WgI90?joM`2OMTT0olEg09mfB@80o<9f0`2OMTT20?o7N`L0WgI9X02Id>D10?ooo`00
/@2Id>D;09mfB@@0/8QJ00D0WgI90<^JI03;VV@0biYT09mfB@040<ZKI@80WgI9103OZ6/0102OMTT0
cYaU0<jLI@3>W6D209mfB@L0gjMZ102OMTT80>B/K@80WgI9103e^7@00`2OMTT0ije^0>N]KP030>N]
KP80WgI91`3i^W@00`2OMTT0lK=a09mfB@0209mfB@H0nKaf0`2OMTT20?o4N@0509mfB@3n_gL0WgI9
0?o5M`2OMTT00`3l`WH0102OMTT0olMk0?o7N`3oag/609mfBJ80VM3U0@3oool00;80VM3U302OMTT3
0;28FP0409mfB@3;VV@0biYT09mfB@D0bY]U00<0WgI90=nXJ`3OZ6/00`3OZ6/0102OMTT0cYaU0<jL
I@3>W6D309mfB@L0gjMZ00<0WgI90>B/K@3T[6d01@3T[6d209mfB@030>fcL@2OMTT0mKQd00<0mKQd
00<0WgI90>N]KP3W[Fh00P3W[Fh00`2OMTT0l;Eb09mfB@080?VjM080WgI91`3i_7H209mfB@80olAi
0P2OMTT0103n_gL0WgI909mfB@2OMTT30?c2MP0309mfB@3oag/0olMk00L0WgI9X`2Id>D10?ooo`00
]02Id>D909mfB@050<:CH02OMTT0WgI909mfB@2`R5X00`2OMTT50<ZKI@80WgI9103OZ6/00`2OMTT0
cYaU0<jLI@020<jLI@0409mfB@3KYVX0WgI909mfB@D0gjMZ00<0WgI90>B/K@3T[6d0103T[6d01@2O
MTT0kK=a0>fcL@3]/g40WgI900@0mKQd00<0WgI90>N]KP3W[Fh00P3W[Fh0102OMTT0l;Eb0?2eLP2O
MTT60?VjM00309mfB@3i_7H0nKaf00<0nKaf102OMTT30?o4N@0509mfB@3n_gL0o[mg0?joM`2OMTT0
103l`WH00`2OMTT0olMk09mfB@0709mfBJ@0VM3U0@3oool00;D0VM3U2P2OMTT20<:CH0D0WgI9103:
VfD0102OMTT0f:EZ09mfB@2OMTT30=nXJ`0509mfB@3>W6D0cYaU0<jLI@2OMTT00`3KYVX209mfB@@0
gjMZ00<0WgI90>B/K@3T[6d00P3T[6d00`2OMTT0kK=a0>fcL@020>fcL@0509mfB@3e^7@0mKQd0?Fh
M02OMTT0103W[Fh00`2OMTT0l;Eb0?2eLP020?2eLP0309mfB@3i^W@0nKYd0080nKYd00<0WgI90?Vl
MP3i_7H00P3i_7H209mfB@80o<1h00D0WgI90?o4N@3oa7T0olAi09mfB@030?joM`0309mfB@3l`WH0
o<9f0080o<9f00<0WgI90?o7N`2OMTT01P2OMTVV09W@i@40oooo002g09W@i@0309mfB@1jIDD0WgI9
00L0WgI90`32Tf0209mfB@@0bY]U00D0WgI90=RUJP3HYFX0f:EZ09mfB@030=nXJ`0509mfB@3>W6D0
cYaU0<jLI@2OMTT0103KYVX209mfB@80gjMZ00<0WgI90>B/K@3T[6d00P2OMTT50>fcL@0509mfB@3e
^7@0mKQd0?FhM02OMTT0103W[Fh00`2OMTT0l;Eb0?2eLP030?2eLP0409mfB@3i^W@0nKYd09mfB@80
nKaf0`2OMTT30?c0N00509mfB@3oa7T0olAi0?o4N@2OMTT00P3n_gL209mfB@@0o<9f102OMTT0103c
_7@0WgI909mfB@2OMTVX09W@i@40oooo002h09W@i@D0WgI900<0`9AQ09mfB@2OMTT0102OMTT20<:C
H080WgI90`3:VfD01@2OMTT0f:EZ0=RUJP3HYFX0WgI900<0gjQ[00D0WgI90<jLI@3>W6D0cYaU09mf
B@050=^VJP80WgI900<0gjMZ09mfB@2OMTT01`3]/g400`2OMTT0mKQd0?FhM00309mfB@80ije^00<0
WgI90?2eLP3`]G80103`]G800`2OMTT0nKYd09mfB@0309mfB@D0o<1h00<0WgI90?o4N@3oa7T00P2O
MTT20?joM`80WgI9103l`WH309mfB@80lkad0`2OMTVY09W@i@40oooo002j09W@i@@0WgI90P30U640
0`2OMTT0QVi;09mfB@0409mfB@050<:CH02OMTT0bY]U0<ZKI@2OMTT0103HYFX00`2OMTT0gjQ[0=nX
J`0309mfB@80cYaU00<0WgI90=^VJP3KYVX0103KYVX209mfB@P0kK=a00H0WgI90?FhM02OMTT0WgI9
0?NkMP2OMTT20>N]KP0309mfB@3`]G80l;Eb00D0l;Eb0P2OMTT60?c0N080WgI90P3oa7T00`2OMTT0
o[mg0?joM`0309mfB@@0o<9f0P2OMTT20?>lM0<0WgI9Z`2Id>D10?ooo`00_02Id>D409mfB@050<2D
H@2OMTT0WgI908I^B`2OMTT00P2dSUd509mfB@D0f:EZ0`2OMTT00`3?XVP0WgI909mfB@0209mfB@L0
fjIZ00<0WgI90>fcL@3]/g401P3]/g4209mfB@040>B_L02OMTT0mk]f0?NkMP80WgI91`3`]G800`2O
MTT0o<1h0?c0N0050?c0N00309mfB@3oa7T0olAi0080WgI90P3n_gL0102OMTT0ol=i0?o3N@2OMTT2
0?c2MP80WgI90P3c_7@409mfBJ`0VM3U0@3oool00;h0VM3U102OMTT00`30U640WgI909mfB@0209mf
B@<0]8iM0P2OMTT70=RUJP80WgI90P3?XVP309mfB@L0fjIZ00<0WgI90>fcL@3]/g401@3]/g40102O
MTT0i:m`0>B_L02OMTT30?NkMP0309mfB@3`]G80l;Eb00@0l;Eb00<0WgI90?c0N03l`7P01@3l`7P0
0`2OMTT0olAi09mfB@0209mfB@030?joM`2OMTT0WgI90080ol=i00<0WgI90?c2MP2OMTT01`2OMTV^
09W@i@40oooo003009W@i@@0WgI900@0`9AQ09mfB@2OMTT0WgI9102dSUd209mfB@H0f:EZ00H0WgI9
0<nRJ03?XVP0cj9X09mfB@3U[Fh209mfB@D0fjIZ00<0WgI90>fcL@3]/g400`3]/g4209mfB@80i:m`
00<0WgI90?NkMP3g^gH00`3g^gH00`2OMTT0l;Eb0?2eLP020?2eLP0309mfB@3l`7P0o<1h00D0o<1h
1@2OMTT00`3n_gL0WgI90?o3N@020?o3N@T0WgI9/02Id>D10?ooo`00`P2Id>D809mfB@@0]8iM0P2O
MTT40=RUJP0309mfB@3?XVP0cj9X0080cj9X00<0WgI90>F]KP3U[Fh00`2OMTT30=^VJP0509mfB@3]
/g40kK=a0>fcL@2OMTT0103T[g000`2OMTT0mk]f0?NkMP030?NkMP0509mfB@3`]G80l;Eb0?2eLP2O
MTT01@3l`7P509mfB@80l[]d0P2OMTT30?o3N@80WgI900<0bj9S09mfB@2OMTT00`2OMTVb09W@i@40
oooo003409W@i@P0WgI9102dSUd209mfB@80f:EZ00<0WgI90<nRJ03?XVP00`3?XVP00`2OMTT0iJe^
0>F]KP020>F]KP@0WgI900<0kK=a09mfB@2OMTT01@3T[g000`2OMTT0mk]f0?NkMP040?NkMP0409mf
B@3`]G80WgI90?c0N0D0WgI900<0kkQd09mfB@2OMTT00`3b^g@00`2OMTT0ol=i0?o3N@0209mfB@80
bj9S1@2OMTVd09W@i@40oooo003609W@i@/0WgI900D0]8iM09mfB@2OMTT0f:EZ09mfB@050<nRJ080
WgI91@3U[Fh209mfB@L0i:m`00<0WgI90?NkMP3g^gH01@3g^gH309mfB@@0kkQd0P2OMTT40?:kM0@0
WgI90P3;XV<409mfBKL0VM3U0@3oool00<P0VM3U102OMTT30:64EPL0WgI91`3?XVP00`2OMTT0iJe^
0>F]KP040>F]KP0309mfB@3T[g00i:m`00<0i:m`00<0WgI90?NkMP3g^gH0103g^gH209mfB@D0kkQd
0P2OMTT40?:kM0T0WgI9^P2Id>D10?ooo`00bP2Id>D509mfB@<0XHAF0P2OMTT30<bMIP80WgI91@3?
XVP409mfB@80iJe^00@0WgI90>B_L03T[g00i:m`102OMTT30?NkMP80WgI91@3_^7@209mfB@@0l[]d
2@2OMTVl09W@i@40oooo003>09W@i@@0WgI90P2QQ5H309mfB@80c9eV0`2OMTT0103?XVP0WgI90;BB
GP2dTUh809mfB@040<fRJ02OMTT0g:a^0=b/KPX0WgI90`3b^g@309mfB@80iK=`00@05Q0:09mfB@2O
MTT0WgI9_`2Id>D10?ooo`00d@2Id>D509mfB@030:64EP2OMTT0WgI900D0WgI9102dTUh309mfB@@0
cJ9X00<0WgI90=b/KP3L[6h00`3L[6h409mfB@040>:`L02OMTT0l[]d0?:kM080WgI90P3U/g00100F
40X0WgI909mfB@2OMTW209W@i@40oooo003F09W@i@D0WgI900<0WH9C09mfB@2OMTT01P2OMTT01@2d
TUh0WgI909mfB@3=XVP0WgI90080g:a^102OMTT50>:`L0P0WgI9a@2Id>D10?ooo`00fP2Id>D309mf
B@L0WH9C302OMTT20=Z/K0D0WgI9bP2Id>D10?ooo`00gP2Id>DE09mfBLh0VM3U0@3oool00?l0VM3U
`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?oo
o`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G2
09W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo
003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80
VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool0
0?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2I
d>D10?ooo`00o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00
o`2Id>G209W@i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@
i@40oooo003o09W@iL80VM3U0@3oool00?l0VM3U`P2Id>D10?ooo`00o`2Id>G209W@i@40oooo0000
\
\>"],
  ImageRangeCache->{{{0, 449}, {263.688, 0}} -> {-0.000855365, 0.1632, \
0.00215823, 0.00215823}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{631, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 57, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1836, 56, 1146, 45, 73, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 1137337, 36351}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 57, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1836, 56, 1146, 45, 73, "Usage",
  CellTags->"Function?"],
Cell[2985, 103, 638, 16, 92, "MathCaption"],
Cell[3626, 121, 407, 8, 75, "MathCaption"],
Cell[4036, 131, 535, 18, 92, "MathCaption"],
Cell[4574, 151, 320, 9, 58, "MathCaption"],
Cell[4897, 162, 180, 5, 41, "MathCaption"],
Cell[5080, 169, 564, 22, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[5669, 195, 34, 0, 39, "ExampleSection"],
Cell[5706, 197, 99, 2, 29, "Input"],
Cell[5808, 201, 129, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[5962, 208, 804, 14, 229, "Input"],
Cell[6769, 224, 89549, 1889, 294, 12279, 930, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[96333, 2116, 95, 2, 25, "Text"],
Cell[96431, 2120, 117, 2, 29, "Input"],

Cell[CellGroupData[{
Cell[96573, 2126, 568, 11, 169, "Input"],
Cell[97144, 2139, 170195, 8002, 294, 89697, 7003, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[267354, 10144, 62, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[267441, 10148, 556, 10, 169, "Input"],
Cell[268000, 10160, 281812, 8478, 287, 156038, 6921, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[549827, 18641, 60, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[549912, 18645, 475, 10, 149, "Input"],
Cell[550390, 18657, 143393, 4801, 294, 46144, 3595, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[693798, 23461, 115, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[693938, 23468, 885, 16, 254, "Input"],
Cell[694826, 23486, 246707, 7635, 271, 140603, 6321, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[941548, 31124, 195, 4, 42, "Text"],
Cell[941746, 31130, 584, 10, 132, "Input"],

Cell[CellGroupData[{
Cell[942355, 31144, 845, 15, 254, "Input"],
Cell[943203, 31161, 193408, 5167, 271, 86522, 3843, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

