(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23063,        570]*)
(*NotebookOutlinePosition[     23742,        593]*)
(*  CellTagsIndexPosition[     23698,        589]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["DrawGraphics", "Title"],

Cell["\<\
\[Copyright] David Park, 2002, 2005
djmp@earthlink.net\
\>", "Subtitle"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input"],

Cell[CellGroupData[{

Cell["Features", "Section"],

Cell[CellGroupData[{

Cell["Drawing Paper Paradigm versus Set-Piece Paradigm", "Subsection",
  ShowGroupOpenCloseIcon->True],

Cell[TextData[{
  "DrawGraphics is an alternative paradigm for producing graphics in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". In the standard paradigm, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " presents a collection of set-piece plot types. Most of the plot types are \
somewhat adaptable. The set-piece plot types are well chosen. However, there \
is a large class of mathematical illustrations which do not fall neatly into \
one of these plot styles. This is especially so when one desires to combine \
elements from several different types of set-piece plots with other graphic \
primitives."
}], "Text",
  ShowGroupOpenCloseIcon->True],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " provides a method, using the Show statement, for combining various \
set-piece plots into a single plot. This is discussed in Section 1.9.4  of \
the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Book. But the method is not easy to use. One must either accept a number \
of side-plots, or take measures to turn the display off and on. Even more of \
a problem is controlling how options are picked up from the various plots."
}], "Text",
  ShowGroupOpenCloseIcon->True],

Cell[TextData[{
  "The DrawGraphics paradigm is to lay down a piece of paper, or an empty \
cube, and then draw upon it. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a number of Graphics primitives, such as Point, Line, Circle, Disk, \
Polygon etc., and Graphics directives, such as PointSize, Thickness, Dashing, \
RGBColor etc. If one desires to produce a piece of graphics using only these \
elements, the process is very simple. Use a Show[Graphics[{...}]] statement \
and add each of the desired graphic primitives and directives as in the \
following example."
}], "Text",
  ShowGroupOpenCloseIcon->True],

Cell[BoxData[
    \(\(Show[
        Graphics[\[IndentingNewLine]{LightBlue, 
            Rectangle[{\(-2\), \(-2\)}, {2, 2}], \[IndentingNewLine]Black, 
            Circle[{0, 0}, 2], \[IndentingNewLine]AbsolutePointSize[5], 
            Point[{0, 0}], \[IndentingNewLine]Red, 
            Line[{{\(-3\), \(-3\)}, {3, 
                  3}}]}], \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic];\)\)], "Input",
  ShowGroupOpenCloseIcon->True],

Cell[TextData[{
  "This is the natural way to do graphics. Specify the graphical directives \
we wish to have in effect and then draw the graphical objects we wish to have \
in our picture. Furthermore, any overall plot options that we wish to use, \
such as AspectRatio, are specified in the Show statement itself. This is a \
nice paradigm and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", itself, provides the framework for it."
}], "Text",
  ShowGroupOpenCloseIcon->True],

Cell[TextData[{
  "The only problem is that many of the graphical objects, such as arbitrary \
curves, do not fit into the paradigm. It would be nice if we could also treat \
curves and other complex graphical objects as primitives just like Points, \
Lines and Polygons. But basically, they ",
  StyleBox["are",
    FontSlant->"Italic"],
  " just Points, Lines and Polygons and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will produce them for us."
}], "Text",
  ShowGroupOpenCloseIcon->True],

Cell[TextData[{
  "The basic routines of DrawGraphics produce the various ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " set-piece plots, with the display turned off, and then extract the \
primitive graphic objects produced by the plot. These can then be used in the \
Show statement just like the other primitive graphic objects. Most of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " plot routines have their counterparts in DrawGraphics. Where the regular \
command has the word Plot, the DrawGraphics routine has the word Draw. Thus \
Plot becomes Draw, ParametricPlot becomes ParametricDraw, ImplicitPlot \
becomes ImplicitDraw. The Draw routines have the same form and accept the \
same options as the Plot routines, except that the overall Plot options that \
do not affect the graphical object, such as AspectRatio, Frame, PlotLabel \
etc., have no effect."
}], "Text",
  ShowGroupOpenCloseIcon->True],

Cell[TextData[{
  "So, with DrawGraphics, we can combine many different graphical elements in \
exactly the same manner as we combined the primitive graphics in the example \
above. Here is a fanciful piece of graphics that combines a ContourPlot, a \
Disk, a Circle, a DensityPlot, a regular Plot, a ParametricPlot, an \
ImplicitPlot, the points generated by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for the ImplicitPlot, some Text and various graphics directives."
}], "Text",
  ShowGroupOpenCloseIcon->True],

Cell[BoxData[{
    \(\(Draw2D[\[IndentingNewLine]{ContourDraw[
            Sin[x\ y], {x, \(-\[Pi]\)/2, \[Pi]/2}, {y, \(-1\), 
              1}], \[IndentingNewLine]Orchid, 
          Disk[{0, 0}, \@2/4], \[IndentingNewLine]Black, 
          Circle[{0, 0}, \@2/4], \[IndentingNewLine]DensityDraw[
            Sin[x\ y], {x, \(-1\)/4, 1/4}, {y, \(-1\)/4, 1/4}, 
            ColorFunction \[Rule] Hue, 
            PlotPoints \[Rule] 8], \[IndentingNewLine]Peacock, 
          Draw[Sin[x], {x, \(-\[Pi]\)/2, \[Pi]/2}], \[IndentingNewLine]Red, 
          ParametricDraw[{Cos[t], Sin[t]}, {t, 0, 
              2  \[Pi]}], \[IndentingNewLine]Blue, 
          ellipse = 
            ImplicitDraw[
              x\^2 + 3  y\^2 \[Equal] 1, {x, \(-1\), 
                1}], \[IndentingNewLine]LightBlue, PointSize[0.01], 
          ellipse /. 
            Line[pts_] \[RuleDelayed] Point /@ pts, \[IndentingNewLine]Gold, 
          Text["\<DrawGraphics!\>", 
            Scaled[{0.95, 
                0.1}], {1, \(-1\)}]}, \[IndentingNewLine]Frame \[Rule] True, 
        AspectRatio \[Rule] Automatic, Background \[Rule] Linen, 
        ImageSize \[Rule] 
          500, \[IndentingNewLine]TextStyle \[Rule] {FontSize \[Rule] 12, 
            FontWeight \[Rule] "\<Bold\>"}, \[IndentingNewLine]PlotLabel \
\[Rule] "\<Combining Plots, Graphics Primitives\n\t and Graphics \
Directives\>"];\)\), "\[IndentingNewLine]", 
    \(Clear[ellipse]\)}], "Input",
  ShowGroupOpenCloseIcon->True],

Cell["\<\
In 2D graphics, the order of drawing elements often matters. The DrawGraphics \
paradigm allows you to precisely specify the desired order.\
\>", "Text",
  ShowGroupOpenCloseIcon->True],

Cell[TextData[{
  "This is the natural way to build up ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics."
}], "Text",
  ShowGroupOpenCloseIcon->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Easy Manipulation of Generated Graphics Primitives", "Subsection",
  ShowGroupOpenCloseIcon->True],

Cell["\<\
Another advantage of the DrawGraphics paradigm is that the graphical \
primitives are immediately available and we can use other routines to \
manipulate them before they are rendered.\
\>", "Text",
  ShowGroupOpenCloseIcon->True],

Cell["\<\
Some of the routines that can be used for manipulation of graphical elements \
are:
1) DrawingTransform and DrawingTransform3D which allow a general mapping of \
all points in a piece of graphics.
2) UseAffineShape, UseRotateShape, UseTranslateShape and UseWireFrame \
directly apply the Shapes routines to a piece of graphics.
3) SplitLineOn... routines. These provide various ways to eliminate unwanted \
return lines in graphics.
4) FineGrain routines. These break long line segments into multiple pieces so \
that the DrawingTransform routines will work better.
5) StitchLineSegments will stitch together line segments produced by various \
plot routines.
6) DrawLineLabels. Attaches value labels to an existing set of lines.\
\>", "Text",
  ParagraphSpacing->{0, 0}],

Cell["\<\
A typical use for DrawingTransform is in making circular contour plots. \
ContourPlot only makes rectangular plots, but we can make a contour plot in \
the \[Theta]-r plane and then use DrawingTransform to transform it to a \
circular plot in the x-y plane. See the example under FineGrainPolygons. \
Sometimes filled plots may be difficult to produce in the desired display \
coordinates, but easy to produce in some other coordinate system. \
DrawingTransform can be used to transform the easy plots to the desired \
display coordinates.\
\>", "Text",
  ShowGroupOpenCloseIcon->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Convenience Routines", "Subsection",
  ShowGroupOpenCloseIcon->True],

Cell["\<\
A number of routines are also provided in DrawGraphics which I believe are \
generally useful in producing nice graphics. I am always interested in \
suggestions. If they are generally useful, and if I am capable of it, I will \
try to implement them.\
\>", "Text"],

Cell["\<\
BlankDrawingPaper and BlankDrawingCube are quick ways to lay down a blank \
piece of paper, or empty cube, to start drawing in. Draw2D and Draw3DItems \
are another quick way to start writing a graphics statement. (I couldn't use \
Draw3D because that is the DrawingCube version of Plot3D.) DontShow is a Show \
statement that suppresses display.\
\>", "Text"],

Cell["\<\
DrawGraphics and DrawGraphics3D will accommodate Plot types that have been \
written by third parties, or that I haven't covered. The only restriction is \
that it must be possible to convert their graphics output to Graphics or \
Graphics3D. So even if I have not provided a specific Draw routine for some \
plot type, you can still use it in the DrawGraphics paradigm.\
\>", "Text"],

Cell["\<\
ColorMix provides a way to mix two RGBColors. NeutralLighting provides \
LightSources and AmbientLighting that allow more neutral lighting and hence \
better display of colored surfaces. It also allows rotation of the light \
sources about the vertical axes.\
\>", "Text"],

Cell["\<\
ContourColors provides a ColorFunction for contour plots that clearly \
distinguishes each contour region. DrawLineLabels will label lines in a \
contour plot, and in other plots. The only requirement is that there is some \
function on the coordinates which is constant on the line.\
\>", "Text"],

Cell["\<\
DrawIndexedPoints makes it easy to click off and edit a set of points from a \
2D plot. SplineToLine generates a Spline function and then turns it into a \
regular line for applications where that is helpful.\
\>", "Text"],

Cell["\<\
In Integrals an iterator may have limits which depend upon a previous \
variable. In graphics the iterators must have fixed limits. But we can \
usually do a change of variable which converts variable limits to fixed \
limits. IteratorSubstitution does this and returns the transformed expression \
and the new fixed iterator. This is useful in smoothly fitting together 3D \
surfaces drawn with ParametricDraw3D.\
\>", "Text"],

Cell["\<\
CustomTicks and CustomGridLines provide an easy method for specifying ticks \
and grids for a plot. There is complete control of styles and formatting. \
XTickLine and YTickLine provide free standing scales.\
\>", "Text"],

Cell["\<\
The DrawingArrows package provides a number of routines for 2D and 3D arrows. \
ArrowCurve allows you to put arrowheads on curves. ProportionalArrow draws an \
arrow with the arrowhead a fractional distance along the shaft. Arrow3D \
provides 3D arrows using arrowcones. ArrowCurve3D allows arrowcones along a \
3D curved line.\
\>", "Text"],

Cell["\<\
MakePolyGrid, TrimPolygons and HollisGrid are routines for crafting 2D grids \
of various shapes. They can then be raised to 3D surfaces.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["DrawGraphics Palette", "Subsection",
  ShowGroupOpenCloseIcon->True],

Cell["\<\
Accompanying the packages is a DrawGraphics palette. This palette is \
basically a color palette which has all the (non-obsolete) colors from the \
Graphics`Colors` standard package. The color names are shown in the status \
area and you can just click a color to paste its name into your notebook.  \
The colors are arranged on the palette in five hue bands, and ordered roughly \
from dark to light in each band. In addition, there is a sixth grouping of \
nearly neutral colors. There are decidedly many more colors in the reddish \
band than in any other band. If you find a color that you like on the \
palette, but don't like the shade, you can easily adjust it by mixing it with \
Black or White using the ColorMix function.\
\>", "Text"],

Cell["\<\
There are three buttons at the bottom right of the palette marked \"C\",  \"D\
\" and \"A\".  The \"C\" button will paste in the ColorMix command. You can \
click the first color into your notebook, select it, and then click the \"C\" \
button, to obtain, for example:\
\>", "Text"],

Cell[BoxData[
    \(\(ColorMix[IndianRed, \[Placeholder]]\)[\[Placeholder]]\)], "Input",
  Evaluatable->False],

Cell["\<\
You can then fill in the second color and the fractional mix. See the \
ColorMix function for more information.\
\>", "Text"],

Cell[TextData[{
  "The \"D\" button will delete all graphics output cells in the notebook. It \
requires a great deal of memory to store most graphics cells, so it is often \
worthwhile to delete these cells before saving a notebook, or before sending \
a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook as an email attachment."
}], "Text"],

Cell["\<\
The \"A\" button is used in conjuction with animation statements. In a normal \
animation, all the animation cells (or movie frames) are first produced.  The \
\"A\" button can be used to paste in commands which automatically select \
these cells, close them, and then start the animation. These commands are:\
\>", "Text"],

Cell[BoxData[{
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]; Pause[0.01]; \), "\n", 
    \(FrontEndExecute[{FrontEnd`SelectionAnimate[200, 
          AnimationDisplayTime \[Rule] 0.1, 
          AnimationDirection \[Rule] Forward]}]\)}], "Input",
  Evaluatable->False],

Cell[TextData[{
  "They should be put in the same cell, and right after, the Animate or \
SpinShow statement (or whatever code you are using to produce the frames). \
Since they involve a fair amount of typing, and it is not always easy to \
remember their exact form, it is convenient to be able to paste them in. The \
first parameter in the SelectionAnimate statement is the time in seconds that \
the animation runs. The AnimationDirection may also be set to Backward or \
ForwardBackward. The Pause statement ensures that the frames are closed \
before the animation starts. A \"feature\" of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is that it seems to pause for a minimum of 1 second."
}], "Text"],

Cell[TextData[{
  "I am indebted to Jack Calman (",
  StyleBox["Jack.Calman@jhuapl.edu",
    FontFamily->"Times New Roman"],
  ") who supplied me with some original color palettes, of which this is a \
modification. I am also indebted to Ted Ersek (ErsekTR@navair.navy.mil)  who \
supplied me with a palette and code for deletion of graphics cells."
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notes and Comments", "Section"],

Cell["\<\
\[FilledSquare] To load the DrawGraphics routines simply use:\
\>", "Text"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  Evaluatable->False],

Cell["\<\
DrawingMaster contains DeclarePackage statements for each of the packages in \
DrawGraphics. The names of these packages are in the third column of the Help \
display. There is no sense in loading the packages individually since \
DrawingMaster will automatically load any package the first time a name from \
that package is used. DrawingMaster also loads Graphics`Colors` even if no \
colors are used. Each of the packages also automatically load the underlying \
standard packages that they require. Thus, for example, ImplicitDrawing loads \
ImplicitPlot. There are DeclarePackage statements for a few symbols in \
standard packages. These include, Arrow, PlotSymbol, MakeSymbol, Animate, \
SpinShow, ShowLegend, Legend, ShadowBox, Spline and AxesFront.
One exception to this is the Arrow command. DrawGraphics`DrawingArrows` \
contains extensions to the Arrow command. If you want to use these \
extensions, and have not previously used any other DrawingArrows commands, \
then the package must be explicitly loaded.\
\>", "Text"],

Cell[TextData[{
  "\[FilledSquare] The Help for DrawGraphics is in \
Add-ons/Extras/DrawGraphics. The third column in the categories section gives \
the names of the various packages in DrawGraphics. The fourth column gives \
the names of the functions in each package. There are individual Help pages \
for each command. Any options for a command are discussed under the command \
entry. Each command also has one or more examples. I have tried to make the \
examples simple but interesting.",
  " In a few cases it has taxed my ingenuity and the example is more fanciful \
than useful.",
  " You can get to the Help file for any command (although indirectly) by \
placing the cursor after the command name and pressing F1. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Help is one of its best features. It is just not possible to remember the \
details of thousands of commands. Every ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " user is well advised to keep Help ever handy."
}], "Text"],

Cell[TextData[{
  "\[FilledSquare] The best way to learn DrawGraphics is probably to look at \
the examples under the commands starting with DrawingPaper. The examples \
following the Introduction are more complex and are probably ",
  StyleBox["not",
    FontSlant->"Italic"],
  " the best place to start. Rather, they show a number of interesting \
techniques for producing graphics and often combine many elements. In some of \
the examples it may be advantageous to use the Hide Categories button on the \
Help window, and even to temporarily enlarge the Help window to full screen \
size."
}], "Text"],

Cell["\<\
\[FilledSquare] The FineGrain... , SplitLineOn...  commands, and \
UseRotateShape, UseAffineShape, UseTranslateShape have changed their usage \
from earlier versions and are, I hope, more convenient to use.\
\>", "Text"],

Cell["\<\
\[FilledSquare] The Draw routines convert all plots to Graphics or Graphics3D \
before extracting the elements.\
\>", "Text"],

Cell[TextData[{
  "\[FilledSquare] You can usually specify styles before drawing statements \
rather than using the PlotStyle option. But there are a few places where this \
does not work, such as ImplicitDraw, because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " embeds a style even if you haven't used PlotStyle."
}], "Text"],

Cell["\<\
\[FilledSquare] DrawGraphics is not appropiate for everything. Even I use \
Plot when I want a quick picture of some function. But DrawGraphics will \
generally be the easiest method if you want to produce a finished piece of \
graphics that includes a number of elements, or if you need some of its \
convenience routines.\
\>", "Text"],

Cell["\<\
\[FilledSquare] Think twice about using ListPlot and MultipleListPlot. They \
are often more of a hinderance than a help. If you have the data points, just \
Map Point, or PlotSymbol, or MakeSymbol on to them, and Apply Line to draw \
the line. No need to agonize over PlotJoined.\
\>", "Text"],

Cell["\<\
\[FilledSquare]  I want to thank Ted Ersek who allowed me to incorporate his \
PrecisionPlot code into DrawGraphics.\
\>", "Text"],

Cell[TextData[{
  "\[FilledSquare] Text3D is based on the Hershey fonts, which were designed \
by Dr. A. V. Hershey. They are readily available on the web in various forms. \
 In 1994, Roland Jakschewitz posted on ",
  StyleBox["MathSource",
    FontSlant->"Italic"],
  " a form of the Hershey fonts and a number of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " routines for using them. I want to thank Nicholas Georgakopoulos for \
providing me with the basic Text3D routine for inclusion in DrawGraphics. The \
present routine is significantly modified from his initial routine."
}], "Text"],

Cell["\<\
\[FilledSquare]  I am indebted to Selwyn Hollis for supplying the HollisGrid \
code for generating 2D grids of various shapes. I decided to call it a \
HollisGrid. Selwyn also provided the PolarDensityDraw and \
ListPolarDensityDraw code.\
\>", "Text"],

Cell["\<\
\[FilledSquare]  I want to thank all those who have given me their comments, \
criticisms and suggestions for DrawGraphics. I appreciate every one of them. \
I also appreciate those who have shared with me some of the graphics they \
have produced.\
\>", "Text"],

Cell[TextData[{
  " ",
  ButtonBox["djmp@earthlink.net",
    ButtonData:>{
      URL[ "mailto:djmp@earthlink.net"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"]
}, Closed]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowSize->{646, 721},
WindowMargins->{{2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 29, 0, 67, "Title"],
Cell[1786, 53, 82, 3, 66, "Subtitle"],
Cell[1871, 58, 73, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[1969, 63, 27, 0, 62, "Section"],

Cell[CellGroupData[{
Cell[2021, 67, 102, 1, 52, "Subsection"],
Cell[2126, 70, 676, 14, 105, "Text"],
Cell[2805, 86, 554, 12, 86, "Text"],
Cell[3362, 100, 628, 12, 105, "Text"],
Cell[3993, 114, 453, 9, 150, "Input"],
Cell[4449, 125, 489, 10, 86, "Text"],
Cell[4941, 137, 508, 12, 67, "Text"],
Cell[5452, 151, 938, 17, 143, "Text"],
Cell[6393, 170, 528, 10, 86, "Text"],
Cell[6924, 182, 1478, 28, 387, "Input"],
Cell[8405, 212, 195, 4, 48, "Text"],
Cell[8603, 218, 168, 6, 29, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8808, 229, 104, 1, 36, "Subsection"],
Cell[8915, 232, 240, 5, 48, "Text"],
Cell[9158, 239, 781, 15, 181, "Text"],
Cell[9942, 256, 595, 10, 105, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[10574, 271, 74, 1, 36, "Subsection"],
Cell[10651, 274, 275, 5, 48, "Text"],
Cell[10929, 281, 370, 6, 67, "Text"],
Cell[11302, 289, 394, 6, 86, "Text"],
Cell[11699, 297, 282, 5, 67, "Text"],
Cell[11984, 304, 307, 5, 67, "Text"],
Cell[12294, 311, 232, 4, 48, "Text"],
Cell[12529, 317, 437, 7, 86, "Text"],
Cell[12969, 326, 231, 4, 48, "Text"],
Cell[13203, 332, 351, 6, 67, "Text"],
Cell[13557, 340, 161, 3, 48, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[13755, 348, 74, 1, 36, "Subsection"],
Cell[13832, 351, 755, 11, 124, "Text"],
Cell[14590, 364, 292, 5, 67, "Text"],
Cell[14885, 371, 110, 2, 50, "Input",
  Evaluatable->False],
Cell[14998, 375, 135, 3, 29, "Text"],
Cell[15136, 380, 360, 8, 67, "Text"],
Cell[15499, 390, 333, 5, 67, "Text"],
Cell[15835, 397, 344, 6, 130, "Input",
  Evaluatable->False],
Cell[16182, 405, 721, 12, 124, "Text"],
Cell[16906, 419, 361, 7, 67, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17316, 432, 37, 0, 62, "Section"],
Cell[17356, 434, 85, 2, 29, "Text"],
Cell[17444, 438, 95, 2, 50, "Input",
  Evaluatable->False],
Cell[17542, 442, 1045, 15, 212, "Text"],
Cell[18590, 459, 1017, 19, 162, "Text"],
Cell[19610, 480, 606, 11, 105, "Text"],
Cell[20219, 493, 230, 4, 48, "Text"],
Cell[20452, 499, 135, 3, 29, "Text"],
Cell[20590, 504, 341, 7, 67, "Text"],
Cell[20934, 513, 347, 6, 67, "Text"],
Cell[21284, 521, 304, 5, 67, "Text"],
Cell[21591, 528, 140, 3, 29, "Text"],
Cell[21734, 533, 606, 12, 86, "Text"],
Cell[22343, 547, 262, 5, 48, "Text"],
Cell[22608, 554, 272, 5, 48, "Text"],
Cell[22883, 561, 164, 6, 29, "Text"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

