(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6948,        227]*)
(*NotebookOutlinePosition[      7879,        260]*)
(*  CellTagsIndexPosition[      7805,        254]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["IteratorSubstitution", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["IteratorSubstitution",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(expr, {var, limit1, limit2}, newvar : w\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  ", is used to transform a plot range iterator, which may contain variable \
limits, to one which contains constant limits. The plotting expr is \
transformed to the new variable and returned along with the new iterator."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "When multivariable integrations are performed, the limits for one iterator \
can depend upon a variable used in a previous iterator. It would be nice to \
do the same in two variable parametric plots. However, it is not directly \
allowed by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". The same result can be obtained by transforming the plotting expression \
by substituting a new variable which does have constant limits. \
IteratorSubstitution performs this transformation and gives the transformed \
expression and the new iterator, which can then be copied into the plotting \
routine."
}], "MathCaption"],

Cell["\<\
This provides a method for fitting surfaces together without zagged edges.\
\>", "MathCaption"],

Cell[TextData[{
  "Use ",
  Cell[BoxData[
      \(IteratorSubstitution[{var, expr}, {var, limit1, limit2}]\)]],
  " to also obtain the new expression for the variable itself."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "We can see what ",
  Cell[BoxData[
      \(IteratorSubstitution\)]],
  " does with the following generic statement."
}], "Text"],

Cell[BoxData[
    \(IteratorSubstitution[{y, g[x, y]}, {y, r[x], b[x]}, w]\)], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  "As ",
  Cell[BoxData[
      \(w\)]],
  " varies from 0 to 1, ",
  Cell[BoxData[
      \(w\ b[x]\  + \ r[x]\  - \ w\ r[x]\)]],
  " varies from ",
  Cell[BoxData[
      \(r[x]\)]],
  " to ",
  Cell[BoxData[
      \(b[x]\)]],
  ", so ",
  Cell[BoxData[
      \(f[x, w\ b[x]\  + \ r[x]\  - \ w\ r[x]]\)]],
  " varies from ",
  Cell[BoxData[
      \(f[x, r[x]]\)]],
  " to ",
  Cell[BoxData[
      \(f[x, b[x]]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Plot the region bounded below by the plane ",
  Cell[BoxData[
      \(z \[Equal] 0\)]],
  ", laterally by the cylinder ",
  Cell[BoxData[
      \(r \[Equal] 2\ Sin[\[Theta]]\)]],
  " and on the top by the paraboloid ",
  Cell[BoxData[
      \(z \[Equal] r\^2\)]],
  ". \nThe parametric representation for the side is:"
}], "Text"],

Cell[BoxData[{
    \(Needs["\<Calculus`VectorAnalysis`\>"]\), "\n", 
    \(side = 
      CoordinatesToCartesian[{2  Sin[\[Theta]], \[Theta], z}, 
        Cylindrical[r, \[Theta], z]]\)}], "Input",
  CellLabel->"In[3]:="],

Cell[TextData[{
  "But the iterator for ",
  Cell[BoxData[
      \(z\)]],
  " is ",
  Cell[BoxData[
      \({z, 0, \((2\ Sin[\[Theta]])\)\^2}\)]],
  " and plotting requires fixed iterator limits. Transform the \
parametrization. This generates the new parametrization in the variable w and \
the iterator which goes with it."
}], "Text"],

Cell[BoxData[
    \(IteratorSubstitution[{2\ Cos[\[Theta]]\ Sin[\[Theta]], 
        2\ Sin[\[Theta]]\^2, z}, \ {z, \ 0, \((2\ Sin[\[Theta]])\)\^2}, 
      w]\)], "Input",
  CellLabel->"In[5]:="],

Cell["Similarly for the top...", "Text"],

Cell[BoxData[
    \(top = 
      CoordinatesToCartesian[{r, \[Theta], r\^2}, 
        Cylindrical[r, \[Theta], z]]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(IteratorSubstitution[{r\ Cos[\[Theta]], r\ Sin[\[Theta]], r\^2}, {r, 0, 
        2  Sin[\[Theta]]}]\)], "Input",
  CellLabel->"In[7]:="],

Cell["We can now use these new parametrizations in the plotting.", "Text"],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{SurfaceColor[Cadet], 
          ParametricDraw3D[{Sin[2\ \[Theta]], 2\ Sin[\[Theta]]\^2, 
              4\ w\ Sin[\[Theta]]\^2}, {w, 0, 1}, {\[Theta], 0, \[Pi]}, 
            PlotPoints \[Rule] {9, 31}], \[IndentingNewLine]SurfaceColor[
            Goldenrod], 
          ParametricDraw3D[{w\ Sin[2\ \[Theta]], 2\ w\ Sin[\[Theta]]\^2, 
              4\ w\^2\ Sin[\[Theta]]\^2}, {w, 0, 1}, {\[Theta], 0, \[Pi]}, 
            PlotPoints \[Rule] {15, 31}]}, \[IndentingNewLine]NeutralLighting[
          0.3, 0.7, 
          0.0], \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {0, 
              2}, {0, 4}}, \[IndentingNewLine]Background \[Rule] 
          Wheat, \[IndentingNewLine]ViewPoint \[Rule] {3, \(-2\), 
            3}, \[IndentingNewLine]ImageSize \[Rule] {300, 500} 
            0.7];\)\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(Clear[side, top]\)], "Input",
  CellLabel->"In[9]:="],

Cell[TextData[{
  "See also the ",
  ButtonBox["Intersecting Cylinders",
    ButtonData:>{"Intersecting Cylinders"},
    ButtonStyle->"AddOnsLink"],
  " example."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{688, 729},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 67, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1846, 56, 556, 16, 67, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7634, 245}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 67, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1846, 56, 556, 16, 67, "Usage",
  CellTags->"Function?"],
Cell[2405, 74, 645, 12, 109, "MathCaption"],
Cell[3053, 88, 105, 2, 41, "MathCaption"],
Cell[3161, 92, 194, 5, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3380, 101, 33, 0, 39, "ExampleSection"],
Cell[3416, 103, 97, 2, 29, "Input"],
Cell[3516, 107, 147, 5, 25, "Text"],
Cell[3666, 114, 111, 2, 29, "Input"],
Cell[3780, 118, 447, 23, 42, "Text"],
Cell[4230, 143, 349, 11, 67, "Text"],
Cell[4582, 156, 220, 5, 49, "Input"],
Cell[4805, 163, 337, 10, 42, "Text"],
Cell[5145, 175, 194, 4, 30, "Input"],
Cell[5342, 181, 40, 0, 25, "Text"],
Cell[5385, 183, 151, 4, 30, "Input"],
Cell[5539, 189, 156, 3, 30, "Input"],
Cell[5698, 194, 74, 0, 25, "Text"],
Cell[5775, 196, 892, 15, 215, "Input"],
Cell[6670, 213, 73, 2, 29, "Input"],
Cell[6746, 217, 174, 6, 25, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

