(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4605,        159]*)
(*NotebookOutlinePosition[      5576,        193]*)
(*  CellTagsIndexPosition[      5502,        187]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ListDraw", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      \(ListDraw[{y\_1, y\_2,  ... }, opts ... ]\)]],
  " extracts the graphics primitives from the corresponding ListPlot \
statement.\n\[FilledSmallSquare] ",
  Cell[BoxData[
      \(ListDraw[{{x\_1, y\_1}, {x\_2 . y\_2},  ... }, opts ... ]\)]],
  "extracts the graphics primitives from the corresponding ListPlot \
statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as ListPlot. Regular ListPlot options may be used. Basic \
Graphics options, such as PlotRange have no effect.\
\>", "MathCaption"],

Cell["\<\
If you use DrawingPaper, ListDraw is not a very necessary command. See the \
examples.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ListPlot",
    ButtonStyle->"RefGuideLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Here is some simulated data.", "Text"],

Cell[BoxData[
    \(\(data = 
        Table[{x, 1 - E\^\(-x\) + Random[Real, {\(-0.05\), 0.05}]}, {x, 0, 2, 
            0.1}];\)\)], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
We can obtain the line and the points by using ListDraw twice.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{AbsolutePointSize[4], 
          ListDraw[data], \[IndentingNewLine]Blue, 
          ListDraw[data, 
            PlotJoined \[Rule] True]}, \[IndentingNewLine]Frame \[Rule] 
          True];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
But since we have the data points we can do the above just as easily using \
the following.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{AbsolutePointSize[4], 
          Point /@ data, \[IndentingNewLine]Blue, 
          Line[data]}, \[IndentingNewLine]Frame \[Rule] True];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
The following fits the data and plots the points and the datafit.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(datafit[x_] = Fit[data, {1, E\^\(-x\)}, x]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(\(\(0.9867037983820448`\)\(\[InvisibleSpace]\)\) - 
      0.9919092127599174`\ \[ExponentialE]\^\(-x\)\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{AbsolutePointSize[4], 
          Point /@ data, \[IndentingNewLine]CadetBlue, 
          Draw[datafit[x], {x, 0, 2}]}, \[IndentingNewLine]Frame \[Rule] 
          True];\)\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(Clear[data, datafit]\)], "Input",
  CellLabel->"In[7]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{494, 740},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 55, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1834, 56, 426, 11, 90, "Usage",
      CellTags->"Function?"],
    Cell[2263, 69, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5256, 176}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 55, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1834, 56, 426, 11, 90, "Usage",
  CellTags->"Function?"],
Cell[2263, 69, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2360, 74, 159, 3, 58, "MathCaption"],
Cell[2522, 79, 117, 3, 58, "MathCaption"],
Cell[2642, 84, 114, 5, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[2781, 93, 34, 0, 39, "ExampleSection"],
Cell[2818, 95, 97, 2, 29, "Input"],
Cell[2918, 99, 44, 0, 25, "Text"],
Cell[2965, 101, 166, 4, 49, "Input"],
Cell[3134, 107, 86, 2, 25, "Text"],
Cell[3223, 111, 278, 6, 89, "Input"],
Cell[3504, 119, 115, 3, 25, "Text"],
Cell[3622, 124, 224, 4, 89, "Input"],
Cell[3849, 130, 89, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[3963, 136, 99, 2, 29, "Input"],
Cell[4065, 140, 160, 3, 23, "Output"]
}, Open  ]],
Cell[4240, 146, 257, 5, 89, "Input"],
Cell[4500, 153, 77, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

