(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    214961,       6163]*)
(*NotebookOutlinePosition[    215935,       6197]*)
(*  CellTagsIndexPosition[    215858,       6191]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ListDrawVectorField3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          RowBox[{"List", 
            StyleBox["DrawVectorField",
              "MR"]}]], 
        StyleBox["[",
          "MR"], 
        RowBox[{
          RowBox[{
            StyleBox["{",
              "MR"], 
            StyleBox[\({pt, vec},  ... \),
              "TI"], 
            StyleBox["}",
              "TI"]}], 
          StyleBox[",",
            "TI"], 
          StyleBox[\(opts ... \),
            "TI"]}], 
        StyleBox["]",
          "MR"]}]]],
  "\n extracts the graphics primitives from the corresponding \
ListPlotVectorField3D statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as ListPlotVectorField3D. Regular ListPlotVectorField3D \
options may be used. Basic Graphics3D options, such as PlotRange have no \
effect.\
\>", "MathCaption"],

Cell[TextData[{
  "Also consider using lists of ",
  ButtonBox["Arrow3D",
    ButtonData:>{"Arrow3D"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawGradientField3D",
    ButtonData:>{"DrawGradientField3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DrawVectorField3D",
    ButtonData:>{"DrawVectorField3D"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["ListPlotVectorField3D",
    ButtonData:>{"Graphics`PlotField3D`", "1.11"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Here, F is a vector field and \[Sigma] is one of the flow lines on the \
field..\
\>", "Text"],

Cell[BoxData[{
    \(F[x_, y_, z_] := {y + 1, 2, 1/\((2  z)\)}\), "\[IndentingNewLine]", 
    \(\[Sigma][t_] := {t\^2, 2  t - 1, \@t}\)}], "Input",
  CellLabel->"In[284]:="],

Cell[TextData[{
  "This generates a table of ",
  Cell[BoxData[
      \({pt, \ vec}\)]],
  " which we can use in ListDrawVectorField3D. Don't forget to Flatten."
}], "Text"],

Cell[BoxData[
    \(\(vectors = 
        Flatten[Table[{{x, y, z}, F[x, y, z]}, {x, 0, 2, 0.5}, {y, 0, 2, 
              0.5}, {z, 0.5, 2, 0.5}], 2];\)\)], "Input",
  CellLabel->"In[286]:="],

Cell["\<\
Here we plot the field and the \[Sigma] trajectory using ArrowCurve3D.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(With[\[IndentingNewLine]{trajectory = 
            ParametricDraw3D[\[Sigma][t] // Evaluate, {t, 0.5, 
                1.5}]}, \[IndentingNewLine]plot1 = \
\[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{SteelBlue, \
\[IndentingNewLine]ListDrawVectorField3D[vectors, 
                ScaleFunction \[Rule] \((1/4 &)\), 
                VectorHeads \[Rule] 
                  True], \[IndentingNewLine]\[IndentingNewLine]Indigo, 
              AbsoluteThickness[2], 
              trajectory, \[IndentingNewLine]SurfaceColor[
                EnglishRed], \(ArrowCurve3D[trajectory, #] &\) /@ 
                Range[1/4, 1, 
                  1/4]}, \[IndentingNewLine]\[IndentingNewLine]\
NeutralLighting[0.3, 0.6, 0.0], \[IndentingNewLine]Background \[Rule] 
              Linen, \[IndentingNewLine]Boxed \[Rule] 
              True, \[IndentingNewLine]Axes \[Rule] 
              True, \[IndentingNewLine]ImageSize \[Rule] 400]];\)\)], "Input",\

  CellLabel->"In[287]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9477 
%%ImageSize: 400 379.079 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
7.47828e-017 1.04569 -0.00350714 1.04569 [
[.06612 .2381 -6 -8.93499 ]
[.06612 .2381 0 .06501 ]
[.18783 .1888 -17.3871 -9 ]
[.18783 .1888 .61286 0 ]
[.31563 .13705 -5.54746 -9 ]
[.31563 .13705 .45254 0 ]
[.44998 .08268 -15.8976 -9 ]
[.44998 .08268 2.10241 0 ]
[.59139 .02548 -5.05094 -9 ]
[.59139 .02548 .94906 0 ]
[.00923 .67634 -3.45231 0 ]
[.00923 .67634 2.54769 9 ]
[.10864 .75148 -10.0707 0 ]
[.10864 .75148 7.92931 9 ]
[.19913 .81988 -3.27355 0 ]
[.19913 .81988 2.72645 9 ]
[.28185 .88239 -9.60039 0 ]
[.28185 .88239 8.39961 9 ]
[.35775 .93976 -3.13495 0 ]
[.35775 .93976 2.86505 9 ]
[.0487 .26596 -18 -2.69286 ]
[.0487 .26596 0 6.30714 ]
[.03114 .37885 -6 -2.78891 ]
[.03114 .37885 0 6.21109 ]
[.01221 .50059 -18 -2.89328 ]
[.01221 .50059 0 6.10672 ]
[-0.00827 .63229 -6 -3.00708 ]
[-0.00827 .63229 0 5.99292 ]
[ 0 0 0 0 ]
[ 1 .9477 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.06214 .25263 m
.68873 0 L
s
.07543 .24727 m
.08008 .25186 L
s
[(0)] .06612 .2381 1 .98555 Mshowa
.19674 .19836 m
.2012 .20314 L
s
[(0.5)] .18783 .1888 .9319 1 Mshowa
.32409 .14702 m
.32832 .152 L
s
[(1)] .31563 .13705 .84915 1 Mshowa
.45793 .09305 m
.4619 .09824 L
s
[(1.5)] .44998 .08268 .7664 1 Mshowa
.59877 .03627 m
.60246 .04167 L
s
[(2)] .59139 .02548 .68365 1 Mshowa
.125 Mabswid
.09923 .23767 m
.102 .24045 L
s
.12326 .22799 m
.126 .23079 L
s
.14752 .21821 m
.15024 .22103 L
s
.17201 .20833 m
.17471 .21118 L
s
.22172 .18829 m
.22436 .19118 L
s
.24693 .17812 m
.24956 .18104 L
s
.2724 .16786 m
.27499 .1708 L
s
.29812 .15749 m
.30068 .16045 L
s
.35032 .13644 m
.35283 .13945 L
s
.37682 .12576 m
.3793 .12879 L
s
.40358 .11497 m
.40603 .11803 L
s
.43062 .10407 m
.43304 .10715 L
s
.48552 .08193 m
.48787 .08507 L
s
.51339 .07069 m
.51571 .07385 L
s
.54156 .05934 m
.54384 .06252 L
s
.57001 .04786 m
.57226 .05108 L
s
.62783 .02456 m
.63 .02782 L
s
.65719 .01272 m
.65933 .016 L
s
.68687 .00075 m
.68897 .00406 L
s
.25 Mabswid
0 .65494 m
.38602 .9477 L
s
.01118 .66342 m
.01215 .65696 L
s
[(0)] .00923 .67634 .15077 -1 Mshowa
.11018 .7385 m
.11095 .73201 L
s
[(0.5)] .10864 .75148 .11897 -1 Mshowa
.20031 .80686 m
.20091 .80035 L
s
[(1)] .19913 .81988 .09118 -1 Mshowa
.28272 .86935 m
.28315 .86283 L
s
[(1.5)] .28185 .88239 .06671 -1 Mshowa
.35834 .9267 m
.35864 .92018 L
s
[(2)] .35775 .93976 .04498 -1 Mshowa
.125 Mabswid
.03175 .67902 m
.03231 .67514 L
s
.05192 .69432 m
.05246 .69044 L
s
.07171 .70933 m
.07222 .70544 L
s
.09113 .72406 m
.09162 .72016 L
s
.12888 .75268 m
.12932 .74879 L
s
.14723 .7666 m
.14765 .7627 L
s
.16525 .78027 m
.16564 .77636 L
s
.18294 .79368 m
.18332 .78978 L
s
.21738 .8198 m
.21772 .81589 L
s
.23415 .83252 m
.23446 .82861 L
s
.25062 .84501 m
.25092 .8411 L
s
.26681 .85729 m
.26709 .85337 L
s
.29836 .88121 m
.2986 .8773 L
s
.31373 .89287 m
.31396 .88896 L
s
.32885 .90434 m
.32906 .90042 L
s
.34372 .91561 m
.34391 .9117 L
s
.37273 .93761 m
.37289 .9337 L
s
.25 Mabswid
.06214 .25263 m
0 .65494 L
s
.06083 .26109 m
.0669 .25866 L
s
[(0.5)] .0487 .26596 1 -0.40159 Mshowa
.04336 .3742 m
.04947 .37188 L
s
[(1)] .03114 .37885 1 -0.38024 Mshowa
.02452 .4962 m
.03067 .494 L
s
[(1.5)] .01221 .50059 1 -0.35705 Mshowa
.00413 .62818 m
.01034 .62612 L
s
[(2)] -0.00827 .63229 1 -0.33176 Mshowa
.125 Mabswid
.05744 .28305 m
.06108 .2816 L
s
.054 .30533 m
.05765 .3039 L
s
.0505 .32795 m
.05416 .32653 L
s
.04696 .3509 m
.05062 .34949 L
s
.03971 .39786 m
.04338 .39648 L
s
.036 .42188 m
.03967 .42051 L
s
.03223 .44627 m
.03591 .44492 L
s
.0284 .47104 m
.03209 .4697 L
s
.02057 .52176 m
.02427 .52045 L
s
.01656 .54772 m
.02026 .54644 L
s
.01248 .57411 m
.0162 .57284 L
s
.00834 .60092 m
.01206 .59967 L
s
.25 Mabswid
.06214 .25263 m
0 .65494 L
s
0 .65494 m
.38602 .9477 L
s
.38602 .9477 m
.39962 .58221 L
s
.39962 .58221 m
.06214 .25263 L
s
.68873 0 m
.94771 .40915 L
s
.94771 .40915 m
1 .79557 L
s
1 .79557 m
.71435 .42163 L
s
.71435 .42163 m
.68873 0 L
s
.06214 .25263 m
0 .65494 L
s
0 .65494 m
.71435 .42163 L
s
.71435 .42163 m
.68873 0 L
s
.68873 0 m
.06214 .25263 L
s
.39962 .58221 m
.94771 .40915 L
s
.94771 .40915 m
1 .79557 L
s
1 .79557 m
.38602 .9477 L
s
.38602 .9477 m
.39962 .58221 L
s
0 0 m
1 0 L
1 .9477 L
0 .9477 L
closepath
clip
newpath
.274 .51 .706 r
.5 Mabswid
.43373 .58068 m
.4317 .58256 L
s
.43684 .5687 m
.43373 .58068 L
s
.44623 .57899 m
.43373 .58068 L
s
.43483 .57052 m
.43684 .5687 L
s
.43684 .5687 m
.44623 .57899 L
s
.38657 .56216 m
.44623 .57899 L
s
.44623 .57899 m
.4317 .58256 L
s
.43483 .57052 m
.44623 .57899 L
s
.4317 .58256 m
.43483 .57052 L
s
.54368 .54616 m
.5422 .54789 L
s
.54695 .5339 m
.54368 .54616 L
s
.55683 .5443 m
.54368 .54616 L
s
.54548 .53557 m
.54695 .5339 L
s
.54695 .5339 m
.55683 .5443 L
s
.49568 .52721 m
.55683 .5443 L
s
.55683 .5443 m
.5422 .54789 L
s
.54548 .53557 m
.55683 .5443 L
s
.5422 .54789 m
.54548 .53557 L
s
.43242 .68074 m
.43151 .68348 L
s
.43444 .66821 m
.43242 .68074 L
s
.44567 .67795 m
.43242 .68074 L
s
.43354 .67089 m
.43444 .66821 L
s
.43444 .66821 m
.44567 .67795 L
s
.38221 .66734 m
.44567 .67795 L
s
.44567 .67795 m
.43151 .68348 L
s
.43354 .67089 m
.44567 .67795 L
s
.43151 .68348 m
.43354 .67089 L
s
.36699 .51952 m
.36507 .52098 L
s
.37123 .50732 m
.36699 .51952 L
s
.3803 .51855 m
.36699 .51952 L
s
.36932 .50872 m
.37123 .50732 L
s
.37123 .50732 m
.3803 .51855 L
s
.31962 .4965 m
.3803 .51855 L
s
.3803 .51855 m
.36507 .52098 L
s
.36932 .50872 m
.3803 .51855 L
s
.65824 .51018 m
.65734 .51176 L
s
.66167 .49763 m
.65824 .51018 L
s
.67207 .50816 m
.65824 .51018 L
s
.66079 .49914 m
.66167 .49763 L
s
.66167 .49763 m
.67207 .50816 L
s
.60937 .49079 m
.67207 .50816 L
s
.36507 .52098 m
.36932 .50872 L
s
.67207 .50816 m
.65734 .51176 L
s
.66079 .49914 m
.67207 .50816 L
s
.65734 .51176 m
.66079 .49914 L
s
.54573 .64726 m
.54543 .64988 L
s
.54788 .63444 m
.54573 .64726 L
s
.55962 .64431 m
.54573 .64726 L
s
.54759 .63699 m
.54788 .63444 L
s
.54788 .63444 m
.55962 .64431 L
s
.4948 .63348 m
.55962 .64431 L
s
.55962 .64431 m
.54543 .64988 L
s
.54759 .63699 m
.55962 .64431 L
s
.54543 .64988 m
.54759 .63699 L
s
.47974 .48237 m
.4784 .48365 L
s
.48415 .46988 m
.47974 .48237 L
s
.49371 .48125 m
.47974 .48237 L
s
.48283 .4711 m
.48415 .46988 L
s
.48415 .46988 m
.49371 .48125 L
s
.4316 .45877 m
.49371 .48125 L
s
.49371 .48125 m
.4784 .48365 L
s
.48283 .4711 m
.49371 .48125 L
s
.42977 .79088 m
.42925 .79439 L
s
.43143 .77797 m
.42977 .79088 L
s
.44353 .78784 m
.42977 .79088 L
s
.77769 .47267 m
.77745 .47407 L
s
.7813 .45982 m
.77769 .47267 L
s
.79227 .47046 m
.77769 .47267 L
s
.43092 .78141 m
.43143 .77797 L
s
.43143 .77797 m
.44353 .78784 L
s
.78107 .46115 m
.7813 .45982 L
s
.7813 .45982 m
.79227 .47046 L
s
.72793 .45282 m
.79227 .47046 L
s
.4784 .48365 m
.48283 .4711 L
s
.44353 .78784 m
.42925 .79439 L
s
.43092 .78141 m
.44353 .78784 L
s
.37757 .77946 m
.44353 .78784 L
s
.79227 .47046 m
.77745 .47407 L
s
.78107 .46115 m
.79227 .47046 L
s
.42925 .79439 m
.43092 .78141 L
s
.36391 .62102 m
.36326 .6235 L
s
.36693 .60812 m
.36391 .62102 L
s
.37814 .61881 m
.36391 .62102 L
s
.77745 .47407 m
.78107 .46115 L
s
.36629 .61052 m
.36693 .60812 L
s
.36693 .60812 m
.37814 .61881 L
s
.37814 .61881 m
.36326 .6235 L
s
.36629 .61052 m
.37814 .61881 L
s
.31287 .60369 m
.37814 .61881 L
s
.66393 .61234 m
.66429 .61482 L
s
.66623 .59921 m
.66393 .61234 L
s
.67852 .60921 m
.66393 .61234 L
s
.6666 .60162 m
.66623 .59921 L
s
.66623 .59921 m
.67852 .60921 L
s
.36326 .6235 m
.36629 .61052 L
s
.29407 .45429 m
.29243 .45525 L
s
.29974 .44206 m
.29407 .45429 L
s
.30829 .45441 m
.29407 .45429 L
s
.61226 .59815 m
.67852 .60921 L
s
.67852 .60921 m
.66429 .61482 L
s
.6666 .60162 m
.67852 .60921 L
s
.29814 .44295 m
.29974 .44206 L
s
.29974 .44206 m
.30829 .45441 L
s
.66429 .61482 m
.6666 .60162 L
s
.30829 .45441 m
.29243 .45525 L
s
.29814 .44295 m
.30829 .45441 L
s
.2473 .42556 m
.30829 .45441 L
s
.59738 .4436 m
.59668 .44469 L
s
.60198 .43081 m
.59738 .4436 L
s
.61207 .44232 m
.59738 .4436 L
s
.6013 .43183 m
.60198 .43081 L
s
.60198 .43081 m
.61207 .44232 L
s
.29243 .45525 m
.29814 .44295 L
s
.54847 .41939 m
.61207 .44232 L
s
.61207 .44232 m
.59668 .44469 L
s
.6013 .43183 m
.61207 .44232 L
s
.54676 .75871 m
.5469 .76211 L
s
.54855 .74549 m
.54676 .75871 L
s
.56119 .75549 m
.54676 .75871 L
s
.90237 .43352 m
.90283 .43472 L
s
.90616 .42035 m
.90237 .43352 L
s
.91773 .43111 m
.90237 .43352 L
s
.5487 .74882 m
.54855 .74549 L
s
.54855 .74549 m
.56119 .75549 L
s
.90664 .42149 m
.90616 .42035 L
s
.90616 .42035 m
.91773 .43111 L
s
.85168 .41318 m
.91773 .43111 L
s
.59668 .44469 m
.6013 .43183 L
s
.56119 .75549 m
.5469 .76211 L
s
.5487 .74882 m
.56119 .75549 L
s
.49385 .74692 m
.56119 .75549 L
s
.91773 .43111 m
.90283 .43472 L
s
.90664 .42149 m
.91773 .43111 L
s
.5469 .76211 m
.5487 .74882 L
s
.48016 .58492 m
.48017 .58724 L
s
.48334 .5717 m
.48016 .58492 L
s
.49505 .58255 m
.48016 .58492 L
s
.90283 .43472 m
.90664 .42149 L
s
.48336 .57395 m
.48334 .5717 L
s
.48334 .5717 m
.49505 .58255 L
s
.49505 .58255 m
.48017 .58724 L
s
.48336 .57395 m
.49505 .58255 L
s
.42851 .56704 m
.49505 .58255 L
s
.78735 .57588 m
.78843 .5782 L
s
.78981 .56243 m
.78735 .57588 L
s
.80268 .57255 m
.78735 .57588 L
s
.42674 .90947 m
.42641 .91381 L
s
.42823 .8962 m
.42674 .90947 L
s
.44098 .90642 m
.42674 .90947 L
s
.79091 .56467 m
.78981 .56243 L
s
.78981 .56243 m
.80268 .57255 L
s
.48017 .58724 m
.48336 .57395 L
s
.4279 .90047 m
.42823 .8962 L
s
.42823 .8962 m
.44098 .90642 L
s
.40966 .41422 m
.40866 .41497 L
s
.41552 .4017 m
.40966 .41422 L
s
.42455 .41422 m
.40966 .41422 L
s
.73492 .56126 m
.80268 .57255 L
s
.80268 .57255 m
.78843 .5782 L
s
.79091 .56467 m
.80268 .57255 L
s
.41456 .40237 m
.41552 .4017 L
s
.41552 .4017 m
.42455 .41422 L
s
.44098 .90642 m
.42641 .91381 L
s
.4279 .90047 m
.44098 .90642 L
s
.37262 .89924 m
.44098 .90642 L
s
.78843 .5782 m
.79091 .56467 L
s
.42455 .41422 m
.40866 .41497 L
s
.41456 .40237 m
.42455 .41422 L
s
.36227 .38471 m
.42455 .41422 L
s
.35895 .73329 m
.35874 .73661 L
s
.36157 .71994 m
.35895 .73329 L
s
.37375 .73075 m
.35895 .73329 L
s
.42641 .91381 m
.4279 .90047 L
s
.36138 .72318 m
.36157 .71994 L
s
.36157 .71994 m
.37375 .73075 L
s
.72026 .4031 m
.72027 .40398 L
s
.72506 .39 m
.72026 .4031 L
s
.73571 .40166 m
.72026 .4031 L
s
.72509 .3908 m
.72506 .39 L
s
.72506 .39 m
.73571 .40166 L
s
.40866 .41497 m
.41456 .40237 L
s
.37375 .73075 m
.35874 .73661 L
s
.36138 .72318 m
.37375 .73075 L
s
.30565 .71825 m
.37375 .73075 L
s
.67056 .37826 m
.73571 .40166 L
s
.73571 .40166 m
.72027 .40398 L
s
.72509 .3908 m
.73571 .40166 L
s
.66897 .72509 m
.66983 .72838 L
s
.67091 .71155 m
.66897 .72509 L
s
.68412 .7217 m
.66897 .72509 L
s
.67178 .71476 m
.67091 .71155 L
s
.67091 .71155 m
.68412 .7217 L
s
.35874 .73661 m
.36138 .72318 L
s
.28898 .55723 m
.2888 .55943 L
s
.29331 .54407 m
.28898 .55723 L
s
.30434 .55596 m
.28898 .55723 L
s
.29315 .54619 m
.29331 .54407 L
s
.29331 .54407 m
.30434 .55596 L
s
.72027 .40398 m
.72509 .3908 L
s
.68412 .7217 m
.66983 .72838 L
s
.67178 .71476 m
.68412 .7217 L
s
.61534 .71292 m
.68412 .7217 L
s
.30434 .55596 m
.2888 .55943 L
s
.29315 .54619 m
.30434 .55596 L
s
.23776 .53475 m
.30434 .55596 L
s
.66983 .72838 m
.67178 .71476 L
s
.60164 .54719 m
.60236 .54935 L
s
.60498 .53365 m
.60164 .54719 L
s
.61723 .54466 m
.60164 .54719 L
s
.2888 .55943 m
.29315 .54619 L
s
.60572 .53573 m
.60498 .53365 L
s
.60498 .53365 m
.61723 .54466 L
s
.21374 .38448 m
.21271 .38489 L
s
.22119 .37253 m
.21374 .38448 L
s
.22894 .38617 m
.21374 .38448 L
s
.22021 .37287 m
.22119 .37253 L
s
.22119 .37253 m
.22894 .38617 L
s
.61723 .54466 m
.60236 .54935 L
s
.60572 .53573 m
.61723 .54466 L
s
.54936 .52875 m
.61723 .54466 L
s
.91634 .53777 m
.91821 .53992 L
s
.91897 .52398 m
.91634 .53777 L
s
.93246 .53424 m
.91634 .53777 L
s
.22894 .38617 m
.21271 .38489 L
s
.22021 .37287 m
.22894 .38617 L
s
.16893 .34869 m
.22894 .38617 L
s
.54769 .87886 m
.54806 .88312 L
s
.54932 .86527 m
.54769 .87886 L
s
.56264 .87565 m
.54769 .87886 L
s
.92086 .52605 m
.91897 .52398 L
s
.91897 .52398 m
.93246 .53424 L
s
.60236 .54935 m
.60572 .53573 L
s
.5497 .86945 m
.54932 .86527 L
s
.54932 .86527 m
.56264 .87565 L
s
.53049 .37234 m
.53018 .37286 L
s
.53655 .35951 m
.53049 .37234 L
s
.5461 .3722 m
.53049 .37234 L
s
.86314 .5227 m
.93246 .53424 L
s
.93246 .53424 m
.91821 .53992 L
s
.92086 .52605 m
.93246 .53424 L
s
.53629 .35995 m
.53655 .35951 L
s
.53655 .35951 m
.5461 .3722 L
s
.21271 .38489 m
.22021 .37287 L
s
.56264 .87565 m
.54806 .88312 L
s
.5497 .86945 m
.56264 .87565 L
s
.49284 .86828 m
.56264 .87565 L
s
.91821 .53992 m
.92086 .52605 L
s
.5461 .3722 m
.53018 .37286 L
s
.53629 .35995 m
.5461 .3722 L
s
.48247 .342 m
.5461 .3722 L
s
.47907 .6985 m
.47957 .70169 L
s
.48184 .68482 m
.47907 .6985 L
s
.49456 .6958 m
.47907 .6985 L
s
.54806 .88312 m
.5497 .86945 L
s
.48237 .68793 m
.48184 .68482 L
s
.48184 .68482 m
.49456 .6958 L
s
.84874 .36077 m
.8495 .36141 L
s
.85374 .34733 m
.84874 .36077 L
s
.865 .35913 m
.84874 .36077 L
s
.85454 .3479 m
.85374 .34733 L
s
.85374 .34733 m
.865 .35913 L
s
.53018 .37286 m
.53629 .35995 L
s
.49456 .6958 m
.47957 .70169 L
s
.48237 .68793 m
.49456 .6958 L
s
.42519 .68293 m
.49456 .6958 L
s
.79821 .33525 m
.865 .35913 L
s
.865 .35913 m
.8495 .36141 L
s
.85454 .3479 m
.865 .35913 L
s
.79677 .68995 m
.7984 .6931 L
s
.79886 .67607 m
.79677 .68995 L
s
.81268 .68636 m
.79677 .68995 L
s
.80051 .67914 m
.79886 .67607 L
s
.79886 .67607 m
.81268 .68636 L
s
.47957 .70169 m
.48237 .68793 L
s
.40824 .51821 m
.40876 .52022 L
s
.41274 .50472 m
.40824 .51821 L
s
.42425 .51681 m
.40824 .51821 L
s
.41329 .50666 m
.41274 .50472 L
s
.41274 .50472 m
.42425 .51681 L
s
.8495 .36141 m
.85454 .3479 L
s
.81268 .68636 m
.7984 .6931 L
s
.80051 .67914 m
.81268 .68636 L
s
.7424 .67736 m
.81268 .68636 L
s
.42425 .51681 m
.40876 .52022 L
s
.41329 .50666 m
.42425 .51681 L
s
.35658 .49496 m
.42425 .51681 L
s
.7984 .6931 m
.80051 .67914 L
s
.7287 .50773 m
.7302 .5097 L
s
.73222 .49385 m
.7287 .50773 L
s
.74504 .50502 m
.7287 .50773 L
s
.35334 .85459 m
.35336 .85879 L
s
.35579 .84083 m
.35334 .85459 L
s
.3687 .85199 m
.35334 .85459 L
s
.40876 .52022 m
.41329 .50666 L
s
.73374 .49573 m
.73222 .49385 L
s
.73222 .49385 m
.74504 .50502 L
s
.35582 .84495 m
.35579 .84083 L
s
.35579 .84083 m
.3687 .85199 L
s
.33221 .34116 m
.33187 .34131 L
s
.33987 .32893 m
.33221 .34116 L
s
.34807 .34278 m
.33221 .34116 L
s
.33958 .32901 m
.33987 .32893 L
s
.33987 .32893 m
.34807 .34278 L
s
.74504 .50502 m
.7302 .5097 L
s
.73374 .49573 m
.74504 .50502 L
s
.6758 .48868 m
.74504 .50502 L
s
.3687 .85199 m
.35336 .85879 L
s
.35582 .84495 m
.3687 .85199 L
s
.29792 .84096 m
.3687 .85199 L
s
.721 .201 .086 r
.93599 .55479 m .84998 .54251 L .84879 .55463 L closepath p F P
0 0 0 r
s
.786 .224 .097 r
.93599 .55479 m .85234 .53039 L .84998 .54251 L closepath p F P
0 0 0 r
s
.274 .51 .706 r
.34807 .34278 m
.33187 .34131 L
s
.33958 .32901 m
.34807 .34278 L
s
.287 .30431 m
.34807 .34278 L
s
.67423 .84685 m
.67538 .85101 L
s
.67601 .83291 m
.67423 .84685 L
s
.68994 .84345 m
.67423 .84685 L
s
.812 .238 .104 r
.93599 .55479 m .85498 .52283 L .85234 .53039 L closepath p F P
0 0 0 r
s
.554 .146 .063 r
.93599 .55479 m .84879 .55463 L .84922 .56222 L closepath p F P
0 0 0 r
s
.274 .51 .706 r
.7302 .5097 m
.73374 .49573 L
s
.28132 .67162 m
.28166 .67475 L
s
.28523 .65792 m
.28132 .67162 L
s
.29735 .66993 m
.28132 .67162 L
s
.67716 .83699 m
.67601 .83291 L
s
.67601 .83291 m
.68994 .84345 L
s
.35336 .85879 m
.35582 .84495 L
s
.28558 .66096 m
.28523 .65792 L
s
.28523 .65792 m
.29735 .66993 L
s
.728 .202 .087 r
.73694 .5201 m .65263 .50336 L .6506 .51534 L closepath p F P
0 0 0 r
s
.789 .225 .097 r
.73694 .5201 m .65553 .49126 L .65263 .50336 L closepath p F P
0 0 0 r
s
.274 .51 .706 r
.65691 .32852 m
.65737 .32878 L
s
.66319 .31536 m
.65691 .32852 L
s
.67329 .32824 m
.65691 .32852 L
s
.66369 .31554 m
.66319 .31536 L
s
.66319 .31536 m
.67329 .32824 L
s
.29735 .66993 m
.28166 .67475 L
s
.28558 .66096 m
.29735 .66993 L
s
.22754 .65177 m
.29735 .66993 L
s
.33187 .34131 m
.33958 .32901 L
s
.68994 .84345 m
.67538 .85101 L
s
.67716 .83699 m
.68994 .84345 L
s
.61864 .83588 m
.68994 .84345 L
s
.805 .236 .103 r
.73694 .5201 m .65821 .48356 L .65553 .49126 L closepath p F P
0 0 0 r
s
.558 .147 .063 r
.73694 .5201 m .6506 .51534 L .65019 .52269 L closepath p F P
0 0 0 r
s
.428 .143 .066 r
.93599 .55479 m .85692 .52274 L .85498 .52283 L closepath p F P
0 0 0 r
s
.93599 .55479 m .84922 .56222 L .85113 .56234 L closepath p F P
s
.274 .51 .706 r
.67329 .32824 m
.65737 .32878 L
s
.66369 .31554 m
.67329 .32824 L
s
.60825 .2973 m
.67329 .32824 L
s
.60477 .6621 m
.60605 .66514 L
s
.60772 .64807 m
.60477 .6621 L
s
.621 .65923 m
.60477 .6621 L
s
.67538 .85101 m
.67716 .83699 L
s
.20631 .48896 m
.20689 .4909 L
s
.21233 .47576 m
.20631 .48896 L
s
.2229 .48914 m
.20631 .48896 L
s
.28166 .67475 m
.28558 .66096 L
s
.60902 .65103 m
.60772 .64807 L
s
.60772 .64807 m
.621 .65923 L
s
.654 .174 .072 r
.93599 .55479 m .85739 .53026 L .85692 .52274 L closepath p F P
0 0 0 r
s
.805 .224 .095 r
.93599 .55479 m .8562 .54255 L .85739 .53026 L closepath p F P
0 0 0 r
s
.875 .25 .106 r
.93599 .55479 m .8538 .55484 L .8562 .54255 L closepath p F P
0 0 0 r
s
.942 .277 .118 r
.93599 .55479 m .85113 .56234 L .8538 .55484 L closepath p F P
0 0 0 r
s
.274 .51 .706 r
.21295 .47763 m
.21233 .47576 L
s
.21233 .47576 m
.2229 .48914 L
s
.03 .18 .33 r
2 Mabswid
.85385 .5419 m
.85622 .54229 L
s
.84049 .53962 m
.85385 .5419 L
s
.82722 .53731 m
.84049 .53962 L
s
.81405 .53497 m
.82722 .53731 L
s
.80097 .53258 m
.81405 .53497 L
s
.78798 .53016 m
.80097 .53258 L
s
.5 Mabswid
.417 .138 .064 r
.73694 .5201 m .65966 .48324 L .65821 .48356 L closepath p F P
0 0 0 r
s
.03 .18 .33 r
2 Mabswid
.77509 .5277 m
.78798 .53016 L
s
.274 .51 .706 r
.5 Mabswid
.65737 .32878 m
.66369 .31554 L
s
.478 .163 .07 r
.73694 .5201 m .65019 .52269 L .65159 .52259 L closepath p F P
0 0 0 r
s
.03 .18 .33 r
2 Mabswid
.76228 .52521 m
.77509 .5277 L
s
.274 .51 .706 r
.5 Mabswid
.2229 .48914 m
.20689 .4909 L
s
.21295 .47763 m
.2229 .48914 L
s
.15615 .45984 m
.2229 .48914 L
s
.03 .18 .33 r
2 Mabswid
.74957 .52267 m
.76228 .52521 L
s
.274 .51 .706 r
.5 Mabswid
.621 .65923 m
.60605 .66514 L
s
.60902 .65103 m
.621 .65923 L
s
.55032 .64597 m
.621 .65923 L
s
.673 .179 .074 r
.73694 .5201 m .65929 .49053 L .65966 .48324 L closepath p F P
0 0 0 r
s
.816 .228 .096 r
.73694 .5201 m .65723 .50267 L .65929 .49053 L closepath p F P
0 0 0 r
s
.878 .251 .106 r
.73694 .5201 m .65428 .51495 L .65723 .50267 L closepath p F P
0 0 0 r
s
.935 .274 .117 r
.73694 .5201 m .65159 .52259 L .65428 .51495 L closepath p F P
0 0 0 r
s
.03 .18 .33 r
2 Mabswid
.73694 .5201 m
.74957 .52267 L
s
.5 Mabswid
.739 .205 .088 r
.53561 .47028 m .4528 .44695 L .44967 .45868 L closepath p F P
0 0 0 r
s
.793 .226 .097 r
.53561 .47028 m .45662 .43491 L .4528 .44695 L closepath p F P
0 0 0 r
s
.274 .51 .706 r
.93053 .65316 m
.93303 .65616 L
s
.9328 .63892 m
.93053 .65316 L
s
.94728 .64936 m
.93053 .65316 L
s
.03 .18 .33 r
2 Mabswid
.65104 .50101 m
.65726 .50248 L
s
.63912 .49812 m
.65104 .50101 L
s
.62728 .4952 m
.63912 .49812 L
s
.274 .51 .706 r
.5 Mabswid
.93531 .64183 m
.9328 .63892 L
s
.9328 .63892 m
.94728 .64936 L
s
.60605 .66514 m
.60902 .65103 L
s
.03 .18 .33 r
2 Mabswid
.61553 .49223 m
.62728 .4952 L
s
.274 .51 .706 r
.5 Mabswid
.53307 .47736 m
.53437 .47917 L
s
.54978 .47582 m
.53307 .47736 L
s
.797 .233 .102 r
.53561 .47028 m .4597 .42707 L .45662 .43491 L closepath p F P
0 0 0 r
s
.274 .51 .706 r
.53307 .47736 m
.53319 .47701 L
s
.53319 .47701 m
.53548 .47027 L
s
.20689 .4909 m
.21295 .47763 L
s
.03 .18 .33 r
2 Mabswid
.60386 .48922 m
.61553 .49223 L
s
.5 Mabswid
.57 .149 .063 r
.53561 .47028 m .44967 .45868 L .4484 .4657 L closepath p F P
0 0 0 r
s
.274 .51 .706 r
.53706 .46559 m
.53776 .46353 L
s
.53549 .47022 m
.53706 .46559 L
s
.53909 .46526 m
.53776 .46353 L
s
.53776 .46353 m
.54978 .47582 L
s
.03 .18 .33 r
2 Mabswid
.59228 .48617 m
.60386 .48922 L
s
.58078 .48308 m
.59228 .48617 L
s
.56936 .47994 m
.58078 .48308 L
s
.55803 .47677 m
.56936 .47994 L
s
.274 .51 .706 r
.5 Mabswid
.94728 .64936 m
.93303 .65616 L
s
.93531 .64183 m
.94728 .64936 L
s
.87542 .64013 m
.94728 .64936 L
s
.13401 .29798 m
.12447 .30916 L
s
.13414 .29782 m
.13401 .29798 L
s
.13401 .29798 m
.14062 .31305 L
s
.54978 .47582 m
.53437 .47917 L
s
.53909 .46526 m
.54978 .47582 L
s
.53235 .47011 m
.53247 .47015 L
s
.53247 .47015 m
.53422 .47072 L
s
.53422 .47072 m
.54978 .47582 L
s
.03 .18 .33 r
2 Mabswid
.54678 .47355 m
.55803 .47677 L
s
.274 .51 .706 r
.5 Mabswid
.12447 .30916 m
.12453 .30907 L
s
.14062 .31305 m
.12447 .30916 L
s
.405 .133 .063 r
.53561 .47028 m .46086 .42644 L .4597 .42707 L closepath p F P
0 0 0 r
s
.698 .186 .076 r
.53561 .47028 m .45962 .43338 L .46086 .42644 L closepath p F P
0 0 0 r
s
.831 .232 .097 r
.53561 .47028 m .45645 .44527 L .45962 .43338 L closepath p F P
0 0 0 r
s
.883 .252 .107 r
.53561 .47028 m .45257 .45749 L .45645 .44527 L closepath p F P
0 0 0 r
s
.925 .271 .116 r
.53561 .47028 m .44949 .46528 L .45257 .45749 L closepath p F P
0 0 0 r
s
.514 .173 .075 r
.53561 .47028 m .4484 .4657 L .44949 .46528 L closepath p F P
0 0 0 r
s
.03 .18 .33 r
2 Mabswid
.53561 .47028 m
.54678 .47355 L
s
.274 .51 .706 r
.5 Mabswid
.14062 .31305 m
.12453 .30907 L
s
.13414 .29782 m
.14062 .31305 L
s
.08372 .26512 m
.14062 .31305 L
s
.93303 .65616 m
.93531 .64183 L
s
.86174 .46642 m
.86409 .46818 L
s
.86545 .45217 m
.86174 .46642 L
s
.87889 .46351 m
.86174 .46642 L
s
.47763 .82141 m
.47841 .82551 L
s
.48024 .80729 m
.47763 .82141 L
s
.49371 .81865 m
.47763 .82141 L
s
.53437 .47917 m
.53729 .47056 L
s
.53729 .47056 m
.53909 .46526 L
s
.86783 .45385 m
.86545 .45217 L
s
.86545 .45217 m
.87889 .46351 L
s
.48104 .81131 m
.48024 .80729 L
s
.48024 .80729 m
.49371 .81865 L
s
.03 .18 .33 r
2 Mabswid
.44921 .44257 m
.4565 .44508 L
s
.274 .51 .706 r
.5 Mabswid
.45627 .2958 m
.4567 .29567 L
s
.46414 .28327 m
.45627 .2958 L
s
.47283 .29734 m
.45627 .2958 L
s
.03 .18 .33 r
2 Mabswid
.43877 .4389 m
.44921 .44257 L
s
.274 .51 .706 r
.5 Mabswid
.46462 .28306 m
.46414 .28327 L
s
.46414 .28327 m
.47283 .29734 L
s
.12453 .30907 m
.13414 .29782 L
s
.87889 .46351 m
.86409 .46818 L
s
.86783 .45385 m
.87889 .46351 L
s
.80822 .44672 m
.87889 .46351 L
s
.03 .18 .33 r
2 Mabswid
.42841 .43518 m
.43877 .4389 L
s
.274 .51 .706 r
.5 Mabswid
.49371 .81865 m
.47841 .82551 L
s
.48104 .81131 m
.49371 .81865 L
s
.42163 .80726 m
.49371 .81865 L
s
.03 .18 .33 r
2 Mabswid
.41813 .43141 m
.42841 .43518 L
s
.40793 .42759 m
.41813 .43141 L
s
.274 .51 .706 r
.5 Mabswid
.47283 .29734 m
.4567 .29567 L
s
.46462 .28306 m
.47283 .29734 L
s
.41068 .25783 m
.47283 .29734 L
s
.03 .18 .33 r
2 Mabswid
.3978 .42373 m
.40793 .42759 L
s
.274 .51 .706 r
.5 Mabswid
.80675 .81331 m
.80875 .81737 L
s
.8087 .79901 m
.80675 .81331 L
s
.82328 .80972 m
.80675 .81331 L
s
.86409 .46818 m
.86783 .45385 L
s
.03 .18 .33 r
2 Mabswid
.38776 .41981 m
.3978 .42373 L
s
.274 .51 .706 r
.5 Mabswid
.40464 .63392 m
.40573 .63689 L
s
.40872 .61986 m
.40464 .63392 L
s
.42135 .63209 m
.40464 .63392 L
s
.8107 .80299 m
.8087 .79901 L
s
.8087 .79901 m
.82328 .80972 L
s
.47841 .82551 m
.48104 .81131 L
s
.03 .18 .33 r
2 Mabswid
.37779 .41584 m
.38776 .41981 L
s
.274 .51 .706 r
.5 Mabswid
.40984 .62275 m
.40872 .61986 L
s
.40872 .61986 m
.42135 .63209 L
s
.03 .18 .33 r
2 Mabswid
.36791 .41183 m
.37779 .41584 L
s
.274 .51 .706 r
.5 Mabswid
.78933 .28262 m
.79062 .28259 L
s
.79584 .26912 m
.78933 .28262 L
s
.80653 .28218 m
.78933 .28262 L
s
.03 .18 .33 r
2 Mabswid
.3581 .40776 m
.36791 .41183 L
s
.274 .51 .706 r
.5 Mabswid
.79718 .26901 m
.79584 .26912 L
s
.79584 .26912 m
.80653 .28218 L
s
.42135 .63209 m
.40573 .63689 L
s
.40984 .62275 m
.42135 .63209 L
s
.35048 .61331 m
.42135 .63209 L
s
.4567 .29567 m
.46462 .28306 L
s
.03 .18 .33 r
2 Mabswid
.34836 .40364 m
.3581 .40776 L
s
.274 .51 .706 r
.5 Mabswid
.82328 .80972 m
.80875 .81737 L
s
.8107 .80299 m
.82328 .80972 L
s
.75043 .80194 m
.82328 .80972 L
s
.758 .21 .089 r
.32913 .39524 m .24839 .36128 L .24369 .37246 L closepath p F P
0 0 0 r
s
.799 .227 .097 r
.32913 .39524 m .25382 .34952 L .24839 .36128 L closepath p F P
0 0 0 r
s
.03 .18 .33 r
2 Mabswid
.33871 .39947 m
.34836 .40364 L
s
.5 Mabswid
.785 .229 .1 r
.32913 .39524 m .25795 .34159 L .25382 .34952 L closepath p F P
0 0 0 r
s
.592 .155 .065 r
.32913 .39524 m .24369 .37246 L .24149 .37887 L closepath p F P
0 0 0 r
s
.274 .51 .706 r
.80653 .28218 m
.79062 .28259 L
s
.79718 .26901 m
.80653 .28218 L
s
.74003 .25048 m
.80653 .28218 L
s
.853 .239 .1 r
.32913 .39524 m .2523 .35818 L .25706 .34686 L closepath p F P
0 0 0 r
s
.89 .254 .108 r
.32913 .39524 m .24678 .37012 L .2523 .35818 L closepath p F P
0 0 0 r
s
.91 .267 .114 r
.32913 .39524 m .24265 .37802 L .24678 .37012 L closepath p F P
0 0 0 r
s
.542 .18 .079 r
.32913 .39524 m .24149 .37887 L .24265 .37802 L closepath p F P
0 0 0 r
s
.394 .128 .062 r
.32913 .39524 m .25921 .34054 L .25795 .34159 L closepath p F P
0 0 0 r
s
.735 .197 .08 r
.32913 .39524 m .25706 .34686 L .25921 .34054 L closepath p F P
0 0 0 r
s
.03 .18 .33 r
2 Mabswid
.32913 .39524 m
.33871 .39947 L
s
.274 .51 .706 r
.5 Mabswid
.73646 .62396 m
.73859 .62683 L
s
.73959 .60956 m
.73646 .62396 L
s
.75347 .62091 m
.73646 .62396 L
s
.80875 .81737 m
.8107 .80299 L
s
.32859 .44667 m
.32994 .4484 L
s
.3348 .43314 m
.32859 .44667 L
s
.34581 .44678 m
.32859 .44667 L
s
.40573 .63689 m
.40984 .62275 L
s
.74174 .61235 m
.73959 .60956 L
s
.73959 .60956 m
.75347 .62091 L
s
.33619 .43479 m
.3348 .43314 L
s
.3348 .43314 m
.34581 .44678 L
s
.79062 .28259 m
.79718 .26901 L
s
.34581 .44678 m
.32994 .4484 L
s
.33619 .43479 m
.34581 .44678 L
s
.27828 .41649 m
.34581 .44678 L
s
.75347 .62091 m
.73859 .62683 L
s
.74174 .61235 m
.75347 .62091 L
s
.68144 .60723 m
.75347 .62091 L
s
.73859 .62683 m
.74174 .61235 L
s
.03 .18 .33 r
2 Mabswid
.24638 .3547 m
.25242 .35791 L
s
.274 .51 .706 r
.5 Mabswid
.66389 .43455 m
.66603 .43614 L
s
.66878 .42036 m
.66389 .43455 L
s
.68135 .43286 m
.66389 .43455 L
s
.32994 .4484 m
.33619 .43479 L
s
.2727 .79566 m
.27329 .79974 L
s
.27643 .78146 m
.2727 .79566 L
s
.28936 .79383 m
.2727 .79566 L
s
.67095 .42186 m
.66878 .42036 L
s
.66878 .42036 m
.68135 .43286 L
s
.03 .18 .33 r
2 Mabswid
.23757 .3499 m
.24638 .3547 L
s
.274 .51 .706 r
.5 Mabswid
.27705 .78546 m
.27643 .78146 L
s
.27643 .78146 m
.28936 .79383 L
s
.03 .18 .33 r
2 Mabswid
.22883 .34504 m
.23757 .3499 L
s
.274 .51 .706 r
.5 Mabswid
.25556 .25076 m
.24583 .26219 L
s
.25645 .2503 m
.25556 .25076 L
s
.25556 .25076 m
.26259 .26609 L
s
.03 .18 .33 r
2 Mabswid
.22017 .34012 m
.22883 .34504 L
s
.274 .51 .706 r
.5 Mabswid
.68135 .43286 m
.66603 .43614 L
s
.67095 .42186 m
.68135 .43286 L
s
.61142 .40963 m
.68135 .43286 L
s
.24583 .26219 m
.24665 .2618 L
s
.26259 .26609 m
.24583 .26219 L
s
.28936 .79383 m
.27329 .79974 L
s
.27705 .78546 m
.28936 .79383 L
s
.21657 .77748 m
.28936 .79383 L
s
.03 .18 .33 r
2 Mabswid
.21159 .33513 m
.22017 .34012 L
s
.20308 .33008 m
.21159 .33513 L
s
.274 .51 .706 r
.5 Mabswid
.26259 .26609 m
.24665 .2618 L
s
.25645 .2503 m
.26259 .26609 L
s
.205 .21673 m
.26259 .26609 L
s
.03 .18 .33 r
2 Mabswid
.19465 .32496 m
.20308 .33008 L
s
.274 .51 .706 r
.5 Mabswid
.19548 .60545 m
.19666 .60845 L
s
.20107 .59157 m
.19548 .60545 L
s
.21287 .60511 m
.19548 .60545 L
s
.60792 .78663 m
.60953 .79061 L
s
.6107 .77215 m
.60792 .78663 L
s
.62477 .7837 m
.60792 .78663 L
s
.66603 .43614 m
.67095 .42186 L
s
.03 .18 .33 r
2 Mabswid
.1863 .31978 m
.19465 .32496 L
s
.274 .51 .706 r
.5 Mabswid
.20228 .59448 m
.20107 .59157 L
s
.20107 .59157 m
.21287 .60511 L
s
.27329 .79974 m
.27705 .78546 L
s
.61234 .77604 m
.6107 .77215 L
s
.6107 .77215 m
.62477 .7837 L
s
.03 .18 .33 r
2 Mabswid
.17802 .31453 m
.1863 .31978 L
s
.274 .51 .706 r
.5 Mabswid
.21287 .60511 m
.19666 .60845 L
s
.20228 .59448 m
.21287 .60511 L
s
.14242 .57931 m
.21287 .60511 L
s
.58633 .24824 m
.58759 .24782 L
s
.59442 .2354 m
.58633 .24824 L
s
.60364 .24969 m
.58633 .24824 L
s
.03 .18 .33 r
2 Mabswid
.16981 .30921 m
.17802 .31453 L
s
.274 .51 .706 r
.5 Mabswid
.59574 .23488 m
.59442 .2354 L
s
.59442 .2354 m
.60364 .24969 L
s
.24665 .2618 m
.25645 .2503 L
s
.62477 .7837 m
.60953 .79061 L
s
.61234 .77604 m
.62477 .7837 L
s
.55134 .77193 m
.62477 .7837 L
s
.03 .18 .33 r
2 Mabswid
.16169 .30382 m
.16981 .30921 L
s
.15364 .29835 m
.16169 .30382 L
s
.274 .51 .706 r
.5 Mabswid
.60364 .24969 m
.58759 .24782 L
s
.59574 .23488 m
.60364 .24969 L
s
.54036 .20908 m
.60364 .24969 L
s
.9457 .77815 m
.94863 .78209 L
s
.94782 .76348 m
.9457 .77815 L
s
.96311 .77436 m
.9457 .77815 L
s
.03 .18 .33 r
2 Mabswid
.14566 .29282 m
.15364 .29835 L
s
.274 .51 .706 r
.5 Mabswid
.53393 .59439 m
.53587 .59718 L
s
.5382 .57996 m
.53393 .59439 L
s
.55137 .59242 m
.53393 .59439 L
s
.12224 .40254 m
.11413 .41539 L
s
.12407 .4043 m
.12224 .40254 L
s
.12224 .40254 m
.13193 .41771 L
s
.11413 .41539 m
.11591 .41723 L
s
.13193 .41771 m
.11413 .41539 L
s
.19666 .60845 m
.20228 .59448 L
s
.95076 .76732 m
.94782 .76348 L
s
.94782 .76348 m
.96311 .77436 L
s
.60953 .79061 m
.61234 .77604 L
s
.03 .18 .33 r
2 Mabswid
.13777 .28721 m
.14566 .29282 L
s
.274 .51 .706 r
.5 Mabswid
.54017 .58266 m
.5382 .57996 L
s
.5382 .57996 m
.55137 .59242 L
s
.13193 .41771 m
.11591 .41723 L
s
.12407 .4043 m
.13193 .41771 L
s
.06715 .37814 m
.13193 .41771 L
s
.55137 .59242 m
.53587 .59718 L
s
.54017 .58266 m
.55137 .59242 L
s
.47943 .57297 m
.55137 .59242 L
s
.58759 .24782 m
.59574 .23488 L
s
.96311 .77436 m
.94863 .78209 L
s
.95076 .76732 m
.96311 .77436 L
s
.88863 .76635 m
.96311 .77436 L
s
.87458 .58396 m
.87764 .58665 L
s
.8779 .56918 m
.87458 .58396 L
s
.89243 .58071 m
.87458 .58396 L
s
.94863 .78209 m
.95076 .76732 L
s
.11591 .41723 m
.12407 .4043 L
s
.45684 .40232 m
.45903 .40382 L
s
.46325 .38844 m
.45684 .40232 L
s
.47473 .40234 m
.45684 .40232 L
s
.53587 .59718 m
.54017 .58266 L
s
.88099 .57178 m
.8779 .56918 L
s
.8779 .56918 m
.89243 .58071 L
s
.46548 .38985 m
.46325 .38844 L
s
.46325 .38844 m
.47473 .40234 L
s
.47473 .40234 m
.45903 .40382 L
s
.46548 .38985 m
.47473 .40234 L
s
.40643 .371 m
.47473 .40234 L
s
.89243 .58071 m
.87764 .58665 L
s
.88099 .57178 m
.89243 .58071 L
s
.81899 .56659 m
.89243 .58071 L
s
.87764 .58665 m
.88099 .57178 L
s
.80113 .38964 m
.8042 .39098 L
s
.80623 .37507 m
.80113 .38964 L
s
.8194 .38778 m
.80113 .38964 L
s
.45903 .40382 m
.46548 .38985 L
s
.4004 .75959 m
.40182 .76355 L
s
.40433 .74502 m
.4004 .75959 L
s
.41778 .75764 m
.4004 .75959 L
s
.80934 .37632 m
.80623 .37507 L
s
.80623 .37507 m
.8194 .38778 L
s
.40577 .74889 m
.40433 .74502 L
s
.40433 .74502 m
.41778 .75764 L
s
.3831 .20121 m
.37316 .21291 L
s
.38483 .20043 m
.3831 .20121 L
s
.3831 .20121 m
.39057 .21681 L
s
.8194 .38778 m
.8042 .39098 L
s
.80934 .37632 m
.8194 .38778 L
s
.74829 .3638 m
.8194 .38778 L
s
.37316 .21291 m
.37483 .2122 L
s
.39057 .21681 m
.37316 .21291 L
s
.41778 .75764 m
.40182 .76355 L
s
.40577 .74889 m
.41778 .75764 L
s
.34392 .74067 m
.41778 .75764 L
s
.39057 .21681 m
.37483 .2122 L
s
.38483 .20043 m
.39057 .21681 L
s
.33231 .16594 m
.39057 .21681 L
s
.32201 .56448 m
.32402 .5673 L
s
.3278 .55024 m
.32201 .56448 L
s
.34005 .56406 m
.32201 .56448 L
s
.74464 .75013 m
.74718 .75398 L
s
.74762 .73526 m
.74464 .75013 L
s
.76232 .74702 m
.74464 .75013 L
s
.8042 .39098 m
.80934 .37632 L
s
.32984 .55296 m
.3278 .55024 L
s
.3278 .55024 m
.34005 .56406 L
s
.40182 .76355 m
.40577 .74889 L
s
.75018 .73901 m
.74762 .73526 L
s
.74762 .73526 m
.76232 .74702 L
s
.34005 .56406 m
.32402 .5673 L
s
.32984 .55296 m
.34005 .56406 L
s
.26889 .53727 m
.34005 .56406 L
s
.72282 .19834 m
.72501 .19757 L
s
.73116 .18516 m
.72282 .19834 L
s
.74095 .19968 m
.72282 .19834 L
s
.7334 .1843 m
.73116 .18516 L
s
.73116 .18516 m
.74095 .19968 L
s
.37483 .2122 m
.38483 .20043 L
s
.76232 .74702 m
.74718 .75398 L
s
.75018 .73901 m
.76232 .74702 L
s
.6875 .73485 m
.76232 .74702 L
s
.74095 .19968 m
.72501 .19757 L
s
.7334 .1843 m
.74095 .19968 L
s
.67651 .15791 m
.74095 .19968 L
s
.66965 .55289 m
.67251 .55548 L
s
.67413 .53807 m
.66965 .55289 L
s
.68787 .55077 m
.66965 .55289 L
s
.24773 .35627 m
.23943 .36943 L
s
.25039 .35779 m
.24773 .35627 L
s
.24773 .35627 m
.2578 .37177 L
s
.23943 .36943 m
.24203 .37104 L
s
.2578 .37177 m
.23943 .36943 L
s
.32402 .5673 m
.32984 .55296 L
s
.74718 .75398 m
.75018 .73901 L
s
.67702 .54057 m
.67413 .53807 L
s
.67413 .53807 m
.68787 .55077 L
s
.2578 .37177 m
.24203 .37104 L
s
.25039 .35779 m
.2578 .37177 L
s
.19271 .33073 m
.2578 .37177 L
s
.68787 .55077 m
.67251 .55548 L
s
.67702 .54057 m
.68787 .55077 L
s
.61484 .53062 m
.68787 .55077 L
s
.72501 .19757 m
.7334 .1843 L
s
.24203 .37104 m
.25039 .35779 L
s
.5915 .35575 m
.59462 .35699 L
s
.59813 .34151 m
.5915 .35575 L
s
.61012 .35568 m
.5915 .35575 L
s
.67251 .55548 m
.67702 .54057 L
s
.18326 .73224 m
.18476 .73627 L
s
.18872 .71777 m
.18326 .73224 L
s
.20139 .73168 m
.18326 .73224 L
s
.60129 .34265 m
.59813 .34151 L
s
.59813 .34151 m
.61012 .35568 L
s
.19025 .72172 m
.18872 .71777 L
s
.18872 .71777 m
.20139 .73168 L
s
.20139 .73168 m
.18476 .73627 L
s
.19025 .72172 m
.20139 .73168 L
s
.12762 .70807 m
.20139 .73168 L
s
.61012 .35568 m
.59462 .35699 L
s
.60129 .34265 m
.61012 .35568 L
s
.54104 .32322 m
.61012 .35568 L
s
.09949 .534 m
.10195 .53705 L
s
.10721 .52028 m
.09949 .534 L
s
.11825 .5357 m
.09949 .534 L
s
.10971 .52324 m
.10721 .52028 L
s
.10721 .52028 m
.11825 .5357 L
s
.59462 .35699 m
.60129 .34265 L
s
.11825 .5357 m
.10195 .53705 L
s
.10971 .52324 m
.11825 .5357 L
s
.04928 .50003 m
.11825 .5357 L
s
.53453 .72171 m
.53686 .72552 L
s
.53866 .70675 m
.53453 .72171 L
s
.55268 .71961 m
.53453 .72171 L
s
.18476 .73627 m
.19025 .72172 L
s
.54102 .71046 m
.53866 .70675 L
s
.53866 .70675 m
.55268 .71961 L
s
.51707 .14917 m
.50692 .16114 L
s
.51972 .14802 m
.51707 .14917 L
s
.51707 .14917 m
.52503 .16504 L
s
.50692 .16114 m
.50951 .16007 L
s
.52503 .16504 m
.50692 .16114 L
s
.55268 .71961 m
.53686 .72552 L
s
.54102 .71046 m
.55268 .71961 L
s
.47773 .702 m
.55268 .71961 L
s
.52503 .16504 m
.50951 .16007 L
s
.51972 .14802 m
.52503 .16504 L
s
.46609 .11257 m
.52503 .16504 L
s
.10195 .53705 m
.10971 .52324 L
s
.45495 .52143 m
.45787 .52404 L
s
.46095 .50681 m
.45495 .52143 L
s
.47368 .52093 m
.45495 .52143 L
s
.88828 .71179 m
.89184 .71548 L
s
.89147 .6965 m
.88828 .71179 L
s
.90687 .70848 m
.88828 .71179 L
s
.46391 .50932 m
.46095 .50681 L
s
.46095 .50681 m
.47368 .52093 L
s
.53686 .72552 m
.54102 .71046 L
s
.89504 .7001 m
.89147 .6965 L
s
.89147 .6965 m
.90687 .70848 L
s
.47368 .52093 m
.45787 .52404 L
s
.46391 .50932 m
.47368 .52093 L
s
.40184 .49309 m
.47368 .52093 L
s
.50951 .16007 m
.51972 .14802 L
s
.90687 .70848 m
.89184 .71548 L
s
.89504 .7001 m
.90687 .70848 L
s
.8306 .69587 m
.90687 .70848 L
s
.81229 .50928 m
.81616 .51165 L
s
.81699 .49405 m
.81229 .50928 L
s
.83134 .50699 m
.81229 .50928 L
s
.37962 .30764 m
.37112 .32114 L
s
.38318 .30889 m
.37962 .30764 L
s
.37962 .30764 m
.39009 .32349 L
s
.37112 .32114 m
.37463 .32248 L
s
.39009 .32349 m
.37112 .32114 L
s
.45787 .52404 m
.46391 .50932 L
s
.89184 .71548 m
.89504 .7001 L
s
.8209 .49632 m
.81699 .49405 L
s
.81699 .49405 m
.83134 .50699 L
s
.39009 .32349 m
.37463 .32248 L
s
.38318 .30889 m
.39009 .32349 L
s
.32475 .28086 m
.39009 .32349 L
s
.83134 .50699 m
.81616 .51165 L
s
.8209 .49632 m
.83134 .50699 L
s
.7572 .48609 m
.83134 .50699 L
s
.37463 .32248 m
.38318 .30889 L
s
.73308 .30679 m
.73721 .30773 L
s
.73994 .29216 m
.73308 .30679 L
s
.75246 .30662 m
.73308 .30679 L
s
.81616 .51165 m
.8209 .49632 L
s
.31441 .69292 m
.31679 .69681 L
s
.32007 .67807 m
.31441 .69292 L
s
.33322 .69229 m
.31441 .69292 L
s
.74411 .29301 m
.73994 .29216 L
s
.73994 .29216 m
.75246 .30662 L
s
.3225 .68186 m
.32007 .67807 L
s
.32007 .67807 m
.33322 .69229 L
s
.33322 .69229 m
.31679 .69681 L
s
.3225 .68186 m
.33322 .69229 L
s
.25876 .6677 m
.33322 .69229 L
s
.75246 .30662 m
.73721 .30773 L
s
.74411 .29301 m
.75246 .30662 L
s
.68263 .27296 m
.75246 .30662 L
s
.22923 .48935 m
.23257 .49219 L
s
.23715 .47527 m
.22923 .48935 L
s
.24856 .49106 m
.22923 .48935 L
s
.24055 .47802 m
.23715 .47527 L
s
.23715 .47527 m
.24856 .49106 L
s
.73721 .30773 m
.74411 .29301 L
s
.24856 .49106 m
.23257 .49219 L
s
.24055 .47802 m
.24856 .49106 L
s
.17943 .45389 m
.24856 .49106 L
s
.67559 .68187 m
.67892 .68551 L
s
.67994 .66649 m
.67559 .68187 L
s
.69457 .67962 m
.67559 .68187 L
s
.31679 .69681 m
.3225 .68186 L
s
.6833 .67003 m
.67994 .66649 L
s
.67994 .66649 m
.69457 .67962 L
s
.65798 .09443 m
.64761 .10669 L
s
.66164 .09288 m
.65798 .09443 L
s
.65798 .09443 m
.66647 .11059 L
s
.64761 .10669 m
.65121 .10523 L
s
.66647 .11059 m
.64761 .10669 L
s
.69457 .67962 m
.67892 .68551 L
s
.6833 .67003 m
.69457 .67962 L
s
.61852 .6613 m
.69457 .67962 L
s
.66647 .11059 m
.65121 .10523 L
s
.66164 .09288 m
.66647 .11059 L
s
.60686 .05641 m
.66647 .11059 L
s
.23257 .49219 m
.24055 .47802 L
s
.5948 .47615 m
.59872 .47853 L
s
.60102 .46112 m
.5948 .47615 L
s
.61427 .47555 m
.5948 .47615 L
s
.60499 .4634 m
.60102 .46112 L
s
.60102 .46112 m
.61427 .47555 L
s
.67892 .68551 m
.6833 .67003 L
s
.61427 .47555 m
.59872 .47853 L
s
.60499 .4634 m
.61427 .47555 L
s
.54178 .44658 m
.61427 .47555 L
s
.65121 .10523 m
.66164 .09288 L
s
.5184 .25647 m
.50969 .27032 L
s
.52298 .25742 m
.5184 .25647 L
s
.5184 .25647 m
.5293 .27268 L
s
.50969 .27032 m
.51421 .27136 L
s
.5293 .27268 m
.50969 .27032 L
s
.59872 .47853 m
.60499 .4634 L
s
.08298 .66356 m
.08581 .66774 L
s
.09063 .64912 m
.08298 .66356 L
s
.1026 .66495 m
.08298 .66356 L
s
.0935 .65321 m
.09063 .64912 L
s
.09063 .64912 m
.1026 .66495 L
s
.1026 .66495 m
.08581 .66774 L
s
.0935 .65321 m
.1026 .66495 L
s
.02995 .63187 m
.1026 .66495 L
s
.5293 .27268 m
.51421 .27136 L
s
.52298 .25742 m
.5293 .27268 L
s
.46378 .22836 m
.5293 .27268 L
s
.08581 .66774 m
.0935 .65321 L
s
.51421 .27136 m
.52298 .25742 L
s
.45246 .65154 m
.45583 .65525 L
s
.45835 .63627 m
.45246 .65154 L
s
.472 .65082 m
.45246 .65154 L
s
.46176 .63988 m
.45835 .63627 L
s
.45835 .63627 m
.472 .65082 L
s
.472 .65082 m
.45583 .65525 L
s
.46176 .63988 m
.472 .65082 L
s
.39689 .62518 m
.472 .65082 L
s
.36584 .44233 m
.37016 .44494 L
s
.37398 .42787 m
.36584 .44233 L
s
.38578 .44405 m
.36584 .44233 L
s
.37835 .43039 m
.37398 .42787 L
s
.37398 .42787 m
.38578 .44405 L
s
.38578 .44405 m
.37016 .44494 L
s
.37835 .43039 m
.38578 .44405 L
s
.31657 .40528 m
.38578 .44405 L
s
.82414 .63992 m
.82857 .64337 L
s
.82872 .6241 m
.82414 .63992 L
s
.844 .6375 m
.82414 .63992 L
s
.45583 .65525 m
.46176 .63988 L
s
.83319 .62744 m
.82872 .6241 L
s
.82872 .6241 m
.844 .6375 L
s
.844 .6375 m
.82857 .64337 L
s
.83319 .62744 m
.844 .6375 L
s
.76684 .61843 m
.844 .6375 L
s
.37016 .44494 m
.37835 .43039 L
s
.74211 .42845 m
.74714 .43057 L
s
.74857 .413 m
.74211 .42845 L
s
.76238 .42775 m
.74211 .42845 L
s
.75365 .41501 m
.74857 .413 L
s
.74857 .413 m
.76238 .42775 L
s
.82857 .64337 m
.83319 .62744 L
s
.76238 .42775 m
.74714 .43057 L
s
.75365 .41501 m
.76238 .42775 L
s
.68926 .39756 m
.76238 .42775 L
s
.66465 .20256 m
.65571 .21677 L
s
.67033 .20317 m
.66465 .20256 L
s
.66465 .20256 m
.676 .21913 L
s
.65571 .21677 m
.66133 .21747 L
s
.676 .21913 m
.65571 .21677 L
s
.74714 .43057 m
.75365 .41501 L
s
.21755 .62057 m
.22133 .62458 L
s
.22542 .60574 m
.21755 .62057 L
s
.23777 .62197 m
.21755 .62057 L
s
.22925 .60965 m
.22542 .60574 L
s
.22542 .60574 m
.23777 .62197 L
s
.23777 .62197 m
.22133 .62458 L
s
.22925 .60965 m
.23777 .62197 L
s
.16503 .58739 m
.23777 .62197 L
s
.676 .21913 m
.66133 .21747 L
s
.67033 .20317 m
.676 .21913 L
s
.61038 .173 m
.676 .21913 L
s
.22133 .62458 m
.22925 .60965 L
s
.66133 .21747 m
.67033 .20317 L
s
.59798 .60792 m
.60244 .61143 L
s
.60411 .59221 m
.59798 .60792 L
s
.61831 .6071 m
.59798 .60792 L
s
.60862 .59562 m
.60411 .59221 L
s
.60411 .59221 m
.61831 .6071 L
s
.61831 .6071 m
.60244 .61143 L
s
.60862 .59562 m
.61831 .6071 L
s
.54258 .58033 m
.61831 .6071 L
s
.50989 .39274 m
.51529 .39509 L
s
.51825 .37789 m
.50989 .39274 L
s
.53047 .39448 m
.50989 .39274 L
s
.52371 .38014 m
.51825 .37789 L
s
.51825 .37789 m
.53047 .39448 L
s
.53047 .39448 m
.51529 .39509 L
s
.52371 .38014 m
.53047 .39448 L
s
.46127 .35398 m
.53047 .39448 L
s
.60244 .61143 m
.60862 .59562 L
s
.51529 .39509 m
.52371 .38014 L
s
.35955 .57521 m
.36438 .57902 L
s
.36765 .55996 m
.35955 .57521 L
s
.3804 .57662 m
.35955 .57521 L
s
.37254 .56367 m
.36765 .55996 L
s
.36765 .55996 m
.3804 .57662 L
s
.3804 .57662 m
.36438 .57902 L
s
.37254 .56367 m
.3804 .57662 L
s
.30768 .54042 m
.3804 .57662 L
s
.36438 .57902 m
.37254 .56367 L
s
.75159 .56187 m
.75726 .56516 L
s
.75798 .5457 m
.75159 .56187 L
s
.77276 .56095 m
.75159 .56187 L
s
.7637 .54887 m
.75798 .5457 L
s
.75798 .5457 m
.77276 .56095 L
s
.77276 .56095 m
.75726 .56516 L
s
.7637 .54887 m
.77276 .56095 L
s
.69646 .53295 m
.77276 .56095 L
s
.662 .34039 m
.6686 .34244 L
s
.6706 .32512 m
.662 .34039 L
s
.68327 .34214 m
.662 .34039 L
s
.67726 .32707 m
.6706 .32512 L
s
.6706 .32512 m
.68327 .34214 L
s
.68327 .34214 m
.6686 .34244 L
s
.67726 .32707 m
.68327 .34214 L
s
.6142 .29977 m
.68327 .34214 L
s
.75726 .56516 m
.7637 .54887 L
s
.6686 .34244 m
.67726 .32707 L
s
.50961 .52727 m
.51562 .53086 L
s
.51796 .51158 m
.50961 .52727 L
s
.53114 .52869 m
.50961 .52727 L
s
.52403 .51507 m
.51796 .51158 L
s
.51796 .51158 m
.53114 .52869 L
s
.53114 .52869 m
.51562 .53086 L
s
.52403 .51507 m
.53114 .52869 L
s
.45854 .49074 m
.53114 .52869 L
s
.51562 .53086 m
.52403 .51507 L
s
.66843 .47652 m
.67575 .47986 L
s
.67704 .46037 m
.66843 .47652 L
s
.69069 .47796 m
.66843 .47652 L
s
.68443 .4636 m
.67704 .46037 L
s
.67704 .46037 m
.69069 .47796 L
s
.69069 .47796 m
.67575 .47986 L
s
.68443 .4636 m
.69069 .47796 L
s
.61837 .43811 m
.69069 .47796 L
s
.67575 .47986 m
.68443 .4636 L
s
0 0 0 r
.25 Mabswid
.68873 0 m
.94771 .40915 L
s
.94771 .40915 m
1 .79557 L
s
1 .79557 m
.71435 .42163 L
s
.71435 .42163 m
.68873 0 L
s
.06214 .25263 m
0 .65494 L
s
0 .65494 m
.71435 .42163 L
s
.71435 .42163 m
.68873 0 L
s
.68873 0 m
.06214 .25263 L
s
.06214 .25263 m
.68873 0 L
s
.07543 .24727 m
.08008 .25186 L
s
[(0)] .06612 .2381 1 .98555 Mshowa
.19674 .19836 m
.2012 .20314 L
s
[(0.5)] .18783 .1888 .9319 1 Mshowa
.32409 .14702 m
.32832 .152 L
s
[(1)] .31563 .13705 .84915 1 Mshowa
.45793 .09305 m
.4619 .09824 L
s
[(1.5)] .44998 .08268 .7664 1 Mshowa
.59877 .03627 m
.60246 .04167 L
s
[(2)] .59139 .02548 .68365 1 Mshowa
.125 Mabswid
.09923 .23767 m
.102 .24045 L
s
.12326 .22799 m
.126 .23079 L
s
.14752 .21821 m
.15024 .22103 L
s
.17201 .20833 m
.17471 .21118 L
s
.22172 .18829 m
.22436 .19118 L
s
.24693 .17812 m
.24956 .18104 L
s
.2724 .16786 m
.27499 .1708 L
s
.29812 .15749 m
.30068 .16045 L
s
.35032 .13644 m
.35283 .13945 L
s
.37682 .12576 m
.3793 .12879 L
s
.40358 .11497 m
.40603 .11803 L
s
.43062 .10407 m
.43304 .10715 L
s
.48552 .08193 m
.48787 .08507 L
s
.51339 .07069 m
.51571 .07385 L
s
.54156 .05934 m
.54384 .06252 L
s
.57001 .04786 m
.57226 .05108 L
s
.62783 .02456 m
.63 .02782 L
s
.65719 .01272 m
.65933 .016 L
s
.68687 .00075 m
.68897 .00406 L
s
.25 Mabswid
0 .65494 m
.38602 .9477 L
s
.01118 .66342 m
.01215 .65696 L
s
[(0)] .00923 .67634 .15077 -1 Mshowa
.11018 .7385 m
.11095 .73201 L
s
[(0.5)] .10864 .75148 .11897 -1 Mshowa
.20031 .80686 m
.20091 .80035 L
s
[(1)] .19913 .81988 .09118 -1 Mshowa
.28272 .86935 m
.28315 .86283 L
s
[(1.5)] .28185 .88239 .06671 -1 Mshowa
.35834 .9267 m
.35864 .92018 L
s
[(2)] .35775 .93976 .04498 -1 Mshowa
.125 Mabswid
.03175 .67902 m
.03231 .67514 L
s
.05192 .69432 m
.05246 .69044 L
s
.07171 .70933 m
.07222 .70544 L
s
.09113 .72406 m
.09162 .72016 L
s
.12888 .75268 m
.12932 .74879 L
s
.14723 .7666 m
.14765 .7627 L
s
.16525 .78027 m
.16564 .77636 L
s
.18294 .79368 m
.18332 .78978 L
s
.21738 .8198 m
.21772 .81589 L
s
.23415 .83252 m
.23446 .82861 L
s
.25062 .84501 m
.25092 .8411 L
s
.26681 .85729 m
.26709 .85337 L
s
.29836 .88121 m
.2986 .8773 L
s
.31373 .89287 m
.31396 .88896 L
s
.32885 .90434 m
.32906 .90042 L
s
.34372 .91561 m
.34391 .9117 L
s
.37273 .93761 m
.37289 .9337 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[287]:=",
  ImageSize->{400, 379.063},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001Nb000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3j
l>HF0?[`iP800000N03jl>H10?ooo`00o`3jl>HD0?[`iP80000000<0n_3V000000000000M`3jl>H1
0?ooo`00k@3jl>H4000001l0n_3V0`0000030?[`iP800000M`3jl>H10?ooo`00k@3jl>H00`000000
n_3V0?[`iP0N0?[`iP8000001P3jl>H00`000000n_3V0000001f0?[`iP40oooo003^0?[`iP030000
003jl>H0n_3V01X0n_3V0`0000080?[`iP040000003jl>H0n_3V000007D0n_3V0@3oool00>l0n_3V
00<000000?[`iP3jl>H05`3jl>H2000000/0n_3V00@000000?[`iP3jl>H00000M@3jl>H10?ooo`00
k@3jl>H010000000n_3V0?[`iP00000E0?[`iP<000000P3jl>H00`000000n_3V0?[`iP080?[`iP05
0000003jl>H0n_3V0?[`iP000000M03jl>H10?ooo`00kP3jl>H2000001@0n_3V0P00000@0?[`iP05
0000003jl>H0n_3V0?[`iP000000M03jl>H10?ooo`00o`3jl>H20?[`iP<000004P3jl>H00`000000
n_3V0?[`iP020?[`iP030000003jl>H0n_3V0740n_3V0@3oool00?l0n_3V0P00000F0?[`iP030000
003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0L03jl>H10?ooo`00o03jl>H3000000030?[`iP00
0000n_3V01D0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP1`0?[`iP40oooo003j
0?[`iP8000006`3jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V06l0n_3V0@3oool0
0?L0n_3V0`00000M0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0KP3jl>H10?oo
o`00m@3jl>H200000200n_3V00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP1^0?[`iP40
oooo003b0?[`iP<000008P3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V06d0n_3V
0@3oool00?00n_3V0P0000020?[`iP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H01@3j
l>H00`000000n_3V0?[`iP1]0?[`iP40oooo003^0?[`iP8000001@3jl>H00`000000n_3V0?[`iP0O
0?[`iP030000003jl>H0n_3V00H0n_3V00<000000?[`iP3jl>H0K03jl>H10?ooo`00j`3jl>H30000
02T0n_3V00<000000?[`iP3jl>H01`3jl>H00`000000n_3V0?[`iP1[0?[`iP40oooo003Y0?[`iP80
0000;03jl>H00`000000n_3V0?[`iP070?[`iP030000003jl>H0n_3V06/0n_3V0@3oool00>H0n_3V
0`0000000`3jl>H000000?[`iP0[0?[`iP030000003jl>H0n_3V00P0n_3V00<000000?[`iP3jl>H0
JP3jl>H10?ooo`00i03jl>H200000340n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`
iP1Y0?[`iP40oooo003Q0?[`iP<000004`3jl>H00`16P[@0n_3V0?[`iP0M0?[`iP030000003jl>H0
n_3V00T0n_3V00<000000?[`iP3jl>H0J@3jl>H10?ooo`00g`3jl>H2000001L0n_3V00<0AX:d0?[`
iP3jl>H0703jl>H00`000000n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V06P0n_3V0@3oool00=`0
n_3V0`00000J0?[`iP0304J2]03jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H02`3jl>H00`000000
n_3V0?[`iP1W0?[`iP40oooo002[0?[`iPD000000P3jl>H2000000@0n_3V0P00000P0?[`iP800000
0`3jl>H00`000000n_3V0?[`iP0H0?[`iP0304J2]03jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H0
2`3jl>H00`000000n_3V0?[`iP1W0?[`iP40oooo002]0?[`iP030000003jl>H0n_3V00L0n_3V00@0
00000?[`iP3jl>H00000703jl>H300000240n_3V00<0AX:d0?[`iP3jl>H06P3jl>H00`000000n_3V
0?[`iP0;0?[`iP030000003jl>H0n_3V06H0n_3V0@3oool00:d0n_3V00<000000?[`iP3jl>H02P3j
l>H00`000000n_3V0?[`iP0H0?[`iP8000009@3jl>H204J2]1X0n_3V00<000000?[`iP3jl>H02`3j
l>H00`000000n_3V0?[`iP1V0?[`iP40oooo002]0?[`iP030000003jl>H0n_3V00P0n_3V0P00000H
0?[`iP<00000:@3jl>H00`16P[@0n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V00`0n_3V00<00000
0?[`iP3jl>H0I@3jl>H10?ooo`00[@3jl>H00`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V
01D0n_3V0P0000020?[`iP030000003jl>H0n_3V02P0n_3V00<0AX:d0?[`iP3jl>H05P3jl>H00`00
0000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V06@0n_3V0@3oool00:`0n_3V0P00000:0?[`iP<0
00004P3jl>H300000300n_3V00<0AX:d0?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP0=0?[`iP03
0000003jl>H0n_3V06@0n_3V0@3oool00</0n_3V0P00000d0?[`iP0304J2]03jl>H0n_3V01@0n_3V
00<000000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP1S0?[`iP40oooo00380?[`iP<00000=`3j
l>H00`16P[@0n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V00l0n_3V00<000000?[`iP3jl>H0HP3j
l>H10?ooo`00aP3jl>H3000003X0n_3V00<0AX:d0?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP0?
0?[`iP030000003jl>H0n_3V0680n_3V0@3oool00<<0n_3V0`0000030?[`iP030000003jl>H0n_3V
03P0n_3V00<0AX:d0?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V
0640n_3V0@3oool00<40n_3V0P0000120?[`iP0304J2]03jl>H0n_3V0100n_3V00<000000?[`iP3j
l>H04@3jl>H00`000000n_3V0?[`iP1P0?[`iP40oooo002n0?[`iP<00000A@3jl>H00`16P[@0n_3V
0?[`iP0?0?[`iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H0H03jl>H10?ooo`00_03j
l>H2000004T0n_3V00@0AX:d0?[`iP3jl>H0n_3V0P16P[@;0?[`iP030000003jl>H0n_3V0180n_3V
00<000000?[`iP3jl>H0G`3jl>H10?ooo`00^@3jl>H300000080n_3V00<000000?[`iP3jl>H0A`3j
l>H504J2]0/0n_3V00<000000?[`iP3jl>H04P3jl>H00`000000n_3V0?[`iP1O0?[`iP40oooo002g
0?[`iP8000001P3jl>H00`000000n_3V0?[`iP170?[`iP80AX:d00<0n_3V04J2]016P[@02P3jl>H0
0`000000n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V05h0n_3V0@3oool00;@0n_3V0`00001B0?[`
iP0304J2]03jl>H0AX:d0080AX:d2P3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V
05d0n_3V0@3oool00;80n_3V0P00001D0?[`iP80AX:d0P3jl>H204J2]0X0n_3V00<000000?[`iP3j
l>H0503jl>H00`000000n_3V0?[`iP1M0?[`iP40oooo002_0?[`iP<000000P3jl>H00`000000n_3V
0?[`iP1@0?[`iPP0AX:d2P3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V05`0n_3V
0@3oool00:d0n_3V0P00001L0?[`iP@0AX:d2P3jl>H00`000000n_3V0?[`iP0E0?[`iP030000003j
l>H0n_3V05/0n_3V0@3oool00:X0n_3V0`00000D0?[`iP0304J2]03jl>H0n_3V05D0n_3V00<00000
0?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP1K0?[`iP40oooo002X0?[`iP800000603jl>H00`16
P[@0n_3V0?[`iP1D0?[`iP030000003jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H0FP3jl>H10?oo
o`00PP3jl>H5000001h0n_3V0`0000000`3jl>H000000?[`iP0H0?[`iP0304J2]03jl>H0n_3V05<0
n_3V00<000000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP1J0?[`iP40oooo00240?[`iP030000
003jl>H0n_3V01`0n_3V0P00000O0?[`iP0304J2]03jl>H0n_3V0580n_3V00<000000?[`iP3jl>H0
5`3jl>H00`000000n_3V0?[`iP1I0?[`iP40oooo00240?[`iP030000003jl>H0n_3V01T0n_3V0`00
000R0?[`iP0304J2]03jl>H0n_3V0540n_3V00<000000?[`iP3jl>H0603jl>H00`000000n_3V0?[`
iP1H0?[`iP40oooo00240?[`iP030000003jl>H0n_3V01L0n_3V0P00000V0?[`iP80AX:dD@3jl>H0
0`000000n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V05P0n_3V0@3oool008@0n_3V00<000000?[`
iP3jl>H05@3jl>H2000000030?[`iP000000n_3V02L0n_3V00<0AX:d0?[`iP3jl>H0CP3jl>H00`00
0000n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V05L0n_3V0@3oool008<0n_3V0P00000D0?[`iP<0
0000;@3jl>H00`16P[@0n_3V0?[`iP1=0?[`iP030000003jl>H0n_3V01X0n_3V00<000000?[`iP3j
l>H0EP3jl>H10?ooo`00U`3jl>H200000340n_3V00<0AX:d0?[`iP3jl>H0C03jl>H00`000000n_3V
0?[`iP0J0?[`iP030000003jl>H0n_3V05H0n_3V0@3oool009@0n_3V0`00000d0?[`iP0304J2]03j
l>H0n_3V04/0n_3V00<000000?[`iP3jl>H06`3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo002B
0?[`iP<00000=`3jl>H00`16P[@0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V01`0n_3V00<00000
0?[`iP3jl>H0E03jl>H10?ooo`00S`3jl>H3000000<0n_3V00<000000?[`iP3jl>H0=@3jl>H00`16
P[@0n_3V0?[`iP190?[`iP030000003jl>H0n_3V01`0n_3V00<000000?[`iP3jl>H0E03jl>H10?oo
o`00S@3jl>H2000003l0n_3V00<0AX:d0?[`iP3jl>H0B03jl>H00`000000n_3V0?[`iP0M0?[`iP03
0000003jl>H0n_3V05<0n_3V0@3oool008X0n_3V0`0000120?[`iP0304J2]03jl>H0n_3V04L0n_3V
00<000000?[`iP3jl>H07@3jl>H00`000000n_3V0?[`iP1C0?[`iP40oooo00280?[`iP<00000A@3j
l>H01016P[@0n_3V0?[`iP3jl>H204J2]4@0n_3V00<000000?[`iP3jl>H07@3jl>H00`000000n_3V
0?[`iP1B0?[`iP40oooo00250?[`iP<000000`3jl>H00`000000n_3V0?[`iP130?[`iPD0AX:dA03j
l>H00`000000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V0540n_3V0@3oool008<0n_3V0P00001=
0?[`iP80AX:d00<0n_3V04J2]016P[@0@`3jl>H00`000000n_3V0?[`iP0N0?[`iP030000003jl>H0
n_3V0540n_3V0@3oool00800n_3V0`00001?0?[`iP0304J2]03jl>H0AX:d0080AX:d@`3jl>H00`00
0000n_3V0?[`iP0O0?[`iP030000003jl>H0n_3V0500n_3V0@3oool007h0n_3V0`00001@0?[`iP80
AX:d0P3jl>H204J2]3/0n_3V00<0AX:d0?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0P0?[`iP03
0000003jl>H0n_3V04l0n_3V0@3oool007/0n_3V0`0000030?[`iP030000003jl>H0n_3V04`0n_3V
2016P[@k0?[`iP80AX:d1@3jl>H00`000000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V04l0n_3V
0@3oool007T0n_3V0P00001I0?[`iP@0AX:d?@3jl>H00`16P[@0n_3V0?[`iP020?[`iP030000003j
l>H0n_3V0240n_3V00<000000?[`iP3jl>H0CP3jl>H10?ooo`00MP3jl>H3000001@0n_3V00<0AX:d
0?[`iP3jl>H0QP3jl>H204J2]080n_3V00<000000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP1=
0?[`iP40oooo00160?[`iP800000103jl>H2000000@0n_3V0P00000P0?[`iP<000005`3jl>H00`16
P[@0n_3V0?[`iP270?[`iP80AX:d00<000000?[`iP3jl>H08P3jl>H00`000000n_3V0?[`iP1=0?[`
iP40oooo00150?[`iP040000003jl>H0n_3V000000P0n_3V00@000000?[`iP3jl>H00000703jl>H3
000000<0n_3V00<000000?[`iP3jl>H05@3jl>H00`16P[@0n_3V0?[`iP1V0?[`iP0304J2]03jl>H0
n_3V01l0n_3V00<000000?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP1<0?[`iP40oooo00150?[`
iP040000003jl>H0n_3V000000/0n_3V00<000000?[`iP3jl>H0603jl>H2000001l0n_3V0P16P[AW
0?[`iP80AX:d7`3jl>H00`000000AX:d04J2]00S0?[`iP030000003jl>H0n_3V04`0n_3V0@3oool0
04D0n_3V00@000000?[`iP3jl>H000002@3jl>H2000001P0n_3V0`00000S0?[`iP0304J2]03jl>H0
n_3V06H0n_3V00<0AX:d0?[`iP3jl>H0703jl>H010000000n_3V0?[`iP16P[@S0?[`iP030000003j
l>H0n_3V04/0n_3V0@3oool004D0n_3V00@000000?[`iP3jl>H000002@3jl>H00`000000n_3V0?[`
iP0E0?[`iP<000009P3jl>H00`16P[@0n_3V0?[`iP1V0?[`iP80AX:d703jl>H010000000n_3V0?[`
iP3jl>H204J2]280n_3V00<000000?[`iP3jl>H0BP3jl>H10?ooo`00AP3jl>H2000000X0n_3V0`00
000B0?[`iP<000000`3jl>H00`000000n_3V0?[`iP0T0?[`iP0304J2]03jl>H0n_3V06L0n_3V00<0
AX:d0?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP030?[`iP0304J2]03jl>H0n_3V01l0n_3V00<0
00000?[`iP3jl>H0BP3jl>H10?ooo`00I@3jl>H2000002h0n_3V00<0AX:d0?[`iP3jl>H0I`3jl>H0
0`16P[@0n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V00@0n_3V0P16P[@40?[`iP80AX:d6P3jl>H0
0`000000n_3V0?[`iP190?[`iP40oooo001R0?[`iP<00000<@3jl>H00`16P[@0n_3V0?[`iP1W0?[`
iP80AX:d603jl>H00`000000n_3V0?[`iP060?[`iP0304J2]03jl>H0n_3V00<0AX:d6`3jl>H00`00
0000n_3V0?[`iP180?[`iP40oooo001P0?[`iP80000000<0n_3V0000003jl>H0<P3jl>H00`16P[@0
n_3V0?[`iP1X0?[`iP0304J2]03jl>H0n_3V01H0n_3V00<000000?[`iP3jl>H01P3jl>H304J2]003
0?[`iP16P[@0AX:d01X0n_3V00<000000?[`iP3jl>H0B03jl>H10?ooo`00G@3jl>H3000003P0n_3V
0P16P[AY0?[`iP80AX:d5P3jl>H00`000000n_3V0?[`iP070?[`iP<0AX:d00<0n_3V04J2]03jl>H0
6P3jl>H00`000000n_3V0?[`iP170?[`iP40oooo001K0?[`iP800000?@3jl>H00`16P[@0n_3V0?[`
iP1X0?[`iP0304J2]03jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H01`3jl>H01P16P[@0n_3V0?[`
iP16P[@0n_3V04J2]1X0n_3V00<000000?[`iP3jl>H0A`3jl>H10?ooo`00F03jl>H300000400n_3V
00<0AX:d0?[`iP3jl>H0J03jl>H204J2]1<0n_3V00<000000?[`iP3jl>H01P3jl>H404J2]0030?[`
iP16P[@0AX:d01/0n_3V00<000000?[`iP3jl>H0AP3jl>H10?ooo`00EP3jl>H2000000030?[`iP00
0000n_3V0440n_3V00<0AX:d0?[`iP3jl>H00P3jl>H00`16P[@0n_3V0?[`iP1T0?[`iP0304J2]03j
l>H0n_3V0100n_3V00<000000?[`iP3jl>H02P3jl>H404J2]1/0n_3V00<000000?[`iP3jl>H0A@3j
l>H10?ooo`00D`3jl>H3000000@0n_3V00<000000?[`iP3jl>H0@03jl>H00`16P[@0n_3V0?[`iP02
04J2]6L0n_3V0P16P[@20?[`iP<0AX:d2`3jl>H00`000000n_3V0?[`iP0Y0?[`iP030000003jl>H0
n_3V04D0n_3V0@3oool00540n_3V0P00001;0?[`iP80AX:d0P3jl>H00`16P[@0n_3V0?[`iP1V0?[`
iP80AX:d00<0n_3V04J2]016P[@02`3jl>H00`000000n_3V0?[`iP0Z0?[`iP030000003jl>H0n_3V
04@0n_3V0@3oool004h0n_3V0`00001>0?[`iP80AX:d00<0n_3V04J2]03jl>H0>@3jl>H00`16P[@0
n_3V0?[`iP0/0?[`iP0304J2]03jl>H0AX:d0080AX:d2P3jl>H00`000000n_3V0?[`iP0[0?[`iP03
0000003jl>H0n_3V04<0n_3V0@3oool004`0n_3V0P0000020?[`iP030000003jl>H0n_3V04/0n_3V
00<0AX:d0?[`iP3jl>H00P16P[@k0?[`iP80AX:d:`3jl>H00`16P[@0n_3V04J2]00304J2]0X0n_3V
00<000000?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP130?[`iP40oooo001:0?[`iP800000D@3j
l>H304J2]080n_3V0P16P[@l0?[`iP0304J2]03jl>H0n_3V02P0n_3V00@0AX:d0?[`iP16P[@0n_3V
0`16P[@90?[`iP030000003jl>H0n_3V02`0n_3V00<000000?[`iP3jl>H0@P3jl>H10?ooo`00A`3j
l>H300000180n_3V00<0AX:d0?[`iP3jl>H0@@3jl>H404J2]3d0n_3V0P16P[@W0?[`iP@0AX:d0P3j
l>H204J2]0T0n_3V00<000000?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP110?[`iP40oooo000R
0?[`iP8000008@3jl>H2000001H0n_3V00<0AX:d0?[`iP3jl>H0P`3jl>H204J2]2H0n_3V2016P[@8
0?[`iP030000003jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H0@@3jl>H10?ooo`008@3jl>H01000
0000n_3V0?[`iP00000M0?[`iP<000000P3jl>H00`000000n_3V0?[`iP0D0?[`iP0304J2]03jl>H0
n_3V08@0n_3V00<0AX:d0?[`iP3jl>H0<`3jl>H00`000000n_3V0?[`iP0^0?[`iP030000003jl>H0
n_3V0400n_3V0@3oool00240n_3V00@000000?[`iP3jl>H000006`3jl>H2000001d0n_3V0P16P[B5
0?[`iP80AX:d<`3jl>H00`000000n_3V0?[`iP0^0?[`iP030000003jl>H0n_3V0400n_3V0@3oool0
0240n_3V00@000000?[`iP3jl>H00000603jl>H300000240n_3V00<0AX:d0?[`iP3jl>H0Q03jl>H0
0`16P[@0n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V02l0n_3V00<000000?[`iP3jl>H0?`3jl>H1
0?ooo`008@3jl>H010000000n_3V0?[`iP00000F0?[`iP8000009@3jl>H00`16P[@0n_3V0?[`iP1K
0?[`iP0304J2]03jl>H0n_3V02H0n_3V0P16P[@`0?[`iP030000003jl>H0n_3V0300n_3V00<00000
0?[`iP3jl>H0?P3jl>H10?ooo`008P3jl>H2000001@0n_3V0`0000020?[`iP030000003jl>H0n_3V
02<0n_3V00<0AX:d0?[`iP3jl>H0F`3jl>H204J2]2P0n_3V00<0AX:d0?[`iP3jl>H0;@3jl>H00`00
0000n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V03h0n_3V0@3oool003H0n_3V0P00000/0?[`iP03
04J2]03jl>H0n_3V05`0n_3V00<0AX:d0?[`iP3jl>H09P3jl>H204J2]0D0n_3V00<0AX:d0?[`iP3j
l>H09P3jl>H00`000000n_3V0?[`iP0`0?[`iP030000003jl>H0n_3V03d0n_3V0@3oool003<0n_3V
0`00000_0?[`iP0304J2]03jl>H0n_3V05`0n_3V0P16P[@X0?[`iP0404J2]03jl>H0n_3V0?[`iP80
AX:d:03jl>H00`000000n_3V0?[`iP0a0?[`iP030000003jl>H0n_3V03`0n_3V0@3oool00340n_3V
0P0000000`3jl>H000000?[`iP0`0?[`iP0304J2]03jl>H0n_3V05d0n_3V00<0AX:d0?[`iP3jl>H0
9P3jl>H304J2]0030?[`iP16P[@0AX:d02L0n_3V00<000000?[`iP3jl>H0<@3jl>H00`000000n_3V
0?[`iP0l0?[`iP40oooo000^0?[`iP<00000=P3jl>H204J2]5h0n_3V0P16P[@W0?[`iP<0AX:d00<0
n_3V04J2]03jl>H09P3jl>H00`000000n_3V0?[`iP0b0?[`iP030000003jl>H0n_3V03/0n_3V0@3o
ool002`0n_3V0P00000k0?[`iP0304J2]03jl>H0n_3V05d0n_3V00<0AX:d0?[`iP3jl>H0903jl>H0
0`16P[@0n_3V0?[`iP0304J2]2H0n_3V00<000000?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP0k
0?[`iP40oooo000Y0?[`iP<00000?P3jl>H00`16P[@0n_3V0?[`iP1M0?[`iP80AX:d8`3jl>H404J2
]0030?[`iP16P[@0AX:d02H0n_3V00<000000?[`iP3jl>H0<`3jl>H00`000000n_3V0?[`iP0j0?[`
iP40oooo000W0?[`iP8000000P3jl>H00`000000n_3V0?[`iP0m0?[`iP0404J2]03jl>H0n_3V0?[`
iP80AX:dF`3jl>H00`16P[@0n_3V0?[`iP0T0?[`iP@0AX:d9@3jl>H00`000000n_3V0?[`iP0;0?[`
iP0304J2]03jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0>@3jl>H10?ooo`009@3jl>H2000000D0
n_3V00<000000?[`iP3jl>H0?@3jl>H00`16P[@0n_3V04J2]00204J2]5`0n_3V00<0AX:d0?[`iP3j
l>H0C03jl>H00`000000n_3V0?[`iP0<0?[`iP80AX:d9P3jl>H00`000000n_3V0?[`iP0i0?[`iP40
oooo000U0?[`iP800000AP3jl>H204J2]0030?[`iP16P[@0AX:d05`0n_3V0P16P[A<0?[`iP030000
003jl>H0n_3V00h0n_3V0P16P[@U0?[`iP030000003jl>H0n_3V03P0n_3V0@3oool002D0n_3V0`00
00150?[`iPD0AX:d>@3jl>H00`16P[@0n_3V0?[`iP0R0?[`iP0304J2]03jl>H0n_3V0080n_3V0`16
P[A40?[`iP030000003jl>H0n_3V0100n_3V0P16P[@T0?[`iP030000003jl>H0n_3V03L0n_3V0@3o
ool002@0n_3V0P0000020?[`iP030000003jl>H0n_3V0480n_3V00<0AX:d0?[`iP3jl>H00P16P[@j
0?[`iP80AX:d8`3jl>H204J2]0030?[`iP16P[@0n_3V0080AX:dA03jl>H00`000000n_3V0?[`iP0B
0?[`iP80AX:d8P3jl>H00`000000n_3V0?[`iP0g0?[`iP40oooo000T0?[`iP030000003jl>H0n_3V
0080n_3V00<000000?[`iP3jl>H0@03jl>H304J2]080n_3V0P16P[@k0?[`iP0304J2]03jl>H0n_3V
0280n_3V00H0AX:d0?[`iP16P[@0AX:d0?[`iP16P[A30?[`iP030000003jl>H0n_3V01@0n_3V0P16
P[@Q0?[`iP030000003jl>H0n_3V03H0n_3V0@3oool002@0n_3V00<000000?[`iP3jl>H00`3jl>H0
10000000n_3V0?[`iP16P[A10?[`iP@0AX:d?03jl>H204J2]280n_3V0`16P[@00`3jl>H0AX:d04J2
]0130?[`iP030000003jl>H0n_3V01H0n_3V0P16P[@P0?[`iP030000003jl>H0n_3V03D0n_3V0@3o
ool00100n_3V0P0000040?[`iP800000103jl>H2000000H0n_3V00<000000?[`iP3jl>H0103jl>H0
10000000n_3V0?[`iP16P[B20?[`iP80AX:d7`3jl>H01`16P[@0n_3V04J2]03jl>H0AX:d0?[`iP16
P[@0@`3jl>H00`000000n_3V0?[`iP0H0?[`iP80AX:d1`3jl>H00`16P[@0n_3V0?[`iP0D0?[`iP03
0000003jl>H0n_3V03D0n_3V0@3oool000l0n_3V00@000000?[`iP3jl>H00000203jl>H010000000
n_3V0?[`iP0000050?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H00P16P[B20?[`
iP0304J2]03jl>H0n_3V01/0n_3V1@16P[@0103jl>H0AX:d04J2]016P[A20?[`iP030000003jl>H0
n_3V01X0n_3V0P16P[@50?[`iP80AX:d5P3jl>H00`000000n_3V0?[`iP0d0?[`iP40oooo000?0?[`
iP040000003jl>H0n_3V000000/0n_3V00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP06
0?[`iP050000003jl>H0n_3V0?[`iP16P[@0PP3jl>H204J2]1l0n_3V1@16P[@j0?[`iP80AX:d1P3j
l>H00`000000n_3V0?[`iP0L0?[`iP80AX:d0P3jl>H00`16P[@0n_3V04J2]00F0?[`iP030000003j
l>H0n_3V03@0n_3V0@3oool000l0n_3V00@000000?[`iP3jl>H000002@3jl>H2000000H0n_3V00<0
00000?[`iP3jl>H01`3jl>H01@000000n_3V0?[`iP3jl>H0AX:d08<0n_3V00<0AX:d0?[`iP3jl>H0
G@3jl>H204J2]0D0n_3V00<000000?[`iP3jl>H07@3jl>H304J2]080n_3V00<0AX:d0?[`iP3jl>H0
503jl>H00`000000n_3V0?[`iP0c0?[`iP40oooo000?0?[`iP040000003jl>H0n_3V000000T0n_3V
00<000000?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP090?[`iP050000003jl>H0n_3V0?[`iP16
P[@0P`3jl>H204J2]5l0n_3V0P16P[@30?[`iP030000003jl>H0n_3V01h0n_3V0`16P[@00`3jl>H0
AX:d04J2]00F0?[`iP030000003jl>H0n_3V0380n_3V0@3oool00100n_3V0P00000:0?[`iP<00000
103jl>H2000000/0n_3V00D000000?[`iP3jl>H0n_3V04J2]01E0?[`iP0304J2]03jl>H0n_3V02`0
n_3V0P16P[AO0?[`iP80AX:d00<0n_3V0000003jl>H07`3jl>H00`16P[@0n_3V0?[`iP0304J2]1H0
n_3V00<000000?[`iP3jl>H0<P3jl>H10?ooo`008`3jl>H00`000000n_3V0?[`iP0;0?[`iP040000
003jl>H0n_3V0?[`iP80AX:dE03jl>H204J2]2h0n_3V00<0AX:d0?[`iP3jl>H00P3jl>H00`16P[@0
n_3V0?[`iP1I0?[`iP0304J2]0000000n_3V01h0n_3V2016P[@F0?[`iP030000003jl>H0n_3V0340
n_3V0@3oool002<0n_3V00<000000?[`iP3jl>H0303jl>H00`000000n_3V0?[`iP020?[`iP0304J2
]03jl>H0n_3V00P0n_3V00<01biD0?[`iP3jl>H0B03jl>H00`16P[@0n_3V0?[`iP0/0?[`iP80AX:d
00@0n_3V04J2]03jl>H0AX:dF`3jl>H00`000000AX:d04J2]00l0?[`iP030000003jl>H0n_3V0300
n_3V0@3oool002<0n_3V00<000000?[`iP3jl>H03@3jl>H00`000000n_3V0?[`iP020?[`iP0304J2
]03jl>H0n_3V00H0n_3V0`07;UA:0?[`iP80AX:d;P3jl>H204J2]0030?[`iP16P[@0n_3V05X0n_3V
00<000000?[`iP3jl>H00P16P[@j0?[`iP030000003jl>H0n_3V0300n_3V0@3oool002<0n_3V00<0
00000?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP020?[`iP0304J2]03jl>H0n_3V00H0n_3V1007
;UA:0?[`iP0304J2]03jl>H0n_3V02/0n_3V0`16P[@00`3jl>H0AX:d0?[`iP1I0?[`iP030000003j
l>H0n_3V0080n_3V0P16P[@60?[`iP0304J2]03jl>H0n_3V0300n_3V00<000000?[`iP3jl>H0;`3j
l>H10?ooo`008`3jl>H00`000000n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V0080n_3V0P16P[@7
0?[`iP@01biDBP3jl>H204J2]2/0n_3V00<0AX:d0?[`iP3jl>H00P16P[AJ0?[`iP030000003jl>H0
n_3V00@0n_3V0P16P[@40?[`iP<0AX:d<@3jl>H00`000000n_3V0?[`iP0^0?[`iP40oooo000R0?[`
iP030000003jl>H0n_3V0140n_3V00<000000?[`iP3jl>H00`3jl>H00`16P[@0n_3V0?[`iP060?[`
iP@01biDBP3jl>H00`16P[@0n_3V0?[`iP0W0?[`iPL0AX:d<`3jl>H204J2]2@0n_3V00<000000?[`
iP3jl>H01P3jl>H204J2]0030?[`iP16P[@0n_3V00<0AX:d<03jl>H00`000000n_3V0?[`iP0^0?[`
iP40oooo000R0?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H00`3jl>H00`16P[@0
n_3V0?[`iP0204J2]0@0n_3V1007;UA:0?[`iP80AX:dH`3jl>H204J2]280n_3V00<000000?[`iP3j
l>H0203jl>H204J2]0040?[`iP16P[@0AX:d04J2]340n_3V00<000000?[`iP3jl>H0;@3jl>H10?oo
o`008P3jl>H00`000000n_3V0?[`iP0C0?[`iP030000003jl>H0n_3V00<0n_3V1016P[@60?[`iP@0
1biDBP3jl>H00`16P[@0n_3V0?[`iP1R0?[`iP80AX:d803jl>H00`000000n_3V0?[`iP090?[`iP<0
AX:d00<0n_3V04J2]016P[@0<03jl>H00`000000n_3V0?[`iP0]0?[`iP40oooo000R0?[`iP800000
5@3jl>H00`000000n_3V0?[`iP020?[`iP80AX:d00<0n_3V04J2]016P[@01P3jl>H400L^E2h0n_3V
00<0AX:d0?[`iP3jl>H06@3jl>H00`16P[@0n_3V0?[`iP1S0?[`iP80AX:d7P3jl>H00`000000n_3V
0?[`iP080?[`iP0404J2]03jl>H0AX:d0?[`iP<0AX:d<@3jl>H00`000000n_3V0?[`iP0/0?[`iP40
oooo000R0?[`iP030000003jl>H0n_3V01D0n_3V0P0000020?[`iP0304J2]03jl>H0AX:d0080AX:d
203jl>H400L^E2d0n_3V0P16P[@J0?[`iP80AX:d1@3jl>H00`16P[@0n_3V0?[`iP1L0?[`iP<0AX:d
703jl>H00`000000n_3V0?[`iP080?[`iPP0AX:d<@3jl>H00`000000n_3V0?[`iP0[0?[`iP40oooo
000R0?[`iP030000003jl>H0n_3V01L0n_3V00@0000004J2]016P[@0AX:d0P3jl>H204J2]0P0n_3V
1007;U@^0?[`iP0304J2]03jl>H0n_3V01T0n_3V00H0AX:d0?[`iP3jl>H0n_3V04J2]03jl>H204J2
]5h0n_3V0`16P[@J0?[`iP030000003jl>H0n_3V0440n_3V00<000000?[`iP3jl>H0:`3jl>H10?oo
o`008@3jl>H00`000000n_3V0?[`iP0I0?[`iP030000003jl>H0n_3V00@0AX:d2P3jl>H400L^E2d0
n_3V0P16P[@J0?[`iP80AX:d00<0n_3V04J2]03jl>H00P16P[AO0?[`iP@0AX:d603jl>H00`000000
n_3V0?[`iP120?[`iP030000003jl>H0n_3V02X0n_3V0@3oool00240n_3V00<000000?[`iP3jl>H0
6P3jl>H00`000000n_3V0?[`iP0>0?[`iPD01biD;@3jl>H204J2]1X0n_3V00@0AX:d0?[`iP16P[@0
n_3V0P16P[AP0?[`iP0404J2]03jl>H0AX:d04J2]0H0n_3V00<0AX:d0?[`iP3jl>H03@3jl>H00`00
0000n_3V0?[`iP130?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00240n_3V00<000000?[`iP3j
l>H06`3jl>H00`000000n_3V0?[`iP0?0?[`iPD01biD;@3jl>H00`16P[@0n_3V0?[`iP0G0?[`iP<0
AX:d00<0n_3V04J2]016P[@0H@3jl>H204J2]0030?[`iP16P[@0AX:d00<0n_3V00<0AX:d0?[`iP16
P[@03`3jl>H00`000000n_3V0?[`iP120?[`iP030000003jl>H0n_3V02T0n_3V0@3oool00240n_3V
00<000000?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP0@0?[`iP@01biD;@3jl>H204J2]1H0n_3V
00L0AX:d0?[`iP16P[@0n_3V04J2]03jl>H0AX:d06<0n_3V00<0AX:d0?[`iP3jl>H00P16P[@0103j
l>H0AX:d0?[`iP16P[@?0?[`iP030000003jl>H0n_3V04<0n_3V00<000000?[`iP3jl>H0:03jl>H1
0?ooo`008@3jl>H00`000000n_3V0?[`iP0M0?[`iP030000003jl>H0n_3V0140n_3V1007;U@]0?[`
iP0304J2]03jl>H0n_3V01<0n_3V1016P[@0103jl>H0AX:d04J2]016P[@i0?[`iP80AX:d:03jl>H2
04J2]080n_3V0P16P[@20?[`iP0304J2]03jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H0@`3jl>H0
0`000000n_3V0?[`iP0X0?[`iP40oooo000Q0?[`iP030000003jl>H0n_3V01h0n_3V00<000000?[`
iP3jl>H04@3jl>H400L^E2d0n_3V0P16P[@G0?[`iP@0AX:d>`3jl>H204J2]2P0n_3V0`16P[@00`3j
l>H0AX:d04J2]00204J2]0d0n_3V00<000000?[`iP3jl>H0A03jl>H00`000000n_3V0?[`iP0W0?[`
iP40oooo000P0?[`iP<00000803jl>H00`000000n_3V0?[`iP0B0?[`iP@01biD;@3jl>H204J2]5H0
n_3V0P16P[@W0?[`iPT0AX:d2`3jl>H00`000000n_3V0?[`iP150?[`iP030000003jl>H0n_3V02H0
n_3V0@3oool00200n_3V00<000000?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0@0?[`iP0304J2
]03jl>H01biD00<01biD;P3jl>H00`16P[@0n_3V0?[`iP020?[`iP0304J2]03jl>H0n_3V0500n_3V
0P16P[@U0?[`iPD0AX:d00@0n_3V04J2]016P[@0AX:d2`3jl>H00`000000n_3V0?[`iP150?[`iP03
0000003jl>H0n_3V02H0n_3V0@3oool00200n_3V00<000000?[`iP3jl>H08P3jl>H00`000000n_3V
0?[`iP0@0?[`iP80AX:d00<0n_3V00L^E007;U@00P07;U@]0?[`iP80AX:d00@0n_3V04J2]03jl>H0
AX:dD`3jl>H204J2]2H0n_3V0P16P[@20?[`iP0304J2]03jl>H0AX:d00X0n_3V00<000000?[`iP3j
l>H0AP3jl>H00`000000n_3V0?[`iP0U0?[`iP40oooo000P0?[`iP030000003jl>H0n_3V02<0n_3V
00<000000?[`iP3jl>H04@3jl>H00`16P[@0n_3V00L^E00400L^E2d0n_3V00@0AX:d0?[`iP3jl>H0
AX:dE@3jl>H204J2]2@0n_3V00D0AX:d0?[`iP16P[@0AX:d0?[`iP0204J2]0X0n_3V00<000000?[`
iP3jl>H0803jl>H204J2]2D0n_3V00<000000?[`iP3jl>H0903jl>H10?ooo`00803jl>H00`000000
n_3V0?[`iP0T0?[`iP030000003jl>H0n_3V0140n_3V0P16P[@00`3jl>H01biD00L^E00300L^E2/0
n_3V0`16P[@00`3jl>H0AX:d0?[`iP1E0?[`iP80AX:d8@3jl>H01016P[@0n_3V0?[`iP3jl>H204J2
]0030?[`iP16P[@0n_3V00T0n_3V00<000000?[`iP3jl>H08P3jl>H304J2]280n_3V00<000000?[`
iP3jl>H0903jl>H10?ooo`00803jl>H00`000000n_3V0?[`iP0U0?[`iP030000003jl>H0n_3V0180
n_3V0P16P[@00`3jl>H01biD00L^E00200L^E0`0n_3V0P00000K0?[`iP<0AX:d00<0n_3V04J2]016
P[@0F03jl>H204J2]0H0n_3V00<0AX:d0?[`iP3jl>H05P3jl>H404J2]080n_3V0`16P[@90?[`iP03
0000003jl>H0n_3V02D0n_3V0P16P[@Q0?[`iP030000003jl>H0n_3V02<0n_3V0@3oool00200n_3V
00<000000?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP0C0?[`iP0304J2]03jl>H0n_3V00@01biD
2P3jl>H3000001d0n_3V1016P[@c0?[`iP80AX:d903jl>H204J2]0@0n_3V0`16P[@H0?[`iPL0AX:d
2@3jl>H00`000000n_3V0?[`iP0W0?[`iP<0AX:d7`3jl>H00`000000n_3V0?[`iP0R0?[`iP40oooo
000O0?[`iP030000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H04`3jl>H204J2]0030?[`iP07
;U@01biD00801biD203jl>H200000080_38D0P00001D0?[`iP80AX:d903jl>H204J2]0030?[`iP16
P[@0n_3V00<0AX:d9`3jl>H00`000000n_3V0?[`iP0Z0?[`iP<0AX:d703jl>H00`000000n_3V0?[`
iP0R0?[`iP40oooo000O0?[`iP030000003jl>H0n_3V02T0n_3V00@000000?[`iP3jl>H0AX:d4`3j
l>H00`16P[@0n_3V0?[`iP0400L^E0H0n_3V0P0000040;`b50030000003jl>H0n_3V05<0n_3V0P16
P[@T0?[`iP80AX:d00@0n_3V04J2]016P[@0AX:d9`3jl>H00`000000n_3V0?[`iP0]0?[`iP<0AX:d
1@3jl>H00`16P[@0n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V0240n_3V0@3oool001l0n_3V0P00
000[0?[`iP030000003jl>H0n_3V0080AX:d4P3jl>H204J2]0030?[`iP07;U@01biD00<01biD103j
l>H010000000fSdI0000000000030;`b50030000003jl>H0n_3V05@0n_3V0P16P[@S0?[`iP<0AX:d
00<0n_3V04J2]016P[@09P3jl>H00`000000n_3V0?[`iP0`0?[`iP<0AX:d0P3jl>H204J2]1<0n_3V
00<000000?[`iP3jl>H08@3jl>H10?ooo`007`3jl>H00`000000n_3V0?[`iP0[0?[`iP050000003j
l>H0n_3V0?[`iP16P[@04`3jl>H00`16P[@0n_3V0?[`iP0500L^E0030?[`iP000000000000<0fSdI
00@000000;`b502l<Q@0_38D0P0000160?[`iP0304J2]03jl>H0n_3V00d0n_3V0P16P[@P0?[`iP04
04J2]03jl>H0AX:d0?[`iP<0AX:d9P3jl>H00`000000n_3V0?[`iP0c0?[`iP80AX:d0P3jl>H00`16
P[@0n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V0200n_3V0@3oool001l0n_3V00<000000?[`iP3j
l>H0;03jl>H010000000n_3V0?[`iP3jl>H204J2]180n_3V0P16P[@20?[`iP801biD00<0AX:d00L^
E007;U@01@3J?AT2000000<0_38D00<000000?[`iP3jl>H0A03jl>H204J2]0l0n_3V0P16P[@N0?[`
iPP0AX:d9@3jl>H00`000000n_3V0?[`iP0d0?[`iPD0AX:d4`3jl>H00`000000n_3V0?[`iP0O0?[`
iP40oooo000O0?[`iP030000003jl>H0n_3V02d0n_3V00<000000?[`iP3jl>H00P3jl>H00`16P[@0
n_3V0?[`iP0A0?[`iP0604J2]03jl>H0n_3V04J2]007;U@0AX:d0P07;U@60=Xm6@050000002l<Q@0
_38D0;`b50000000A`3jl>H204J2]0l0n_3V0`16P[@60?[`iP0304J2]03jl>H0n_3V0400n_3V00<0
00000?[`iP3jl>H0<P3jl>H01016P[@0n_3V0?[`iP3jl>H304J2]180n_3V00<000000?[`iP3jl>H0
7`3jl>H10?ooo`007P3jl>H00`000000n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V0080n_3V0P16
P[@B0?[`iPH0AX:d00<0hd4K0000000000001@3J?AT200000080_38D00<000000?[`iP3jl>H0AP3j
l>H00`16P[@0n_3V0?[`iP0?0?[`iP80AX:d0`3jl>H304J2]440n_3V00<000000?[`iP3jl>H0<P3j
l>H404J2]1H0n_3V00<000000?[`iP3jl>H07P3jl>H10?ooo`007P3jl>H00`000000n_3V0?[`iP0`
0?[`iP030000003jl>H0n_3V00<0n_3V00<0AX:d0?[`iP3jl>H0403jl>H304J2]00300000016P[@0
hd4K0080hd4K0P0000050=Xm6@80000000<0_38D000000000000A`3jl>H204J2]140n_3V0P16P[@0
103jl>H0AX:d0?[`iP16P[A10?[`iP030000003jl>H0n_3V00/0n_3V0P16P[A00?[`iP030000003j
l>H0n_3V01d0n_3V0@3oool001h0n_3V00<000000?[`iP3jl>H0<@3jl>H00`000000n_3V0?[`iP03
0?[`iP80AX:d403jl>H204J2]00400000016P[@0hd4K04J2]0@0hd4K0P0000050=Xm6@040000002l
<Q@0_38D000004P0n_3V00<0AX:d0?[`iP3jl>H0403jl>H204J2]0030?[`iP16P[@0AX:d0400n_3V
00<000000?[`iP3jl>H03@3jl>H304J2]3d0n_3V00<000000?[`iP3jl>H07@3jl>H10?ooo`007P3j
l>H00`000000n_3V0?[`iP0b0?[`iP030000003jl>H0n_3V00@0n_3V0P16P[@=0?[`iP@0AX:d00<0
000004J2]016P[@01P3S@A/2000000@0fSdI0P0000000`2l<Q@000000?[`iP170?[`iP80AX:d403j
l>H00`16P[@0n_3V04J2]00204J2]400n_3V00<000000?[`iP3jl>H0403jl>H304J2]3/0n_3V00<0
00000?[`iP3jl>H0703jl>H10?ooo`007P3jl>H00`000000n_3V0000000c0?[`iP030000003jl>H0
n_3V00D0n_3V00<0AX:d0?[`iP3jl>H00`3jl>H00`16P[@0n_3V0?[`iP050?[`iPL0AX:d1`3S@A/2
000000@0fSdI00@000000;`b500000000000:03jl>H204J2]1h0n_3V0P16P[@=0?[`iPL0AX:d?`3j
l>H00`000000n_3V0?[`iP0C0?[`iP<0AX:d>@3jl>H00`000000n_3V0?[`iP0K0?[`iP40oooo000N
0?[`iP800000=@3jl>H00`000000n_3V0?[`iP050?[`iP80AX:d0P3jl>H204J2]0P0n_3V00<00000
0>Q47@3XA1d00`3XA1d3000000H0hd4K0P0000030=Xm6@80000000<0_38D0000003jl>H0:03jl>H2
04J2]1h0n_3V00<0AX:d0?[`iP3jl>H02P3jl>H404J2]480n_3V00<000000?[`iP3jl>H05P3jl>H3
04J2]0T0n_3V00<0AX:d0?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`iP0K0?[`iP40oooo000N0?[`
iP030000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H01P3jl>H01@16P[@0n_3V04J2]03jl>H0
AX:d00H0n_3V00<000000>Q47@3XA1d01`3XA1d4000000@0hd4K0`0000020=Xm6@030000002l<Q@0
000002X0n_3V0P16P[@M0?[`iP80AX:d1P3jl>H00`16P[@0n_3V0?[`iP170?[`iP030000003jl>H0
n_3V01T0n_3V1016P[@50?[`iP80AX:d;03jl>H00`000000n_3V0?[`iP0J0?[`iP40oooo000D0?[`
iPD00000103jl>H00`000000n_3V0?[`iP070?[`iP0304J2]03jl>H0n_3V02d0n_3V00<000000?[`
iP3jl>H01P3jl>H204J2]0030?[`iP16P[@0n_3V00D0n_3V0`00000;0>Q47@<00000103S@A/20000
00040=Xm6@0000000000000002/0n_3V0P16P[@M0?[`iP80AX:d0`3jl>H01016P[@0n_3V04J2]016
P[@g0?[`iP80AX:d3P3jl>H00`000000n_3V0?[`iP0M0?[`iP<0AX:d00<0n_3V04J2]03jl>H00P16
P[@[0?[`iP030000003jl>H0n_3V01X0n_3V0@3oool001H0n_3V00<000000?[`iP3jl>H0103jl>H0
0`000000n_3V0?[`iP080?[`iP80AX:d;P3jl>H00`000000n_3V0?[`iP050?[`iP0504J2]03jl>H0
AX:d0?[`iP16P[@0203jl>H6000000P0j4@M0`0000030>=16`80000000@0fSdI0000000000000000
:`3jl>H204J2]1d0n_3V00D0AX:d0?[`iP3jl>H0AX:d0?[`iP0204J2]3T0n_3V0`16P[@;0?[`iP03
0000003jl>H0n_3V0200n_3V0`16P[@20?[`iP0304J2]03jl>H0n_3V02T0n_3V00<000000?[`iP3j
l>H06@3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V00X0n_3V
0P16P[@]0?[`iP030000003jl>H0n_3V00<0n_3V0`16P[@00`3jl>H0AX:d04J2]00>0?[`iPH00000
1@3XA1d300000080hd4K1@00000A0?[`iP80AX:d6@3jl>H204J2]1`0n_3V0P16P[@20?[`iP<0AX:d
>`3jl>H304J2]0P0n_3V00<000000?[`iP3jl>H08@3jl>H604J2]2/0n_3V00<000000?[`iP3jl>H0
603jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V00`0n_3V00<0
AX:d0?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP050?[`iP@0AX:d4`3jl>H5000000<0j4@M0`00
00000`3S@A/000000000000200000180n_3V0P16P[@I0?[`iP<0AX:d6@3jl>H01@16P[@0n_3V04J2
]016P[@0n_3V0080AX:d?P3jl>H304J2]0D0n_3V00<000000?[`iP3jl>H0803jl>H01016P[@0n_3V
04J2]03jl>H404J2]2X0n_3V00<000000?[`iP3jl>H0603jl>H10?ooo`005P3jl>H00`000000n_3V
0?[`iP040?[`iP030000003jl>H0n_3V00d0n_3V0P16P[@/0?[`iP030000003jl>H0n_3V0200n_3V
3@00000B0?[`iP80AX:d6P3jl>H204J2]0@0n_3V0P16P[@A0?[`iP0304J2]03jl>H0n_3V0080AX:d
00<0n_3V04J2]03jl>H0@03jl>H204J2]0<0n_3V00<000000?[`iP3jl>H00P3jl>H00`16P[@0n_3V
0?[`iP0K0?[`iPH0AX:d;@3jl>H00`000000n_3V0?[`iP0G0?[`iP40oooo000E0?[`iP8000001P3j
l>H00`000000n_3V0?[`iP0?0?[`iP80AX:d:`3jl>H00`000000n_3V0?[`iP0U0?[`iPP0000000<0
1biD0?[`iP3jl>H0403jl>H204J2]1X0n_3V0P16P[@20?[`iP<0AX:d3`3jl>H404J2]080n_3V0`16
P[A20?[`iP<0AX:d00<000000?[`iP3jl>H00P3jl>H204J2]1d0n_3V0P16P[@a0?[`iP030000003j
l>H0n_3V01H0n_3V0@3oool001`0n_3V00<000000?[`iP3jl>H04P3jl>H00`16P[@0n_3V0?[`iP0Y
0?[`iP030000003jl>H0n_3V02X0n_3V00@0000000L^E007;U@01biD4`3jl>H204J2]1X0n_3V0`16
P[@00`3jl>H0AX:d04J2]00@0?[`iPL0AX:dA@3jl>H00`000000AX:d04J2]0020?[`iP0304J2]03j
l>H0AX:d04l0n_3V00<000000?[`iP3jl>H05P3jl>H10?ooo`00703jl>H3000001<0n_3V0P16P[@Z
0?[`iP030000003jl>H0n_3V02/0n_3V1007;U@C0?[`iP80AX:d6@3jl>H304J2]0030?[`iP16P[@0
n_3V05<0n_3V0P16P[@60?[`iP030000003jl>H0n_3V00<0AX:d0P3jl>H00`16P[@0n_3V0?[`iP1=
0?[`iP030000003jl>H0n_3V01D0n_3V0@3oool001`0n_3V00<000000?[`iP3jl>H05@3jl>H204J2
]2T0n_3V00<000000?[`iP3jl>H0:`3jl>H700L^E140n_3V0`16P[@E0?[`iP80AX:d0P3jl>H304J2
]5D0n_3V0P16P[@50?[`iP050000003jl>H0n_3V04J2]03jl>H01016P[A>0?[`iP030000003jl>H0
n_3V01D0n_3V0@3oool001`0n_3V00<000000?[`iP3jl>H05`3jl>H00`16P[@0n_3V0?[`iP030?[`
iP0304J2]03jl>H0n_3V0240n_3V00<000000?[`iP3jl>H0;03jl>H700L^E180n_3V0P16P[@30?[`
iP0304J2]03jl>H0n_3V00d0n_3V2016P[AF0?[`iP80AX:d0`3jl>H00`000000n_3V0?[`iP0704J2
]4h0n_3V00<000000?[`iP3jl>H0503jl>H10?ooo`00703jl>H00`000000n_3V0?[`iP0H0?[`iP80
AX:d0P3jl>H00`16P[@0n_3V04J2]00S0?[`iP030000003jl>H0n_3V02<0n_3V00<0AX:d0?[`iP3j
l>H02@3jl>H500L^E180n_3V0`16P[@00`3jl>H0AX:d0?[`iP1]0?[`iP<0AX:d00<000000?[`iP3j
l>H01016P[AB0?[`iP030000003jl>H0n_3V01<0n_3V0@3oool001`0n_3V00<000000?[`iP3jl>H0
6P3jl>H604J2]2<0n_3V00<000000?[`iP3jl>H08`3jl>H204J2]0/0n_3V1@07;U@B0?[`iP80AX:d
00<0n_3V04J2]03jl>H0K`3jl>H00`000000AX:d0?[`iP1F0?[`iP030000003jl>H0n_3V01<0n_3V
0@3oool001`0n_3V00<000000?[`iP3jl>H06`3jl>H304J2]0030?[`iP16P[@0n_3V02<0n_3V00<0
00000?[`iP3jl>H0903jl>H204J2]0/0n_3V1@07;U@?0?[`iP0304J2]03jl>H0n_3V00<0AX:dB03j
l>H204J2]2D0n_3V00@000000?[`iP16P[@0AX:dE@3jl>H2000001@0n_3V0@3oool001/0n_3V00<0
00000?[`iP3jl>H0703jl>H404J2]0030?[`iP16P[@0n_3V02<0n_3V00<000000?[`iP3jl>H09@3j
l>H204J2]0/0n_3V1`07;U@;0?[`iPL0AX:dB@3jl>H304J2]280n_3V00@000000?[`iP3jl>H0n_3V
0`16P[@70?[`iP0304J2]03jl>H0n_3V02@0n_3V0P16P[@O0?[`iP<0000000<0n_3V0000003jl>H0
4`3jl>H10?ooo`006`3jl>H00`000000n_3V0?[`iP0K0?[`iP@0AX:d00<0n_3V04J2]016P[@09@3j
l>H00`000000n_3V0?[`iP0@0?[`iP80AX:d503jl>H204J2]0/0n_3V1P07;U@90?[`iP@0AX:dD03j
l>H304J2]1l0n_3V00<000000?[`iP3jl>H0103jl>H204J2]0@0n_3V00<0AX:d0?[`iP16P[@09`3j
l>H404J2]1P0n_3V0`0000040?[`iP030000003jl>H0n_3V0180n_3V0@3oool001/0n_3V00<00000
0?[`iP3jl>H0703jl>H704J2]2D0n_3V0P00000B0?[`iP80AX:d503jl>H00`16P[@0n_3V0?[`iP0<
0?[`iP@01biD?@3jl>H204J2]1l0n_3V0`16P[@L0?[`iP030000003jl>H0n_3V00H0n_3V0P16P[@2
0?[`iP0404J2]03jl>H0AX:d04J2]2X0n_3V1016P[@@0?[`iP@000001`3jl>H00`000000n_3V0?[`
iP0B0?[`iP40oooo000K0?[`iP800000B`3jl>H00`000000n_3V0?[`iP0A0?[`iP80AX:d4`3jl>H2
04J2]0d0n_3V1`07;U@k0?[`iP<0AX:d7`3jl>H304J2]0P0n_3V0P16P[@>0?[`iP8000002P3jl>H4
04J2]0030?[`iP16P[@0AX:d02d0n_3V0`16P[@80?[`iP0304J2]03jl>H0000000800000303jl>H0
0`000000n_3V0?[`iP0A0?[`iP40oooo000K0?[`iP030000003jl>H0n_3V04/0n_3V00<000000?[`
iP3jl>H04P3jl>H204J2]1<0n_3V0P16P[@=0?[`iPL01biD?03jl>H204J2]200n_3V0`16P[@50?[`
iP<0AX:d2P3jl>H300000080n_3V00<000000?[`iP3jl>H0203jl>H01P16P[@0n_3V04J2]016P[@0
n_3V04J2]300n_3V1016P[@30?[`iP0300000016P[@0AX:d00l0n_3V00<000000?[`iP3jl>H04@3j
l>H10?ooo`006`3jl>H00`000000n_3V0?[`iP1<0?[`iP040000003jl>H0AX:d04J2]180n_3V0P16
P[@C0?[`iP80AX:d3`3jl>H500L^E1<0n_3V0P00000W0?[`iP<0AX:d803jl>H304J2]0040?[`iP16
P[@0AX:d0?[`iP80AX:d1P3jl>H3000000H0n_3V00<000000?[`iP3jl>H01P3jl>H01@16P[@0n_3V
0?[`iP16P[@0n_3V00<0AX:d<`3jl>H504J2]0030?[`iP16P[@0AX:d00d0n_3V00<000000?[`iP3j
l>H04@3jl>H10?ooo`006P3jl>H00`000000n_3V0?[`iP1>0?[`iP030000003jl>H0n_3V0080AX:d
4P3jl>H204J2]1<0n_3V0P16P[@40?[`iP0304J2]03jl>H0n_3V00P0n_3V1`07;U@?0?[`iP@00000
:03jl>H304J2]200n_3V0`16P[@20?[`iP0404J2]03jl>H0n_3V0?[`iP<000002@3jl>H00`000000
n_3V0?[`iP060?[`iPT0AX:d;`3jl>H3000000<0n_3V1P16P[@<0?[`iP030000003jl>H0n_3V0140
n_3V0@3oool001X0n_3V00<000000?[`iP3jl>H0C`3jl>H010000000n_3V0?[`iP3jl>H204J2]180
n_3V0`16P[@B0?[`iP0504J2]03jl>H0n_3V04J2]03jl>H00P16P[@:0?[`iPL01biD303jl>H20000
00<0/RlC0P00000Y0?[`iP<0AX:d1@3jl>H00`16P[@0n_3V0?[`iP0E0?[`iP0304J2]03jl>H0AX:d
00<0AX:d0`00000=0?[`iP030000003jl>H0n_3V00H0n_3V1@16P[@^0?[`iP@000001P3jl>H01016
P[@0n_3V0?[`iP3jl>H304J2]0/0n_3V00<000000?[`iP3jl>H04@3jl>H10?ooo`006P3jl>H00`00
0000n_3V0?[`iP1@0?[`iP030000003jl>H0n_3V0080n_3V0P16P[@C0?[`iP80AX:d1@3jl>H00`16
P[@0n_3V0?[`iP090?[`iP<0AX:d00@0n_3V04J2]016P[@0AX:d3@3jl>H500L^E0X0n_3V0`000004
0;8_4`030000003jl>H0n_3V02T0n_3V0`16P[@20?[`iP80AX:d5P3jl>H304J2]0<000000P16P[@?
0?[`iP030000003jl>H0n_3V03D0n_3V0`00000:0?[`iP@0AX:d3P3jl>H00`000000n_3V0?[`iP0A
0?[`iP40oooo000J0?[`iP030000003jl>H0n_3V0540n_3V00<000000?[`iP3jl>H00`3jl>H204J2
]1<0n_3V0P16P[@30?[`iP80AX:d2`3jl>H604J2]0l0n_3V1P07;U@70?[`iP80000000<0e3/H0000
000000000`2b;a<2000002`0n_3V0P16P[@20?[`iP0304J2]03jl>H0n_3V01<0n_3V0`00000204J2
]1<0n_3V00<000000?[`iP3jl>H0<@3jl>H3000001l0n_3V00<000000?[`iP3jl>H04@3jl>H10?oo
o`006P3jl>H00`000000n_3V0?[`iP1B0?[`iP030000003jl>H0n_3V00@0n_3V0P16P[@C0?[`iP<0
AX:d0P3jl>H00`16P[@0n_3V0?[`iP080?[`iP0304J2]03jl>H0AX:d00@0AX:d403jl>H900L^E003
0?[`iP000000000000@0e3/H0P0000030;8_4`800000:`3jl>H504J2]080n_3V00<0AX:d0?[`iP3j
l>H0303jl>H3000001P0n_3V00<000000?[`iP3jl>H0;P3jl>H3000002<0n_3V00<000000?[`iP3j
l>H0403jl>H10?ooo`006P3jl>H00`000000n_3V0?[`iP1C0?[`iP030000003jl>H0n_3V00D0n_3V
0`16P[@50?[`iP0304J2]03jl>H0n_3V00X0n_3V0P16P[@00`3jl>H0AX:d0?[`iP080?[`iP@0AX:d
0P3jl>H204J2]1@0n_3V2007;U@60=@k608000000`2b;a<00`000000n_3V0?[`iP0W0?[`iP0404J2
]03jl>H0n_3V0?[`iP<0AX:d0P3jl>H204J2]0T0n_3V0`00000L0?[`iP030000003jl>H0n_3V02X0
n_3V0`00000V0?[`iP030000003jl>H0n_3V0100n_3V0@3oool001X0n_3V0P00001E0?[`iP030000
003jl>H0n_3V00L0n_3V0P16P[@30?[`iP80AX:d2P3jl>H204J2]0040?[`iP16P[@0AX:d04J2]0T0
n_3V2016P[@G0?[`iPD01biD1`3D>aP200000080/RlC0P00000W0?[`iP@0AX:d1`3jl>H204J2]0<0
n_3V1000000P0?[`iP030000003jl>H0n_3V02D0n_3V1000000Y0?[`iP030000003jl>H0n_3V0100
n_3V0@3oool001T0n_3V0P00001G0?[`iP030000003jl>H0n_3V00P0n_3V0`16P[@00`3jl>H0AX:d
04J2]0090?[`iPL0AX:d:03jl>H20000000300L^E03R@1/00000008000001P3D>aP200000080/RlC
00<000000?[`iP3jl>H03`3jl>H204J2]200n_3V0`00000U0?[`iP030000003jl>H0n_3V01X0n_3V
0P16P[@50?[`iP<00000;@3jl>H00`000000n_3V0?[`iP0@0?[`iP40oooo000I0?[`iP030000003j
l>H0n_3V05L0n_3V00<000000?[`iP3jl>H02@3jl>H204J2]0030?[`iP16P[@0n_3V00P0n_3V1016
P[@[0?[`iP8000001@3R@1/3000000D0e3/H0P0000000`2b;a<000000000000A0?[`iP80AX:d6`3j
l>H300000080n_3V0P16P[@T0?[`iP030000003jl>H0n_3V01`0n_3V1016P[@00`000000n_3V0?[`
iP0^0?[`iP030000003jl>H0n_3V0100n_3V0@3oool001T0n_3V00<000000?[`iP3jl>H0F03jl>H0
0`000000n_3V0?[`iP070?[`iP0304J2]03jl>H0n_3V00<0AX:d=`3jl>H2000000P0hT0K0`000004
0=@k6080000000<0/RlC0000000000004@3jl>H304J2]1D0n_3V0`0000070?[`iP80AX:d803jl>H2
04J2]0030?[`iP000000n_3V01/0n_3V0`0000020?[`iP@0AX:d303jl>H00`16P[@0n_3V0?[`iP0N
0?[`iP030000003jl>H0n_3V0100n_3V0@3oool001T0n_3V00<000000?[`iP3jl>H0=P3jl>H00`16
P[@0n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V00H0n_3V1`16P[@e0?[`iP800000303R@1/30000
00<0e3/H0P0000000`2b;a<000000?[`iP0B0?[`iP80AX:d403jl>H3000000`0n_3V0P16P[@P0?[`
iP80AX:d00<0000004J2]03jl>H05P3jl>H3000000T0n_3V1016P[@80?[`iP80AX:d7`3jl>H00`00
0000n_3V0?[`iP0@0?[`iP40oooo000I0?[`iP030000003jl>H0n_3V03L0n_3V0P16P[@Q0?[`iP03
0000003jl>H0n_3V0440n_3V1@00000<0>906`<000000P3D>aP4000001<0n_3V0`16P[@:0?[`iP<0
00004@3jl>H00`16P[@0n_3V0?[`iP0P0?[`iP0400000016P[@0AX:d04J2]100n_3V1000000@0?[`
iP@0AX:d0`3jl>H01016P[@0n_3V04J2]016P[@O0?[`iP030000003jl>H0n_3V00l0n_3V0@3oool0
01T0n_3V00<000000?[`iP3jl>H0;@3jl>H204J2]0X0n_3V0P16P[@P0?[`iP030000003jl>H0n_3V
03T0n_3V0P16P[@50?[`iP8000000`3/AAd6000000T0hT0K0`0000000`3D>aP00000000000020000
01@0n_3V0P16P[@50?[`iP<000005@3jl>H204J2]0L0n_3V00<0AX:d0?[`iP3jl>H05P3jl>H01000
0000n_3V0?[`iP3jl>H304J2]0P0n_3V00<0AX:d0?[`iP0000000P00000H0?[`iPD0AX:d0P3jl>H0
0`16P[@0n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V00l0n_3V0@3oool001P0n_3V00<000000?[`
iP3jl>H0<03jl>H204J2]0X0n_3V0P16P[@O0?[`iP030000003jl>H0n_3V03X0n_3V0`16P[@20?[`
iP030000003/AAd0k4DM00P0k4DM1P0000060>906`H000005@3jl>H204J2]0<00000103jl>H204J2
]1@0n_3V0P16P[@50?[`iP<0AX:d5`3jl>H00`000000n_3V0?[`iP030?[`iP@0AX:d0`3jl>H00`00
0000AX:d04J2]00N0?[`iPH0AX:d7@3jl>H00`000000n_3V0?[`iP0?0?[`iP40oooo000H0?[`iP03
0000003jl>H0n_3V0380n_3V0P16P[@:0?[`iP80AX:d7P3jl>H00`000000n_3V0?[`iP0l0?[`iP80
AX:d2@0000080>a57@L000000P3R@1/5000000<0n_3V0P16P[@=0?[`iP<0000000@0n_3V04J2]016
P[@0AX:d0P3jl>H01016P[@0n_3V04J2]016P[@E0?[`iP80AX:d0P3jl>H01@16P[@0n_3V04J2]03j
l>H0AX:d01L0n_3V00<000000?[`iP3jl>H01P3jl>H304J2]0040?[`iP16P[@0AX:d04J2]1`0n_3V
0P16P[@20?[`iP@0AX:d703jl>H00`000000n_3V0?[`iP0?0?[`iP40oooo000H0?[`iP030000003j
l>H0n_3V03@0n_3V0`16P[@90?[`iP80AX:d7@3jl>H00`000000n_3V0?[`iP0n0?[`iP<0AX:d1@3j
l>HG0000000300L^E016P[@0AX:d0080AX:d2@3jl>H3000000L0n_3V1016P[@00`3jl>H0AX:d04J2
]00F0?[`iP<0AX:d0P3jl>H204J2]1P0n_3V00<000000?[`iP3jl>H00P3jl>H3000000<0n_3V1@16
P[@K0?[`iPD0AX:d7`3jl>H00`000000n_3V0?[`iP0?0?[`iP40oooo000H0?[`iP800000>03jl>H2
04J2]0T0n_3V0P16P[@L0?[`iP030000003jl>H0n_3V0400n_3V0`16P[@60?[`iP80AX:d2P3jl>H7
000000801biD00<0AX:d00L^E007;U@00P07;U@40?[`iP<000002`3jl>H404J2]0030?[`iP16P[@0
n_3V01H0n_3V0`16P[@0103jl>H0AX:d04J2]016P[@H0?[`iP@000001P3jl>H00`16P[@0n_3V0?[`
iP0304J2]3h0n_3V00<000000?[`iP3jl>H03`3jl>H10?ooo`00603jl>H00`000000n_3V0?[`iP0i
0?[`iP80AX:d2@3jl>H204J2]1/0n_3V00<000000?[`iP3jl>H0@P3jl>H304J2]0<0n_3V0`16P[@A
0?[`iP0300L^E016P[@01biD00@01biD0`00000>0?[`iP0404J2]03jl>H0AX:d0?[`iP<0AX:d5P3j
l>H00`16P[@0n_3V0?[`iP0204J2]0030?[`iP16P[@0n_3V01@0n_3V100000090?[`iP@0AX:d@03j
l>H00`000000n_3V0?[`iP0?0?[`iP40oooo000H0?[`iP030000003jl>H0n_3V03/0n_3V0`16P[@6
0?[`iP0404J2]03jl>H0AX:d04J2]0D0n_3V00<0AX:d0?[`iP3jl>H04P3jl>H00`000000n_3V0?[`
iP140?[`iP@0AX:d00<0n_3V04J2]03jl>H03`3jl>H204J2]080n_3V00@0AX:d0000000000000000
0`07;U@=0?[`iPT0AX:d503jl>H01016P[@0n_3V0?[`iP16P[@20?[`iP<0AX:d4@3jl>H3000000@0
n_3V00<000000?[`iP3jl>H01P3jl>H204J2]4<0n_3V00<000000?[`iP3jl>H03P3jl>H10?ooo`00
603jl>H00`000000n_3V0?[`iP0n0?[`iP80AX:d0`3jl>H304J2]080n_3V0P16P[@20?[`iP0404J2
]03jl>H0AX:d04J2]1<0n_3V00<000000?[`iP3jl>H0A@3jl>H504J2]0l0n_3V0P16P[@300000003
04J2]03jl>H0n_3V00H01biD2`3jl>H504J2]1L0n_3V2@16P[@>0?[`iP<00000203jl>H00`000000
n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V00h0n_3V0@3oool001L0n_3V00<000000?[`iP3jl>H0
@@3jl>H704J2]0<0n_3V0`16P[@0103jl>H0AX:d04J2]016P[@C0?[`iP030000003jl>H0n_3V04<0
n_3V0P16P[@20?[`iP<0AX:d3@3jl>H30000000304J2]03jl>H0n_3V00D0n_3V2P07;U@R0?[`iPD0
AX:d3P3jl>H3000000`0n_3V00<000000?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`iP0>0?[`iP40
oooo000G0?[`iP030000003jl>H0n_3V04<0n_3V0`16P[@00`3jl>H0AX:d0?[`iP030?[`iPH0AX:d
503jl>H00`000000n_3V0?[`iP120?[`iP@0AX:d3@3jl>H3000000l0n_3V2@07;U@J0?[`iP800000
4P3jl>H4000000l0n_3V00<000000?[`iP3jl>H0B@3jl>H00`000000n_3V0?[`iP0>0?[`iP40oooo
000G0?[`iP030000003jl>H0n_3V04<0n_3V0P16P[@0103jl>H0AX:d04J2]016P[@30?[`iP0304J2
]03jl>H0AX:d00@0AX:d503jl>H00`000000n_3V0?[`iP1?0?[`iP<000005`3jl>H:00L^E1@0n_3V
00@000000:`]4P00000000003@3jl>H300000180n_3V0P16P[@00`000000n_3V0?[`iP180?[`iP03
0000003jl>H0n_3V00h0n_3V0@3oool001L0n_3V00<000000?[`iP3jl>H0@P3jl>H804J2]0030?[`
iP16P[@0AX:d0080AX:d0P3jl>H204J2]1D0n_3V00<000000?[`iP3jl>H0B`3jl>H3000001h0n_3V
2007;U@A0?[`iP8000000`2/;A8200000080AX:d1P3jl>H3000001L0n_3V00@0AX:d00000016P[@0
AX:dA`3jl>H00`000000n_3V0?[`iP0>0?[`iP40oooo000G0?[`iP030000003jl>H0n_3V04<0n_3V
1016P[@40?[`iP0404J2]03jl>H0AX:d0?[`iPD0AX:d5@3jl>H00`000000n_3V0?[`iP0h0?[`iP03
04J2]03jl>H0n_3V00/0n_3V1000000V0?[`iPD01biD3`3jl>H3000000@0[2dB0P00000404J2]080
0000703jl>H00`000000n_3V04J2]00204J2]4@0n_3V00<000000?[`iP3jl>H03P3jl>H10?ooo`00
5`3jl>H3000004`0n_3V1016P[@J0?[`iP030000003jl>H0n_3V0240n_3V0P16P[@E0?[`iP80AX:d
203jl>H3000002`0n_3V2007;U@:0?[`iP80000000@0d3XH00000000000000000`2/;A8300000003
0?[`iP16P[@0AX:d0080AX:d303jl>H00`16P[@0n_3V0?[`iP0;0?[`iP030000003jl>H0n_3V0080
n_3V1016P[@:0?[`iP0304J2]03jl>H0n_3V03@0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`00
5P3jl>H2000006d0n_3V00<000000?[`iP3jl>H00P16P[@<0?[`iP80AX:d4P3jl>H204J2]1D0n_3V
0P16P[@30?[`iP<00000<@3jl>H900L^E0L0n_3V0P0000040=0j608000000`2/;A82000000@0n_3V
1016P[@80?[`iP80AX:d3@3jl>H00`000000n_3V0?[`iP050?[`iP<0AX:d1`3jl>H204J2]3D0n_3V
00<000000?[`iP3jl>H03@3jl>H10?ooo`005P3jl>H00`000000n_3V0?[`iP1]0?[`iP040000003j
l>H0n_3V0?[`iP80AX:d303jl>H304J2]140n_3V0`16P[@D0?[`iP<00000>@3jl>H:00L^E0800000
1`3@>QP300000080[2dB0P0000060?[`iP@0AX:d103jl>H304J2]0d0n_3V00<000000?[`iP3jl>H0
1`3jl>H404J2]080n_3V00@0AX:d0?[`iP16P[@0AX:d=03jl>H00`000000n_3V0?[`iP0=0?[`iP40
oooo00000`3jl>H000000000000300000080n_3V0P0000040?[`iP8000001P3jl>H00`000000n_3V
0?[`iP070?[`iP0304J2]03jl>H0n_3V06@0n_3V00<000000?[`iP3jl>H00P3jl>H304J2]0`0n_3V
1016P[@@0?[`iP80AX:d3`3jl>H300000080n_3V0P16P[@l0?[`iPP01biD2P3@>QP3000000040:`]
4P0000000000000000L0n_3V1@16P[@20?[`iP0304J2]03jl>H0n_3V00/0n_3V00<000000?[`iP3j
l>H02P3jl>H304J2]0040?[`iP16P[@0n_3V04J2]3<0n_3V00<000000?[`iP3jl>H03@3jl>H10?oo
o`000`3jl>H00`000000n_3V0?[`iP070?[`iP040000003jl>H0n_3V000000D0n_3V00<000000?[`
iP3jl>H0203jl>H204J2]6D0n_3V00<000000?[`iP3jl>H0103jl>H204J2]0h0n_3V0`16P[@:0?[`
iP0304J2]03jl>H0n_3V0080n_3V0`16P[@90?[`iP<000001`3jl>H204J2]3d0n_3V0P00000400L^
E0030000003@>QP0d3XH00T0d3XH0P0000020:`]4P800000203jl>H604J2]0`0n_3V00<000000?[`
iP3jl>H0303jl>H604J2]380n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`000`3jl>H00`000000
n_3V0?[`iP0:0?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H02P3jl>H204J2]6@0
n_3V00<000000?[`iP3jl>H01@3jl>H304J2]0P0n_3V00<0AX:d0?[`iP3jl>H00`3jl>H304J2]0L0
n_3V0P16P[@60?[`iP80AX:d103jl>H300000080n_3V00<0AX:d0?[`iP3jl>H01`3jl>H204J2]3P0
n_3V0`0000030?[`iP0400000007;U@0h40K0>106`D00000203@>QP3000000030:`]4P0000000000
00H0n_3V00@0AX:d0?[`iP3jl>H0n_3V0`16P[@<0?[`iP030000003jl>H0n_3V00X0n_3V00@0AX:d
0?[`iP16P[@0n_3V1016P[@a0?[`iP030000003jl>H0n_3V00d0n_3V0@3oool000<0n_3V00<00000
0?[`iP3jl>H0203jl>H2000000H0n_3V00<000000?[`iP3jl>H0303jl>H204J2]6<0n_3V00<00000
0?[`iP3jl>H01`3jl>H304J2]0@0n_3V0`16P[@70?[`iP<0AX:d0`3jl>H404J2]0L0n_3V00@0AX:d
0000000000000000103jl>H00`16P[@0n_3V04J2]00:0?[`iP0304J2]03jl>H0n_3V0340n_3V1000
00060?[`iP030000003P@1/0h40K00H0h40K1@0000060=0j60D00000103jl>H404J2]100n_3V00<0
00000?[`iP3jl>H02@3jl>H604J2]3<0n_3V00<000000?[`iP3jl>H03@3jl>H10?ooo`000`3jl>H0
0`000000n_3V0?[`iP080?[`iP030000003jl>H0n_3V00D0n_3V00<000000?[`iP3jl>H03P3jl>H2
04J2]680n_3V00<000000?[`iP3jl>H02@3jl>H204J2]080n_3V0`16P[@:0?[`iP@0AX:d0P3jl>H0
0`16P[@0n_3V0?[`iP030?[`iP<0000000@0n_3V04J2]016P[@0AX:d0`3jl>H404J2]0X0n_3V0P16
P[@70?[`iP0304J2]03jl>H0n_3V02@0n_3V0`0000090?[`iP8000003@3P@1/6000000<0d3XH1000
000G0?[`iP030000003jl>H0n_3V00T0n_3V0`16P[@e0?[`iP030000003jl>H0n_3V00d0n_3V0@3o
ool00080n_3V0P00000:0?[`iP<00000103jl>H00`000000n_3V0?[`iP0A0?[`iP80AX:dH@3jl>H0
0`000000n_3V0?[`iP0:0?[`iP<0AX:d00<0n_3V04J2]016P[@0303jl>H504J2]0040?[`iP000000
0000000000L0n_3V0`16P[@0103jl>H0AX:d0?[`iP16P[@<0?[`iP80AX:d103jl>H01016P[@0n_3V
04J2]016P[@Q0?[`iP<00000303jl>H9000000`0h40K1@000000103@>QP0000000000000000F0?[`
iP030000003jl>H0n_3V0440n_3V00<000000?[`iP3jl>H0303jl>H10?ooo`005@3jl>H00`000000
n_3V0?[`iP0C0?[`iP80AX:dH03jl>H00`000000n_3V0?[`iP0:0?[`iP0304J2]03jl>H0AX:d0080
AX:d2`3jl>H01016P[@0n_3V0?[`iP3jl>H3000000`0n_3V0`16P[@20?[`iP0304J2]03jl>H0n_3V
00/0n_3V0P16P[@20?[`iP0404J2]03jl>H0AX:d04J2]1h0n_3V0`00000?0?[`iP8000001`3_AQd@
000000030>106`000000000000@0000000<01biD0?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP11
0?[`iP030000003jl>H0n_3V00`0n_3V0@3oool001D0n_3V0P00000F0?[`iP80AX:d1`3jl>H00`16
P[@0n_3V0?[`iP1E0?[`iP030000003jl>H0n_3V00T0n_3V1P16P[@:0?[`iP0404J2]00000000000
000000h0n_3V00@0AX:d0?[`iP16P[@0n_3V0`16P[@?0?[`iP80AX:d0P3jl>H304J2]1X0n_3V0`00
000B0?[`iP030000003_AQd0kdHM00h0kdHM3`00000700L^E0h0n_3V00<000000?[`iP3jl>H0@03j
l>H00`000000n_3V0?[`iP0<0?[`iP40oooo000E0?[`iP030000003jl>H0n_3V01L0n_3V0P16P[@4
0?[`iP<0AX:dE`3jl>H00`000000n_3V0?[`iP080?[`iP<0AX:d2`3jl>H300000140n_3V2016P[@>
0?[`iP0404J2]03jl>H0AX:d04J2]080n_3V00<0AX:d0?[`iP3jl>H0503jl>H4000001D0n_3V4@00
000@0?[`iP/01biD2P3jl>H00`000000n_3V0?[`iP0F0?[`iP80000000@0n_3V04J2]016P[@0AX:d
8`3jl>H00`000000n_3V0?[`iP0<0?[`iP40oooo000E0?[`iP030000003jl>H0n_3V01T0n_3V0P16
P[@20?[`iP0304J2]03jl>H0AX:d05P0n_3V00<000000?[`iP3jl>H04P3jl>H3000001D0n_3V1016
P[@A0?[`iP0304J2]03jl>H0n_3V00<0AX:d00<0n_3V04J2]03jl>H04@3jl>H3000003l0n_3V2`07
;U@60?[`iP030000003jl>H0n_3V01D0n_3V00@000000:L/4P00000000000P3jl>H504J2]0d0n_3V
00<0AX:d0?[`iP3jl>H03P3jl>H00`000000n_3V0?[`iP0<0?[`iP40oooo000E0?[`iP030000003j
l>H0n_3V01/0n_3V0P16P[@0103jl>H0AX:d0?[`iP16P[AH0?[`iP8000003`3jl>H3000002L0n_3V
0P16P[@30?[`iPD0AX:d0P3jl>H204J2]0l0n_3V0`0000170?[`iP/01biD00<0n_3V0000003jl>H0
5@3jl>H2000000<0Yb`B0P0000050?[`iPD0AX:d203jl>H204J2]0l0n_3V00<000000?[`iP3jl>H0
303jl>H10?ooo`00503jl>H00`000000n_3V0?[`iP0M0?[`iP<0AX:d00<0n_3V04J2]016P[@0F@3j
l>H00`000000n_3V0?[`iP090?[`iP<00000;03jl>H404J2]0030?[`iP16P[@0AX:d00H0AX:d1P3j
l>H304J2]080n_3V0`00000A0?[`iP80AX:d?03jl>H800L^E00300000007;U@01biD01<0n_3V0`00
00040:L/4P<000001`3jl>H604J2]080n_3V1016P[@=0?[`iP030000003jl>H0n_3V00`0n_3V0@3o
ool001@0n_3V00<000000?[`iP3jl>H0703jl>H01016P[@0n_3V04J2]03jl>H304J2]5X0n_3V00<0
00000?[`iP3jl>H01@3jl>H3000003<0n_3V0`16P[@>0?[`iP0300000016P[@0AX:d0080AX:d503j
l>H404J2]1T0n_3V0P16P[@R0?[`iP@01biD00<0000000L^E007;U@01007;U@>0?[`iP80000000@0
cSTH0000000000000000102W;182000000/0n_3V1`16P[@=0?[`iP030000003jl>H0n_3V00/0n_3V
0@3oool001@0n_3V00<000000?[`iP3jl>H0703jl>H804J2]2d0n_3V0P16P[@[0?[`iP040000003j
l>H0n_3V0?[`iP<00000>@3jl>H304J2]0L0n_3V0P16P[@2000000D0n_3V1016P[@:0?[`iP0304J2
]03jl>H0n_3V00L0n_3V0`16P[@H0?[`iP<0AX:d903jl>H00`0000001biD00L^E00800L^E0T0n_3V
0P0000040<hi60<000000`2W;183000000T0n_3V0P16P[@20?[`iP<0AX:d303jl>H00`000000n_3V
0?[`iP0;0?[`iP40oooo000D0?[`iP030000003jl>H0n_3V01d0n_3V1016P[@b0?[`iP<0AX:d203j
l>H204J2]1h0n_3V1000000o0?[`iP@0AX:d0`00000304J2]0X0n_3V1@16P[@50?[`iP80AX:d2`3j
l>H404J2]0X0n_3V00<0AX:d0?[`iP3jl>H02P3jl>H204J2]280n_3V00<000000?[`iP3jl>H00P3j
l>H;00L^E0<0n_3V00<000000<Ti600000001`3>>AP3000000<0Yb`B0P0000070?[`iPD0AX:d3P3j
l>H00`000000n_3V0?[`iP0;0?[`iP40oooo000D0?[`iP030000003jl>H0n_3V05H0n_3V1016P[@6
0?[`iP<0AX:d2@3jl>H204J2]0d0n_3V0`0000020?[`iP030000003jl>H0n_3V03l0n_3V0`000004
04J2]0030?[`iP16P[@0AX:d00h0n_3V1016P[@00`3jl>H0AX:d0?[`iP0204J2]0d0n_3V0`16P[@7
0?[`iP80AX:d3@3jl>H304J2]200n_3V00<000000?[`iP3jl>H01P3jl>H;00L^E0030000003>>AP0
cSTH00P0cSTH0`0000020:L/4P8000001P3jl>H204J2]100n_3V00<000000?[`iP3jl>H02`3jl>H1
0?ooo`00503jl>H00`000000n_3V0?[`iP1J0?[`iP<0AX:d1P3jl>H204J2]0T0n_3V0P16P[@80?[`
iP<000001P3jl>H00`000000n_3V0?[`iP0k0?[`iP<000001@3jl>H604J2]140n_3V1016P[@00`3j
l>H0AX:d0?[`iP0>0?[`iP@0AX:d0P3jl>H01016P[@0n_3V04J2]016P[@?0?[`iP<0AX:d7P3jl>H0
0`000000n_3V0?[`iP0:0?[`iPL01biD0`00000:0<hi60L000005@3jl>H00`000000n_3V0?[`iP0;
0?[`iP40oooo000D0?[`iP800000GP3jl>H304J2]0D0n_3V0`16P[@80?[`iP80AX:d0`3jl>H30000
00X0n_3V00<000000?[`iP3jl>H0=`3jl>H3000000P0n_3V1`16P[@@0?[`iP0404J2]03jl>H0n_3V
0?[`iP<0AX:d4P3jl>H404J2]080n_3V00<0AX:d0?[`iP3jl>H03`3jl>H204J2]0T0n_3V00<0AX:d
0?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP0=0?[`iP<01biD0`3O?a/6000000P0cSTH1@00000C
0?[`iP030000003jl>H0n_3V00/0n_3V0@3oool001<0n_3V0P00001R0?[`iP<0AX:d103jl>H404J2
]0L0n_3V0`00000>0?[`iP030000003jl>H0n_3V0380n_3V1000000;0?[`iP@0AX:d4`3jl>H504J2
]1H0n_3V1P16P[@B0?[`iP<0AX:d1P3jl>H304J2]180n_3V00<000000?[`iP3jl>H0303jl>H00`00
0000^3<F000000090=lo6`H000001@3>>AP500000100n_3V00<000000?[`iP3jl>H02`3jl>H10?oo
o`004`3jl>H00`000000n_3V0?[`iP1T0?[`iP@0AX:d0P3jl>H01016P[@0n_3V04J2]016P[@20?[`
iP<000000P3jl>H204J2]0h0n_3V00<000000?[`iP3jl>H0;P3jl>H3000002H0n_3V0P16P[@H0?[`
iP0404J2]03jl>H0AX:d0?[`iP@0AX:d503jl>H304J2]080n_3V00<0AX:d0?[`iP3jl>H00P16P[@A
0?[`iP030000003jl>H0n_3V00/0n_3V00<000000;Pc5P000000403O?a/600000080cSTH1000000?
0?[`iP030000003jl>H0n_3V00X0n_3V0@3oool001<0n_3V00<000000?[`iP3jl>H0I`3jl>H504J2
]0050?[`iP000000000000000016P[@0103jl>H404J2]0d0n_3V00<000000?[`iP3jl>H0:P3jl>H3
000004<0n_3V1P16P[@I0?[`iP<0AX:d00<0n_3V04J2]03jl>H00P16P[@A0?[`iP030000003jl>H0
n_3V00X0n_3V00<000000;Pc5P0000005P3O?a/8000000d0n_3V00<000000?[`iP3jl>H02P3jl>H1
0?ooo`004`3jl>H00`000000n_3V0?[`iP1V0?[`iP80AX:d0P3jl>H3000000@0n_3V1016P[@0103j
l>H0AX:d04J2]03jl>H204J2]0`0n_3V00<000000?[`iP3jl>H09P3jl>H3000004L0n_3V0P16P[@N
0?[`iP<0AX:d0P3jl>H00`16P[@0n_3V0?[`iP0@0?[`iP030000003jl>H0n_3V00T0n_3V8`00000;
0?[`iP030000003jl>H0n_3V00X0n_3V0@3oool001<0n_3V00<000000?[`iP3jl>H0IP3jl>H01@16
P[@00000000000000000AX:d00T0n_3V0P16P[@20?[`iP0304J2]03jl>H0n_3V0080AX:d2`3jl>H0
0`000000n_3V0?[`iP0R0?[`iP<00000J@3jl>H00`16P[@0n_3V0?[`iP0504J2]180n_3V00<00000
0?[`iP3jl>H0203jl>H00`000000SBD@0000000?0?567P/000004@3jl>H00`000000n_3V0?[`iP0:
0?[`iP40oooo000C0?[`iP030000003jl>H0n_3V06@0n_3V0`0000000`16P[@0n_3V0?[`iP090?[`
iP0304J2]03jl>H0AX:d00@0AX:d0`3jl>H204J2]0H0n_3V00D0AX:d0?[`iP3jl>H0n_3V0000000O
0?[`iP@00000I@3jl>H304J2]0@0n_3V2@16P[@A0?[`iP030000003jl>H0n_3V00P0n_3V0P000005
0?567P/00000703jl>H00`000000n_3V0?[`iP0:0?[`iP40oooo000B0?[`iP030000003jl>H0n_3V
0680n_3V0`00000?0?[`iPP0AX:d103jl>H204J2]0<0n_3V00<0AX:d0?[`iP16P[@00`3jl>H01000
0000n_3V04J2]016P[@H0?[`iP<00000K03jl>H704J2]0040?[`iP16P[@0AX:d04J2]0L0n_3V00<0
AX:d0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP070?[`iPL000009`3jl>H00`000000n_3V0?[`
iP0:0?[`iP40oooo000B0?[`iP030000003jl>H0n_3V05l0n_3V0`00000B0?[`iP80AX:d00@0n_3V
04J2]016P[@0AX:d203jl>H204J2]0050?[`iP16P[@0AX:d0?[`iP16P[@00`3jl>H00`000000n_3V
0?[`iP0404J2]0X0n_3V0`16P[@40?[`iP<00000M03jl>H504J2]0P0n_3V0P16P[@:0?[`iP80AX:d
00<000000?[`iP3jl>H0=03jl>H00`000000n_3V0?[`iP0:0?[`iP40oooo000B0?[`iP030000003j
l>H0n_3V05`0n_3V0`00000F0?[`iP80AX:d3@3jl>H304J2]0030?[`iP16P[@0AX:d00<0n_3V00<0
00000?[`iP3jl>H00`3jl>H404J2]0T0n_3V1016P[Al0?[`iPH0AX:d0P3jl>H404J2]0/0n_3V00@0
000004J2]016P[@0AX:d3`3jl>H00`16P[@0n_3V0?[`iP0Q0?[`iP030000003jl>H0n_3V00T0n_3V
0@3oool00180n_3V00<000000?[`iP3jl>H0F@3jl>H3000002L0n_3V00<0AX:d0?[`iP16P[@00P16
P[@00`3jl>H0AX:d0?[`iP030?[`iP030000003jl>H0n_3V00H0n_3V1016P[@30?[`iP8000000P16
P[@20?[`iP@0AX:d2P3jl>H00`16P[@0n_3V0?[`iP1a0?[`iPL0AX:d2P3jl>H010000000n_3V0?[`
iP3jl>H504J2]0X0n_3V0`16P[@Q0?[`iP030000003jl>H0n_3V00T0n_3V0@3oool00180n_3V0P00
001G0?[`iP<00000:P3jl>H00`16P[@0n_3V04J2]0020?[`iP<0AX:d103jl>H00`000000n_3V0?[`
iP080?[`iP0300000016P[@0AX:d00H0AX:d1@3jl>H504J2]0@0n_3V0`16P[Ac0?[`iP80AX:d0P3j
l>H304J2]0X0n_3V00<000000?[`iP3jl>H01@3jl>H504J2]0D0n_3V00@0AX:d0?[`iP16P[@0AX:d
803jl>H00`000000n_3V0?[`iP090?[`iP40oooo000B0?[`iP030000003jl>H0n_3V05<0n_3V0`00
000/0?[`iPX0AX:d103jl>H00`000000n_3V0?[`iP040?[`iP<000001@3jl>H504J2]0T0n_3V1016
P[@00`3jl>H0AX:d04J2]00304J2]700n_3V1@16P[@=0?[`iP030000003jl>H0n_3V00T0n_3V1@16
P[@00`3jl>H0AX:d0?[`iP0204J2]1l0n_3V00<000000?[`iP3jl>H02@3jl>H10?ooo`004@3jl>H0
0`000000n_3V0?[`iP0`0?[`iP80AX:d7`3jl>H300000300n_3V1@16P[@90?[`iP030000003jl>H0
n_3V00<000001`3jl>H204J2]080n_3V0`16P[@<0?[`iPX0AX:d303jl>H00`16P[@0n_3V0?[`iP1N
0?[`iP80AX:d403jl>H00`000000n_3V0?[`iP0<0?[`iPD0AX:d00<0n_3V04J2]03jl>H07@3jl>H0
0`000000n_3V0?[`iP090?[`iP40oooo000A0?[`iP030000003jl>H0n_3V0380n_3V0`16P[@I0?[`
iP<00000@P3jl>H2000000X0n_3V1016P[@?0?[`iP0404J2]03jl>H0n_3V0?[`iP<0AX:d0`3jl>H4
04J2]0P0n_3V1016P[A_0?[`iP030000003jl>H0n_3V00`0n_3V00@0AX:d0?[`iP16P[@0n_3V1016
P[@M0?[`iP030000003jl>H0n_3V00T0n_3V0@3oool00140n_3V00<000000?[`iP3jl>H0=@3jl>H2
04J2]1<0n_3V100000150?[`iP030000003jl>H0n_3V01`0n_3V1@16P[@90?[`iP@0AX:d103jl>H3
04J2]0040?[`iP16P[@0AX:d04J2]6d0n_3V00<000000?[`iP3jl>H02`3jl>H604J2]1l0n_3V00<0
00000?[`iP3jl>H02@3jl>H10?ooo`004@3jl>H00`000000n_3V0?[`iP0g0?[`iP<0AX:d3@3jl>H3
000004T0n_3V00<000000?[`iP3jl>H0703jl>H204J2]100n_3V1@16P[@20?[`iP0404J2]03jl>H0
n_3V0?[`iP<0AX:dJ`3jl>H00`000000n_3V0?[`iP0;0?[`iP80AX:d8`3jl>H00`000000n_3V0?[`
iP080?[`iP40oooo000A0?[`iP030000003jl>H0n_3V03X0n_3V0`16P[@70?[`iP<00000C03jl>H0
0`000000n_3V0?[`iP0a0?[`iPH0AX:d1@3jl>H304J2]6T0n_3V00<000000?[`iP3jl>H0;`3jl>H0
0`000000n_3V0?[`iP080?[`iP40oooo000A0?[`iP030000003jl>H0n_3V03`0n_3V0`16P[@20?[`
iP<000000P3jl>H00`16P[@0n_3V0?[`iP1:0?[`iP030000003jl>H0n_3V0340n_3V0P16P[@20?[`
iP<0AX:d1`3jl>H304J2]0X0n_3V00<0AX:d0?[`iP3jl>H0FP3jl>H00`000000n_3V0?[`iP0^0?[`
iP030000003jl>H0n_3V00P0n_3V0@3oool00140n_3V00<000000?[`iP3jl>H0?P3jl>H300000003
04J2]03jl>H0n_3V0080n_3V0P16P[A;0?[`iP030000003jl>H0n_3V0340n_3V1@16P[@<0?[`iP80
AX:d1`3jl>H01016P[@0n_3V04J2]016P[AJ0?[`iP030000003jl>H0n_3V02h0n_3V00<000000?[`
iP3jl>H0203jl>H10?ooo`00403jl>H00`000000n_3V0?[`iP0l0?[`iP<000000P3jl>H604J2]003
0?[`iP16P[@0AX:d04X0n_3V00<000000?[`iP3jl>H0<@3jl>H204J2]140n_3V0`16P[@40?[`iP03
04J2]03jl>H0n_3V00@0AX:dF03jl>H00`000000n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V00P0
n_3V0@3oool00100n_3V0P00000j0?[`iP<000001`3jl>H204J2]0030?[`iP16P[@0AX:d0080n_3V
00<0AX:d0?[`iP3jl>H0A`3jl>H00`000000n_3V0?[`iP170?[`iP@0AX:d0P3jl>H304J2]080n_3V
1@16P[@=0?[`iP0304J2]03jl>H0n_3V04@0n_3V00<000000?[`iP3jl>H0;03jl>H00`000000n_3V
0?[`iP080?[`iP40oooo000@0?[`iP030000003jl>H0n_3V03H0n_3V0`00000<0?[`iPL0AX:dB03j
l>H00`000000n_3V0?[`iP1:0?[`iP@0AX:d00<0n_3V04J2]016P[@01P3jl>H504J2]0P0n_3V0P16
P[A60?[`iP030000003jl>H0n_3V02/0n_3V00<000000?[`iP3jl>H0203jl>H10?ooo`00403jl>H0
0`000000n_3V0?[`iP0c0?[`iP<000003`3jl>H804J2]0@0n_3V00<0AX:d0?[`iP3jl>H07P3jl>H3
04J2]1l0n_3V00<000000?[`iP3jl>H0B@3jl>H00`16P[@0n_3V0?[`iP0504J2]0/0n_3V1P16P[@2
0?[`iP@0AX:dA03jl>H00`000000n_3V0?[`iP0/0?[`iP030000003jl>H0n_3V00L0n_3V0@3oool0
0100n_3V00<000000?[`iP3jl>H0<03jl>H3000001<0n_3V1@16P[@50?[`iP<0AX:d8P3jl>H504J2
]0d0n_3V00<0AX:d0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP190?[`iPT0AX:d403jl>H704J2
]0040?[`iP16P[@0AX:d04J2]400n_3V00<000000?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP07
0?[`iP40oooo000@0?[`iP030000003jl>H0n_3V02d0n_3V0`00000K0?[`iP80AX:d0`3jl>H00`16
P[@0n_3V04J2]00W0?[`iPD0AX:d203jl>H204J2]0/0n_3V00<000000?[`iP3jl>H0BP3jl>H204J2
]0040?[`iP16P[@0AX:d04J2]1<0n_3V00@0AX:d0?[`iP3jl>H0n_3V0`16P[@30?[`iPH0AX:d3@3j
l>H00`16P[@0n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V02X0n_3V00<000000?[`iP3jl>H01`3j
l>H10?ooo`003`3jl>H00`000000n_3V0?[`iP0[0?[`iP<00000803jl>H304J2]0040?[`iP16P[@0
n_3V04J2]2/0n_3V1P16P[@20?[`iP@0AX:d2@3jl>H00`000000n_3V0?[`iP1;0?[`iP80AX:d5P3j
l>H504J2]0/0n_3V1@16P[@80?[`iP80AX:d;@3jl>H00`000000n_3V0?[`iP0Y0?[`iP030000003j
l>H0n_3V00L0n_3V0@3oool000l0n_3V00<000000?[`iP3jl>H0:03jl>H3000002D0n_3V0`16P[@2
0?[`iP0304J2]03jl>H0n_3V02`0n_3V2@16P[@80?[`iP030000003jl>H0n_3V06<0n_3V0P16P[@C
0?[`iPD0AX:d0`3jl>H404J2]2/0n_3V00<000000?[`iP3jl>H0:@3jl>H00`000000n_3V0?[`iP07
0?[`iP40oooo000?0?[`iP030000003jl>H0n_3V02D0n_3V0`00000W0?[`iP0304J2]03jl>H0AX:d
0080AX:d00<0n_3V04J2]016P[@0<03jl>H704J2]0L0n_3V00<000000?[`iP3jl>H0O@3jl>H804J2
]0H0n_3V0P16P[@S0?[`iP030000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H01`3jl>H10?oo
o`003`3jl>H00`000000n_3V0?[`iP0R0?[`iP<00000:P3jl>H404J2]0040?[`iP16P[@0AX:d04J2
]300n_3V1`16P[@60?[`iP050000003jl>H0n_3V0?[`iP16P[@0OP3jl>H204J2]080n_3V0`16P[@7
0?[`iP@0AX:d803jl>H00`000000n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V00L0n_3V0@3oool0
00l0n_3V00<000000?[`iP3jl>H07`3jl>H3000002d0n_3V0P16P[@20?[`iPD0AX:d;`3jl>H204J2
]0D0n_3V1016P[@20?[`iP040000003jl>H0n_3V0?[`iP80AX:dO@3jl>H604J2]0`0n_3V1016P[@=
0?[`iP0304J2]03jl>H0n_3V00d0n_3V00<000000?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP06
0?[`iP40oooo000?0?[`iP<00000703jl>H300000340n_3V1016P[@n0?[`iP@0AX:d0P3jl>H304J2
]7`0n_3V1016P[@B0?[`iP<0AX:d2P3jl>H204J2]0h0n_3V00<000000?[`iP3jl>H09`3jl>H00`00
0000n_3V0?[`iP060?[`iP40oooo000>0?[`iP8000006`3jl>H3000007P0n_3V00<0000004J2]016
P[@00P16P[@20?[`iP0304J2]03jl>H0n_3V07X0n_3V00<0AX:d0?[`iP3jl>H05@3jl>H404J2]0H0
n_3V00<0AX:d0?[`iP16P[@03P3jl>H00`000000n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V00H0
n_3V0@3oool000h0n_3V00<000000?[`iP3jl>H01`3jl>H204J2]0d0n_3V1000001k0?[`iP030000
003jl>H0n_3V00H0AX:dU`3jl>H304J2]0<0n_3V00@0AX:d0?[`iP16P[@0AX:d3P3jl>H00`000000
n_3V0?[`iP0U0?[`iP030000003jl>H0n_3V00H0n_3V0@3oool000D0n_3V100000050?[`iP030000
003jl>H0n_3V00T0n_3V0P16P[@80?[`iP<00000O`3jl>H00`000000n_3V0?[`iP0804J2]1/0n_3V
1016P[@@0?[`iP0304J2]03jl>H0n_3V06H0n_3V1@16P[@20?[`iP0304J2]03jl>H0n_3V00`0n_3V
00<000000?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP060?[`iP40oooo00050?[`iP030000003j
l>H0n_3V00H0n_3V00<000000?[`iP3jl>H02`3jl>H204J2]0<0n_3V0`0000220?[`iP030000003j
l>H0n_3V00@0AX:d103jl>H304J2]0X0n_3V00<0AX:d0?[`iP3jl>H03`3jl>H604J2]0X0n_3V0P16
P[AY0?[`iP0304J2]03jl>H0AX:d00@0AX:d3P3jl>H00`000000n_3V0?[`iP0S0?[`iP030000003j
l>H0n_3V00H0n_3V0@3oool000H0n_3V00<000000?[`iP3jl>H01@3jl>H00`000000n_3V0?[`iP0=
0?[`iP<00000Q@3jl>H00`000000n_3V0?[`iP0;0?[`iP80AX:d1`3jl>H304J2]1H0n_3V1P16P[@4
0?[`iP@0AX:dI`3jl>H01016P[@0n_3V04J2]03jl>H404J2]0d0n_3V00<000000?[`iP3jl>H04P3j
l>H00`16P[@0n_3V0?[`iP0>0?[`iP030000003jl>H0n_3V00H0n_3V0@3oool000L0n_3V00<00000
0?[`iP3jl>H0103jl>H00`000000n_3V0?[`iP0:0?[`iP<000000P3jl>H204J2]8@0n_3V00<00000
0?[`iP3jl>H03@3jl>H304J2]0@0n_3V00@0AX:d0?[`iP16P[@0AX:d6`3jl>H604J2]0030?[`iP16
P[@0AX:d06H0n_3V1P16P[@=0?[`iP<0AX:d00<0000004J2]03jl>H04@3jl>H204J2]100n_3V00<0
00000?[`iP3jl>H01@3jl>H10?ooo`001@3jl>H010000000n_3V0?[`iP0000050?[`iP030000003j
l>H0n_3V00L0n_3V0`0000070?[`iP80AX:dPP3jl>H00`000000n_3V0?[`iP0@0?[`iP@0AX:d0P3j
l>H204J2]1h0n_3V00<0AX:d0?[`iP3jl>H01016P[AV0?[`iP80AX:d503jl>H00`000000AX:d04J2
]00704J2]0T0n_3V1016P[@>0?[`iP030000003jl>H0n_3V00D0n_3V0@3oool000H0n_3V0P000005
0?[`iP030000003jl>H0n_3V00D0n_3V0`00000<0?[`iP80AX:dP03jl>H00`000000n_3V0?[`iP0C
0?[`iP<0AX:d0P3jl>H00`16P[@0n_3V0?[`iP0K0?[`iPD0AX:dO`3jl>H00`000000n_3V0?[`iP06
0?[`iP/0AX:d00<0n_3V04J2]016P[@03@3jl>H00`000000n_3V0?[`iP050?[`iP40oooo000=0?[`
iP030000003jl>H0n_3V0080n_3V0`00000A0?[`iP<0AX:d1`3jl>H00`16P[@0n_3V0?[`iP1c0?[`
iP030000003jl>H0n_3V0180n_3V00<0AX:d0?[`iP3jl>H01@16P[@L0?[`iP80AX:d0`3jl>H604J2
]0d0n_3V00<0AX:d0?[`iP3jl>H0J@3jl>H00`000000n_3V0?[`iP0>0?[`iPL0AX:d303jl>H00`00
0000n_3V0?[`iP050?[`iP40oooo000=0?[`iP030000003jl>H00000008000005`3jl>H204J2]0@0
n_3V0`16P[@c0?[`iP80AX:d?`3jl>H00`000000n_3V0?[`iP0B0?[`iPT0AX:d9P3jl>H504J2]0P0
n_3V0P16P[A[0?[`iP030000003jl>H0n_3V00d0n_3V1P16P[@=0?[`iP030000003jl>H0n_3V00D0
n_3V0@3oool000d0n_3V0P00000L0?[`iP80AX:d0P3jl>H00`16P[@0n_3V04J2]00e0?[`iP@0AX:d
>`3jl>H00`000000n_3V0?[`iP0C0?[`iPD0AX:d;P3jl>H504J2]0<0n_3V1016P[AZ0?[`iP030000
003jl>H0n_3V00`0n_3V1016P[@?0?[`iP030000003jl>H0n_3V00D0n_3V0@3oool000h0n_3V00@0
00000?[`iP3jl>H000006`3jl>H204J2]0040?[`iP16P[@0n_3V04J2]3P0n_3V1016P[@<0?[`iP03
04J2]03jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H0B`3jl>H804J2]6X0n_3V00<000000?[`iP3j
l>H0303jl>H00`16P[@0n_3V0?[`iP0?0?[`iP030000003jl>H0n_3V00D0n_3V0@3oool000l0n_3V
0`00000L0?[`iP<0AX:d00<0n_3V04J2]016P[@0>`3jl>H304J2]0T0n_3V0P16P[@Y0?[`iP030000
003jl>H0n_3V04d0n_3V0P16P[@20?[`iP<0AX:dJ@3jl>H00`000000n_3V0?[`iP0O0?[`iP030000
003jl>H0n_3V00@0n_3V0@3oool00140n_3V00<000000?[`iP3jl>H06@3jl>H01016P[@0n_3V04J2
]03jl>H304J2]3h0n_3V1016P[@40?[`iP80AX:d00<0n_3V04J2]03jl>H09`3jl>H00`000000n_3V
0?[`iP1=0?[`iPP0AX:dJ@3jl>H00`000000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V00@0n_3V
0@3oool00140n_3V0P00000J0?[`iPP0AX:d@@3jl>H804J2]2P0n_3V00<000000?[`iP3jl>H0CP3j
l>H204J2]0D0n_3V1016P[AV0?[`iP030000003jl>H0n_3V01d0n_3V00<000000?[`iP3jl>H0103j
l>H10?ooo`004`3jl>H2000001T0n_3V1016P[@o0?[`iP80AX:d1`3jl>H504J2]240n_3V1016P[@2
0?[`iP030000003jl>H0n_3V00/0n_3V00<0AX:d0?[`iP3jl>H0B`3jl>H404J2]0d0n_3V00<0AX:d
0?[`iP3jl>H0D`3jl>H00`000000n_3V0?[`iP0L0?[`iP030000003jl>H0n_3V00@0n_3V0@3oool0
01D0n_3V00<000000?[`iP3jl>H0F`3jl>H304J2]0<0n_3V0P16P[@20?[`iP<0AX:d903jl>H604J2
]0X0n_3V0P16P[A@0?[`iP@0AX:d2@3jl>H204J2]5@0n_3V00<000000?[`iP3jl>H0703jl>H00`00
0000n_3V0?[`iP040?[`iP40oooo000F0?[`iP030000003jl>H0n_3V05d0n_3V0P16P[@00`3jl>H0
AX:d04J2]00304J2]2P0n_3V00@000000?[`iP3jl>H0n_3V1P16P[@40?[`iP@0AX:dDP3jl>H504J2
]0<0n_3V00@0AX:d0?[`iP16P[@0AX:dE03jl>H00`000000n_3V0?[`iP0K0?[`iP030000003jl>H0
n_3V00@0n_3V0@3oool001L0n_3V0`00001N0?[`iP<0AX:d:`3jl>H00`000000n_3V0?[`iP070?[`
iPH0AX:d00<0n_3V04J2]016P[@0EP3jl>H404J2]0030?[`iP16P[@0n_3V0080AX:d:@3jl>H00`16
P[@0n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V01X0n_3V00<000000?[`iP3jl>H0103jl>H10?oo
o`006@3jl>H00`000000n_3V0?[`iP1O0?[`iP<0AX:d2P3jl>H00`16P[@0n_3V0?[`iP0K0?[`iP03
0000003jl>H0n_3V00X0n_3V0P16P[@00`3jl>H0AX:d04J2]00204J2]5P0n_3V1@16P[@00`3jl>H0
AX:d0?[`iP0A0?[`iPD0AX:d4@3jl>H204J2]2T0n_3V00<000000?[`iP3jl>H06P3jl>H00`000000
n_3V0?[`iP030?[`iP40oooo000I0?[`iP800000H`3jl>H304J2]0L0n_3V0P16P[@L0?[`iP030000
003jl>H0n_3V00X0n_3V1@16P[AI0?[`iP0304J2]03jl>H0AX:d0080n_3V1016P[@F0?[`iPT0AX:d
203jl>H404J2]2P0n_3V00<000000?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP030?[`iP40oooo
000K0?[`iP800000I03jl>H304J2]0<0n_3V00@0AX:d0?[`iP16P[@0AX:d6`3jl>H00`000000n_3V
0?[`iP080?[`iP@0AX:dG03jl>H704J2]240n_3V3@16P[@W0?[`iP030000003jl>H0n_3V01T0n_3V
00<000000?[`iP3jl>H00`3jl>H10?ooo`007@3jl>H00`000000n_3V0?[`iP1T0?[`iP80AX:d00<0
n_3V04J2]03jl>H00P16P[@K0?[`iP030000003jl>H0n_3V00/0n_3V1P16P[@=0?[`iP0304J2]03j
l>H0n_3V04P0n_3V0`16P[@[0?[`iP0304J2]03jl>H0AX:d00@0AX:d9`3jl>H00`000000n_3V0?[`
iP0H0?[`iP030000003jl>H0n_3V00<0n_3V0@3oool000l0n_3V0P00000=0?[`iP030000003jl>H0
n_3V06D0n_3V0`16P[@20?[`iP0304J2]03jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H04@3jl>H5
04J2]0P0n_3V0P16P[Ag0?[`iPH0AX:d:@3jl>H00`000000n_3V0?[`iP0G0?[`iP030000003jl>H0
n_3V00<0n_3V0@3oool000h0n_3V00@000000?[`iP3jl>H000003@3jl>H3000006@0n_3V00<0AX:d
0?[`iP16P[@01016P[@I0?[`iP030000003jl>H0n_3V01H0n_3V1@16P[@30?[`iP@0AX:dM@3jl>H4
04J2]2`0n_3V00<000000?[`iP3jl>H05P3jl>H00`000000n_3V0?[`iP030?[`iP40oooo000>0?[`
iP040000003jl>H0n_3V000000l0n_3V00<000000?[`iP3jl>H0HP3jl>H804J2]1L0n_3V00<00000
0?[`iP3jl>H0703jl>H804J2]7D0n_3V00<0AX:d0?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0F
0?[`iP030000003jl>H0n_3V00<0n_3V0@3oool000h0n_3V00@000000?[`iP3jl>H000003`3jl>H2
000006@0n_3V1016P[@J0?[`iP030000003jl>H0n_3V01h0n_3V00@0AX:d0?[`iP3jl>H0n_3V0`16
P[B00?[`iP<0AX:d5@3jl>H00`16P[@0n_3V0?[`iP090?[`iP030000003jl>H0n_3V01H0n_3V00<0
00000?[`iP3jl>H00P3jl>H10?ooo`003P3jl>H010000000n_3V0?[`iP00000A0?[`iP800000P03j
l>H00`000000n_3V0?[`iP0N0?[`iPD0AX:dQ@3jl>H604J2]0l0n_3V0P16P[@;0?[`iP030000003j
l>H0n_3V01D0n_3V00<000000?[`iP3jl>H00P3jl>H10?ooo`003`3jl>H2000001@0n_3V00<00000
0?[`iP3jl>H0O@3jl>H00`000000n_3V0?[`iP0M0?[`iP<0AX:dSP3jl>H604J2]0P0n_3V00@0AX:d
0?[`iP16P[@0AX:d2`3jl>H00`000000n_3V0?[`iP0D0?[`iP030000003jl>H0n_3V0080n_3V0@3o
ool002H0n_3V00<000000?[`iP3jl>H0O03jl>H00`000000n_3V0?[`iP0P0?[`iP@0AX:dT03jl>H6
04J2]080n_3V00<0AX:d0?[`iP16P[@00`16P[@90?[`iP030000003jl>H0n_3V01@0n_3V00<00000
0?[`iP3jl>H00P3jl>H10?ooo`009`3jl>H3000007/0n_3V00<000000?[`iP3jl>H0903jl>H404J2
]0d0n_3V00<0AX:d0?[`iP3jl>H0PP3jl>H604J2]0030?[`iP16P[@0AX:d00T0n_3V00<000000?[`
iP3jl>H04`3jl>H00`000000n_3V0?[`iP020?[`iP40oooo000X0?[`iP800000503jl>H204J2]6D0
n_3V00<000000?[`iP3jl>H0:03jl>H404J2]0T0n_3V0P16P[B40?[`iP0304J2]03jl>H0AX:d0080
n_3V1016P[@90?[`iP030000003jl>H0n_3V0180n_3V00<000000?[`iP3jl>H00P3jl>H10?ooo`00
:P3jl>H00`000000n_3V0?[`iP0C0?[`iP<0AX:dHP3jl>H00`000000n_3V0?[`iP0/0?[`iP@0AX:d
103jl>H204J2]0030?[`iP16P[@0n_3V02l0n_3V00<0AX:d0?[`iP3jl>H0D03jl>H504J2]0030?[`
iP16P[@0AX:d00/0n_3V00<000000?[`iP3jl>H04@3jl>H00`000000n_3V0?[`iP020?[`iP40oooo
000[0?[`iP030000003jl>H0n_3V01D0n_3V0`16P[AO0?[`iP030000003jl>H0n_3V0300n_3V2@16
P[@I0?[`iPD0AX:d4@3jl>H204J2]580n_3V0P16P[@00`3jl>H0AX:d04J2]00>0?[`iP030000003j
l>H0n_3V0100n_3V00<000000?[`iP3jl>H00P3jl>H10?ooo`00;03jl>H2000001P0n_3V0`16P[AL
0?[`iP030000003jl>H0n_3V03@0n_3V1P16P[@M0?[`iPT0AX:d203jl>H404J2]540n_3V0P16P[@@
0?[`iP030000003jl>H0n_3V0140n_3V00@000000?[`iP3jl>H0n_3V0@3oool002h0n_3V00<00000
0?[`iP3jl>H0603jl>H304J2]0X0n_3V00<0AX:d0?[`iP3jl>H0:P3jl>H304J2]180n_3V00<0AX:d
0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP0c0?[`iP80AX:d0P3jl>H404J2]2D0n_3V2@16P[@2
0?[`iP80AX:dH`3jl>H00`000000n_3V0?[`iP0@0?[`iP040000003jl>H0n_3V0?[`iP40oooo000_
0?[`iP8000006`3jl>H404J2]0D0n_3V0`16P[@^0?[`iPD0AX:d3@3jl>H204J2]0/0n_3V00<00000
0?[`iP3jl>H0<`3jl>H404J2]0030?[`iP16P[@0AX:d02d0n_3V00<0AX:d0?[`iP16P[@01016P[AS
0?[`iP030000003jl>H0n_3V00l0n_3V00@000000?[`iP3jl>H0n_3V0@3oool00300n_3V0P00000N
0?[`iP<0AX:d0P3jl>H404J2]380n_3V1@16P[@80?[`iP0304J2]03jl>H0AX:d00X0n_3V00<00000
0?[`iP3jl>H0<`3jl>H204J2]0030?[`iP16P[@0AX:d02l0n_3V1P16P[AU0?[`iP030000003jl>H0
n_3V00h0n_3V00@000000?[`iP3jl>H0n_3V0@3oool00380n_3V00<000000?[`iP3jl>H07P3jl>H3
04J2]080n_3V00<0AX:d0?[`iP3jl>H0=@3jl>H604J2]0030?[`iP16P[@0AX:d00<0AX:d2@3jl>H0
0`000000n_3V0?[`iP0d0?[`iP80AX:d<@3jl>H01016P[@0n_3V04J2]016P[AW0?[`iP030000003j
l>H0n_3V00h0n_3V00@000000?[`iP3jl>H0n_3V0@3oool003<0n_3V00<000000?[`iP3jl>H07P3j
l>H604J2]3`0n_3V1`16P[@80?[`iP030000003jl>H0n_3V06L0n_3V0P16P[AZ0?[`iP030000003j
l>H0n_3V00d0n_3V00@000000?[`iP3jl>H0n_3V0@3oool003@0n_3V0P0000020?[`iP030000003j
l>H0n_3V01P0n_3V2016P[@l0?[`iP0404J2]03jl>H0n_3V0?[`iP<0AX:d1`3jl>H00`000000n_3V
0?[`iP3D0?[`iP030000003jl>H0n_3V00`0n_3V00@000000?[`iP3jl>H0n_3V0@3oool003H0n_3V
00<000000?[`iP0000006P3jl>H204J2]0040?[`iP16P[@0AX:d04J2]3h0n_3V1@16P[@90?[`iP03
0000003jl>H0n_3V06h0n_3V0`16P[@D0?[`iP0304J2]03jl>H0n_3V04d0n_3V00<000000?[`iP3j
l>H0303jl>H00`000000n_3V0?[`iP010?ooo`00=`3jl>H00`000000n_3V0?[`iP0J0?[`iP80AX:d
@@3jl>H204J2]0`0n_3V00<000000?[`iP3jl>H0L@3jl>H604J2]0h0n_3V0P16P[A>0?[`iP030000
003jl>H0n_3V00`0n_3V00<000000?[`iP3jl>H00@3oool003L0n_3V0`00001G0?[`iP<0AX:d4@3j
l>H00`000000n_3V0?[`iP1g0?[`iPH0AX:d203jl>H304J2]4h0n_3V00<000000?[`iP3jl>H02`3j
l>H00`000000n_3V0?[`iP010?ooo`00>P3jl>H00`000000n_3V0?[`iP1G0?[`iP@0AX:d3@3jl>H0
0`000000n_3V0?[`iP1m0?[`iPH0AX:d00<0n_3V04J2]03jl>H01016P[A=0?[`iP030000003jl>H0
n_3V00X0n_3V00<000000?[`iP3jl>H00@3oool003/0n_3V00<000000?[`iP3jl>H0FP3jl>H404J2
]0T0n_3V00D000000?[`iP3jl>H0n_3V04J2]00f0?[`iP0304J2]03jl>H0n_3V04P0n_3V2016P[A=
0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H00@3oool003`0n_3V0P00001N0?[`
iP@0AX:d1@3jl>H010000000n_3V0?[`iP3jl>H204J2]200n_3V1@16P[@@0?[`iP80AX:dBP3jl>H2
04J2]080n_3V1016P[A<0?[`iP030000003jl>H0n_3V00T0n_3V00<000000?[`iP3jl>H00@3oool0
03h0n_3V0P00001P0?[`iP@0AX:d00@0n_3V0000003jl>H0n_3V0P16P[@00`3jl>H0AX:d0?[`iP0S
0?[`iPP0AX:d203jl>H404J2]4P0n_3V1016P[@00`3jl>H0AX:d04J2]01>0?[`iP030000003jl>H0
n_3V00P0n_3V00<000000?[`iP3jl>H00@3oool003l0n_3V00<000000?[`iP3jl>H0HP3jl>H904J2
]2/0n_3V2@16P[@0103jl>H0AX:d04J2]016P[A70?[`iP80AX:d00<0n_3V04J2]016P[@0D@3jl>H0
0`000000n_3V0?[`iP080?[`iP4000000@3jl>H10?ooo`00@03jl>H2000006<0n_3V00<000000?[`
iP3jl>H01P16P[@b0?[`iPH0AX:dA`3jl>H204J2]5@0n_3V00<000000?[`iP3jl>H01`3jl>H10000
0040n_3V0@3oool00480n_3V00<000000?[`iP3jl>H0H03jl>H010000000n_3V04J2]016P[@20?[`
iP@0AX:d<@3jl>H504J2]9l0n_3V00<000000?[`iP3jl>H01P3jl>H100000040n_3V0@3oool004<0
n_3V00<000000?[`iP3jl>H0G`3jl>H00`000000n_3V04J2]00504J2]3<0n_3V0`16P[BQ0?[`iP03
0000003jl>H0n_3V00H0n_3V0@0000010?[`iP40oooo000_0?[`iP800000103jl>H2000000@0n_3V
0P0000070?[`iP<00000GP3jl>H00`000000n_3V0?[`iP0204J2]3H0n_3V00<0AX:d0?[`iP3jl>H0
U`3jl>H00`16P[@0n_3V0?[`iP080?[`iP030000003jl>H0n_3V00D0n_3V0@0000010?[`iP40oooo
000^0?[`iP040000003jl>H0n_3V000000P0n_3V00@000000?[`iP3jl>H00000203jl>H00`000000
n_3V0?[`iP1K0?[`iP030000003jl>H0n_3V0;d0n_3V1@16P[@A0?[`iP<0AX:d2@3jl>H00`000000
n_3V0?[`iP040?[`iP4000000@3jl>H10?ooo`00;P3jl>H010000000n_3V0?[`iP00000;0?[`iP03
0000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0FP3jl>H00`000000n_3V0?[`iP320?[`iPT0
AX:d203jl>H01016P[@0n_3V04J2]016P[@90?[`iP030000003jl>H0n_3V00<0n_3V0@0000010?[`
iP40oooo000^0?[`iP040000003jl>H0n_3V000000T0n_3V0P00000;0?[`iP030000003jl>H0n_3V
05T0n_3V00<000000?[`iP3jl>H0>P3jl>H304J2]8h0n_3V3P16P[@70?[`iP030000003jl>H0n_3V
00@0n_3V0@0000010?ooo`00;P3jl>H010000000n_3V0?[`iP0000090?[`iP030000003jl>H0n_3V
00/0n_3V0P00001I0?[`iP030000003jl>H0n_3V03d0n_3V1P16P[@>0?[`iP0304J2]03jl>H0n_3V
07l0n_3V00<0AX:d0?[`iP16P[@01016P[@70?[`iP030000003jl>H0n_3V00<0n_3V0@0000010?oo
o`00;`3jl>H2000000X0n_3V0`00000=0?[`iP030000003jl>H0000005H0n_3V00<000000?[`iP3j
l>H0@`3jl>H604J2]0P0n_3V0`16P[Ao0?[`iPH0AX:d2@3jl>H00`000000n_3V0?[`iP020?[`iP40
00000@3oool004`0n_3V0P00000B0?[`iP<0AX:d>`3jl>H404J2]080n_3V00<000000?[`iP3jl>H0
303jl>H00`16P[@0n_3V0?[`iP0j0?[`iPH0AX:d0P3jl>H404J2]7h0n_3V1016P[@<0?[`iP050000
003jl>H0n_3V0?[`iP0000000@3oool004d0n_3V0P00000D0?[`iP@0AX:d403jl>H00`16P[@0n_3V
0?[`iP0X0?[`iPH0AX:d2`3jl>H204J2]440n_3V2016P[Am0?[`iP0304J2]03jl>H0n_3V00`0n_3V
00D000000?[`iP3jl>H0n_3V000000010?ooo`00C`3jl>H00`000000n_3V0?[`iP0E0?[`iPD0AX:d
2`3jl>H204J2]2/0n_3V00@000000?[`iP3jl>H0n_3V1`16P[@40?[`iP@0AX:d@03jl>H204J2]080
n_3V1016P[B<0?[`iP040000003jl>H0n_3V00000040oooo001@0?[`iP030000003jl>H0n_3V01T0
n_3V1@16P[@60?[`iP<0AX:d:P3jl>H00`000000n_3V0?[`iP080?[`iPH0AX:d00<0n_3V04J2]016
P[@0?`3jl>H404J2]0030?[`iP16P[@0AX:d08h0n_3V00<000000?[`iP0000000@3oool00540n_3V
0P0000000`3jl>H000000?[`iP0K0?[`iP@0AX:d00<0n_3V04J2]03jl>H00`16P[@Y0?[`iP030000
003jl>H0n_3V00/0n_3V0P16P[@00`3jl>H0AX:d04J2]00204J2]3h0n_3V0P16P[@00`3jl>H0AX:d
04J2]02A0?[`iP4000000@3jl>H100000000D`3jl>H00`000000n_3V0?[`iP0O0?[`iPL0AX:d:03j
l>H00`000000n_3V0?[`iP0;0?[`iPD0AX:d@@3jl>H204J2]9<0n_3V0@0000010?[`iP400000001C
0?[`iP8000008@3jl>H204J2]080n_3V0`16P[@W0?[`iP030000003jl>H0n_3V00/0n_3V0P16P[CJ
0?[`iP800000001E0?[`iP8000007`3jl>H504J2]2T0n_3V00<000000?[`iP3jl>H0iP3jl>H30000
0000E`3jl>H010000000n_3V0?[`iP00000K0?[`iP80AX:d;03jl>H00`000000n_3V0?[`iP2N0?[`
iP0304J2]03jl>H0n_3V0440n_3V100000020?[`iP40oooo001H0?[`iP030000003jl>H0000004T0
n_3V00<000000?[`iP3jl>H0Q`3jl>H504J2]180n_3V0P16P[@n0?[`iP@000001P3jl>H10?ooo`00
F@3jl>H2000004T0n_3V00<000000?[`iP3jl>H0S03jl>H904J2]0T0n_3V1016P[@h0?[`iP@00000
2P3jl>H10?ooo`00FP3jl>H2000004P0n_3V00<000000?[`iP3jl>H0203jl>H404J2]1<0n_3V00<0
AX:d0?[`iP3jl>H0L`3jl>H:04J2]080n_3V0P16P[@c0?[`iP@000003P3jl>H10?ooo`00G03jl>H0
0`000000n_3V0?[`iP150?[`iP030000003jl>H0n_3V00`0n_3V1`16P[@<0?[`iP80AX:dO03jl>H7
04J2]2h0n_3V1000000B0?[`iP40oooo001M0?[`iP800000A@3jl>H00`000000n_3V0?[`iP0C0?[`
iPL0AX:d1@3jl>H404J2]7X0n_3V1P16P[@[0?[`iP@000005P3jl>H10?ooo`00G`3jl>H00`000000
n_3V000000120?[`iP030000003jl>H0n_3V01X0n_3V2P16P[Ai0?[`iP@0AX:d:@3jl>H4000001X0
n_3V0@3oool00600n_3V0P0000120?[`iP030000003jl>H0n_3V01h0n_3V0P16P[@00`3jl>H0AX:d
04J2]00204J2]7T0n_3V00<0AX:d0?[`iP3jl>H09@3jl>H4000001h0n_3V0@3oool00640n_3V0P00
00110?[`iP030000003jl>H0n_3V01h0n_3V00<0AX:d0?[`iP16P[@00`16P[BN0?[`iP@000008P3j
l>H10?ooo`00H`3jl>H00`000000n_3V0?[`iP0n0?[`iP030000003jl>H0n_3V01h0n_3V1016P[BL
0?[`iP@000009P3jl>H10?ooo`00I03jl>H00`000000n_3V0?[`iP0m0?[`iP030000003jl>H0n_3V
01h0n_3V0P16P[BJ0?[`iP@00000:P3jl>H10?ooo`00I@3jl>H3000003`0n_3V00<000000?[`iP3j
l>H0]@3jl>H5000002h0n_3V0@3oool005L0n_3V1@00000;0?[`iP030000003jl>H0n_3V03X0n_3V
00<000000?[`iP3jl>H0/@3jl>H4000003<0n_3V0@3oool005T0n_3V00<000000?[`iP3jl>H02`3j
l>H2000003/0n_3V00<000000?[`iP3jl>H0J`3jl>H00`16P[@0n_3V0?[`iP0o0?[`iP@00000=`3j
l>H10?ooo`00F@3jl>H00`000000n_3V0?[`iP0=0?[`iP030000003jl>H0n_3V03P0n_3V00<00000
0?[`iP3jl>H0E03jl>H504J2]180n_3V0P16P[@l0?[`iP@00000>`3jl>H10?ooo`00F@3jl>H00`00
0000n_3V0?[`iP0>0?[`iP800000=`3jl>H00`000000n_3V0?[`iP1J0?[`iPT0AX:d2@3jl>H404J2
]3H0n_3V1000000o0?[`iP40oooo001I0?[`iP030000003jl>H0n_3V0100n_3V00<000000?[`iP00
00004@3jl>H404J2]180n_3V00<0AX:d0?[`iP3jl>H02P3jl>H00`000000n_3V0?[`iP1S0?[`iPX0
AX:d00@0n_3V04J2]016P[@0AX:d<@3jl>H4000004<0n_3V0@3oool005P0n_3V0P00000C0?[`iP03
0000003jl>H0n_3V01@0n_3V1`16P[@;0?[`iP80AX:d2`3jl>H00`000000n_3V0?[`iP1[0?[`iPL0
AX:d;03jl>H4000004L0n_3V0@3oool006d0n_3V0`00000K0?[`iPH0AX:d1@3jl>H404J2]0T0n_3V
00<000000?[`iP3jl>H0J`3jl>H604J2]2T0n_3V1000001;0?[`iP40oooo001`0?[`iP030000003j
l>H0n_3V01h0n_3V2P16P[@80?[`iP030000003jl>H0n_3V06/0n_3V00@0AX:d0?[`iP16P[@0AX:d
9`3jl>H4000004l0n_3V0@3oool00740n_3V00<000000?[`iP3jl>H08@3jl>H204J2]0030?[`iP16
P[@0AX:d0080AX:d1`3jl>H00`000000n_3V0?[`iP1[0?[`iP80AX:d9@3jl>H4000005<0n_3V0@3o
ool00780n_3V0`00000P0?[`iPH0AX:d203jl>H00`000000n_3V0?[`iP2>0?[`iP@00000E`3jl>H1
0?ooo`00M03jl>H00`000000n_3V0?[`iP0N0?[`iP0404J2]03jl>H0AX:d04J2]0X0n_3V00<00000
0?[`iP3jl>H0R@3jl>H5000005/0n_3V0@3oool007D0n_3V00<000000?[`iP3jl>H07@3jl>H204J2
]0`0n_3V00<000000?[`iP3jl>H0Q@3jl>H400000600n_3V0@3oool007H0n_3V0P00000[0?[`iP03
0000003jl>H0n_3V0840n_3V1000001T0?[`iP40oooo001h0?[`iP030000003jl>H0000002P0n_3V
00<000000?[`iP3jl>H0>`3jl>H00`16P[@0n_3V0?[`iP0o0?[`iP@00000J03jl>H10?ooo`00N@3j
l>H2000002P0n_3V00<000000?[`iP3jl>H0>`3jl>H204J2]3`0n_3V1000001/0?[`iP40oooo001j
0?[`iP8000009`3jl>H00`000000n_3V0?[`iP0U0?[`iPL0AX:d3`3jl>H404J2]3H0n_3V1000001`
0?[`iP40oooo001l0?[`iP030000003jl>H0n_3V02@0n_3V00<000000?[`iP3jl>H0;03jl>H@04J2
]0040?[`iP16P[@0AX:d04J2]340n_3V1000001d0?[`iP40oooo001m0?[`iP030000003jl>H0n_3V
02<0n_3V00<000000?[`iP3jl>H0>P3jl>H704J2]2`0n_3V1000001h0?[`iP40oooo001n0?[`iP<0
00008P3jl>H00`000000n_3V0?[`iP0j0?[`iP0304J2]03jl>H0AX:d00<0AX:d:@3jl>H4000007`0
n_3V0@3oool00800n_3V00<000000?[`iP3jl>H0803jl>H00`000000n_3V0?[`iP0j0?[`iP@0AX:d
9`3jl>H400000800n_3V0@3oool00800n_3V0P00000Q0?[`iP030000003jl>H0n_3V03X0n_3V0P16
P[@U0?[`iP@00000Q03jl>H10?ooo`00PP3jl>H2000001l0n_3V00<000000?[`iP3jl>H0G@3jl>H4
000008P0n_3V0@3oool008@0n_3V00<000000?[`iP3jl>H0703jl>H00`000000n_3V0?[`iP1H0?[`
iPD00000S03jl>H10?ooo`00Q@3jl>H2000001`0n_3V00<000000?[`iP3jl>H0E03jl>H400000940
n_3V0@3oool00740n_3V1@0000020?[`iP800000103jl>H2000000H0n_3V00<000000?[`iP3jl>H0
6P3jl>H00`000000n_3V0?[`iP1@0?[`iP@00000U@3jl>H10?ooo`00L`3jl>H00`000000n_3V0?[`
iP070?[`iP040000003jl>H0n_3V000000H0n_3V0P00000J0?[`iP030000003jl>H0n_3V00`0n_3V
00<0AX:d0?[`iP3jl>H0?@3jl>H4000009T0n_3V0@3oool007<0n_3V00<000000?[`iP3jl>H02P3j
l>H00`000000n_3V0?[`iP060?[`iP030000003jl>H0n_3V01L0n_3V00<000000?[`iP3jl>H0303j
l>H204J2]3X0n_3V1000002M0?[`iP40oooo001c0?[`iP030000003jl>H0n_3V00P0n_3V0P00000:
0?[`iP030000003jl>H000000100n_3V1`16P[@>0?[`iP@0AX:d=03jl>H400000:40n_3V0@3oool0
07<0n_3V00<000000?[`iP3jl>H0203jl>H00`000000n_3V0?[`iP0:0?[`iP8000005P3jl>H00`00
0000AX:d04J2]00=04J2]0040?[`iP16P[@0AX:d04J2]2l0n_3V1000002U0?[`iP40oooo001b0?[`
iP8000002P3jl>H3000000/0n_3V0P00000E0?[`iP030000003jl>H0n_3V00/0n_3V1`16P[@Z0?[`
iP@00000Z@3jl>H10?ooo`00SP3jl>H00`000000n_3V0?[`iP0B0?[`iP030000003jl>H0n_3V00/0
n_3V00<0AX:d0?[`iP16P[@00`16P[@W0?[`iP@00000[@3jl>H10?ooo`00S`3jl>H300000100n_3V
00<000000?[`iP3jl>H0303jl>H404J2]2D0n_3V1000002a0?[`iP40oooo002A0?[`iP030000003j
l>H0n_3V00h0n_3V00<000000?[`iP3jl>H0303jl>H204J2]2<0n_3V1000002e0?[`iP40oooo002A
0?[`iP8000003`3jl>H00`000000n_3V0?[`iP0/0?[`iPD00000^@3jl>H10?ooo`00T`3jl>H20000
00d0n_3V00<000000?[`iP3jl>H0:03jl>H400000;h0n_3V0@3oool009D0n_3V00<000000?[`iP00
00002P3jl>H00`000000n_3V0?[`iP0T0?[`iP@00000`P3jl>H10?ooo`00UP3jl>H2000000X0n_3V
00<000000?[`iP3jl>H0803jl>H400000<H0n_3V0@3oool009L0n_3V0P0000090?[`iP030000003j
l>H0n_3V01`0n_3V1000003:0?[`iP40oooo002I0?[`iP030000003jl>H0n_3V00H0n_3V00<00000
0?[`iP3jl>H0603jl>H400000<h0n_3V0@3oool009X0n_3V00<000000?[`iP3jl>H01@3jl>H00`00
0000n_3V0?[`iP0D0?[`iP@00000dP3jl>H10?ooo`00V`3jl>H3000000@0n_3V00<000000?[`iP3j
l>H0403jl>H400000=H0n_3V0@3oool009d0n_3V00<000000?[`iP3jl>H00P3jl>H00`000000n_3V
0?[`iP0<0?[`iP@00000fP3jl>H10?ooo`00WP3jl>H01@000000n_3V0?[`iP3jl>H0000000X0n_3V
1000003N0?[`iP40oooo002O0?[`iP80000000<0n_3V0000003jl>H01@3jl>H400000>80n_3V0@3o
ool00:40n_3V0P0000020?[`iP@00000iP3jl>H10?ooo`00XP3jl>H300000>X0n_3V0@3oool009D0
n_3V1000003f0?[`iP40oooo002E0?[`iP030000003jl>H0n_3V0?L0n_3V0@3oool009H0n_3V00<0
00000?[`iP3jl>H0mP3jl>H10?ooo`00U`3jl>H00`000000n_3V0?[`iP3e0?[`iP40oooo002E0?[`
iP040000003jl>H0n_3V00000?H0n_3V0@3oool009H0n_3V0P00003g0?[`iP40oooo003o0?[`iY00
n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {378.063, 0}} -> {-0.0329568, -0.00481779, \
0.00247937, 0.00247937}}]
}, Open  ]],

Cell["\<\
Unfortunately, RealTime3D throws away all style directives. This looks even \
nicer if you enlarge to a full screen. Also, notice that if you hold down \
Ctrl you can zoom in and out.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(<< RealTime3D`\), "\[IndentingNewLine]", 
    \(\(Show[plot1];\)\), "\[IndentingNewLine]", 
    \(<< Default3D`\)}], "Input",
  CellLabel->"In[288]:="],

Cell[BoxData[
  Graphics3D[{
    Line[{{0.000000, 0.000000, 0.500000},{0.102062, 0.204124, 0.602062}}],
    Line[{{0.113593, 0.147327, 0.581650},{0.102062, 0.204124, 0.602062},{
      0.049706, 0.179271, 0.581650}}],
    Line[{{0.088170, 0.176340, 0.549047},{0.102062, 0.204124, 0.602062},{
      0.075129, 0.150258, 0.614252}}],
    Line[{{0.113593, 0.147327, 0.581650},{0.088170, 0.176340, 0.549047},{
      0.049706, 0.179271, 0.581650},{0.075129, 0.150258, 0.614252},{
      0.113593, 0.147327, 0.581650}}],
    Line[{{0.000000, 0.000000, 1.000000},{0.109109, 0.218218, 1.054554}}],
    Line[{{0.119231, 0.158602, 1.043644},{0.109109, 0.218218, 1.054554},{
      0.055343, 0.190546, 1.043644}}],
    Line[{{0.090773, 0.181545, 1.008790},{0.109109, 0.218218, 1.054554},{
      0.083802, 0.167604, 1.078497}}],
    Line[{{0.119231, 0.158602, 1.043644},{0.090773, 0.181545, 1.008790},{
      0.055343, 0.190546, 1.043644},{0.083802, 0.167604, 1.078497},{
      0.119231, 0.158602, 1.043644}}],
    Line[{{0.000000, 0.000000, 1.500000},{0.110581, 0.221163, 1.536860}}],
    Line[{{0.120409, 0.160958, 1.529488},{0.110581, 0.221163, 1.536860},{
      0.056521, 0.192902, 1.529488}}],
    Line[{{0.090820, 0.181640, 1.494164},{0.110581, 0.221163, 1.536860},{
      0.086110, 0.172220, 1.564812}}],
    Line[{{0.120409, 0.160958, 1.529488},{0.090820, 0.181640, 1.494164},{
      0.056521, 0.192902, 1.529488},{0.086110, 0.172220, 1.564812},{
      0.120409, 0.160958, 1.529488}}],
    Line[{{0.000000, 0.000000, 2.000000},{0.111111, 0.222222, 2.027778}}],
    Line[{{0.120833, 0.161806, 2.022222},{0.111111, 0.222222, 2.027778},{
      0.056945, 0.193750, 2.022222}}],
    Line[{{0.090664, 0.181327, 1.986729},{0.111111, 0.222222, 2.027778},{
      0.087114, 0.174228, 2.057715}}],
    Line[{{0.120833, 0.161806, 2.022222},{0.090664, 0.181327, 1.986729},{
      0.056945, 0.193750, 2.022222},{0.087114, 0.174228, 2.057715},{
      0.120833, 0.161806, 2.022222}}],
    Line[{{0.000000, 0.500000, 0.500000},{0.139271, 0.685695, 0.592848}}],
    Line[{{0.139989, 0.627128, 0.574278},{0.139271, 0.685695, 0.592848},{
      0.082846, 0.669985, 0.574278}}],
    Line[{{0.119376, 0.659167, 0.541118},{0.139271, 0.685695, 0.592848},{
      0.103459, 0.637945, 0.607438}}],
    Line[{{0.139989, 0.627128, 0.574278},{0.119376, 0.659167, 0.541118},{
      0.082846, 0.669985, 0.574278},{0.103459, 0.637945, 0.607438},{
      0.139989, 0.627128, 0.574278}}],
    Line[{{0.000000, 0.500000, 1.000000},{0.147087, 0.696116, 1.049029}}],
    Line[{{0.146241, 0.635464, 1.039223},{0.147087, 0.696116, 1.049029},{
      0.089098, 0.678321, 1.039223}}],
    Line[{{0.121872, 0.662496, 1.004202},{0.147087, 0.696116, 1.049029},{
      0.113467, 0.651290, 1.074244}}],
    Line[{{0.146241, 0.635464, 1.039223},{0.121872, 0.662496, 1.004202},{
      0.089098, 0.678321, 1.039223},{0.113467, 0.651290, 1.074244},{
      0.146241, 0.635464, 1.039223}}],
    Line[{{0.000000, 0.500000, 1.500000},{0.148684, 0.698246, 1.533041}}],
    Line[{{0.147519, 0.637168, 1.526433},{0.148684, 0.698246, 1.533041},{
      0.090376, 0.680025, 1.526433}}],
    Line[{{0.121779, 0.662373, 1.491032},{0.148684, 0.698246, 1.533041},{
      0.116115, 0.654820, 1.561834}}],
    Line[{{0.147519, 0.637168, 1.526433},{0.121779, 0.662373, 1.491032},{
      0.090376, 0.680025, 1.526433},{0.116115, 0.654820, 1.561834},{
      0.147519, 0.637168, 1.526433}}],
    Line[{{0.000000, 0.500000, 2.000000},{0.149256, 0.699007, 2.024876}}],
    Line[{{0.147976, 0.637777, 2.019901},{0.149256, 0.699007, 2.024876},{
      0.090833, 0.680634, 2.019901}}],
    Line[{{0.121537, 0.662049, 1.984364},{0.149256, 0.699007, 2.024876},{
      0.117272, 0.656363, 2.055438}}],
    Line[{{0.147976, 0.637777, 2.019901},{0.121537, 0.662049, 1.984364},{
      0.090833, 0.680634, 2.019901},{0.117272, 0.656363, 2.055438},{
      0.147976, 0.637777, 2.019901}}],
    Line[{{0.000000, 1.000000, 0.500000},{0.166667, 1.166667, 0.583333}}],
    Line[{{0.158587, 1.108080, 0.566667},{0.166667, 1.166667, 0.583333},{
      0.108080, 1.158587, 0.566667}}],
    Line[{{0.141751, 1.141751, 0.532995},{0.166667, 1.166667, 0.583333},{
      0.124915, 1.124915, 0.600338}}],
    Line[{{0.158587, 1.108080, 0.566667},{0.141751, 1.141751, 0.532995},{
      0.108080, 1.158587, 0.566667},{0.124915, 1.124915, 0.600338},{
      0.158587, 1.108080, 0.566667}}],
    Line[{{0.000000, 1.000000, 1.000000},{0.174078, 1.174078, 1.043519}}],
    Line[{{0.164516, 1.114008, 1.034816},{0.174078, 1.174078, 1.043519},{
      0.114008, 1.164516, 1.034816}}],
    Line[{{0.143658, 1.143658, 0.999647},{0.174078, 1.174078, 1.043519},{
      0.134866, 1.134866, 1.069985}}],
    Line[{{0.164516, 1.114008, 1.034816},{0.143658, 1.143658, 0.999647},{
      0.114008, 1.164516, 1.034816},{0.134866, 1.134866, 1.069985},{
      0.164516, 1.114008, 1.034816}}],
    Line[{{0.000000, 1.000000, 1.500000},{0.175562, 1.175562, 1.529260}}],
    Line[{{0.165703, 1.115196, 1.523408},{0.175562, 1.175562, 1.529260},{
      0.115196, 1.165703, 1.523408}}],
    Line[{{0.143405, 1.143405, 1.487939},{0.175562, 1.175562, 1.529260},{
      0.137494, 1.137494, 1.558877}}],
    Line[{{0.165703, 1.115196, 1.523408},{0.143405, 1.143405, 1.487939},{
      0.115196, 1.165703, 1.523408},{0.137494, 1.137494, 1.558877},{
      0.165703, 1.115196, 1.523408}}],
    Line[{{0.000000, 1.000000, 2.000000},{0.176090, 1.176090, 2.022011}}],
    Line[{{0.166126, 1.115618, 2.017609},{0.176090, 1.176090, 2.022011},{
      0.115618, 1.166126, 2.017609}}],
    Line[{{0.143096, 1.143096, 1.982033},{0.176090, 1.176090, 2.022011},{
      0.138649, 1.138649, 2.053185}}],
    Line[{{0.166126, 1.115618, 2.017609},{0.143096, 1.143096, 1.982033},{
      0.115618, 1.166126, 2.017609},{0.138649, 1.138649, 2.053185},{
      0.166126, 1.115618, 2.017609}}],
    Line[{{0.000000, 1.500000, 0.500000},{0.186339, 1.649071, 0.574536}}],
    Line[{{0.171382, 1.591369, 0.559628},{0.186339, 1.649071, 0.574536},{
      0.126761, 1.647145, 0.559628}}],
    Line[{{0.157386, 1.625909, 0.525538},{0.186339, 1.649071, 0.574536},{
      0.140757, 1.612605, 0.593719}}],
    Line[{{0.171382, 1.591369, 0.559628},{0.157386, 1.625909, 0.525538},{
      0.126761, 1.647145, 0.559628},{0.140757, 1.612605, 0.593719},{
      0.171382, 1.591369, 0.559628}}],
    Line[{{0.000000, 1.500000, 1.000000},{0.192879, 1.654303, 1.038576}}],
    Line[{{0.176614, 1.595554, 1.030861},{0.192879, 1.654303, 1.038576},{
      0.131993, 1.651331, 1.030861}}],
    Line[{{0.158607, 1.626885, 0.995574},{0.192879, 1.654303, 1.038576},{
      0.150000, 1.620000, 1.066147}}],
    Line[{{0.176614, 1.595554, 1.030861},{0.158607, 1.626885, 0.995574},{
      0.131993, 1.651331, 1.030861},{0.150000, 1.620000, 1.066147},{
      0.176614, 1.595554, 1.030861}}],
    Line[{{0.000000, 1.500000, 1.500000},{0.194168, 1.655334, 1.525889}}],
    Line[{{0.177645, 1.596379, 1.520711},{0.194168, 1.655334, 1.525889},{
      0.133024, 1.652156, 1.520711}}],
    Line[{{0.158222, 1.626578, 1.485189},{0.194168, 1.655334, 1.525889},{
      0.152446, 1.621957, 1.556234}}],
    Line[{{0.177645, 1.596379, 1.520711},{0.158222, 1.626578, 1.485189},{
      0.133024, 1.652156, 1.520711},{0.152446, 1.621957, 1.556234},{
      0.177645, 1.596379, 1.520711}}],
    Line[{{0.000000, 1.500000, 2.000000},{0.194625, 1.655700, 2.019463}}],
    Line[{{0.178010, 1.596672, 2.015570},{0.194625, 1.655700, 2.019463},{
      0.133389, 1.652448, 2.015570}}],
    Line[{{0.157871, 1.626297, 1.979964},{0.194625, 1.655700, 2.019463},{
      0.153529, 1.622823, 2.051176}}],
    Line[{{0.178010, 1.596672, 2.015570},{0.157871, 1.626297, 1.979964},{
      0.133389, 1.652448, 2.015570},{0.153529, 1.622823, 2.051176},{
      0.178010, 1.596672, 2.015570}}],
    Line[{{0.000000, 2.000000, 0.500000},{0.200446, 2.133631, 0.566815}}],
    Line[{{0.180167, 2.077188, 0.553452},{0.200446, 2.133631, 0.566815},{
      0.140546, 2.136621, 0.553452}}],
    Line[{{0.168299, 2.112199, 0.519037},{0.200446, 2.133631, 0.566815},{
      0.152415, 2.101610, 0.587867}}],
    Line[{{0.180167, 2.077188, 0.553452},{0.168299, 2.112199, 0.519037},{
      0.140546, 2.136621, 0.553452},{0.152415, 2.101610, 0.587867},{
      0.180167, 2.077188, 0.553452}}],
    Line[{{0.000000, 2.000000, 1.000000},{0.206041, 2.137361, 1.034340}}],
    Line[{{0.184643, 2.080172, 1.027472},{0.206041, 2.137361, 1.034340},{
      0.145022, 2.139605, 1.027472}}],
    Line[{{0.168914, 2.112610, 0.992096},{0.206041, 2.137361, 1.034340},{
      0.160751, 2.107167, 1.062848}}],
    Line[{{0.184643, 2.080172, 1.027472},{0.168914, 2.112610, 0.992096},{
      0.145022, 2.139605, 1.027472},{0.160751, 2.107167, 1.062848},{
      0.184643, 2.080172, 1.027472}}],
    Line[{{0.000000, 2.000000, 1.500000},{0.207129, 2.138086, 1.523014}}],
    Line[{{0.185514, 2.080753, 1.518412},{0.207129, 2.138086, 1.523014},{
      0.145893, 2.140185, 1.518412}}],
    Line[{{0.168439, 2.112293, 1.482849},{0.207129, 2.138086, 1.523014},{
      0.162968, 2.108645, 1.553974}}],
    Line[{{0.185514, 2.080753, 1.518412},{0.168439, 2.112293, 1.482849},{
      0.145893, 2.140185, 1.518412},{0.162968, 2.108645, 1.553974},{
      0.185514, 2.080753, 1.518412}}],
    Line[{{0.000000, 2.000000, 2.000000},{0.207514, 2.138343, 2.017293}}],
    Line[{{0.185822, 2.080958, 2.013834},{0.207514, 2.138343, 2.017293},{
      0.146201, 2.140390, 2.013834}}],
    Line[{{0.168067, 2.112045, 1.978206},{0.207514, 2.138343, 2.017293},{
      0.163956, 2.109304, 2.049463}}],
    Line[{{0.185822, 2.080958, 2.013834},{0.168067, 2.112045, 1.978206},{
      0.146201, 2.140390, 2.013834},{0.163956, 2.109304, 2.049463},{
      0.185822, 2.080958, 2.013834}}],
    Line[{{0.500000, 0.000000, 0.500000},{0.602062, 0.204124, 0.602062}}],
    Line[{{0.613593, 0.147327, 0.581650},{0.602062, 0.204124, 0.602062},{
      0.549706, 0.179271, 0.581650}}],
    Line[{{0.588170, 0.176340, 0.549047},{0.602062, 0.204124, 0.602062},{
      0.575129, 0.150258, 0.614252}}],
    Line[{{0.613593, 0.147327, 0.581650},{0.588170, 0.176340, 0.549047},{
      0.549706, 0.179271, 0.581650},{0.575129, 0.150258, 0.614252},{
      0.613593, 0.147327, 0.581650}}],
    Line[{{0.500000, 0.000000, 1.000000},{0.609109, 0.218218, 1.054554}}],
    Line[{{0.619231, 0.158602, 1.043644},{0.609109, 0.218218, 1.054554},{
      0.555343, 0.190546, 1.043644}}],
    Line[{{0.590773, 0.181545, 1.008790},{0.609109, 0.218218, 1.054554},{
      0.583802, 0.167604, 1.078497}}],
    Line[{{0.619231, 0.158602, 1.043644},{0.590773, 0.181545, 1.008790},{
      0.555343, 0.190546, 1.043644},{0.583802, 0.167604, 1.078497},{
      0.619231, 0.158602, 1.043644}}],
    Line[{{0.500000, 0.000000, 1.500000},{0.610581, 0.221163, 1.536860}}],
    Line[{{0.620409, 0.160958, 1.529488},{0.610581, 0.221163, 1.536860},{
      0.556521, 0.192902, 1.529488}}],
    Line[{{0.590820, 0.181640, 1.494164},{0.610581, 0.221163, 1.536860},{
      0.586110, 0.172220, 1.564812}}],
    Line[{{0.620409, 0.160958, 1.529488},{0.590820, 0.181640, 1.494164},{
      0.556521, 0.192902, 1.529488},{0.586110, 0.172220, 1.564812},{
      0.620409, 0.160958, 1.529488}}],
    Line[{{0.500000, 0.000000, 2.000000},{0.611111, 0.222222, 2.027778}}],
    Line[{{0.620833, 0.161806, 2.022222},{0.611111, 0.222222, 2.027778},{
      0.556945, 0.193750, 2.022222}}],
    Line[{{0.590664, 0.181327, 1.986729},{0.611111, 0.222222, 2.027778},{
      0.587114, 0.174228, 2.057715}}],
    Line[{{0.620833, 0.161806, 2.022222},{0.590664, 0.181327, 1.986729},{
      0.556945, 0.193750, 2.022222},{0.587114, 0.174228, 2.057715},{
      0.620833, 0.161806, 2.022222}}],
    Line[{{0.500000, 0.500000, 0.500000},{0.639271, 0.685695, 0.592848}}],
    Line[{{0.639989, 0.627128, 0.574278},{0.639271, 0.685695, 0.592848},{
      0.582846, 0.669985, 0.574278}}],
    Line[{{0.619376, 0.659167, 0.541118},{0.639271, 0.685695, 0.592848},{
      0.603459, 0.637945, 0.607438}}],
    Line[{{0.639989, 0.627128, 0.574278},{0.619376, 0.659167, 0.541118},{
      0.582846, 0.669985, 0.574278},{0.603459, 0.637945, 0.607438},{
      0.639989, 0.627128, 0.574278}}],
    Line[{{0.500000, 0.500000, 1.000000},{0.647087, 0.696116, 1.049029}}],
    Line[{{0.646241, 0.635464, 1.039223},{0.647087, 0.696116, 1.049029},{
      0.589098, 0.678321, 1.039223}}],
    Line[{{0.621872, 0.662496, 1.004202},{0.647087, 0.696116, 1.049029},{
      0.613467, 0.651290, 1.074244}}],
    Line[{{0.646241, 0.635464, 1.039223},{0.621872, 0.662496, 1.004202},{
      0.589098, 0.678321, 1.039223},{0.613467, 0.651290, 1.074244},{
      0.646241, 0.635464, 1.039223}}],
    Line[{{0.500000, 0.500000, 1.500000},{0.648684, 0.698246, 1.533041}}],
    Line[{{0.647519, 0.637168, 1.526433},{0.648684, 0.698246, 1.533041},{
      0.590376, 0.680025, 1.526433}}],
    Line[{{0.621779, 0.662373, 1.491032},{0.648684, 0.698246, 1.533041},{
      0.616115, 0.654820, 1.561834}}],
    Line[{{0.647519, 0.637168, 1.526433},{0.621779, 0.662373, 1.491032},{
      0.590376, 0.680025, 1.526433},{0.616115, 0.654820, 1.561834},{
      0.647519, 0.637168, 1.526433}}],
    Line[{{0.500000, 0.500000, 2.000000},{0.649256, 0.699007, 2.024876}}],
    Line[{{0.647976, 0.637777, 2.019901},{0.649256, 0.699007, 2.024876},{
      0.590833, 0.680634, 2.019901}}],
    Line[{{0.621537, 0.662049, 1.984364},{0.649256, 0.699007, 2.024876},{
      0.617272, 0.656363, 2.055438}}],
    Line[{{0.647976, 0.637777, 2.019901},{0.621537, 0.662049, 1.984364},{
      0.590833, 0.680634, 2.019901},{0.617272, 0.656363, 2.055438},{
      0.647976, 0.637777, 2.019901}}],
    Line[{{0.500000, 1.000000, 0.500000},{0.666667, 1.166667, 0.583333}}],
    Line[{{0.658587, 1.108080, 0.566667},{0.666667, 1.166667, 0.583333},{
      0.608079, 1.158587, 0.566667}}],
    Line[{{0.641751, 1.141751, 0.532995},{0.666667, 1.166667, 0.583333},{
      0.624915, 1.124915, 0.600338}}],
    Line[{{0.658587, 1.108080, 0.566667},{0.641751, 1.141751, 0.532995},{
      0.608079, 1.158587, 0.566667},{0.624915, 1.124915, 0.600338},{
      0.658587, 1.108080, 0.566667}}],
    Line[{{0.500000, 1.000000, 1.000000},{0.674078, 1.174078, 1.043519}}],
    Line[{{0.664516, 1.114008, 1.034816},{0.674078, 1.174078, 1.043519},{
      0.614008, 1.164516, 1.034816}}],
    Line[{{0.643658, 1.143658, 0.999647},{0.674078, 1.174078, 1.043519},{
      0.634866, 1.134866, 1.069985}}],
    Line[{{0.664516, 1.114008, 1.034816},{0.643658, 1.143658, 0.999647},{
      0.614008, 1.164516, 1.034816},{0.634866, 1.134866, 1.069985},{
      0.664516, 1.114008, 1.034816}}],
    Line[{{0.500000, 1.000000, 1.500000},{0.675562, 1.175562, 1.529260}}],
    Line[{{0.665703, 1.115196, 1.523408},{0.675562, 1.175562, 1.529260},{
      0.615196, 1.165703, 1.523408}}],
    Line[{{0.643405, 1.143405, 1.487939},{0.675562, 1.175562, 1.529260},{
      0.637494, 1.137494, 1.558877}}],
    Line[{{0.665703, 1.115196, 1.523408},{0.643405, 1.143405, 1.487939},{
      0.615196, 1.165703, 1.523408},{0.637494, 1.137494, 1.558877},{
      0.665703, 1.115196, 1.523408}}],
    Line[{{0.500000, 1.000000, 2.000000},{0.676090, 1.176090, 2.022011}}],
    Line[{{0.666126, 1.115618, 2.017609},{0.676090, 1.176090, 2.022011},{
      0.615618, 1.166126, 2.017609}}],
    Line[{{0.643096, 1.143096, 1.982033},{0.676090, 1.176090, 2.022011},{
      0.638649, 1.138649, 2.053185}}],
    Line[{{0.666126, 1.115618, 2.017609},{0.643096, 1.143096, 1.982033},{
      0.615618, 1.166126, 2.017609},{0.638649, 1.138649, 2.053185},{
      0.666126, 1.115618, 2.017609}}],
    Line[{{0.500000, 1.500000, 0.500000},{0.686339, 1.649071, 0.574536}}],
    Line[{{0.671382, 1.591369, 0.559628},{0.686339, 1.649071, 0.574536},{
      0.626761, 1.647145, 0.559628}}],
    Line[{{0.657386, 1.625909, 0.525538},{0.686339, 1.649071, 0.574536},{
      0.640757, 1.612605, 0.593719}}],
    Line[{{0.671382, 1.591369, 0.559628},{0.657386, 1.625909, 0.525538},{
      0.626761, 1.647145, 0.559628},{0.640757, 1.612605, 0.593719},{
      0.671382, 1.591369, 0.559628}}],
    Line[{{0.500000, 1.500000, 1.000000},{0.692879, 1.654303, 1.038576}}],
    Line[{{0.676614, 1.595554, 1.030861},{0.692879, 1.654303, 1.038576},{
      0.631993, 1.651331, 1.030861}}],
    Line[{{0.658607, 1.626885, 0.995574},{0.692879, 1.654303, 1.038576},{
      0.650000, 1.620000, 1.066147}}],
    Line[{{0.676614, 1.595554, 1.030861},{0.658607, 1.626885, 0.995574},{
      0.631993, 1.651331, 1.030861},{0.650000, 1.620000, 1.066147},{
      0.676614, 1.595554, 1.030861}}],
    Line[{{0.500000, 1.500000, 1.500000},{0.694168, 1.655334, 1.525889}}],
    Line[{{0.677645, 1.596379, 1.520711},{0.694168, 1.655334, 1.525889},{
      0.633024, 1.652156, 1.520711}}],
    Line[{{0.658222, 1.626578, 1.485189},{0.694168, 1.655334, 1.525889},{
      0.652446, 1.621957, 1.556234}}],
    Line[{{0.677645, 1.596379, 1.520711},{0.658222, 1.626578, 1.485189},{
      0.633024, 1.652156, 1.520711},{0.652446, 1.621957, 1.556234},{
      0.677645, 1.596379, 1.520711}}],
    Line[{{0.500000, 1.500000, 2.000000},{0.694625, 1.655700, 2.019463}}],
    Line[{{0.678010, 1.596672, 2.015570},{0.694625, 1.655700, 2.019463},{
      0.633389, 1.652448, 2.015570}}],
    Line[{{0.657871, 1.626297, 1.979964},{0.694625, 1.655700, 2.019463},{
      0.653529, 1.622823, 2.051176}}],
    Line[{{0.678010, 1.596672, 2.015570},{0.657871, 1.626297, 1.979964},{
      0.633389, 1.652448, 2.015570},{0.653529, 1.622823, 2.051176},{
      0.678010, 1.596672, 2.015570}}],
    Line[{{0.500000, 2.000000, 0.500000},{0.700446, 2.133631, 0.566815}}],
    Line[{{0.680167, 2.077188, 0.553452},{0.700446, 2.133631, 0.566815},{
      0.640546, 2.136621, 0.553452}}],
    Line[{{0.668299, 2.112199, 0.519037},{0.700446, 2.133631, 0.566815},{
      0.652415, 2.101610, 0.587867}}],
    Line[{{0.680167, 2.077188, 0.553452},{0.668299, 2.112199, 0.519037},{
      0.640546, 2.136621, 0.553452},{0.652415, 2.101610, 0.587867},{
      0.680167, 2.077188, 0.553452}}],
    Line[{{0.500000, 2.000000, 1.000000},{0.706041, 2.137361, 1.034340}}],
    Line[{{0.684643, 2.080172, 1.027472},{0.706041, 2.137361, 1.034340},{
      0.645022, 2.139605, 1.027472}}],
    Line[{{0.668914, 2.112610, 0.992096},{0.706041, 2.137361, 1.034340},{
      0.660751, 2.107167, 1.062848}}],
    Line[{{0.684643, 2.080172, 1.027472},{0.668914, 2.112610, 0.992096},{
      0.645022, 2.139605, 1.027472},{0.660751, 2.107167, 1.062848},{
      0.684643, 2.080172, 1.027472}}],
    Line[{{0.500000, 2.000000, 1.500000},{0.707129, 2.138086, 1.523014}}],
    Line[{{0.685514, 2.080753, 1.518412},{0.707129, 2.138086, 1.523014},{
      0.645893, 2.140185, 1.518412}}],
    Line[{{0.668439, 2.112293, 1.482849},{0.707129, 2.138086, 1.523014},{
      0.662968, 2.108645, 1.553974}}],
    Line[{{0.685514, 2.080753, 1.518412},{0.668439, 2.112293, 1.482849},{
      0.645893, 2.140185, 1.518412},{0.662968, 2.108645, 1.553974},{
      0.685514, 2.080753, 1.518412}}],
    Line[{{0.500000, 2.000000, 2.000000},{0.707514, 2.138343, 2.017293}}],
    Line[{{0.685822, 2.080958, 2.013834},{0.707514, 2.138343, 2.017293},{
      0.646201, 2.140390, 2.013834}}],
    Line[{{0.668067, 2.112045, 1.978206},{0.707514, 2.138343, 2.017293},{
      0.663956, 2.109304, 2.049463}}],
    Line[{{0.685822, 2.080958, 2.013834},{0.668067, 2.112045, 1.978206},{
      0.646201, 2.140390, 2.013834},{0.663956, 2.109304, 2.049463},{
      0.685822, 2.080958, 2.013834}}],
    Line[{{1.000000, 0.000000, 0.500000},{1.102062, 0.204124, 0.602062}}],
    Line[{{1.113593, 0.147327, 0.581650},{1.102062, 0.204124, 0.602062},{
      1.049706, 0.179271, 0.581650}}],
    Line[{{1.088170, 0.176340, 0.549047},{1.102062, 0.204124, 0.602062},{
      1.075129, 0.150258, 0.614252}}],
    Line[{{1.113593, 0.147327, 0.581650},{1.088170, 0.176340, 0.549047},{
      1.049706, 0.179271, 0.581650},{1.075129, 0.150258, 0.614252},{
      1.113593, 0.147327, 0.581650}}],
    Line[{{1.000000, 0.000000, 1.000000},{1.109109, 0.218218, 1.054554}}],
    Line[{{1.119231, 0.158602, 1.043644},{1.109109, 0.218218, 1.054554},{
      1.055343, 0.190546, 1.043644}}],
    Line[{{1.090773, 0.181545, 1.008790},{1.109109, 0.218218, 1.054554},{
      1.083802, 0.167604, 1.078497}}],
    Line[{{1.119231, 0.158602, 1.043644},{1.090773, 0.181545, 1.008790},{
      1.055343, 0.190546, 1.043644},{1.083802, 0.167604, 1.078497},{
      1.119231, 0.158602, 1.043644}}],
    Line[{{1.000000, 0.000000, 1.500000},{1.110582, 0.221163, 1.536860}}],
    Line[{{1.120409, 0.160958, 1.529488},{1.110582, 0.221163, 1.536860},{
      1.056521, 0.192902, 1.529488}}],
    Line[{{1.090820, 0.181640, 1.494164},{1.110582, 0.221163, 1.536860},{
      1.086110, 0.172220, 1.564812}}],
    Line[{{1.120409, 0.160958, 1.529488},{1.090820, 0.181640, 1.494164},{
      1.056521, 0.192902, 1.529488},{1.086110, 0.172220, 1.564812},{
      1.120409, 0.160958, 1.529488}}],
    Line[{{1.000000, 0.000000, 2.000000},{1.111111, 0.222222, 2.027778}}],
    Line[{{1.120833, 0.161806, 2.022222},{1.111111, 0.222222, 2.027778},{
      1.056945, 0.193750, 2.022222}}],
    Line[{{1.090664, 0.181327, 1.986729},{1.111111, 0.222222, 2.027778},{
      1.087114, 0.174228, 2.057715}}],
    Line[{{1.120833, 0.161806, 2.022222},{1.090664, 0.181327, 1.986729},{
      1.056945, 0.193750, 2.022222},{1.087114, 0.174228, 2.057715},{
      1.120833, 0.161806, 2.022222}}],
    Line[{{1.000000, 0.500000, 0.500000},{1.139271, 0.685695, 0.592848}}],
    Line[{{1.139989, 0.627128, 0.574278},{1.139271, 0.685695, 0.592848},{
      1.082846, 0.669985, 0.574278}}],
    Line[{{1.119376, 0.659167, 0.541118},{1.139271, 0.685695, 0.592848},{
      1.103459, 0.637945, 0.607438}}],
    Line[{{1.139989, 0.627128, 0.574278},{1.119376, 0.659167, 0.541118},{
      1.082846, 0.669985, 0.574278},{1.103459, 0.637945, 0.607438},{
      1.139989, 0.627128, 0.574278}}],
    Line[{{1.000000, 0.500000, 1.000000},{1.147087, 0.696116, 1.049029}}],
    Line[{{1.146241, 0.635464, 1.039223},{1.147087, 0.696116, 1.049029},{
      1.089098, 0.678321, 1.039223}}],
    Line[{{1.121872, 0.662496, 1.004202},{1.147087, 0.696116, 1.049029},{
      1.113467, 0.651290, 1.074244}}],
    Line[{{1.146241, 0.635464, 1.039223},{1.121872, 0.662496, 1.004202},{
      1.089098, 0.678321, 1.039223},{1.113467, 0.651290, 1.074244},{
      1.146241, 0.635464, 1.039223}}],
    Line[{{1.000000, 0.500000, 1.500000},{1.148684, 0.698246, 1.533041}}],
    Line[{{1.147519, 0.637168, 1.526433},{1.148684, 0.698246, 1.533041},{
      1.090376, 0.680025, 1.526433}}],
    Line[{{1.121779, 0.662373, 1.491032},{1.148684, 0.698246, 1.533041},{
      1.116115, 0.654820, 1.561834}}],
    Line[{{1.147519, 0.637168, 1.526433},{1.121779, 0.662373, 1.491032},{
      1.090376, 0.680025, 1.526433},{1.116115, 0.654820, 1.561834},{
      1.147519, 0.637168, 1.526433}}],
    Line[{{1.000000, 0.500000, 2.000000},{1.149256, 0.699007, 2.024876}}],
    Line[{{1.147976, 0.637777, 2.019901},{1.149256, 0.699007, 2.024876},{
      1.090833, 0.680634, 2.019901}}],
    Line[{{1.121537, 0.662049, 1.984364},{1.149256, 0.699007, 2.024876},{
      1.117272, 0.656363, 2.055438}}],
    Line[{{1.147976, 0.637777, 2.019901},{1.121537, 0.662049, 1.984364},{
      1.090833, 0.680634, 2.019901},{1.117272, 0.656363, 2.055438},{
      1.147976, 0.637777, 2.019901}}],
    Line[{{1.000000, 1.000000, 0.500000},{1.166667, 1.166667, 0.583333}}],
    Line[{{1.158587, 1.108080, 0.566667},{1.166667, 1.166667, 0.583333},{
      1.108080, 1.158587, 0.566667}}],
    Line[{{1.141751, 1.141751, 0.532995},{1.166667, 1.166667, 0.583333},{
      1.124915, 1.124915, 0.600338}}],
    Line[{{1.158587, 1.108080, 0.566667},{1.141751, 1.141751, 0.532995},{
      1.108080, 1.158587, 0.566667},{1.124915, 1.124915, 0.600338},{
      1.158587, 1.108080, 0.566667}}],
    Line[{{1.000000, 1.000000, 1.000000},{1.174078, 1.174078, 1.043519}}],
    Line[{{1.164516, 1.114008, 1.034816},{1.174078, 1.174078, 1.043519},{
      1.114008, 1.164516, 1.034816}}],
    Line[{{1.143658, 1.143658, 0.999647},{1.174078, 1.174078, 1.043519},{
      1.134866, 1.134866, 1.069985}}],
    Line[{{1.164516, 1.114008, 1.034816},{1.143658, 1.143658, 0.999647},{
      1.114008, 1.164516, 1.034816},{1.134866, 1.134866, 1.069985},{
      1.164516, 1.114008, 1.034816}}],
    Line[{{1.000000, 1.000000, 1.500000},{1.175562, 1.175562, 1.529260}}],
    Line[{{1.165703, 1.115196, 1.523408},{1.175562, 1.175562, 1.529260},{
      1.115196, 1.165703, 1.523408}}],
    Line[{{1.143405, 1.143405, 1.487939},{1.175562, 1.175562, 1.529260},{
      1.137494, 1.137494, 1.558877}}],
    Line[{{1.165703, 1.115196, 1.523408},{1.143405, 1.143405, 1.487939},{
      1.115196, 1.165703, 1.523408},{1.137494, 1.137494, 1.558877},{
      1.165703, 1.115196, 1.523408}}],
    Line[{{1.000000, 1.000000, 2.000000},{1.176090, 1.176090, 2.022011}}],
    Line[{{1.166126, 1.115618, 2.017609},{1.176090, 1.176090, 2.022011},{
      1.115618, 1.166126, 2.017609}}],
    Line[{{1.143096, 1.143096, 1.982033},{1.176090, 1.176090, 2.022011},{
      1.138649, 1.138649, 2.053185}}],
    Line[{{1.166126, 1.115618, 2.017609},{1.143096, 1.143096, 1.982033},{
      1.115618, 1.166126, 2.017609},{1.138649, 1.138649, 2.053185},{
      1.166126, 1.115618, 2.017609}}],
    Line[{{1.000000, 1.500000, 0.500000},{1.186339, 1.649071, 0.574536}}],
    Line[{{1.171382, 1.591369, 0.559628},{1.186339, 1.649071, 0.574536},{
      1.126761, 1.647145, 0.559628}}],
    Line[{{1.157386, 1.625909, 0.525538},{1.186339, 1.649071, 0.574536},{
      1.140757, 1.612605, 0.593719}}],
    Line[{{1.171382, 1.591369, 0.559628},{1.157386, 1.625909, 0.525538},{
      1.126761, 1.647145, 0.559628},{1.140757, 1.612605, 0.593719},{
      1.171382, 1.591369, 0.559628}}],
    Line[{{1.000000, 1.500000, 1.000000},{1.192879, 1.654303, 1.038576}}],
    Line[{{1.176614, 1.595554, 1.030861},{1.192879, 1.654303, 1.038576},{
      1.131993, 1.651331, 1.030861}}],
    Line[{{1.158607, 1.626885, 0.995574},{1.192879, 1.654303, 1.038576},{
      1.150000, 1.620000, 1.066147}}],
    Line[{{1.176614, 1.595554, 1.030861},{1.158607, 1.626885, 0.995574},{
      1.131993, 1.651331, 1.030861},{1.150000, 1.620000, 1.066147},{
      1.176614, 1.595554, 1.030861}}],
    Line[{{1.000000, 1.500000, 1.500000},{1.194168, 1.655334, 1.525889}}],
    Line[{{1.177645, 1.596379, 1.520711},{1.194168, 1.655334, 1.525889},{
      1.133024, 1.652156, 1.520711}}],
    Line[{{1.158222, 1.626578, 1.485189},{1.194168, 1.655334, 1.525889},{
      1.152446, 1.621957, 1.556234}}],
    Line[{{1.177645, 1.596379, 1.520711},{1.158222, 1.626578, 1.485189},{
      1.133024, 1.652156, 1.520711},{1.152446, 1.621957, 1.556234},{
      1.177645, 1.596379, 1.520711}}],
    Line[{{1.000000, 1.500000, 2.000000},{1.194625, 1.655700, 2.019463}}],
    Line[{{1.178010, 1.596672, 2.015570},{1.194625, 1.655700, 2.019463},{
      1.133389, 1.652448, 2.015570}}],
    Line[{{1.157871, 1.626297, 1.979964},{1.194625, 1.655700, 2.019463},{
      1.153529, 1.622823, 2.051176}}],
    Line[{{1.178010, 1.596672, 2.015570},{1.157871, 1.626297, 1.979964},{
      1.133389, 1.652448, 2.015570},{1.153529, 1.622823, 2.051176},{
      1.178010, 1.596672, 2.015570}}],
    Line[{{1.000000, 2.000000, 0.500000},{1.200446, 2.133631, 0.566815}}],
    Line[{{1.180167, 2.077188, 0.553452},{1.200446, 2.133631, 0.566815},{
      1.140546, 2.136621, 0.553452}}],
    Line[{{1.168299, 2.112199, 0.519037},{1.200446, 2.133631, 0.566815},{
      1.152415, 2.101610, 0.587867}}],
    Line[{{1.180167, 2.077188, 0.553452},{1.168299, 2.112199, 0.519037},{
      1.140546, 2.136621, 0.553452},{1.152415, 2.101610, 0.587867},{
      1.180167, 2.077188, 0.553452}}],
    Line[{{1.000000, 2.000000, 1.000000},{1.206041, 2.137361, 1.034340}}],
    Line[{{1.184643, 2.080172, 1.027472},{1.206041, 2.137361, 1.034340},{
      1.145022, 2.139605, 1.027472}}],
    Line[{{1.168914, 2.112610, 0.992096},{1.206041, 2.137361, 1.034340},{
      1.160751, 2.107167, 1.062848}}],
    Line[{{1.184643, 2.080172, 1.027472},{1.168914, 2.112610, 0.992096},{
      1.145022, 2.139605, 1.027472},{1.160751, 2.107167, 1.062848},{
      1.184643, 2.080172, 1.027472}}],
    Line[{{1.000000, 2.000000, 1.500000},{1.207129, 2.138086, 1.523014}}],
    Line[{{1.185514, 2.080753, 1.518412},{1.207129, 2.138086, 1.523014},{
      1.145893, 2.140185, 1.518412}}],
    Line[{{1.168439, 2.112293, 1.482849},{1.207129, 2.138086, 1.523014},{
      1.162968, 2.108645, 1.553974}}],
    Line[{{1.185514, 2.080753, 1.518412},{1.168439, 2.112293, 1.482849},{
      1.145893, 2.140185, 1.518412},{1.162968, 2.108645, 1.553974},{
      1.185514, 2.080753, 1.518412}}],
    Line[{{1.000000, 2.000000, 2.000000},{1.207514, 2.138343, 2.017293}}],
    Line[{{1.185822, 2.080958, 2.013834},{1.207514, 2.138343, 2.017293},{
      1.146201, 2.140390, 2.013834}}],
    Line[{{1.168067, 2.112045, 1.978206},{1.207514, 2.138343, 2.017293},{
      1.163956, 2.109304, 2.049463}}],
    Line[{{1.185822, 2.080958, 2.013834},{1.168067, 2.112045, 1.978206},{
      1.146201, 2.140390, 2.013834},{1.163956, 2.109304, 2.049463},{
      1.185822, 2.080958, 2.013834}}],
    Line[{{1.500000, 0.000000, 0.500000},{1.602062, 0.204124, 0.602062}}],
    Line[{{1.613593, 0.147327, 0.581650},{1.602062, 0.204124, 0.602062},{
      1.549706, 0.179271, 0.581650}}],
    Line[{{1.588170, 0.176340, 0.549047},{1.602062, 0.204124, 0.602062},{
      1.575129, 0.150258, 0.614252}}],
    Line[{{1.613593, 0.147327, 0.581650},{1.588170, 0.176340, 0.549047},{
      1.549706, 0.179271, 0.581650},{1.575129, 0.150258, 0.614252},{
      1.613593, 0.147327, 0.581650}}],
    Line[{{1.500000, 0.000000, 1.000000},{1.609109, 0.218218, 1.054554}}],
    Line[{{1.619231, 0.158602, 1.043644},{1.609109, 0.218218, 1.054554},{
      1.555343, 0.190546, 1.043644}}],
    Line[{{1.590773, 0.181545, 1.008790},{1.609109, 0.218218, 1.054554},{
      1.583802, 0.167604, 1.078497}}],
    Line[{{1.619231, 0.158602, 1.043644},{1.590773, 0.181545, 1.008790},{
      1.555343, 0.190546, 1.043644},{1.583802, 0.167604, 1.078497},{
      1.619231, 0.158602, 1.043644}}],
    Line[{{1.500000, 0.000000, 1.500000},{1.610582, 0.221163, 1.536860}}],
    Line[{{1.620409, 0.160958, 1.529488},{1.610582, 0.221163, 1.536860},{
      1.556521, 0.192902, 1.529488}}],
    Line[{{1.590820, 0.181640, 1.494164},{1.610582, 0.221163, 1.536860},{
      1.586110, 0.172220, 1.564812}}],
    Line[{{1.620409, 0.160958, 1.529488},{1.590820, 0.181640, 1.494164},{
      1.556521, 0.192902, 1.529488},{1.586110, 0.172220, 1.564812},{
      1.620409, 0.160958, 1.529488}}],
    Line[{{1.500000, 0.000000, 2.000000},{1.611111, 0.222222, 2.027778}}],
    Line[{{1.620833, 0.161806, 2.022222},{1.611111, 0.222222, 2.027778},{
      1.556945, 0.193750, 2.022222}}],
    Line[{{1.590664, 0.181327, 1.986729},{1.611111, 0.222222, 2.027778},{
      1.587114, 0.174228, 2.057715}}],
    Line[{{1.620833, 0.161806, 2.022222},{1.590664, 0.181327, 1.986729},{
      1.556945, 0.193750, 2.022222},{1.587114, 0.174228, 2.057715},{
      1.620833, 0.161806, 2.022222}}],
    Line[{{1.500000, 0.500000, 0.500000},{1.639271, 0.685695, 0.592848}}],
    Line[{{1.639989, 0.627128, 0.574278},{1.639271, 0.685695, 0.592848},{
      1.582846, 0.669985, 0.574278}}],
    Line[{{1.619376, 0.659167, 0.541118},{1.639271, 0.685695, 0.592848},{
      1.603459, 0.637945, 0.607438}}],
    Line[{{1.639989, 0.627128, 0.574278},{1.619376, 0.659167, 0.541118},{
      1.582846, 0.669985, 0.574278},{1.603459, 0.637945, 0.607438},{
      1.639989, 0.627128, 0.574278}}],
    Line[{{1.500000, 0.500000, 1.000000},{1.647087, 0.696116, 1.049029}}],
    Line[{{1.646241, 0.635464, 1.039223},{1.647087, 0.696116, 1.049029},{
      1.589098, 0.678321, 1.039223}}],
    Line[{{1.621872, 0.662496, 1.004202},{1.647087, 0.696116, 1.049029},{
      1.613467, 0.651290, 1.074244}}],
    Line[{{1.646241, 0.635464, 1.039223},{1.621872, 0.662496, 1.004202},{
      1.589098, 0.678321, 1.039223},{1.613467, 0.651290, 1.074244},{
      1.646241, 0.635464, 1.039223}}],
    Line[{{1.500000, 0.500000, 1.500000},{1.648684, 0.698246, 1.533041}}],
    Line[{{1.647519, 0.637168, 1.526433},{1.648684, 0.698246, 1.533041},{
      1.590376, 0.680025, 1.526433}}],
    Line[{{1.621779, 0.662373, 1.491032},{1.648684, 0.698246, 1.533041},{
      1.616115, 0.654820, 1.561834}}],
    Line[{{1.647519, 0.637168, 1.526433},{1.621779, 0.662373, 1.491032},{
      1.590376, 0.680025, 1.526433},{1.616115, 0.654820, 1.561834},{
      1.647519, 0.637168, 1.526433}}],
    Line[{{1.500000, 0.500000, 2.000000},{1.649256, 0.699007, 2.024876}}],
    Line[{{1.647976, 0.637777, 2.019901},{1.649256, 0.699007, 2.024876},{
      1.590833, 0.680634, 2.019901}}],
    Line[{{1.621537, 0.662049, 1.984364},{1.649256, 0.699007, 2.024876},{
      1.617272, 0.656363, 2.055438}}],
    Line[{{1.647976, 0.637777, 2.019901},{1.621537, 0.662049, 1.984364},{
      1.590833, 0.680634, 2.019901},{1.617272, 0.656363, 2.055438},{
      1.647976, 0.637777, 2.019901}}],
    Line[{{1.500000, 1.000000, 0.500000},{1.666667, 1.166667, 0.583333}}],
    Line[{{1.658587, 1.108080, 0.566667},{1.666667, 1.166667, 0.583333},{
      1.608080, 1.158587, 0.566667}}],
    Line[{{1.641751, 1.141751, 0.532995},{1.666667, 1.166667, 0.583333},{
      1.624915, 1.124915, 0.600338}}],
    Line[{{1.658587, 1.108080, 0.566667},{1.641751, 1.141751, 0.532995},{
      1.608080, 1.158587, 0.566667},{1.624915, 1.124915, 0.600338},{
      1.658587, 1.108080, 0.566667}}],
    Line[{{1.500000, 1.000000, 1.000000},{1.674078, 1.174078, 1.043519}}],
    Line[{{1.664516, 1.114008, 1.034816},{1.674078, 1.174078, 1.043519},{
      1.614008, 1.164516, 1.034816}}],
    Line[{{1.643658, 1.143658, 0.999647},{1.674078, 1.174078, 1.043519},{
      1.634866, 1.134866, 1.069985}}],
    Line[{{1.664516, 1.114008, 1.034816},{1.643658, 1.143658, 0.999647},{
      1.614008, 1.164516, 1.034816},{1.634866, 1.134866, 1.069985},{
      1.664516, 1.114008, 1.034816}}],
    Line[{{1.500000, 1.000000, 1.500000},{1.675562, 1.175562, 1.529260}}],
    Line[{{1.665703, 1.115196, 1.523408},{1.675562, 1.175562, 1.529260},{
      1.615196, 1.165703, 1.523408}}],
    Line[{{1.643405, 1.143405, 1.487939},{1.675562, 1.175562, 1.529260},{
      1.637494, 1.137494, 1.558877}}],
    Line[{{1.665703, 1.115196, 1.523408},{1.643405, 1.143405, 1.487939},{
      1.615196, 1.165703, 1.523408},{1.637494, 1.137494, 1.558877},{
      1.665703, 1.115196, 1.523408}}],
    Line[{{1.500000, 1.000000, 2.000000},{1.676090, 1.176090, 2.022011}}],
    Line[{{1.666126, 1.115618, 2.017609},{1.676090, 1.176090, 2.022011},{
      1.615618, 1.166126, 2.017609}}],
    Line[{{1.643096, 1.143096, 1.982033},{1.676090, 1.176090, 2.022011},{
      1.638649, 1.138649, 2.053185}}],
    Line[{{1.666126, 1.115618, 2.017609},{1.643096, 1.143096, 1.982033},{
      1.615618, 1.166126, 2.017609},{1.638649, 1.138649, 2.053185},{
      1.666126, 1.115618, 2.017609}}],
    Line[{{1.500000, 1.500000, 0.500000},{1.686339, 1.649071, 0.574536}}],
    Line[{{1.671382, 1.591369, 0.559628},{1.686339, 1.649071, 0.574536},{
      1.626761, 1.647145, 0.559628}}],
    Line[{{1.657386, 1.625909, 0.525538},{1.686339, 1.649071, 0.574536},{
      1.640757, 1.612605, 0.593719}}],
    Line[{{1.671382, 1.591369, 0.559628},{1.657386, 1.625909, 0.525538},{
      1.626761, 1.647145, 0.559628},{1.640757, 1.612605, 0.593719},{
      1.671382, 1.591369, 0.559628}}],
    Line[{{1.500000, 1.500000, 1.000000},{1.692879, 1.654303, 1.038576}}],
    Line[{{1.676614, 1.595554, 1.030861},{1.692879, 1.654303, 1.038576},{
      1.631993, 1.651331, 1.030861}}],
    Line[{{1.658607, 1.626885, 0.995574},{1.692879, 1.654303, 1.038576},{
      1.650000, 1.620000, 1.066147}}],
    Line[{{1.676614, 1.595554, 1.030861},{1.658607, 1.626885, 0.995574},{
      1.631993, 1.651331, 1.030861},{1.650000, 1.620000, 1.066147},{
      1.676614, 1.595554, 1.030861}}],
    Line[{{1.500000, 1.500000, 1.500000},{1.694168, 1.655334, 1.525889}}],
    Line[{{1.677645, 1.596379, 1.520711},{1.694168, 1.655334, 1.525889},{
      1.633024, 1.652156, 1.520711}}],
    Line[{{1.658222, 1.626578, 1.485189},{1.694168, 1.655334, 1.525889},{
      1.652446, 1.621957, 1.556234}}],
    Line[{{1.677645, 1.596379, 1.520711},{1.658222, 1.626578, 1.485189},{
      1.633024, 1.652156, 1.520711},{1.652446, 1.621957, 1.556234},{
      1.677645, 1.596379, 1.520711}}],
    Line[{{1.500000, 1.500000, 2.000000},{1.694625, 1.655700, 2.019463}}],
    Line[{{1.678010, 1.596672, 2.015570},{1.694625, 1.655700, 2.019463},{
      1.633389, 1.652448, 2.015570}}],
    Line[{{1.657871, 1.626297, 1.979964},{1.694625, 1.655700, 2.019463},{
      1.653529, 1.622823, 2.051176}}],
    Line[{{1.678010, 1.596672, 2.015570},{1.657871, 1.626297, 1.979964},{
      1.633389, 1.652448, 2.015570},{1.653529, 1.622823, 2.051176},{
      1.678010, 1.596672, 2.015570}}],
    Line[{{1.500000, 2.000000, 0.500000},{1.700446, 2.133631, 0.566815}}],
    Line[{{1.680167, 2.077188, 0.553452},{1.700446, 2.133631, 0.566815},{
      1.640546, 2.136621, 0.553452}}],
    Line[{{1.668299, 2.112199, 0.519037},{1.700446, 2.133631, 0.566815},{
      1.652415, 2.101610, 0.587867}}],
    Line[{{1.680167, 2.077188, 0.553452},{1.668299, 2.112199, 0.519037},{
      1.640546, 2.136621, 0.553452},{1.652415, 2.101610, 0.587867},{
      1.680167, 2.077188, 0.553452}}],
    Line[{{1.500000, 2.000000, 1.000000},{1.706041, 2.137361, 1.034340}}],
    Line[{{1.684643, 2.080172, 1.027472},{1.706041, 2.137361, 1.034340},{
      1.645022, 2.139605, 1.027472}}],
    Line[{{1.668914, 2.112610, 0.992096},{1.706041, 2.137361, 1.034340},{
      1.660751, 2.107167, 1.062848}}],
    Line[{{1.684643, 2.080172, 1.027472},{1.668914, 2.112610, 0.992096},{
      1.645022, 2.139605, 1.027472},{1.660751, 2.107167, 1.062848},{
      1.684643, 2.080172, 1.027472}}],
    Line[{{1.500000, 2.000000, 1.500000},{1.707129, 2.138086, 1.523014}}],
    Line[{{1.685514, 2.080753, 1.518412},{1.707129, 2.138086, 1.523014},{
      1.645893, 2.140185, 1.518412}}],
    Line[{{1.668439, 2.112293, 1.482849},{1.707129, 2.138086, 1.523014},{
      1.662968, 2.108645, 1.553974}}],
    Line[{{1.685514, 2.080753, 1.518412},{1.668439, 2.112293, 1.482849},{
      1.645893, 2.140185, 1.518412},{1.662968, 2.108645, 1.553974},{
      1.685514, 2.080753, 1.518412}}],
    Line[{{1.500000, 2.000000, 2.000000},{1.707514, 2.138343, 2.017293}}],
    Line[{{1.685822, 2.080958, 2.013834},{1.707514, 2.138343, 2.017293},{
      1.646201, 2.140390, 2.013834}}],
    Line[{{1.668067, 2.112045, 1.978206},{1.707514, 2.138343, 2.017293},{
      1.663956, 2.109304, 2.049463}}],
    Line[{{1.685822, 2.080958, 2.013834},{1.668067, 2.112045, 1.978206},{
      1.646201, 2.140390, 2.013834},{1.663956, 2.109304, 2.049463},{
      1.685822, 2.080958, 2.013834}}],
    Line[{{2.000000, 0.000000, 0.500000},{2.102062, 0.204124, 0.602062}}],
    Line[{{2.113594, 0.147327, 0.581650},{2.102062, 0.204124, 0.602062},{
      2.049706, 0.179271, 0.581650}}],
    Line[{{2.088170, 0.176340, 0.549047},{2.102062, 0.204124, 0.602062},{
      2.075129, 0.150258, 0.614252}}],
    Line[{{2.113594, 0.147327, 0.581650},{2.088170, 0.176340, 0.549047},{
      2.049706, 0.179271, 0.581650},{2.075129, 0.150258, 0.614252},{
      2.113594, 0.147327, 0.581650}}],
    Line[{{2.000000, 0.000000, 1.000000},{2.109109, 0.218218, 1.054554}}],
    Line[{{2.119231, 0.158602, 1.043644},{2.109109, 0.218218, 1.054554},{
      2.055343, 0.190546, 1.043644}}],
    Line[{{2.090773, 0.181545, 1.008790},{2.109109, 0.218218, 1.054554},{
      2.083802, 0.167604, 1.078497}}],
    Line[{{2.119231, 0.158602, 1.043644},{2.090773, 0.181545, 1.008790},{
      2.055343, 0.190546, 1.043644},{2.083802, 0.167604, 1.078497},{
      2.119231, 0.158602, 1.043644}}],
    Line[{{2.000000, 0.000000, 1.500000},{2.110581, 0.221163, 1.536860}}],
    Line[{{2.120409, 0.160958, 1.529488},{2.110581, 0.221163, 1.536860},{
      2.056521, 0.192902, 1.529488}}],
    Line[{{2.090820, 0.181640, 1.494164},{2.110581, 0.221163, 1.536860},{
      2.086110, 0.172220, 1.564812}}],
    Line[{{2.120409, 0.160958, 1.529488},{2.090820, 0.181640, 1.494164},{
      2.056521, 0.192902, 1.529488},{2.086110, 0.172220, 1.564812},{
      2.120409, 0.160958, 1.529488}}],
    Line[{{2.000000, 0.000000, 2.000000},{2.111111, 0.222222, 2.027778}}],
    Line[{{2.120833, 0.161806, 2.022222},{2.111111, 0.222222, 2.027778},{
      2.056945, 0.193750, 2.022222}}],
    Line[{{2.090663, 0.181327, 1.986729},{2.111111, 0.222222, 2.027778},{
      2.087114, 0.174228, 2.057715}}],
    Line[{{2.120833, 0.161806, 2.022222},{2.090663, 0.181327, 1.986729},{
      2.056945, 0.193750, 2.022222},{2.087114, 0.174228, 2.057715},{
      2.120833, 0.161806, 2.022222}}],
    Line[{{2.000000, 0.500000, 0.500000},{2.139271, 0.685695, 0.592848}}],
    Line[{{2.139989, 0.627128, 0.574278},{2.139271, 0.685695, 0.592848},{
      2.082846, 0.669985, 0.574278}}],
    Line[{{2.119375, 0.659167, 0.541118},{2.139271, 0.685695, 0.592848},{
      2.103459, 0.637945, 0.607438}}],
    Line[{{2.139989, 0.627128, 0.574278},{2.119375, 0.659167, 0.541118},{
      2.082846, 0.669985, 0.574278},{2.103459, 0.637945, 0.607438},{
      2.139989, 0.627128, 0.574278}}],
    Line[{{2.000000, 0.500000, 1.000000},{2.147087, 0.696116, 1.049029}}],
    Line[{{2.146241, 0.635464, 1.039223},{2.147087, 0.696116, 1.049029},{
      2.089098, 0.678321, 1.039223}}],
    Line[{{2.121872, 0.662496, 1.004202},{2.147087, 0.696116, 1.049029},{
      2.113467, 0.651290, 1.074244}}],
    Line[{{2.146241, 0.635464, 1.039223},{2.121872, 0.662496, 1.004202},{
      2.089098, 0.678321, 1.039223},{2.113467, 0.651290, 1.074244},{
      2.146241, 0.635464, 1.039223}}],
    Line[{{2.000000, 0.500000, 1.500000},{2.148684, 0.698246, 1.533041}}],
    Line[{{2.147519, 0.637168, 1.526433},{2.148684, 0.698246, 1.533041},{
      2.090376, 0.680025, 1.526433}}],
    Line[{{2.121779, 0.662373, 1.491032},{2.148684, 0.698246, 1.533041},{
      2.116115, 0.654820, 1.561834}}],
    Line[{{2.147519, 0.637168, 1.526433},{2.121779, 0.662373, 1.491032},{
      2.090376, 0.680025, 1.526433},{2.116115, 0.654820, 1.561834},{
      2.147519, 0.637168, 1.526433}}],
    Line[{{2.000000, 0.500000, 2.000000},{2.149256, 0.699007, 2.024876}}],
    Line[{{2.147976, 0.637777, 2.019901},{2.149256, 0.699007, 2.024876},{
      2.090833, 0.680634, 2.019901}}],
    Line[{{2.121537, 0.662049, 1.984364},{2.149256, 0.699007, 2.024876},{
      2.117272, 0.656363, 2.055438}}],
    Line[{{2.147976, 0.637777, 2.019901},{2.121537, 0.662049, 1.984364},{
      2.090833, 0.680634, 2.019901},{2.117272, 0.656363, 2.055438},{
      2.147976, 0.637777, 2.019901}}],
    Line[{{2.000000, 1.000000, 0.500000},{2.166667, 1.166667, 0.583333}}],
    Line[{{2.158587, 1.108080, 0.566667},{2.166667, 1.166667, 0.583333},{
      2.108079, 1.158587, 0.566667}}],
    Line[{{2.141751, 1.141751, 0.532995},{2.166667, 1.166667, 0.583333},{
      2.124915, 1.124915, 0.600338}}],
    Line[{{2.158587, 1.108080, 0.566667},{2.141751, 1.141751, 0.532995},{
      2.108079, 1.158587, 0.566667},{2.124915, 1.124915, 0.600338},{
      2.158587, 1.108080, 0.566667}}],
    Line[{{2.000000, 1.000000, 1.000000},{2.174078, 1.174078, 1.043519}}],
    Line[{{2.164516, 1.114008, 1.034816},{2.174078, 1.174078, 1.043519},{
      2.114008, 1.164516, 1.034816}}],
    Line[{{2.143658, 1.143658, 0.999647},{2.174078, 1.174078, 1.043519},{
      2.134866, 1.134866, 1.069985}}],
    Line[{{2.164516, 1.114008, 1.034816},{2.143658, 1.143658, 0.999647},{
      2.114008, 1.164516, 1.034816},{2.134866, 1.134866, 1.069985},{
      2.164516, 1.114008, 1.034816}}],
    Line[{{2.000000, 1.000000, 1.500000},{2.175562, 1.175562, 1.529260}}],
    Line[{{2.165703, 1.115196, 1.523408},{2.175562, 1.175562, 1.529260},{
      2.115196, 1.165703, 1.523408}}],
    Line[{{2.143405, 1.143405, 1.487939},{2.175562, 1.175562, 1.529260},{
      2.137494, 1.137494, 1.558877}}],
    Line[{{2.165703, 1.115196, 1.523408},{2.143405, 1.143405, 1.487939},{
      2.115196, 1.165703, 1.523408},{2.137494, 1.137494, 1.558877},{
      2.165703, 1.115196, 1.523408}}],
    Line[{{2.000000, 1.000000, 2.000000},{2.176090, 1.176090, 2.022011}}],
    Line[{{2.166126, 1.115618, 2.017609},{2.176090, 1.176090, 2.022011},{
      2.115618, 1.166126, 2.017609}}],
    Line[{{2.143096, 1.143096, 1.982033},{2.176090, 1.176090, 2.022011},{
      2.138649, 1.138649, 2.053185}}],
    Line[{{2.166126, 1.115618, 2.017609},{2.143096, 1.143096, 1.982033},{
      2.115618, 1.166126, 2.017609},{2.138649, 1.138649, 2.053185},{
      2.166126, 1.115618, 2.017609}}],
    Line[{{2.000000, 1.500000, 0.500000},{2.186339, 1.649071, 0.574536}}],
    Line[{{2.171382, 1.591369, 0.559628},{2.186339, 1.649071, 0.574536},{
      2.126761, 1.647145, 0.559628}}],
    Line[{{2.157386, 1.625909, 0.525538},{2.186339, 1.649071, 0.574536},{
      2.140757, 1.612605, 0.593719}}],
    Line[{{2.171382, 1.591369, 0.559628},{2.157386, 1.625909, 0.525538},{
      2.126761, 1.647145, 0.559628},{2.140757, 1.612605, 0.593719},{
      2.171382, 1.591369, 0.559628}}],
    Line[{{2.000000, 1.500000, 1.000000},{2.192879, 1.654303, 1.038576}}],
    Line[{{2.176614, 1.595554, 1.030861},{2.192879, 1.654303, 1.038576},{
      2.131993, 1.651331, 1.030861}}],
    Line[{{2.158607, 1.626885, 0.995574},{2.192879, 1.654303, 1.038576},{
      2.150000, 1.620000, 1.066147}}],
    Line[{{2.176614, 1.595554, 1.030861},{2.158607, 1.626885, 0.995574},{
      2.131993, 1.651331, 1.030861},{2.150000, 1.620000, 1.066147},{
      2.176614, 1.595554, 1.030861}}],
    Line[{{2.000000, 1.500000, 1.500000},{2.194168, 1.655334, 1.525889}}],
    Line[{{2.177645, 1.596379, 1.520711},{2.194168, 1.655334, 1.525889},{
      2.133024, 1.652156, 1.520711}}],
    Line[{{2.158222, 1.626578, 1.485189},{2.194168, 1.655334, 1.525889},{
      2.152446, 1.621957, 1.556234}}],
    Line[{{2.177645, 1.596379, 1.520711},{2.158222, 1.626578, 1.485189},{
      2.133024, 1.652156, 1.520711},{2.152446, 1.621957, 1.556234},{
      2.177645, 1.596379, 1.520711}}],
    Line[{{2.000000, 1.500000, 2.000000},{2.194625, 1.655700, 2.019463}}],
    Line[{{2.178010, 1.596672, 2.015570},{2.194625, 1.655700, 2.019463},{
      2.133389, 1.652448, 2.015570}}],
    Line[{{2.157871, 1.626297, 1.979964},{2.194625, 1.655700, 2.019463},{
      2.153529, 1.622823, 2.051176}}],
    Line[{{2.178010, 1.596672, 2.015570},{2.157871, 1.626297, 1.979964},{
      2.133389, 1.652448, 2.015570},{2.153529, 1.622823, 2.051176},{
      2.178010, 1.596672, 2.015570}}],
    Line[{{2.000000, 2.000000, 0.500000},{2.200446, 2.133631, 0.566815}}],
    Line[{{2.180167, 2.077188, 0.553452},{2.200446, 2.133631, 0.566815},{
      2.140546, 2.136621, 0.553452}}],
    Line[{{2.168299, 2.112199, 0.519037},{2.200446, 2.133631, 0.566815},{
      2.152415, 2.101610, 0.587867}}],
    Line[{{2.180167, 2.077188, 0.553452},{2.168299, 2.112199, 0.519037},{
      2.140546, 2.136621, 0.553452},{2.152415, 2.101610, 0.587867},{
      2.180167, 2.077188, 0.553452}}],
    Line[{{2.000000, 2.000000, 1.000000},{2.206041, 2.137361, 1.034340}}],
    Line[{{2.184644, 2.080172, 1.027472},{2.206041, 2.137361, 1.034340},{
      2.145022, 2.139605, 1.027472}}],
    Line[{{2.168915, 2.112610, 0.992096},{2.206041, 2.137361, 1.034340},{
      2.160751, 2.107167, 1.062848}}],
    Line[{{2.184644, 2.080172, 1.027472},{2.168915, 2.112610, 0.992096},{
      2.145022, 2.139605, 1.027472},{2.160751, 2.107167, 1.062848},{
      2.184644, 2.080172, 1.027472}}],
    Line[{{2.000000, 2.000000, 1.500000},{2.207129, 2.138086, 1.523014}}],
    Line[{{2.185514, 2.080753, 1.518412},{2.207129, 2.138086, 1.523014},{
      2.145893, 2.140185, 1.518412}}],
    Line[{{2.168439, 2.112293, 1.482849},{2.207129, 2.138086, 1.523014},{
      2.162968, 2.108645, 1.553974}}],
    Line[{{2.185514, 2.080753, 1.518412},{2.168439, 2.112293, 1.482849},{
      2.145893, 2.140185, 1.518412},{2.162968, 2.108645, 1.553974},{
      2.185514, 2.080753, 1.518412}}],
    Line[{{2.000000, 2.000000, 2.000000},{2.207514, 2.138343, 2.017293}}],
    Line[{{2.185822, 2.080958, 2.013834},{2.207514, 2.138343, 2.017293},{
      2.146201, 2.140390, 2.013834}}],
    Line[{{2.168067, 2.112045, 1.978206},{2.207514, 2.138343, 2.017293},{
      2.163956, 2.109304, 2.049463}}],
    Line[{{2.185822, 2.080958, 2.013834},{2.168067, 2.112045, 1.978206},{
      2.146201, 2.140390, 2.013834},{2.163956, 2.109304, 2.049463},{
      2.185822, 2.080958, 2.013834}}],
    Line[{{0.250000, 0.000000, 0.707107},{0.263696, 0.027027, 0.716599}}],
    Line[{{0.263696, 0.027027, 0.716599},{0.277757, 0.054054, 0.725966}}],
    Line[{{0.277757, 0.054054, 0.725966},{0.292184, 0.081081, 0.735215}}],
    Line[{{0.292184, 0.081081, 0.735215},{0.306976, 0.108108, 0.744348}}],
    Line[{{0.306976, 0.108108, 0.744348},{0.322133, 0.135135, 0.753371}}],
    Line[{{0.322133, 0.135135, 0.753371},{0.337655, 0.162162, 0.762287}}],
    Line[{{0.337655, 0.162162, 0.762287},{0.353543, 0.189189, 0.771100}}],
    Line[{{0.353543, 0.189189, 0.771100},{0.369795, 0.216216, 0.779813}}],
    Line[{{0.369795, 0.216216, 0.779813},{0.386413, 0.243243, 0.788430}}],
    Line[{{0.386413, 0.243243, 0.788430},{0.403397, 0.270270, 0.796954}}],
    Line[{{0.403397, 0.270270, 0.796954},{0.420745, 0.297297, 0.805387}}],
    Line[{{0.420745, 0.297297, 0.805387},{0.438459, 0.324324, 0.813733}}],
    Line[{{0.438459, 0.324324, 0.813733},{0.456538, 0.351351, 0.821995}}],
    Line[{{0.456538, 0.351351, 0.821995},{0.474982, 0.378378, 0.830174}}],
    Line[{{0.474982, 0.378378, 0.830174},{0.493791, 0.405405, 0.838274}}],
    Line[{{0.493791, 0.405405, 0.838274},{0.512966, 0.432432, 0.846296}}],
    Line[{{0.512966, 0.432432, 0.846296},{0.532505, 0.459459, 0.854242}}],
    Line[{{0.532505, 0.459459, 0.854242},{0.552411, 0.486486, 0.862116}}],
    Line[{{0.552411, 0.486486, 0.862116},{0.572681, 0.513514, 0.869918}}],
    Line[{{0.572681, 0.513514, 0.869918},{0.593316, 0.540541, 0.877650}}],
    Line[{{0.593316, 0.540541, 0.877650},{0.614317, 0.567568, 0.885316}}],
    Line[{{0.614317, 0.567568, 0.885316},{0.635683, 0.594595, 0.892915}}],
    Line[{{0.635683, 0.594595, 0.892915},{0.657414, 0.621622, 0.900450}}],
    Line[{{0.657414, 0.621622, 0.900450},{0.679511, 0.648649, 0.907923}}],
    Line[{{0.679511, 0.648649, 0.907923},{0.701972, 0.675676, 0.915335}}],
    Line[{{0.701972, 0.675676, 0.915335},{0.724799, 0.702703, 0.922687}}],
    Line[{{0.724799, 0.702703, 0.922687},{0.747991, 0.729730, 0.929981}}],
    Line[{{0.747991, 0.729730, 0.929981},{0.771549, 0.756757, 0.937218}}],
    Line[{{0.771549, 0.756757, 0.937218},{0.795471, 0.783784, 0.944400}}],
    Line[{{0.795471, 0.783784, 0.944400},{0.819759, 0.810811, 0.951528}}],
    Line[{{0.819759, 0.810811, 0.951528},{0.844412, 0.837838, 0.958603}}],
    Line[{{0.844412, 0.837838, 0.958603},{0.869430, 0.864865, 0.965625}}],
    Line[{{0.869430, 0.864865, 0.965625},{0.894814, 0.891892, 0.972598}}],
    Line[{{0.894814, 0.891892, 0.972598},{0.920562, 0.918919, 0.979520}}],
    Line[{{0.920562, 0.918919, 0.979520},{0.946676, 0.945946, 0.986394}}],
    Line[{{0.946676, 0.945946, 0.986394},{0.973156, 0.972973, 0.993220}}],
    Line[{{0.973156, 0.972973, 0.993220},{1.000000, 1.000000, 1.000000}}],
    Line[{{1.000000, 1.000000, 1.000000},{1.027210, 1.027027, 1.006734}}],
    Line[{{1.027210, 1.027027, 1.006734},{1.054785, 1.054054, 1.013423}}],
    Line[{{1.054785, 1.054054, 1.013423},{1.082725, 1.081081, 1.020069}}],
    Line[{{1.082725, 1.081081, 1.020069},{1.111030, 1.108108, 1.026671}}],
    Line[{{1.111030, 1.108108, 1.026671},{1.139701, 1.135135, 1.033232}}],
    Line[{{1.139701, 1.135135, 1.033232},{1.168736, 1.162162, 1.039750}}],
    Line[{{1.168736, 1.162162, 1.039750},{1.198137, 1.189189, 1.046229}}],
    Line[{{1.198137, 1.189189, 1.046229},{1.227904, 1.216216, 1.052667}}],
    Line[{{1.227904, 1.216216, 1.052667},{1.258035, 1.243243, 1.059066}}],
    Line[{{1.258035, 1.243243, 1.059066},{1.288532, 1.270270, 1.065427}}],
    Line[{{1.288532, 1.270270, 1.065427},{1.319394, 1.297297, 1.071750}}],
    Line[{{1.319394, 1.297297, 1.071750},{1.350621, 1.324324, 1.078036}}],
    Line[{{1.350621, 1.324324, 1.078036},{1.382213, 1.351351, 1.084286}}],
    Line[{{1.382213, 1.351351, 1.084286},{1.414171, 1.378378, 1.090500}}],
    Line[{{1.414171, 1.378378, 1.090500},{1.446494, 1.405405, 1.096678}}],
    Line[{{1.446494, 1.405405, 1.096678},{1.479182, 1.432432, 1.102822}}],
    Line[{{1.479182, 1.432432, 1.102822},{1.512235, 1.459459, 1.108932}}],
    Line[{{1.512235, 1.459459, 1.108932},{1.545654, 1.486486, 1.115008}}],
    Line[{{1.545654, 1.486486, 1.115008},{1.579437, 1.513514, 1.121052}}],
    Line[{{1.579437, 1.513514, 1.121052},{1.613587, 1.540541, 1.127063}}],
    Line[{{1.613587, 1.540541, 1.127063},{1.648101, 1.567568, 1.133042}}],
    Line[{{1.648101, 1.567568, 1.133042},{1.682980, 1.594595, 1.138990}}],
    Line[{{1.682980, 1.594595, 1.138990},{1.718225, 1.621622, 1.144907}}],
    Line[{{1.718225, 1.621622, 1.144907},{1.753835, 1.648649, 1.150793}}],
    Line[{{1.753835, 1.648649, 1.150793},{1.789810, 1.675676, 1.156649}}],
    Line[{{1.789810, 1.675676, 1.156649},{1.826150, 1.702703, 1.162476}}],
    Line[{{1.826150, 1.702703, 1.162476},{1.862856, 1.729730, 1.168274}}],
    Line[{{1.862856, 1.729730, 1.168274},{1.899927, 1.756757, 1.174044}}],
    Line[{{1.899927, 1.756757, 1.174044},{1.937363, 1.783784, 1.179785}}],
    Line[{{1.937363, 1.783784, 1.179785},{1.975164, 1.810811, 1.185498}}],
    Line[{{1.975164, 1.810811, 1.185498},{2.013331, 1.837838, 1.191184}}],
    Line[{{2.013331, 1.837838, 1.191184},{2.051863, 1.864865, 1.196843}}],
    Line[{{2.051863, 1.864865, 1.196843},{2.090760, 1.891892, 1.202475}}],
    Line[{{2.090760, 1.891892, 1.202475},{2.130022, 1.918919, 1.208081}}],
    Line[{{2.130022, 1.918919, 1.208081},{2.169649, 1.945946, 1.213661}}],
    Line[{{2.169649, 1.945946, 1.213661},{2.209642, 1.972973, 1.219216}}],
    Line[{{2.209642, 1.972973, 1.219216},{2.250000, 2.000000, 1.224745}}],
    Line[{{0.614317, 0.567568, 0.885316},{0.635662, 0.594568, 0.892907}}],
    Line[{{1.111030, 1.108108, 1.026671},{1.139672, 1.135108, 1.033225}}],
    Line[{{1.648101, 1.567568, 1.133042},{1.682945, 1.594568, 1.138984}}],
    Line[{{2.209642, 1.972973, 1.219216},{2.249960, 1.999973, 1.224739}}],
    Polygon[{{0.635683, 0.594595, 0.892915},{0.516555, 0.326625, 0.830250},{
      0.511369, 0.342463, 0.788504}}],
    Polygon[{{0.635683, 0.594595, 0.892915},{0.511369, 0.342463, 0.788504},{
      0.486370, 0.369480, 0.762703}}],
    Polygon[{{0.635683, 0.594595, 0.892915},{0.486370, 0.369480, 0.762703},{
      0.451108, 0.397356, 0.762703}}],
    Polygon[{{0.635683, 0.594595, 0.892915},{0.451108, 0.397356, 0.762703},{
      0.419051, 0.415444, 0.788504}}],
    Polygon[{{0.635683, 0.594595, 0.892915},{0.419051, 0.415444, 0.788504},{
      0.402444, 0.416834, 0.830250}}],
    Polygon[{{0.635683, 0.594595, 0.892915},{0.402444, 0.416834, 0.830250},{
      0.407630, 0.400997, 0.871997}}],
    Polygon[{{0.635683, 0.594595, 0.892915},{0.407630, 0.400997, 0.871997},{
      0.432628, 0.373980, 0.897798}}],
    Polygon[{{0.635683, 0.594595, 0.892915},{0.432628, 0.373980, 0.897798},{
      0.467890, 0.346103, 0.897798}}],
    Polygon[{{0.635683, 0.594595, 0.892915},{0.467890, 0.346103, 0.897798},{
      0.499948, 0.328016, 0.871997}}],
    Polygon[{{0.635683, 0.594595, 0.892915},{0.499948, 0.328016, 0.871997},{
      0.516555, 0.326625, 0.830250}}],
    Polygon[{{1.139701, 1.135135, 1.033232},{0.880994, 0.991211, 0.985451},{
      0.885413, 0.976288, 1.027621}}],
    Polygon[{{1.139701, 1.135135, 1.033232},{0.885413, 0.976288, 1.027621},{
      0.907200, 0.946850, 1.053683}}],
    Polygon[{{1.139701, 1.135135, 1.033232},{0.907200, 0.946850, 1.053683},{
      0.938033, 0.914142, 1.053683}}],
    Polygon[{{1.139701, 1.135135, 1.033232},{0.938033, 0.914142, 1.053683},{
      0.966135, 0.890657, 1.027621}}],
    Polygon[{{1.139701, 1.135135, 1.033232},{0.966135, 0.890657, 1.027621},{
      0.980772, 0.885365, 0.985451}}],
    Polygon[{{1.139701, 1.135135, 1.033232},{0.980772, 0.885365, 0.985451},{
      0.976353, 0.900289, 0.943281}}],
    Polygon[{{1.139701, 1.135135, 1.033232},{0.976353, 0.900289, 0.943281},{
      0.954566, 0.929727, 0.917219}}],
    Polygon[{{1.139701, 1.135135, 1.033232},{0.954566, 0.929727, 0.917219},{
      0.923733, 0.962435, 0.917219}}],
    Polygon[{{1.139701, 1.135135, 1.033232},{0.923733, 0.962435, 0.917219},{
      0.895631, 0.985920, 0.943281}}],
    Polygon[{{1.139701, 1.135135, 1.033232},{0.895631, 0.985920, 0.943281},{
      0.880994, 0.991211, 0.985451}}],
    Polygon[{{1.682980, 1.594595, 1.138990},{1.410529, 1.475490, 1.100127},{
      1.414522, 1.461013, 1.142494}}],
    Polygon[{{1.682980, 1.594595, 1.138990},{1.414522, 1.461013, 1.142494},{
      1.434007, 1.430105, 1.168678}}],
    Polygon[{{1.682980, 1.594595, 1.138990},{1.434007, 1.430105, 1.168678},{
      1.461539, 1.394574, 1.168678}}],
    Polygon[{{1.682980, 1.594595, 1.138990},{1.461539, 1.394574, 1.168678},{
      1.486603, 1.367990, 1.142494}}],
    Polygon[{{1.682980, 1.594595, 1.138990},{1.486603, 1.367990, 1.142494},{
      1.499625, 1.360508, 1.100127}}],
    Polygon[{{1.682980, 1.594595, 1.138990},{1.499625, 1.360508, 1.100127},{
      1.495631, 1.374986, 1.057760}}],
    Polygon[{{1.682980, 1.594595, 1.138990},{1.495631, 1.374986, 1.057760},{
      1.476147, 1.405893, 1.031576}}],
    Polygon[{{1.682980, 1.594595, 1.138990},{1.476147, 1.405893, 1.031576},{
      1.448615, 1.441425, 1.031576}}],
    Polygon[{{1.682980, 1.594595, 1.138990},{1.448615, 1.441425, 1.031576},{
      1.423551, 1.468008, 1.057760}}],
    Polygon[{{1.682980, 1.594595, 1.138990},{1.423551, 1.468008, 1.057760},{
      1.410529, 1.475490, 1.100127}}],
    Polygon[{{2.250000, 2.000000, 1.224745},{1.969356, 1.899591, 1.191839},{
      1.973067, 1.885359, 1.234315}}],
    Polygon[{{2.250000, 2.000000, 1.224745},{1.973067, 1.885359, 1.234315},{
      1.990819, 1.853480, 1.260566}}],
    Polygon[{{2.250000, 2.000000, 1.224745},{1.990819, 1.853480, 1.260566},{
      2.015831, 1.816131, 1.260566}}],
    Polygon[{{2.250000, 2.000000, 1.224745},{2.015831, 1.816131, 1.260566},{
      2.038549, 1.787579, 1.234315}}],
    Polygon[{{2.250000, 2.000000, 1.224745},{2.038549, 1.787579, 1.234315},{
      2.050296, 1.778728, 1.191839}}],
    Polygon[{{2.250000, 2.000000, 1.224745},{2.050296, 1.778728, 1.191839},{
      2.046584, 1.792960, 1.149363}}],
    Polygon[{{2.250000, 2.000000, 1.224745},{2.046584, 1.792960, 1.149363},{
      2.028832, 1.824838, 1.123112}}],
    Polygon[{{2.250000, 2.000000, 1.224745},{2.028832, 1.824838, 1.123112},{
      2.003820, 1.862187, 1.123112}}],
    Polygon[{{2.250000, 2.000000, 1.224745},{2.003820, 1.862187, 1.123112},{
      1.981102, 1.890740, 1.149363}}],
    Polygon[{{2.250000, 2.000000, 1.224745},{1.981102, 1.890740, 1.149363},{
      1.969356, 1.899591, 1.191839}}]},
    Boxed -> True,
    Lighting -> True,
    ViewPoint -> {3.761313, 0.613860, 1.119367}
  ]
], "Graphics",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00Z03ooom800000300oooo001P
0?ooodP00000AP3oool200000300oooo000Y0?ooocL00000SP3oool200000300oooo000Y0?ooo`03
0000003oool0oooo0<80oooo0P00000`0?ooo`00:@3oool200000<80oooo00<000000?ooo`000000
<03oool002T0oooo00<000000?ooo`000000`@3oool00`000000oooo0000000`0?ooo`00:@3oool0
0`000000oooo000000300?ooo`040000003oool0oooo00000300oooo000Y0?ooo`040000003oool0
oooo00000;l0oooo00@000000?ooo`3oool00000<03oool002P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`2l0?ooo`040000003oool0oooo00000300oooo000X0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0^`3oool01@000000oooo0?ooo`3oool000000300oooo
000X0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0^P3oool01@000000oooo0?oo
o`3oool000000300oooo000X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0^03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo000X0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02h0oooo000X0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0[P3oool20000
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`00:03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08D0oooo0P00000U0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0^0?ooo`00:03oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo08<0oooo00<000000?ooo`0000007@3oool3000000@0
oooo1P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;P3oool002P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00L0oooo
0P00000L0?ooo`H000000P3oool01@000000oooo0?ooo`3oool0000001l0oooo2P0000030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0;@3oool002P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0Y0?ooo`8000002P3oool00`000000oooo0?ooo`0J0?ooo`D00000
0`3oool010000000oooo00000000000Q0?ooo`P000008`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;@3oool002P0oooo00<000000?ooo`3o
ool02@3oool010000000oooo0?ooo`3oool3000002H0oooo100000040?ooo`<000008@3oool70000
02@0oooo00@000000?ooo`00000000009@3oool2000000D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0]0?ooo`00:03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo0`0000060?ooo`030000003oool0oooo01h0oooo100000020?ooo`8000008`3oool00`00
0000oooo0?ooo`02000002<0oooo0`00000V0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0]0?ooo`00:03oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00H0oooo0P0000030?ooo`<000008P3oool5000002<0oooo00<000000?ooo`00
0000E03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02d0oooo000X0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool300000080oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`02000002<0oooo0P00001D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0;@3oool002P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`080?ooo`D000008P3oool3000007X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0]0?ooo`00:03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`0000000P00000R0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0]0?ooo`00:03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00L0oooo0`00002P0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;@3oool002P0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2Q0?ooo`8000001P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo02d0oooo000X0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0]0?ooo`00:03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool06@3oool2000000H0oooo
00<000000?ooo`0000006P3oool=000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0]0?ooo`00:03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02H0oooo0P00
000S0?ooo`D00000103oool00`000000oooo0000000L0?ooo`X000008@3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;@3oool002P0oooo00<0
00000?ooo`3oool04@3oool010000000oooo0?ooo`3oool2000002@0oooo0`0000050?ooo`800000
7P3oool5000000030?ooo`000000oooo0200oooo00<000000?ooo`3oool00P00000Q0?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0]0?ooo`00:03o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo0`0000060?ooo`030000003o
ool0oooo01/0oooo1@0000000`3oool000000000000P0?ooo`030000003oool00000008000008@3o
ool3000002<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02d0oooo000X0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool2
000000<0oooo0P00000P0?ooo`D00000803oool010000000oooo00000000000R0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0]0?ooo`00:03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0`0000000`3oool000000000000P
0?ooo`040000003oool0000000000240oooo0P00001>0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0;@3oool002P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`08
0?ooo`@00000803oool300000780oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0]
0?ooo`00:03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo1000002D0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;@3oool002P0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`060?ooo`800000S`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0;@3oool002P0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02d0oooo000X0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`060?ooo`800000603o
ool4000000@0oooo00<000000?ooo`000000603oool<000000<0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0]0?ooo`009`3oool00`000000oooo0?ooo`0H0?ooo`050000003oool0
oooo0?ooo`0000008@3oool300000240oooo100000030?ooo`030000003oool0000001`0oooo1`00
000O0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0]0?ooo`009`3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo0?ooo`<00000
8@3oool3000000<0oooo0`00000L0?ooo`L000007P3oool010000000oooo0?ooo`00000P0?ooo`80
0000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02d0oooo000W0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0103oool2000000@0oooo0P00000L0?ooo`@00000
00<0oooo0000003oool07P3oool010000000oooo00000000000O0?ooo`8000009`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo02d0oooo000W0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool01@3oool4000000030?ooo`000000oooo01d0oooo1@00000N0?ooo`<00000
803oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
;@3oool002L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`070?ooo`@000007P3o
ool4000001h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo02d0oooo000W0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01`3oool0
10000000oooo00000000000N0?ooo`800000J`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo02d0oooo000W0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool3
000008D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo02d0oooo000W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`0F0?ooo`800000103oool2000000030?ooo`000000oooo00<0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0]0?ooo`009`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool07P3oool2000000H0oooo0P00000G0?ooo`D0
000000D0oooo000000000000oooo0000000I0?ooo`P000000`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo02d0oooo000W0?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3o
ool0oooo0P00000O0?ooo`<000001@3oool2000001P0oooo10000000103oool000000?ooo`00000L
0?ooo`H00000703oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0;@3oool002L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`02
0?ooo`<000001@3oool00`000000oooo0?ooo`0G0?ooo`<0000000@0oooo0000003oool00000703o
ool5000001`0oooo00@000000?ooo`3oool000007P3oool2000000@0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0/0?ooo`009`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00@0oooo0P0000020?ooo`800000703oool5000001`0oooo00@000000?ooo`0000000000
7@3oool2000002@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0/0?ooo`009`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00H0oooo1@00000L0?ooo`040000003o
ool00000000001`0ooooB000000E0?ooo`030000003oool0oooo02`0oooo000W0?ooo`030000003o
ool0oooo0240ooooB`0000150?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0/0?ooo`009`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00H0oooo1000001R0?ooo`800000603oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0/0?ooo`009`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0603oool20000
00H0oooo00L000000?ooo`3oool0oooo0000003oool000000100oooo1@0000020?ooo`030000003o
ool0000000D0oooo00<000000?ooo`3oool00`3oool5000000/0oooo00<000000?ooo`3oool0;03o
ool002L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo0P0000030?ooo`<000007@3oool3000000040?ooo`000000oooo0?ooo`8000005`3o
ool6000000030?ooo`000000oooo00D00000503oool6000000@0oooo2`00000;0?ooo`030000003o
ool0oooo02`0oooo000W0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0103oool2
000001D0oooo00<000000?ooo`0000001P3oool3000000<0oooo0P00000=0?ooo`8000001`3oool6
000000030?ooo`000000oooo01H0oooo300000000`3oool000000?ooo`0E0?ooo`030000003oool0
00000080oooo100000050?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool0;03o
ool002L0oooo00<000000?ooo`3oool03@3oool2000000X0oooo0P0000060?ooo`030000003oool0
oooo00H0oooo0`0000030?ooo`8000000`3oool<000000030?ooo`000000oooo00L0oooo0`000000
0`3oool000000?ooo`0>0?oooa0000006`3oool300000080oooo00<000000?ooo`0000005`3oool2
000000H0oooo00<000000?ooo`3oool0103oool2000000d0oooo00<000000?ooo`3oool0;03oool0
02L0oooo00<000000?ooo`3oool03`3oool700000080oooo00@000000?ooo`00000000001@3oool0
0`000000oooo0?ooo`090?ooo`<0000000<0oooo0000003oool02`3oool6000000T0oooo1000000F
0?ooo`070000003oool000000?ooo`000000oooo0000000L0?ooo`030000003oool0oooo0080oooo
0P00000P0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;03oool002L0oooo00<0
00000?ooo`3oool05P3oool7000000@0oooo00<000000?ooo`3oool02`3oool4000000`0oooo00@0
00000?ooo`00000000002P3oool3000001L0oooo0P0000030?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0/0?ooo`009`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0000000800000103oool00`000000oooo0?ooo`0;0?ooo`@00000303o
ool2000000`0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo02`0oooo000W0?ooo`030000003oool0oooo01P0oooo0`0000060?ooo`030000003oool0
oooo00/0oooo0P0000200?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?oo
o`0/0?ooo`009`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<00000403oool0
0`000000oooo0?ooo`0/0?ooo`009`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
04D0oooo0P00000S0?ooo`030000003oool000000200oooo00<000000?ooo`0000000`00000@0?oo
o`030000003oool0oooo02`0oooo000W0?ooo`030000003oool0oooo0240oooo00@000000?ooo`3o
ool000007`3oool200000280oooo00@000000?ooo`00000000008@3oool5000001T0oooo3@00000?
0?ooo`030000003oool0oooo02`0oooo000W0?ooo`030000003oool0oooo0200oooo0P0000030?oo
o`@000003`3oool5000000H0oooo00@000000?ooo`0000000000603oool=000001T0oooo2@000002
0?ooo`030000003oool0oooo00d0oooo0`00000>0?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0/0?ooo`009`3oool00`000000oooo0?ooo`0D0?oo
o`H000001@3oool00`000000oooo000000070?ooo`D000002@3oool30000000303<c<`0000000000
00/00000803oool010000000oooo0?ooo`00000R0?ooo`8000003`3oool00`000000<c<c03<c<`05
000000X0oooo00<000000?ooo`3oool00P00000A0?ooo`030000003oool0oooo02`0oooo000W0?oo
o`030000003oool0oooo01X0oooo2@00000;0?ooo`D00000103oool00`000000TUPc099H<`030000
000403<c<`000000000000000080oooo00<000000?ooo`3oool00P00000P0?ooo`030000003oool0
000002<0oooo00<000000?ooo`3oool03@3oool4000000@0<c<c100000070?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0;03oool002L0oooo00<000000?ooo`3oool07`3oool50000
00l0oooo1@000005099H<`L0000000<0oooo0000003oool0503oool5000000T0oooo00<000000?oo
o`3oool04@3oool5000001/0oooo00<0000007Dc<`1e<c<00P1e<c<<000000<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0/0?ooo`009P3oool00`000000oooo0?ooo`0P0?ooo`04
0000003oool00000000001<0oooo00<000000=^8<`0000001P000002099H<`@000005@3oool20000
00<0<c<c1000000I0?ooo`8000000`0c<c<4000001P0oooo00<0000007Dc<`1e<c<02P1e<c<80000
01D0oooo00<000000?ooo`3oool0;03oool002H0oooo00<000000?ooo`3oool0803oool3000001@0
oooo00<000000=^8<`3KR3<01P3KR3<8000001<0oooo00<0000008Hn<`00000010000000100c<c<0
000000000000000F0?ooo`030000001l<c<0O3<c00D0000000<0<c<c0000000000000P0000050?oo
o`8000003P3ooolF000001@0oooo00<000000?ooo`3oool0;03oool002H0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0B0?oooaX000002@3oool00`000000QShc08Hn<`0408Hn<`L0
00000`3oool2000000l0oooo00<0000007`c<`1l<c<01@1l<c<8000000030?ooo`000000oooo0080
00002@3oool5000000X0`e/c3000000C0?ooo`030000003oool0oooo02`0oooo000V0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool04`3oool00`000000njMl0?^WO0030?^WO0L00000
103oool2000000H0oooo500000000`26?S<000000000000300000080oooo00<000000?ooo`3oool0
2`3ooolO000000@0oooo00<000000<=K<`33Fc<01033Fc<400000080jII^2P00000C0?ooo`030000
003oool0oooo02`0oooo000V0?ooo`030000003oool0oooo01`0oooo0P0000040?ooo`030000003o
ool0oooo0080oooo0P00000@0?ooo``000000`3oool010000000oooo00000000000>0?ooo`030000
003ALc<0dG<c00P0dG<c5`00000;0<UU<`L000000P3oool00`000000oooo0?ooo`0;0?ooo`030000
0033Fc<0`e/c00@000000`3YUVh4000000D0oooo0`00000D0?ooo`030000003oool0oooo02`0oooo
000V0?ooo`030000003oool0oooo01h0oooo1`0000000`3oool000000?ooo`0200000100oooo0`00
00080?ooo`L000003P3oool00`000000dG<c0=5c<`020=5c<``000000P3oool00`000000oooo0?oo
o`0<0?ooo`0300000039IC<0bFDc00<0bFDc1@000000103/Vg4000000000000000030?ooo`800000
3P3oool3000000D0jII^100000080?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
;03oool002H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`06000001d0oooo00@0
00000?ooo`00000000003P3oool5000000@0lZ1f100000040?ooo`8000003`3oool6000000<0k9]a
100000050?ooo`030000003oool0oooo00h0oooo00@000000>VFKP3YUVh0jII^0`0000000`3Za=T0
00000?ooo`090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;03oool002H0oooo
00<000000?ooo`3oool08P3oool01P000000oooo0?ooo`3oool000000?ooo`8000007P3oool20000
0140oooo00@000000?:PMP3bX7H0lZ1f1P00000G0?ooo`030000003/Vg40k9]a00<0k9]a1@00000I
0?ooo`<000000P3Za=T2000000P0oooo00@000000?ooo`3oool000005@3oool00`000000oooo0?oo
o`0/0?ooo`009P3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo0?ooo`800000=03o
ool6000000/0oooo00<000000?ooo`3oool03@3oool00`000000k9]a0>bKL@02000000030>2of000
0000000000P0oooo0P00000C0?ooo`<000002@3oool3000000030?ooo`000000oooo01@0oooo00<0
00000?ooo`3oool0;03oool002H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo00/0oooo0P00000@0?ooo`D000002@3oool010000000oooo00000000
000K0?ooo`H000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02`0oooo000V
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L
0?ooo`8000005P3oool6000000050?ooo`000000oooo0?ooo`0000005P3oool;000001H0oooo1@00
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0/0?ooo`009P3oool00`000000oooo0?ooo`0R0?ooo`D000001@3oool3000001@0oooo3000
000K0?ooo`H00000703oool00`000000oooo0000000O0?ooo`8000000`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo02`0oooo000V0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool00P3oool8000001`0oooo00@000000?ooo`00000000007@3oool3000001h0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02`0oooo000V
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01P3oool00`000000oooo00000002
000001/0oooo00<000000?ooo`0000007P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0[0?ooo`009P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo0P00000N0?ooo`030000003oool0oooo
03d0oooo0P00000M0?ooo`<000001@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
02/0oooo000V0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0n0?ooo`800000703oool010000000oooo00000000000H0?ooo`L000001@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo02/0oooo000V0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?ooo`8000001`3oool2000001@0
oooo2@0000000`3oool000000?ooo`0D0?ooo`X000005@3oool3000000<0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02/0oooo000V0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool00`3oool5000000<0oooo00<000000?ooo`00
00005@3oool:000001X0oooo1000000K0?ooo`030000003oool0000001d0oooo0P0000060?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0:`3oool002H0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`080?ooo`L000006P3oool010000000oooo00000000000K0?ooo`80
00007@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0:`3oool002H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0;0?ooo`040000
003oool00000000001X0oooo0`00000L0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0[0?ooo`009P3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00/0oooo0`0000200?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
:`3oool002H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0:`3oool002H0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:`3oool0
02H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0[0?ooo`009P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0:`3oool002H0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool09@3oool3000001l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`02000000/0oooo00<000000?ooo`3oool0:`3oool002H0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0L0?ooo`<000009@3oool00`000000oooo0000000U0?ooo`030000003o
ool0oooo008000007P3oool010000000oooo0?ooo`3oool8000000X0oooo00<000000?ooo`3oool0
:`3oool002H0oooo00<000000?ooo`3oool06@3oool2000000H0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0000000K0?ooo`8000001`3oool5000001/0oooo3P00000K0?ooo`L000000P3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool0:`3oool002H0oooo00<0
00000?ooo`3oool0303oool6000000H0oooo00@000000?ooo`00000000001@3oool00`000000oooo
0?ooo`0A0?ooo`l00000703oool<000002@0oooo00@000000?ooo`3oool000007`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0:`3oool002H0oooo
00<000000?ooo`3oool04P3oool;000000@0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`02000002@0oooo00<000000?ooo`0000009P3oool200000200oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02/0oooo000U0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`0000009@3oool2000002H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0200000140oooo00<000000?ooo`3oool0:`3oool002D0oooo00<000000?ooo`3oool06@3oool0
10000000oooo0000000000050?ooo`030000003oool0oooo01`0oooo0P00000X0?ooo`800000903o
ool200000240oooo00@000000?ooo`000000oooo0P00000@0?ooo`030000003oool0oooo02/0oooo
000U0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0Q0?ooo`8000008P3oool010000000oooo00000000000R0?ooo`040000003oool0000000000200
oooo1`00000?0?ooo`030000003oool0oooo02/0oooo000U0?ooo`030000003oool0oooo0240oooo
0P00000R0?ooo`040000003oool00000000001P0oooo1P0000020?ooo`D000006@3oool>000001T0
oooo2@0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0:`3oool002D0oooo
00<000000?ooo`3oool05@3oool7000000@0oooo00@000000?ooo`00000000005`3oool>000001h0
oooo2000000Q0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`000000oooo0000000A
0?ooo`030000003oool0oooo02/0oooo000U0?ooo`030000003oool0oooo01`0oooo2@00000P0?oo
o`040000003oool0oooo00000240oooo00<000000?ooo`0000008`3oool00`000000oooo0000000Q
0?ooo`030000003oool0oooo008000004@3oool00`000000oooo0?ooo`0[0?ooo`009@3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0000000800000803oool00`000000oooo0000000S0?oo
o`030000003oool000000280oooo0P00000Q0?ooo`8000005@3oool00`000000oooo0?ooo`0[0?oo
o`009@3oool00`000000oooo0?ooo`0Q0?ooo`8000008`3oool01@000000oooo0?ooo`3oool00000
0240oooo0P00000Q0?ooo`030000003oool000000200oooo00@000000?ooo`0000000000503oool0
0`000000oooo0?ooo`0[0?ooo`009@3oool00`000000oooo0?ooo`0Q0?ooo`8000001@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0000001l0oooo00@000000?ooo`3oool00000603oool<
000001P0oooo3000000C0?ooo`030000003oool0oooo02/0oooo000U0?ooo`030000003oool0oooo
01`0oooo1`0000040?ooo`<000005P3oool=000001H0oooo3@00000N0?ooo`030000003oool0oooo
00800000803oool3000001@0oooo00<000000?ooo`3oool0:`3oool002D0oooo00<000000?ooo`3o
ool08P3oool9000001d0oooo00<000000?ooo`3oool00P00000O0?ooo`030000003oool000000200
oooo0`00000N0?ooo`030000003oool0oooo008000005@3oool00`000000oooo0?ooo`0[0?ooo`00
9@3oool00`000000oooo0?ooo`0R0?ooo`050000003oool0oooo0?ooo`0000000P3oool2000001h0
oooo0`00000P0?ooo`<000007`3oool3000001l0oooo0P0000020?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0:`3oool002D0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0I0?ooo`8000000P3oool2000001h0oooo
0`00000N0?ooo`030000003oool0000001h0oooo100000000`3oool000000?ooo`0D0?ooo`030000
003oool0oooo02/0oooo000U0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`8000005@3oool3000000D0oooo00@000000?ooo`0000000000
5@3oool<000001D0oooo3000000F0?ooo`P000000P3oool00`000000oooo0000000E0?ooo`030000
003oool0oooo02/0oooo000U0?ooo`030000003oool0oooo0280oooo2`0000000`3oool000000000
000G0?ooo`T00000703oool010000000oooo0?ooo`00000N0?ooo`030000003oool0000001l0oooo
0P0000020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:`3oool002D0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`D000006`3oool010000000oooo0000
0000000M0?ooo`<000007P3oool2000001d0oooo0P0000000`3oool000000?ooo`020?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0:P3oool002D0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`070?ooo`<000000`3oool00`000000oooo0?ooo`0H0?ooo`040000003o
ool0oooo000001d0oooo0`00000L0?ooo`030000003oool0000001`0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02X0oooo000U0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo0?ooo`<000004`3oool4000000@0oooo00<000000?ooo`000000503oool;000001D0
oooo2`00000E0?ooo`X00000103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02X0
oooo000U0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0103oool9000000030?oo
o`000000oooo01H0oooo2000000J0?ooo`040000003oool0oooo000001`0oooo00<000000?ooo`00
00007@3oool2000000D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0Z0?ooo`00
9@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00`0oooo1000000J0?ooo`030000
003oool0000001`0oooo0P00000M0?ooo`8000007P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0:P3oool002D0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0<0?ooo`<00000703oool00`000000oooo0?ooo`1Q0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0:P3oool002D0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:P3oool0
02D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0:P3oool002D0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:P3oool002D0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0:P3oool002D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:P3oool002D0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0:P3oool002D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:P3oool002D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0:P3oool002D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0:P3oool002@0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:P3o
ool002@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0:P3oool002@0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:P3oool002@0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0:P3oool002@0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:P3oool002@0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0Z0?ooo`00903oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool09P3oool200000200oooo00<00000
0?ooo`3oool0103oool00`000000oooo0000000<0?ooo`030000003oool0oooo02X0oooo000T0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0L0?oo
o`8000009P3oool00`000000oooo0000000V0?ooo`030000003oool000000200oooo00<000000?oo
o`3oool0103oool010000000oooo00000000000;0?ooo`030000003oool0oooo02X0oooo000T0?oo
o`030000003oool0oooo01X0oooo0`0000050?ooo`030000003oool0oooo01`0oooo00@000000?oo
o`0000000000903oool00`000000oooo0?ooo`02000001`0oooo1@0000030?ooo`050000003oool0
oooo0?ooo`000000703oool?000000X0oooo00<000000?ooo`3oool0:P3oool002@0oooo00<00000
0?ooo`3oool03@3oool8000000@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`0B0?ooo``0000000<0oooo0000000000006P3oool?00000200oooo2@00000N0?ooo`030000003o
ool0oooo0080000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02X0oooo000T0?ooo`030000003oool0oooo01D0oooo2@0000040?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`0P0?ooo`030000003oool0
oooo00800000903oool5000001l0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000`0oooo00<000000?ooo`3oool0:P3oool002@0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`02000000<0oooo0`00000M0?ooo`080000003oool000000000003oool00000
0?ooo`00000Q0?ooo`<0000000<0oooo0000003oool08@3oool00`000000oooo0?ooo`02000001X0
oooo3@0000000`3oool000000?ooo`0<0?ooo`030000003oool0oooo02X0oooo000T0?ooo`030000
003oool0oooo01D0oooo200000040?ooo`<00000603oool:00000080oooo0P00000H0?ooo`h00000
6@3oool=000001l0oooo0P000000103oool000000?ooo`3oool2000000l0oooo00<000000?ooo`3o
ool0:P3oool002@0oooo00<000000?ooo`3oool06P3oool00`000000oooo00000008000000<0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`07000001l0oooo00@000000?ooo`000000
00008@3oool3000000030?ooo`000000oooo01h0oooo00<000000?ooo`0000000P0000000`3oool0
00000000000@0?ooo`030000003oool0oooo02X0oooo000T0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`0000000P0000020?ooo`030000003oool0000001H0oooo0P0000040?ooo`040000
003oool000000?ooo`<000005`3oool4000000@0oooo0P0000000`3oool000000?ooo`0G0?ooo``0
0000603oool?00000140oooo00<000000?ooo`3oool0:P3oool002@0oooo00<000000?ooo`3oool0
7@3oool;000000030?ooo`000000000001L0oooo3@00000I0?ooo`T000007`3oool4000001d0oooo
00D000000?ooo`00000000000?ooo`02000001@0oooo00<000000?ooo`3oool0:P3oool002@0oooo
00<000000?ooo`3oool08@3oool2000000@0oooo1@0000000`3oool000000000000J0?ooo`030000
003oool0oooo0080000000<0oooo0000003oool0703oool4000001h0oooo1000000G0?ooo`800000
1@3oool00`000000oooo00000003000001D0oooo00<000000?ooo`3oool0:P3oool002@0oooo00<0
00000?ooo`3oool08P3oool800000080oooo00@000000?ooo`0000000000503oool:000000040?oo
o`0000000000000001@0oooo3000000F0?ooo`/000006@3oool9000000030?ooo`000000oooo01D0
oooo00<000000?ooo`3oool0:@3oool002@0ooood000000/0?ooo`009P3oool300000200oooo00<0
00000?ooo`3oool00`3oool8000000030?ooo`000000oooo008000004`3oool9000000030?ooo`00
0000oooo01<0oooo3000000D0?ooo`/000005@3oool<000000<0oooo00<000000?ooo`3oool0403o
ool2000002h0oooo000Y0?ooo`@00000703oool00`000000oooo0?ooo`080?ooo`T00000603oool0
0`000000oooo00000003000001/0oooo00<000000?ooo`000000703oool00`000000oooo0000000M
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool03P3oool200000300oooo000]0?oo
o`@00000603oool00`000000oooo0?ooo`0<0?ooo`040000003oool00000000001/0oooo0`00000L
0?ooo`8000007P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02`3oool300000380oooo000a0?ooo`@00000503oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`090?oo
o`800000=@3oool003D0oooo1000000@0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool01`3oool2000003L0oooo000i0?ooo`@00000303oool00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo00D0oooo0P00000i0?ooo`00?@3oool3000000T0oooo00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`030?ooo`800000>`3oool00400oooo100000050?ooo`030000003oool0
oooo0940oooo00<000000?ooo`3oool00`00000m0?ooo`00A03oool4000000030?ooo`000000oooo
0980oooo0`0000100?ooo`00B03ooonF00000480oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000
\
\>"]]
}, Open  ]],

Cell[BoxData[
    \(Clear[F, \[Sigma], plot1]\)], "Input",
  CellLabel->"In[291]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->{},
WindowSize->{494, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 68, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1847, 56, 701, 27, 73, "Usage",
      CellTags->"Function?"],
    Cell[2551, 85, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 215612, 6180}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 68, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1847, 56, 701, 27, 73, "Usage",
  CellTags->"Function?"],
Cell[2551, 85, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2648, 90, 189, 4, 75, "MathCaption"],
Cell[2840, 96, 159, 6, 41, "MathCaption"],
Cell[3002, 104, 405, 14, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3432, 122, 33, 0, 39, "ExampleSection"],
Cell[3468, 124, 97, 2, 29, "Input"],
Cell[3568, 128, 104, 3, 25, "Text"],
Cell[3675, 133, 173, 3, 52, "Input"],
Cell[3851, 138, 173, 5, 42, "Text"],
Cell[4027, 145, 190, 4, 49, "Input"],
Cell[4220, 151, 94, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[4339, 157, 998, 19, 389, "Input"],
Cell[5340, 178, 118829, 4606, 386, 44442, 3684, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[124184, 4787, 207, 4, 59, "Text"],

Cell[CellGroupData[{
Cell[124416, 4795, 172, 4, 69, "Input"],
Cell[124591, 4801, 90243, 1353, 294, 58927, 964, "BoxData", "Graphics3D", \
"Graphics"]
}, Open  ]],
Cell[214849, 6157, 84, 2, 29, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

