(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6118,        191]*)
(*NotebookOutlinePosition[      7125,        226]*)
(*  CellTagsIndexPosition[      7051,        220]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ListPolarDensityDraw", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ListPolarDensityDraw[",
  StyleBox["matrix", "TI"],
  "] generates a polar density plot from an array of height values. Rows \
correspond to constant angles, and columns correspond to constant radii."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell[TextData[{
  "The options that can be used, and their default values are:\n",
  Cell[BoxData[
      \(ColorFunction \[Rule] Automatic\)]],
  " \t (GrayLevel)\n",
  Cell[BoxData[
      \(ColorFunctionScaling \[Rule] True\)]],
  "\n",
  Cell[BoxData[
      \(Mesh \[Rule] False\)]],
  " \t\t\t(Opposite of DensityPlot)\n",
  Cell[BoxData[
      \(MeshStyle \[Rule] GrayLevel[0]\)]],
  "\n",
  Cell[BoxData[
      \(PlotRange \[Rule] Automati\)]],
  "c"
}], "MathCaption"],

Cell[TextData[{
  "PlotRange specifies how the domain is set to the matrix rows and columns \
and what the max and mix z values will be. Automatic can be used for all or \
parts of the PlotRange specification. The Automatic values are taken to be\n\
",
  Cell[BoxData[
      \(PlotRange \[Rule] {{0, 1}, {0, 2  \[Pi]}, {mindata, maxdata}}\)]]
}], "MathCaption"],

Cell["\<\
DrawingTransform cannot be used on the graphics produced by \
ListPolarDensityPlot.\
\>", "MathCaption"],

Cell["This routine was kindly contributed by Selwyn Hollis.", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DensityPlot",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["PolarDensityDraw",
    ButtonData:>{"PolarDensityDraw"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ContourDraw",
    ButtonData:>{"ContourDraw"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
The following matrix varies with radius but has the same pattern for every \
angle.\
\>", "Text"],

Cell[BoxData[
    \(polardata = Table[Range[20], {20}]\)], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
Plotting the matrix, we see that the angular domain is assumed to be 0 to 2\
\[Pi] and the radial domain is 0 to 1.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{ListPolarDensityDraw[
            polardata]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 350];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
If we transpose the matrix, we obtain a variation with angle but constant \
radial values.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{ListPolarDensityDraw[
            polardata // Transpose]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 350];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell[TextData[{
  "Returning to the original matrix, we can change the r\[Theta] domain and z \
range by using ",
  Cell[BoxData[
      \(PlotRange\)]],
  ". In this case the PlotRange option is put in ListPolarDensityDraw \
statement. It is also necessary to specify the Background in the Draw \
statement because the routine actually draws circular segments from the \
origin to the minimum radius with the specified background color, which it \
cannot pick up from the outer options. By specifying ",
  Cell[BoxData[
      \(\(-20\)\)]],
  " as the minimun z value we obtain only a partial range of the GrayLevel \
scale."
}], "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{ListPolarDensityDraw[
            polardata, \[IndentingNewLine]PlotRange \[Rule] {{0.5, 1}, {0, 
                  3  \[Pi]/4}, {\(-20\), 
                  Automatic}}, \[IndentingNewLine]Background \[Rule] 
              Linen]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 350];\)\)], "Input",
  CellLabel->"In[5]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{700, 526},
WindowMargins->{{-5, Automatic}, {Automatic, -3}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 67, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1846, 56, 278, 6, 50, "Usage",
      CellTags->"Function?"],
    Cell[2127, 64, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6806, 209}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 67, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1846, 56, 278, 6, 50, "Usage",
  CellTags->"Function?"],
Cell[2127, 64, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2224, 69, 474, 17, 159, "MathCaption"],
Cell[2701, 88, 361, 7, 81, "MathCaption"],
Cell[3065, 97, 114, 3, 41, "MathCaption"],
Cell[3182, 102, 76, 0, 41, "MathCaption"],
Cell[3261, 104, 327, 13, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3613, 121, 34, 0, 39, "ExampleSection"],
Cell[3650, 123, 97, 2, 29, "Input"],
Cell[3750, 127, 107, 3, 25, "Text"],
Cell[3860, 132, 91, 2, 29, "Input"],
Cell[3954, 136, 139, 3, 25, "Text"],
Cell[4096, 141, 344, 6, 129, "Input"],
Cell[4443, 149, 114, 3, 25, "Text"],
Cell[4560, 154, 357, 6, 129, "Input"],
Cell[4920, 162, 637, 14, 93, "Text"],
Cell[5560, 178, 530, 9, 169, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

