(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7847,        256]*)
(*NotebookOutlinePosition[      8778,        289]*)
(*  CellTagsIndexPosition[      8704,        283]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["MakePolyGrid", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["MakePolyGrid",
          "MR"], 
        StyleBox["[",
          "MR"], \({nx, \ ny}, \ {{xmin, \ ymin}, \ {xmax, \ ymax}}\), 
        "]"}]]],
  " will create a 2D rectangular grid of rectangular polygons with nx \
rectangles horizontally and ny rectangles vertically. The entire grid will \
span the region defined by the second argument."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "A rectangular grid of rectangular polygons is the starting point for \
creating 2D regions that can be mapped smoothly into 3D space. See the \
examples in ",
  ButtonBox["RaiseTo3D",
    ButtonData:>{"RaiseTo3D"},
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["TrimPolygons",
    ButtonData:>{"TrimPolygons"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[TextData[{
  "It will generally be desirable to apply N to the resulting grid so that ",
  Cell[BoxData[
      \(TrimPolygons\)]],
  " or other routines will work more efficiently."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["HollisGrid",
    ButtonData:>{"HollisGrid"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DrawingTransform",
    ButtonData:>{"DrawingTransform"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FineGrainPolygons",
    ButtonData:>{"FineGrainPolygons"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PolygonOutline",
    ButtonData:>{"PolygonOutline"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RaiseTo3D",
    ButtonData:>{"RaiseTo3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["TrimPolygons",
    ButtonData:>{"TrimPolygons"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example - What a PolyGrid is.", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
The following generates an array of square polygons, 5 across and 10 high, \
which cover the specified region.\
\>", "Text"],

Cell[BoxData[
    \(\(polygrid = 
        MakePolyGrid[{5, \ 10}, \ {{0, 0}, \ {5, 10}}];\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{polygrid // 
            PolygonOutline[Black]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] True];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
This generates a smaller array, which is displayed explicitly.\
\>", "Text"],

Cell[BoxData[
    \(polygrid = MakePolyGrid[{1, \ 2}, \ {{0, 0}, \ {5, 10}}]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{polygrid // 
            PolygonOutline[Black]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] True];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(Clear[polygrid]\)], "Input",
  CellLabel->"In[6]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example - Using a PolyGrid as a Mask", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[7]:="],

Cell["\<\
Suppose we want to draw a number of circles or other curves, but only want to \
display the parts that are within a circle of radius 1.  Here is a set of \
randomly drawn circles.\
\>", "Text"],

Cell[BoxData[
    \(\(circleset = 
        Table[Circle[{Random[Real, {\(-2\), 2}], Random[Real, {\(-2\), 2}]}, 
            Random[Real, {0.5, 2}]], {8}];\)\)], "Input",
  CellLabel->"In[8]:="],

Cell["This is the circle set.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{circleset}, \[IndentingNewLine]AspectRatio \
\[Rule] Automatic, \[IndentingNewLine]Frame \[Rule] True];\)\)], "Input",
  CellLabel->"In[9]:="],

Cell["\<\
We now create a grid of polygons and trim out a circle of radius 1 in the \
center.\
\>", "Text"],

Cell[BoxData[
    \(\(polygrid = 
        MakePolyGrid[{25, 25}, \ {{\(-1.5\), \(-1.5\)}, \ {1.5, 1.5}}] // 
          N;\)\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(\(polys = 
        polygrid // TrimPolygons[#1\^2 + #2\^2 &, \ {1, \ 10}];\)\)], "Input",\

  CellLabel->"In[11]:="],

Cell["Here is our mask.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{SkyBlue, 
          polys, \[IndentingNewLine]polys // 
            PolygonOutline[Black]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] True];\)\)], "Input",
  CellLabel->"In[12]:="],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics has a problem in that circles are not confined to the stated \
PlotRange when Frame is True. Try it. But they are when Frame is False."
}], "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{circleset, \[IndentingNewLine]SkyBlue, 
          polys, \[IndentingNewLine]Black, 
          Circle[{0, 0}, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]PlotRange \[Rule] {{\(-2\), 
                2}, {\(-2\), 2}} 3/4, \[IndentingNewLine]Frame \[Rule] 
          False];\)\)], "Input",
  CellLabel->"In[13]:="],

Cell[TextData[{
  "If we want a Frame, we can convert the circles to Lines with \
ToPointPrimitives. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " correctly renders Lines within the PlotRange with a Frame."
}], "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{circleset // 
            ToPointPrimitives, \[IndentingNewLine]SkyBlue, 
          polys, \[IndentingNewLine]Black, 
          Circle[{0, 0}, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]PlotRange \[Rule] {{\(-2\), 
                2}, {\(-2\), 2}} 3/4\ 1.001, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]AxesFront \[Rule] True];\)\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(Clear[circleset, polygrid, polys]\)], "Input",
  CellLabel->"In[15]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{586, 721},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 59, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1838, 56, 471, 13, 67, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 8533, 274}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 59, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1838, 56, 471, 13, 67, "Usage",
  CellTags->"Function?"],
Cell[2312, 71, 395, 12, 58, "MathCaption"],
Cell[2710, 85, 205, 5, 58, "MathCaption"],
Cell[2918, 92, 672, 26, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3615, 122, 55, 0, 39, "ExampleSection"],
Cell[3673, 124, 97, 2, 29, "Input"],
Cell[3773, 128, 134, 3, 25, "Text"],
Cell[3910, 133, 128, 3, 29, "Input"],
Cell[4041, 138, 237, 4, 89, "Input"],
Cell[4281, 144, 86, 2, 25, "Text"],
Cell[4370, 148, 113, 2, 29, "Input"],
Cell[4486, 152, 237, 4, 89, "Input"],
Cell[4726, 158, 72, 2, 29, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4835, 165, 62, 0, 33, "ExampleSection"],
Cell[4900, 167, 97, 2, 29, "Input"],
Cell[5000, 171, 203, 4, 42, "Text"],
Cell[5206, 177, 194, 4, 49, "Input"],
Cell[5403, 183, 39, 0, 25, "Text"],
Cell[5445, 185, 191, 3, 89, "Input"],
Cell[5639, 190, 107, 3, 25, "Text"],
Cell[5749, 195, 161, 4, 29, "Input"],
Cell[5913, 201, 136, 4, 30, "Input"],
Cell[6052, 207, 33, 0, 25, "Text"],
Cell[6088, 209, 281, 5, 109, "Input"],
Cell[6372, 216, 228, 5, 42, "Text"],
Cell[6603, 223, 401, 7, 149, "Input"],
Cell[7007, 232, 231, 6, 42, "Text"],
Cell[7241, 240, 484, 8, 169, "Input"],
Cell[7728, 250, 91, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

