(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7898,        213]*)
(*NotebookOutlinePosition[      8886,        248]*)
(*  CellTagsIndexPosition[      8812,        242]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["MultipleListDraw", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      \(MultipleListDraw[data, opts ... ]\)]],
  " extracts the graphics primitives from the corresponding MultipleListPlot \
statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as MultipleListPlot. Regular MultipleListPlot options may \
be used. Basic Graphics options, such as PlotRange have no effect.\
\>", "MathCaption"],

Cell["\<\
If you use DrawingPaper, MultipleListDraw is not a very necessary command. \
See the examples.\
\>", "MathCaption"],

Cell[TextData[{
  "The really useful commands from the MultipleListPlot package are ",
  ButtonBox["PlotSymbol",
    ButtonData:>{"Graphics`MultipleListPlot`", "1.22"},
    ButtonStyle->"AddOnsLink"],
  "  and ",
  ButtonBox["MakeSymbol",
    ButtonData:>{"Graphics`MultipleListPlot`", "1.22"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["MultipleListPlot.",
    ButtonData:>{"Graphics`MultipleListPlot`", "1.3"},
    ButtonStyle->"AddOnsLink"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Here are two sets of simulated data.", "Text"],

Cell[BoxData[{
    \(\(data1 = 
        Table[{x, 1 - E\^\(-x\) + Random[Real, {\(-0.05\), 0.05}]}, {x, 0, 2, 
            0.1}];\)\), "\n", 
    \(\(data2 = 
        Table[{x, 1 - E\^\(\(-2\) x\) + Random[Real, {\(-0.05\), 0.05}]}, {x, 
            0, 2, 0.1}];\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell["This plots the data along with the ideal curves.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{MultipleListDraw[data1, data2, 
            PlotJoined \[Rule] True, 
            SymbolShape \[Rule] {PlotSymbol[Triangle, 5, 
                  Filled \[Rule] False], 
                PlotSymbol[Box]}], \[IndentingNewLine]HotPink, 
          Draw[{1 - E\^\(-x\), 1 - E\^\(\(-2\) x\)}, {x, 0, 
              2}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotLabel \[Rule] "\<Two Series of \
Data\>", \[IndentingNewLine]ImageSize \[Rule] 
          400, \[IndentingNewLine]Background \[Rule] Linen];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
But since we have the data points we can do the above just as easily without \
MultipleListPlot using the following.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{PlotSymbol[Triangle, 5, 
              Filled \[Rule] False] /@ data1, \[IndentingNewLine]Line[
            data1], \[IndentingNewLine]PlotSymbol[Box] /@ 
            data2, \[IndentingNewLine]{AbsoluteDashing[{1, 3}], 
            Line[data2]}, \[IndentingNewLine]HotPink, 
          Draw[{1 - E\^\(-x\), 1 - E\^\(\(-2\) x\)}, {x, 0, 
              2}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotLabel \[Rule] "\<Two Series of \
Data\>", \[IndentingNewLine]ImageSize \[Rule] 
          400, \[IndentingNewLine]Background \[Rule] Linen];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell["\<\
This makes the same plot except that MakeSymbol is used to mark the lower \
data points with a symbol consisting of a red cross in a blue circle. I don't \
especially like it, but it illustrates how MakeSymbol can be used to create \
your own plot symbol.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{MakeSymbol[{Red, 
                Line[{{\(-3\), \(-3\)}, {3, 3}}], 
                Line[{{\(-3\), 3}, {3, \(-3\)}}], Blue, 
                Circle[{0, 0}, Offset[{5, 5}]]}] /@ 
            data1, \[IndentingNewLine]Line[
            data1], \[IndentingNewLine]PlotSymbol[Box] /@ 
            data2, \[IndentingNewLine]{AbsoluteDashing[{1, 3}], 
            Line[data2]}, \[IndentingNewLine]ForestGreen, 
          Draw[{1 - E\^\(-x\), 1 - E\^\(\(-2\) x\)}, {x, 0, 
              2}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotLabel \[Rule] "\<Two Series of \
Data\>", \[IndentingNewLine]ImageSize \[Rule] 
          400, \[IndentingNewLine]Background \[Rule] Linen];\)\)], "Input",
  CellLabel->"In[6]:="],

Cell["\<\
It is important to use good graphics to present your data in as favorable a \
light as possible.\
\>", "Text"],

Cell[BoxData[{
    \(\(data1 = {{\(-8.753\), 0.0128905}, {\(-7.17711\), 
            0.328069}, {\(-5.04966\), 0.958425}, {\(-2.60703\), 
            1.90396}, {\(-0.55837\), 2.92829}, {1.64788, 4.2678}, {3.53895, 
            5.6073}, {5.27243, 7.1832}, {7.1635, 8.83788}};\)\), "\n", 
    \(\(data2 = {{\(-9.22577\), 0.249274}, {\(-8.20144\), 
            1.43119}, {\(-6.94073\), 0.564452}, {\(-4.34051\), 
            2.14034}, {\(-3.15859\), 
            0.879631}, {\(-1.81908\), \(-0.775055\)}, {\(-0.400781\), \
\(-0.223493\)}, {1.09632, \(-2.03577\)}, {2.8298, \(-3.53286\)}, {4.2481, \
\(-2.66612\)}, {6.37555, \(-6.13309\)}};\)\), "\n", 
    \(\(Draw2D[\[IndentingNewLine]{MakeSymbol[{Text[\[HappySmiley], {0, 0}, 
                  Background \[Rule] Gold, 
                  TextStyle \[Rule] {FontSize \[Rule] 20}]}] /@ 
            data1, \[IndentingNewLine]Line[
            data1], \[IndentingNewLine]MakeSymbol[{Text[\[FreakedSmiley], {0, 
                    0}, Background \[Rule] Gray, 
                  TextStyle \[Rule] {FontSize \[Rule] 20}]}] /@ 
            data2, \[IndentingNewLine]Line[
            data2], \[IndentingNewLine]Text["\<My Data\>", {3.11657, 
              7.73457}, {1, 
              0}], \[IndentingNewLine]Text["\<Dr. Dumkopft's Data\>", \
{1.29127, \(-4.22328\)}, {1, 0}]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotLabel \[Rule] "\<Good and Bad \
Science\>", \[IndentingNewLine]ImageSize \[Rule] 
          400, \[IndentingNewLine]Background \[Rule] Linen];\)\)}], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(Clear[data1, data2]\)], "Input",
  CellLabel->"In[10]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{551, 721},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 63, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1842, 56, 234, 7, 50, "Usage",
      CellTags->"Function?"],
    Cell[2079, 65, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 8567, 231}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 63, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1842, 56, 234, 7, 50, "Usage",
  CellTags->"Function?"],
Cell[2079, 65, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2176, 70, 175, 3, 58, "MathCaption"],
Cell[2354, 75, 125, 3, 58, "MathCaption"],
Cell[2482, 80, 351, 10, 58, "MathCaption"],
Cell[2836, 92, 169, 5, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3030, 101, 34, 0, 39, "ExampleSection"],
Cell[3067, 103, 97, 2, 29, "Input"],
Cell[3167, 107, 52, 0, 25, "Text"],
Cell[3222, 109, 302, 7, 91, "Input"],
Cell[3527, 118, 64, 0, 25, "Text"],
Cell[3594, 120, 616, 11, 173, "Input"],
Cell[4213, 133, 140, 3, 42, "Text"],
Cell[4356, 138, 657, 11, 213, "Input"],
Cell[5016, 151, 279, 5, 59, "Text"],
Cell[5298, 158, 788, 14, 253, "Input"],
Cell[6089, 174, 120, 3, 25, "Text"],
Cell[6212, 179, 1578, 26, 449, "Input"],
Cell[7793, 207, 77, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

