(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7170,        217]*)
(*NotebookOutlinePosition[      8142,        251]*)
(*  CellTagsIndexPosition[      8068,        245]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["NeutralLighting", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["NeutralLighting",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(saturation, brightness, ambient, \ \[Theta] : 0\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will generate the options for a controlled lighting that can be made more \
neutral in color."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
NeutralLighting is useful when you color surfaces and don't want the color to \
be overwhelmed by the colors of the default lights.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
The regular lights in their regular positions with their regular red, green \
and blue hues are used. However you can control the saturation and brightness \
of the lights and add an ambient gray level.\
\>", "MathCaption"],

Cell[TextData[{
  "The fourth optional argument, \[Theta], will rotate the light sources in a \
left handed sense about the vertical axis. The default rotation is zero. \
Usable ranges usually run from about ",
  Cell[BoxData[
      \(\(-10\) \[Degree]\)]],
  " to ",
  Cell[BoxData[
      \(100  \[Degree]\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "NeutralLighting generates the sequence of options which control the \
lighting. The command can be mixed with the overall plot options. As an \
example, ",
  Cell[BoxData[
      \(NeutralLighting[0.3, 0.5, 0.1]\)]],
  " gives ",
  Cell[BoxData[
      \(Sequence[\[IndentingNewLine]Lighting \[Rule] 
          True, \[IndentingNewLine]AmbientLight \[Rule] GrayLevel[0.1`], 
        LightSources \[Rule] {{{1, 0, 1}, Hue[0.`, 0.3`, 0.6`]}, {{1, 1, 1}, 
              Hue[0.333333`, 0.3`, 0.6`]}, {{0, 1, 1}, 
              Hue[0.666667`, 0.3`, 0.6`]}}]\)]],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
We will plot a Wheat colored sphere with various lighting options.\
\>", "Text"],

Cell[BoxData[
    \(sphere[\[Phi]_, \[Theta]_] := {Cos[\[Theta]] Cos[\[Phi]], 
        Sin[\[Theta]] Cos[\[Phi]], Sin[\[Phi]]}\)], "Input",
  CellLabel->"In[2]:="],

Cell["With regular lighting the color is substantially lost.", "Text"],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{SurfaceColor[Wheat], 
          ParametricDraw3D[
            Evaluate[
              sphere[\[Phi], \[Theta]]], {\[Phi], \(-\[Pi]\)/2, \[Pi]/
                2}, {\[Theta], 0, 2  \[Pi]}, 
            PlotPoints \[Rule] {20, 
                31}]}, \[IndentingNewLine]Background \[Rule] 
          LightBlue];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell["Using Wheat color with no lighting loses the shading.", "Text"],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{Wheat, 
          ParametricDraw3D[
            Evaluate[
              sphere[\[Phi], \[Theta]]], {\[Phi], \(-\[Pi]\)/2, \[Pi]/
                2}, {\[Theta], 0, 2  \[Pi]}, 
            PlotPoints \[Rule] {20, 
                31}]}, \[IndentingNewLine]Lighting \[Rule] 
          False, \[IndentingNewLine]Background \[Rule] 
          LightBlue];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["With neutral lighting we can see the color and the shading.", "Text"],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{SurfaceColor[Wheat], 
          ParametricDraw3D[
            Evaluate[
              sphere[\[Phi], \[Theta]]], {\[Phi], \(-\[Pi]\)/2, \[Pi]/
                2}, {\[Theta], 0, 2  \[Pi]}, 
            PlotPoints \[Rule] {20, 31}]}, \[IndentingNewLine]NeutralLighting[
          0.2, 0.5, \ 0.0], \[IndentingNewLine]Background \[Rule] 
          LightBlue\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell["\<\
A specular component in the SurfaceColor can give added emphasis.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{SurfaceColor[Wheat, Wheat, 3], 
          ParametricDraw3D[
            Evaluate[
              sphere[\[Phi], \[Theta]]], {\[Phi], \(-\[Pi]\)/2, \[Pi]/
                2}, {\[Theta], 0, 2  \[Pi]}, 
            PlotPoints \[Rule] {20, 31}]}, \[IndentingNewLine]NeutralLighting[
          0.2, 0.3, \ 0.1], \[IndentingNewLine]Background \[Rule] 
          LightBlue\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[6]:="],

Cell["This rotates the light sources to the left side.", "Text"],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{SurfaceColor[Wheat, Wheat, 3], 
          ParametricDraw3D[
            Evaluate[
              sphere[\[Phi], \[Theta]]], {\[Phi], \(-\[Pi]\)/2, \[Pi]/
                2}, {\[Theta], 0, 2  \[Pi]}, 
            PlotPoints \[Rule] {20, 31}]}, \[IndentingNewLine]NeutralLighting[
          0.2, 0.3, \ 0.1, 
          70  \[Degree]], \[IndentingNewLine]Background \[Rule] 
          LightBlue\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(Clear[sphere]\)], "Input",
  CellLabel->"In[8]:="],

Cell[TextData[{
  "There are other examples of NeutralLighting in the examples of ",
  ButtonBox["ListDraw3D",
    ButtonData:>{"ListDraw3D"},
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["IteratorSubstitution",
    ButtonData:>{"IteratorSubstitution"},
    ButtonStyle->"AddOnsLink"],
  " ."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{494, 740},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 62, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1841, 56, 435, 15, 50, "Usage",
      CellTags->"Function?"],
    Cell[2279, 73, 187, 4, 58, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7821, 234}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 62, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1841, 56, 435, 15, 50, "Usage",
  CellTags->"Function?"],
Cell[2279, 73, 187, 4, 58, "MathCaption",
  CellTags->"Function?"],
Cell[2469, 79, 233, 4, 75, "MathCaption"],
Cell[2705, 85, 336, 10, 75, "MathCaption"],
Cell[3044, 97, 599, 14, 186, "MathCaption"],

Cell[CellGroupData[{
Cell[3668, 115, 34, 0, 39, "ExampleSection"],
Cell[3705, 117, 97, 2, 29, "Input"],
Cell[3805, 121, 90, 2, 25, "Text"],
Cell[3898, 125, 163, 3, 29, "Input"],
Cell[4064, 130, 70, 0, 25, "Text"],
Cell[4137, 132, 402, 9, 109, "Input"],
Cell[4542, 143, 69, 0, 25, "Text"],
Cell[4614, 145, 442, 10, 109, "Input"],
Cell[5059, 157, 75, 0, 25, "Text"],
Cell[5137, 159, 468, 9, 149, "Input"],
Cell[5608, 170, 89, 2, 25, "Text"],
Cell[5700, 174, 478, 9, 149, "Input"],
Cell[6181, 185, 64, 0, 25, "Text"],
Cell[6248, 187, 504, 10, 149, "Input"],
Cell[6755, 199, 70, 2, 29, "Input"],
Cell[6828, 203, 314, 10, 42, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

