(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4661,        153]*)
(*NotebookOutlinePosition[      5632,        187]*)
(*  CellTagsIndexPosition[      5558,        181]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ParametricDraw", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          RowBox[{"Parametric", 
            StyleBox["Draw",
              "MR"]}]], 
        StyleBox["[",
          "MR"], 
        StyleBox[\({fx, fy}, {t, tmin, tmax}, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " extracts the graphics primitives from the corresponding ParametricPlot \
statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as ParametricPlot. Regular Plot options may be used. Basic \
Graphics options, such as PlotRange have no effect.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Draw",
    ButtonData:>{"Draw"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["ParametricPlot",
    ButtonStyle->"RefGuideLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["The following parametrizes a circle and an ellipse.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{ParametricDraw[{Cos[\[Theta]], 
              Sin[\[Theta]]}, {\[Theta], 0, 
              2  \[Pi]}], \[IndentingNewLine]Red, 
          ParametricDraw[{Cos[\[Theta]], Sin[\[Theta]]/2}, {\[Theta], 0, 
              2  \[Pi]}]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] True];\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  "The following is the parametrization of a Lissajous figure from Alfred \
Gray's ",
  StyleBox["Modern Differential Geometry of Curves and Surfaces with \
Mathematica",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[BoxData[
    \(\(lissajous[n_, d_, a_, b_]\)[t_] := {a\ Sin[n\ t + d], 
        b\ Sin[t]}\)], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
Here 11 different Lissajous figures are drawn with different Hues by using \
MapThread on a range of hues and a range off phase offsets. With DrawingPaper \
it is very easy to Map a set of graphics onto a parameter range, or MapThread \
it onto several parameters.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{MapThread[{Hue[#1], 
                ParametricDraw[
                  Evaluate[\(lissajous[4, #2, 1, 1]\)[t]], {t, 0, 2  \[Pi]}, 
                  PlotPoints \[Rule] 100]} &, {Range[0, 1, 0.1], 
              Range[0, 2  \[Pi], 
                2  \[Pi]/10]}]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Background \[Rule] 
          Black];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(Clear[lissajous]\)], "Input",
  CellLabel->"In[5]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{494, 740},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 61, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1840, 56, 465, 17, 50, "Usage",
      CellTags->"Function?"],
    Cell[2308, 75, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5312, 170}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 61, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1840, 56, 465, 17, 50, "Usage",
  CellTags->"Function?"],
Cell[2308, 75, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2405, 80, 161, 3, 58, "MathCaption"],
Cell[2569, 85, 207, 9, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[2801, 98, 34, 0, 39, "ExampleSection"],
Cell[2838, 100, 97, 2, 29, "Input"],
Cell[2938, 104, 67, 0, 25, "Text"],
Cell[3008, 106, 417, 7, 109, "Input"],
Cell[3428, 115, 231, 7, 42, "Text"],
Cell[3662, 124, 132, 3, 29, "Input"],
Cell[3797, 129, 288, 5, 59, "Text"],
Cell[4088, 136, 469, 9, 149, "Input"],
Cell[4560, 147, 73, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

