(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    171757,       4148]*)
(*NotebookOutlinePosition[    172749,       4183]*)
(*  CellTagsIndexPosition[    172672,       4177]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["PointParametricDraw3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          RowBox[{"PointParametric", 
            StyleBox["Draw3D",
              "MR"]}]], 
        StyleBox["[",
          "MR"], 
        StyleBox[\({x, y, z}, {u, u0, u1, \((du)\)}, {v, v0, v1, \((dv)\)}, 
          opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " extracts the graphics primitives from the corresponding \
PointParametricPlot3D statement."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Usage is the same as PointParametricPlot3D. Regular PointParametricPlot3D \
options may be used. Basic Graphics3D options, such as PlotRange have no \
effect.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Draw3D",
    ButtonData:>{"Draw3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CylindricalDraw3D",
    ButtonData:>{"CylindricalDraw3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SphericalDraw3D",
    ButtonData:>{"SphericalDraw3D"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ParametricDraw3D",
    ButtonData:>{"ParametricDraw3D"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["PointParametricPlot3D",
    ButtonData:>{"Graphics`ParametricPlot3D`", "1.3"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example ", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[292]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{EdgeForm[], 
          SurfaceColor[GoldenrodLight], 
          SphericalDraw3D[0.99, {\[Theta], 0, \[Pi]}, {\[Phi], 0, 2  \[Pi]}, 
            PlotPoints \[Rule] {21, 41}], \[IndentingNewLine]Firebrick, 
          AbsolutePointSize[
            5], \[IndentingNewLine]PointParametricDraw3D[{Cos[u]\ Cos[v], 
              Sin[u]\ Cos[v], Sin[v]}, {u, 0, 
              2  \[Pi], \[Pi]/16}, {v, \(-\[Pi]\)/2, \[Pi]/2, \[Pi]/
                18}]}, \[IndentingNewLine]NeutralLighting[0.3, 0.5, 
          0], \[IndentingNewLine]Background \[Rule] 
          CadetBlue, \[IndentingNewLine]Boxed \[Rule] 
          False, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)], "Input",
  CellLabel->"In[293]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.372 .62 .628 r
MFill
% Scaling calculations
-0.0567234 1.16608 5.12828e-017 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.763 .693 .417 r
.53198 .58412 m .50043 .53959 L .49674 .58301 L F
.53198 .58412 m .53127 .54059 L .50043 .53959 L F
.746 .674 .406 r
.53256 .62763 m .53198 .58412 L .49674 .58301 L F
.747 .678 .41 r
.56711 .58196 m .53127 .54059 L .53198 .58412 L F
.728 .658 .398 r
.57132 .62531 m .53198 .58412 L .53256 .62763 L F
.57132 .62531 m .56711 .58196 L .53198 .58412 L F
.78 .708 .425 r
.49674 .58301 m .47009 .53567 L .46205 .57864 L F
.49674 .58301 m .50043 .53959 L .47009 .53567 L F
.765 .691 .414 r
.49369 .62644 m .49674 .58301 L .46205 .57864 L F
.746 .674 .406 r
.53256 .62763 m .49674 .58301 L .49369 .62644 L F
.747 .678 .41 r
.56711 .58196 m .56201 .53865 L .53127 .54059 L F
.731 .665 .403 r
.60147 .57656 m .56201 .53865 L .56711 .58196 L F
.71 .643 .39 r
.60926 .61951 m .56711 .58196 L .57132 .62531 L F
.60926 .61951 m .60147 .57656 L .56711 .58196 L F
.778 .71 .428 r
.53127 .54059 m .5047 .49688 L .50043 .53959 L F
.53127 .54059 m .53045 .49773 L .5047 .49688 L F
.764 .698 .422 r
.56201 .53865 m .53045 .49773 L .53127 .54059 L F
.728 .654 .394 r
.53301 .67045 m .53256 .62763 L .49369 .62644 L F
.708 .637 .385 r
.57458 .66802 m .53256 .62763 L .53301 .67045 L F
.57458 .66802 m .57132 .62531 L .53256 .62763 L F
.793 .724 .435 r
.50043 .53959 m .4794 .49352 L .47009 .53567 L F
.50043 .53959 m .5047 .49688 L .4794 .49352 L F
.765 .691 .414 r
.49369 .62644 m .46205 .57864 L .45541 .62174 L F
.749 .673 .403 r
.49132 .6692 m .49369 .62644 L .45541 .62174 L F
.728 .654 .394 r
.53301 .67045 m .49369 .62644 L .49132 .6692 L F
.764 .698 .422 r
.56201 .53865 m .55612 .49607 L .53045 .49773 L F
.751 .686 .416 r
.59206 .5338 m .55612 .49607 L .56201 .53865 L F
.731 .665 .403 r
.60147 .57656 m .59206 .5338 L .56201 .53865 L F
.688 .619 .376 r
.61529 .66196 m .57132 .62531 L .57458 .66802 L F
.61529 .66196 m .60926 .61951 L .57132 .62531 L F
.797 .724 .433 r
.46205 .57864 m .44086 .52888 L .42859 .57107 L F
.46205 .57864 m .47009 .53567 L .44086 .52888 L F
.784 .709 .423 r
.45541 .62174 m .46205 .57864 L .42859 .57107 L F
.808 .738 .442 r
.47009 .53567 m .45505 .48772 L .44086 .52888 L F
.47009 .53567 m .4794 .49352 L .45505 .48772 L F
.716 .652 .397 r
.6344 .56798 m .59206 .5338 L .60147 .57656 L F
.692 .627 .383 r
.64567 .61028 m .60147 .57656 L .60926 .61951 L F
.64567 .61028 m .6344 .56798 L .60147 .57656 L F
.784 .709 .423 r
.45541 .62174 m .42859 .57107 L .41843 .6136 L F
.769 .692 .412 r
.45026 .6643 m .45541 .62174 L .41843 .6136 L F
.749 .673 .403 r
.49132 .6692 m .45541 .62174 L .45026 .6643 L F
.751 .686 .416 r
.59206 .5338 m .58117 .49192 L .55612 .49607 L F
.738 .675 .411 r
.62081 .52611 m .58117 .49192 L .59206 .5338 L F
.716 .652 .397 r
.6344 .56798 m .62081 .52611 L .59206 .5338 L F
.793 .728 .439 r
.53045 .49773 m .5095 .45555 L .5047 .49688 L F
.53045 .49773 m .52953 .45623 L .5095 .45555 L F
.782 .717 .433 r
.55612 .49607 m .52953 .45623 L .53045 .49773 L F
.708 .632 .38 r
.53332 .71186 m .53301 .67045 L .49132 .6692 L F
.686 .612 .37 r
.57682 .70939 m .53301 .67045 L .53332 .71186 L F
.57682 .70939 m .57458 .66802 L .53301 .67045 L F
.806 .739 .444 r
.5047 .49688 m .48983 .45288 L .4794 .49352 L F
.5047 .49688 m .5095 .45555 L .48983 .45288 L F
.667 .601 .367 r
.65439 .65232 m .60926 .61951 L .61529 .66196 L F
.65439 .65232 m .64567 .61028 L .60926 .61951 L F
.782 .717 .433 r
.55612 .49607 m .5495 .45491 L .52953 .45623 L F
.771 .708 .429 r
.58117 .49192 m .5495 .45491 L .55612 .49607 L F
.73 .652 .39 r
.4897 .71059 m .49132 .6692 L .45026 .6643 L F
.708 .632 .38 r
.53332 .71186 m .49132 .6692 L .4897 .71059 L F
.663 .592 .36 r
.61943 .70321 m .57458 .66802 L .57682 .70939 L F
.61943 .70321 m .61529 .66196 L .57458 .66802 L F
.816 .742 .442 r
.42859 .57107 m .41334 .51933 L .39701 .56041 L F
.42859 .57107 m .44086 .52888 L .41334 .51933 L F
.805 .728 .433 r
.41843 .6136 m .42859 .57107 L .39701 .56041 L F
.819 .751 .45 r
.4794 .49352 m .47094 .44827 L .45505 .48772 L F
.4794 .49352 m .48983 .45288 L .47094 .44827 L F
.825 .753 .45 r
.44086 .52888 m .43218 .47957 L .41334 .51933 L F
.44086 .52888 m .45505 .48772 L .43218 .47957 L F
.771 .708 .429 r
.58117 .49192 m .56897 .45161 L .5495 .45491 L F
.76 .699 .425 r
.6051 .48536 m .56897 .45161 L .58117 .49192 L F
.738 .675 .411 r
.62081 .52611 m .6051 .48536 L .58117 .49192 L F
.7 .639 .391 r
.66525 .55635 m .62081 .52611 L .6344 .56798 L F
.674 .611 .375 r
.67983 .59775 m .6344 .56798 L .64567 .61028 L F
.67983 .59775 m .66525 .55635 L .6344 .56798 L F
.726 .665 .406 r
.64767 .5157 m .6051 .48536 L .62081 .52611 L F
.7 .639 .391 r
.66525 .55635 m .64767 .5157 L .62081 .52611 L F
.769 .692 .412 r
.45026 .6643 m .41843 .6136 L .41056 .65579 L F
.752 .672 .4 r
.44672 .7056 m .45026 .6643 L .41056 .65579 L F
.73 .652 .39 r
.4897 .71059 m .45026 .6643 L .44672 .7056 L F
.805 .728 .433 r
.41843 .6136 m .39701 .56041 L .38347 .60212 L F
.791 .712 .422 r
.41056 .65579 m .41843 .6136 L .38347 .60212 L F
.639 .571 .35 r
.6604 .69338 m .61529 .66196 L .61943 .70321 L F
.6604 .69338 m .65439 .65232 L .61529 .66196 L F
.832 .764 .457 r
.45505 .48772 m .45324 .4418 L .43218 .47957 L F
.45505 .48772 m .47094 .44827 L .45324 .4418 L F
.645 .581 .358 r
.69115 .63921 m .64567 .61028 L .65439 .65232 L F
.69115 .63921 m .67983 .59775 L .64567 .61028 L F
.76 .699 .425 r
.6051 .48536 m .58752 .44639 L .56897 .45161 L F
.75 .691 .421 r
.62739 .47648 m .58752 .44639 L .6051 .48536 L F
.726 .665 .406 r
.64767 .5157 m .62739 .47648 L .6051 .48536 L F
.808 .745 .449 r
.52953 .45623 m .51476 .41633 L .5095 .45555 L F
.52953 .45623 m .52853 .4168 L .51476 .41633 L F
.799 .737 .445 r
.5495 .45491 m .52853 .4168 L .52953 .45623 L F
.817 .754 .454 r
.5095 .45555 m .50124 .41445 L .48983 .45288 L F
.5095 .45555 m .51476 .41633 L .50124 .41445 L F
.683 .606 .364 r
.53348 .75117 m .53332 .71186 L .4897 .71059 L F
.659 .584 .353 r
.57798 .74871 m .53332 .71186 L .53348 .75117 L F
.57798 .74871 m .57682 .70939 L .53332 .71186 L F
.842 .77 .458 r
.41334 .51933 m .41129 .46921 L .3881 .50716 L F
.41334 .51933 m .43218 .47957 L .41129 .46921 L F
.835 .76 .451 r
.39701 .56041 m .41334 .51933 L .3881 .50716 L F
.799 .737 .445 r
.5495 .45491 m .54225 .41588 L .52853 .4168 L F
.79 .729 .442 r
.56897 .45161 m .54225 .41588 L .5495 .45491 L F
.835 .76 .451 r
.39701 .56041 m .3881 .50716 L .36796 .54679 L F
.826 .749 .443 r
.38347 .60212 m .39701 .56041 L .36796 .54679 L F
.707 .627 .374 r
.48886 .7499 m .4897 .71059 L .44672 .7056 L F
.683 .606 .364 r
.53348 .75117 m .4897 .71059 L .48886 .7499 L F
.828 .763 .459 r
.48983 .45288 m .48829 .41122 L .47094 .44827 L F
.48983 .45288 m .50124 .41445 L .48829 .41122 L F
.634 .562 .342 r
.62158 .74255 m .57682 .70939 L .57798 .74871 L F
.62158 .74255 m .61943 .70321 L .57682 .70939 L F
.791 .712 .422 r
.41056 .65579 m .38347 .60212 L .37297 .64378 L F
.775 .694 .41 r
.40514 .69692 m .41056 .65579 L .37297 .64378 L F
.752 .672 .4 r
.44672 .7056 m .41056 .65579 L .40514 .69692 L F
.79 .729 .442 r
.56897 .45161 m .55562 .41356 L .54225 .41588 L F
.782 .723 .439 r
.58752 .44639 m .55562 .41356 L .56897 .45161 L F
.713 .655 .402 r
.67204 .50273 m .62739 .47648 L .64767 .5157 L F
.685 .626 .385 r
.69334 .54184 m .64767 .5157 L .66525 .55635 L F
.69334 .54184 m .67204 .50273 L .64767 .5157 L F
.847 .778 .464 r
.43218 .47957 m .43714 .43359 L .41129 .46921 L F
.43218 .47957 m .45324 .4418 L .43714 .43359 L F
.654 .595 .367 r
.71104 .58209 m .66525 .55635 L .67983 .59775 L F
.71104 .58209 m .69334 .54184 L .66525 .55635 L F
.826 .749 .443 r
.38347 .60212 m .36796 .54679 L .35123 .58744 L F
.815 .734 .433 r
.37297 .64378 m .38347 .60212 L .35123 .58744 L F
.613 .548 .339 r
.69894 .68001 m .65439 .65232 L .6604 .69338 L F
.69894 .68001 m .69115 .63921 L .65439 .65232 L F
.838 .774 .464 r
.47094 .44827 m .47619 .40669 L .45324 .4418 L F
.47094 .44827 m .48829 .41122 L .47619 .40669 L F
.73 .649 .385 r
.44489 .74492 m .44672 .7056 L .40514 .69692 L F
.707 .627 .374 r
.48886 .7499 m .44672 .7056 L .44489 .74492 L F
.75 .691 .421 r
.62739 .47648 m .60475 .43935 L .58752 .44639 L F
.741 .684 .418 r
.64755 .46545 m .60475 .43935 L .62739 .47648 L F
.713 .655 .402 r
.67204 .50273 m .64755 .46545 L .62739 .47648 L F
.782 .723 .439 r
.58752 .44639 m .56833 .4099 L .55562 .41356 L F
.775 .717 .436 r
.60475 .43935 m .56833 .4099 L .58752 .44639 L F
.606 .537 .33 r
.66351 .73274 m .61943 .70321 L .62158 .74255 L F
.66351 .73274 m .6604 .69338 L .61943 .70321 L F
.621 .561 .348 r
.7248 .6228 m .67983 .59775 L .69115 .63921 L F
.7248 .6228 m .71104 .58209 L .67983 .59775 L F
.86 .788 .468 r
.3881 .50716 m .39285 .45682 L .36573 .49257 L F
.3881 .50716 m .41129 .46921 L .39285 .45682 L F
.856 .781 .462 r
.36796 .54679 m .3881 .50716 L .36573 .49257 L F
.849 .784 .47 r
.45324 .4418 m .46524 .40096 L .43714 .43359 L F
.45324 .4418 m .47619 .40669 L .46524 .40096 L F
.862 .793 .472 r
.41129 .46921 m .42301 .42381 L .39285 .45682 L F
.41129 .46921 m .43714 .43359 L .42301 .42381 L F
.856 .781 .462 r
.36796 .54679 m .36573 .49257 L .34211 .53044 L F
.85 .771 .455 r
.35123 .58744 m .36796 .54679 L .34211 .53044 L F
.775 .717 .436 r
.60475 .43935 m .58009 .40498 L .56833 .4099 L F
.769 .713 .434 r
.62026 .43062 m .58009 .40498 L .60475 .43935 L F
.741 .684 .418 r
.64755 .46545 m .62026 .43062 L .60475 .43935 L F
.815 .734 .433 r
.37297 .64378 m .35123 .58744 L .33824 .62841 L F
.8 .717 .422 r
.36574 .68467 m .37297 .64378 L .33824 .62841 L F
.775 .694 .41 r
.40514 .69692 m .37297 .64378 L .36574 .68467 L F
.822 .763 .46 r
.52853 .4168 m .52039 .37994 L .51476 .41633 L F
.52853 .4168 m .52745 .38019 L .52039 .37994 L F
.816 .757 .457 r
.54225 .41588 m .52745 .38019 L .52853 .4168 L F
.755 .671 .395 r
.40234 .73628 m .40514 .69692 L .36574 .68467 L F
.73 .649 .385 r
.44489 .74492 m .40514 .69692 L .40234 .73628 L F
.701 .646 .398 r
.69338 .48742 m .64755 .46545 L .67204 .50273 L F
.668 .613 .379 r
.71804 .52466 m .67204 .50273 L .69334 .54184 L F
.71804 .52466 m .69338 .48742 L .67204 .50273 L F
.829 .768 .463 r
.51476 .41633 m .51347 .37896 L .50124 .41445 L F
.51476 .41633 m .52039 .37994 L .51347 .37896 L F
.816 .757 .457 r
.54225 .41588 m .53448 .3797 L .52745 .38019 L F
.811 .752 .455 r
.55562 .41356 m .53448 .3797 L .54225 .41588 L F
.653 .574 .345 r
.53348 .78763 m .53348 .75117 L .48886 .7499 L F
.627 .55 .333 r
.578 .78523 m .53348 .75117 L .53348 .78763 L F
.578 .78523 m .57798 .74871 L .53348 .75117 L F
.732 .678 .416 r
.66509 .45245 m .62026 .43062 L .64755 .46545 L F
.701 .646 .398 r
.69338 .48742 m .66509 .45245 L .64755 .46545 L F
.835 .775 .466 r
.50124 .41445 m .50685 .37727 L .48829 .41122 L F
.50124 .41445 m .51347 .37896 L .50685 .37727 L F
.679 .597 .356 r
.48884 .78639 m .48886 .7499 L .44489 .74492 L F
.653 .574 .345 r
.53348 .78763 m .48886 .7499 L .48884 .78639 L F
.811 .752 .455 r
.55562 .41356 m .54133 .37849 L .53448 .3797 L F
.806 .748 .453 r
.56833 .4099 m .54133 .37849 L .55562 .41356 L F
.633 .577 .359 r
.73858 .56352 m .69334 .54184 L .71104 .58209 L F
.73858 .56352 m .71804 .52466 L .69334 .54184 L F
.598 .525 .32 r
.62163 .77921 m .57798 .74871 L .578 .78523 L F
.62163 .77921 m .62158 .74255 L .57798 .74871 L F
.575 .509 .316 r
.70299 .71941 m .6604 .69338 L .66351 .73274 L F
.70299 .71941 m .69894 .68001 L .6604 .69338 L F
.861 .796 .476 r
.43714 .43359 m .45568 .39415 L .42301 .42381 L F
.43714 .43359 m .46524 .40096 L .45568 .39415 L F
.583 .522 .326 r
.73428 .66326 m .69115 .63921 L .69894 .68001 L F
.73428 .66326 m .7248 .6228 L .69115 .63921 L F
.85 .771 .455 r
.35123 .58744 m .34211 .53044 L .32244 .56977 L F
.84 .759 .446 r
.33824 .62841 m .35123 .58744 L .32244 .56977 L F
.842 .782 .47 r
.48829 .41122 m .50069 .37491 L .47619 .40669 L F
.48829 .41122 m .50685 .37727 L .50069 .37491 L F
.806 .748 .453 r
.56833 .4099 m .54782 .37658 L .54133 .37849 L F
.801 .745 .452 r
.58009 .40498 m .54782 .37658 L .56833 .4099 L F
.769 .713 .434 r
.62026 .43062 m .59062 .39889 L .58009 .40498 L F
.763 .709 .433 r
.63367 .42037 m .59062 .39889 L .62026 .43062 L F
.732 .678 .416 r
.66509 .45245 m .63367 .42037 L .62026 .43062 L F
.703 .619 .366 r
.44485 .78153 m .44489 .74492 L .40234 .73628 L F
.679 .597 .356 r
.48884 .78639 m .44489 .74492 L .44485 .78153 L F
.85 .789 .474 r
.47619 .40669 m .49513 .37194 L .46524 .40096 L F
.47619 .40669 m .50069 .37491 L .49513 .37194 L F
.878 .809 .481 r
.39285 .45682 m .41121 .41265 L .37734 .44263 L F
.39285 .45682 m .42301 .42381 L .41121 .41265 L F
.88 .807 .478 r
.36573 .49257 m .39285 .45682 L .37734 .44263 L F
.36573 .49257 m .37734 .44263 L .34677 .47581 L F
.879 .803 .474 r
.34211 .53044 m .36573 .49257 L .34677 .47581 L F
.593 .538 .337 r
.75458 .60332 m .71104 .58209 L .7248 .6228 L F
.75458 .60332 m .73858 .56352 L .71104 .58209 L F
.566 .496 .305 r
.66358 .76964 m .62158 .74255 L .62163 .77921 L F
.66358 .76964 m .66351 .73274 L .62158 .74255 L F
.801 .745 .452 r
.58009 .40498 m .5538 .37402 L .54782 .37658 L F
.797 .742 .451 r
.59062 .39889 m .5538 .37402 L .58009 .40498 L F
.872 .808 .482 r
.42301 .42381 m .44776 .38641 L .41121 .41265 L F
.42301 .42381 m .45568 .39415 L .44776 .38641 L F
.8 .717 .422 r
.36574 .68467 m .33824 .62841 L .32928 .66898 L F
.78 .694 .407 r
.36199 .72406 m .36574 .68467 L .32928 .66898 L F
.755 .671 .395 r
.40234 .73628 m .36574 .68467 L .36199 .72406 L F
.725 .672 .414 r
.67958 .43774 m .63367 .42037 L .66509 .45245 L F
.689 .637 .394 r
.71113 .47003 m .66509 .45245 L .69338 .48742 L F
.71113 .47003 m .67958 .43774 L .66509 .45245 L F
.879 .803 .474 r
.34211 .53044 m .34677 .47581 L .32007 .51161 L F
.876 .796 .468 r
.32244 .56977 m .34211 .53044 L .32007 .51161 L F
.857 .796 .478 r
.46524 .40096 m .49032 .36841 L .45568 .39415 L F
.46524 .40096 m .49513 .37194 L .49032 .36841 L F
.651 .6 .373 r
.73872 .50509 m .69338 .48742 L .71804 .52466 L F
.73872 .50509 m .71113 .47003 L .69338 .48742 L F
.84 .759 .446 r
.33824 .62841 m .32244 .56977 L .30713 .60989 L F
.827 .742 .434 r
.32928 .66898 m .33824 .62841 L .30713 .60989 L F
.763 .709 .433 r
.63367 .42037 m .59968 .39176 L .59062 .39889 L F
.759 .706 .432 r
.64466 .40881 m .59968 .39176 L .63367 .42037 L F
.725 .672 .414 r
.67958 .43774 m .64466 .40881 L .63367 .42037 L F
.797 .742 .451 r
.59062 .39889 m .55913 .37086 L .5538 .37402 L F
.794 .74 .45 r
.59968 .39176 m .55913 .37086 L .59062 .39889 L F
.728 .641 .376 r
.40227 .77309 m .40234 .73628 L .36199 .72406 L F
.703 .619 .366 r
.44485 .78153 m .40234 .73628 L .40227 .77309 L F
.538 .477 .299 r
.73921 .70269 m .69894 .68001 L .70299 .71941 L F
.73921 .70269 m .73428 .66326 L .69894 .68001 L F
.609 .558 .35 r
.76177 .54232 m .71804 .52466 L .73858 .56352 L F
.76177 .54232 m .73872 .50509 L .71804 .52466 L F
.864 .804 .482 r
.45568 .39415 m .48636 .36442 L .44776 .38641 L F
.45568 .39415 m .49032 .36841 L .48636 .36442 L F
.548 .492 .311 r
.76563 .64334 m .7248 .6228 L .73428 .66326 L F
.76563 .64334 m .75458 .60332 L .7248 .6228 L F
.836 .781 .471 r
.52745 .38019 m .52632 .34715 L .52039 .37994 L F
.834 .779 .47 r
.53448 .3797 m .52632 .34715 L .52745 .38019 L F
.528 .462 .288 r
.70308 .75662 m .66351 .73274 L .66358 .76964 L F
.70308 .75662 m .70299 .71941 L .66351 .73274 L F
.839 .783 .473 r
.52039 .37994 m .52632 .34715 L .51347 .37896 L F
.832 .777 .47 r
.54133 .37849 m .52632 .34715 L .53448 .3797 L F
.876 .796 .468 r
.32244 .56977 m .32007 .51161 L .29778 .54938 L F
.868 .785 .459 r
.30713 .60989 m .32244 .56977 L .29778 .54938 L F
.841 .785 .474 r
.51347 .37896 m .52632 .34715 L .50685 .37727 L F
.894 .826 .49 r
.37734 .44263 m .40204 .40033 L .36516 .42692 L F
.37734 .44263 m .41121 .41265 L .40204 .40033 L F
.9 .828 .489 r
.34677 .47581 m .37734 .44263 L .36516 .42692 L F
.614 .533 .32 r
.53333 .82047 m .53348 .78763 L .48884 .78639 L F
.585 .507 .307 r
.57685 .81818 m .53348 .78763 L .53333 .82047 L F
.57685 .81818 m .578 .78523 L .53348 .78763 L F
.794 .74 .45 r
.59968 .39176 m .56368 .36718 L .55913 .37086 L F
.792 .739 .45 r
.60703 .38375 m .56368 .36718 L .59968 .39176 L F
.759 .706 .432 r
.64466 .40881 m .60703 .38375 L .59968 .39176 L F
.83 .775 .469 r
.54782 .37658 m .52632 .34715 L .54133 .37849 L F
.884 .82 .489 r
.41121 .41265 m .44169 .3779 L .40204 .40033 L F
.41121 .41265 m .44776 .38641 L .44169 .3779 L F
.844 .788 .475 r
.50685 .37727 m .52632 .34715 L .50069 .37491 L F
.641 .557 .331 r
.48968 .81929 m .48884 .78639 L .44485 .78153 L F
.614 .533 .32 r
.53333 .82047 m .48884 .78639 L .48968 .81929 L F
.828 .774 .468 r
.5538 .37402 m .52632 .34715 L .54782 .37658 L F
.552 .478 .292 r
.6195 .81243 m .578 .78523 L .57685 .81818 L F
.6195 .81243 m .62163 .77921 L .578 .78523 L F
.9 .828 .489 r
.34677 .47581 m .36516 .42692 L .33174 .45719 L F
.904 .828 .487 r
.32007 .51161 m .34677 .47581 L .33174 .45719 L F
.846 .79 .476 r
.50069 .37491 m .52632 .34715 L .49513 .37194 L F
.755 .705 .432 r
.65292 .39618 m .60703 .38375 L .64466 .40881 L F
.717 .668 .412 r
.69061 .42161 m .64466 .40881 L .67958 .43774 L F
.69061 .42161 m .65292 .39618 L .64466 .40881 L F
.827 .773 .468 r
.55913 .37086 m .52632 .34715 L .5538 .37402 L F
.677 .629 .391 r
.7248 .45089 m .67958 .43774 L .71113 .47003 L F
.7248 .45089 m .69061 .42161 L .67958 .43774 L F
.871 .811 .486 r
.44776 .38641 m .48337 .36005 L .44169 .3779 L F
.44776 .38641 m .48636 .36442 L .48337 .36005 L F
.561 .511 .324 r
.77975 .58104 m .73858 .56352 L .75458 .60332 L F
.77975 .58104 m .76177 .54232 L .73858 .56352 L F
.849 .793 .478 r
.49513 .37194 m .52632 .34715 L .49032 .36841 L F
.666 .579 .342 r
.44667 .81465 m .44485 .78153 L .40227 .77309 L F
.641 .557 .331 r
.48968 .81929 m .44485 .78153 L .44667 .81465 L F
.826 .773 .468 r
.56368 .36718 m .52632 .34715 L .55913 .37086 L F
.827 .742 .434 r
.32928 .66898 m .30713 .60989 L .29657 .65005 L F
.807 .719 .418 r
.32464 .7084 m .32928 .66898 L .29657 .65005 L F
.78 .694 .407 r
.36199 .72406 m .32928 .66898 L .32464 .7084 L F
.792 .739 .45 r
.60703 .38375 m .56734 .36305 L .56368 .36718 L F
.791 .739 .451 r
.61247 .37504 m .56734 .36305 L .60703 .38375 L F
.755 .705 .432 r
.65292 .39618 m .61247 .37504 L .60703 .38375 L F
.752 .663 .387 r
.3619 .76117 m .36199 .72406 L .32464 .7084 L F
.728 .641 .376 r
.40227 .77309 m .36199 .72406 L .3619 .76117 L F
.632 .586 .367 r
.75479 .4835 m .71113 .47003 L .73872 .50509 L F
.75479 .4835 m .7248 .45089 L .71113 .47003 L F
.851 .796 .479 r
.49032 .36841 m .52632 .34715 L .48636 .36442 L F
.514 .443 .274 r
.66049 .80329 m .62163 .77921 L .6195 .81243 L F
.66049 .80329 m .66358 .76964 L .62163 .77921 L F
.904 .828 .487 r
.32007 .51161 m .33174 .45719 L .30246 .49062 L F
.903 .824 .482 r
.29778 .54938 m .32007 .51161 L .30246 .49062 L F
.826 .773 .468 r
.56734 .36305 m .52632 .34715 L .56368 .36718 L F
.868 .785 .459 r
.30713 .60989 m .29778 .54938 L .2804 .58847 L F
.855 .769 .447 r
.29657 .65005 m .30713 .60989 L .2804 .58847 L F
.895 .832 .495 r
.40204 .40033 m .43763 .36882 L .39578 .38713 L F
.40204 .40033 m .44169 .3779 L .43763 .36882 L F
.91 .843 .499 r
.36516 .42692 m .40204 .40033 L .39578 .38713 L F
.877 .818 .49 r
.44169 .3779 m .48142 .35541 L .43763 .36882 L F
.44169 .3779 m .48337 .36005 L .48142 .35541 L F
.853 .798 .481 r
.48636 .36442 m .52632 .34715 L .48337 .36005 L F
.492 .437 .279 r
.77137 .6828 m .73428 .66326 L .73921 .70269 L F
.77137 .6828 m .76563 .64334 L .73428 .66326 L F
.482 .421 .267 r
.73932 .7403 m .70299 .71941 L .70308 .75662 L F
.73932 .7403 m .73921 .70269 L .70299 .71941 L F
.826 .773 .468 r
.57 .35859 m .52632 .34715 L .56734 .36305 L F
.791 .739 .451 r
.61247 .37504 m .57 .35859 L .56734 .36305 L F
.91 .843 .499 r
.36516 .42692 m .39578 .38713 L .35668 .41002 L F
.921 .851 .501 r
.33174 .45719 m .36516 .42692 L .35668 .41002 L F
.79 .74 .452 r
.61585 .36583 m .57 .35859 L .61247 .37504 L F
.752 .705 .433 r
.6582 .38276 m .61247 .37504 L .65292 .39618 L F
.6582 .38276 m .61585 .36583 L .61247 .37504 L F
.711 .665 .412 r
.69783 .4044 m .65292 .39618 L .69061 .42161 L F
.69783 .4044 m .6582 .38276 L .65292 .39618 L F
.581 .536 .34 r
.77992 .51886 m .73872 .50509 L .76177 .54232 L F
.77992 .51886 m .75479 .4835 L .73872 .50509 L F
.69 .6 .351 r
.40506 .80658 m .40227 .77309 L .3619 .76117 L F
.666 .579 .342 r
.44667 .81465 m .40227 .77309 L .40506 .80658 L F
.855 .8 .482 r
.48337 .36005 m .52632 .34715 L .48142 .35541 L F
.826 .774 .469 r
.57161 .35389 m .52632 .34715 L .57 .35859 L F
.79 .74 .452 r
.61585 .36583 m .57161 .35389 L .57 .35859 L F
.504 .455 .292 r
.79219 .62054 m .75458 .60332 L .76563 .64334 L F
.79219 .62054 m .77975 .58104 L .75458 .60332 L F
.664 .621 .388 r
.73393 .43039 m .69061 .42161 L .7248 .45089 L F
.73393 .43039 m .69783 .4044 L .69061 .42161 L F
.903 .824 .482 r
.29778 .54938 m .30246 .49062 L .27794 .52661 L F
.898 .815 .474 r
.2804 .58847 m .29778 .54938 L .27794 .52661 L F
.467 .401 .252 r
.69907 .79085 m .66358 .76964 L .66049 .80329 L F
.69907 .79085 m .70308 .75662 L .66358 .76964 L F
.921 .851 .501 r
.33174 .45719 m .35668 .41002 L .32111 .43708 L F
.929 .855 .5 r
.30246 .49062 m .33174 .45719 L .32111 .43708 L F
.883 .825 .494 r
.43763 .36882 m .48056 .35061 L .43571 .35939 L F
.43763 .36882 m .48142 .35541 L .48056 .35061 L F
.906 .844 .502 r
.39578 .38713 m .43763 .36882 L .43571 .35939 L F
.857 .802 .483 r
.48142 .35541 m .52632 .34715 L .48056 .35061 L F
.826 .775 .47 r
.57211 .34906 m .52632 .34715 L .57161 .35389 L F
.791 .743 .453 r
.61707 .35632 m .57161 .35389 L .61585 .36583 L F
.61707 .35632 m .57211 .34906 L .57161 .35389 L F
.751 .706 .434 r
.66031 .36885 m .61585 .36583 L .6582 .38276 L F
.66031 .36885 m .61707 .35632 L .61585 .36583 L F
.906 .844 .502 r
.39578 .38713 m .43571 .35939 L .39264 .37335 L F
.926 .86 .509 r
.35668 .41002 m .39578 .38713 L .39264 .37335 L F
.859 .804 .484 r
.48056 .35061 m .52632 .34715 L .48083 .34577 L F
.827 .776 .471 r
.57148 .34423 m .52632 .34715 L .57211 .34906 L F
.829 .778 .472 r
.56973 .33951 m .52632 .34715 L .57148 .34423 L F
.832 .783 .474 r
.56303 .33089 m .52632 .34715 L .56689 .33503 L F
.835 .785 .476 r
.55824 .32721 m .52632 .34715 L .56303 .33089 L F
.837 .788 .477 r
.55264 .32408 m .52632 .34715 L .55824 .32721 L F
.84 .791 .479 r
.54636 .32158 m .52632 .34715 L .55264 .32408 L F
.843 .794 .48 r
.53957 .31979 m .52632 .34715 L .54636 .32158 L F
.846 .796 .481 r
.53244 .31875 m .52632 .34715 L .53957 .31979 L F
.849 .799 .483 r
.52514 .31848 m .52632 .34715 L .53244 .31875 L F
.851 .801 .484 r
.51788 .319 m .52632 .34715 L .52514 .31848 L F
.854 .803 .485 r
.51084 .32029 m .52632 .34715 L .51788 .319 L F
.856 .805 .486 r
.50419 .32231 m .52632 .34715 L .51084 .32029 L F
.857 .806 .486 r
.49811 .32502 m .52632 .34715 L .50419 .32231 L F
.859 .807 .486 r
.49276 .32833 m .52632 .34715 L .49811 .32502 L F
.86 .807 .486 r
.48825 .33217 m .52632 .34715 L .49276 .32833 L F
.48471 .33643 m .52632 .34715 L .48825 .33217 L F
.48222 .341 m .52632 .34715 L .48471 .33643 L F
.859 .806 .485 r
.48083 .34577 m .52632 .34715 L .48222 .341 L F
.83 .78 .473 r
.56689 .33503 m .52632 .34715 L .56973 .33951 L F
.888 .831 .497 r
.43571 .35939 m .48056 .35061 L .48083 .34577 L F
.807 .719 .418 r
.32464 .7084 m .29657 .65005 L .29109 .6895 L F
.778 .686 .397 r
.32453 .74588 m .32464 .7084 L .29109 .6895 L F
.752 .663 .387 r
.3619 .76117 m .32464 .7084 L .32453 .74588 L F
.56 .477 .285 r
.533 .84891 m .53333 .82047 L .48968 .81929 L F
.528 .448 .271 r
.57449 .84677 m .53333 .82047 L .533 .84891 L F
.57449 .84677 m .57685 .81818 L .53333 .82047 L F
.793 .746 .455 r
.61604 .34676 m .57211 .34906 L .61707 .35632 L F
.61604 .34676 m .57148 .34423 L .57211 .34906 L F
.611 .571 .361 r
.76571 .46028 m .7248 .45089 L .75479 .4835 L F
.76571 .46028 m .73393 .43039 L .7248 .45089 L F
.521 .478 .307 r
.79958 .55634 m .76177 .54232 L .77975 .58104 L F
.79958 .55634 m .77992 .51886 L .76177 .54232 L F
.588 .502 .297 r
.49139 .84781 m .48968 .81929 L .44667 .81465 L F
.56 .477 .285 r
.533 .84891 m .48968 .81929 L .49139 .84781 L F
.855 .769 .447 r
.29657 .65005 m .2804 .58847 L .26839 .62814 L F
.835 .745 .43 r
.29109 .6895 m .29657 .65005 L .26839 .62814 L F
.705 .664 .412 r
.70096 .38648 m .6582 .38276 L .69783 .4044 L F
.70096 .38648 m .66031 .36885 L .6582 .38276 L F
.49 .414 .253 r
.61513 .8414 m .57685 .81818 L .57449 .84677 L F
.61513 .8414 m .6195 .81243 L .57685 .81818 L F
.888 .831 .497 r
.43571 .35939 m .48083 .34577 L .43602 .34982 L F
.916 .855 .508 r
.39264 .37335 m .43571 .35939 L .43602 .34982 L F
.892 .836 .5 r
.43602 .34982 m .48083 .34577 L .48222 .341 L F
.929 .855 .5 r
.30246 .49062 m .32111 .43708 L .28983 .46787 L F
.933 .854 .497 r
.27794 .52661 m .30246 .49062 L .28983 .46787 L F
.926 .86 .509 r
.35668 .41002 m .39264 .37335 L .35222 .39228 L F
.943 .874 .513 r
.32111 .43708 m .35668 .41002 L .35222 .39228 L F
.712 .62 .359 r
.36562 .79519 m .3619 .76117 L .32453 .74588 L F
.69 .6 .351 r
.40506 .80658 m .3619 .76117 L .36562 .79519 L F
.795 .75 .458 r
.61278 .33738 m .57148 .34423 L .61604 .34676 L F
.61278 .33738 m .56973 .33951 L .57148 .34423 L F
.751 .709 .437 r
.65912 .35479 m .61707 .35632 L .66031 .36885 L F
.65912 .35479 m .61604 .34676 L .61707 .35632 L F
.423 .368 .239 r
.7715 .72089 m .73921 .70269 L .73932 .7403 L F
.7715 .72089 m .77137 .6828 L .73921 .70269 L F
.613 .524 .307 r
.4504 .84347 m .44667 .81465 L .40506 .80658 L F
.588 .502 .297 r
.49139 .84781 m .44667 .81465 L .4504 .84347 L F
.898 .815 .474 r
.2804 .58847 m .27794 .52661 L .25878 .5645 L F
.886 .799 .461 r
.26839 .62814 m .2804 .58847 L .25878 .5645 L F
.894 .84 .503 r
.43857 .34035 m .48222 .341 L .48471 .33643 L F
.892 .836 .5 r
.43602 .34982 m .48222 .341 L .43857 .34035 L F
.434 .386 .253 r
.79866 .66002 m .76563 .64334 L .77137 .6828 L F
.79866 .66002 m .79219 .62054 L .76563 .64334 L F
.799 .755 .461 r
.60732 .32842 m .56973 .33951 L .61278 .33738 L F
.60732 .32842 m .56689 .33503 L .56973 .33951 L F
.443 .371 .231 r
.65416 .83286 m .6195 .81243 L .61513 .8414 L F
.65416 .83286 m .66049 .80329 L .6195 .81243 L F
.651 .614 .386 r
.73815 .40896 m .69783 .4044 L .73393 .43039 L F
.73815 .40896 m .70096 .38648 L .69783 .4044 L F
.409 .348 .224 r
.73443 .77527 m .70308 .75662 L .69907 .79085 L F
.73443 .77527 m .73932 .7403 L .70308 .75662 L F
.916 .855 .508 r
.39264 .37335 m .43602 .34982 L .39277 .3593 L F
.941 .877 .518 r
.35222 .39228 m .39264 .37335 L .39277 .3593 L F
.547 .51 .327 r
.79243 .49357 m .75479 .4835 L .77992 .51886 L F
.79243 .49357 m .76571 .46028 L .75479 .4835 L F
.923 .865 .514 r
.39277 .3593 m .43602 .34982 L .43857 .34035 L F
.895 .843 .505 r
.44333 .33123 m .48471 .33643 L .48825 .33217 L F
.894 .84 .503 r
.43857 .34035 m .48471 .33643 L .44333 .33123 L F
.805 .762 .465 r
.59977 .32011 m .56689 .33503 L .60732 .32842 L F
.59977 .32011 m .56303 .33089 L .56689 .33503 L F
.943 .874 .513 r
.32111 .43708 m .35222 .39228 L .31528 .4159 L F
.956 .883 .515 r
.28983 .46787 m .32111 .43708 L .31528 .4159 L F
.701 .664 .413 r
.6998 .36829 m .66031 .36885 L .70096 .38648 L F
.6998 .36829 m .65912 .35479 L .66031 .36885 L F
.753 .714 .44 r
.65458 .34093 m .61604 .34676 L .65912 .35479 L F
.65458 .34093 m .61278 .33738 L .61604 .34676 L F
.447 .407 .267 r
.8132 .59521 m .77975 .58104 L .79219 .62054 L F
.8132 .59521 m .79958 .55634 L .77975 .58104 L F
.895 .844 .506 r
.45022 .32269 m .48825 .33217 L .49276 .32833 L F
.895 .843 .505 r
.44333 .33123 m .48825 .33217 L .45022 .32269 L F
.634 .542 .314 r
.41077 .83594 m .40506 .80658 L .36562 .79519 L F
.613 .524 .307 r
.4504 .84347 m .40506 .80658 L .41077 .83594 L F
.933 .854 .497 r
.27794 .52661 m .28983 .46787 L .26356 .50185 L F
.93 .847 .489 r
.25878 .5645 m .27794 .52661 L .26356 .50185 L F
.811 .769 .469 r
.59031 .3127 m .56303 .33089 L .59977 .32011 L F
.59031 .3127 m .55824 .32721 L .56303 .33089 L F
.892 .843 .506 r
.45909 .31496 m .49276 .32833 L .49811 .32502 L F
.895 .844 .506 r
.45022 .32269 m .49276 .32833 L .45909 .31496 L F
.586 .553 .353 r
.77102 .43594 m .73393 .43039 L .76571 .46028 L F
.77102 .43594 m .73815 .40896 L .73393 .43039 L F
.818 .777 .474 r
.57917 .30637 m .55824 .32721 L .59031 .3127 L F
.57917 .30637 m .55264 .32408 L .55824 .32721 L F
.384 .318 .203 r
.69085 .82126 m .66049 .80329 L .65416 .83286 L F
.69085 .82126 m .69907 .79085 L .66049 .80329 L F
.929 .873 .519 r
.39623 .34533 m .43857 .34035 L .44333 .33123 L F
.923 .865 .514 r
.39277 .3593 m .43857 .34035 L .39623 .34533 L F
.835 .745 .43 r
.29109 .6895 m .26839 .62814 L .26214 .66761 L F
.802 .709 .405 r
.29096 .72743 m .29109 .6895 L .26214 .66761 L F
.778 .686 .397 r
.32453 .74588 m .29109 .6895 L .29096 .72743 L F
.941 .877 .518 r
.35222 .39228 m .39277 .3593 L .35199 .37413 L F
.963 .896 .526 r
.31528 .4159 m .35222 .39228 L .35199 .37413 L F
.733 .638 .365 r
.32914 .7806 m .32453 .74588 L .29096 .72743 L F
.712 .62 .359 r
.36562 .79519 m .32453 .74588 L .32914 .7806 L F
.887 .84 .505 r
.46972 .30827 m .49811 .32502 L .50419 .32231 L F
.892 .843 .506 r
.45909 .31496 m .49811 .32502 L .46972 .30827 L F
.827 .786 .478 r
.56662 .3013 m .55264 .32408 L .57917 .30637 L F
.56662 .3013 m .54636 .32158 L .55264 .32408 L F
.757 .72 .444 r
.64676 .32763 m .61278 .33738 L .65458 .34093 L F
.64676 .32763 m .60732 .32842 L .61278 .33738 L F
.953 .893 .527 r
.35199 .37413 m .39277 .3593 L .39623 .34533 L F
.469 .435 .286 r
.81339 .52965 m .77992 .51886 L .79958 .55634 L F
.81339 .52965 m .79243 .49357 L .77992 .51886 L F
.881 .836 .503 r
.48186 .30278 m .50419 .32231 L .51084 .32029 L F
.887 .84 .505 r
.46972 .30827 m .50419 .32231 L .48186 .30278 L F
.886 .799 .461 r
.26839 .62814 m .25878 .5645 L .24551 .60358 L F
.864 .773 .442 r
.26214 .66761 m .26839 .62814 L .24551 .60358 L F
.836 .796 .483 r
.55299 .29766 m .54636 .32158 L .56662 .3013 L F
.55299 .29766 m .53957 .31979 L .54636 .32158 L F
.637 .606 .383 r
.73718 .38711 m .70096 .38648 L .73815 .40896 L F
.73718 .38711 m .6998 .36829 L .70096 .38648 L F
.956 .883 .515 r
.28983 .46787 m .31528 .4159 L .28268 .44384 L F
.963 .886 .513 r
.26356 .50185 m .28983 .46787 L .28268 .44384 L F
.873 .83 .5 r
.49518 .29867 m .51084 .32029 L .51788 .319 L F
.881 .836 .503 r
.48186 .30278 m .51084 .32029 L .49518 .29867 L F
.846 .805 .488 r
.53864 .29553 m .53957 .31979 L .55299 .29766 L F
.53864 .29553 m .53244 .31875 L .53957 .31979 L F
.697 .665 .415 r
.69426 .35027 m .65912 .35479 L .6998 .36829 L F
.69426 .35027 m .65458 .34093 L .65912 .35479 L F
.865 .822 .497 r
.50934 .29604 m .51788 .319 L .52514 .31848 L F
.873 .83 .5 r
.49518 .29867 m .51788 .319 L .50934 .29604 L F
.855 .814 .492 r
.52396 .29499 m .53244 .31875 L .53864 .29553 L F
.52396 .29499 m .52514 .31848 L .53244 .31875 L F
.865 .822 .497 r
.50934 .29604 m .52514 .31848 L .52396 .29499 L F
.343 .297 .202 r
.79881 .69865 m .77137 .6828 L .7715 .72089 L F
.79881 .69865 m .79866 .66002 L .77137 .6828 L F
.33 .277 .186 r
.7658 .75675 m .73932 .7403 L .73443 .77527 L F
.7658 .75675 m .7715 .72089 L .73932 .7403 L F
.931 .879 .523 r
.40301 .33182 m .44333 .33123 L .45022 .32269 L F
.929 .873 .519 r
.39623 .34533 m .44333 .33123 L .40301 .33182 L F
.479 .395 .235 r
.5325 .87213 m .533 .84891 L .49139 .84781 L F
.443 .362 .219 r
.5709 .87018 m .533 .84891 L .5325 .87213 L F
.5709 .87018 m .57449 .84677 L .533 .84891 L F
.651 .556 .318 r
.37325 .82531 m .36562 .79519 L .32914 .7806 L F
.634 .542 .314 r
.41077 .83594 m .36562 .79519 L .37325 .82531 L F
.508 .42 .247 r
.49399 .87112 m .49139 .84781 L .4504 .84347 L F
.479 .395 .235 r
.5325 .87213 m .49139 .84781 L .49399 .87112 L F
.762 .728 .449 r
.63577 .31526 m .60732 .32842 L .64676 .32763 L F
.63577 .31526 m .59977 .32011 L .60732 .32842 L F
.397 .32 .197 r
.60849 .86529 m .57449 .84677 L .5709 .87018 L F
.60849 .86529 m .61513 .8414 L .57449 .84677 L F
.93 .847 .489 r
.25878 .5645 m .26356 .50185 L .24297 .53839 L F
.917 .83 .475 r
.24551 .60358 m .25878 .5645 L .24297 .53839 L F
.353 .316 .216 r
.8203 .6347 m .79219 .62054 L .79866 .66002 L F
.8203 .6347 m .8132 .59521 L .79219 .62054 L F
.503 .476 .311 r
.79875 .46698 m .76571 .46028 L .79243 .49357 L F
.79875 .46698 m .77102 .43594 L .76571 .46028 L F
.963 .896 .526 r
.31528 .4159 m .35199 .37413 L .31456 .39413 L F
.98 .911 .529 r
.28268 .44384 m .31528 .4159 L .31456 .39413 L F
.307 .247 .165 r
.72443 .80674 m .69907 .79085 L .69085 .82126 L F
.72443 .80674 m .73443 .77527 L .69907 .79085 L F
.962 .905 .534 r
.35612 .356 m .39623 .34533 L .40301 .33182 L F
.953 .893 .527 r
.35199 .37413 m .39623 .34533 L .35612 .356 L F
.929 .881 .524 r
.41301 .3191 m .45022 .32269 L .45909 .31496 L F
.931 .879 .523 r
.40301 .33182 m .45022 .32269 L .41301 .3191 L F
.53 .439 .255 r
.45607 .86717 m .4504 .84347 L .41077 .83594 L F
.508 .42 .247 r
.49399 .87112 m .4504 .84347 L .45607 .86717 L F
.98 .917 .537 r
.31456 .39413 m .35199 .37413 L .35612 .356 L F
.77 .739 .455 r
.62186 .30415 m .59977 .32011 L .63577 .31526 L F
.62186 .30415 m .59031 .3127 L .59977 .32011 L F
.338 .267 .169 r
.64455 .85753 m .61513 .8414 L .60849 .86529 L F
.64455 .85753 m .65416 .83286 L .61513 .8414 L F
.695 .668 .417 r
.68435 .33291 m .65458 .34093 L .69426 .35027 L F
.68435 .33291 m .64676 .32763 L .65458 .34093 L F
.555 .532 .343 r
.77035 .41103 m .73815 .40896 L .77102 .43594 L F
.77035 .41103 m .73718 .38711 L .73815 .40896 L F
.368 .34 .232 r
.82793 .56782 m .79958 .55634 L .8132 .59521 L F
.82793 .56782 m .81339 .52965 L .79958 .55634 L F
.963 .886 .513 r
.26356 .50185 m .28268 .44384 L .2552 .47561 L F
.96 .88 .504 r
.24297 .53839 m .26356 .50185 L .2552 .47561 L F
.622 .599 .38 r
.73086 .36539 m .6998 .36829 L .73718 .38711 L F
.73086 .36539 m .69426 .35027 L .6998 .36829 L F
.802 .709 .405 r
.29096 .72743 m .26214 .66761 L .262 .70607 L F
.748 .651 .368 r
.2964 .76299 m .29096 .72743 L .262 .70607 L F
.733 .638 .365 r
.32914 .7806 m .29096 .72743 L .2964 .76299 L F
.924 .879 .524 r
.42601 .30756 m .45909 .31496 L .46972 .30827 L F
.929 .881 .524 r
.41301 .3191 m .45909 .31496 L .42601 .30756 L F
.864 .773 .442 r
.26214 .66761 m .24551 .60358 L .23861 .64307 L F
.822 .728 .411 r
.262 .70607 m .26214 .66761 L .23861 .64307 L F
.78 .751 .461 r
.60535 .29465 m .59031 .3127 L .62186 .30415 L F
.60535 .29465 m .57917 .30637 L .59031 .3127 L F
.545 .45 .257 r
.41944 .86033 m .41077 .83594 L .37325 .82531 L F
.53 .439 .255 r
.45607 .86717 m .41077 .83594 L .41944 .86033 L F
.66 .563 .317 r
.33859 .8117 m .32914 .7806 L .2964 .76299 L F
.651 .556 .318 r
.37325 .82531 m .32914 .7806 L .33859 .8117 L F
.964 .913 .539 r
.36464 .33837 m .40301 .33182 L .41301 .3191 L F
.962 .905 .534 r
.35612 .356 m .40301 .33182 L .36464 .33837 L F
.913 .873 .522 r
.44173 .2975 m .46972 .30827 L .48186 .30278 L F
.924 .879 .524 r
.42601 .30756 m .46972 .30827 L .44173 .2975 L F
.98 .911 .529 r
.28268 .44384 m .31456 .39413 L .2814 .41904 L F
.989 .916 .527 r
.2552 .47561 m .28268 .44384 L .2814 .41904 L F
.262 .196 .131 r
.67838 .847 m .65416 .83286 L .64455 .85753 L F
.67838 .847 m .69085 .82126 L .65416 .83286 L F
.396 .376 .255 r
.82055 .50152 m .79243 .49357 L .81339 .52965 L F
.82055 .50152 m .79875 .46698 L .79243 .49357 L F
.22 .178 .132 r
.79239 .73554 m .7715 .72089 L .7658 .75675 L F
.79239 .73554 m .79881 .69865 L .7715 .72089 L F
.917 .83 .475 r
.24551 .60358 m .24297 .53839 L .22869 .5768 L F
.887 .796 .45 r
.23861 .64307 m .24551 .60358 L .22869 .5768 L F
.793 .765 .469 r
.58666 .28702 m .57917 .30637 L .60535 .29465 L F
.58666 .28702 m .56662 .3013 L .57917 .30637 L F
.695 .673 .421 r
.67022 .31668 m .64676 .32763 L .68435 .33291 L F
.67022 .31668 m .63577 .31526 L .64676 .32763 L F
.229 .196 .147 r
.82046 .67393 m .79866 .66002 L .79881 .69865 L F
.82046 .67393 m .8203 .6347 L .79866 .66002 L F
.21 .162 .117 r
.75415 .78949 m .73443 .77527 L .72443 .80674 L F
.75415 .78949 m .7658 .75675 L .73443 .77527 L F
.989 .933 .545 r
.31916 .37231 m .35612 .356 L .36464 .33837 L F
.98 .917 .537 r
.31456 .39413 m .35612 .356 L .31916 .37231 L F
.899 .863 .517 r
.45977 .28925 m .48186 .30278 L .49518 .29867 L F
.913 .873 .522 r
.44173 .2975 m .48186 .30278 L .45977 .28925 L F
.998 .934 .541 r
.2814 .41904 m .31456 .39413 L .31916 .37231 L F
.808 .781 .477 r
.56629 .28152 m .56662 .3013 L .58666 .28702 L F
.56629 .28152 m .55299 .29766 L .56662 .3013 L F
.444 .43 .287 r
.79843 .43967 m .77102 .43594 L .79875 .46698 L F
.79843 .43967 m .77035 .41103 L .77102 .43594 L F
.882 .849 .511 r
.47966 .28304 m .49518 .29867 L .50934 .29604 L F
.899 .863 .517 r
.45977 .28925 m .49518 .29867 L .47966 .28304 L F
.549 .452 .254 r
.38481 .85067 m .37325 .82531 L .33859 .8117 L F
.545 .45 .257 r
.41944 .86033 m .37325 .82531 L .38481 .85067 L F
.825 .798 .486 r
.54479 .2783 m .55299 .29766 L .56629 .28152 L F
.54479 .2783 m .53864 .29553 L .55299 .29766 L F
.96 .88 .504 r
.24297 .53839 m .2552 .47561 L .23362 .51066 L F
.941 .856 .485 r
.22869 .5768 m .24297 .53839 L .23362 .51066 L F
.604 .59 .376 r
.71918 .34436 m .69426 .35027 L .73086 .36539 L F
.71918 .34436 m .68435 .33291 L .69426 .35027 L F
.236 .214 .161 r
.83551 .60728 m .8132 .59521 L .8203 .6347 L F
.83551 .60728 m .82793 .56782 L .8132 .59521 L F
.959 .914 .54 r
.37744 .32173 m .41301 .3191 L .42601 .30756 L F
.964 .913 .539 r
.36464 .33837 m .41301 .3191 L .37744 .32173 L F
.863 .833 .503 r
.50086 .27908 m .50934 .29604 L .52396 .29499 L F
.882 .849 .511 r
.47966 .28304 m .50934 .29604 L .50086 .27908 L F
.844 .816 .494 r
.52278 .27748 m .53864 .29553 L .54479 .2783 L F
.52278 .27748 m .52396 .29499 L .53864 .29553 L F
.515 .504 .329 r
.76348 .38616 m .73718 .38711 L .77035 .41103 L F
.76348 .38616 m .73086 .36539 L .73718 .38711 L F
.863 .833 .503 r
.50086 .27908 m .52396 .29499 L .52278 .27748 L F
.347 .262 .155 r
.53183 .88932 m .5325 .87213 L .49399 .87112 L F
.305 .225 .136 r
.56609 .8876 m .5325 .87213 L .53183 .88932 L F
.56609 .8876 m .5709 .87018 L .5325 .87213 L F
.696 .68 .425 r
.65216 .30207 m .63577 .31526 L .67022 .31668 L F
.65216 .30207 m .62186 .30415 L .63577 .31526 L F
.183 .135 .092 r
.70928 .83383 m .69085 .82126 L .67838 .847 L F
.70928 .83383 m .72443 .80674 L .69085 .82126 L F
.375 .287 .166 r
.49747 .88843 m .49399 .87112 L .45607 .86717 L F
.347 .262 .155 r
.53183 .88932 m .49399 .87112 L .49747 .88843 L F
.249 .173 .109 r
.59959 .8833 m .5709 .87018 L .56609 .8876 L F
.59959 .8833 m .60849 .86529 L .5709 .87018 L F
.822 .728 .411 r
.262 .70607 m .23861 .64307 L .23845 .6821 L F
.749 .651 .361 r
.2682 .74261 m .262 .70607 L .23845 .6821 L F
.748 .651 .368 r
.2964 .76299 m .262 .70607 L .2682 .74261 L F
.989 .916 .527 r
.2552 .47561 m .2814 .41904 L .25336 .44847 L F
.979 .903 .513 r
.23362 .51066 m .2552 .47561 L .25336 .44847 L F
.655 .556 .307 r
.30754 .7953 m .2964 .76299 L .2682 .74261 L F
.66 .563 .317 r
.33859 .8117 m .2964 .76299 L .30754 .7953 L F
.253 .242 .18 r
.83572 .53889 m .81339 .52965 L .82793 .56782 L F
.83572 .53889 m .82055 .50152 L .81339 .52965 L F
.391 .299 .169 r
.46366 .88496 m .45607 .86717 L .41944 .86033 L F
.375 .287 .166 r
.49747 .88843 m .45607 .86717 L .46366 .88496 L F
.944 .906 .536 r
.39428 .30655 m .42601 .30756 L .44173 .2975 L F
.959 .914 .54 r
.37744 .32173 m .42601 .30756 L .39428 .30655 L F
.986 .938 .547 r
.32912 .35099 m .36464 .33837 L .37744 .32173 L F
.989 .933 .545 r
.31916 .37231 m .36464 .33837 L .32912 .35099 L F
.887 .796 .45 r
.23861 .64307 m .22869 .5768 L .22125 .61627 L F
.826 .732 .406 r
.23845 .6821 m .23861 .64307 L .22125 .61627 L F
.195 .133 .083 r
.63169 .87647 m .60849 .86529 L .59959 .8833 L F
.63169 .87647 m .64455 .85753 L .60849 .86529 L F
.998 .934 .541 r
.2814 .41904 m .31916 .37231 L .28626 .39409 L F
.999 .934 .534 r
.25336 .44847 m .2814 .41904 L .28626 .39409 L F
.701 .69 .43 r
.63057 .28951 m .62186 .30415 L .65216 .30207 L F
.63057 .28951 m .60535 .29465 L .62186 .30415 L F
1 .945 .546 r
.28626 .39409 m .31916 .37231 L .32912 .35099 L F
.537 .438 .239 r
.3529 .83833 m .33859 .8117 L .30754 .7953 L F
.549 .452 .254 r
.38481 .85067 m .33859 .8117 L .3529 .83833 L F
.105 .086 .066 r
.77927 .76977 m .7658 .75675 L .75415 .78949 L F
.77927 .76977 m .79239 .73554 L .7658 .75675 L F
.583 .579 .37 r
.70227 .32464 m .68435 .33291 L .71918 .34436 L F
.70227 .32464 m .67022 .31668 L .68435 .33291 L F
.106 .095 .078 r
.81342 .71199 m .79881 .69865 L .79239 .73554 L F
.81342 .71199 m .82046 .67393 L .79881 .69865 L F
.291 .29 .209 r
.82057 .47256 m .79875 .46698 L .82055 .50152 L F
.82057 .47256 m .79843 .43967 L .79875 .46698 L F
.392 .298 .163 r
.43104 .87893 m .41944 .86033 L .38481 .85067 L F
.391 .299 .169 r
.46366 .88496 m .41944 .86033 L .43104 .87893 L F
.941 .856 .485 r
.22869 .5768 m .23362 .51066 L .21862 .5483 L F
.889 .802 .446 r
.22125 .61627 m .22869 .5768 L .21862 .5483 L F
.919 .889 .528 r
.41479 .29329 m .44173 .2975 L .45977 .28925 L F
.944 .906 .536 r
.39428 .30655 m .44173 .2975 L .41479 .29329 L F
.121 .112 .094 r
.83569 .64717 m .8203 .6347 L .82046 .67393 L F
.83569 .64717 m .83551 .60728 L .8203 .6347 L F
.361 .365 .252 r
.79118 .41234 m .77035 .41103 L .79843 .43967 L F
.79118 .41234 m .76348 .38616 L .77035 .41103 L F
.463 .466 .309 r
.75033 .36201 m .73086 .36539 L .76348 .38616 L F
.75033 .36201 m .71918 .34436 L .73086 .36539 L F
.084 .062 .043 r
.73654 .81821 m .72443 .80674 L .70928 .83383 L F
.73654 .81821 m .75415 .78949 L .72443 .80674 L F
.126 .082 .049 r
.66173 .86722 m .64455 .85753 L .63169 .87647 L F
.66173 .86722 m .67838 .847 L .64455 .85753 L F
.709 .703 .436 r
.60602 .27942 m .60535 .29465 L .63057 .28951 L F
.60602 .27942 m .58666 .28702 L .60535 .29465 L F
.964 .926 .541 r
.34439 .33079 m .37744 .32173 L .39428 .30655 L F
.986 .938 .547 r
.32912 .35099 m .37744 .32173 L .34439 .33079 L F
.885 .864 .515 r
.43846 .28236 m .45977 .28925 L .47966 .28304 L F
.919 .889 .528 r
.41479 .29329 m .45977 .28925 L .43846 .28236 L F
.979 .903 .513 r
.23362 .51066 m .25336 .44847 L .23126 .4819 L F
.935 .857 .479 r
.21862 .5483 m .23362 .51066 L .23126 .4819 L F
.147 .137 .115 r
.84363 .57831 m .82793 .56782 L .83551 .60728 L F
.84363 .57831 m .83572 .53889 L .82793 .56782 L F
.723 .72 .444 r
.57916 .27211 m .58666 .28702 L .60602 .27942 L F
.57916 .27211 m .56629 .28152 L .58666 .28702 L F
.388 .292 .158 r
.40027 .87044 m .38481 .85067 L .3529 .83833 L F
.392 .298 .163 r
.43104 .87893 m .38481 .85067 L .40027 .87044 L F
.559 .566 .363 r
.68044 .30682 m .67022 .31668 L .70227 .32464 L F
.68044 .30682 m .65216 .30207 L .67022 .31668 L F
.749 .651 .361 r
.2682 .74261 m .23845 .6821 L .2453 .71977 L F
.617 .52 .277 r
.28087 .77635 m .2682 .74261 L .2453 .71977 L F
.655 .556 .307 r
.30754 .7953 m .2682 .74261 L .28087 .77635 L F
.847 .833 .499 r
.46465 .27413 m .47966 .28304 L .50086 .27908 L F
.885 .864 .515 r
.43846 .28236 m .47966 .28304 L .46465 .27413 L F
.745 .741 .454 r
.55076 .26784 m .56629 .28152 L .57916 .27211 L F
.55076 .26784 m .54479 .2783 L .56629 .28152 L F
.999 .934 .534 r
.25336 .44847 m .28626 .39409 L .25836 .42106 L F
.961 .896 .504 r
.23126 .4819 m .25336 .44847 L .25836 .42106 L F
.826 .732 .406 r
.23845 .6821 m .22125 .61627 L .22108 .65594 L F
.711 .617 .331 r
.2453 .71977 m .23845 .6821 L .22108 .65594 L F
.973 .93 .535 r
.2974 .36963 m .32912 .35099 L .34439 .33079 L F
1 .945 .546 r
.28626 .39409 m .32912 .35099 L .2974 .36963 L F
.056 .037 .021 r
.68907 .85567 m .67838 .847 L .66173 .86722 L F
.68907 .85567 m .70928 .83383 L .67838 .847 L F
.494 .396 .207 r
.3244 .82347 m .30754 .7953 L .28087 .77635 L F
.537 .438 .239 r
.3529 .83833 m .30754 .7953 L .3244 .82347 L F
.808 .8 .482 r
.49265 .26887 m .50086 .27908 L .52278 .27748 L F
.847 .833 .499 r
.46465 .27413 m .50086 .27908 L .49265 .26887 L F
.773 .768 .467 r
.52163 .26674 m .54479 .2783 L .55076 .26784 L F
.52163 .26674 m .52278 .27748 L .54479 .2783 L F
.175 .163 .137 r
.836 .50907 m .82055 .50152 L .83572 .53889 L F
.836 .50907 m .82057 .47256 L .82055 .50152 L F
.972 .92 .522 r
.25836 .42106 m .28626 .39409 L .2974 .36963 L F
.808 .8 .482 r
.49265 .26887 m .52278 .27748 L .52163 .26674 L F
.203 .132 .078 r
.531 .8997 m .53183 .88932 L .49747 .88843 L F
.174 .113 .067 r
.56009 .89826 m .53183 .88932 L .531 .8997 L F
.56009 .89826 m .56609 .8876 L .53183 .88932 L F
.918 .893 .523 r
.36468 .31229 m .39428 .30655 L .41479 .29329 L F
.964 .926 .541 r
.34439 .33079 m .39428 .30655 L .36468 .31229 L F
.021 .02 .017 r
.79906 .74791 m .79239 .73554 L .77927 .76977 L F
.79906 .74791 m .81342 .71199 L .79239 .73554 L F
.224 .146 .086 r
.50182 .89896 m .49747 .88843 L .46366 .88496 L F
.203 .132 .078 r
.531 .8997 m .49747 .88843 L .50182 .89896 L F
.396 .416 .28 r
.73103 .33928 m .71918 .34436 L .75033 .36201 L F
.73103 .33928 m .70227 .32464 L .71918 .34436 L F
.889 .802 .446 r
.22125 .61627 m .21862 .5483 L .21079 .58774 L F
.78 .694 .374 r
.22108 .65594 m .22125 .61627 L .21079 .58774 L F
.137 .089 .052 r
.58851 .89463 m .56609 .8876 L .56009 .89826 L F
.58851 .89463 m .59959 .8833 L .56609 .8876 L F
0 0 0 r
.75947 .8004 m .75415 .78949 L .73654 .81821 L F
.75947 .8004 m .77927 .76977 L .75415 .78949 L F
.228 .221 .173 r
.81308 .4435 m .79843 .43967 L .82057 .47256 L F
.81308 .4435 m .79118 .41234 L .79843 .43967 L F
.535 .553 .353 r
.65419 .29146 m .65216 .30207 L .68044 .30682 L F
.65419 .29146 m .63057 .28951 L .65216 .30207 L F
.05 .047 .039 r
.82817 .68651 m .82046 .67393 L .81342 .71199 L F
.82817 .68651 m .83569 .64717 L .82046 .67393 L F
.307 .312 .224 r
.77688 .3857 m .76348 .38616 L .79118 .41234 L F
.77688 .3857 m .75033 .36201 L .76348 .38616 L F
.237 .154 .091 r
.47312 .89603 m .46366 .88496 L .43104 .87893 L F
.224 .146 .086 r
.50182 .89896 m .46366 .88496 L .47312 .89603 L F
.375 .277 .151 r
.37199 .85962 m .3529 .83833 L .3244 .82347 L F
.388 .292 .158 r
.40027 .87044 m .3529 .83833 L .37199 .85962 L F
.089 .058 .034 r
.61569 .88889 m .59959 .8833 L .58851 .89463 L F
.61569 .88889 m .63169 .87647 L .59959 .8833 L F
.935 .857 .479 r
.21862 .5483 m .23126 .4819 L .21588 .51869 L F
.825 .751 .407 r
.21079 .58774 m .21862 .5483 L .21588 .51869 L F
.076 .071 .059 r
.84382 .61889 m .83551 .60728 L .83569 .64717 L F
.84382 .61889 m .84363 .57831 L .83551 .60728 L F
0 0 0 r
.7131 .84201 m .70928 .83383 L .68907 .85567 L F
.7131 .84201 m .73654 .81821 L .70928 .83383 L F
.85 .839 .492 r
.38958 .29608 m .41479 .29329 L .43846 .28236 L F
.918 .893 .523 r
.36468 .31229 m .41479 .29329 L .38958 .29608 L F
.241 .157 .092 r
.44549 .89096 m .43104 .87893 L .40027 .87044 L F
.237 .154 .091 r
.47312 .89603 m .43104 .87893 L .44549 .89096 L F
.898 .873 .501 r
.31476 .34637 m .34439 .33079 L .36468 .31229 L F
.973 .93 .535 r
.2974 .36963 m .34439 .33079 L .31476 .34637 L F
.516 .542 .344 r
.62419 .27907 m .63057 .28951 L .65419 .29146 L F
.62419 .27907 m .60602 .27942 L .63057 .28951 L F
.026 .017 .01 r
.64105 .88112 m .63169 .87647 L .61569 .88889 L F
.64105 .88112 m .66173 .86722 L .63169 .87647 L F
.961 .896 .504 r
.23126 .4819 m .25836 .42106 L .23632 .45279 L F
.848 .788 .431 r
.21588 .51869 m .23126 .4819 L .23632 .45279 L F
.617 .52 .277 r
.28087 .77635 m .2453 .71977 L .2593 .75513 L F
.449 .355 .187 r
.3 .80633 m .28087 .77635 L .2593 .75513 L F
.494 .396 .207 r
.3244 .82347 m .28087 .77635 L .3 .80633 L F
.711 .617 .331 r
.2453 .71977 m .22108 .65594 L .22847 .69486 L F
.531 .441 .226 r
.2593 .75513 m .2453 .71977 L .22847 .69486 L F
.102 .095 .08 r
.84406 .54842 m .83572 .53889 L .84363 .57831 L F
.84406 .54842 m .836 .50907 L .83572 .53889 L F
.371 .39 .264 r
.70591 .31867 m .70227 .32464 L .73103 .33928 L F
.70591 .31867 m .68044 .30682 L .70227 .32464 L F
.874 .842 .474 r
.2704 .39412 m .2974 .36963 L .31476 .34637 L F
.972 .92 .522 r
.25836 .42106 m .2974 .36963 L .2704 .39412 L F
.859 .815 .451 r
.23632 .45279 m .25836 .42106 L .2704 .39412 L F
.766 .769 .454 r
.41846 .28269 m .43846 .28236 L .46465 .27413 L F
.85 .839 .492 r
.38958 .29608 m .43846 .28236 L .41846 .28269 L F
.78 .694 .374 r
.22108 .65594 m .21079 .58774 L .21061 .62809 L F
.585 .505 .256 r
.22847 .69486 m .22108 .65594 L .21061 .62809 L F
.232 .151 .089 r
.41948 .88383 m .40027 .87044 L .37199 .85962 L F
.241 .157 .092 r
.44549 .89096 m .40027 .87044 L .41948 .88383 L F
.508 .539 .339 r
.59126 .27009 m .60602 .27942 L .62419 .27907 L F
.59126 .27009 m .57916 .27211 L .60602 .27942 L F
.329 .235 .131 r
.34684 .84661 m .3244 .82347 L .3 .80633 L F
.375 .277 .151 r
.37199 .85962 m .3244 .82347 L .34684 .84661 L F
.132 .122 .103 r
.82838 .47909 m .82057 .47256 L .836 .50907 L F
.82838 .47909 m .81308 .4435 L .82057 .47256 L F
0 0 0 r
.77741 .78068 m .77927 .76977 L .75947 .8004 L F
.77741 .78068 m .79906 .74791 L .77927 .76977 L F
.252 .251 .187 r
.75561 .36056 m .75033 .36201 L .77688 .3857 L F
.75561 .36056 m .73103 .33928 L .75033 .36201 L F
0 0 0 r
.81282 .72429 m .81342 .71199 L .79906 .74791 L F
.81282 .72429 m .82817 .68651 L .81342 .71199 L F
.66405 .87145 m .66173 .86722 L .64105 .88112 L F
.66405 .87145 m .68907 .85567 L .66173 .86722 L F
.68 .696 .414 r
.45055 .27258 m .46465 .27413 L .49265 .26887 L F
.766 .769 .454 r
.41846 .28269 m .46465 .27413 L .45055 .27258 L F
.698 .133 .133 r
5 Mabswid
.21409 .5213 Mdot
.167 .155 .131 r
.79792 .41513 m .79118 .41234 L .81308 .4435 L F
.79792 .41513 m .77688 .3857 L .79118 .41234 L F
.772 .768 .44 r
.33806 .325 m .36468 .31229 L .38958 .29608 L F
.898 .873 .501 r
.31476 .34637 m .36468 .31229 L .33806 .325 L F
.518 .551 .342 r
.55637 .26483 m .57916 .27211 L .59126 .27009 L F
.55637 .26483 m .55076 .26784 L .57916 .27211 L F
0 0 0 r
.73318 .82647 m .73654 .81821 L .7131 .84201 L F
.73318 .82647 m .75947 .8004 L .73654 .81821 L F
.698 .133 .133 r
.83859 .51917 Mdot
.825 .751 .407 r
.21079 .58774 m .21588 .51869 L .20784 .55807 L F
.622 .556 .285 r
.21061 .62809 m .21079 .58774 L .20784 .55807 L F
.698 .133 .133 r
.33825 .84073 Mdot
0 0 0 r
.83596 .65961 m .83569 .64717 L .82817 .68651 L F
.83596 .65961 m .84382 .61889 L .83569 .64717 L F
.606 .631 .38 r
.48492 .2661 m .49265 .26887 L .52163 .26674 L F
.68 .696 .414 r
.45055 .27258 m .49265 .26887 L .48492 .2661 L F
.698 .133 .133 r
.71625 .83968 Mdot
.55 .581 .355 r
.52056 .26348 m .55076 .26784 L .55637 .26483 L F
.52056 .26348 m .52163 .26674 L .55076 .26784 L F
.698 .133 .133 r
.43053 .88779 Mdot
.337 .353 .239 r
.67551 .30085 m .68044 .30682 L .70591 .31867 L F
.67551 .30085 m .65419 .29146 L .68044 .30682 L F
.606 .631 .38 r
.48492 .2661 m .52163 .26674 L .52056 .26348 L F
.698 .133 .133 r
.62415 .88727 Mdot
.42839 .27854 Mdot
.072 .047 .027 r
.53002 .90258 m .531 .8997 L .50182 .89896 L F
.043 .028 .017 r
.55298 .90144 m .531 .8997 L .53002 .90258 L F
.55298 .90144 m .56009 .89826 L .531 .8997 L F
.204 .133 .078 r
.39567 .87475 m .37199 .85962 L .34684 .84661 L F
.232 .151 .089 r
.41948 .88383 m .37199 .85962 L .39567 .87475 L F
.698 .133 .133 r
.62226 .27779 Mdot
.089 .058 .034 r
.50698 .90199 m .50182 .89896 L .47312 .89603 L F
.072 .047 .027 r
.53002 .90258 m .50182 .89896 L .50698 .90199 L F
.698 .133 .133 r
.33588 .32572 Mdot
.004 .002 .001 r
.57539 .89858 m .56009 .89826 L .55298 .90144 L F
.57539 .89858 m .58851 .89463 L .56009 .89826 L F
.848 .788 .431 r
.21588 .51869 m .23632 .45279 L .22093 .48867 L F
.63 .581 .301 r
.20784 .55807 m .21588 .51869 L .22093 .48867 L F
.698 .133 .133 r
.23778 .44396 Mdot
.71516 .32428 Mdot
.007 .006 .005 r
.84425 .58971 m .84363 .57831 L .84382 .61889 L F
.84425 .58971 m .84406 .54842 L .84363 .57831 L F
.698 .133 .133 r
.21225 .64727 Mdot
.81421 .44191 Mdot
.691 .686 .382 r
.28946 .36841 m .31476 .34637 L .33806 .325 L F
.874 .842 .474 r
.2704 .39412 m .31476 .34637 L .28946 .36841 L F
.095 .062 .036 r
.48434 .89968 m .47312 .89603 L .44549 .89096 L F
.089 .058 .034 r
.50698 .90199 m .47312 .89603 L .48434 .89968 L F
0 0 0 r
.68414 .86004 m .68907 .85567 L .66405 .87145 L F
.68414 .86004 m .7131 .84201 L .68907 .85567 L F
.531 .441 .226 r
.2593 .75513 m .22847 .69486 L .24353 .73203 L F
.34 .26 .14 r
.28039 .78719 m .2593 .75513 L .24353 .73203 L F
.449 .355 .187 r
.3 .80633 m .2593 .75513 L .28039 .78719 L F
.698 .133 .133 r
.84112 .64529 Mdot
.28036 .37687 Mdot
0 0 0 r
.59676 .89407 m .58851 .89463 L .57539 .89858 L F
.59676 .89407 m .61569 .88889 L .58851 .89463 L F
.614 .631 .362 r
.36684 .30622 m .38958 .29608 L .41846 .28269 L F
.772 .768 .44 r
.33806 .325 m .38958 .29608 L .36684 .30622 L F
.859 .815 .451 r
.23632 .45279 m .2704 .39412 L .24901 .4241 L F
0 0 0 r
.22093 .48867 m .23632 .45279 L .24901 .4241 L F
.238 .156 .091 r
.32543 .83164 m .3 .80633 L .28039 .78719 L F
.329 .235 .131 r
.34684 .84661 m .3 .80633 L .32543 .83164 L F
.698 .133 .133 r
.77106 .37506 Mdot
.77106 .37506 Mdot
0 0 0 r
.24901 .4241 m .2704 .39412 L .28946 .36841 L F
.698 .133 .133 r
.4652 .26755 Mdot
.585 .505 .256 r
.22847 .69486 m .21061 .62809 L .21838 .66836 L F
.093 .086 .072 r
.24353 .73203 m .22847 .69486 L .21838 .66836 L F
.698 .133 .133 r
.58525 .26709 Mdot
.227 .147 .087 r
.72773 .3377 m .73103 .33928 L .75561 .36056 L F
.72773 .3377 m .70591 .31867 L .73103 .33928 L F
.088 .057 .034 r
.46258 .8957 m .44549 .89096 L .41948 .88383 L F
.095 .062 .036 r
.48434 .89968 m .44549 .89096 L .46258 .8957 L F
.698 .133 .133 r
.39591 .87699 Mdot
.138 .09 .053 r
.64063 .28646 m .65419 .29146 L .67551 .30085 L F
.64063 .28646 m .62419 .27907 L .65419 .29146 L F
.504 .434 .218 r
.83638 .51835 m .836 .50907 L .84406 .54842 L F
.83638 .51835 m .82838 .47909 L .836 .50907 L F
.698 .133 .133 r
.65857 .87628 Mdot
.577 .602 .351 r
.61665 .88798 m .61569 .88889 L .59676 .89407 L F
.61665 .88798 m .64105 .88112 L .61569 .88889 L F
.726 .698 .38 r
.78976 .75944 m .79906 .74791 L .77741 .78068 L F
.78976 .75944 m .81282 .72429 L .79906 .74791 L F
.698 .133 .133 r
.50485 .26182 Mdot
.5455 .26166 Mdot
.723 .71 .394 r
.74876 .80932 m .75947 .8004 L .73318 .82647 L F
.74876 .80932 m .77741 .78068 L .75947 .8004 L F
.204 .133 .078 r
.39567 .87475 m .34684 .84661 L .37459 .86388 L F
.28 .287 .202 r
.37459 .86388 m .34684 .84661 L .32543 .83164 L F
.622 .556 .285 r
.21061 .62809 m .20784 .55807 L .20765 .59912 L F
.069 .064 .054 r
.21838 .66836 m .21061 .62809 L .20765 .59912 L F
.459 .377 .194 r
.81265 .44976 m .81308 .4435 L .82838 .47909 L F
.81265 .44976 m .79792 .41513 L .81308 .4435 L F
.363 .276 .148 r
.77516 .38827 m .77688 .3857 L .79792 .41513 L F
.77516 .38827 m .75561 .36056 L .77688 .3857 L F
.698 .133 .133 r
.20459 .56538 Mdot
.743 .697 .374 r
.81996 .69939 m .82817 .68651 L .81282 .72429 L F
.81996 .69939 m .83596 .65961 L .82817 .68651 L F
.614 .631 .362 r
.36684 .30622 m .41846 .28269 L .40038 .29067 L F
0 0 0 r
.40038 .29067 m .41846 .28269 L .45055 .27258 L F
.698 .133 .133 r
.84809 .56324 Mdot
.30834 .82062 Mdot
.088 .057 .034 r
.46258 .8957 m .41948 .88383 L .44217 .8901 L F
.382 .409 .266 r
.44217 .8901 m .41948 .88383 L .39567 .87475 L F
.698 .133 .133 r
.25845 .76261 Mdot
.74578 .81939 Mdot
.753 .748 .425 r
.70081 .8471 m .7131 .84201 L .68414 .86004 L F
.70081 .8471 m .73318 .82647 L .7131 .84201 L F
.698 .133 .133 r
.36776 .3021 Mdot
.148 .096 .057 r
.60223 .276 m .62419 .27907 L .64063 .28646 L F
.60223 .276 m .59126 .27009 L .62419 .27907 L F
.698 .133 .133 r
.79537 .76104 Mdot
.68284 .30089 Mdot
.697 .707 .411 r
.63459 .88041 m .64105 .88112 L .61665 .88798 L F
.63459 .88041 m .66405 .87145 L .64105 .88112 L F
.691 .686 .382 r
.28946 .36841 m .33806 .325 L .31527 .34473 L F
0 0 0 r
.31527 .34473 m .33806 .325 L .36684 .30622 L F
.63 .581 .301 r
.20784 .55807 m .22093 .48867 L .21288 .52796 L F
.045 .042 .035 r
.20765 .59912 m .20784 .55807 L .21288 .52796 L F
.698 .133 .133 r
.5113 .90546 Mdot
.54313 .90538 Mdot
.749 .685 .365 r
.83625 .63187 m .84382 .61889 L .83596 .65961 L F
.83625 .63187 m .84425 .58971 L .84382 .61889 L F
.015 .01 .006 r
.43777 .2789 m .45055 .27258 L .48492 .2661 L F
0 0 0 r
.40038 .29067 m .45055 .27258 L .43777 .2789 L F
.698 .133 .133 r
.36543 .86297 Mdot
.2222 .69152 Mdot
.21916 .48349 Mdot
.275 .181 .106 r
.69384 .3179 m .70591 .31867 L .72773 .3377 L F
.69384 .3179 m .67551 .30085 L .70591 .31867 L F
.698 .133 .133 r
.47994 .90258 Mdot
.68878 .86208 Mdot
.57443 .90233 Mdot
.139 .09 .053 r
.56146 .26987 m .59126 .27009 L .60223 .276 L F
.56146 .26987 m .55637 .26483 L .59126 .27009 L F
.34 .26 .14 r
.28039 .78719 m .24353 .73203 L .26618 .76639 L F
.238 .156 .091 r
.32543 .83164 m .28039 .78719 L .30834 .81498 L F
.247 .244 .185 r
.30834 .81498 m .28039 .78719 L .26618 .76639 L F
.698 .133 .133 r
.83113 .68965 Mdot
.83281 .48136 Mdot
0 0 0 r
.22093 .48867 m .24901 .4241 L .23405 .45904 L F
.017 .016 .014 r
.21288 .52796 m .22093 .48867 L .23405 .45904 L F
.413 .441 .288 r
.42356 .88299 m .39567 .87475 L .37459 .86388 L F
.382 .409 .266 r
.44217 .8901 m .39567 .87475 L .42356 .88299 L F
.093 .086 .072 r
.24353 .73203 m .21838 .66836 L .2342 .70748 L F
.181 .168 .141 r
.26618 .76639 m .24353 .73203 L .2342 .70748 L F
0 0 0 r
.26936 .39666 m .28946 .36841 L .31527 .34473 L F
.24901 .4241 m .28946 .36841 L .26936 .39666 L F
.072 .047 .028 r
.47792 .27134 m .48492 .2661 L .52056 .26348 L F
.015 .01 .006 r
.43777 .2789 m .48492 .2661 L .47792 .27134 L F
.698 .133 .133 r
.30685 .34616 Mdot
.723 .643 .341 r
.83657 .56034 m .84406 .54842 L .84425 .58971 L F
.83657 .56034 m .83638 .51835 L .84406 .54842 L F
.34 .352 .243 r
.35677 .8514 m .32543 .83164 L .30834 .81498 L F
.28 .287 .202 r
.37459 .86388 m .32543 .83164 L .35677 .8514 L F
.113 .074 .043 r
.51958 .26829 m .55637 .26483 L .56146 .26987 L F
.51958 .26829 m .52056 .26348 L .55637 .26483 L F
0 0 0 r
.23405 .45904 m .24901 .4241 L .26936 .39666 L F
.809 .804 .467 r
.65016 .87152 m .66405 .87145 L .63459 .88041 L F
.65016 .87152 m .68414 .86004 L .66405 .87145 L F
.698 .133 .133 r
.74398 .34452 Mdot
.072 .047 .028 r
.47792 .27134 m .52056 .26348 L .51958 .26829 L F
.698 .133 .133 r
.25479 .40827 Mdot
.45008 .8968 Mdot
.60418 .89639 Mdot
.79653 .40631 Mdot
.79653 .40631 Mdot
.629 .65 .396 r
.52889 .89735 m .53002 .90258 L .50698 .90199 L F
.661 .679 .41 r
.54486 .89656 m .53002 .90258 L .52889 .89735 L F
.54486 .89656 m .55298 .90144 L .53002 .90258 L F
.9 .862 .485 r
.75932 .7909 m .77741 .78068 L .74876 .80932 L F
.75932 .7909 m .78976 .75944 L .77741 .78068 L F
.069 .064 .054 r
.21838 .66836 m .20765 .59912 L .21563 .64082 L F
.155 .144 .121 r
.2342 .70748 m .21838 .66836 L .21563 .64082 L F
.609 .631 .387 r
.51286 .89694 m .50698 .90199 L .48434 .89968 L F
.629 .65 .396 r
.52889 .89735 m .50698 .90199 L .51286 .89694 L F
.698 .133 .133 r
.40692 .28309 Mdot
.704 .717 .43 r
.56043 .89457 m .55298 .90144 L .54486 .89656 L F
.56043 .89457 m .57539 .89858 L .55298 .90144 L F
.698 .133 .133 r
.64331 .28217 Mdot
.437 .34 .181 r
.74513 .3638 m .75561 .36056 L .77516 .38827 L F
.74513 .3638 m .72773 .3377 L .75561 .36056 L F
0 0 0 r
.34732 .32387 m .36684 .30622 L .40038 .29067 L F
.31527 .34473 m .36684 .30622 L .34732 .32387 L F
.894 .867 .496 r
.7136 .83287 m .73318 .82647 L .70081 .8471 L F
.7136 .83287 m .74876 .80932 L .73318 .82647 L F
.657 .567 .298 r
.82037 .4889 m .82838 .47909 L .83638 .51835 L F
.82037 .4889 m .81265 .44976 L .82838 .47909 L F
.91 .856 .476 r
.79597 .73711 m .81282 .72429 L .78976 .75944 L F
.79597 .73711 m .81996 .69939 L .81282 .72429 L F
.602 .623 .385 r
.49713 .89533 m .48434 .89968 L .46258 .8957 L F
.609 .631 .387 r
.51286 .89694 m .48434 .89968 L .49713 .89533 L F
.698 .133 .133 r
.20484 .61131 Mdot
.756 .76 .454 r
.57524 .89142 m .57539 .89858 L .56043 .89457 L F
.57524 .89142 m .59676 .89407 L .57539 .89858 L F
.549 .454 .234 r
.78886 .42197 m .79792 .41513 L .81265 .44976 L F
.78886 .42197 m .77516 .38827 L .79792 .41513 L F
.698 .133 .133 r
.84785 .60924 Mdot
.445 .473 .309 r
.40718 .87451 m .37459 .86388 L .35677 .8514 L F
.413 .441 .288 r
.42356 .88299 m .37459 .86388 L .40718 .87451 L F
.297 .202 .116 r
.65478 .30186 m .67551 .30085 L .69384 .3179 L F
.65478 .30186 m .64063 .28646 L .67551 .30085 L F
.606 .624 .388 r
.48204 .89255 m .46258 .8957 L .44217 .8901 L F
.602 .623 .385 r
.49713 .89533 m .46258 .8957 L .48204 .89255 L F
.045 .042 .035 r
.20765 .59912 m .21288 .52796 L .2127 .56973 L F
.13 .121 .101 r
.21563 .64082 m .20765 .59912 L .2127 .56973 L F
.698 .133 .133 r
.28566 .79755 Mdot
.42269 .88828 Mdot
.905 .835 .462 r
.81997 .67377 m .83596 .65961 L .81996 .69939 L F
.81997 .67377 m .83625 .63187 L .83596 .65961 L F
.698 .133 .133 r
.63139 .88773 Mdot
.809 .806 .478 r
.58896 .88719 m .59676 .89407 L .57524 .89142 L F
.58896 .88719 m .61665 .88798 L .59676 .89407 L F
.698 .133 .133 r
.76801 .79617 Mdot
.34022 .84607 Mdot
.898 .877 .51 r
.66297 .86147 m .68414 .86004 L .65016 .87152 L F
.66297 .86147 m .70081 .8471 L .68414 .86004 L F
.698 .133 .133 r
.45171 .2697 Mdot
.71365 .84504 Mdot
.59826 .26913 Mdot
.618 .631 .394 r
.46793 .88866 m .44217 .8901 L .42356 .88299 L F
.606 .624 .388 r
.48204 .89255 m .44217 .8901 L .46793 .88866 L F
.698 .133 .133 r
.24199 .73366 Mdot
.079 .051 .03 r
.38483 .30655 m .40038 .29067 L .43777 .2789 L F
0 0 0 r
.34732 .32387 m .40038 .29067 L .38483 .30655 L F
.008 .005 .003 r
.29712 .37134 m .31527 .34473 L .34732 .32387 L F
0 0 0 r
.26936 .39666 m .31527 .34473 L .29712 .37134 L F
.247 .244 .185 r
.30834 .81498 m .26618 .76639 L .29612 .79692 L F
.383 .401 .272 r
.34268 .83755 m .30834 .81498 L .29612 .79692 L F
.34 .352 .243 r
.35677 .8514 m .30834 .81498 L .34268 .83755 L F
.181 .168 .141 r
.26618 .76639 m .2342 .70748 L .25795 .74436 L F
.313 .319 .228 r
.29612 .79692 m .26618 .76639 L .25795 .74436 L F
.017 .016 .014 r
.21288 .52796 m .23405 .45904 L .22622 .49822 L F
.104 .096 .081 r
.2127 .56973 m .21288 .52796 L .22622 .49822 L F
.698 .133 .133 r
.20961 .52739 Mdot
.81127 .73196 Mdot
.86 .847 .501 r
.60127 .88195 m .61665 .88798 L .58896 .88719 L F
.60127 .88195 m .63459 .88041 L .61665 .88798 L F
.874 .79 .435 r
.82862 .60399 m .84425 .58971 L .83625 .63187 L F
.82862 .60399 m .83657 .56034 L .84425 .58971 L F
.698 .133 .133 r
.50009 .26271 Mdot
.54974 .26252 Mdot
.84235 .52524 Mdot
.29 .197 .113 r
.61169 .29019 m .64063 .28646 L .65478 .30186 L F
.61169 .29019 m .60223 .276 L .64063 .28646 L F
.698 .133 .133 r
.34324 .31918 Mdot
.70706 .3178 Mdot
.155 .144 .121 r
.2342 .70748 m .21563 .64082 L .23186 .68203 L F
.254 .251 .189 r
.25795 .74436 m .2342 .70748 L .23186 .68203 L F
0 0 0 r
.23405 .45904 m .26936 .39666 L .25528 .43066 L F
.074 .068 .057 r
.22622 .49822 m .23405 .45904 L .25528 .43066 L F
.508 .522 .338 r
.39344 .8648 m .35677 .8514 L .34268 .83755 L F
.445 .473 .309 r
.40718 .87451 m .35677 .8514 L .39344 .8648 L F
.037 .034 .029 r
.25528 .43066 m .26936 .39666 L .29712 .37134 L F
.457 .359 .19 r
.70846 .34256 m .72773 .3377 L .74513 .3638 L F
.70846 .34256 m .69384 .3179 L .72773 .3377 L F
.974 .93 .534 r
.72209 .81764 m .74876 .80932 L .7136 .83287 L F
.72209 .81764 m .75932 .7909 L .74876 .80932 L F
.698 .133 .133 r
.39874 .87725 Mdot
.65512 .87656 Mdot
.635 .642 .402 r
.45513 .88373 m .42356 .88299 L .40718 .87451 L F
.618 .631 .394 r
.46793 .88866 m .42356 .88299 L .45513 .88373 L F
.984 .928 .528 r
.7644 .7716 m .78976 .75944 L .75932 .7909 L F
.7644 .7716 m .79597 .73711 L .78976 .75944 L F
.144 .093 .055 r
.42676 .29343 m .43777 .2789 L .47792 .27134 L F
.079 .051 .03 r
.38483 .30655 m .43777 .2789 L .42676 .29343 L F
.813 .721 .396 r
.82055 .53159 m .83638 .51835 L .83657 .56034 L F
.82055 .53159 m .82037 .4889 L .83638 .51835 L F
.698 .133 .133 r
.2369 .44629 Mdot
.955 .921 .536 r
.67266 .85046 m .70081 .8471 L .66297 .86147 L F
.67266 .85046 m .7136 .83287 L .70081 .8471 L F
.903 .88 .52 r
.61188 .87581 m .63459 .88041 L .60127 .88195 L F
.61188 .87581 m .65016 .87152 L .63459 .88041 L F
.698 .133 .133 r
.21525 .65768 Mdot
.263 .174 .101 r
.56585 .28334 m .60223 .276 L .61169 .29019 L F
.56585 .28334 m .56146 .26987 L .60223 .276 L F
.698 .133 .133 r
.28362 .37488 Mdot
.81434 .44424 Mdot
.81434 .44424 Mdot
.83742 .65573 Mdot
.13 .121 .101 r
.21563 .64082 m .2127 .56973 L .22069 .6129 L F
.207 .199 .157 r
.23186 .68203 m .21563 .64082 L .22069 .6129 L F
.698 .133 .133 r
.51579 .90235 Mdot
.613 .514 .279 r
.75734 .3966 m .77516 .38827 L .78886 .42197 L F
.75734 .3966 m .74513 .3638 L .77516 .38827 L F
.698 .133 .133 r
.5381 .90229 Mdot
.76704 .37309 Mdot
.978 .908 .513 r
.79562 .71418 m .81996 .69939 L .79597 .73711 L F
.79562 .71418 m .81997 .67377 L .81996 .69939 L F
.727 .63 .345 r
.79605 .46096 m .81265 .44976 L .82037 .4889 L F
.79605 .46096 m .78886 .42197 L .81265 .44976 L F
.698 .133 .133 r
.49382 .90032 Mdot
.193 .125 .074 r
.47187 .28499 m .47792 .27134 L .51958 .26829 L F
.144 .093 .055 r
.42676 .29343 m .47792 .27134 L .47187 .28499 L F
.698 .133 .133 r
.56002 .90015 Mdot
.23 .15 .088 r
.51874 .28159 m .56146 .26987 L .56585 .28334 L F
.51874 .28159 m .51958 .26829 L .56146 .26987 L F
.121 .084 .055 r
.33174 .34897 m .34732 .32387 L .38483 .30655 L F
.008 .005 .003 r
.29712 .37134 m .34732 .32387 L .33174 .34897 L F
.698 .133 .133 r
.32135 .82677 Mdot
.653 .653 .409 r
.44395 .87787 m .40718 .87451 L .39344 .8648 L F
.635 .642 .402 r
.45513 .88373 m .40718 .87451 L .44395 .87787 L F
.193 .125 .074 r
.47187 .28499 m .51958 .26829 L .51874 .28159 L F
.698 .133 .133 r
.73214 .82562 Mdot
.809 .796 .483 r
.52765 .88363 m .52889 .89735 L .51286 .89694 L F
.825 .81 .489 r
.5359 .88321 m .52889 .89735 L .52765 .88363 L F
.5359 .88321 m .54486 .89656 L .52889 .89735 L F
.698 .133 .133 r
.47297 .89627 Mdot
.313 .319 .228 r
.29612 .79692 m .25795 .74436 L .28925 .77786 L F
.465 .468 .31 r
.33278 .82262 m .29612 .79692 L .28925 .77786 L F
.383 .401 .272 r
.34268 .83755 m .29612 .79692 L .33278 .82262 L F
.796 .783 .477 r
.51936 .88342 m .51286 .89694 L .49713 .89533 L F
.809 .796 .483 r
.52765 .88363 m .51286 .89694 L .51936 .88342 L F
.698 .133 .133 r
.5808 .89599 Mdot
.842 .825 .497 r
.54394 .88218 m .54486 .89656 L .5359 .88321 L F
.54394 .88218 m .56043 .89457 L .54486 .89656 L F
.934 .902 .533 r
.62052 .8689 m .65016 .87152 L .61188 .87581 L F
.62052 .8689 m .66297 .86147 L .65016 .87152 L F
.698 .133 .133 r
.27138 .77221 Mdot
.104 .096 .081 r
.2127 .56973 m .22622 .49822 L .22604 .54069 L F
.178 .164 .134 r
.22069 .6129 m .2127 .56973 L .22604 .54069 L F
.561 .562 .361 r
.38272 .85408 m .34268 .83755 L .33278 .82262 L F
.508 .522 .338 r
.39344 .8648 m .34268 .83755 L .38272 .85408 L F
.947 .865 .487 r
.81249 .64806 m .83625 .63187 L .81997 .67377 L F
.81249 .64806 m .82862 .60399 L .83625 .63187 L F
.698 .133 .133 r
.38825 .29738 Mdot
.37913 .86403 Mdot
.786 .773 .472 r
.51123 .88258 m .49713 .89533 L .48204 .89255 L F
.796 .783 .477 r
.51936 .88342 m .49713 .89533 L .51123 .88258 L F
.476 .379 .209 r
.6661 .32534 m .69384 .3179 L .70846 .34256 L F
.6661 .32534 m .65478 .30186 L .69384 .3179 L F
.698 .133 .133 r
.66162 .29633 Mdot
.78179 .77072 Mdot
.67446 .86322 Mdot
.86 .839 .504 r
.55156 .88054 m .56043 .89457 L .54394 .88218 L F
.55156 .88054 m .57524 .89142 L .56043 .89457 L F
.254 .251 .189 r
.25795 .74436 m .23186 .68203 L .25617 .72157 L F
.397 .395 .269 r
.28925 .77786 m .25795 .74436 L .25617 .72157 L F
.698 .133 .133 r
.20986 .57439 Mdot
.779 .765 .468 r
.50346 .88113 m .48204 .89255 L .46793 .88866 L F
.786 .773 .472 r
.51123 .88258 m .48204 .89255 L .50346 .88113 L F
.698 .133 .133 r
.8421 .5723 Mdot
1 .945 .546 r
.72593 .80176 m .75932 .7909 L .72209 .81764 L F
.72593 .80176 m .7644 .7716 L .75932 .7909 L F
.878 .853 .512 r
.55859 .87834 m .57524 .89142 L .55156 .88054 L F
.55859 .87834 m .58896 .88719 L .57524 .89142 L F
.983 .937 .547 r
.67894 .83874 m .7136 .83287 L .67266 .85046 L F
.67894 .83874 m .72209 .81764 L .7136 .83287 L F
.698 .133 .133 r
.45394 .89032 Mdot
.165 .127 .092 r
.28437 .40441 m .29712 .37134 L .33174 .34897 L F
.037 .034 .029 r
.25528 .43066 m .29712 .37134 L .28437 .40441 L F
.698 .133 .133 r
.5997 .88993 Mdot
.074 .068 .057 r
.22622 .49822 m .25528 .43066 L .2479 .4697 L F
.182 .157 .124 r
.22604 .54069 m .22622 .49822 L .2479 .4697 L F
.671 .663 .416 r
.43465 .87119 m .39344 .8648 L .38272 .85408 L F
.653 .653 .409 r
.44395 .87787 m .39344 .8648 L .43465 .87119 L F
.774 .759 .465 r
.49622 .8791 m .46793 .88866 L .45513 .88373 L F
.779 .765 .468 r
.50346 .88113 m .46793 .88866 L .49622 .8791 L F
.894 .804 .452 r
.81289 .57671 m .83657 .56034 L .82862 .60399 L F
.81289 .57671 m .82055 .53159 L .83657 .56034 L F
.182 .148 .112 r
.2479 .4697 m .25528 .43066 L .28437 .40441 L F
.207 .199 .157 r
.23186 .68203 m .22069 .6129 L .23691 .65628 L F
.357 .346 .24 r
.25617 .72157 m .23186 .68203 L .23691 .65628 L F
.209 .148 .098 r
.37239 .33038 m .38483 .30655 L .42676 .29343 L F
.121 .084 .055 r
.33174 .34897 m .38483 .30655 L .37239 .33038 L F
.698 .133 .133 r
.2359 .70292 Mdot
1 .933 .535 r
.76366 .75186 m .79597 .73711 L .7644 .7716 L F
.76366 .75186 m .79562 .71418 L .79597 .73711 L F
.894 .865 .518 r
.56487 .87563 m .58896 .88719 L .55859 .87834 L F
.56487 .87563 m .60127 .88195 L .58896 .88719 L F
.953 .914 .539 r
.62696 .86137 m .66297 .86147 L .62052 .8689 L F
.62696 .86137 m .67266 .85046 L .66297 .86147 L F
.698 .133 .133 r
.81674 .70116 Mdot
.626 .528 .295 r
.71876 .37455 m .74513 .3638 L .75734 .3966 L F
.71876 .37455 m .70846 .34256 L .74513 .3638 L F
.698 .133 .133 r
.43995 .282 Mdot
.6096 .28134 Mdot
.47 .376 .213 r
.61926 .31279 m .65478 .30186 L .6661 .32534 L F
.61926 .31279 m .61169 .29019 L .65478 .30186 L F
.698 .133 .133 r
.22771 .48996 Mdot
.772 .754 .463 r
.48968 .87655 m .45513 .88373 L .44395 .87787 L F
.774 .759 .465 r
.49622 .8791 m .45513 .88373 L .48968 .87655 L F
.698 .133 .133 r
.43743 .88265 Mdot
.823 .728 .409 r
.79621 .50431 m .82037 .4889 L .82055 .53159 L F
.79621 .50431 m .79605 .46096 L .82037 .4889 L F
.698 .133 .133 r
.32356 .34545 Mdot
.61605 .88217 Mdot
.82351 .48789 Mdot
.82351 .48789 Mdot
.7265 .34394 Mdot
.907 .874 .522 r
.57023 .87246 m .60127 .88195 L .56487 .87563 L F
.57023 .87246 m .61188 .87581 L .60127 .88195 L F
.736 .638 .358 r
.76376 .43544 m .78886 .42197 L .79605 .46096 L F
.76376 .43544 m .75734 .3966 L .78886 .42197 L F
.465 .468 .31 r
.33278 .82262 m .28925 .77786 L .32741 .8069 L F
.603 .592 .377 r
.37532 .84256 m .33278 .82262 L .32741 .8069 L F
.561 .562 .361 r
.38272 .85408 m .33278 .82262 L .37532 .84256 L F
.698 .133 .133 r
.36467 .84901 Mdot
.977 .899 .514 r
.7884 .69124 m .81997 .67377 L .79562 .71418 L F
.7884 .69124 m .81249 .64806 L .81997 .67377 L F
.698 .133 .133 r
.68861 .84811 Mdot
.178 .164 .134 r
.22069 .6129 m .22604 .54069 L .23381 .58534 L F
.337 .315 .22 r
.23691 .65628 m .22069 .6129 L .23381 .58534 L F
.698 .133 .133 r
.26732 .41139 Mdot
.30975 .80568 Mdot
.49594 .27395 Mdot
.397 .395 .269 r
.28925 .77786 m .25617 .72157 L .28809 .75821 L F
.533 .52 .338 r
.32741 .8069 m .28925 .77786 L .28809 .75821 L F
.698 .133 .133 r
.55345 .27373 Mdot
.688 .672 .42 r
.42749 .86385 m .38272 .85408 L .37532 .84256 L F
.671 .663 .416 r
.43465 .87119 m .38272 .85408 L .42749 .86385 L F
.698 .133 .133 r
.78322 .40952 Mdot
.74331 .80444 Mdot
.289 .215 .136 r
.41795 .31627 m .42676 .29343 L .47187 .28499 L F
.209 .148 .098 r
.37239 .33038 m .42676 .29343 L .41795 .31627 L F
.771 .75 .461 r
.48402 .87352 m .44395 .87787 L .43465 .87119 L F
.772 .754 .463 r
.48968 .87655 m .44395 .87787 L .48402 .87352 L F
.988 .934 .546 r
.68156 .82657 m .72209 .81764 L .67894 .83874 L F
.68156 .82657 m .72593 .80176 L .72209 .81764 L F
.446 .356 .207 r
.56937 .30542 m .61169 .29019 L .61926 .31279 L F
.56937 .30542 m .56585 .28334 L .61169 .29019 L F
.916 .879 .525 r
.57454 .86892 m .61188 .87581 L .57023 .87246 L F
.57454 .86892 m .62052 .8689 L .61188 .87581 L F
.96 .915 .54 r
.631 .8534 m .67266 .85046 L .62696 .86137 L F
.631 .8534 m .67894 .83874 L .67266 .85046 L F
.698 .133 .133 r
.22033 .62299 Mdot
.267 .207 .141 r
.32079 .38121 m .33174 .34897 L .37239 .33038 L F
.165 .127 .092 r
.28437 .40441 m .33174 .34897 L .32079 .38121 L F
.698 .133 .133 r
.42406 .87349 Mdot
.83164 .62103 Mdot
.62922 .87294 Mdot
.996 .933 .542 r
.72488 .78558 m .7644 .7716 L .72593 .80176 L F
.72488 .78558 m .76366 .75186 L .7644 .7716 L F
.357 .346 .24 r
.25617 .72157 m .23691 .65628 L .26116 .69856 L F
.484 .465 .306 r
.28809 .75821 m .25617 .72157 L .26116 .69856 L F
.182 .157 .124 r
.22604 .54069 m .2479 .4697 L .24772 .51285 L F
.328 .294 .204 r
.23381 .58534 m .22604 .54069 L .24772 .51285 L F
.933 .847 .483 r
.79735 .62295 m .82862 .60399 L .81249 .64806 L F
.79735 .62295 m .81289 .57671 L .82862 .60399 L F
.358 .278 .169 r
.46703 .30719 m .47187 .28499 L .51874 .28159 L F
.289 .215 .136 r
.41795 .31627 m .47187 .28499 L .46703 .30719 L F
.698 .133 .133 r
.26647 .74541 Mdot
.772 .748 .46 r
.47935 .87009 m .43465 .87119 L .42749 .86385 L F
.771 .75 .461 r
.48402 .87352 m .43465 .87119 L .47935 .87009 L F
.409 .324 .192 r
.51806 .30352 m .56585 .28334 L .56937 .30542 L F
.51806 .30352 m .51874 .28159 L .56585 .28334 L F
.698 .133 .133 r
.52084 .88873 Mdot
.53245 .8887 Mdot
.78615 .74387 Mdot
.616 .521 .297 r
.67408 .35665 m .70846 .34256 L .71876 .37455 L F
.67408 .35665 m .6661 .32534 L .70846 .34256 L F
.358 .278 .169 r
.46703 .30719 m .51874 .28159 L .51806 .30352 L F
.698 .133 .133 r
.50943 .88766 Mdot
.54383 .88757 Mdot
.922 .881 .526 r
.5777 .86507 m .62052 .8689 L .57454 .86892 L F
.5777 .86507 m .62696 .86137 L .62052 .8689 L F
.303 .25 .171 r
.27769 .44331 m .28437 .40441 L .32079 .38121 L F
.182 .148 .112 r
.2479 .4697 m .28437 .40441 L .27769 .44331 L F
.319 .276 .19 r
.24772 .51285 m .2479 .4697 L .27769 .44331 L F
.856 .821 .497 r
.52632 .86126 m .52765 .88363 L .51936 .88342 L F
.86 .825 .499 r
.52632 .86126 m .5359 .88321 L .52765 .88363 L F
.852 .818 .495 r
.52632 .86126 m .51936 .88342 L .51123 .88258 L F
.864 .829 .501 r
.52632 .86126 m .54394 .88218 L .5359 .88321 L F
.603 .592 .377 r
.37532 .84256 m .32741 .8069 L .37151 .8305 L F
.702 .68 .424 r
.42266 .85599 m .37532 .84256 L .37151 .8305 L F
.688 .672 .42 r
.42749 .86385 m .37532 .84256 L .42266 .85599 L F
.698 .133 .133 r
.49863 .88554 Mdot
.848 .814 .493 r
.52632 .86126 m .51123 .88258 L .50346 .88113 L F
.698 .133 .133 r
.55458 .88539 Mdot
.868 .832 .502 r
.52632 .86126 m .55156 .88054 L .54394 .88218 L F
.983 .91 .526 r
.75689 .73217 m .79562 .71418 L .76366 .75186 L F
.75689 .73217 m .7884 .69124 L .79562 .71418 L F
.533 .52 .338 r
.32741 .8069 m .28809 .75821 L .32687 .79077 L F
.635 .614 .388 r
.37151 .8305 m .32741 .8069 L .32687 .79077 L F
.698 .133 .133 r
.37322 .32161 Mdot
.845 .811 .492 r
.52632 .86126 m .50346 .88113 L .49622 .8791 L F
.874 .783 .447 r
.78908 .55085 m .82055 .53159 L .81289 .57671 L F
.78908 .55085 m .79621 .50431 L .82055 .53159 L F
.872 .835 .503 r
.52632 .86126 m .55859 .87834 L .55156 .88054 L F
.698 .133 .133 r
.67636 .32046 Mdot
.337 .315 .22 r
.23691 .65628 m .23381 .58534 L .24959 .63089 L F
.455 .427 .283 r
.26116 .69856 m .23691 .65628 L .24959 .63089 L F
.698 .133 .133 r
.35605 .83268 Mdot
.22795 .53801 Mdot
.48884 .88244 Mdot
.96 .909 .537 r
.6325 .84516 m .67894 .83874 L .631 .8534 L F
.6325 .84516 m .68156 .82657 L .67894 .83874 L F
.698 .133 .133 r
.41439 .86316 Mdot
.56431 .88223 Mdot
.774 .746 .459 r
.47581 .86633 m .42749 .86385 L .42266 .85599 L F
.772 .748 .46 r
.47935 .87009 m .42749 .86385 L .47581 .86633 L F
.698 .133 .133 r
.69688 .83173 Mdot
.842 .807 .49 r
.52632 .86126 m .49622 .8791 L .48968 .87655 L F
.698 .133 .133 r
.63867 .86255 Mdot
.875 .837 .504 r
.52632 .86126 m .56487 .87563 L .55859 .87834 L F
.72 .625 .357 r
.72416 .41325 m .75734 .3966 L .76376 .43544 L F
.72416 .41325 m .71876 .37455 L .75734 .3966 L F
.698 .133 .133 r
.82327 .536 Mdot
.82327 .536 Mdot
.978 .919 .539 r
.68036 .81423 m .72593 .80176 L .68156 .82657 L F
.68036 .81423 m .72488 .78558 L .72593 .80176 L F
.803 .709 .405 r
.76391 .4794 m .79605 .46096 L .79621 .50431 L F
.76391 .4794 m .76376 .43544 L .79605 .46096 L F
.924 .88 .525 r
.57961 .86102 m .62696 .86137 L .5777 .86507 L F
.57961 .86102 m .631 .8534 L .62696 .86137 L F
.361 .293 .187 r
.36364 .36189 m .37239 .33038 L .41795 .31627 L F
.267 .207 .141 r
.32079 .38121 m .37239 .33038 L .36364 .36189 L F
.839 .804 .488 r
.52632 .86126 m .48968 .87655 L .48402 .87352 L F
.484 .465 .306 r
.28809 .75821 m .26116 .69856 L .29291 .73844 L F
.582 .557 .357 r
.32687 .79077 m .28809 .75821 L .29291 .73844 L F
.878 .838 .505 r
.52632 .86126 m .57023 .87246 L .56487 .87563 L F
.698 .133 .133 r
.48041 .87845 Mdot
.57265 .8782 Mdot
.24106 .67151 Mdot
.30618 .78349 Mdot
.837 .802 .487 r
.52632 .86126 m .48402 .87352 L .47935 .87009 L F
.698 .133 .133 r
.81093 .66974 Mdot
.949 .868 .501 r
.77421 .6689 m .81249 .64806 L .7884 .69124 L F
.77421 .6689 m .79735 .62295 L .81249 .64806 L F
.594 .502 .291 r
.62459 .34359 m .6661 .32534 L .67408 .35665 L F
.62459 .34359 m .61926 .31279 L .6661 .32534 L F
.698 .133 .133 r
.74641 .78222 Mdot
.88 .839 .505 r
.52632 .86126 m .57454 .86892 L .57023 .87246 L F
.698 .133 .133 r
.25893 .4548 Mdot
.328 .294 .204 r
.23381 .58534 m .24772 .51285 L .25505 .55894 L F
.438 .401 .265 r
.24959 .63089 m .23381 .58534 L .25505 .55894 L F
.698 .133 .133 r
.30972 .38057 Mdot
.702 .68 .424 r
.42266 .85599 m .37151 .8305 L .42033 .84782 L F
.776 .746 .458 r
.47349 .86234 m .42266 .85599 L .42033 .84782 L F
.774 .746 .459 r
.47581 .86633 m .42266 .85599 L .47349 .86234 L F
.635 .614 .388 r
.37151 .8305 m .32687 .79077 L .37147 .81819 L F
.715 .686 .427 r
.42033 .84782 m .37151 .8305 L .37147 .81819 L F
.698 .133 .133 r
.74018 .37898 Mdot
.79156 .45292 Mdot
.47368 .87372 Mdot
.976 .908 .53 r
.71881 .76951 m .76366 .75186 L .72488 .78558 L F
.71881 .76951 m .75689 .73217 L .76366 .75186 L F
.698 .133 .133 r
.57927 .87344 Mdot
.836 .799 .486 r
.52632 .86126 m .47935 .87009 L .47581 .86633 L F
.698 .133 .133 r
.43047 .30476 Mdot
.881 .84 .506 r
.52632 .86126 m .5777 .86507 L .57454 .86892 L F
.923 .876 .523 r
.58022 .85686 m .631 .8534 L .57961 .86102 L F
.58022 .85686 m .6325 .84516 L .631 .8534 L F
.698 .133 .133 r
.61875 .30403 Mdot
.40885 .85201 Mdot
.455 .427 .283 r
.26116 .69856 m .24959 .63089 L .27312 .67596 L F
.546 .514 .331 r
.29291 .73844 m .26116 .69856 L .27312 .67596 L F
.698 .133 .133 r
.64397 .85137 Mdot
.952 .898 .531 r
.6314 .83685 m .68156 .82657 L .6325 .84516 L F
.6314 .83685 m .68036 .81423 L .68156 .82657 L F
.397 .336 .217 r
.31503 .41995 m .32079 .38121 L .36364 .36189 L F
.303 .25 .171 r
.27769 .44331 m .32079 .38121 L .31503 .41995 L F
.582 .557 .357 r
.32687 .79077 m .29291 .73844 L .33132 .77463 L F
.661 .631 .396 r
.37147 .81819 m .32687 .79077 L .33132 .77463 L F
.431 .357 .221 r
.41174 .34722 m .41795 .31627 L .46703 .30719 L F
.361 .293 .187 r
.36364 .36189 m .41795 .31627 L .41174 .34722 L F
.835 .798 .485 r
.52632 .86126 m .47581 .86633 L .47349 .86234 L F
.319 .276 .19 r
.24772 .51285 m .27769 .44331 L .27753 .48708 L F
.427 .381 .25 r
.25505 .55894 m .24772 .51285 L .27753 .48708 L F
.698 .133 .133 r
.46891 .86843 Mdot
.58393 .86811 Mdot
.882 .839 .505 r
.52632 .86126 m .57961 .86102 L .5777 .86507 L F
.901 .815 .47 r
.77463 .59919 m .81289 .57671 L .79735 .62295 L F
.77463 .59919 m .78908 .55085 L .81289 .57671 L F
.565 .477 .28 r
.57185 .33592 m .61926 .31279 L .62459 .34359 L F
.57185 .33592 m .56937 .30542 L .61926 .31279 L F
.698 .133 .133 r
.35381 .81562 Mdot
.416 .362 .236 r
.27753 .48708 m .27769 .44331 L .31503 .41995 L F
.715 .686 .427 r
.42033 .84782 m .37147 .81819 L .42059 .83951 L F
.78 .746 .458 r
.47246 .8582 m .42033 .84782 L .42059 .83951 L F
.776 .746 .458 r
.47349 .86234 m .42033 .84782 L .47246 .8582 L F
.698 .133 .133 r
.49259 .29592 Mdot
.55645 .29568 Mdot
.69875 .81464 Mdot
.834 .796 .484 r
.52632 .86126 m .47349 .86234 L .47246 .8582 L F
.698 .133 .133 r
.23803 .58886 Mdot
.27163 .71813 Mdot
.696 .604 .35 r
.67827 .39522 m .71876 .37455 L .72416 .41325 L F
.67827 .39522 m .67408 .35665 L .71876 .37455 L F
.962 .899 .528 r
.67528 .80204 m .72488 .78558 L .68036 .81423 L F
.67528 .80204 m .71881 .76951 L .72488 .78558 L F
.953 .878 .51 r
.74403 .71306 m .7884 .69124 L .75689 .73217 L F
.74403 .71306 m .77421 .6689 L .7884 .69124 L F
.882 .838 .505 r
.52632 .86126 m .58022 .85686 L .57961 .86102 L F
.698 .133 .133 r
.7804 .71659 Mdot
.92 .87 .519 r
.57951 .8527 m .6325 .84516 L .58022 .85686 L F
.57951 .8527 m .6314 .83685 L .6325 .84516 L F
.698 .133 .133 r
.81322 .58698 Mdot
.81322 .58698 Mdot
.485 .406 .246 r
.46361 .33777 m .46703 .30719 L .51806 .30352 L F
.431 .357 .221 r
.41174 .34722 m .46703 .30719 L .46361 .33777 L F
.698 .133 .133 r
.4663 .86275 Mdot
.661 .631 .396 r
.37147 .81819 m .33132 .77463 L .3753 .80591 L F
.726 .692 .429 r
.42059 .83951 m .37147 .81819 L .3753 .80591 L F
.698 .133 .133 r
.58641 .86242 Mdot
.842 .753 .434 r
.75754 .52726 m .79621 .50431 L .78908 .55085 L F
.75754 .52726 m .76391 .4794 L .79621 .50431 L F
.529 .445 .266 r
.51759 .33395 m .56937 .30542 L .57185 .33592 L F
.51759 .33395 m .51806 .30352 L .56937 .30542 L F
.438 .401 .265 r
.24959 .63089 m .25505 .55894 L .26991 .60662 L F
.523 .483 .311 r
.27312 .67596 m .24959 .63089 L .26991 .60662 L F
.546 .514 .331 r
.29291 .73844 m .27312 .67596 L .30382 .71909 L F
.619 .585 .37 r
.33132 .77463 m .29291 .73844 L .30382 .71909 L F
.78 .746 .458 r
.47246 .8582 m .42059 .83951 L .47275 .85403 L F
.834 .795 .483 r
.52632 .86126 m .47246 .8582 L .47275 .85403 L F
.485 .406 .246 r
.46361 .33777 m .51806 .30352 L .51759 .33395 L F
.775 .684 .395 r
.72429 .45774 m .76376 .43544 L .76391 .4794 L F
.72429 .45774 m .72416 .41325 L .76376 .43544 L F
.698 .133 .133 r
.40774 .84044 Mdot
.881 .837 .504 r
.52632 .86126 m .57951 .8527 L .58022 .85686 L F
.698 .133 .133 r
.64482 .83979 Mdot
.875 .829 .499 r
.52632 .86126 m .56961 .84117 L .57414 .84475 L F
.873 .826 .498 r
.52632 .86126 m .56398 .83798 L .56961 .84117 L F
.87 .823 .496 r
.52632 .86126 m .55738 .83527 L .56398 .83798 L F
.866 .819 .494 r
.52632 .86126 m .54998 .83311 L .55738 .83527 L F
.863 .816 .492 r
.52632 .86126 m .54196 .83156 L .54998 .83311 L F
.859 .813 .491 r
.52632 .86126 m .53354 .83065 L .54196 .83156 L F
.856 .809 .489 r
.52632 .86126 m .52493 .83042 L .53354 .83065 L F
.853 .806 .488 r
.52632 .86126 m .51636 .83087 L .52493 .83042 L F
.849 .804 .486 r
.52632 .86126 m .50805 .83199 L .51636 .83087 L F
.846 .801 .485 r
.52632 .86126 m .50021 .83374 L .50805 .83199 L F
.844 .799 .484 r
.52632 .86126 m .49304 .83609 L .50021 .83374 L F
.841 .797 .483 r
.52632 .86126 m .48673 .83896 L .49304 .83609 L F
.839 .796 .483 r
.52632 .86126 m .48144 .84228 L .48673 .83896 L F
.837 .795 .483 r
.52632 .86126 m .47729 .84596 L .48144 .84228 L F
.836 .795 .483 r
.52632 .86126 m .47437 .84991 L .47729 .84596 L F
.835 .795 .483 r
.52632 .86126 m .47275 .85403 L .47437 .84991 L F
.88 .835 .502 r
.52632 .86126 m .57747 .84862 L .57951 .8527 L F
.878 .832 .501 r
.52632 .86126 m .57414 .84475 L .57747 .84862 L F
.941 .883 .523 r
.62766 .82869 m .68036 .81423 L .6314 .83685 L F
.62766 .82869 m .67528 .80204 L .68036 .81423 L F
.726 .692 .429 r
.42059 .83951 m .3753 .80591 L .42349 .83128 L F
.784 .746 .458 r
.47275 .85403 m .42059 .83951 L .42349 .83128 L F
.698 .133 .133 r
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.52632 .86433 Mdot
.784 .746 .458 r
.47275 .85403 m .42349 .83128 L .47437 .84991 L F
.698 .133 .133 r
.46598 .85691 Mdot
.36263 .35555 Mdot
.5866 .85658 Mdot
.68674 .35434 Mdot
.31114 .76102 Mdot
.914 .862 .515 r
.57747 .84862 m .6314 .83685 L .57951 .8527 L F
.57747 .84862 m .62766 .82869 L .6314 .83685 L F
.95 .88 .515 r
.70769 .75399 m .75689 .73217 L .71881 .76951 L F
.70769 .75399 m .74403 .71306 L .75689 .73217 L F
.467 .399 .25 r
.35903 .4005 m .36364 .36189 L .41174 .34722 L F
.397 .336 .217 r
.31503 .41995 m .36364 .36189 L .35903 .4005 L F
.698 .133 .133 r
.25914 .50384 Mdot
.915 .834 .484 r
.75314 .64781 m .79735 .62295 L .77421 .6689 L F
.75314 .64781 m .77463 .59919 L .79735 .62295 L F
.698 .133 .133 r
.74095 .75976 Mdot
.619 .585 .37 r
.33132 .77463 m .30382 .71909 L .34083 .75888 L F
.682 .645 .403 r
.3753 .80591 m .33132 .77463 L .34083 .75888 L F
.698 .133 .133 r
.79134 .50201 Mdot
.427 .381 .25 r
.25505 .55894 m .27753 .48708 L .28417 .53453 L F
.508 .461 .296 r
.26991 .60662 m .25505 .55894 L .28417 .53453 L F
.788 .748 .458 r
.47437 .84991 m .429 .82334 L .47729 .84596 L F
.47437 .84991 m .42349 .83128 L .429 .82334 L F
.907 .853 .51 r
.57414 .84475 m .62766 .82869 L .57747 .84862 L F
.668 .579 .339 r
.6274 .38207 m .67408 .35665 L .67827 .39522 L F
.6274 .38207 m .62459 .34359 L .67408 .35665 L F
.698 .133 .133 r
.30258 .42372 Mdot
.25794 .64068 Mdot
.46799 .85113 Mdot
.523 .483 .311 r
.27312 .67596 m .26991 .60662 L .292 .65439 L F
.591 .55 .349 r
.30382 .71909 m .27312 .67596 L .292 .65439 L F
.698 .133 .133 r
.58445 .85081 Mdot
.682 .645 .403 r
.3753 .80591 m .34083 .75888 L .38301 .79401 L F
.737 .698 .432 r
.42349 .83128 m .3753 .80591 L .38301 .79401 L F
.698 .133 .133 r
.74724 .42212 Mdot
.35826 .79846 Mdot
.737 .698 .432 r
.42349 .83128 m .38301 .79401 L .429 .82334 L F
.698 .133 .133 r
.79339 .63899 Mdot
.79339 .63899 Mdot
.941 .876 .516 r
.66634 .79032 m .71881 .76951 L .67528 .80204 L F
.66634 .79032 m .70769 .75399 L .71881 .76951 L F
.698 .133 .133 r
.69391 .7975 Mdot
.793 .75 .459 r
.47729 .84596 m .43701 .81589 L .48144 .84228 L F
.47729 .84596 m .429 .82334 L .43701 .81589 L F
.698 .133 .133 r
.41123 .8289 Mdot
.486 .424 .268 r
.3149 .46428 m .31503 .41995 L .35903 .4005 L F
.416 .362 .236 r
.27753 .48708 m .31503 .41995 L .3149 .46428 L F
.498 .443 .282 r
.28417 .53453 m .27753 .48708 L .3149 .46428 L F
.698 .133 .133 r
.64106 .82825 Mdot
.907 .853 .51 r
.57414 .84475 m .62133 .82088 L .62766 .82869 L F
.898 .844 .505 r
.56961 .84117 m .62133 .82088 L .57414 .84475 L F
.927 .867 .515 r
.62133 .82088 m .67528 .80204 L .62766 .82869 L F
.62133 .82088 m .66634 .79032 L .67528 .80204 L F
.866 .781 .454 r
.74465 .57755 m .78908 .55085 L .77463 .59919 L F
.74465 .57755 m .75754 .52726 L .78908 .55085 L F
.698 .133 .133 r
.47229 .84563 Mdot
.58004 .84533 Mdot
.58004 .84533 Mdot
.798 .753 .46 r
.48144 .84228 m .44736 .80914 L .48673 .83896 L F
.48144 .84228 m .43701 .81589 L .44736 .80914 L F
.922 .845 .494 r
.7252 .69508 m .77421 .6689 L .74403 .71306 L F
.7252 .69508 m .75314 .64781 L .77421 .6689 L F
.521 .448 .275 r
.40847 .38572 m .41174 .34722 L .46361 .33777 L F
.467 .399 .25 r
.35903 .4005 m .41174 .34722 L .40847 .38572 L F
.898 .844 .505 r
.56961 .84117 m .61255 .81364 L .62133 .82088 L F
.889 .834 .499 r
.56398 .83798 m .61255 .81364 L .56961 .84117 L F
.698 .133 .133 r
.42378 .33783 Mdot
.591 .55 .349 r
.30382 .71909 m .292 .65439 L .32076 .70069 L F
.649 .606 .38 r
.34083 .75888 m .30382 .71909 L .32076 .70069 L F
.745 .657 .383 r
.67837 .44013 m .72416 .41325 L .72429 .45774 L F
.67837 .44013 m .67827 .39522 L .72416 .41325 L F
.698 .133 .133 r
.62521 .33707 Mdot
.747 .704 .434 r
.429 .82334 m .39449 .78279 L .43701 .81589 L F
.429 .82334 m .38301 .79401 L .39449 .78279 L F
.81 .722 .421 r
.71892 .50675 m .76391 .4794 L .75754 .52726 L F
.71892 .50675 m .72429 .45774 L .76391 .4794 L F
.804 .757 .461 r
.48673 .83896 m .45981 .80328 L .49304 .83609 L F
.48673 .83896 m .44736 .80914 L .45981 .80328 L F
.637 .552 .327 r
.57316 .37433 m .62459 .34359 L .6274 .38207 L F
.57316 .37433 m .57185 .33592 L .62459 .34359 L F
.698 .133 .133 r
.2872 .69148 Mdot
.889 .834 .499 r
.56398 .83798 m .60149 .80715 L .61255 .81364 L F
.88 .824 .494 r
.55738 .83527 m .60149 .80715 L .56398 .83798 L F
.508 .461 .296 r
.26991 .60662 m .28417 .53453 L .29761 .58421 L F
.572 .524 .332 r
.292 .65439 m .26991 .60662 L .29761 .58421 L F
.698 .133 .133 r
.47871 .84064 Mdot
.57349 .84038 Mdot
.912 .851 .506 r
.61255 .81364 m .66634 .79032 L .62133 .82088 L F
.698 .133 .133 r
.76424 .69001 Mdot
.76424 .69001 Mdot
.649 .606 .38 r
.34083 .75888 m .32076 .70069 L .3553 .74397 L F
.7 .657 .408 r
.38301 .79401 m .34083 .75888 L .3553 .74397 L F
.811 .762 .463 r
.49304 .83609 m .47404 .79847 L .50021 .83374 L F
.49304 .83609 m .45981 .80328 L .47404 .79847 L F
.7 .657 .408 r
.38301 .79401 m .3553 .74397 L .39449 .78279 L F
.698 .133 .133 r
.26835 .55685 Mdot
.88 .824 .494 r
.55738 .83527 m .58844 .80162 L .60149 .80715 L F
.87 .814 .489 r
.54998 .83311 m .58844 .80162 L .55738 .83527 L F
.923 .851 .501 r
.69169 .73944 m .74403 .71306 L .70769 .75399 L F
.69169 .73944 m .7252 .69508 L .74403 .71306 L F
.698 .133 .133 r
.41929 .81783 Mdot
.565 .487 .295 r
.46182 .3762 m .46361 .33777 L .51759 .33395 L F
.521 .448 .275 r
.40847 .38572 m .46361 .33777 L .46182 .3762 L F
.698 .133 .133 r
.78221 .55514 Mdot
.63275 .81723 Mdot
.63275 .81723 Mdot
.49022 .32854 Mdot
.818 .767 .466 r
.50021 .83374 m .48969 .79487 L .50805 .83199 L F
.50021 .83374 m .47404 .79847 L .48969 .79487 L F
.698 .133 .133 r
.55856 .32828 Mdot
.48705 .83636 Mdot
.603 .521 .312 r
.51734 .37235 m .57185 .33592 L .57316 .37433 L F
.51734 .37235 m .51759 .33395 L .57185 .33592 L F
.87 .814 .489 r
.54998 .83311 m .57371 .79718 L .58844 .80162 L F
.861 .805 .484 r
.54196 .83156 m .57371 .79718 L .54998 .83311 L F
.698 .133 .133 r
.56506 .83614 Mdot
.92 .853 .505 r
.6537 .77939 m .70769 .75399 L .66634 .79032 L F
.912 .851 .506 r
.61255 .81364 m .6537 .77939 L .66634 .79032 L F
.698 .133 .133 r
.32484 .7392 Mdot
.826 .773 .469 r
.50805 .83199 m .50634 .79257 L .51636 .83087 L F
.50805 .83199 m .48969 .79487 L .50634 .79257 L F
.758 .711 .436 r
.43701 .81589 m .4095 .77257 L .44736 .80914 L F
.43701 .81589 m .39449 .78279 L .4095 .77257 L F
.565 .487 .295 r
.46182 .3762 m .51759 .33395 L .51734 .37235 L F
.92 .853 .505 r
.6537 .77939 m .69169 .73944 L .70769 .75399 L F
.861 .805 .484 r
.54196 .83156 m .55769 .79399 L .57371 .79718 L F
.851 .796 .48 r
.53354 .83065 m .55769 .79399 L .54196 .83156 L F
.882 .8 .468 r
.72554 .62864 m .77463 .59919 L .75314 .64781 L F
.72554 .62864 m .74465 .57755 L .77463 .59919 L F
.698 .133 .133 r
.72676 .738 Mdot
.72676 .738 Mdot
.36947 .78189 Mdot
.834 .78 .472 r
.51636 .83087 m .52354 .79164 L .52493 .83042 L F
.51636 .83087 m .50634 .79257 L .52354 .79164 L F
.851 .796 .48 r
.53354 .83065 m .54081 .79212 L .55769 .79399 L F
.842 .788 .476 r
.52493 .83042 m .54081 .79212 L .53354 .83065 L F
.54 .472 .293 r
.35893 .44529 m .35903 .4005 L .40847 .38572 L F
.486 .424 .268 r
.3149 .46428 m .35903 .4005 L .35893 .44529 L F
.842 .788 .476 r
.52493 .83042 m .52354 .79164 L .54081 .79212 L F
.698 .133 .133 r
.68233 .78099 Mdot
.68233 .78099 Mdot
.498 .443 .282 r
.28417 .53453 m .3149 .46428 L .32061 .51294 L F
.56 .505 .318 r
.29761 .58421 m .28417 .53453 L .32061 .51294 L F
.698 .133 .133 r
.49696 .83296 Mdot
.55507 .8328 Mdot
.897 .835 .497 r
.60149 .80715 m .6537 .77939 L .61255 .81364 L F
.698 .133 .133 r
.35716 .39846 Mdot
.572 .524 .332 r
.292 .65439 m .29761 .58421 L .31756 .63454 L F
.626 .577 .362 r
.32076 .70069 m .292 .65439 L .31756 .63454 L F
.698 .133 .133 r
.69211 .39724 Mdot
.30277 .47363 Mdot
.50807 .83061 Mdot
.54391 .83051 Mdot
.551 .489 .306 r
.32061 .51294 m .3149 .46428 L .35893 .44529 L F
.698 .133 .133 r
.74706 .47208 Mdot
.715 .63 .371 r
.62747 .42729 m .67827 .39522 L .67837 .44013 L F
.62747 .42729 m .6274 .38207 L .67827 .39522 L F
.698 .133 .133 r
.51992 .82938 Mdot
.53203 .82935 Mdot
.768 .718 .439 r
.44736 .80914 m .42773 .76366 L .45981 .80328 L F
.44736 .80914 m .4095 .77257 L .42773 .76366 L F
.716 .669 .413 r
.39449 .78279 m .37446 .73034 L .4095 .77257 L F
.39449 .78279 m .3553 .74397 L .37446 .73034 L F
.698 .133 .133 r
.43169 .80771 Mdot
.833 .75 .439 r
.70807 .55876 m .75754 .52726 L .74465 .57755 L F
.70807 .55876 m .71892 .50675 L .75754 .52726 L F
.698 .133 .133 r
.62011 .80718 Mdot
.626 .577 .362 r
.32076 .70069 m .31756 .63454 L .34346 .6838 L F
.673 .625 .389 r
.3553 .74397 m .32076 .70069 L .34346 .6838 L F
.897 .835 .497 r
.60149 .80715 m .63761 .76956 L .6537 .77939 L F
.881 .819 .489 r
.58844 .80162 m .63761 .76956 L .60149 .80715 L F
.698 .133 .133 r
.28648 .61185 Mdot
.891 .814 .479 r
.70074 .6788 m .75314 .64781 L .7252 .69508 L F
.70074 .6788 m .72554 .62864 L .75314 .64781 L F
.673 .625 .389 r
.3553 .74397 m .34346 .6838 L .37446 .73034 L F
.779 .693 .407 r
.6742 .49009 m .72429 .45774 L .71892 .50675 L F
.6742 .49009 m .67837 .44013 L .72429 .45774 L F
.698 .133 .133 r
.7642 .61031 Mdot
.899 .831 .493 r
.63761 .76956 m .69169 .73944 L .6537 .77939 L F
.778 .726 .443 r
.45981 .80328 m .4487 .75633 L .47404 .79847 L F
.45981 .80328 m .42773 .76366 L .4487 .75633 L F
.583 .511 .313 r
.40839 .43085 m .40847 .38572 L .46182 .3762 L F
.54 .472 .293 r
.35893 .44529 m .40847 .38572 L .40839 .43085 L F
.56 .505 .318 r
.29761 .58421 m .32061 .51294 L .33216 .56443 L F
.611 .557 .348 r
.31756 .63454 m .29761 .58421 L .33216 .56443 L F
.897 .824 .487 r
.67109 .72631 m .7252 .69508 L .69169 .73944 L F
.67109 .72631 m .70074 .6788 L .7252 .69508 L F
.899 .831 .493 r
.63761 .76956 m .67109 .72631 L .69169 .73944 L F
.881 .819 .489 r
.58844 .80162 m .61846 .76113 L .63761 .76956 L F
.866 .804 .481 r
.57371 .79718 m .61846 .76113 L .58844 .80162 L F
.685 .602 .358 r
.57319 .41974 m .6274 .38207 L .62747 .42729 L F
.57319 .41974 m .57316 .37433 L .6274 .38207 L F
.698 .133 .133 r
.38719 .76664 Mdot
.44802 .79898 Mdot
.31305 .66665 Mdot
.66426 .76583 Mdot
.60358 .79853 Mdot
.42032 .38056 Mdot
.731 .68 .418 r
.4095 .77257 m .39792 .7184 L .42773 .76366 L F
.4095 .77257 m .37446 .73034 L .39792 .7184 L F
.698 .133 .133 r
.62855 .37979 Mdot
.789 .734 .447 r
.47404 .79847 m .47187 .75082 L .48969 .79487 L F
.47404 .79847 m .4487 .75633 L .47187 .75082 L F
.698 .133 .133 r
.73783 .66533 Mdot
.866 .804 .481 r
.57371 .79718 m .59671 .75436 L .61846 .76113 L F
.852 .79 .474 r
.55769 .79399 m .59671 .75436 L .57371 .79718 L F
.698 .133 .133 r
.34707 .71897 Mdot
.85 .77 .453 r
.69199 .61204 m .74465 .57755 L .72554 .62864 L F
.69199 .61204 m .70807 .55876 L .74465 .57755 L F
.551 .489 .306 r
.32061 .51294 m .35893 .44529 L .3635 .49497 L F
.601 .541 .336 r
.33216 .56443 m .32061 .51294 L .3635 .49497 L F
.698 .133 .133 r
.70406 .7179 Mdot
.878 .811 .482 r
.61846 .76113 m .67109 .72631 L .63761 .76956 L F
.593 .527 .325 r
.3635 .49497 m .35893 .44529 L .40839 .43085 L F
.62 .544 .33 r
.46177 .42156 m .46182 .3762 L .51734 .37235 L F
.583 .511 .313 r
.40839 .43085 m .46182 .3762 L .46177 .42156 L F
.698 .133 .133 r
.31059 .52859 Mdot
.611 .557 .348 r
.31756 .63454 m .33216 .56443 L .34929 .61704 L F
.655 .601 .373 r
.34346 .6838 m .31756 .63454 L .34929 .61704 L F
.801 .744 .451 r
.48969 .79487 m .4966 .74729 L .50634 .79257 L F
.48969 .79487 m .47187 .75082 L .4966 .74729 L F
.698 .133 .133 r
.73932 .52713 Mdot
.654 .574 .344 r
.51733 .4178 m .57316 .37433 L .57319 .41974 L F
.51733 .4178 m .51734 .37235 L .57316 .37433 L F
.852 .79 .474 r
.55769 .79399 m .57297 .74946 L .59671 .75436 L F
.838 .777 .468 r
.54081 .79212 m .57297 .74946 L .55769 .79399 L F
.694 .641 .396 r
.37446 .73034 m .37146 .66897 L .39792 .7184 L F
.37446 .73034 m .34346 .6838 L .37146 .66897 L F
.698 .133 .133 r
.46765 .79202 Mdot
.62 .544 .33 r
.46177 .42156 m .51734 .37235 L .51733 .4178 L F
.812 .754 .456 r
.50634 .79257 m .52218 .74587 L .52354 .79164 L F
.50634 .79257 m .4966 .74729 L .52218 .74587 L F
.698 .133 .133 r
.58379 .79168 Mdot
.3573 .44909 Mdot
.838 .777 .468 r
.54081 .79212 m .54789 .7466 L .57297 .74946 L F
.825 .765 .462 r
.52354 .79164 m .54789 .7466 L .54081 .79212 L F
.698 .133 .133 r
.489 .37116 Mdot
.655 .601 .373 r
.34346 .6838 m .34929 .61704 L .37146 .66897 L F
.749 .666 .394 r
.62468 .47795 m .67837 .44013 L .6742 .49009 L F
.62468 .47795 m .62747 .42729 L .67837 .44013 L F
.698 .133 .133 r
.55966 .3709 Mdot
.825 .765 .462 r
.52354 .79164 m .52218 .74587 L .54789 .7466 L F
.698 .133 .133 r
.69197 .4479 Mdot
.803 .721 .425 r
.6658 .54352 m .71892 .50675 L .70807 .55876 L F
.6658 .54352 m .6742 .49009 L .71892 .50675 L F
.746 .691 .423 r
.42773 .76366 m .42508 .70855 L .4487 .75633 L F
.42773 .76366 m .39792 .7184 L .42508 .70855 L F
.863 .787 .465 r
.67118 .66473 m .72554 .62864 L .70074 .6788 L F
.67118 .66473 m .69199 .61204 L .72554 .62864 L F
.872 .8 .474 r
.64637 .715 m .70074 .6788 L .67109 .72631 L F
.878 .811 .482 r
.61846 .76113 m .64637 .715 L .67109 .72631 L F
.698 .133 .133 r
.48978 .78716 Mdot
.56154 .78695 Mdot
.859 .792 .472 r
.59671 .75436 m .64637 .715 L .61846 .76113 L F
.698 .133 .133 r
.41086 .75339 Mdot
.872 .8 .474 r
.64637 .715 m .67118 .66473 L .70074 .6788 L F
.698 .133 .133 r
.64027 .75271 Mdot
.5135 .78464 Mdot
.53777 .78457 Mdot
.601 .541 .336 r
.33216 .56443 m .3635 .49497 L .37273 .54798 L F
.643 .584 .361 r
.34929 .61704 m .33216 .56443 L .37273 .54798 L F
.698 .133 .133 r
.32599 .58646 Mdot
.629 .559 .341 r
.41164 .48132 m .40839 .43085 L .46177 .42156 L F
.593 .527 .325 r
.3635 .49497 m .40839 .43085 L .41164 .48132 L F
.698 .133 .133 r
.7241 .58516 Mdot
.761 .703 .428 r
.4487 .75633 m .45522 .70112 L .47187 .75082 L F
.4487 .75633 m .42508 .70855 L .45522 .70112 L F
.714 .657 .403 r
.39792 .7184 m .40406 .65669 L .42508 .70855 L F
.39792 .7184 m .37146 .66897 L .40406 .65669 L F
.72 .64 .381 r
.57189 .47081 m .62747 .42729 L .62468 .47795 L F
.57189 .47081 m .57319 .41974 L .62747 .42729 L F
.859 .792 .472 r
.59671 .75436 m .61817 .70589 L .64637 .715 L F
.84 .774 .463 r
.57297 .74946 m .61817 .70589 L .59671 .75436 L F
.636 .571 .351 r
.37273 .54798 m .3635 .49497 L .41164 .48132 L F
.821 .743 .44 r
.65336 .5986 m .70807 .55876 L .69199 .61204 L F
.65336 .5986 m .6658 .54352 L .70807 .55876 L F
.698 .133 .133 r
.37719 .70131 Mdot
.67353 .7004 Mdot
.34849 .64486 Mdot
.643 .584 .361 r
.34929 .61704 m .37273 .54798 L .3864 .60253 L F
.68 .622 .383 r
.37146 .66897 m .34929 .61704 L .3864 .60253 L F
.698 .133 .133 r
.70188 .64375 Mdot
.849 .777 .463 r
.61817 .70589 m .67118 .66473 L .64637 .715 L F
.698 .133 .133 r
.42041 .43169 Mdot
.68 .622 .383 r
.37146 .66897 m .3864 .60253 L .40406 .65669 L F
.776 .715 .434 r
.47187 .75082 m .48748 .69636 L .4966 .74729 L F
.47187 .75082 m .45522 .70112 L .48748 .69636 L F
.698 .133 .133 r
.62846 .43095 Mdot
.774 .695 .412 r
.61905 .53242 m .6742 .49009 L .6658 .54352 L F
.61905 .53242 m .62468 .47795 L .6742 .49009 L F
.698 .133 .133 r
.4396 .74278 Mdot
.661 .587 .355 r
.46356 .47253 m .46177 .42156 L .51733 .4178 L F
.629 .559 .341 r
.41164 .48132 m .46177 .42156 L .46356 .47253 L F
.698 .133 .133 r
.61127 .74227 Mdot
.3633 .50564 Mdot
.84 .774 .463 r
.57297 .74946 m .58725 .69929 L .61817 .70589 L F
.823 .758 .455 r
.54789 .7466 m .58725 .69929 L .57297 .74946 L F
.698 .133 .133 r
.68609 .50454 Mdot
.691 .614 .369 r
.51758 .46898 m .57319 .41974 L .57189 .47081 L F
.51758 .46898 m .51733 .4178 L .57319 .41974 L F
.836 .761 .452 r
.63729 .65337 m .69199 .61204 L .67118 .66473 L F
.63729 .65337 m .65336 .5986 L .69199 .61204 L F
.791 .729 .441 r
.4966 .74729 m .52091 .69444 L .52218 .74587 L F
.4966 .74729 m .48748 .69636 L .52091 .69444 L F
.849 .777 .463 r
.61817 .70589 m .63729 .65337 L .67118 .66473 L F
.661 .587 .355 r
.46356 .47253 m .51733 .4178 L .51758 .46898 L F
.823 .758 .455 r
.54789 .7466 m .55451 .69543 L .58725 .69929 L F
.806 .743 .448 r
.52218 .74587 m .55451 .69543 L .54789 .7466 L F
.52218 .74587 m .52091 .69444 L .55451 .69543 L F
.732 .672 .411 r
.42508 .70855 m .44037 .6474 L .45522 .70112 L F
.42508 .70855 m .40406 .65669 L .44037 .6474 L F
.636 .571 .351 r
.37273 .54798 m .41164 .48132 L .41819 .5355 L F
.671 .608 .373 r
.3864 .60253 m .37273 .54798 L .41819 .5355 L F
.698 .133 .133 r
.48903 .42256 Mdot
.55963 .42231 Mdot
.827 .757 .452 r
.58725 .69929 m .63729 .65337 L .61817 .70589 L F
.666 .597 .364 r
.41819 .5355 m .41164 .48132 L .46356 .47253 L F
.698 .133 .133 r
.47224 .73535 Mdot
.57846 .73503 Mdot
.795 .718 .427 r
.61073 .58882 m .6658 .54352 L .65336 .5986 L F
.61073 .58882 m .61905 .53242 L .6658 .54352 L F
.698 .133 .133 r
.41408 .6871 Mdot
.747 .67 .4 r
.56928 .5259 m .62468 .47795 L .61905 .53242 L F
.56928 .5259 m .57189 .47081 L .62468 .47795 L F
.698 .133 .133 r
.37508 .56589 Mdot
.703 .641 .392 r
.40406 .65669 m .42787 .59153 L .44037 .6474 L F
.40406 .65669 m .3864 .60253 L .42787 .59153 L F
.698 .133 .133 r
.63629 .68641 Mdot
.671 .608 .373 r
.3864 .60253 m .41819 .5355 L .42787 .59153 L F
.698 .133 .133 r
.50732 .73148 Mdot
.67453 .5649 Mdot
.54328 .73137 Mdot
.75 .688 .418 r
.45522 .70112 m .47934 .64144 L .48748 .69636 L F
.45522 .70112 m .44037 .6474 L .47934 .64144 L F
.812 .738 .44 r
.6 .64512 m .65336 .5986 L .63729 .65337 L F
.827 .757 .452 r
.58725 .69929 m .6 .64512 L .63729 .65337 L F
.698 .133 .133 r
.39225 .62727 Mdot
.807 .738 .443 r
.55451 .69543 m .6 .64512 L .58725 .69929 L F
.698 .133 .133 r
.4242 .4894 Mdot
.6577 .62642 Mdot
.812 .738 .44 r
.6 .64512 m .61073 .58882 L .65336 .5986 L F
.694 .622 .376 r
.46716 .52747 m .46356 .47253 L .51758 .46898 L F
.666 .597 .364 r
.41819 .5355 m .46356 .47253 L .46716 .52747 L F
.698 .133 .133 r
.6248 .4887 Mdot
.721 .646 .388 r
.51808 .52423 m .57189 .47081 L .56928 .5259 L F
.51808 .52423 m .51758 .46898 L .57189 .47081 L F
.769 .703 .426 r
.48748 .69636 m .51978 .63904 L .52091 .69444 L F
.48748 .69636 m .47934 .64144 L .51978 .63904 L F
.697 .63 .384 r
.42787 .59153 m .41819 .5355 L .46716 .52747 L F
.807 .738 .443 r
.55451 .69543 m .56042 .64028 L .6 .64512 L F
.787 .72 .434 r
.52091 .69444 m .56042 .64028 L .55451 .69543 L F
.694 .622 .376 r
.46716 .52747 m .51758 .46898 L .51808 .52423 L F
.787 .72 .434 r
.52091 .69444 m .51978 .63904 L .56042 .64028 L F
.725 .66 .401 r
.44037 .6474 m .47248 .58446 L .47934 .64144 L F
.44037 .6474 m .42787 .59153 L .47248 .58446 L F
.77 .695 .416 r
.56541 .58308 m .61905 .53242 L .61073 .58882 L F
.56541 .58308 m .56928 .5259 L .61905 .53242 L F
.698 .133 .133 r
.45622 .67711 Mdot
.59391 .67668 Mdot
.697 .63 .384 r
.42787 .59153 m .46716 .52747 L .47248 .58446 L F
.789 .717 .43 r
.56042 .64028 m .61073 .58882 L .6 .64512 L F
.698 .133 .133 r
.49037 .48088 Mdot
.55843 .48064 Mdot
.43164 .55135 Mdot
.789 .717 .43 r
.56042 .64028 m .56541 .58308 L .61073 .58882 L F
.698 .133 .133 r
.61762 .55073 Mdot
.721 .651 .394 r
.47248 .58446 m .46716 .52747 L .51808 .52423 L F
.698 .133 .133 r
.50168 .67189 Mdot
.54833 .67175 Mdot
.746 .678 .41 r
.47934 .64144 m .51882 .58161 L .51978 .63904 L F
.47934 .64144 m .47248 .58446 L .51882 .58161 L F
.698 .133 .133 r
.44247 .61486 Mdot
.745 .673 .405 r
.51882 .58161 m .56928 .5259 L .56541 .58308 L F
.51882 .58161 m .51808 .52423 L .56928 .5259 L F
.698 .133 .133 r
.60717 .61433 Mdot
.767 .697 .42 r
.51978 .63904 m .56541 .58308 L .56042 .64028 L F
.721 .651 .394 r
.47248 .58446 m .51808 .52423 L .51882 .58161 L F
.767 .697 .42 r
.51978 .63904 m .51882 .58161 L .56541 .58308 L F
.698 .133 .133 r
.49301 .54374 Mdot
.55608 .54352 Mdot
.49683 .60837 Mdot
.55266 .60819 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[293]:=",
  ImageSize->{400, 434.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1O
WZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040
oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nN
X900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3o
ool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijP
T01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?oo
o`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@
05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo
003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900
GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool0
0?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01O
WZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00
o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nN
X040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o
05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP
0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0
GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ01
0?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1O
WZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040
oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nN
X900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3o
ool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijP
T01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?oo
o`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@
05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo
003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900
GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool0
0?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01O
WZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00
aP1OWZ050;8R8Pd0GijP1@2b8R:b05nNX040oooo003505nNX0L0/R8R2`1OWZ070;8R8[40GijP0@3o
ool00;P0GijP0`2b8R8:05nNX0L0/R8R2`1OWZ070;8R8PX0GijP0`2b8R:T05nNX040oooo002c05nN
X0<0/R8R00<0GijP0;8R8P2b8R800`2b8R8905nNX0D0/R8R1@0B30L:01`B2`D0/R8R2@1OWZ050;8R
8P0405nNX02b8R80/R8R0;8R8Yl0GijP0@3oool00;80GijP2P2b8R8505nNX0D04P`70`2b8R86018<
1`/0718;0`2b8R8201`B2`D08aL=0`1OWZ0:0;8R8Yh0GijP0@3oool00;80GijP202b8R8600<20@@0
4P`70`2b8R88034O4P`0>RHF0`2b8R8203XV5P/08aL=1P2b8R:N05nNX040oooo002Y05nNX0<0/R8R
1P1OWZ050;8R8PL00`811@0a7a850;8R8PL0<AlB2`0j9QH50;8R8P80>RHF1`13;1T402<G3@D0/R8R
1P1OWZ030;8R8YD0GijP0@3oool00:P0GijP1@2b8R8305nNX080000000@00`810;8R8P2b8R80/R8R
0`030P4502@G3PD0<AlB1@2b8R87034O4P/0>RHF1@2b8R8203XV5Pl0@b`I0P0U60h405nNX0D0/R8R
U01OWZ010?ooo`00X@1OWZ030;8R8P@0GijP1@2b8R8010000000/R8R0;8R8P2b8R8300<20@X091L>
1@0a7a850;8R8PL0<AlB2`0j9QH50;8R8P80>RHF4013;1T01@1:<Q`0/R8R0;8R8P2b8R809AP>00D0
/R8R101OWZ030;8R8Xd0GijP0@3oool00:00GijP1@2b8R8305nNX080/R8R0`0000050;8R8P/091L>
1`0a7a830;8R8PP0<AlB300j9QH30;8R8P<0>RHF4013;1T50;8R8P<09AP>0P2b8R8305nNX0D0/R8R
S01OWZ010?ooo`00X01OWZ050;8R8P0305nNX0000000000000<000000P0D3@L50;8R8P/091L>4@0a
7a8C03XV5Q00@b`I1@2b8R8304Xb70809AP>00<08aL=05nNX01OWZ001@2b8R:<05nNX040oooo002P
05nNX0D0/R8R0P00000601@=1`D0/R8R2P0T5`hB05]7:a@0J58a1P1bFc@904</6@D0/R8R1P1:<Q`0
0`0U60h08aL=0;8R8P040;8R8X`0GijP0@3oool00:40GijP0P2b8R8901@=1`8091L>0`2b8R8502@G
3PH0BCLR4P1KAb/D06QB<@`0LU/d1013;1T30;8R8PX0BS8L0`2b8R:=05nNX040oooo002O05nNX0`0
50d71@0T5`h<04Tg8PL0FdL[0`2b8R8805]7:`l0J58a0`2b8R8206QB<A80LU/d301:<Q`204`c7@03
02<G3@1OWZ00GijP08X0GijP0@3oool009T0GijP0`2b8R8205nNX0030000000D3@L050d700T050d7
4P19=b8605]7:`D0/R8R1`1KAb/>06QB<@D0/R8R00<0J58a079K=01bFc@04@1bFc@307QP=PT0BS8L
101<<ad0101OWZ00/R8R0;8R8P2b8R:605nNX040oooo002H05nNX0D0/R8R00<0000001@=1`0D3@L0
200D3@L203DU6A80BCLR1P1KAb/50;8R8PL0FdL[3P1XDS450;8R8P80J58a4P1bFc@607QP=PL0BS8L
0`1<<ad50;8R8PD0GijP0`2b8R9m05nNX040oooo002A05nNX0<0/R8R101OWZ050;8R8PP050d71@0e
9ATA04Tg8PL0FdL[1@2b8R8705]7:`h0J58a1@2b8R8206QB<A80LU/d2P1hH3H404Xb7080C3<M1@2b
8R80101<<ad0GijP05nNX01OWZ050;8R8W`0GijP0@3oool00900GijP1@2b8R8305nNX0D0/R8R1@0D
3@L703DU6@0404Tg8P2b8R80/R8R0;8R8Ph0BCLR201KAb/30;8R8PP0FdL[3`1XDS430;8R8P<0J58a
4P1bFc@30;8R8PX0N60f0P1:<Q`00`1<<ad0/R8R0;8R8P030;8R8P<0C3<M00<0GijP0;8R8P2b8R80
0`2b8R9l05nNX040oooo002@05nNX0D0/R8R00@0GijP00000000000000000`2b8R8301@=1`X0=BDI
1@2b8R8=04Tg8Q<0FdL[5@1XDS4A079K=0D0/R8R301hH3H0101<<ad0/R8R0;8R8P2b8R8504`c7@03
04H^6`2b8R80/R8R0080/R8RO01OWZ010?ooo`00T01OWZ040;8R8PH000000P0D3@L<03DU6@0304Tg
8P2b8R80/R8R00<0/R8R3@19=b8905]7:`X0O6Ln5@27LD@A079K=0D0/R8R3@1hH3H207UQ=@L0C3<M
0P16;Q/00`2b8R80GijP05nNX01k05nNX040oooo002A05nNX0030;8R8P000000000000D000003`0e
9AT00`19=b80/R8R0;8R8P030;8R8P`0BCLR501lIchF08MaA0H0T7Y72P1bFc@50;8R8Pd0N60f101i
HCD604`c7@<0ARhKO01OWZ010?ooo`00T@1OWZ06000000807QD>3`0e9AT204Tg8P<0/R8R2019=b85
06iK>1@0O6Ln5P27LD@=091jA`@0LU/d0`2b8R8?07QP=PH0NF4e101<<ad304H^6g/0GijP0@3oool0
08l0GijP1P00000301hE3Pl0=BDI2@19=b8:06iK>1@0O6Ln5P27LD@C091jAa00N60f201iHCD304`c
7@@0ARhK0`1OWZ030;8R8W<0GijP0@3oool008L0GijP0`2b8R8305nNX0H000001@0N5@h?03DU6@@0
BCLR3`1^FcPD07aW?QH0Qg54502@NTL309R0BPd0N60f101iHCD30;8R8P<0NF4e00<0C3<M04H^6`16
;Q/00`16;Q/50;8R8W80GijP0@3oool008H0GijP1@2b8R800`1OWZ00000000000003000000807QD>
0`2b8R800`0N5@h0=BDI03DU6@0=03DU6A@0KU/h501lIchF08MaA1@0T7Y71`2HP4X907QP=P<0NF4e
1@2b8R8407UQ=@@0ARhK1@2b8R9b05nNX040oooo002505nNX0H0/R8R1000000301hE3PD0/R8R300e
9AT305a;;a@0KU/h501lIchF08MaA1@0T7Y72P2HP4X707QP=P80NF4e1@2b8R8507UQ=@0307AK<016
;Q/0ARhK00L0/R8RL01OWZ010?ooo`00Q01OWZ070;8R8P8000001@0N5@h50;8R8PP0=BDI1`1LBblC
06iK>0T0O6Ln0`2b8R8907aW?Pl0Qg540`2b8R8408MaA1@0T7Y73P2HP4X307QP=P80NF4e1@2b8R86
07UQ=@80M5/`00<0ARhK0;8R8P2b8R801@2b8R9_05nNX040oooo002405nNX080/R8R00@000000;8R
8P2b8R80/R8R200N5@h50;8R8PD0=BDI2P1LBblC06iK>0P0O6Ln1@2b8R8807aW?Ph0Qg541@2b8R83
08MaA1@0T7Y74@2HP4X307UQ=@<0/R8R1`1iHCD407AK<0<0ARhK0`2b8R9_05nNX040oooo002405nN
X0030;8R8P00000000000080000000<00P4001hE3P0N5@h01`0N5@h30;8R8P80=BDI3P1LBblC06iK
>0P0O6Ln1@2b8R8807aW?Ph0Qg541@2b8R8308MaA1@0T7Y74P2HP4X209f5C0/0NF4e101dFc0304H^
6`80/R8RK`1OWZ010?ooo`00Q01OWZ03000000800P402`0N5@hB05a;;a<0KU/h201lIch50;8R8PP0
O6Ln3P27LD@50;8R8P<0Qg545@2@NTLA09R0BP@0WHE<2@1iHCD607AK<080ARhKL01OWZ010?ooo`00
P`1OWZ03000000<00P402@0N5@h204@d9140G4/_0`1^FcP30;8R8Ph0KU/h2@1lIch30;8R8PT0O6Ln
3`27LD@30;8R8P@0Qg54502@NTL30;8R8Pl0V81:1`2MQD`707UQ=@L0M5/`00<0ARhK05nNX01OWZ00
K@1OWZ010?ooo`00PP1OWZ02000000@00P40200N5@h404@d9140G4/_0P1^FcP50;8R8Pd0KU/h5@1l
IchF08MaA1<0T7Y71@2b8R8>09R0BPT0WHE<1P1iHCD807AK<6h0GijP0@3oool00840GijP00<00000
008100020@000`020@0701hE3PH0A3@T4@1LBbl206iK>0D0/R8R301^FcPF091lBaH0VXE?1`2SSE<<
091jA`D0/R8R3`2HP4X;09f5C0<0NF4e2@1dFc1]05nNX040oooo001i05nNX0<0/R8R101OWZ030;8R
8P@00P401@0N5@h804@d9140G4/_0P1^FcP50;8R8PL0KU/h1@25LTHF091lBaH0VXE?3P2SSE<5091j
A`D0/R8R3`2HP4X=09f5C080NF4e1P1dFc030;8R8P0406mG;P1OWZ00GijP05nNX0<0/R8RI@1OWZ01
0?ooo`00N01OWZ050;8R8P80GijP1@2b8R82008100@07QD>2@14=2@B05a;;`<0KU/h0`2b8R8306iK
>0X0QG965P2@O4/F09Z5CaD0XheC0P2b8R8@09R0BPl0WHE<1@1dFc050;8R8P0306mG;P1OWZ00/R8R
00@0/R8RI01OWZ010?ooo`00N01OWZ050;8R8P800P401@2b8R82008100807QD>2`14=2@B05a;;`@0
KU/h3`25LTHF091lBaH0VXE?5P2SSE<30:^DEPh0V81:402MQD`0102PQd/0M5/`07AK<01dFc050;8R
8P80KeL^1@2b8R9T05nNX040oooo001h05nNX0D0/R8R0P020@050;8R8P030081000N5@h0A3@T00`0
A3@T4@1LBblD08EbAQH0T7a;5P2JQDlF0:>=D`H0ZiAF302HP4X?09f5C0<0X8M;00<0M5/`0;8R8P2b
8R800`2b8R800`1dFc00KeL^06mG;P040;8R8V@0GijP0@3oool007T0GijP0`2b8R84008100<0/R8R
00<00P4004@d9014=2@02@14=2@30;8R8P0304@d901LBbl0G4/_00`0G4/_0`1gISlD08EbAQH0T7a;
5P2JQDlF0:>=D`T0ZiAF2@2HP4X509f5C0<0/R8R1`2MQD`40:27B`0407AK<02b8R80/R8R0;8R8P<0
M5/`0`1_Ebh00`2b8R80GijP05nNX01S05nNX040oooo001j05nNX08000001`020@000`0Z81L0A3@T
04@d900804@d90D0/R8R2`1LBbl607MV?a@0QG965P2@O4/F09Z5CaH0XheC302[U5H609R0BP@0WHE<
1@2b8R8709f5C0D0X8M;1@1dFc0406mG;VD0GijP0@3oool007T0GijP0P000006008100<0:R0G2P14
=2@50;8R8PP0G4/_2@1gISlD08EbAQH0T7a;5P2JQDlF0:>=D`l0ZiAF0`2HP4X409f5C0D0/R8R1`2M
QD`70:27B`@0M5/`101_EbiT05nNX040oooo001h05nNX08000001P020@0302XP5`/0A3@T1@2b8R85
05a;;``0MfHo5025LTHF091lBaH0VXE?5P2SSE<B0:^DEP@0WHE<1@2b8R8709f5C0P0X8M;101dFc04
06mG;V<0GijP0@3oool007L0GijP0`000004008100D0:R0G3014=2@30;8R8P<0G4/_3`1gISlD08Eb
AQH0T7a;5P2JQDlF0:>=Da<0ZiAF0P2bVUT209f5C0<0/R8R2@2MQD`90:27B`80M5/`1@1_EbiR05nN
X040oooo001f05nNX0<0000010020@0502XP5`l0A3@T4`1gISlD08EbAQH0T7a;5P2JQDlF0:>=Da<0
ZiAF1@2bVUT;09f5C0/0X8M;00<0M5/`06mG;P1_Ebh00`1_EbiQ05nNX040oooo001e05nNX0<00000
0`020@0702XP5`d0A3@T0P1UESLC07MV?a@0QG962P2@O4/30;8R8PT0T7a;402JQDl30;8R8P<0VXE?
5P2SSE<C0:^DEPL0/YYI2@2MQD`<0:27B`H0KeL^H01OWZ010?ooo`00L`1OWZ05000000800P40200Z
81L:04@d90D0IEHg4P1gISlE08EbAPT0T7a;1@2b8R88091lB`l0VXE?1@2b8R8209Z5CaH0XheC4`2[
U5H:0;:JF@L0WHE<302PQd/00`2LPdL0KeL^06mG;P0306mG;P0405nNX02b8R80/R8R0;8R8U/0GijP
0@3oool00700GijP0`2b8R84000000030081000Z81L0:R0G00L0:R0G2@14=2@706EF=a80MfHo5@25
LTH9091lB`D0/R8R202@O4/?09Z5C`D0/R8R0P2JQDlF0:>=Da<0ZiAF302bVUT509f5C0`0X8M;0P2L
PdL406mG;PD0/R8RFP1OWZ010?ooo`00KP1OWZ060;8R8P8000002`0Z81L604@d90X0IEHg4P1gISlE
08EbAPT0T7a;1@2b8R88091lB`l0VXE?1@2b8R8209Z5CaH0XheC4`2[U5H?0;:JF@80WHE<3@2PQd/2
09b3A`<0KeL^1P2b8R9I05nNX040oooo001]05nNX0L0/R8R00<0000000T81`0Z81L00`0Z81L30;8R
8P<0:R0G1@14=2@<06EF=a80MfHo0`25LTH30;8R8Pl0QG962P2NRe@30;8R8PT0WX]D402WTUP30;8R
8P<0Yi9H5@2SSE<30;8R8Q40ZiAF4@2bVUT80:27B`<0/R8R0P2PQd/409b3A`0306mG;P2b8R80/R8R
00@0/R8RF@1OWZ010?ooo`00K@1OWZ070;8R8P802@P70`0Z81L50;8R8P80:R0G0P14=2@?06EF=a80
MfHo0P25LTH50;8R8PT0QG961@2EPU0F09j;E1H0Yi9H202_VU/<0:>=D`D0/R8R4@2[U5HA0;:JF@03
0;ROF`2PQd/0X8M;00<0X8M;1@2b8R800`2PQd/0W8=709b3A`0309b3A`0306mG;P2b8R80/R8R00<0
/R8RF@1OWZ010?ooo`00K@1OWZ060;8R8P802@P7100Z81L50;8R8P0302XP5`1UESL0IEHg0100IEHg
4P1gISl208EbAPD0/R8R0`25LTH;09F2D1H0WX]D5P2WTUP?0:nJF`D0XheC1@2b8R8A0:^DEQ40/YYI
0`2hWe/30:27B`D0/R8R0P2PQd/509b3A`80KeL^00<0G4HU0;8R8P1OWZ00F@1OWZ010?ooo`00KP1O
WZ00102b8R80000000000000000300T81`@0:R0G1@2b8R800`1=?b/0IEHg06EF=`0?06EF=a<0MfHo
0P25LTH50;8R8Ph0UH9@5P2NRe@F0:NBF1@0[iYK1@2b8R8A0:^DEQ40/YYI1@2hWe/00`2PQd/0/R8R
0;8R8P030;8R8P80X8M;1`2LPdL00`1_Ebh0G4HU05nNX01I05nNX040oooo001^05nNX0<000001009
20L502XP5`<0/R8R0P1=?b/A06EF=a80MfHo102EPU030;8R8Pl0UH9@5P2NRe@F0:NBF1D0[iYK0`2b
8R820;NQGQ00ZiAF4@2bVUT70;ROF`<0/R8R102PQd/709b3A`0306mG;P1OWZ00GijP05P0GijP0@3o
ool006h0GijP0P00000400T81`L0:R0G101=?b/A06EF=`l0MfHo0`2:N4/F09F2D1H0WX]D5P2WTUPF
0:nJF`P0]j5N302[U5HA0;:JF@P0^9mK1P2PQd/809b3A`0305a69@1OWZ00GijP05L0GijP0@3oool0
06d0GijP0P00000500T81`H0:R0G1@1=?b/A06EF=``0MfHo1P2:N4/F09F2D1H0WX]D5P2WTUPF0:nJ
F``0]j5N202[U5HA0;:JF@X0^9mK102PQd/909b3A`0305a69@1OWZ00GijP05H0GijP0@3oool006`0
GijP0P00000500T81`D0:R0G1`1=?b/>06EF=`<0/R8R2@1gISl908YhBaH0UH9@5P2NRe@F0:NBF1H0
[iYK402gXEh40:^DEPD0/YYI0`2b8R890;:JF@`0^9mK0`2PQd/809b3A`0308ad>`1LARD0GijP05H0
GijP0@3oool006/0GijP0P00000600T81`@0:R0G201=?b/=06EF=`D0/R8R1@1gISl<08YhBaH0UH9@
5P2NRe@F0:NBF1H0[iYK502gXEh40;:JF@D0/R8R2@2bVUT=0;ROF`030:27B`2LPdL0W8=700L0W8=7
00<0S7@k05nNX01OWZ00E@1OWZ010?ooo`00J`1OWZ0800T81`<0:R0G2@1=?b/=06EF=`D0/R8R0P1g
ISl?08YhBaH0UH9@5P2NRe@F0:NBF1H0[iYK502gXEh30;jXHP030;:JF@2b8R80/R8R00<0/R8R2@2b
VUT>0;ROF`T0W8=70P2<M3]F05nNX040oooo001Z05nNX0030000000920L02@P700D02@P70P0Z81L:
04do:`h0IEHg1@2b8R8A08YhBaH0UH9@5P2NRe@F0:NBF1H0[iYK502gXEh40;jXHPD0/R8R2@2bVUT?
0;ROF`030;bSF`2LPdL0W8=700D0W8=70`2<M3/205nNX0<0/R8RD01OWZ010?ooo`00I01OWZ030;8R
8P80GijP0P00000700T81`0302XP5`1=?b/0CCl[00T0CCl[3`1UESL30;8R8Q80RWQ;5P2EPU0F09j;
E1H0Yi9H5P2_VU/D0;NQGPD0_ZQR0`2b8R8:0;:JF@l0^9mK0P2lXe/709b3A`80S7@k00<0G4HU0;8R
8P2b8R800`2b8R9?05nNX040oooo001S05nNX0D0/R8R00@0GijP0;8R8P2b8R80/R8R1@0920L=04do
:`d0IEHg101lK4@C08YhBaH0UH9@5P2NRe@F0:NBF1H0[iYK502gXEh;0;jXHPL0/YYI3`2hWe/30;bS
F`D0W8=70`2b8R800`2<M3/0/R8R0;8R8P030;8R8Tl0GijP0@3oool006<0GijP2P2b8R8300T81`03
02hU701=?b/0CCl[00/0CCl[2`1UESL607a/A1<0RWQ;5P2EPU0F09j;E1H0Yi9H5P2_VU/D0;NQGPd0
_ZQR1@2bVUT?0;ROF`@0_:=K0`2LPdL50;8R8P0308ad>`2b8R80/R8R0080/R8RC`1OWZ010?ooo`00
H`1OWZ0:0;8R8P802@P70P0^9A`=04do:`P0IEHg2@1lK4@C08YhBaH0UH9@5P2NRe@F0:NBF1H0[iYK
502gXEh@0;jXHP80/YYI3`2hWe/50;bSF`80W8=71@2b8R8208ad>`80/R8RD01OWZ010?ooo`00I01O
WZ030;8R8P030000002b8R80/R8R00<0/R8R00@02@P702hU700^9A`0;RDL3@1=?b/606EF=`/0O6a4
4`2:N4/F09F2D1H0WX]D5P2WTUPF0:nJFa@0]j5N4P2nZ68?0;ROF`L0_:=K1@2b8R8308ad>e40GijP
0@3oool006H0GijP0P0000001@0920L0/R8R0;8R8P2b8R802@P700@0;RDL3@1=?b/406EF=`d0O6a4
4`2:N4/F09F2D1H0WX]D5P2WTUPF0:nJFa@0]j5N4P2nZ6820<J_I@d0^9mK202lXe/30;8R8P@0S7@k
D@1OWZ010?ooo`00I@1OWZ03000000<02@P71@0^9A`704do:`<0/R8R101=?b/206EF=`l0O6a44`2:
N4/F09F2D0X0WX]D0`2b8R8909j;E100Yi9H0`2b8R830:NBF1H0[iYK502gXEhB0;jXHP@0aZmU1@2h
We/30;8R8P@0^9mK202lXe/209b3A`D0S7@kD01OWZ010?ooo`00I@1OWZ02000000<02@P71P0^9A`6
04do:`D0/R8R0P1=?b/B07a/A1<0RWQ;5P2EPU0909j;E0D0/R8R202YUUX?0;2MGPD0/R8R0P2`WEhF
0:nJFa@0]j5N4P2nZ6860<J_I@80^9mK1@2b8R830;ROF`T0_:=K00<0W8=708ad>`2<M3/00`2<M3/0
0`1eH340GijP05nNX01=05nNX040oooo001T05nNX0<000000P0920L702hU70H0CCl[1@2b8R800`1=
?b/0JU`l07a/A00A07a/A1<0RWQ;5P2EPU090:VFFPD0/R8R202YUUX?0;2MGPD0/R8R0P2`WEh80;RS
H@h0[iYK502gXEhB0;jXHPP0aZmU1@2b8R830;ROF`X0_:=K1P2<M3]?05nNX040oooo001S05nNX0<0
00000P0920L802hU70H0CCl[1@2b8R8206YL?180O6a44`2:N4/?09F2D0L0XHmG2@2YUUX50;8R8PP0
ZIIJ3`2`WEh50;8R8P80/9eN3`2hXf460:nJF`<0/R8R4P2gXEhB0;jXHPP0aZmU1@2b8R830;ROF`/0
_:=K1@2<M3/00`1eH340GijP05nNX01<05nNX040oooo001S05nNX0<0000000<02@P702hU700^9A`0
1`0^9A`704do:`<0/R8R0`1ZG3`B07a/A1<0RWQ;102EPU030;8R8P0309F2D02QSeL0XHmG00`0XHmG
2P2YUUX30;8R8PT0ZIIJ402`WEh30;8R8P<0/9eN502hXf450;8R8Q40]j5N4P2nZ6890<J_I@<0/R8R
102hWe/;0;bSF`030;ZQF02<M3/0S7@k00<0S7@kCP1OWZ010?ooo`00H`1OWZ02000000X0;RDL201=
?b/606YL?180O6a44`2:N4/30:6?E`D0/R8R3P2QSeLF0:VFFQH0/9eN502hXf450;8R8P030;nZI02g
XEh0]j5N00h0]j5N4P2nZ68=0<J_I@<0^9mK2`2lXe/20;ZQF0@0S7@k00<0MF0a05nNX01OWZ00B`1O
WZ010?ooo`00HP1OWZ03000000X0;RDL1P1=?b/806YL?180O6a4402:N4/409N6D`80XHmG1@2b8R8>
0:6?EaH0ZIIJ5P2`WEhD0;RSH@D0/R8R1@2oZV@<0;NQGQ80_ZQR3`36[fD00`2hWe/0_:=K0;bSF`09
0;bSF`<0^Z5H0`2<M3/00`1eH340GijP05nNX01;05nNX040oooo001R05nNX080000000<04Q4>02hU
700^9A`0200^9A`404do:`X0JU`l4P1lK4@=08YhB`L0UhIC0P2QSeL50;8R8Ph0XHmG5P2YUUXF0;2M
GQD0^:=Q0`2b8R8:0;nZI0P0]j5N4P2nZ68@0<J_I@/0_:=K102jXEP308ad>`0307EP<@1OWZ00GijP
04X0GijP0@3oool005d0GijP0`2b8R800`1OWZ00000000000002018A3PX0;RDL0`1=?b/;06YL?180
O6a42P2:N4/:09N6D`<0XHmG0`2b8R8?0:6?EaH0ZIIJ5P2`WEhF0;RSHA00_jYT102gXEhB0;jXHQ00
aZmU0P3=]FL:0;bSF`@0^Z5H0P2<M3/0101eH340/R8R0;8R8P2b8R9905nNX040oooo001L05nNX0D0
/R8R0P000002018A3PX0;RDL00<0CCl[06YL?01ZG3`02`1ZG3`B07a/A0L0RWQ;3@2GQU<E0:6?EaH0
ZIIJ5P2`WEhF0;RSHA@0_jYT4P2nZ68@0<J_I@<0cKEW2@2lXe/50;ZQF080S7@k102b8R9805nNX040
oooo001L05nNX0D0/R8R00@00000018A3P0B4@h04Q4>2@0^9A`?06YL?180O6a4102:N4/@09N6DaD0
XHmG5P2YUUXF0;2MGQH0^:=Q502oZV@30<NaJ080_ZQR0`2b8R8:0;jXHQ00aZmU103=]FL80;bSF`H0
^Z5H1@2b8R9805nNX040oooo001L05nNX0D0/R8R0`0B4@h902hU70030556<01ZG3`0JU`l00d0JU`l
401lK4@30;8R8Q<0UhIC5@2QSeLF0:VFFQH0/9eN5P2hXf4D0;nZI0@0ak5X1@2b8R890;jXHQ00aZmU
1P3=]FL60;bSF`L0^Z5H102b8R9805nNX040oooo001L05nNX0D0/R8R0`0B4@h802hU7080DDH`3`1Z
G3`?07a/A0D0/R8R4P2GQU<E0:6?EaH0ZIIJ5P2`WEhF0;RSHA@0_jYT1037/FP50;8R8PT0_ZQR4036
[fD70<feI`<0_:=K0`2b8R870;ZQF0<0/R8RB01OWZ010?ooo`00G@1OWZ030;8R8P@04Q4>0P0^9A`3
0;8R8P80;RDL0`1AAS0?06YL?0h0O6a400<0SGe>0;8R8P2b8R800`2b8R8B09N6DaD0XHmG5P2YUUXF
0;2MGQH0^:=Q502oZV@40<NaJ0D0/R8R0P37/FP70;jXHQ00aZmU203=]FL00`2lXe/0/R8R0;8R8P03
0;8R8PH0^Z5H0P2b8R9905nNX040oooo001N05nNX0030000000B4@h04Q4>00<04Q4>00<0;RDL0;8R
8P2b8R800`2b8R840556<0l0JU`l301lK4@308emCPD0/R8R4P2GQU<E0:6?EaH0ZIIJ5P2`WEhF0;RS
HA@0_jYT1@37/FP30;8R8PD0ak5X1@2nZ68@0<J_I@T0cKEW1@2b8R870;ZQF00307EP<@1OWZ00GijP
04L0GijP0@3oool005h0GijP00<00000018A3P0B4@h00`0B4@h00`0^9A`0/R8R0;8R8P030;8R8P@0
DDH`3`1ZG3`907a/A0L0SGe>0`2b8R8C09N6DaD0XHmG5P2YUUXF0;2MGQH0^:=Q502oZV@@0<NaJ080
_ZQR4036[fD90<feI`D0/R8R1`2jXEP00`1eH340GijP05nNX01705nNX040oooo001N05nNX0D04Q4>
0P0^9A`50;8R8P@0DDH`3`1ZG3`707a/A0`0SGe>502GQU<D0:6?EaH0ZIIJ5P2`WEhF0;RSHA@0_jYT
4P37/FP@0<J_I@X0cKEW0`2b8R880;ZQF0030:RAC01eH340GijP04L0GijP0@3oool005d0GijP1P0B
4@h302hU70<0/R8R1@1AAS0?06YL?0D0O6a43P2=ODhD09N6Da@0XHmG5P2YUUXF0;2MGQH0^:=Q502o
ZV@B0<NaJ080ckQ[3P36[fD=0<feI`P0^Z5H00<0Z95<07EP<@1OWZ00A`1OWZ010?ooo`00G@1OWZ06
018A3P<0;RDL201AAS0?06YL?0<0O6a4402=ODhD09N6Da@0XHmG5P2YUUXF0;2MGQH0^:=Q502oZV@B
0<NaJ0@0ckQ[3036[fD=0<feI`030=:jJ02jXEP0^Z5H00D0^Z5H0P2XTD`00`1eH340GijP05nNX015
05nNX040oooo001L05nNX0030000000B4@h04Q4>00@04Q4>0P0^9A`90556<0l0JU`l4`2=ODhD09N6
Da@0XHmG5P2YUUXF0;2MGQH0^:=Q502oZV@B0<NaJ0H0ckQ[2P36[fD=0<feI`80d[YX1`2jXEP00`2X
TD`0MF0a05nNX01605nNX040oooo001L05nNX00300@40`0B4@h04Q4>00@04Q4>00<0;RDL0556<01A
AS00201AAS0906YL?0<0/R8R0P1ZG3`207maB180SGe>502GQU<D0:6?EaH0ZIIJ5P2`WEhF0;RSHA@0
_jYT4P37/FP80<nhJ`040<J_I@2b8R80/R8R0;8R8P@0aZmU3@3=]FL30=:jJ0H0^Z5H0P2XTDa705nN
X040oooo001K05nNX0030000000410<04Q4>00@04Q4>301AAS0806YL?0D0/R8R0`1oLDPB08emCQ@0
UhIC502QSeL;0:VFFP/0/ImP5P2hYF<F0;RSHA@0_jYT4P37/FP80<nhJ`D0/R8R0`36[fD=0<feI`@0
d[YX1@2jXEP20:RAC00307EP<@1OWZ00GijP04@0GijP0@3oool005/0GijP00<010@3018A3P0B4@h0
100B4@h<0556<0P0JU`l1@2b8R8307maB1<0SGe>4`2GQU<D0:6?EaH0/ImP5P2hYF<70;n[IPl0^:=Q
502oZV@B0<NaJ0P0ckQ[1@2b8R830<J_I@d0cKEW1@3B^VP40;ZQF0<0Z95<AP1OWZ010?ooo`00F`1O
WZ000`0410<04Q4>018A3P03018A3P0302hX7`1AAS00DDH`00X0DDH`201ZG3`50;8R8P<0Og584`2=
ODhC09N6D`h0XHmG1`2ZV5d90;6OH0<0/R8R2@2aWf0?0;RUH`<0/R8R102hYF<>0;n[IPP0^:=Q502o
ZV@B0<NaJ0P0ckQ[1@2b8R830<J_I@d0cKEW1P3B^VP30;ZQF0<0Z95<00<0MF0a05nNX02b8R800P2b
8R9105nNX040oooo001F05nNX0<0/R8R00<0GijP00@40`0410<0100B4@h202hX7``0DDH`1`1ZG3`2
07maB0<0/R8R101oLDPC08emCQ<0UhIC1`2QSeL>0:ZHG@P0/ImP1@2b8R880;6OH0h0^:ES1@2b8R83
0;RUHaD0_j]V5@2oZV@B0<NaJ0T0ckQ[0`2b8R830<nhJ`030<J_I@3=]FL0cKEW00/0cKEW1`3B^VP3
0;ZQF0<0Z95<1@2b8R9005nNX040oooo001E05nNX0D0/R8R0P0410<4018A3P80;RPO301AAS0506YL
?0/0Og584`2=ODhC09N6DaD0ZYQM202aWf050;8R8PP0/ImP3P2hYF<50;8R8P<0^:ES5@2oZfH40<Ja
JA40_jYT4P37/FP@0<nhJ`d0cKEW203B^VP20;ZQF0<0Z95<1@2b8R9005nNX040oooo001E05nNX0@0
/R8R0`0410<3018A3P<0;RPO301AAS0406YL?0`0Og584`2=ODh@09N6D`@0XY9I502ZV5d80;6OH0D0
/R8R202aWf0>0;RUH`D0/R8R0`2hYF<D0;n[IP<0/R8R1P36/FT=0;nZI140ak5X4@3?^6/20=O0K`/0
cKEW2@3B^VP01@2jXEP0/R8R0;8R8P2b8R80Z95<00@0/R8R@01OWZ010?ooo`00E@1OWZ070;8R8P80
4Q4>100^:1l<0556<080JU`l3P1oLDPC08emCPd0UhIC1`2RTUT30:ZHG@<0/R8R3P2ZV5d90;6OH0<0
/R8R2@2aWf0?0;RUH`<0/R8R102hYF<C0;n[IPD0/R8R2@36/FT90;nZI140ak5X4@3?^6/30=O0K`X0
cKEW2@3B^VP80;8R8T40GijP0@3oool005H0GijP1`2b8R8502hX7``0DDH`401oLDPC08emCPX0UhIC
2P2RTUT20:ZHG@D0/R8R3@2ZV5dE0;6OH1H0^:ES4`2oZfH50;8R8Pd0a[5Y1@2oZV@A0<NaJ140ckQ[
103G`6l90<feI`T0d[YX1@2b8R9405nNX040oooo001H05nNX0D0/R8R1@0^:1l;0556<080KF4o401o
LDPB08emCPL0UhIC3@2RTUT20:ZHG@D0/R8R3@2ZV5dE0;6OH1H0^:ES4`2oZfH50;8R8Q40a[5Y4P37
/FPA0<nhJ`H0el1_1`3=]FL90=:jJ0D0/R8R00<0PFlg05nNX01OWZ00@@1OWZ010?ooo`00F01OWZ05
0;8R8PD0;RPO2P1AAS0306eQ?a00Og584P2=ODh409N6Da00XY9I0P2ZV5d50;8R8Pd0ZYQM5@2aWf0F
0;RUHa@0_j]V0`2b8R8B0<JaJ@<0cKQ/3`37/FPA0<nhJ`L0el1_1P3=]FL:0=:jJ0<0/R8R00<0Z95<
085_=`1OWZ00@P1OWZ010?ooo`00F01OWZ00100410<0/R8R0;8R8P2b8R8602hX7`T0DDH`101]HCl@
07maB180SGe>502RTUT30:ZHG@<0/R8R3P2ZV5dE0;6OH1H0^:ES5@2oZfHD0<JaJ@D0cKQ/3@37/FPA
0<nhJ`P0el1_1@3=]FL:0=:jJ080d;QU0`2XTDa305nNX040oooo001G05nNX0<010@3200^:1l40556
<0<0/R8R00<0DDH`06eQ?`1]HCl00`1]HCl@07maB100SGe>0`2IRUHC0::BFA@0ZYQM5@2aWf0F0;RU
HaD0_j]V5036/FT80<fhK0X0ak5X4@3?^6/:0=O0K`<0/R8R2P3B^VP20=2hI@<0Z95<@`1OWZ010?oo
o`00E`1OWZ0300@40`P0;RPO0`1AAS050;8R8PD0KF4o401oLDP=08emCP<0VHYF0`2b8R8C0::BFA@0
ZYQM5@2aWf0F0;RUHaD0_j]V5036/FT30<fhK0<0/R8R103=^6`80<NaJ140ckQ[2@3G`6l50;8R8PT0
d[YX0`3@^6D20:RAC003085_=`1OWZ00GijP0400GijP0@3oool005L0GijP0P0410<00`0J61@0;RPO
02hX7`0602hX7`<0DDH`1@2b8R8506eQ?a00Og582`2=ODh409V:EPD0/R8R4P2RTUTE0:ZHGA@0/ImP
5P2hYF<E0;n[IQ@0a[5Y0P3=^6`50;8R8PH0cKQ/1@37/FPA0<nhJ`T0el1_1@2b8R890=:jJ0<0d;QU
0P2XTD`00`21KcL0GijP05nNX01005nNX040oooo001G05nNX08010@300<06QPD02hX7`0^:1l01P0^
:1l30556<0D0/R8R1P1]HCl?07maB0P0SGe>1`2IRUH50;8R8Q80XY9I5@2ZV5dD0;6OH1H0^:ES502o
ZfHD0<JaJ@<0cKQ/1@2b8R880<fhK0<0ak5X403?^6/:0=O0K`D0/R8R2@3B^VP40=2hI@030:RAC021
KcL0GijP0440GijP0@3oool005H0GijP0P0410<201XH50P0;RPO0`1AAS00101]HCl0/R8R0;8R8P2b
8R8706eQ?`l0Og581P2=ODh909V:EPD0/R8R4P2RTUTE0:ZHGA@0/ImP5P2hYF<D0;n[IQ@0a[5Y0`3=
^6`50;8R8PX0cKQ/4@3?^6/;0=O0K`<0/R8R00<0glQb0=:jJ03B^VP01`3B^VP40=2hI@80Z95<@P1O
WZ010?ooo`00EP1OWZ0200@40`806QPD200^:1l20556<0`0KF4o3`1oLDP308emCPd0VHYF0`2b8R8D
0::BFA@0ZYQM502aWf0F0;RUHa@0_j]V5036/FT40<fhK0<0/R8R2`3=^6`20=FoL0l0ckQ[3P3G`6l2
0=o8LPP0d[YX1@3@^6D00`2XTD`0PFlg05nNX01005nNX040oooo001F05nNX00400@40`0J61@06QPD
01XH50P0;RPO3P1]HCl?07maB1<0VHYF502RTUTD0:ZHGA@0/ImP5P2hYF<D0;n[IQ@0a[5Y4P3=^6`4
0=FoL0d0ckQ[3P3G`6l30=o8LPL0d[YX1@3@^6D0102XTD`0PFlg0;8R8P2b8R8o05nNX040oooo001D
05nNX080/R8R00@010@301XH500J61@06QPD200^:1l00`1CBc@0KF4o06eQ?`0;06eQ?`h0Og580P2?
PE4C09V:EQ<0XY9I502ZV5dD0;6OH1H0^:ES502oZfHD0<JaJA80cKQ/1P3E_g0;0<nhJ`h0el1_103O
b7860=:jJ0H0d;QU00@0PFlg0;8R8P2b8R80/R8R?P1OWZ010?ooo`00D`1OWZ020;8R8P0300@40`0J
61@06QPD00806QPD1`0^:1l205=;=0d0KF4o301oLDP408n1DA<0VHYF4`2RTUTD0:ZHGA@0/ImP5P2h
YF<D0;n[IQ<0a[5Y4`3=^6`80=FoL0T0ckQ[3P3G`6l50=o8LPD0d[YX1P3@^6D01021KcL0/R8R0;8R
8P2b8R8n05nNX040oooo001C05nNX080/R8R00<010@301XH500J61@00P0J61@602hX7`<0Dd/d3P1]
HCl:07maB0D0Sh5A4`2IRUHC0::BFA@0ZYQM502aWf0F0;RUHa@0_j]V4`36/FTB0<fhK0/0eKm`1`3?
^6/=0=O0K`L0glQb103B^VP60=2hI@030;VTE`2b8R80/R8R0080/R8R?@1OWZ010?ooo`00DP1OWZ03
0;8R8PD06QPD1P0^:1l305=;=0h0KF4o201oLDP0102?PE40/R8R0;8R8P2b8R8308n1DA<0VHYF4`2R
TUTD0:ZHGA@0/ImP5P2hYF<D0;n[IQ<0a[5Y4P3=^6`80=FoL0<0/R8R0P3E_g050<nhJ`d0el1_203O
b7830=:jJ0H0d;QU00<0^JAG0;8R8P2b8R800`2b8R8l05nNX040oooo001A05nNX0D0/R8R100J61@5
02hX7`@0Dd/d3P1]HCl707maB00308n1D@2b8R80/R8R00<0/R8R0`2?PE4B09V:EQ<0XY9I502ZV5dD
0;6OH1D0^:ES5@2oZfHC0<JaJA80cKQ/1`3E_g050;8R8P<0eKm`0`3?^6/=0=O0K`T0glQb0P3B^VP6
0=2hI@030;VTE`2b8R80/R8R00<0/R8R?01OWZ010?ooo`00D@1OWZ050;8R8P@06QPD100^:1l505=;
=0h0KF4o1@1oLDP308n1D@D0/R8R0`2?PE4B09V:EQ<0XY9I502ZV5dE0;RVI1@0_ZaW1`35/FX>0;n[
IQ<0a[5Y4P3=^6`70=FoL0D0/R8R1@3E_g0>0=O0K`X0glQb00<0d[YX0=2hI@3@^6D0103@^6D00`2i
Y5L0/R8R0;8R8P030;8R8S`0GijP0@3oool00540GijP1@2b8R8401XH50<0;RPO1`1CBc@=06eQ?`@0
Og58102?PE450;8R8P<0Sh5A4P2IRUHC0::BF@h0ZYQM1`2bXF8D0;RVI1@0_ZaW3P35/FX70;n[IQ80
a[5Y4`3=^6`70=FoL0D0/R8R1@3E_g020=g7M0`0el1_2`3Ob7830;8R8P<0d;QU0P2iY5L30;8R8Sd0
GijP0@3oool00580GijP0`2b8R8401XH50<0/R8R00<0;RPO05=;=01CBc@01@1CBc@=06eQ?`80Og58
1`2?PE430;8R8P@0Sh5A4`2IRUHB0::BF@L0ZYQM3P2bXF8D0;RVI1@0_ZaW5035/FXC0<JaJA80cKQ/
2@3E_g030;8R8PH0eKm`0`3Mag@;0=O0K`X0glQb1@2b8R820=2hI@80^JAG@01OWZ010?ooo`00E01O
WZ0401XH50D0/R8R1`1CBc@=06eQ?a40Sh5A4P2IRUHB0::BFAD0/Z5R502hYV@D0;j/Ia@0aK5Z1@3;
]fd>0<JaJA80cKQ/4P3E_g040=g7M0T0el1_2`3Ob7850;8R8P80d;QU0P2iY5L00`21KcL0GijP05nN
X00m05nNX040oooo001D05nNX0@06QPD1@2b8R8705=;=0`0KF4o0P22MT/@08n1DA80VHYF3`2RTUT4
0:^KGa@0/Z5R202hYV@30;8R8PT0^:IT3@2n[6L30;8R8P@0_ZaW5035/FX90<^gK@X0a[5Y4P3=^6`A
0=FoL0L0gLMd1`3G`6l;0=o8LPD0/R8R0P3@^6D20;VTE`03085_=`1OWZ00GijP03d0GijP0@3oool0
05@0GijP100J61@50;8R8PL0Dd/d2`1]HCl3089fBa00Sh5A4P2IRUH;0::BF@P0Zi]O502bXF870;RV
I0D0/R8R202hYV@<0;j/I`D0/R8R0`2n[6LD0<FaJPh0bkM]1@36/FTB0<fhK140eKm`203Mag@60=O0
K``0glQb0`2b8R830=2hI@<0^JAG?`1OWZ010?ooo`00D`1OWZ000`0;2PP06QPD01XH500301XH50<0
/R8R201CBc@906eQ?`D0PWI;402?PE4B09V:EPP0XY9I2`2[VelD0;:QHPL0^:IT1@2b8R880;RVI0`0
_ZaW1@2b8R830;j/Ia@0aK5Z4P3;]fdC0<fhK140eKm`2@3Mag@50=O0K``0glQb0`3TcG<30=2hI@<0
^JAG?`1OWZ010?ooo`00D`1OWZ000`0;2PP06QPD01XH500301XH5080;BTR2P1CBc@706eQ?`L0PWI;
402?PE4A09V:EP@0XY9I3`2[Vel40;:QHP<0/R8R3@2bXF870;RVI0D0/R8R202hYV@<0;j/I`D0/R8R
0`2n[6LB0<FaJP<0/R8R4@3;]fd30=:nL0l0cKQ/4P3E_g0;0=g7M0<0el1_2`3Ob7840>C=L`<0d;QU
0`2iY5Lo05nNX040oooo001C05nNX00300/:200J61@06QPD00<06QPD0P0]:B8:05=;=0H0KF4o2022
MT/@08n1DA40VHYF4`2[Vel30;:QHPD0/R8R302bXF880;RVI0<0/R8R2@2hYV@=0;j/I`<0/R8R102n
[6LA0<FaJPD0/R8R403;]fd60=:nL0`0cKQ/4@3E_g0=0=g7M080el1_2`3Ob7850>C=L`80d;QU0`2i
Y5L00`010@40GijP05nNX00l05nNX040oooo001C05nNX00300/:200J61@06QPD00806QPD0`0]:B8:
05=;=0@0KF4o2P22MT/@08n1D@l0VHYF0`2TUE`C0:^KG`80/Z5R1@2b8R8<0;:QHQ@0^:IT502n[6LA
0<FaJPD0/R8R403;]fd90=:nL0T0cKQ/4@3E_g0;0=g7M0<0/R8R303Ob7850>C=L`80d;QU0`2iY5L0
0`010@40GijP05nNX00l05nNX040oooo001C05nNX00300/:200J61@06QPD00806QPD0`0]:B8:05=;
=0<0KF4o0P22MT/30;8R8PH0PWI;402?PE4=09V:EPD0Y9EL4`2[Vel20;:QHPD0/R8R302bXF8D0;RV
I1@0_ZaW4@35/FX50;8R8Q00bkM]303B_W060<fhK140eKm`2P3Mag@50;8R8P/0glQb1P3TcG<01@3@
^6D0^JAG0;VTE`2iY5L00@4103h0GijP0@3oool005<0GijP00@02`X801XH500J61@06QPD100]:B8:
05=;=080KF4o0P22MT/50;8R8PH0PWI;402?PE4:09V:EPL0Y9EL4`2[Vel30;:QHP<0/R8R3@2bXF8D
0;RVI1<0_ZaW4`35/FX30;8R8Q00bkM]403B_W030<fhK140eKm`2P3Mag@50;8R8P030>K@N03Ob780
glQb00P0glQb1P3TcG<01@3@^6D0^JAG0;VTE`2iY5L00@4103h0GijP0@3oool00580GijP0P0;2PP3
01XH50D0;BTR2@1CBc@4089fB`D0/R8R1P22MT/@08n1D@L0VHYF2`2TUE`B0:^KGa@0/Z5R4`2hYV@C
0;j/Ia@0aK5Z4P3;]fdB0=:nL140eKm`2`3Mag@50;8R8P80i]1h2@3Ob7870>C=L`<0^JAG00@00@41
0;8R8P2b8R80/R8R>`1OWZ010?ooo`00D01OWZ020;8R8P802`X80P0J61@602dY8PT0Dd/d00@0L6I3
089fB`22MT/0PWI;1@2b8R86089fBa00Sh5A1@2IRUH;0:BEG0<0/R8R4@2[VelD0;:QHQ<0^:IT4`2n
[6LC0<FaJQ<0bkM]103B_W030;8R8P/0d[i`0P3IaG<?0=FoL0`0gLMd0`2b8R840>K@N0L0glQb203T
cG<30;VTE`D0/R8R>P1OWZ010?ooo`00C`1OWZ030;8R8P802`X80P0J61@602dY8PP0Dd/d0P1`IT<4
089fB`<0/R8R1`22MT/@08n1D@<0VHYF302TUE`50;8R8Q00Zi]O502bXF8C0;RVI1<0_ZaW4`35/FXC
0<^gK@<0d[i`1@2b8R8:0=:nL0@0fLEc3@3E_g0>0=g7M0H0i]1h1P3Ob7880>C=L`030=o:K`2iY5L0
^JAG00D0/R8R>P1OWZ010?ooo`00C`1OWZ030;8R8P802`X800<06QPD02dY8P0]:B801@0]:B8705=;
=0<0L6I33`22MT/?08n1D@l0Y9EL1@2b8R8A0:^KGa<0/Z5R4`2hYV@C0;j/Ia<0aK5Z4P3;]fd40=:n
L0D0/R8R2P3B_W060=W5L`/0eKm`3P3Mag@70>K@N0D0glQb203TcG<00`3ObVl0^JAG0;VTE`050;8R
8SX0GijP0@3oool004l0GijP0`2b8R8200/:200301XH500]:B80;BTR00D0;BTR1`1CBc@4071V@`h0
PWI;3@2?PE4309b>F@h0Y9EL1@2b8R8A0:^KGa<0/Z5R4`2hYV@C0;j/Ia<0aK5Z4P3;]fd40=:nL0D0
/R8R2@3B_W090=W5L`P0eKm`3`3Mag@80>K@N0@0glQb203TcG<00`3ObVl0/R8R0;8R8P040;8R8S/0
GijP0@3oool00500GijP1@2b8R8702dY8PH0Dd/d1@1`IT<>089fB`/0Sh5A1@2LSUT?0:BEG0<0/R8R
4P2[VelC0;:QHQ<0^:IT4`2n[6LC0<FaJQ80bkM]1@3B_W030;8R8PX0d[i`2`3IaG<60=FoL0h0gLMd
2P3Vd7P30=o8LPP0i<ec1@2b8R8m05nNX040oooo001A05nNX0D0/R8R1`0]:B8405=;=0H0L6I33P22
MT/908n1D@L0W8iI4P2TUE`B0:^KGa<0/Z5R4`2hYV@C0;j/Ia<0aK5Z4P3;]fdB0=:nL0d0fLEc103E
_g0>0=g7M0/0i]1h0P3Ob7880>C=L`D0/R8R?@1OWZ010?ooo`00D@1OWZ050;8R8PL0;BTR0`1CBc@8
071V@`h0PWI;1P2?PE4:09b>FA40Y9EL4P2[VelC0;:QHQ<0^:IT4`2n[6LB0<FaJQ<0bkM]4P3B_W0?
0=W5L`80eKm`3P3Mag@<0>K@N0P0i<ec00<0glY_0;8R8P2b8R800`2b8R8m05nNX040oooo001A05nN
X0D0/R8R1`0]:B8305=;=0P0L6I33P22MT/408n1D@`0W8iI4P2TUE`B0:^KGa80/Z5R4`2hYV@C0;j/
Ia80aK5Z4P3;]fdB0=:nL140fLEc3`3Mag@<0>K@N0030>kHN`3TcG<0i<ec00D0i<ec0P3ObVl30;8R
8Sh0GijP0@3oool00580GijP0`2b8R8802dY8P80Dd/d2@1`IT<>089fB`80Sh5A2@2LSUT30;8R8P80
W8iI4P2TUE`B0:^KGa80/Z5R4`2hYV@C0;j/Ia80aK5Z4P3;]fdB0=:nL0L0fLEc0`2b8R870=W5L`80
hLag303Mag@=0>K@N080k]Qk1P3TcG<30=o:K`030;VTE`010@40GijP03d0GijP0@3oool00580GijP
0P0;2PP2024N6@L0;BTR0`2b8R89071V@`d0PWI;2P2LSUT50;8R8P80W8iI4@2TUE`B0:^KGa80/Z5R
2P2hYV@90;j]J180a;9[4`35/FXB0<^gKA80d[i`1P3IaG<50;8R8PH0fLEc0`3Qc7L;0=g7M0`0i]1h
0`2b8R860>C=L`@0glY_00<00@4105nNX01OWZ00?01OWZ010?ooo`00DP1OWZ00100;2PP08AhI024N
6@0Q7QT602dY8PD0/R8R201`IT<<089fB`80TXID2@2LSUT50;8R8P80W8iI4P2TUE`A0:^KGa80/Z5R
4`2n[FPB0<BbJ`T0bKM^2P35/FXB0<^gKA40d[i`1`3IaG<50;8R8PD0fLEc1P3Qc7L90=g7M0/0i]1h
1@2b8R850>C=L`@0glY_00<00@4105nNX01OWZ00?01OWZ010?ooo`00DP1OWZ00100;2PP08AhI024N
6@0Q7QT602dY8PD0/R8R201`IT<;089fB`<0TXID2@2LSUT50;8R8P80W8iI4P2TUE`A0:^KG`T0/Z5R
2P2iZ6HB0;j]J180a;9[4P39]fhB0<^gKA80d[i`1`3IaG<50;8R8PD0fLEc1`3Qc7L80=g7M0/0i]1h
1@2b8R850>C=L`@0glY_00<00@4105nNX01OWZ00?01OWZ010?ooo`00DP1OWZ00100;2PP08AhI024N
6@0Q7QT602dY8PD0/R8R2@1`IT<9089fB`D0TXID2@2LSUT30;8R8P@0W8iI4@2TUE`A0:^KGa<0^JQV
4P2n[FPB0<BbJa80bKM^1@3?_70=0<^gKA80d[i`203IaG<30;8R8PD0fLEc2P3Qc7L50=g7M0`0i]1h
1@2b8R80103^f7/0i<ec0>C=L`3TcG<50=o:K`0300410@1OWZ00GijP03`0GijP0@3oool00580GijP
00<02`X8024N6@0Q7QT00P0Q7QT502dY8P0405I@>02b8R80/R8R0;8R8PX0L6I32022MT/609:6E100
W8iI4@2TUE`>0:^KG`@0/jAT4P2iZ6HB0;j]J180a;9[4P39]fh90<nlL0T0bkM]4P3B_W0@0=W5L`/0
hLag103Mag@<0>K@N0040>kHN`2b8R80/R8R0;8R8P80k]Qk0`3TcG<50=o:K`0300410@1OWZ00GijP
03`0GijP0@3oool00580GijP00<02`X8024N6@0Q7QT00P0Q7QT502dY8P<0EU0h2`1`IT<6089fB`P0
TXID402LSUTB0:BEG0X0Zi]O1`2cY6@B0;VXIQ80_ZeX4P34/V/B0<VgKPd0cka`1@3;]fdA0=:nL140
fLEc3@3Qc7L20=g7M0`0i]1h1`3^f7/20>C=L`D0glY_00<00@4105nNX01OWZ00?01OWZ010?ooo`00
DP1OWZ05024N6@@0;BTR101FD3P<071V@`@0PWI;2P2BQU@@09b>FA40Y9EL1`2[Vel:0;>TI180^JQV
4P2n[FPB0<BbJa80bKM^4@3?_70B0=:nL100fLEc3`3Qc7L=0>K@N0L0k]Qk0P3TcG<50=o:K`030041
0@1OWZ00GijP03`0GijP0@3oool005<0GijP100Q7QT402dY8P@0EU0h301`IT<3089fB`/0TXID402L
SUTA0:BEG0@0Zi]O3@2cY6@B0;VXIQ80_ZeX4P34/V/B0<VgKQ40cka`0`3F`W<?0=:nL100fLEc3`3Q
c7L00`3ZeG/0i]1h0>K@N0090>K@N0T0k]Qk00<0i<ec0=o:K`3ObVl00`3ObVl00`010@40GijP05nN
X00l05nNX040oooo001C05nNX0D08AhI0P0]:B8605I@>0/0L6I30P22MT/=09:6E0l0W8iI4@2TUE`B
0;>TI140^JQV202n[FP30;8R8PL0_ZeX3034/V/30;8R8P<0a;9[4@39]fhB0<nlL0H0e/9c303B_W0?
0=W5La00hLag0P3ZeG/:0>K@N0T0k]Qk1P3ObVl010010@40/R8R0;8R8P2b8R8k05nNX040oooo001@
05nNX0<0/R8R1@0Q7QT202dY8PH0EU0h2`1`IT<609:6E0<0/R8R1P2BQU@@09b>F@h0Y9EL0`2^Wf8A
0;>TI180^JQV1P2n[FP50;8R8PH0_ZeX2`34/V/50;8R8P80a;9[4@39]fhB0<nlL0P0e/9c2@3B_W0@
0=W5L`X0hLag0`2b8R820>7<M`@0j]Ek2@3Vd7P90>kHN`030?;MO03ObVl0glY_0080glY_00<0_jmM
0;8R8P2b8R800`2b8R8j05nNX040oooo001?05nNX0@0/R8R1@0Q7QT00`0]:B80EU0h05I@>00505I@
>0/0L6I300<0QG]?09:6E02BQU@00P2BQU@50;8R8PD0TXID402LSUT;0:BEG0H0[YmR4@2cY6@B0;VX
IPH0_ZeX1@2b8R860;j]J0/0a;9[1@2b8R820<BbJa00bKM^0`2b8R8?0<nlL0`0e/9c1P3B_W0@0=W5
L`T0hLag1@2b8R800`3Qc7L0j]Ek0>[EN`030>[EN`L0i]1h2P3^f7/00`3bgG`0glY_0=o:K`020=o:
K`030;n_G@2b8R80/R8R00<0/R8R>P1OWZ010?ooo`00C`1OWZ050;8R8P@08AhI00<0;BTR05I@>01F
D3P01P1FD3P9071V@`80QG]?102BQU@50;8R8PH0TXID3`2LSUT90:BEG0P0[YmR4@2cY6@30;VXIP<0
/R8R302iZ6H60;j]J0D0/R8R1P2n[FP;0<BbJ`D0/R8R0P34/V/?0<VgKPD0/R8R3P3?_70?0=K2L`<0
d[i`3`3IaG<:0>7<M`D0/R8R1`3ZeG/60>K@N0T0k]Qk0P3bgG`40=o:K`030;n_G@2b8R80/R8R00<0
/R8R>P1OWZ010?ooo`00C`1OWZ050;8R8P@08AhI2@1FD3P8071V@`@0QG]?0`2BQU@50;8R8PH0TXID
402LSUT50:BEG0`0[YmR402cY6@20;VXIPD0/R8R2`2iZ6H70;j]J0<0/R8R1`2n[FP<0<BbJ`<0/R8R
0P34/V/@0<VgKPD0/R8R3P3?_70A0=K2La00fLEc2P3Qc7L50;8R8PP0j]Ek1@3Vd7P90>kHN`<0l]el
0`3ObVl00`2o[ed00@410;8R8P020;8R8S/0GijP0@3oool00500GijP0`2b8R800`1OWZ008AhI024N
6@02024N6@0303@b:01FD3P0EU0h00H0EU0h1`1`IT<508EkC`@0TXID0`2b8R8709:6E100W8iI0`2T
UE`>0:jOHQ40/jAT00<0^JQV0;8R8P2b8R800`2b8R8;0;VXIQ40_ZeX4@34/V/@0<VgKPD0/R8R3P3?
_70A0=K2L`<0g<Ug303IaG<<0>7<M`<0/R8R2P3ZeG/30>K@N0X0k]Qk00@0l]el0;8R8P2b8R80/R8R
0P3ObVl00`2o[ed00@4105nNX00m05nNX040oooo001D05nNX0808AhI0`2b8R8905I@>0D0L6I31`25
Ndl>09:6E0l0W8iI4@2^Wf8A0;>TI0030;VXIP2b8R80/R8R00<0/R8R2`2iZ6HA0;j]J140a;9[4@39
]fh30;8R8Ph0cka`4P3F`W<50=c9M`X0fLEc3`3Qc7L;0>[EN`80i]1h2@3^f7/00`3bgG`0/R8R0;8R
8P030;8R8P80_jmM00<00@4105nNX01OWZ00?01OWZ010?ooo`00E01OWZ000`0A40d0/R8R0;8R8P03
0;8R8PP0EU0h1@1`IT<708EkC`h0TXID3P2LSUT20:NIGa40[YmR402cY6@20;VXIP<0/R8R302iZ6HA
0;j]J140a;9[4@39]fhA0<nlL0<0e/9c0`2b8R8;0=K2L`P0g<Ug203IaG<>0>7<M`d0j]Ek00<0i]1h
0>kHN`3^f7/01`3^f7/00`3bgG`0/R8R0;8R8P030;8R8P80_jmM?`1OWZ010?ooo`00E01OWZ000`0A
40d0/R8R0;8R8P030;8R8PP0EU0h101`IT<908EkC`h0TXID2`2LSUT40:NIG`l0[YmR0`2b8R8?0;>T
I180^JQV402n[FPA0<BbJa40bKM^4@3?_7020=K2L`D0/R8R2P3F`W<:0=c9M`D0fLEc3`3Qc7L=0>[E
N`X0k]Qk00<0l]el0;8R8P2b8R800`2b8R820;n_GCl0GijP0@3oool005@0GijP00<04A0=0;8R8P2b
8R800`2b8R8905I@>080L6I32P25Ndl>09:6E0T0W8iI1`2WVEl=0:jOHPD0/R8R3`2cY6@A0;VXIQ00
_ZeX4@34/V/A0<VgKQ00cka`0`3F`W<50;8R8PT0e/9c3@3LbGL30=W5L`l0hLag3@3ZeG/00`3bgX00
k]Qk0>kHN`060>kHN`<0l]el0`2b8R800`3ObVl0_jmM0;n_G@0o05nNX040oooo001D05nNX003014@
3@0Q7QT0/R8R0080/R8R0P0d<RP805I@>003071V@`25Ndl0QG]?00X0QG]?3@2BQU@709b>F@T0YiUO
3@2^Wf850;8R8Pl0/jAT4@2iZ6H@0;j]J140a;9[4@39]fh@0<nlL0<0e/9c1@2b8R890=K2L`l0g<Ug
3`3Qc7L=0>[EN`<0l]j01`3^f7/60?;MO0030=o:K`2o[ed0_jmM03l0GijP0@3oool005D0GijP00<0
4A0=024N6@0d<RP00`0d<RP805I@>0d0QG]?3P2BQU@409b>F@`0YiUO302^Wf850;8R8Pl0/jAT4@2i
Z6H@0;j]J140a;9[4@39]fh@0<nlL0@0e/9c0`2b8R890=K2La00g<Ug0P3Td7X=0>7<M`d0j]Ek0`3b
gX070>kHN`H0l]el0`2o[edo05nNX040oooo001E05nNX003014@3@0Q7QT0=38X00<0=38X201FD3P0
0`1dKDP0QG]?08EkC`0;08EkC`d0TXID0P2LSUT>0:NIG`d0[YmR0`2b8R8@0;>TI140^JQV402n[FPA
0<BbJa00bKM^4@3?_70@0=K2L`l0g<Ug103Td7X;0>7<M``0j]Ek0`2b8R830?;NP0D0k]Qk1`3bgG`2
0;n_GD00GijP0@3oool005D0GijP00<04A0=024N6@0d<RP0100d<RP605I@>080M6e800@0QG]?0;8R
8P2b8R80/R8R2@25Ndl=09:6E140YiUO402^Wf8?0;>TI140^JQV402n[FPA0<BbJa00bKM^403?_70A
0=K2L`l0g<Ug1P3Td7X90>7<M`/0j]Ek1@2b8R820?;NP0D0k]Qk1`3bgG`20;n_GD00GijP0@3oool0
05D0GijP00<04A0=024N6@0d<RP0100d<RP605I@>080M6e81@2b8R8908EkC`/0TXID0P2PTe`@0:NI
Ga00[YmR402cY6@@0;VXIQ00_ZeX4@34/V/@0<VgKQ00cka`403F`W<70=c9M`<0/R8R1@3LbGL80>C@
NPL0hLag303ZeG/50;8R8P<0l]j0103^f7/60?;MO0030>OEMP2o[ed0_jmM0400GijP0@3oool005D0
GijP00<04A0=03@b:00d<RP0100d<RP505I@>0<0M6e81@2b8R8908EkC`X0TXID102PTe`:0:NIG`<0
/R8R0`2WVEl?0:jOHQ00/jAT402iZ6H@0<BcKA00bKQ_4@39]fh@0<nlL100e/9c1P3LbGL50;8R8P@0
g<Ug2@3Td7X60>7<M``0j]Ek1@2b8R840?;NP080k]Qk1`3bgG`00`3WeGH0_jmM0;n_G@020;8R8Sh0
GijP0@3oool005<0GijP0`2b8R800`0A40d0=38X03@b:00403@b:0@0EU0h0`1dKDP50;8R8PX0QG]?
1`2BQU@60:2CG0T0YiUO1@2b8R820:NIGa00[YmR3`2cY6@;0;VXIPH0_k1[3`34/fd@0<VhK`P0c[aa
2@39]fh@0<nlL0l0e/9c1`3LbGL50;8R8P<0g<Ug303Td7X30>7<M`d0j]Ek00@0l]j00;8R8P2b8R80
/R8R1@3bgX020>kHN`L0l]el00<0imEf0;n_G@2o[ed00`2b8R8m05nNX040oooo001B05nNX0@0/R8R
00<04A0=03@b:00d<RP0100d<RP305I@>0D0M6e80`2b8R8;08EkC`H0TXID202PTe`80:NIG`D0/R8R
0P2WVEl@0:jOHPl0/jAT1P2iZ6H;0;n`J`l0a;=]4039^6l@0<jlLA00cka`403F`W<70=c9M`D0/R8R
0`3LbGL=0>C@NP80hLag303ZeG/;0?;NP0030>kHN`3bgG`0l]el00@0l]el0P3WeGH20;n_G@<0/R8R
?@1OWZ010?ooo`00DP1OWZ040;8R8P03014@3@0W91h0=38X00@0=38X0`1FD3P707A]B0d0QG]?0`2B
QU@:0:2CG0P0YiUO1@2b8R830:NIG`l0[YmR3`2cY6@A0;n`J`l0a;=]4039^6l@0<jlL@D0dl5c2`3?
_70?0=K2L`T0g<Ug0`2b8R830=c9M`l0i=1j3@3ZeG/;0?;NP0L0l]el0P3WeGH00`2o[ed0/R8R0;8R
8P020;8R8Sd0GijP0@3oool00580GijP102b8R800`0A40d09b@N03@b:00503@b:00305I@>01dKDP0
M6e800H0M6e83@25Ndl209:6E0`0X9=L202WVEl30;8R8P@0YiUO402^Wf8:0;>TI0D0^jaY402o/6/?
0<BcKA00bKQ_403>_74:0=?1L`H0cka`3`3F`W<?0=c9M`l0i=1j00<0k=Qn0>[EN`3ZeG/02@3ZeG/<
0?;NP0030?[VP`3bgG`0l]el00@0l]el0P3WeGH40;8R8Sh0GijP0@3oool005<0GijP102b8R800`0W
91h0=38X03@b:00403@b:00305I@>01dKDP0M6e800L0M6e83025Ndl?0:2CG0l0YiUO3`2^Wf850;>T
I0X0^jaY402o/6/?0<BcKA00bKQ_403>_74?0=?1La00e/9c3P3LbGL?0>C@NP<0k=Qn2P3ZeG/;0?;N
P080n^J31@3bgG`20>OEMPD0/R8R?P1OWZ010?ooo`00D`1OWZ050;8R8P0302LT7P0d<RP0=38X00<0
=38X2P1dKDP<08EkC`0309N<F@2PTe`0X9=L00`0X9=L3`2WVEl?0:jOHPl0^jaY402o/6/?0<BcKA00
bKQ_403>_74?0=?1L`<0fLIf303F`W<?0=c9M`l0i=1j103/f7h80>[EN``0l]j00P3jiX<50?;MO080
imEf1@2b8R8n05nNX040oooo001C05nNX0D0/R8R00<09b@N03@b:00d<RP00`0d<RP00`1KF3d0M6e8
07A]B00807A]B0X0QG]?0`2GS5T>0:2CG0l0YiUO302^Wf830;JXI`l0^jaY3`2o/6/?0<BcKA00bKQ_
3`3>_74@0=?1L`H0fLIf2@3F`W<>0=c9M`l0i=1j1P3/f7h70>[EN`/0l]j0103jiX<40?;MO080imEf
1@2b8R8n05nNX040oooo001C05nNX0D0/R8R00<09b@N03@b:00d<RP00`0d<RP205]H?@T0M6e82@25
Ndl409N<F@D0X9=L0`2b8R860:2CG0l0YiUO2@2^Wf860;JXI`l0^jaY402o/6/>0<BcKA00bKQ_3`3>
_74?0=?1L`T0fLIf1P3F`W<?0=c9M`X0i=1j0`2b8R820>C@NPL0k=Qn1@3ZeG/<0?;NP0@0n^J30`3b
gG`40>OEMP<0/R8R?`1OWZ010?ooo`00E01OWZ030;8R8P<09b@N100d<RP205]H?@X0M6e81`25Ndl6
09N<F@<0X9=L1@2b8R860:2CG0l0YiUO1P2^Wf890;JXI`h0^jaY402o/6/>0<BcKA00bKQ_3`3>_74?
0=?1L``0fLIf0`3F`W<>0=c9M`X0i=1j1@2b8R890>cHOP@0j]Ek2`3bgX050?[VP`<0l]el103WeGI2
05nNX040oooo001G05nNX0<09b@N100d<RP0101KF3d0/R8R0;8R8P2b8R8807A]B0H0QG]?1`2GS5T3
0:2CG0D0/R8R1P2PTe`?0:NIG`<0[YmR302fZ6L>0;^/JA00_k1[1P34/fd30;8R8PD0a;=]2P39^6l3
0;8R8P<0bKQ_3`3>_74?0=?1L`h0fLIf3`3LbGL:0>C@NPD0/R8R2P3/f7h20>[EN`/0l]j00P3jiX<3
0;8R8P80n^J30P3bgG`40>OEMT80GijP0@3oool005L0GijP100W91h203@b:00305]H?@2b8R80/R8R
00<0/R8R201dKDP408EkC`T0UhaI0P2PTe`50;8R8PL0X9=L3P2WVEl?0;JXI`l0^jaY3`2o/6/50<Bc
K@D0/R8R1034/fd90<VhK`D0/R8R00<0bKQ_0<jlL@3>_7403@3>_74?0=?1L`l0fLIf0`3Oc7T;0=c9
M`/0i=1j1@2b8R8;0>cHOP`0l]j000<0n^J30;8R8P2b8R800`2b8R800`3jiX<0l]el0>OEMP030>OE
MP030;jbG`1OWZ00GijP0400GijP0@3oool005P0GijP0`0W91h203@b:00305]H?@2b8R80/R8R00<0
/R8R201dKDP308EkC`/0UhaI0P2PTe`30;8R8PT0X9=L302WVEl20;6TI@l0]ZQW3P2k[6T?0;n`J`D0
a;=]1@2b8R840<BcK@T0bKQ_1@2b8R800`39^6l0c[aa0<jlL@0;0<jlL@<0/R8R3P3C`G<>0=W6MPH0
glai2@3LbGL<0>C@NP<0/R8R303/f7h00`3ch880l]j00?;NP0080?;NP080n^J31@2b8R800`3jiX<0
l]el0>OEMP030>OEMT<0GijP0@3oool005P0GijP0`0W91h203@b:00305]H?@2b8R80/R8R00<0/R8R
2@1dKDP00`25Ndl0UhaI09N<F@0:09N<F@h0X9=L2P2WVEl40;6TI@l0]ZQW3P2k[6T30;n`J`<0/R8R
2@2o/6/50<BcK@D0/R8R1034/fd90<VhK`D0/R8R00<0bKQ_0<jlL@3>_7402P3>_7450;8R8P`0dl5c
3`3IaWH90=o<N@D0g<Ug3`3Td7X<0>cHOP<0ln222@3bgX020?[VP`D0/R8R00<0n^J30>OEMP3WeGH0
0P3WeGH00`2n/Ul0GijP05nNX01105nNX040oooo001I05nNX0<09b@N00<0=38X05]H?@1KF3d00`2b
8R800`1KF3d0M6e807A]B00707A]B0h0UhaI3P2PTe`70:NIG`L0/JAU3`2fZ6L>0;^/J@030;n`J`2b
8R80/R8R00<0/R8R202o/6/60<BcK@<0/R8R1@34/fd:0<VhK`<0/R8R0P39^6l<0<jlL@D0/R8R303C
`G<>0=W6MP`0glai0`3LbGL>0>C@NP`0k=Qn103ch8880?;NP0@0n^J30`2b8R820?[VP`@0imEf00<0
_[9O05nNX01OWZ00@@1OWZ010?ooo`00F@1OWZ0302LT7P0303@b:01KF3d0FePm00D0FePm201dKDP0
0`2;Pe@0UhaI09N<F@0;09N<F@h0X9=L1@2WVEl90;6TI@l0]ZQW3P2k[6T00`2o/6/0/R8R0;8R8P03
0;8R8PT0_k1[3@34/fd?0<VhK``0c[aa1@2b8R8<0=?1L`h0fLIf3P3Oc7T?0>C@NP`0k=Qn1@3ch886
0?;NP0T0n^J300<0n^R30>OEMP3WeGH00P3WeGI405nNX040oooo001I05nNX0<09b@N201KF3d807A]
B080Rh=D3@2GS5T>0:2CG080YiUO302aY6D=0;JXI`<0/R8R302k[6T00`2o/6/0/R8R0;8R8P030;8R
8PT0_k1[3@34/fd?0<VhK`d0c[aa0`2b8R8<0=?1L`80fLIf0`2b8R890=W6MPl0glai0P3UdW`<0>C@
NP`0k=Qn1`3ch8850?;NP0T0n^J300D0n^R30>OEMP3WeGH0imEf0;jbG`1405nNX040oooo001J05nN
X0<09b@N201KF3d607A]B0@0Rh=D302GS5T>0:2CG0h0/JAU302fZ6L50;8R8P/0^jaY0P2o/6/30;8R
8PX0_k1[3@34/fd?0<VhK`h0c[aa3P3C`G<00`3IaWH0/R8R0;8R8P030;8R8PP0fLIf3P3Oc7T40>GB
O0X0i=1j303/f7h80??PPP@0l]j02@3jiX<20?[XP`<0imEf00<0_[9O05nNX01OWZ00@P1OWZ010?oo
o`00E`1OWZ030;8R8P<09b@N00<0@D0`05]H?@1KF3d01P1KF3d507A]B0D0Rh=D00@0UhaI0;8R8P2b
8R80/R8R202GS5T<0:2CG080[9mS3P2aY6D;0;JXI`D0/R8R302k[6T>0;n`J`d0a;=]3`39^6l>0<jl
L@h0dl5c00<0fLIf0;8R8P2b8R800`2b8R870=W6MPl0glai1P3UdW`80>C@NP/0k=Qn0`2b8R870??P
PP<0l]j0203jiX<30?[XP`80imEf00@0_[9O0;8R8P2b8R80/R8R@P1OWZ010?ooo`00EP1OWZ040;8R
8P<09b@N00<0@D0`05]H?@1KF3d01P1KF3d407A]B0H0Rh=D1@2b8R8809N<F@X0X9=L102/Wf<=0;6T
I@/0]ZQW1@2b8R8<0;^/J@h0_k1[3@34/fd?0<VhK`d0c[aa3P3C`G<20=W6MPD0/R8R1`3IaWH>0=o<
N@P0iM9l1P3Td7X;0>cHOPD0/R8R1`3ch8800`3bgX00n^J30?[VP`070?[VP`<0n^R30P3WeGH50;8R
8T40GijP0@3oool005H0GijP1@2b8R8202LT7P80@D0`201KF3d307A]B0H0Rh=D1@2b8R8809N<F@P0
X9=L1P2/Wf<>0;6TI@/0]ZQW0`2b8R8=0;^/J@h0_k1[3@34/fd?0<VhK`d0c[aa3P3C`G<30=W6MP<0
/R8R1`3IaWH>0=o<N@/0iM9l103Td7X;0>cHOPD0/R8R1`3ch8890?[VP`@0n^R30P3WeGH50;8R8T40
GijP0@3oool005H0GijP1@2b8R8202LT7P<0@D0`1`1KF3d207A]B0L0Rh=D1@2b8R8909N<F@H0X9=L
202/Wf<=0;6TI@h0]ZQW3P2k[6T=0;n`J`d0a;=]3`39^6l=0<jlL@d0dl5c3P3IaWH>0=o<N@`0iM9l
0P3Td7X<0>cHOPD0/R8R1`3ch8800`3kj8H0n^J30?[VP`050?[VP`D0n^R300<0imEf0;jbG`2b8R80
102b8R9105nNX040oooo001G05nNX0<0/R8R00<0GijP01LF4P0W91h00`11@30805]H?@0307A]B02;
Pe@0Rh=D00H0Rh=D0`2b8R8:09N<F@@0X9=L2`2/Wf<80;6TI@<0/R8R0P2aY6D>0;JXI`d0^jaY3@2o
/6/>0<ZjL0d0c[ib3P3>_74=0=?1L`d0fLIf1P3Oc7T30;8R8PD0glai3P3UdW`<0>cHOP80ln220`2b
8R870??PPP80nnR61`3jiX<20?[XP`<0/R8R00<0imEf0;jbG`1OWZ000`2b8R9205nNX040oooo001L
05nNX00502LT7P2b8R80/R8R0;8R8P11@3001`1KF3d;08^3E0`0UhaI0P2PTe`<0:bOH`L0/JAU1@2b
8R800`2aY6D0]ZQW0;JXI`0<0;JXI`d0^jaY1`2o/6/70<JgK`d0b[Y`3@3>_W8=0=;2M0h0dl5c3@3I
aWH50=o<N@D0/R8R0`3Oc7T?0>GBO0030>cIP03/f7h0k=Qn00P0k=Qn303ch8830?_XQPH0n^J30P3j
j8<50;8R8TL0GijP0@3oool005`0GijP1@2b8R8705]H?@0307]gCP2;Pe@0Rh=D00T0Rh=D2`2GS5T?
0:bOH`H0/JAU1@2b8R820;6TI@d0]ZQW3@2k[6T>0<JgK`d0b[Y`3@3>_W8=0=;2M0@0elIf2@3C`G<=
0=W6MPH0glai1@2b8R830=o<N@h0iM9l0`3/fH090>cHOP/0ln221@3kj8H50?[VP`80n^R31@2b8R97
05nNX040oooo001L05nNX0D0/R8R00<0@D0`05]H?@1KF3d0101KF3d207]gCP/0Rh=D2P2GS5T00`2V
Vf40[9mS0:bOH`0=0:bOH`D0/JAU1@2b8R820;6TI@h0]ZQW202k[6T50<:cK@d0a[M_3@3:^W0=0<jn
LPd0d/9d203GaWH50=?1L`d0fLIf1P3Oc7T50;8R8P80glai3P3UdW`50>cIP0L0k=Qn303ch8850?_X
QP@0n^J30`3jj8<50;8R8TL0GijP0@3oool005`0GijP1@2b8R820450<0D0FePm0`1kMdh;08^3E0P0
UhaI0`2VVf4>0:bOH`H0/JAU0`2b8R840;6TI@d0]ZQW102k[6T90<:cK@d0a[M_3@3:^W0=0<jnLPd0
d/9d303GaWH=0=W6MPP0glai0`2b8R830=o<N@d0iM9l1`3/fH050>cHOP`0ln221P3kj8H30?[VP`D0
n^R30`2b8R9805nNX040oooo001M05nNX0<0/R8R0`11@30505]H?@<0NgM>2`2;Pe@709N<F@D0YY]Q
3P2/Wf<<0;6TI@d0]ZQW3P32/fd<0<JgK`d0b[Y`3@3>_W8<0=;2M0d0elIf0`3KbWP:0=W6MPd0glai
3@3UdW`90>cIP0@0k=Qn2`3ch8880?_XQP80n^J31P3jj8<00`3XfgT0_[9O05nNX01705nNX040oooo
001N05nNX0H0@D0`0`1KF3d507]gCP/0Rh=D1@2GS5T70:JKH@d0[9mS3@2aY6D:0;JXI`<0_[1/3@32
/fd=0<JgK``0b[Y`3@3>_W8<0=;2M0d0elIf1P3KbWP60=W6MPd0glai3P3UdW`:0>cIP080k=Qn2`3c
h8820?_XQP<0/R8R103kj8H00`3jiX<0n^R30?[XP`040?[XP`80j=]iB@1OWZ010?ooo`00GP1OWZ00
0`0^:b@0@D0`0450<0040450<080FePm101kMdh30;8R8PX0Rh=D0`2GS5T90:JKH@D0[9mS0`2b8R85
0:bOH``0/JAU1`2fZ6L70;j`K0`0`[=]3@36]fl<0<ZjL0`0c[ib3@3B`W@<0=O6MPX0flYh0`3IaWH=
0=o<N@P0iM9l0`2b8R820>GBO0`0k=V0303ch8800`3kj8H0/R8R0;8R8P030;8R8P<0nnR61P3jj8<3
0>SKNDT0GijP0@3oool005l0GijP1P11@30205]H?@<0NgM>1@2b8R8:08^3E00309N<F@2VVf40YY]Q
00P0YY]Q102/Wf<50;8R8PD0[9mS302aY6D30;JXI`X0_[1/3@32/fd<0<JgK``0b[Y`303>_W8<0=;2
M0d0elIf303KbWP=0=o<N@P0iM9l1@2b8R8=0>cIP0030??QP`3ch880ln2200P0ln220P3kj8H50;8R
8P<0nnR61P3jj8<20>SKN@030;jbG`1OWZ00GijP04L0GijP0@3oool005l0GijP00<0;R/T0450<011
@3001011@300101KF3d0NgM>07]gCP1kMdh50;8R8PX0Rh=D302VVf430:bOH`D0/R8R1@2/Wf<<0;6T
I@h0_[1/3032/fd<0<JgK``0b[Y`303>_W8<0=;2M0`0elIf3@3KbWP30>3?N`T0glai2@3UdW`50;8R
8P`0k=V00`3chH<80??PPP<0nnR61@2b8R820?_XQP030?o^R03jj8<0n^R300<0n^R30`3XfgU:05nN
X040oooo001P05nNX00302h[9011@300@D0`00<0@D0`101kMdh50;8R8PX0Rh=D00<0WYEN0:JKH@2V
Vf402P2VVf420:bOH`D0/R8R1P2/Wf<:0;6TI@80^ji[3@2n/6`<0<:cK@`0a[M_303:^W0<0<jnLP`0
d/9d303GaWH<0=_:N0H0h<mk1`3Oc7T90>GBO0D0/R8R2`3/fH050??QP`H0ln221@3kj8H30;8R8P80
nnR60P3okXP40?[XP`@0j=]iBP1OWZ010?ooo`00H01OWZ000`0^:b@0@D0`0450<0030450<00306EU
A01kMdh0NgM>0080NgM>0`2b8R8207]gCPP0Rh=D0`2NUEh<0:JKH@80[9mS0`2b8R880:bOH`L0/JAU
1@2k[V/=0;j`K0`0`[=]3036]fl;0<ZjL0`0c[ib2`3B`W@=0=O6MP`0flYh2@3Pcg/30=o<N@/0iM9l
0`2b8R8;0>cIP0L0ln631@3ch8890?_XQP<0onj8103jj8<30>SKND/0GijP0@3oool00640GijP00<0
;R/T0450<011@3000P11@30206EUA0T0NgM>1`2;Pe@409jEGP`0YY]Q302/Wf<50;6TI@L0^ji[3@2n
/6`<0<:cK@`0a[M_103:^W030;8R8P@0b[Y`1`3>_W830;8R8P80c[ib2`3B`W@<0=O6MP`0flYh303P
cg/=0>GBO0`0k=V02@3chH<30??PPPT0nnR6103okXP30?[XP`80j=]i0`2b8R9:05nNX040oooo001O
05nNX0<0/R8R00@0;R/T0450<011@300@D0`0`1UID@807]gCPH0Rh=D1P2NUEh<0:JKH@`0[9mS0P2a
Y6D:0;^^J`d0_[1/2`32/fd<0<JgK`<0b[Y`1@2b8R830<ZjL0H0c[ib1@2b8R800`3>_W80d/9d0=;2
M0090=;2M0`0elIf2`3KbWP=0>3?N`80i]An2P3UdW`<0>cIP0/0ln6300<0ln220?_XQP3kj8H01`3k
j8H50?o^R080n^R30P3XfgT50;8R8TT0GijP0@3oool005h0GijP1@2b8R830450<0@0IFE4201kMdh4
08^3E0P0WYEN2`2VVf4<0:bOH`d0^ji[302n/6`<0<:cK@040<JgK`2b8R80/R8R0;8R8PL0a[M_0`3:
^W050;8R8P<0b[Y`1P3>_W850;8R8PX0d/9d0`2b8R8:0=O6MP`0flYh303Pcg/50>KDOPL0iM9l303/
fH0<0??QP`T0nnR61P3okXP20?[XP`80j=]i1@2b8R9905nNX040oooo001N05nNX0D0/R8R00<0;R/T
0450<011@300101UID@907]gCP<0Rh=D2@2NUEh0102VVf40/R8R0;8R8P2b8R870:JKH@X0[9mS0P2g
ZfT<0;^^J`d0_[1/2`32/fd50;8R8PH0a[M_0`3:^W050;8R8P<0b[Y`1P3>_W850;8R8PT0d/9d1@2b
8R890=O6MP/0flYh303Pcg/70>KDOPD0iM9l2`3/fH030;8R8PX0ln630P3ij8L80?_XQPH0onj800@0
n^R30>SKN@3XfgT0j=]i1@2b8R9905nNX040oooo001N05nNX0D0/R8R0P0^:b@00`11@300IFE406EU
A00306EUA0T0NgM>00<0Rh=D09jEGP2NUEh0202NUEh50;8R8PL0YY]Q1`2/Wf<50;N[J@`0^ji[302n
/6`;0<:cK@D0/R8R1`36]fl30<ZjL0<0/R8R103:^W070<jnLP<0/R8R00<0c[ib0=;2M03B`W@01`3B
`W@50;8R8PP0elIf303KbWP;0>3?N`X0i]An0P3UdW`;0>cIP0D0/R8R203chH<30?WXQ`L0nnR61`3o
kXP40>SKN@0405nNX02b8R80/R8R0;8R8TX0GijP0@3oool005l0GijP0`2b8R80101OWZ00;R/T02h[
9011@30606EUA0P0NgM>2`2NUEh50;8R8PP0YY]Q1@2/Wf<70;N[J@`0^ji[2P2n/6`30;8R8PT0`[=]
1@2b8R870<JgK`X0b[Y`2`3>_W890=;2M0D0/R8R203GaWH0103KbWP0/R8R0;8R8P2b8R870=_:N0`0
h<mk2`3Ve7h<0>cIP0D0/R8R1`3chH<40?WXQ`H0nnR60`3okXP30;8R8P80onj8103XfgU>05nNX040
oooo001T05nNX080;R/T0`1UID@30;8R8P0306EUA01kMdh0NgM>00D0NgM>0P2DSU/909jEGPD0/R8R
2@2VVf420:bOH`X0]j]Y2`2k[V/90;j`K0D0/R8R2@32/fd30;8R8PP0a[M_2P3:^W0;0<jnLPX0d/9d
0`2b8R890=O6MPD0/R8R1@3KbWP<0>3?N``0i]An0P3[fX4:0>cIP0D0/R8R1P3chH<50?WXQ`D0nnR6
0`3okXP50;8R8P040?_]Q`3XfgT0j=]i0>SKNDl0GijP0@3oool006@0GijP00@0Ed8S02h[901UID@0
IFE41@2b8R800`1UID@0NgM>07]gCP0407]gCP<0U8iK2@2NUEh30;8R8PX0YY]Q3@2gZfT;0;^^J`P0
_[1/1@2b8R890<:cK@/0a[M_2P3:^W0;0<jnLPX0d/9d2`3GaWH00`3KbWP0/R8R0;8R8P030;8R8PD0
flYh2`3Pcg/<0>KDOP@0jmZ1203/fH020??QP`<0/R8R1P3chH<70?WXQ`<0nnR6103okXP50;8R8P04
0?_]Q`3XfgT0j=]i0;VbHDl0GijP0@3oool006D0GijP0P0^:b@00`1UID@0/R8R0;8R8P030;8R8P03
06EUA01kMdh0NgM>00@0NgM>102DSU/;09jEGPT0YY]Q0P2cZ6P<0;N[J@`0^ji[1`2n/6`50;8R8PX0
`[=]2P36]fl:0<ZjL0X0c[ib2`3B`W@;0=O6MP030=_:N02b8R80/R8R00<0/R8R103KbWP;0>3?N``0
i]An1P3[fX460>cIP0/0ln63203ij8L20?_XQPD0onj81@2b8R800`3kkHL0j=]i0>SKN@1@05nNX040
oooo001V05nNX00302h[901@DCX0/R8R00@0/R8R0P1UID@407]gCPH0U8iK2`2NUEh70:JKH@@0/jQX
302gZfT70;^^J`<0/R8R00<0^ji[0;j`K02n/6`01P2n/6`30;8R8P030;j`K032/fd0`[=]00P0`[=]
2P36]fl:0<o1M0X0dl=f2P3FaWL;0=O6MP<0flYh0`2b8R850=_:N0@0h<mk0`2b8R840>3?N`/0i]An
203[fX440>cIP0/0ln632@3ij8L00`3kj8H0onj80?o^R0050?o^R0<0/R8R00<0nnf70>SKN@3XfgT0
D@1OWZ010?ooo`00IP1OWZ000`1G@R<0;R/T051A>P030;8R8P@0IFE40`1kMdh709B>F`/0WYEN1@2V
Vf460;>XJ0`0]j]Y1@2k[V/50;8R8P030;^^J`2n/6`0_[1/00T0_[1/2P32/fd;0<fnL`T0cl5d2P3C
`gH:0=K6M`D0f/Yi1P3GaWH:0=_:N0@0h<mk1@2b8R820>3?N`/0i]An2P3[fX420>cIP0/0ln632P3i
j8L80?o^R0@0nnf700<0j=]i0;VbH@1OWZ00D01OWZ010?ooo`00I`1OWZ000`0^:b@0D54j051A>P07
06EUA080NgM>202DSU/;09jEGP<0YY]Q202cZ6P<0;N[J@@0^ji[1@2b8R820;^^J`/0_[1/1@32/fd5
0<VkLPX0cKic2@3?`G@:0=?3MPX0e/Ig2P3JbWT:0=_:N0D0h<mk1@2b8R800`3Pcg/0i]An0>KDOP09
0>KDOP`0jmZ12`3chH<0103ij8L0/R8R0;8R8P2b8R860?WXQ`030?k^RP3okXP0onj800D0onj81@3k
kHL00`3XfgT0GijP05nNX01@05nNX040oooo001W05nNX00405M28`0^:b@0D54j051A>PL0IFE400<0
NgM>09B>F`2DSU/01P2DSU/30;8R8PT0WYEN00<0YY]Q0;>XJ02cZ6P0202cZ6P<0;N[J@<0^ji[1@2b
8R820;^^J`/0_[1/2P39^g8:0<fnL`T0cl5d2P3C`gH90=K6M`/0f/Yi0`3McG/70=_:N0D0h<mk1@2b
8R8;0>KDOP`0jmZ10P3`h8@90??QP`030?WXQ`2b8R80/R8R00<0/R8R103ij8L20?k^RPH0onj81P3k
kHL30;8R8U00GijP0@3oool006H0GijP0P2b8R80101G@R<0D54j051A>P1@DCX606EUA0P0U8iK1@2b
8R8809jEGP`0/jQX302gZfT30;^^J`<0/R8R102k[V/70;j`K0@0akUa2P39^g890<fnL`T0cl5d2P3C
`gH90=K6M`X0f/Yi1`3McG/30=_:N0L0h<mk0`2b8R800`3Pcg/0i]An0>KDOP080>KDOP`0jmZ1103`
h8@70??QP`80nNR71@2b8R830?WXQ`<0o^j:1@3okXP60?_]Q`D0/R8RC`1OWZ010?ooo`00I@1OWZ04
0;8R8P0402h[901@DCX0D54j051A>PH0IFE400<0R8EF09B>F`2DSU/0102DSU/50;8R8PP0WYEN0P2^
YFL;0;>XJ0D0]j]Y0`2b8R830;N[J@/0^ji[0`2n/6`80<NiL@T0bK]b2P3=_W<80<o1M0T0dl=f2P3F
aWL:0=[:N@T0gLek2`3Pcg/70>KDOP<0/R8R303[fX450?3PQ0H0ln630`3ij8L50;8R8P80nNR7103n
kXX40?o^R0H0nnf700<0i]al0;8R8P2b8R800`2b8R9?05nNX040oooo001U05nNX0D0/R8R101@DCX5
06EUA080R8EF1@2DSU/50;8R8P0309B>F`2NUEh0WYEN00@0WYEN102^YFL;0;>XJ0<0]j]Y1@2b8R83
0;N[J@X0^ji[2`37^G4:0<VkLPT0cKic203?`G@90=?3MPT0e/Ig2P3JbWT:0=g=N`<0hM5m1`3Pcg/7
0>KDOPD0/R8R2P3[fX470?3PQ0@0ln631@3ij8L30;8R8P80nNR71@3nkXX30?o^R0H0nnf700<0i]al
0;VbH@2b8R80102b8R9?05nNX040oooo001U05nNX0D0/R8R00D0D54j0;8R8P2b8R80/R8R051A>P04
06EUA0<0R8EF1@2DSU/30;8R8P<0U8iK1@2NUEh50:jUI`/0/jQX0P2gZfT50;8R8P@0]j]Y202k[V/2
0<BgL0/0akUa2@39^g890<fnL`P0cl5d2@3C`gH90=K6M`X0f/Yi2@3McG/70>7AO@<0h<mk203Ve7h5
0;8R8PT0jmZ12@3`h8@20??QP`X0nNR71P3nkXX20?o^R0@0nnf70`2b8R800`3Vg7`0GijP05nNX003
0;8R8U00GijP0@3oool006H0GijP0`2b8R800`1OWZ00/R8R0;8R8P030;8R8P04051A>P1UID@0IFE4
06EUA0@0R8EF2`2DSU/309jEGPL0[ZEW2`2cZ6P00`2gZfT0/R8R0;8R8P030;8R8PD0]j]Y1@2k[V/5
0<BgL0X0akUa2@39^g890<fnL`P0cl5d2@3C`gH90=K6M`T0f/Yi2@3McG/:0>7AO@T0i]An1@2b8R88
0>_JP@X0l>242`3ij8L70?k^RP030?o^R03kkHL0nnf70080nnf71@2b8R9E05nNX040oooo001Z05nN
X0D0/R8R0P1@DCX206EUA0H0R8EF2P2DSU/209jEGPT0[ZEW2P2cZ6P0102gZfT0/R8R0;8R8P2b8R87
0;N[J@80^ji[2034]g0:0<NiL@T0bK]b203=_W<80<o1M0T0dl=f203FaWL90=[:N@T0gLek2P3QdGd3
0>GEO`L0i]An00@0jmZ10;8R8P2b8R80/R8R203[fX4:0?3PQ080m^J72@3ij8L80?k^RPD0nnf71@2b
8R9E05nNX040oooo001Z05nNX0D0/R8R0`1@DCX00`1UID@0R8EF08R5EP0508R5EPX0U8iK2`2^YFL:
0;>XJ0X0]j]Y2`34]g0:0<NiL@P0bK]b2@3=_W<70<o1M0T0dl=f203FaWL90=[:N@T0gLek2@3QdGd5
0>GEO`D0i]An2`3[fX4;0?3PQ0<0m^J7203ij8L80?k^RP030?oaR`3kkHL0nnf700<0nnf71@2b8R9E
05nNX040oooo001[05nNX0<0/R8R1@1@DCX808R5EPT0U8iK0P2YXFD:0:jUI`80/jQX0`2b8R850;>X
J0P0]j]Y0`32]Vl:0<BgL0T0akUa2@39^g880<fnL`L0cl5d203C`gH90=K6M`P0f/Yi2@3McG/90>7A
O@P0iMEo0P3Ve7h:0>_JP@<0/R8R2@3`h8@50?KVQ`H0nNR70P3nkXX30;8R8P<0o^j:0P3olH/40?_]
Q`80i]al0`2b8R9F05nNX040oooo001]05nNX003079J;`0o?Rl0D54j00<0D54j1P28QEH30;8R8PP0
U8iK0`2YXFD:0:jUI`D0/R8R1@2cZ6P50;N[J@H0`[I_2@34]g0:0<NiL@P0bK]b203=_W<20<o1M0<0
/R8R0P3?`G@50=?3MP<0/R8R203FaWL90=[:N@P0gLek2@3QdGd:0>GEO`X0jmZ11@2b8R860?3PQ0L0
m^J71@3ij8L20?k^RPD0/R8R00@0o^j:0?oaR`3olH/0oo6;0`3kkHL40>KLO5P0GijP0@3oool006h0
GijP0P0o?Rl4051A>P0407MgC`28QEH0R8EF08R5EPD0/R8R00<0R8EF09B>F`2DSU/0102DSU/40:VQ
I@T0[ZEW1@2b8R860;>XJ0<0]j]Y2032]Vl90<BgL0T0akUa2039^g80103=_W<0/R8R0;8R8P2b8R84
0<fnL`030<o1M02b8R80/R8R00<0/R8R00<0cl5d0=?3MP3C`gH00P3C`gH50;8R8PH0e/Ig0`2b8R86
0=[:N@P0gLek2@3QdGd:0>GEO`80jMV12@3[fX450;8R8PD0l>242@3fiXL30?WXQ`<0o^j:1@2b8R83
0?oaR`<0nnf7103Vg7aI05nNX040oooo001_05nNX080?ch_0`1@DCX207MgC`80R8EF1@2b8R8208R5
EP@0U8iK1`2YXFD70:jUI`D0/R8R1`2cZ6P;0<:fK`T0a;M`2@37^G470<VkLPD0/R8R103=_W<50;8R
8P030<o1M03C`gH0dl=f0080dl=f1@2b8R850=K6M`D0/R8R103JbWT90=g=N`P0hM5m2P3UeGl40>WI
P@L0jmZ100<0l>240;8R8P2b8R800`2b8R840?3PQ0X0m^J70P3ij8L40?k^RPD0/R8R0`3olH/20?_]
Q`@0i]al00<0^KET05nNX01OWZ00E`1OWZ010?ooo`00K`1OWZ0303ln;`<0D54j0`1gMdl50;8R8P<0
R8EF0`2DSU/80:VQI@L0[ZEW0`2b8R870;>XJ0<0_kA_2P32]Vl90<BgL0L0akUa0`2b8R850<VkLPD0
/R8R103=_W<50;8R8P030<o1M03C`gH0dl=f0080dl=f1@2b8R850=K6M`D0/R8R103JbWT30;8R8PD0
gLek203QdGd:0>GEO`H0jMV11@3[fX430?3PQ0<0/R8R0`3`h8@<0?KVQ`L0o^j:0`2b8R840?oaR`03
0?_]Q`3Vg7`0i]al0080i]al00<0^KET05nNX01OWZ00F01OWZ010?ooo`00L01OWZ0303ln;`80D54j
101gMdl30;8R8PD0R8EF0P2DSU/90:VQI@X0[ZEW1@2cZ6P50;ndK`X0`[I_2@34]g050<NiL@D0/R8R
1039^g850;8R8P@0cKic00@0cl5d0;8R8P2b8R80/R8R0P3?`G@50=?3MP<0/R8R1P3FaWL50;8R8P<0
f/Yi1@2b8R830=g=N`P0hM5m2P3UeGl80>WIP@<0jmZ12@3`h8@<0?KVQ`030?[[R@3nkXX0o^j:00D0
o^j:1`3olH/40>KLO0030;VeI01OWZ00GijP05T0GijP0@3oool00740GijP0`0o?Rl2051A>P@0MgM?
2028QEH<0:VQI@T0[ZEW0`2cZ6P70;ndK`X0`[I_2034]g050<NiL@D0/R8R1@39^g830;8R8PD0cKic
1P3?`G@70=?3MPP0e/Ig0`2b8R840=[:N@D0/R8R0P3McG/80>7AO@X0iMEo2P3YfH4:0?3PQ0/0m^J7
0`3jjhT50?k^RPP0oo6;0`3Vg7`30;8R8U/0GijP0@3oool00700GijP0`2b8R8203ln;`03051A>P1g
Mdl0MgM?00@0MgM?1P28QEH20::MH`T0ZJ5U0`2b8R880:jUI`/0_kA_2@32]Vl50<BgL0<0/R8R1037
^G450;8R8PH0bK]b1`3=_W<70=G7N0H0elUi1`3IbgX70=[:N@030=g=N`2b8R80/R8R00<0/R8R0P3M
cG/20>7AO@<0/R8R0P3QdGd:0>GEO`X0jMV10P3]gH<70?3PQ080m^J70`2b8R870?KVQ`@0n^^9103n
kXX80?oaR`030?W^R03Vg7`0i]al00D0/R8RFP1OWZ010?ooo`00K`1OWZ050;8R8P80?ch_1`1gMdl5
08R5EP@0XYeS1P2YXFD50;8R8PL0[ZEW0P2l/Vh:0;ndK`T0`[I_0`34]g050;8R8P@0akUa0`2b8R80
1037^G40bK]b0<VkLP39^g840=74M`L0dlEh1P3EagP60=O9N@L0fL]j1P3LcW/30=g=N`<0/R8R0P3M
cG/20>7AO@D0/R8R2@3UeGl:0>WIP@D0kMf31@3`h8@20?KVQ`D0/R8R103fiXL60?[[R@<0o^j:203o
lH/0103ikXP0i]al0>KLO03Vg7`50;8R8UX0GijP0@3oool006l0GijP1@2b8R8303ln;`03069VA@1g
Mdl0MgM?00@0MgM?1028QEH50::MH`D0ZJ5U1@2b8R800`2YXFD0[ZEW0:jUI`030:jUI`D0_;9^2@2o
]6l90<:fK`80a;M`1@2b8R800`34]g00akUa0<NiL@050<NiL@L0dLAg1`3CaGP60=G7N0H0elUi1`3I
bgX60=c>N`<0g]1m103McG/30>7AO@D0/R8R203UeGl:0>WIP@L0kMf30`3`h8@30?KVQ`D0/R8R0P3f
iXL80?[[R@80o^j:103olH/30;8R8P030?oaR`3ikXP0nNj80080i]al00<0^KET0;8R8P2b8R800`2b
8R9J05nNX040oooo001_05nNX0D0/R8R00H0GijP03ln;`0o?Rl0?ch_069VA@1gMdl30;8R8P<0MgM?
0P28QEH70::MH`<0ZJ5U1@2b8R820:VQI@@0[ZEW1P2l/Vh:0;ndK`P0`[I_00<0a;M`0;8R8P2b8R80
0`2b8R820<BgL0<0akUa103?`gH70=74M`H0dlEh1P3EagP60=O9N@H0fL]j1P3LcW/70=k@O@@0hM5m
1@2b8R830>GEO`<0/R8R00<0iMEo0>WIP@3YfH401`3YfH4:0>gMP`D0m^J71@2b8R800`3fiXL0n^^9
0?[[R@070?[[R@D0oo6;1@2b8R80103ikXP0i]al0>KLO02i]F@205nNX0<0/R8RF`1OWZ010?ooo`00
L01OWZ030;8R8P<0GijP0P0o?Rl00`1RITD0/R8R0;8R8P030;8R8P<0MgM?00<0R8EF0::MH`2RWF<0
1`2RWF<20:VQI@<0/R8R102YXFD20:jUI`T0_;9^2@2o]6l30<:fK`<0/R8R0P32]Vl01034]g00/R8R
0;8R8P2b8R830<BgL0P0cl=f1P3Aa7L70=?5N0D0eLMh1P3GbGT60=W;NPH0g<ik1`3Nd7d30>7BOP80
hM5m0`2b8R830>GEO`D0/R8R203YfH4:0>gMP`80l>:51@3fiXL30;8R8PX0n^^900<0o>n;0?oaR`3o
lH/00`3olH/50;8R8P030?W^R03Vg7`0^KET0640GijP0@3oool007L0GijP0P0o?Rl50;8R8P@0MgM?
2P2RWF<90:VQI@/0_;9^2@2o]6l00`32]Vl0/R8R0;8R8P030;8R8P80`[I_1034]g030<g1MPP0cl=f
1P3Aa7L60=?5N0D0eLMh1@3GbGT60=W;NPH0g<ik1`3Nd7d60>7BOPH0iMEo1@2b8R860>WIP@X0kMf3
103`hXD60?KVQ`X0n^^90`3lkh/50?oaR`D0/R8R00<0i]al0;VeI01OWZ00H@1OWZ010?ooo`00N01O
WZ000`0o?Rl0/R8R0;8R8P030;8R8PD0MgM?00<0VYMP0::MH`2RWF<0202RWF<70:VQI@80^K5]2`2l
/Vh80;ndK`D0/R8R0`32]Vl70<g1MPL0cl=f1P3Aa7L60=?5N0D0eLMh1@3GbGT60=W;NPD0g<ik1`3N
d7d60>7BOP<0hmEo103UeGl50;8R8PD0jMV12@3]gH<70?3RQ@@0m^J70P3jjhT30;8R8P@0n^^91@3l
kh/50?oaR`040?W^R02b8R80/R8R0;8R8P80^KETH`1OWZ010?ooo`00N@1OWZ001@0o?Rl0/R8R0;8R
8P2b8R80HVI500D0MgM?0`2JUf060::MH`<0/R8R00<0XYeS0:VQI@2YXFD00`2YXFD40;VaK@/0_;9^
1P2o]6l50;8R8P80`[I_0`3<`7D60<g1MPL0cl=f1P3Aa7L50=?5N0D0eLMh1@3GbGT60=W;NPD0g<ik
1P3Nd7d60>7BOPH0hmEo0`3UeGl30;8R8P80jMV10`2b8R890>gMP`P0l>:50P3fiXL30?[[R@D0/R8R
00<0n^^90?c_R`3lkh/01@3lkh/30?oaR`D0nNj800<0i=en0;VeI01OWZ00H`1OWZ010?ooo`00NP1O
WZ000`0o?Rl0HVI5069VA@02069VA@@0MgM?1@2JUf030::MH`D0/R8R00<0XYeS0:VQI@2YXFD00P2Y
XFD60;VaK@X0_;9^00@0_kA_0;8R8P2b8R80/R8R0P2o]6l30;8R8P80`[I_1@3<`7D60<g1MPL0cl=f
1@3Aa7L60=?5N0@0eLMh1@3GbGT50=W;NPD0g<ik1P3Nd7d60>7BOPP0hmEo1P3YfH450;8R8PH0kMf3
2P3`hXD50?[[R@D0/R8R203lkh/20?oaR`D0nNj800<0i=en0;8R8P2b8R80I01OWZ010?ooo`00NP1O
WZ000`2b8R80HVI5069VA@04069VA@<0MgM?1P2JUf000`2RWF<0/R8R0;8R8P030;8R8P<0XYeS0P2Y
XFD80;VaK@P0_;9^1@2b8R840;ndK`P0c<1e1P3=`GH60<o3MPH0dLAg1@3CaGP40=G7N0D0elUi1@3I
bgX50=c>N`D0g]1m1P3QdWh80>?EO`80iMR11@3YfH450;8R8P@0kMf32P3`hXD20??UQ`D0n^^91@2b
8R880?c_R`030?oaR`3ikXP0nNj80080nNj80P3TgGh40;8R8V<0GijP0@3oool007T0GijP0`2b8R80
0`1GFSh0HVI5069VA@03069VA@80MgM?1`2JUf050;8R8P@0XYeS2`2i/Fd60;bbKPD0/R8R0`2o]6l3
0<^oM@P0c<1e1@3=`GH60<o3MPD0dLAg1@3CaGP40=G7N0@0elUi1@3IbgX50=c>N`D0g]1m1P3QdWh7
0>?EO`D0iMR10`3YfH400`3]gH<0/R8R0;8R8P030;8R8P80kMf32P3`hXD40??UQ`H0n^^90`2b8R88
0?c_R`D0nNj80P3TgGh50;8R8V<0GijP0@3oool007T0GijP102b8R80101GFSh0HVI50;8R8P2b8R82
069VA@0307MgC`2JUf00VYMP00H0VYMP0`2b8R850::MH`<0]jm]2P2i/Fd40;bbKPD0/R8R0P2o]6l6
0<^oM@L0c<1e1@3=`GH60<o3MPD0dLAg103CaGP40=G7N0@0elUi1@3IbgX40=c>N`H0g]1m1@3QdWh7
0>?EO`L0iMR1103]gH<30;8R8P80kMf32@3`hXD60??UQ`@0n^^92`3lkh/20?__S0<0nNj80`2b8R80
0`2i]F@0/R8R0;8R8P030;8R8V<0GijP0@3oool007T0GijP2@2b8R82069VA@/0VYMP1@2RWF<50;N_
K@X0^K5]1P2b8R820;bbKPT0bkme1P3<`7D50<g1MPH0cl=f103Aa7L50=?5N0<0/R8R0P3GbGT30;8R
8P@0fL]j103LcW/50=k@O@D0hM9n1P3SeGl70>GHP@<0j=Z21P3]gH<30;8R8PH0l>:5203ciHL20?[[
R@/0o>n;0`3kkh`30?W^R0D0/R8R00@0GijP0;8R8P2b8R80/R8RI01OWZ010?ooo`00NP1OWZ030;8R
8P0305nNX02b8R80/R8R00<0/R8R0P1RITD208n?G0X0VYMP0`2RWF<80;N_K@H0^K5]1@2b8R830;bb
KP@0bKme203;_gD60<c0M@@0cL5f1@3?`gH40=74M`<0/R8R00<0dlEh0;8R8P2b8R80202b8R80103I
bgX0/R8R0;8R8P2b8R820=c>N`D0g]1m1@3QdWh60>?EO`H0iMR11P3XfX830>gMP`030?3RQ@2b8R80
/R8R00<0/R8R0P3`hXD;0??UQ`H0o>n;0`2b8R820?c_R`@0nnn<0`3ikXP00`3TgGh0/R8R0;8R8P03
0;8R8VP0GijP0@3oool007h0GijP1@2b8R83069VA@<0ShmL102JUf030;8R8P<0VYMP00<0XYeS0;N_
K@2g[fd0202g[fd40;VaK@D0/R8R0P2l/Vh70<VoM@L0bkme1P3<`7D40<g1MP@0cl=f6P2b8R820=k@
O@D0hM9n1@3SeGl60>GHP@T0j=Z20`3`hXD50;8R8P/0lnF70P3ej8T50?c_R`D0/R8R1@3kkh`0103i
kXP0i=en0>CMOP3TgGh50;8R8VP0GijP0@3oool007l0GijP0`2b8R8205MJ?P80HVI51@2?Se`00`2J
Uf00/R8R0;8R8P030;8R8P<0VYMP302g[fd20;VaK@D0/R8R00<0^K5]0<VoM@39_gD02039_gD70<^o
M@D0c<1e0`3=`GHR0;8R8P80hM9n1@3SeGl50>GHP@T0j=Z20`3Yg8<20?3RQ@D0/R8R2@3ciHL40?GX
R@D0o>n;1@2b8R840?__S0060?W^R03TgGh0i=en0>CMOP30_f`0GijP0`2b8R9Y05nNX040oooo0023
05nNX0<0EeXn00<0HVI508n?G02?Se`00`2?Se`50;8R8P@0VYMP0P2c[V`<0;N_K@<0/R8R0P2i/Fd3
0<RnM@T0bKme1`3;_gD50<c0M@d0/R8R00H0fLel0;8R8P2b8R80/R8R0=[>O03Kcgd30;8R8P030=_@
O@2b8R80/R8R00/0/R8R103SeGl50>GHP@P0j=Z21P3Yg8<30?3RQ@D0/R8R1@3ciHL70?GXR@@0o>n;
00<0nnn<0;8R8P2b8R800`2b8R830?__S0@0i=enK`1OWZ010?ooo`00Q01OWZ001017BC<0EeXn05MJ
?P1RITD408n?G0D0/R8R102JUf050;>^K0L0]jm]0`2b8R80102g[fd0^K5]0;VaK@2i/Fd60<RnM@P0
bKme1`3;_gD00`3<`7D0/R8R0;8R8P0<0;8R8P<0fLel0`3JcW`20=_?O@<0fm1m00<0g=1m0;8R8P2b
8R80302b8R800`3SeGl0iMR10>GHP@020>GHP@P0j=Z2203Yg8<40??UQ`D0/R8R0P3ciHL90?GXR@80
o>n;103kkh`30;8R8P80nnn<00H0m>^90>CMOP3TgGh0i=en0<2oK02b8R9_05nNX040oooo002405nN
X080/R8R0P1GFSh508n?G0<0/R8R00<0ShmL09ZGH02JUf000P2JUf080;>^K0<0]jm]1@2b8R820;N_
K@X0b;ie1`39_gD50<^oM@/0/R8R00@0f<ak0=S=O03HcG`0f<el0`3IcG`30=[>O080flmm0`3Kd7d3
0=c@O@80gM5n2`2b8R820>GHP@L0j=Z22@3Yg8<30>_NQ0<0lnF71@2b8R8:0?GXR@X0nnn<0P3djhT2
0>CMOP80`;m/0P2b8R9_05nNX040oooo002405nNX0D0/R8R00<0EeXn08:5EP2?Se`01`2?Se`209ZG
H0X0/ji/00<0]jm]0;8R8P2b8R800`2b8R820;N_K@@0akie2@38_WD60<VoM@030<^oM@2b8R80/R8R
00L0/R8R0`3Gc7/30=S<N`<0f<el0`3IcG`20=[>O080flmm0P3Kd7d30=c@O@<0gM5n103NdWh90;8R
8PD0j=Z2203Yg8<60>_NQ0<0lnF71@2b8R870?GXR@<0mNZ:203kkh`30?C[R@80i=en1@2b8R9_05nN
X040oooo002405nNX0H0/R8R00@0EeXn08:5EP22QEH0PXEF0P2?Se`30;8R8P80ShmL2`2c[V`50;8R
8P80]jm]1`37_WD90<RnM@<0bKme202b8R840=K;N`<0elak0P3Hc7/30=S=O080fLel0P3JcW`20=_?
O@80fm1m0P3Ld7d30=gAOP<0g]9n0`3Odgl00`3Oe7l0/R8R0;8R8P060;8R8P030>SJPP3Yg8<0jMb3
00H0jMb32@3[gX@30??UQ`040?GXR@2b8R80/R8R0;8R8PD0mNR91P3ejXX30?__S0<0/R8R103djhT0
0`3TgGh0`;m/0;8R8P040;8R8W00GijP0@3oool008D0GijP1@2b8R800`17BC<0EeXn08:5EP0208:5
EPD0/R8R0P2?Se`30;2/J`P0/ji/102b8R820;N_K@/0akie1`38_WD80;8R8PL0e/]k0P3Gc7/20=S<
N`80f<el0P3IcG`20=[>O0030=_?O@3Kd7d0fm1m0080g=1m0`3MdGh20=kBOP<0gm=o103Oe7l80;8R
8PD0jMb3303[gX@30?GXR@<0/R8R0`3ej8T80?GZRP<0nnn<1@2b8R820?C[R@80`;m/00<0GijP0;8R
8P2b8R800`2b8R9`05nNX040oooo002505nNX0D0/R8R0P1OWZ000`17BC<0PXEF08:5EP050;8R8P<0
ShmL1P2`[6/40;>^K0D0/R8R00<0/ji/0<NnM@37_WD03037_WD30<RnM@L0/R8R2`3Fbg/00`3Gc7/0
f<ak0=S<N`020=S=O080fLel00@0f/il0=_?O@3Kd7d0fm1m0P3Ld7d0103MdGh0g]9n0=kBOP3NdWh2
0=oCO`<0gmAo1@3Pe8070;8R8P030>WLP`3[gX@0jmj400P0jmj41@3/h8D20?GXR@D0/R8R2P3ejXX2
0?__S0030?C[R@2b8R80/R8R00<0/R8R00<0iN220<2oK030_f`00P1OWZ050;8R8W00GijP0@3oool0
08H0GijP0`2b8R8505nNX00308:5EP2b8R80/R8R00<0/R8R0P22QEH208n?G0T0/:a[1@2b8R820;>^
K0D0a[ie2`37_WD60;8R8P@0eL]k2@3Fbg/20=O<N`070=S<N`3HcG`0f<el0=W=O03JcW`0flmm0=_@
O@020=c@O@030=gAOP3NdWh0g]9n0080gm=o0P3Oe7l50>3DP0@0hMF01P2b8R860>_NQ0X0k>250P3e
j8T50;8R8PT0mNZ:103djhT50;8R8P030<2oK01OWZ00GijP00<0GijP0`2b8R9a05nNX040oooo002?
05nNX00404M9<`2b8R80/R8R0;8R8PD0PXEF2@2`[6/50;8R8P80/ji/2P36_WD50<NnM@H0/R8R2@3E
bg/70=K;N`0:0=O<N`3Hc7/0f<el0=W=O03JcW`0flmm0=_@O@3Ld7d0gM5n0=kBOP80gm=o0P3Oe7l3
0>3DP0T0hMF01P2b8R8>0>cPQ@<0mNZ:1@2b8R850?GZRP<0lnV91@3djhT01@3Uh880/R8R0;8R8P2b
8R80`;m/07X0GijP0@3oool00940GijP0`1aNDl508:5EP@0ZjUZ1@2`[6/30;8R8P<0/:a[3`36_WD5
0;8R8Ph0eL]k1@3Fbg/02@3Gc7/0f<el0=W=O03Kcgd0g=1m0=gAOP3NdWh0gm=o0=oDO`020>3DP0H0
hMF01`3QeX400`3/h8D0/R8R0;8R8P030;8R8PP0k>251P3/hHH40?GZRP<0/R8R00<0mNZ:0??YR@3c
jHT01@3cjHT30?C[R@H0iN2200<0/R8R05nNX01OWZ00N@1OWZ010?ooo`00T01OWZ020;8R8P0404M9
<`1aNDl0LGU?075iC`<0/R8R00<0PXEF0:^YJP2[ZFX01@2[ZFX30;2/J`<0/R8R0P2`[6/>0<JnM@D0
/R8R4P3Ebg/30=K;N`<0/R8R00<0gm=o0>3DP03QeH000P3QeH0>0>7FP@H0/R8R00<0k>250>cQQP3/
hHH02`3/hHH20?GZRP<0/R8R2@3cjHT20?C[R@040>GPPP2b8R80/R8R0;8R8P<0iN220`2b8R9j05nN
X040oooo002?05nNX0D0/R8R00<0LGU?0;8R8P2b8R800`2b8R800`22QEH0ZjUZ0:^YJP060:^YJPD0
/R8R0P2`[6/>0<JnM@D0/R8R4`3Ebg/50;8R8Q80hMJ11@2b8R8>0>cQQP80lnV91@2b8R870??YR@<0
iN222P2b8R9j05nNX040oooo002?05nNX0D0/R8R00<0GijP0;8R8P2b8R800`2b8R82075iC`L0ZjUZ
1@2b8R820:^YJPh0a[ie1@2b8R8;0=G<O0H0e/al0P3FcG`50;8R8P80h=J10P3QeX430>7GP@/0hMJ1
1@2b8R8=0>cQQP<0lnV91@2b8R820??YR@@0knJ8103Uh88:0;8R8WX0GijP0@3oool008l0GijP1@2b
8R800`1OWZ00/R8R0;8R8P030;8R8P@0LGU?102WYfP00`2[ZFX0/R8R0;8R8P030;8R8P<0ZjUZ3@35
_gD60;8R8P/0e/al103FcG`20=O>O@030=S?O@2b8R80/R8R00<0/R8R00<0gmF00=oFP@3PeX400`3P
eX440>7FP@L0hMN11@2b8R8=0>cQQP@0lnV91@2b8R850>oVR0@0iN2200<0cleg0;8R8P2b8R800`2b
8R80101OWZ00/R8R0;8R8P2b8R9k05nNX040oooo002@05nNX0<0/R8R0`1OWZ030;8R8P<0JG190`1a
NDl50:NWJ0<0/R8R00D0YjMX0;8R8P2b8R80/R8R0:^YJP0=0<FoM@D0/R8R1P3Fc7`70=K=O080elim
0P3Hcgd00`3Id7h0f]5n0;8R8P020;8R8P040=gDP03Ne800gmF00=oEP080gmJ11@3PeX460>7FP@03
0>cQQP2b8R80/R8R00<0/R8R303/hHH30>oVR0H0/R8R1@3_iXP20>GPPP<0cleg0P1OWZ030;8R8X00
GijP0@3oool009/0GijP0`1YL4T30;8R8PH0YjMX1@2b8R800`2WYfP0aKme0<FoM@0:0<FoM@L0/R8R
203FcG`30=O>O@80f<mm0P3Id7h20=[AOP030=_BO`3Ldgl0g==o0080gMB000<0g]B00=oEP03OeH00
0`3OeX470>3FP@80j^661P2b8R8;0>[QQP<0knJ81@2b8R850>oVR0050<o=M`2b8R80/R8R0;8R8P3?
cGL0Q`1OWZ010?ooo`00V`1OWZ070;8R8PD0YjMX1@2b8R830:NWJ0/0aKmf1`2b8R850=K=O0<0elim
0`3Hcgd20=W@OP<0f]5n00<0fm9o0=cCO`3Ldgl00`3Me8020=kDP080gmF0103OeX430>3FP@030>SO
Q@2b8R80/R8R00D0/R8R0P3XghD90>[QQP@0knJ81@2b8R840>OQQ@030<o=M`2b8R80/R8R00@0/R8R
QP1OWZ010?ooo`00V`1OWZ070;8R8P80JG190`2RY6H50;8R8P@0YjMX2@35_gH20<G1MPP0/R8R103G
cWd40=S?O@80fM1n0`3JdGh20=_BO`80g==o103Me8020=kDP0<0gmF0103OeX490;8R8PX0j=n50`2b
8R820>OQQ@D0/R8R0P3WhHD30<o=M`H0/R8RQP1OWZ010?ooo`00V`1OWZ070;8R8P80HFQ40P1YL4T2
0::TIP<0/R8R0P2RY6H30;8R8P030::TIP35`GH0aL5f00T0aL5f2P2b8R840=S?O@80fM1n103JdGh2
0=_BO`<0g==o103Me8020=kDP0<0gmF000<0i=f40;8R8P2b8R80202b8R890>SOQ@030>OQQ@2b8R80
/R8R00<0/R8R0P3WhHD30;8R8P80in6500@0cleg0;:dJ@2b]6T0GijP1P2b8R:605nNX040oooo002L
05nNX0D0/R8R101OWZ02065XA00306U`B@2RY6H0XZAV0080XZAV1@2b8R820::TIPL0aL5f0`36`WL;
0;8R8P<0fM1n1@3JdGh20=_BO`<0g==o103Me8030=kDP0/0/R8R203TgH@40>OQQ@D0/R8R1@3WhHD2
0;:dJ@D0GijP102b8R:705nNX040oooo002W05nNX080/R8R0`2RY6H50;8R8P@0XZAV2@36`WL;0;8R
8P060<W5N02b8R80/R8R0;8R8P3;b7X0/R8R0`3KdWl30=cCOa40/R8R1`3TgH@0103Lf800/R8R0;8R
8P2b8R820=cHP0D0/R8R0`3Lf8020;8R8Y80GijP0@3oool00:H0GijP1@2b8R800`0F3PP0/R8R0;8R
8P030;8R8P<0WZ5T0`2b8R800`2NXF@0a/9g0<K2M`030<K2M`D0al=g8@2b8R870>3JP`<0g=R01@2b
8R820=cHP0<0/R8R0P3Lf8050;8R8Y40GijP0@3oool00:H0GijP2P2b8R8309jQI0D0/R8R0P2NXF@8
0<O3M`80bLEh702b8R830=cFP@D0h=Z31@3?cWX50;8R8P@0clij00<0GijP0;8R8P2b8R801@2b8R:A
05nNX040oooo002V05nNX0P0/R8R0`1OWZ000`0F3PP0/R8R0;8R8P040;8R8P<0VimS0`2b8R8209^O
H`D0bLEh0`2b8R800`3;b7X0/R8R0;8R8P0?0;8R8P80em=o0`2b8R860=cFP@040<o>NP2b8R80/R8R
0;8R8P@0clij1P2b8R8505nNX0H0/R8RT@1OWZ010?ooo`00Y`1OWZ060;8R8P@0GijP1`2b8R8209^O
H`D0/R8R102JWf840<W5N0<0blQj0`2b8R80103?bg/0/R8R0;8R8P2b8R820<o;N`<0/R8R0`3Ccgd6
0=OCO`H0`L9d1@2b8R840<72M0H0/R8R1P1OWZ030;8R8Y80GijP0@3oool00;40GijP1P2b8R800`1O
WZ00VYmR09ZOHP050;8R8PD0VYmR0P2b8R860<_8NPL0cl]k1P3Ccgd50;BgKP<0/R8R00@0];M^0<72
M031`W@0`L9d1@2b8R8505nNX0D0/R8RV`1OWZ010?ooo`00/@1OWZ050;8R8P@0GijP1`2b8R8209^Q
H`D0/R8R0`2KXF<50;8R8P<0XJIU00<0ZJeX0;8R8P2b8R800`2b8R820:V]J080];M^1@2b8R830;Bg
KPD0/R8R1@1OWZ050;8R8Y/0GijP0@3oool00;80GijP0`2b8R8605nNX0L0/R8R00<0GijP0;8R8P2b
8R800`2b8R8205nNX0030:6VI@2b8R80/R8R00<0/R8R0`2QYVD00`2Y[FP0/R8R0;8R8P030;8R8P<0
ZJeX00<0GijP0;8R8P2b8R800`2b8R800`1OWZ00/R8R0;8R8P040;8R8PL0GijP0`2b8R:L05nNX040
oooo002m05nNX0D0/R8R00<0GijP0;8R8P2b8R800`2b8R8205nNX0H0/R8R101OWZ070;8R8P80GijP
1@2b8R800`1OWZ00/R8R0;8R8P030;8R8ZL0GijP0@3oool00;h0GijP0`2b8R8305nNX0<0/R8R0`1O
WZ050;8R8PH0GijP1P2b8R8305nNX0<0/R8R0`1OWZ030;8R8ZP0GijP0@3oool00<X0GijP1@2b8R87
05nNX0D0/R8R]01OWZ010?ooo`00b`1OWZ030;8R8PT0GijP0`2b8R:e05nNX040oooo003o05nNX900
GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool0
0?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01O
WZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00
o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nN
X040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o
05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP
0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0
GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ01
0?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1O
WZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040
oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nN
X900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3o
ool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijP
T01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?oo
o`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@
05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo
003o05nNX900GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900
GijP0@3oool00?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool0
0?l0GijPT01OWZ010?ooo`00o`1OWZ2@05nNX040oooo003o05nNX900GijP0@3oool00?l0GijPT01O
WZ010?ooo`00o`1OWZ2@05nNX040oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {0.0486402, -8.31051*^-05, \
0.00214933, 0.00214933}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->{},
WindowSize->{494, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 68, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1847, 56, 520, 18, 68, "Usage",
      CellTags->"Function?"],
    Cell[2370, 76, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 172426, 4166}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 68, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1847, 56, 520, 18, 68, "Usage",
  CellTags->"Function?"],
Cell[2370, 76, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2467, 81, 189, 4, 75, "MathCaption"],
Cell[2659, 87, 601, 22, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3285, 113, 34, 0, 39, "ExampleSection"],
Cell[3322, 115, 99, 2, 29, "Input"],

Cell[CellGroupData[{
Cell[3446, 121, 756, 13, 249, "Input"],
Cell[4205, 136, 167512, 4007, 441, 103773, 3215, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

