(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9630,        287]*)
(*NotebookOutlinePosition[     10639,        322]*)
(*  CellTagsIndexPosition[     10564,        316]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["PolarDensityDraw", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] PolarDensityDraw[",
  StyleBox["f[r,\[Theta]", "TI"],
  StyleBox["],", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula"],
  StyleBox["r", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["rmin", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["rmax", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula"],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula"],
  StyleBox["\[Theta]", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["\[Theta]min", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["\[Theta]max", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula"],
  "] generates a polar density plot of ",
  Cell[BoxData[
      \(f[r, \[Theta]]\)]],
  "."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell[TextData[{
  "The options that can be used, and their default values are:\n",
  Cell[BoxData[
      \(ColorFunction \[Rule] Automatic\)]],
  " \t (GrayLevel)\n",
  Cell[BoxData[
      \(ColorFunctionScaling \[Rule] True\)]],
  "\n",
  Cell[BoxData[
      \(PlotPoints \[Rule] Automatic\)]],
  "\n",
  Cell[BoxData[
      \(Mesh \[Rule] False\)]],
  " \t\t\t(Opposite of DensityPlot)\n",
  Cell[BoxData[
      \(MeshStyle \[Rule] GrayLevel[0]\)]]
}], "MathCaption"],

Cell[TextData[{
  "The default value of ",
  StyleBox["PlotPoints",
    FontFamily->"Courier"],
  " is ",
  StyleBox["{",
    FontFamily->"Courier"],
  "15, ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Theta]\)]],
  StyleBox["}",
    FontFamily->"Courier"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Theta] = \[LeftFloor]4 \( \[Theta]2 - \[Theta]1\
\)\/\(2  \[Pi]\)\[CenterDot]15\[RightFloor]\)]],
  ".  For any specification of the form ",
  StyleBox["PlotPoints\[ThinSpace]\[Rule]",
    FontFamily->"Courier"],
  "\[ThinSpace]",
  Cell[BoxData[
      \(TraditionalForm\`p\_r\)]],
  ", the actual ",
  StyleBox["PlotPoints",
    FontFamily->"Courier"],
  " value becomes ",
  StyleBox["{",
    FontFamily->"Courier"],
  Cell[BoxData[
      \(TraditionalForm\`p\_r\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Theta]\)]],
  StyleBox["}",
    FontFamily->"Courier"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Theta] = \[LeftFloor]4 \(\( \[Theta]2 - \
\[Theta]1\)\/\(2  \[Pi]\)\) p\_r\[RightFloor]\)]],
  ". "
}], "MathCaption"],

Cell["\<\
PolarDensityDraw actually constructs a table and uses ListPolarDensityDraw.\
\>", "MathCaption"],

Cell["\<\
DrawingTransform cannot be used on the graphics produced by PolarDensityPlot.\
\
\>", "MathCaption"],

Cell["This routine was kindly contributed by Selwyn Hollis.", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DensityPlot",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["ListPolarDensityDraw",
    ButtonData:>{"ListPolarDensityDraw"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ContourDraw",
    ButtonData:>{"ContourDraw"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
The following plots a polar function over a restricted radial and angular \
domain.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{PolarDensityDraw[
            Cos[2  r\ \[Theta]], {r,  .5, 2}, {\[Theta], \[Pi]/3, 
              11  \[Pi]/6}]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  "Here, some of the PolarDensityDraw options are used. If the Background \
selected for the plot is not White and the minimum radius is not zero, then \
the Background should ",
  StyleBox["also",
    FontSlant->"Italic"],
  " be included in the options for PolarDensityDraw."
}], "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{PolarDensityDraw[
            Cos[2  r\ \[Theta]], {r,  .5, 2}, {\[Theta], \[Pi]/3, 
              11  \[Pi]/6}, \[IndentingNewLine]ColorFunction \[Rule] 
              Hue, \[IndentingNewLine]PlotPoints \[Rule] 
              30, \[IndentingNewLine]Mesh \[Rule] 
              True, \[IndentingNewLine]MeshStyle \[Rule] 
              Gray, \[IndentingNewLine]Background \[Rule] 
              Linen]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]Background \[Rule] 
          Linen\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{PolarDensityDraw[
            r\ Cos[3  \[Theta]] - \ Sin[4  r + 5  \[Theta]], {r, 0, 
              6}, {\[Theta], 0, 
              8  \[Pi]/4}, \[IndentingNewLine]PlotPoints \[Rule] 
              45, \[IndentingNewLine]ColorFunction \[Rule] \((Hue[#, 
                    1, #] &)\)]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          False, \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 
          450\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell[TextData[{
  "Perhaps the following function should have been done as a rectangular \
plot! It uses the TwoColorScale to delineate positive and negative regions. \
The ",
  Cell[BoxData[
      \(ColorFunctionScaling \[Rule] False\)]],
  " option is used so the color function applies to actual values of the \
function. A set of contours was drawn on top of the density plot. The density \
plot graphics cannot be transformed by DrawingTransform because they involve \
the use of the Circle primitive, nor do we need to transform it. However, it \
was easier to draw the contours with the polar form of the function and then \
transform to rectangular coordinates using DrawingTransform. The contours can \
be transformed because they are Line primitives."
}], "Text"],

Cell[BoxData[
    \(\(Module[\[IndentingNewLine]{colorfun, 
          f = Exp[\(-r\)/4] Cos[r\ Cos[\[Theta]]] 
              Cos[r\ Sin[\[Theta]]]}, \
\[IndentingNewLine]\[IndentingNewLine]colorfun = 
          TwoColorScale[{\(-0.5\), 0, 1}, {\(ColorMix[Peacock, Black]\)[0.5], 
              Peacock, \(ColorMix[Peacock, White]\)[
                0.8], \(ColorMix[Melon, White]\)[0.8], 
              Melon, \(ColorMix[Melon, Black]\)[0.5]}]; \[IndentingNewLine]\n
        Draw2D[\[IndentingNewLine]{PolarDensityDraw[
              f, \ {r, 0, 6}, \ {\[Theta], 0, 
                2  \[Pi]}, \[IndentingNewLine]ColorFunction \[Rule] colorfun, 
              ColorFunctionScaling \[Rule] 
                False, \[IndentingNewLine]PlotPoints \[Rule] 
                60], \[IndentingNewLine]ContourDraw[
                f, {r, 0, 6}, \ {\[Theta], 0, 
                  2  \[Pi]}, \[IndentingNewLine]Contours \[Rule] {0.1, \(-0.1\
\)}, \[IndentingNewLine]ContourShading \[Rule] 
                  False, \[IndentingNewLine]ContourStyle \[Rule] 
                  AlizarinCrimson, \[IndentingNewLine]PlotPoints \[Rule] 60] /. 
              DrawingTransform[#1  Cos[#2] &, #1 
                     Sin[#2] &]}, \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]PlotLabel \[Rule] 
            f, \[IndentingNewLine]FrameLabel \[Rule] {x, 
              y}, \[IndentingNewLine]Background \[Rule] \(ColorMix[Mint, 
                White]\)[0.5], \[IndentingNewLine]ImageSize \[Rule] 
            450\[IndentingNewLine]]];\)\)], "Input",
  CellLabel->"In[5]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{700, 526},
WindowMargins->{{23, Automatic}, {Automatic, 24}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 63, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1842, 56, 835, 34, 33, "Usage",
      CellTags->"Function?"],
    Cell[2680, 92, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 10318, 305}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 63, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1842, 56, 835, 34, 33, "Usage",
  CellTags->"Function?"],
Cell[2680, 92, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2777, 97, 469, 16, 158, "MathCaption"],
Cell[3249, 115, 1080, 40, 66, "MathCaption"],
Cell[4332, 157, 106, 2, 41, "MathCaption"],
Cell[4441, 161, 110, 3, 41, "MathCaption"],
Cell[4554, 166, 76, 0, 41, "MathCaption"],
Cell[4633, 168, 335, 13, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[4993, 185, 34, 0, 39, "ExampleSection"],
Cell[5030, 187, 97, 2, 29, "Input"],
Cell[5130, 191, 107, 3, 25, "Text"],
Cell[5240, 196, 333, 6, 109, "Input"],
Cell[5576, 204, 305, 7, 42, "Text"],
Cell[5884, 213, 678, 12, 229, "Input"],
Cell[6565, 227, 618, 11, 189, "Input"],
Cell[7186, 240, 773, 13, 110, "Text"],
Cell[7962, 255, 1640, 28, 469, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

