(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4888,        174]*)
(*NotebookOutlinePosition[      5895,        209]*)
(*  CellTagsIndexPosition[      5821,        203]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["PrecisionDraw", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] Precision",
  Cell[BoxData[
      RowBox[{
        StyleBox["Draw",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(f, {x, xmin, xmax}, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " draws the function f using high precision evaluation.\n\
\[FilledSmallSquare] Precision",
  Cell[BoxData[
      RowBox[{
        StyleBox["Draw",
          "MR"], 
        StyleBox["[",
          "MR"], 
        RowBox[{
          RowBox[{
            StyleBox["{",
              "MR"], 
            StyleBox[\(f1, f2,  ... \),
              "TI"], 
            StyleBox["}",
              "TI"]}], 
          StyleBox[",",
            "TI"], 
          StyleBox[\({x, xmin, xmax}\),
            "TI"], 
          StyleBox[",",
            "TI"], 
          StyleBox[\(opts ... \),
            "TI"]}], 
        StyleBox["]",
          "MR"]}]]],
  " draws multiple functions fi using high precision evaluation."
}], "Usage",
  CellTags->"Function?"],

Cell[" Display of the Graphics is suppressed.", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
Ted Ersek and Mikhail Bronshtein, the authors of the underlying PrecisionPlot \
routine, kindly permitted me to include it in DrawGraphics.\
\>", "MathCaption"],

Cell["\<\
The underlying routine, PrecisionPlot, has the attributes HoldRest. \
Evaluation of the first argument is not necessary.\
\>", "MathCaption"],

Cell["\<\
Usage is the same as Plot. Regular Plot options may be used. Basic Graphics \
options, such as PlotRange have no effect.\
\>", "MathCaption"],

Cell["PrecisionPlot may also be used directly.", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Draw",
    ButtonData:>{"Draw"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["Plot",
    ButtonStyle->"RefGuideLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
This was a sample function provided to MathGroup by Selwyn Hollis.\
\>", "Text"],

Cell[BoxData[
    \(f[t_] = 
      Simplify[Nest[
          1 - \[Integral]\_0\%t\( 
                    2\ s\ \((#1 /. \[InvisibleSpace]t \[Rule] 
                          s)\)\) \[DifferentialD]s &, Cos[t], 12]]\)], "Input",\

  CellLabel->"In[2]:="],

Cell["Regular plotting precision is inadequate.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Draw[
            f[t], {t, \(-3\), 3}]}, \[IndentingNewLine]Frame \[Rule] 
          True];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell["PrecisionDraw gives a smooth curve.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{PrecisionDraw[
            f[t], {t, \(-3\), 3}]}, \[IndentingNewLine]Frame \[Rule] 
          True];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["PrecisionPlot may be used directly.", "Text"],

Cell[BoxData[
    \(\(PrecisionPlot[f[t], {t, \(-3\), 3}];\)\)], "Input",
  CellLabel->"In[5]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{568, 602},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 60, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1839, 56, 1033, 40, 73, "Usage",
      CellTags->"Function?"],
    Cell[2875, 98, 87, 1, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5574, 192}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 60, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1839, 56, 1033, 40, 73, "Usage",
  CellTags->"Function?"],
Cell[2875, 98, 87, 1, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2965, 101, 170, 3, 58, "MathCaption"],
Cell[3138, 106, 151, 3, 58, "MathCaption"],
Cell[3292, 111, 151, 3, 58, "MathCaption"],
Cell[3446, 116, 63, 0, 41, "MathCaption"],
Cell[3512, 118, 197, 9, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3734, 131, 34, 0, 39, "ExampleSection"],
Cell[3771, 133, 97, 2, 29, "Input"],
Cell[3871, 137, 90, 2, 25, "Text"],
Cell[3964, 141, 253, 7, 40, "Input"],
Cell[4220, 150, 57, 0, 25, "Text"],
Cell[4280, 152, 180, 4, 69, "Input"],
Cell[4463, 158, 51, 0, 25, "Text"],
Cell[4517, 160, 189, 4, 69, "Input"],
Cell[4709, 166, 51, 0, 25, "Text"],
Cell[4763, 168, 97, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

