(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14707,        382]*)
(*NotebookOutlinePosition[     15679,        416]*)
(*  CellTagsIndexPosition[     15604,        410]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ProportionalArrow", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"Proportional", 
              StyleBox["Arrow",
                "MR"]}]], 
          StyleBox["[",
            "MR"], 
          StyleBox["fractional",
            "MR"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(base, tip, opt ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will draw an arrow from base to tip with the arrowhead placed fractional \
distance between the base and tip."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed. \
\>", "MathCaption",
  CellTags->"Function?"],

Cell[TextData[{
  "The options are the same as in ",
  ButtonBox["Arrow",
    ButtonData:>{"Graphics`Arrow`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[TextData[{
  Cell[BoxData[
      \(HeadScaling \[Rule] Relative\)]],
  " is taken to mean relative to the length of the entire line from base to \
tip."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ArrowCurve",
    ButtonData:>{"ArrowCurve"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowLine",
    ButtonData:>{"ArrowLine"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrowTangent",
    ButtonData:>{"ArrowTangent"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Arrow",
    ButtonData:>{"Graphics`Arrow`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  " ."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Here, directed arrows are used on the edges of a trianagle.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(With[\[IndentingNewLine]{pts = {{\(-1\), 0}, {1, 0}, {0, 
                1}}}, \[IndentingNewLine]Draw2D[\[IndentingNewLine]{\
AbsolutePointSize[4], 
            Point /@ pts, \[IndentingNewLine]MapThread[\(ProportionalArrow[
                    0.5]\)[#1, #2, HeadCenter \[Rule] 1/2] &, {pts, 
                RotateLeft[pts]}]}, \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]PlotRange \[Rule] {{\(-2\), 
                2}, {\(-1\), 2}}, \[IndentingNewLine]Background \[Rule] 
            Linen]];\)\)], "Input",
  CellLabel->"In[294]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.5 0.25 0.25 0.25 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.025 0 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.025 0 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 0 0 r
4 Mabswid
.25 .25 Mdot
.75 .25 Mdot
.5 .5 Mdot
.5 Mabswid
[ ] 0 setdash
.25 .25 m
.5 .25 L
s
% Start of user PostScript
-1. 0 0 0 MAarrowhead1
% End of user PostScript
.5 .25 m
.75 .25 L
s
.75 .25 m
.625 .375 L
s
% Start of user PostScript
1. 0 0.5 0.5 MAarrowhead1
% End of user PostScript
.625 .375 m
.5 .5 L
s
.5 .5 m
.375 .375 L
s
% Start of user PostScript
0 1. -0.5 0.5 MAarrowhead1
% End of user PostScript
.375 .375 m
.25 .25 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[294]:=",
  ImageSize->{288, 216},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000f2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3j
l>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40
oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`
iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3o
ool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V
803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?oo
o`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP
0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo
003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00
n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool0
0?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803j
l>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00
o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`
iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o
0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V
0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0
n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H1
0?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3j
l>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40
oooo003o0?[`iR00n_3V0@3oool00840n_3V0`00002K0?[`iP40oooo00230?[`iPD00000U`3jl>H1
0?ooo`00A`3jl>H2000003`0n_3V200000190?[`iP800000A`3jl>H10?ooo`00AP3jl>JC000004H0
n_3V0@3oool004H0n_3V1000000l0?[`iPP00000A`3jl>H4000004H0n_3V0@3oool004L0n_3V0`00
000j0?[`iPH00000B`3jl>H3000004L0n_3V0@3oool004X0n_3V00<000000?[`iP3jl>H0=@3jl>H5
000004d0n_3V00<000000?[`iP3jl>H0B03jl>H10?ooo`00B`3jl>H00`000000n_3V0?[`iP0c0?[`
iP800000D03jl>H00`000000n_3V0?[`iP190?[`iP40oooo001<0?[`iP030000003jl>H0n_3V08<0
n_3V00<000000?[`iP3jl>H0BP3jl>H10?ooo`00C@3jl>H00`000000n_3V0?[`iP210?[`iP030000
003jl>H0n_3V04/0n_3V0@3oool004h0n_3V00<000000?[`iP3jl>H0O`3jl>H00`000000n_3V0?[`
iP1<0?[`iP40oooo001?0?[`iP030000003jl>H0n_3V07d0n_3V00<000000?[`iP3jl>H0C@3jl>H1
0?ooo`00D03jl>H00`000000n_3V0?[`iP1k0?[`iP030000003jl>H0n_3V04h0n_3V0@3oool00540
n_3V00<000000?[`iP3jl>H0N@3jl>H00`000000n_3V0?[`iP1?0?[`iP40oooo001B0?[`iP030000
003jl>H0n_3V07L0n_3V00<000000?[`iP3jl>H0D03jl>H10?ooo`00D`3jl>H00`000000n_3V0?[`
iP1e0?[`iP030000003jl>H0n_3V0540n_3V0@3oool005@0n_3V00<000000?[`iP3jl>H0L`3jl>H0
0`000000n_3V0?[`iP1B0?[`iP40oooo001E0?[`iP030000003jl>H0n_3V0740n_3V00<000000?[`
iP3jl>H0D`3jl>H10?ooo`00EP3jl>H00`000000n_3V0?[`iP1_0?[`iP030000003jl>H0n_3V05@0
n_3V0@3oool005L0n_3V00<000000?[`iP3jl>H0K@3jl>H00`000000n_3V0?[`iP1E0?[`iP40oooo
001H0?[`iP030000003jl>H0n_3V06/0n_3V00<000000?[`iP3jl>H0EP3jl>H10?ooo`00F@3jl>H0
0`000000n_3V0?[`iP1Y0?[`iP030000003jl>H0n_3V05L0n_3V0@3oool005X0n_3V00<000000?[`
iP3jl>H0I`3jl>H00`000000n_3V0?[`iP1H0?[`iP40oooo001K0?[`iP030000003jl>H0n_3V06D0
n_3V00<000000?[`iP3jl>H0F@3jl>H10?ooo`00G03jl>H00`000000n_3V0?[`iP1S0?[`iP030000
003jl>H0n_3V05X0n_3V0@3oool005d0n_3V00<000000?[`iP3jl>H0H@3jl>H00`000000n_3V0?[`
iP1K0?[`iP40oooo001N0?[`iP030000003jl>H0n_3V05T0n_3V00<000000?[`iP3jl>H00`3jl>H0
0`000000n_3V0?[`iP1L0?[`iP40oooo001O0?[`iP030000003jl>H0n_3V05L0n_3V0P0000040?[`
iP030000003jl>H0n_3V05d0n_3V0@3oool00600n_3V00<000000?[`iP3jl>H0EP3jl>H00`000000
n_3V0?[`iP020?[`iP030000003jl>H0n_3V05h0n_3V0@3oool00640n_3V00<000000?[`iP3jl>H0
E03jl>H2000000<0n_3V00<000000?[`iP3jl>H0G`3jl>H10?ooo`00HP3jl>H00`000000n_3V0?[`
iP1C0?[`iP8000000P3jl>H00`000000n_3V0?[`iP1P0?[`iP40oooo001S0?[`iP030000003jl>H0
n_3V0540n_3V0`000000103jl>H000000?[`iP3jl>H2000005l0n_3V0@3oool006@0n_3V00<00000
0?[`iP3jl>H0D03jl>H2000000030?[`iP000000n_3V00<00000H03jl>H10?ooo`00I@3jl>H00`00
0000n_3V0?[`iP1>0?[`iPL00000HP3jl>H10?ooo`00IP3jl>H00`000000n_3V0?[`iP1=0?[`iPH0
0000H`3jl>H10?ooo`00I`3jl>H00`000000n_3V0?[`iP1;0?[`iPD00000I@3jl>H10?ooo`00J03j
l>H00`000000n_3V0?[`iP1:0?[`iP@00000IP3jl>H10?ooo`00J@3jl>H00`000000n_3V0?[`iP18
0?[`iP<00000J03jl>H10?ooo`00JP3jl>H00`000000n_3V0?[`iP170?[`iP800000J@3jl>H10?oo
o`00J`3jl>H00`000000n_3V0?[`iP150?[`iP030000003jl>H0n_3V06T0n_3V0@3oool006`0n_3V
0P0000140?[`iP030000003jl>H0n_3V06X0n_3V0@3oool006`0n_3V100000110?[`iP030000003j
l>H0n_3V06/0n_3V0@3oool006d0n_3V1000000o0?[`iP030000003jl>H0n_3V06`0n_3V0@3oool0
06d0n_3V1P00000l0?[`iP030000003jl>H0n_3V06d0n_3V0@3oool006h0n_3V1P00000j0?[`iP03
0000003jl>H0n_3V06h0n_3V0@3oool006l0n_3V1`00000g0?[`iP030000003jl>H0n_3V06l0n_3V
0@3oool006l0n_3V100000000`3jl>H0000000000002000003@0n_3V00<000000?[`iP3jl>H0L03j
l>H10?ooo`00L03jl>H2000000030?[`iP000000n_3V0080n_3V0P00000b0?[`iP030000003jl>H0
n_3V0740n_3V0@3oool00740n_3V00@000000?[`iP3jl>H00000=@3jl>H00`000000n_3V0?[`iP1b
0?[`iP40oooo001a0?[`iP8000000P3jl>H00`000000n_3V0?[`iP0a0?[`iP030000003jl>H0n_3V
07<0n_3V0@3oool00780n_3V00D000000?[`iP3jl>H0n_3V0000000a0?[`iP030000003jl>H0n_3V
07@0n_3V0@3oool00780n_3V0P0000030?[`iP030000003jl>H0n_3V02d0n_3V00<000000?[`iP3j
l>H0M@3jl>H10?ooo`00L`3jl>H00`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V02/0n_3V
00<000000?[`iP3jl>H0MP3jl>H10?ooo`00N@3jl>H00`000000n_3V0?[`iP0Y0?[`iP030000003j
l>H0n_3V07L0n_3V0@3oool007X0n_3V00<000000?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP1h
0?[`iP40oooo001k0?[`iP030000003jl>H0n_3V02D0n_3V00<000000?[`iP3jl>H0N@3jl>H10?oo
o`00O03jl>H00`000000n_3V0?[`iP0S0?[`iP030000003jl>H0n_3V07X0n_3V0@3oool007d0n_3V
00<000000?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP1k0?[`iP40oooo001n0?[`iP030000003j
l>H0n_3V01l0n_3V00<000000?[`iP3jl>H0O03jl>H10?ooo`00O`3jl>H00`000000n_3V0?[`iP0M
0?[`iP030000003jl>H0n_3V07d0n_3V0@3oool00800n_3V00<000000?[`iP3jl>H06`3jl>H00`00
0000n_3V0?[`iP1n0?[`iP40oooo00210?[`iP030000003jl>H0n_3V01T0n_3V00<000000?[`iP3j
l>H0O`3jl>H10?ooo`00PP3jl>H00`000000n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V0800n_3V
0@3oool008<0n_3V00<000000?[`iP3jl>H05@3jl>H00`000000n_3V0?[`iP210?[`iP40oooo0024
0?[`iP030000003jl>H0n_3V01<0n_3V00<000000?[`iP3jl>H0PP3jl>H10?ooo`00Q@3jl>H00`00
0000n_3V0?[`iP0A0?[`iP030000003jl>H0n_3V08<0n_3V0@3oool008H0n_3V00<000000?[`iP3j
l>H03`3jl>H00`000000n_3V0?[`iP240?[`iP40oooo00270?[`iP030000003jl>H0n_3V00d0n_3V
00<000000?[`iP3jl>H0Q@3jl>H10?ooo`00R03jl>H00`000000n_3V0?[`iP0;0?[`iP030000003j
l>H0n_3V08H0n_3V0@3oool008T0n_3V00<000000?[`iP3jl>H02@3jl>H00`000000n_3V0?[`iP27
0?[`iP40oooo002:0?[`iP030000003jl>H0n_3V00L0n_3V00<000000?[`iP3jl>H0R03jl>H10?oo
o`00R`3jl>H00`000000n_3V0?[`iP050?[`iP030000003jl>H0n_3V08T0n_3V0@3oool008`0n_3V
00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP2:0?[`iP40oooo002=0?[`iP030000003j
l>H0000000800000S@3jl>H10?ooo`00SP3jl>H4000008d0n_3V0@3oool008h0n_3V1000002=0?[`
iP40oooo002?0?[`iP800000SP3jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3o
ool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V
803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?oo
o`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP
0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo
003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00
n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool0
0?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803j
l>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00
o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`
iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o
0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V
0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0
n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H1
0?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3j
l>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40
oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`
iR00n_3V0@3oool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3o
ool00?l0n_3V803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V
803jl>H10?ooo`00o`3jl>HP0?[`iP40oooo003o0?[`iR00n_3V0@3oool00?l0n_3V803jl>H10?oo
o`00o`3jl>HP0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {215, 0}} -> {-2.00235, -1.00002, 0.0139536, \
0.0139536}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->{},
WindowSize->{494, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 64, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1843, 56, 645, 24, 67, "Usage",
      CellTags->"Function?"],
    Cell[2491, 82, 95, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 15358, 399}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 64, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1843, 56, 645, 24, 67, "Usage",
  CellTags->"Function?"],
Cell[2491, 82, 95, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2589, 87, 174, 6, 41, "MathCaption"],
Cell[2766, 95, 176, 5, 58, "MathCaption"],
Cell[2945, 102, 450, 18, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[3420, 124, 33, 0, 39, "ExampleSection"],
Cell[3456, 126, 97, 2, 29, "Input"],
Cell[3556, 130, 75, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[3656, 134, 599, 10, 189, "Input"],
Cell[4258, 146, 10409, 231, 222, 1693, 118, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

