(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5415,        164]*)
(*NotebookOutlinePosition[      6311,        196]*)
(*  CellTagsIndexPosition[      6237,        190]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["SplitLineOnDistance", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["SplitLineOnDistance",
          "MR"], 
        StyleBox["[",
          "MR"], "distance", "]"}]]],
  " is a rule which will split any Line primitives into multiple lines \
whenever two points are farther apart than the distance specified."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "The distance is calculated by applying ",
  Cell[BoxData[
      \(\((\@\(\((#2 - #1)\) . \((#2 - #1)\)\) &)\)\)]],
  " to adjacent points."
}], "MathCaption"],

Cell[TextData[{
  "The usage is ",
  Cell[BoxData[
      \(graphics /. SplitLineOnDistance[distance]\)]]
}], "MathCaption"],

Cell["\<\
The purpose is to eliminate \"return lines\". SplitLineOnDistance will work \
on parametric plots where the jumps are not vertical.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["SplitLineOnVertical",
    ButtonData:>{"SplitLineOnVertical"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SplitLineOnSlope",
    ButtonData:>{"SplitLineOnSlope"},
    ButtonStyle->"AddOnsLink"],
  " ."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
The following is a parametrization of the folium of Descartes.\
\>", "Text"],

Cell[BoxData[
    \(folium[t_] := {3  t, 3  t\^2}/\((1 + t\^3)\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Blue, 
          ParametricDraw[Evaluate[folium[t]], {t, \(-100\), 100}, 
            PlotPoints \[Rule] 100]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 2}, {\(-3\), 
              2}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Folium of \
Descartes\>", \[IndentingNewLine]Background \[Rule] Linen];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[TextData[{
  "The 45\[Degree] straight line is not part of the curve and is caused by \
plotting over the discontinuity at ",
  Cell[BoxData[
      \(t \[Equal] \(-1\)\)]],
  ". We can eliminate it with SplitLineOnDistance."
}], "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Blue, 
          ParametricDraw[Evaluate[folium[t]], {t, \(-100\), 100}, 
              PlotPoints \[Rule] 100] /. 
            SplitLineOnDistance[5]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 2}, {\(-3\), 
              2}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Folium of \
Descartes\>", \[IndentingNewLine]Background \[Rule] Linen];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["We could also have drawn the curve in two pieces.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Blue, 
          ParametricDraw[Evaluate[folium[t]], {t, \(-100\), \(-1\)}, 
            PlotPoints \[Rule] 100], \[IndentingNewLine]Red, 
          ParametricDraw[Evaluate[folium[t]], {t, \(-1\), 100}, 
            PlotPoints \[Rule] 100]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 2}, {\(-3\), 
              2}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Folium of \
Descartes\>", \[IndentingNewLine]Background \[Rule] Linen];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(Clear[folium]\)], "Input",
  CellLabel->"In[6]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{538, 730},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 66, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1845, 56, 370, 11, 50, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6066, 181}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 66, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1845, 56, 370, 11, 50, "Usage",
  CellTags->"Function?"],
Cell[2218, 69, 177, 5, 42, "MathCaption"],
Cell[2398, 76, 123, 4, 41, "MathCaption"],
Cell[2524, 82, 162, 3, 58, "MathCaption"],
Cell[2689, 87, 275, 10, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[2989, 101, 34, 0, 39, "ExampleSection"],
Cell[3026, 103, 97, 2, 29, "Input"],
Cell[3126, 107, 86, 2, 25, "Text"],
Cell[3215, 111, 101, 2, 30, "Input"],
Cell[3319, 115, 502, 8, 169, "Input"],
Cell[3824, 125, 241, 6, 42, "Text"],
Cell[4068, 133, 543, 9, 169, "Input"],
Cell[4614, 144, 65, 0, 25, "Text"],
Cell[4682, 146, 632, 10, 209, "Input"],
Cell[5317, 158, 70, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

