(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5071,        162]*)
(*NotebookOutlinePosition[      5967,        194]*)
(*  CellTagsIndexPosition[      5893,        188]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["StitchLineSegments", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["StitchLineSegments",
          "MR"], 
        StyleBox["[",
          "MR"], "segs", "]"}]]],
  " will stitch together a list of Line segments into one Line."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
One must be careful with the order of the Lines and the order of the points \
within each Line. \
\>", "MathCaption"],

Cell["The segs list is Flattened as the first step.", "MathCaption"],

Cell["\<\
One application is to combine Lines produced by various Plot routines into \
one Line and perhaps convert it to a Polygon.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Here are two parabolas with their axes in the y and -y directions.  Suppose \
we wish to color the area between them.\
\>", "Text"],

Cell[BoxData[{
    \(\(par1[t_] := {\(-3\) + t\^2, t};\)\), "\[IndentingNewLine]", 
    \(par2[t_] := {3 - t\^2, t}\)}], "Input",
  CellLabel->"In[2]:="],

Cell["This finds their points of intersection.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[par1[t] \[Equal] par2[t]]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({{t \[Rule] \(-\@3\)}, {t \[Rule] \@3}}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["This plots the two curves to show the area we wish to color.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{ParametricDraw[
            Evaluate[{par1[t], 
                par2[t]}], {t, \(-\@3\), \@3}]}, \
\[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Background \[Rule] 
          Linen\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell["\<\
We want to define a curve by stitching the two arc segments together. Then \
all we have to do is convert the Line to a Polygon. The only thing we have to \
be careful about is stitching them end to end in the correct order. Since the \
plotting iterators always run from the minimum value to the maximum value (no \
matter in what order we put them), we will often have to reverse the order of \
the points in some of the line segments.\
\>", "Text"],

Cell["\<\
Here we assemble our curve by drawing the two line segments separately and \
stitching them together.\
\>", "Text"],

Cell[BoxData[
    \(\(curve = 
        StitchLineSegments[{ParametricDraw[
              par1[t] // Evaluate, {t, \(-\@3\), \@3}], 
            ParametricDraw[par2[t] // Evaluate, {t, \(-\@3\), \@3}] /. 
              Line[a_] \[RuleDelayed] Line[Reverse[a]]}];\)\)], "Input",
  CellLabel->"In[6]:="],

Cell["\<\
Now it is a simple matter to draw the colored area and outline it in Black.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{LightBlue, 
          curve /. Line \[Rule] Polygon, \[IndentingNewLine]Black, 
          curve}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Background \[Rule] 
          Linen\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(Clear[par1, par2, curve]\)], "Input",
  CellLabel->"In[8]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{538, 730},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 65, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1844, 56, 289, 10, 33, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5722, 179}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 65, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1844, 56, 289, 10, 33, "Usage",
  CellTags->"Function?"],
Cell[2136, 68, 127, 3, 58, "MathCaption"],
Cell[2266, 73, 68, 0, 41, "MathCaption"],
Cell[2337, 75, 153, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[2515, 82, 33, 0, 39, "ExampleSection"],
Cell[2551, 84, 97, 2, 29, "Input"],
Cell[2651, 88, 141, 3, 42, "Text"],
Cell[2795, 93, 153, 3, 51, "Input"],
Cell[2951, 98, 56, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[3032, 102, 88, 2, 29, "Input"],
Cell[3123, 106, 97, 2, 26, "Output"]
}, Open  ]],
Cell[3235, 111, 76, 0, 25, "Text"],
Cell[3314, 113, 323, 7, 135, "Input"],
Cell[3640, 122, 461, 7, 93, "Text"],
Cell[4104, 131, 125, 3, 25, "Text"],
Cell[4232, 136, 300, 6, 97, "Input"],
Cell[4535, 144, 99, 2, 25, "Text"],
Cell[4637, 148, 322, 6, 129, "Input"],
Cell[4962, 156, 81, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

