(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7269,        205]*)
(*NotebookOutlinePosition[      8239,        240]*)
(*  CellTagsIndexPosition[      8165,        234]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Text3D", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["Text3D",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(string, \ {x, y, z}, \ {hscale, \ 
            vscale}, \ {\[Phi], \ \[Theta], \ \[Psi]}, \ opts\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " draws the string as 3D vector characters at the position {x, y, z} with \
the specified horizontal and vertical scales and with the given orientation."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "When the regular ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Text statement is used in 3D Graphics, it merely projects the 2D text \
onto the viewing plane. There is no perspective for the text, not is the text \
ever hidden behind surfaces. Text3D provides true 3D text that will rotate, \
have perspective and hide behind surfaces. However, it is intrinsically more \
complicated than regular Text in that the user must supply not only the point \
of application but also the orientation of the text."
}], "MathCaption"],

Cell["\<\
The text starts in the xy-plane aligned along the x-axis.
1) It is rotated counterclockwise in the xy-plane (about the z-axis)  by the \
angle \[Psi].
2) It is then rotated about the y-axis by the angle \[Phi].
3) It is rotated again about the z-axis by the angle \[Theta].\
\>", "MathCaption"],

Cell["\<\
The angles \[Phi] and \[Theta] determine the direction of the normal vector \
to the plane of the text. The angle \[Psi] rotates the text in the text \
plane.\
\>", "MathCaption"],

Cell["\<\
Setting hscale and vscale to 1 will produce a capital M that is approximately \
1 unit on a side. The scale of the text can also be affected by BoxRatios and \
by other transformations that are performed on the text.\
\>", "MathCaption"],

Cell["\<\
The option Font3D specifies the font to be used. There are two fonts, a sans \
serif FuturaFont3D and TimesFont3D. Both fonts contain the standard English \
keyboard characters and the upper and lower case Greek letters.\
\>", "MathCaption"],

Cell["\<\
The option Align3D specifies the alignment of the text with respect to the \
plot point {x,y,z}. The choices are Left, Center and Right.\
\>", "MathCaption"],

Cell["\<\
 FineGrainLines and DrawingTransform3D can be used to bend and warp the text \
to better fit on curved surfaces.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Text",
    ButtonData:>{"Text"},
    ButtonStyle->"RefGuideLink"],
  ",  ",
  ButtonBox["DrawingTransform3D",
    ButtonData:>{"DrawingTransform3D"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["FineGrainLines",
    ButtonData:>{"FineGrainLines"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example ", "ExampleSection"],

Cell[TextData[{
  "See also ",
  ButtonBox["Using Text3D",
    ButtonData:>{"Using Text3D"},
    ButtonStyle->"AddOnsLink"],
  " in the Examples Section."
}], "Text"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
The following routine produces one frame for an animation that draws two text \
strings along diagonal lines on a hyperbolic paraboloid surface. The text \
strings are first produced along 45\[Degree] lines in the xy-plane. They are \
then mapped slightly above the surface using DrawingTransform3D.\
\>", "Text"],

Cell[BoxData[
    \(\(frame[
          d_] := \[IndentingNewLine]Module[{string1, 
            string2}, \[IndentingNewLine]string1 = 
            Text3D["\<Escher\>", {d, d, 0}, {0.1, 0.1}, {0, 0, 
                45  \[Degree]}, Font3D \[Rule] TimesFont3D, 
              Align3D \[Rule] Left]; \[IndentingNewLine]string1 = 
            string1 /. 
              DrawingTransform3D[#1 &, #2 &, #1\^2 - #2\^2 + 
                    0.005 &]; \[IndentingNewLine]string2 = 
            Text3D["\<Penrose\>", {d, \(-d\), 0}, {0.1, 0.1}, {0, 
                0, \(-45\) \[Degree]}, Font3D \[Rule] TimesFont3D, 
              Align3D \[Rule] Left]; \[IndentingNewLine]string2 = 
            string2 /. 
              DrawingTransform3D[#1 &, #2 &, #1\^2 - #2\^2 + 
                    0.005 &]; \[IndentingNewLine]Draw3DItems[\
\[IndentingNewLine]{SurfaceColor[\(ColorMix[Tomato, White]\)[0.3]], 
              EdgeForm[\(ColorMix[Tomato, Black]\)[
                  0.2]], \[IndentingNewLine]ParametricDraw3D[{x, y, 
                  x\^2 - y\^2}, {x, \(-1\), 1}, {y, \(-1\), 
                  1}], \[IndentingNewLine]string1, 
              string2}, \[IndentingNewLine]NeutralLighting[0.3, 0.5, 0.1, 
              40  \[Degree]], \[IndentingNewLine]ViewPoint -> {\(-1.099\), \ \
\(-1.995\), \ 2.502}, \[IndentingNewLine]Background \[Rule] \(ColorMix[
                  Peacock, White]\)[0.5], \[IndentingNewLine]Boxed \[Rule] 
              False, \[IndentingNewLine]ImageSize \[Rule] 500]];\)\)], "Input",\

  CellLabel->"In[2]:="],

Cell["The following produces the animation.", "Text"],

Cell[BoxData[{
    \(Animate[frame[d], {d, \(-0.95\), 0.45, 0.05}]\), "\n", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
Notice that the scale of the letters is distorted by the mapping.\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{601, 720},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 53, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1832, 56, 532, 16, 50, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7994, 225}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 53, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1832, 56, 532, 16, 50, "Usage",
  CellTags->"Function?"],
Cell[2367, 74, 556, 10, 109, "MathCaption"],
Cell[2926, 86, 304, 6, 116, "MathCaption"],
Cell[3233, 94, 189, 4, 58, "MathCaption"],
Cell[3425, 100, 247, 4, 75, "MathCaption"],
Cell[3675, 106, 251, 4, 75, "MathCaption"],
Cell[3929, 112, 167, 3, 58, "MathCaption"],
Cell[4099, 117, 143, 3, 58, "MathCaption"],
Cell[4245, 122, 358, 14, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[4628, 140, 34, 0, 39, "ExampleSection"],
Cell[4665, 142, 166, 6, 25, "Text"],
Cell[4834, 150, 97, 2, 29, "Input"],
Cell[4934, 154, 323, 5, 59, "Text"],
Cell[5260, 161, 1534, 27, 377, "Input"],
Cell[6797, 190, 53, 0, 25, "Text"],
Cell[6853, 192, 296, 5, 89, "Input"],
Cell[7152, 199, 89, 2, 25, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

