(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7081,        207]*)
(*NotebookOutlinePosition[      8011,        240]*)
(*  CellTagsIndexPosition[      7937,        234]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ToPointPrimitives", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["ToPointPrimitives",
          "MR"], "[", "graphics", "]"}]]],
  " will convert Circle, Disk, Rectangle, Raster and RasterArray primitives \
to forms using Lines, Polygons and color directives."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
The purpose of ToPointPrimitives is to put the graphics opjects into a form \
that can be subjected to nonlinear transformations with DrawingTransform, or \
converted to 3D objects.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DrawingTransform",
    ButtonData:>{"DrawingTransform"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
The following development shows how to convert a rectangular RasterArray into \
a three-dimensional curved object. We start by creating a RasterArray in the \
\[Theta]r-plane.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{g1 = 
            RasterArray[
              Table[\(ColorMix[Yellow, DeepSkyBlue]\)[\((i - 1)\)/9], {i, 
                  10}, {j, 40}], {{0, 1}, {2  \[Pi], 
                  2}}]}, \[IndentingNewLine]AspectRatio \[Rule] 
          1/GoldenRatio, \[IndentingNewLine]Frame \[Rule] True];\)\)], "Input",\

  CellLabel->"In[2]:="],

Cell["\<\
We now convert the RasterArray to a collection of Polygons with color \
directives. At the same time we transform from polar coordinates to \
rectangular coordinates.\
\>", "Text"],

Cell[BoxData[
    \(\(g2 = \((g1 // ToPointPrimitives)\) /. 
          DrawingTransform[#2\ Cos[#1] &, #2\ Sin[#1] &];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell["This is the first polygon.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g2\[LeftDoubleBracket]1, 1\[RightDoubleBracket]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({RGBColor[1.`, 1.`, 0.`], 
      Polygon[{{1, 0}, {Cos[\[Pi]\/20], 
            Sin[\[Pi]\/20]}, {11\/10\ Cos[\[Pi]\/20], 
            11\/10\ Sin[\[Pi]\/20]}, {11\/10, 0}}]}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{g2}, \[IndentingNewLine]AspectRatio \
\[Rule] Automatic, \[IndentingNewLine]Frame \[Rule] True];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell["\<\
We now use a stereographic mapping X to map the xy-plane onto the unit \
sphere.\
\>", "Text"],

Cell[BoxData[{
    \(X[u_, v_] := 
      With[{t = 
            u\^2 + v\^2}, {\(2  u\)\/\(1 + t\), \(2  v\)\/\(1 + t\), \(t - \
1\)\/\(t + 1\)}]\), "\n", 
    \(\(g3 = 
        N[g2] /. {x_?NumberQ, y_?NumberQ} \[RuleDelayed] 
            X[x, y];\)\)}], "Input",
  CellLabel->"In[6]:="],

Cell["\<\
We now convert the polygon colors to FaceForms with the same color. We color \
the inside surface Gray. NeutralLighting is used so the colors will show to \
best advantage. Notice that 3D Polygons have edges; 2D Polygons don't.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{g3 /. 
            c : RGBColor[__] \[RuleDelayed] 
              FaceForm[SurfaceColor[c], 
                SurfaceColor[Gray]]}, \[IndentingNewLine]NeutralLighting[0.1, 
          0.5, 0]];\)\)], "Input",
  CellLabel->"In[8]:="],

Cell["\<\
Although the following example doesn't actually require ToPointPrimitives, it \
eliminates the rendering errors in Raster and RasterArray. See the same \
example in DrawingTransform.\
\>", "Text"],

Cell[BoxData[
    \(\(Module[{g}, \
\[IndentingNewLine]Draw2D[\[IndentingNewLine]{AbsolutePointSize[4], 
            LightCoral, \[IndentingNewLine]\[IndentingNewLine]g = {Polygon[{{\
\(-1\), \(-1\)}, {1, \(-1\)}, {1, 1}, {\(-1\), 
                      1}}], \[IndentingNewLine]Raster[
                  Table[i\ j, {i, 0, 10}, {j, 0, 10}], {{1, \(-1\)}, {3, 
                      1}}, {0, 100}], \[IndentingNewLine]RasterArray[
                  Table[\(ColorMix[
                        TurquoiseBlue, \(ColorMix[Magenta, AureolineYellow]\)[
                          j/10]]\)[i/10], {i, 0, 10}, {j, 0, 
                      10}], {{3, \(-1\)}, {5, 
                      1}}], \[IndentingNewLine]Rectangle[{3/2, \(-1\)/2}, {5/
                      2, 1/2}], \[IndentingNewLine]Black, \
\[IndentingNewLine]Line[{{\(-1\), 
                      1}, {1, \(-1\)}}], \[IndentingNewLine]Text["\<X\>", \
{0.5, 0.5}, {\(-1\), \(-1\)}], \[IndentingNewLine]LightSeaGreen, 
                Disk[{0, 0}, 1/2], \[IndentingNewLine]Black, 
                Circle[{0, 0}, 1/2], 
                Point[{0, 0}]\[IndentingNewLine]}; \[IndentingNewLine]g // 
              ToPointPrimitives, \
\[IndentingNewLine]\[IndentingNewLine]Peacock, \[IndentingNewLine]\((g // 
                  ToPointPrimitives)\) /. 
              DrawingTransform[#1 + 2 &, #2 + 
                    2 &]}, \[IndentingNewLine]\[IndentingNewLine]AspectRatio \
\[Rule] Automatic, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]ImageSize \[Rule] 500]];\)\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(Clear[g1, g2, g3]\)], "Input",
  CellLabel->"In[10]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{601, 709},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 64, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1843, 56, 324, 9, 50, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7767, 225}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 64, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1843, 56, 324, 9, 50, "Usage",
  CellTags->"Function?"],
Cell[2170, 67, 212, 4, 58, "MathCaption"],
Cell[2385, 73, 158, 6, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[2568, 83, 33, 0, 39, "ExampleSection"],
Cell[2604, 85, 97, 2, 29, "Input"],
Cell[2704, 89, 199, 4, 42, "Text"],
Cell[2906, 95, 379, 8, 109, "Input"],
Cell[3288, 105, 190, 4, 42, "Text"],
Cell[3481, 111, 157, 3, 49, "Input"],
Cell[3641, 116, 42, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[3708, 120, 104, 2, 29, "Input"],
Cell[3815, 124, 232, 5, 61, "Output"]
}, Open  ]],
Cell[4062, 132, 184, 3, 89, "Input"],
Cell[4249, 137, 104, 3, 25, "Text"],
Cell[4356, 142, 288, 8, 62, "Input"],
Cell[4647, 152, 251, 4, 42, "Text"],
Cell[4901, 158, 284, 6, 69, "Input"],
Cell[5188, 166, 206, 4, 42, "Text"],
Cell[5397, 172, 1578, 27, 489, "Input"],
Cell[6978, 201, 75, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

