(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11544,        331]*)
(*NotebookOutlinePosition[     12476,        364]*)
(*  CellTagsIndexPosition[     12401,        358]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["TrimPolygons", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["TrimPolygons",
            "MR"], 
          StyleBox["[",
            "MR"], \(f, {fmin, fmax}\), "]"}], "[", "polygrid", "]"}]]],
  " extracts a list of polygons from an array of rectangular polygons so that \
f applied to the polygon points is between fmin and fmax. Rectangles entirely \
outside the range are eliminated and rectangles entirely within the range are \
left untouched. Rectangles partly in and out are trimed."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "TrimPolygons works on arrays of rectangular polygons, which will usually \
be created by ",
  ButtonBox["MakePolyGrid",
    ButtonData:>{"MakePolyGrid"},
    ButtonStyle->"AddOnsLink"],
  ". Its principal purpose to to create 2D polygonal arrays that can then be \
smoothly warped into 3D space."
}], "MathCaption"],

Cell["\<\
For efficient operation use N on the grid of polygons to convert to \
approximate numbers.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["HollisGrid",
    ButtonData:>{"HollisGrid"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DrawingTransform",
    ButtonData:>{"DrawingTransform"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MakePolyGrid",
    ButtonData:>{"MakePolyGrid"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PolygonOutline",
    ButtonData:>{"PolygonOutline"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RaiseTo3D",
    ButtonData:>{"RaiseTo3D"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example 1", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Here is a sample function.", "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\[IndentingNewLine]", 
    \(f[x_, y_] := Exp[\(-\((x\^2 + 2  y\^2)\)\)]\)}], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
This is a 3D picture of the surface. We want to differentiate the part of the \
surface which lies above an off center circle in the xy-plane.\
\>", "Text"],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{Draw3D[
            f[x, y], {x, \(-1\), 1}, {y, \(-1\), 1}, 
            PlotPoints \[Rule] 25]}, \[IndentingNewLine]BoxRatios \[Rule] {1, 
            1, 0.5}, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
The following creates a 25\[Times]25 array of square polygons which cover the \
xy projection of the surface.\
\>", "Text"],

Cell[BoxData[
    \(\(polygrid = 
        MakePolyGrid[{25, 25}, {{\(-1\), \(-1\)}, {1, 1}}] // N;\)\)], "Input",\

  CellLabel->"In[5]:="],

Cell["\<\
The following extracts and trims the polygons from polygrid according to \
whether they lie inside or outside the circle (or cylinder) centered at x = \
0.25, y = -0.25 and with radius 1/2. \
\>", "Text"],

Cell[BoxData[{
    \(\(polys1 = 
        polygrid // 
          TrimPolygons[\((#1 - 0.25)\)\^2 + \((#2 + 0.25)\)\^2 &, {\(-10\), 
              1/4}];\)\), "\[IndentingNewLine]", 
    \(\(polys2 = 
        polygrid // 
          TrimPolygons[\((#1 - 0.25)\)\^2 + \((#2 + 0.25)\)\^2 &, {1/4, 
              10}];\)\)}], "Input",
  CellLabel->"In[6]:="],

Cell["This is a 2D plot of the resulting polygons.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{LightSteelBlue, 
          polys1, \[IndentingNewLine]polys1 // 
            PolygonOutline[Black], \[IndentingNewLine]Wheat, 
          polys2, \[IndentingNewLine]polys2 // 
            PolygonOutline[Black]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
              1}}, \[IndentingNewLine]ImageSize \[Rule] 300];\)\)], "Input",
  CellLabel->"In[8]:="],

Cell[TextData[{
  "Here we raise the polygons to a 3D surface using ",
  Cell[BoxData[
      \(f[x, y]\)]],
  " for the z coordinate. We give the two regions different surface colors as \
above. The NeutralLighting \"option\" allows the pastel colors to display \
well with shading without being overwhelmed by the default light colors. \
(Notice that in 2D the Polygon outlines are not automatically drawn, which is \
why the PolygonOutline routine was used. In 3D the edges of Polygons are \
drawn and must be suppressed with ",
  Cell[BoxData[
      \(EdgeForm[]\)]],
  " if you don't want them.)"
}], "Text"],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{SurfaceColor[
              LightSteelBlue], \[IndentingNewLine]polys1, \
\[IndentingNewLine]SurfaceColor[Wheat], \[IndentingNewLine]polys2} // 
          RaiseTo3D[f], \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            0.5}, \[IndentingNewLine]Axes \[Rule] 
          False, \[IndentingNewLine]NeutralLighting[0.3, 0.5, 
          0], \[IndentingNewLine]ImageSize \[Rule] 400];\)\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(Clear[f, polygrid, polys1, polys2]\)], "Input",
  CellLabel->"In[10]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2 - Contour Plot on a 3D Surface", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[11]:="],

Cell["Here is a sample function.", "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\[IndentingNewLine]", 
    \(f[x_, y_] := Sin[x] Sin[y] - x\)}], "Input",
  CellLabel->"In[12]:="],

Cell["The regular 3D plot...", "Text"],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{Draw3D[
            f[x, y], {x, \(-\[Pi]\)/2, \[Pi]/2}, {y, \(-\[Pi]\)/2, \[Pi]/2}, 
            PlotPoints \[Rule] 21]}, \[IndentingNewLine]BoxRatios \[Rule] {1, 
            1, 0.5}, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)], "Input",
  CellLabel->"In[14]:="],

Cell["...and a contour plot.", "Text"],

Cell[BoxData[{
    \(\(contours = Range[\(-2\), 2, 0.5];\)\), "\[IndentingNewLine]", 
    \(\(Draw2D[\[IndentingNewLine]{g = 
            ContourDraw[
              f[x, y], {x, \(-\[Pi]\)/2, \[Pi]/2}, {y, \(-\[Pi]\)/2, \[Pi]/
                  2}, ColorFunction \[Rule] Hue, 
              Contours \[Rule] 
                contours]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] True];\)\)}], "Input",
  CellLabel->"In[15]:="],

Cell["\<\
Our objective is to put the contour plot onto the 3D surface. First, create a \
polygrid covering the xy projection of the surface.\
\>", "Text"],

Cell[BoxData[
    \(\(polygrid = 
        MakePolyGrid[{20, 
              20}, {{\(-\[Pi]\)/2, \(-\[Pi]\)/2}, {\[Pi]/2, \[Pi]/2}}] // 
          N;\)\)], "Input",
  CellLabel->"In[17]:="],

Cell["Next, cut and trim the polygons for each contour region.", "Text"],

Cell[BoxData[{
    \(Clear[polys]\), "\n", 
    \(Do[polys[i] = 
        polygrid // 
          TrimPolygons[
            f, {contours\[LeftDoubleBracket]i\[RightDoubleBracket], 
              contours\[LeftDoubleBracket]i + 1\[RightDoubleBracket]}], {i, 
        1, Length[contours] - 1}]\)}], "Input",
  CellLabel->"In[18]:="],

Cell["This shows the resulting polygonal regions.", "Text"],

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{Table[{Hue[i/Length[contours]], 
              polys[i], \[IndentingNewLine]polys[i] // 
                PolygonOutline[Black]}, {i, 1, 
              Length[contours] - 1}]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotRange \[Rule] {{\(-\[Pi]\)/2, \[Pi]/
                2}, {\(-\[Pi]\)/2, \[Pi]/
                2}}, \[IndentingNewLine]ImageSize \[Rule] 300];\)\)], "Input",\

  CellLabel->"In[20]:="],

Cell["Now, the polygon arrays are raised to the 3D surface.", "Text"],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{Table[\[IndentingNewLine]{\
SurfaceColor[Hue[i/Length[contours]]], polys[i] // RaiseTo3D[f]}, {i, 1, 
              Length[contours] - 
                1}]}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            0.5}, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]NeutralLighting[0.3, 0.5, 
          0], \[IndentingNewLine]ImageSize \[Rule] 400];\)\)], "Input",
  CellLabel->"In[21]:="],

Cell[TextData[{
  "The edges of the trimmed polygons automatically give the contour lines. If \
we don't want to see the \"mesh\" we can use ",
  Cell[BoxData[
      \(EdgeForm[]\)]],
  ". However, this also eliminates the contour lines. We get them back by \
extracting the contour lines from the 2D contour plot done above. The \
primitives were saved in the variable g. We raise the lines to 3D and put \
them slightly above the surface to eliminate intersection effects."
}], "Text"],

Cell[BoxData[{
    \(\(clines = Cases[g, Line[_], \[Infinity]];\)\), "\n", 
    \(\(plot1 = \
\[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{Table[{EdgeForm[], 
                SurfaceColor[Hue[i/Length[contours]]], 
                polys[i] // RaiseTo3D[f]}, {i, 1, 
                Length[contours] - 1}], \[IndentingNewLine]clines // 
              RaiseTo3D[
                f[#1, #2] + 
                    0.025 &]}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
              0.5}, \[IndentingNewLine]Axes \[Rule] 
            True, \[IndentingNewLine]NeutralLighting[0.3, 0.5, 
            0], \[IndentingNewLine]ImageSize \[Rule] 400];\)\)}], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \(Clear[f, contours, g, polygrid, polys]\)], "Input",
  CellLabel->"In[24]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{544, 730},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 59, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1838, 56, 578, 14, 84, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 12230, 349}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 59, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1838, 56, 578, 14, 84, "Usage",
  CellTags->"Function?"],
Cell[2419, 72, 334, 8, 75, "MathCaption"],
Cell[2756, 82, 121, 3, 41, "MathCaption"],
Cell[2880, 87, 560, 22, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3465, 113, 35, 0, 39, "ExampleSection"],
Cell[3503, 115, 97, 2, 29, "Input"],
Cell[3603, 119, 42, 0, 25, "Text"],
Cell[3648, 121, 149, 3, 50, "Input"],
Cell[3800, 126, 166, 3, 42, "Text"],
Cell[3969, 131, 399, 7, 129, "Input"],
Cell[4371, 140, 133, 3, 25, "Text"],
Cell[4507, 145, 139, 4, 29, "Input"],
Cell[4649, 151, 214, 4, 42, "Text"],
Cell[4866, 157, 352, 9, 92, "Input"],
Cell[5221, 168, 60, 0, 25, "Text"],
Cell[5284, 170, 532, 9, 189, "Input"],
Cell[5819, 181, 612, 13, 110, "Text"],
Cell[6434, 196, 477, 8, 189, "Input"],
Cell[6914, 206, 92, 2, 29, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7043, 213, 66, 0, 33, "ExampleSection"],
Cell[7112, 215, 98, 2, 29, "Input"],
Cell[7213, 219, 42, 0, 25, "Text"],
Cell[7258, 221, 137, 3, 49, "Input"],
Cell[7398, 226, 38, 0, 25, "Text"],
Cell[7439, 228, 371, 6, 129, "Input"],
Cell[7813, 236, 38, 0, 25, "Text"],
Cell[7854, 238, 478, 9, 129, "Input"],
Cell[8335, 249, 155, 3, 42, "Text"],
Cell[8493, 254, 188, 5, 49, "Input"],
Cell[8684, 261, 72, 0, 25, "Text"],
Cell[8759, 263, 328, 8, 89, "Input"],
Cell[9090, 273, 59, 0, 25, "Text"],
Cell[9152, 275, 543, 10, 169, "Input"],
Cell[9698, 287, 69, 0, 25, "Text"],
Cell[9770, 289, 466, 8, 169, "Input"],
Cell[10239, 299, 487, 9, 93, "Text"],
Cell[10729, 310, 688, 13, 209, "Input"],
Cell[11420, 325, 96, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

