(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    295703,      15313]*)
(*NotebookOutlinePosition[    296678,      15347]*)
(*  CellTagsIndexPosition[    296600,      15341]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["UseRotateShape", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["UseRotateShape",
            "MR"], 
          StyleBox["[",
            "MR"], 
          StyleBox[\(\[Phi], \[Theta], \[Psi]\),
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["g",
          "MR"], 
        StyleBox["]",
          "MR"]}]]],
  " will multiply all coordinates of the primitive graphics object g by the \
specified scale factors."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
The object is first rotated about the z axis by \[Psi], then about the new x \
axis by \[Theta], then about the new z axis by \[Phi].\
\>", "MathCaption"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
UseRotateShape implements the RotateShape function directly on primitive \
graphics.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["UseAffineShape",
    ButtonData:>{"UseAffineShape"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["UseTranslateShape",
    ButtonData:>{"UseTranslateShape"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["UseWireFrame",
    ButtonData:>{"UseWireFrame"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DrawingTransform3D",
    ButtonData:>{"DrawingTransform3D"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["RotateShape",
    ButtonData:>{"Graphics`Shapes`", "1.12"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[328]:="],

Cell["\<\
Here, a sphere centered at the origin is stretched in the x and y directions \
and squeezed in the z direction (Cobalt), then rotated about the z axis by 90\
\[Degree](Black). The transformations are rendered as wireframes.\
\>", "Text"],

Cell[BoxData[
    \(\(gsphere = 
        SphericalDraw3D[1, {\[Theta], 0, \[Pi]}, {\[Phi], 0, 2  \[Pi]}, 
          PlotPoints \[Rule] {21, 31}];\)\)], "Input",
  CellLabel->"In[329]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{{EdgeForm[Blue], 
            SurfaceColor[SteelBlue, SteelBlue, 3], 
            gsphere}, \[IndentingNewLine]Cobalt, \[IndentingNewLine]gsphere2 \
= \(gsphere // UseAffineShape[{3, 1, 1/2}]\) // 
              UseWireFrame, \[IndentingNewLine]Black, 
          gsphere2 // 
            UseRotateShape[0, 0, 
              90  \[Degree]]}, \[IndentingNewLine]NeutralLighting[0.3, 0.6, 
          0], \[IndentingNewLine]Background \[Rule] 
          YellowBrown, \[IndentingNewLine]BoxStyle \[Rule] 
          Black, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)], "Input",
  CellLabel->"In[330]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .7782 
%%ImageSize: 400 311.28 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.86 .58 .44 r
MFill
% Scaling calculations
5.01986e-017 1.04948 -0.0840974 1.04948 [
[ 0 0 0 0 ]
[ 1 .7782 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.03114 .256 m
0 .45252 L
s
0 .45252 m
.39761 .7782 L
s
.39761 .7782 m
.40383 .60035 L
s
.40383 .60035 m
.03114 .256 L
s
.69069 0 m
.97431 .43047 L
s
.97431 .43047 m
1 .61842 L
s
1 .61842 m
.70263 .20566 L
s
.70263 .20566 m
.69069 0 L
s
.03114 .256 m
0 .45252 L
s
0 .45252 m
.70263 .20566 L
s
.70263 .20566 m
.69069 0 L
s
.69069 0 m
.03114 .256 L
s
.40383 .60035 m
.97431 .43047 L
s
.97431 .43047 m
1 .61842 L
s
1 .61842 m
.39761 .7782 L
s
.39761 .7782 m
.40383 .60035 L
s
0 0 m
1 0 L
1 .7782 L
0 .7782 L
closepath
clip
newpath
.5 Mabswid
.62128 .5909 m
.64818 .59507 L
s
.64818 .59507 m
.64378 .58297 L
s
.64982 .6037 m
.64818 .59507 L
s
.64818 .59507 m
.67014 .59279 L
s
.62257 .5995 m
.64982 .6037 L
s
.64867 .60871 m
.64982 .6037 L
s
.64982 .6037 m
.67207 .60141 L
s
.67014 .59279 m
.66494 .58077 L
s
.67207 .60141 m
.67014 .59279 L
s
.67014 .59279 m
.68642 .58414 L
s
.61783 .57893 m
.64378 .58297 L
s
.64378 .58297 m
.63667 .56762 L
s
.64378 .58297 m
.66494 .58077 L
s
.67071 .60645 m
.67207 .60141 L
s
.67207 .60141 m
.68859 .59268 L
s
.59027 .58039 m
.62128 .5909 L
s
.62128 .5909 m
.61783 .57893 L
s
.62257 .5995 m
.62128 .5909 L
s
.66494 .58077 m
.65656 .56553 L
s
.66494 .58077 m
.68061 .57236 L
s
.59115 .58891 m
.62257 .5995 L
s
.62167 .60457 m
.62257 .5995 L
s
.58791 .56872 m
.61783 .57893 L
s
.61783 .57893 m
.61226 .56378 L
s
.62167 .60457 m
.64867 .60871 L
s
.64471 .60997 m
.64867 .60871 L
s
.64867 .60871 m
.67071 .60645 L
s
.61226 .56378 m
.63667 .56762 L
s
.63667 .56762 m
.62698 .54925 L
s
.63667 .56762 m
.65656 .56553 L
s
.66604 .60779 m
.67071 .60645 L
s
.67071 .60645 m
.68706 .59783 L
s
.65656 .56553 m
.64513 .54732 L
s
.65656 .56553 m
.67126 .55755 L
s
.59053 .5941 m
.62167 .60457 L
s
.61856 .60597 m
.62167 .60457 L
s
.68642 .58414 m
.68061 .57236 L
s
.68859 .59268 m
.68642 .58414 L
s
.68642 .58414 m
.69642 .56927 L
s
.58411 .5541 m
.61226 .56378 L
s
.61226 .56378 m
.60466 .54571 L
s
.68706 .59783 m
.68859 .59268 L
s
.68859 .59268 m
.69874 .57769 L
s
.68061 .57236 m
.67126 .55755 L
s
.68061 .57236 m
.69019 .55792 L
s
.55609 .56376 m
.59027 .58039 L
s
.59027 .58039 m
.58791 .56872 L
s
.59115 .58891 m
.59027 .58039 L
s
.61856 .60597 m
.64471 .60997 L
s
.63797 .60741 m
.64471 .60997 L
s
.64471 .60997 m
.66604 .60779 L
s
.55651 .57214 m
.59115 .58891 L
s
.59053 .5941 m
.59115 .58891 L
s
.55495 .55258 m
.58791 .56872 L
s
.58791 .56872 m
.58411 .5541 L
s
.6581 .60534 m
.66604 .60779 L
s
.66604 .60779 m
.68184 .59945 L
s
.68184 .59945 m
.68706 .59783 L
s
.68706 .59783 m
.69711 .58303 L
s
.60466 .54571 m
.62698 .54925 L
s
.62698 .54925 m
.61481 .52816 L
s
.62698 .54925 m
.64513 .54732 L
s
.67126 .55755 m
.65849 .53995 L
s
.67126 .55755 m
.68018 .54387 L
s
.58841 .59585 m
.61856 .60597 L
s
.61328 .60362 m
.61856 .60597 L
s
.64513 .54732 m
.63079 .52643 L
s
.64513 .54732 m
.65849 .53995 L
s
.55621 .57754 m
.59053 .5941 L
s
.58841 .59585 m
.59053 .5941 L
s
.57893 .53678 m
.60466 .54571 L
s
.60466 .54571 m
.59514 .525 L
s
.55311 .5388 m
.58411 .5541 L
s
.58411 .5541 m
.57893 .53678 L
s
.67297 .59746 m
.68184 .59945 L
s
.68184 .59945 m
.69151 .58514 L
s
.69642 .56927 m
.69019 .55792 L
s
.69874 .57769 m
.69642 .56927 L
s
.69642 .56927 m
.69961 .54853 L
s
.65849 .53995 m
.6425 .51986 L
s
.65849 .53995 m
.66654 .52734 L
s
.61328 .60362 m
.63797 .60741 L
s
.62853 .60097 m
.63797 .60741 L
s
.63797 .60741 m
.6581 .60534 L
s
.69019 .55792 m
.68018 .54387 L
s
.69019 .55792 m
.6932 .53781 L
s
.69711 .58303 m
.69874 .57769 L
s
.69874 .57769 m
.70201 .55677 L
s
.64696 .59907 m
.6581 .60534 L
s
.6581 .60534 m
.67297 .59746 L
s
.55519 .57984 m
.58841 .59585 L
s
.58481 .59406 m
.58841 .59585 L
s
.55062 .52268 m
.57893 .53678 L
s
.57893 .53678 m
.57244 .51703 L
s
.59514 .525 m
.61481 .52816 L
s
.61481 .52816 m
.60036 .50466 L
s
.61481 .52816 m
.63079 .52643 L
s
.58481 .59406 m
.61328 .60362 L
s
.60588 .59749 m
.61328 .60362 L
s
.5198 .54138 m
.55609 .56376 L
s
.55609 .56376 m
.55495 .55258 L
s
.55651 .57214 m
.55609 .56376 L
s
.68018 .54387 m
.66654 .52734 L
s
.68018 .54387 m
.68289 .52482 L
s
.69151 .58514 m
.69711 .58303 L
s
.69711 .58303 m
.70032 .56238 L
s
.51998 .53087 m
.55495 .55258 L
s
.55495 .55258 m
.55311 .5388 L
s
.63079 .52643 m
.61376 .5032 L
s
.63079 .52643 m
.6425 .51986 L
s
.51973 .54956 m
.55651 .57214 L
s
.55621 .57754 m
.55651 .57214 L
s
.57244 .51703 m
.59514 .525 L
s
.59514 .525 m
.58382 .50197 L
s
.52027 .51826 m
.55311 .5388 L
s
.55311 .5388 m
.55062 .52268 L
s
.66053 .59183 m
.67297 .59746 L
s
.67297 .59746 m
.68201 .58395 L
s
.51978 .55525 m
.55621 .57754 L
s
.55519 .57984 m
.55621 .57754 L
s
.6425 .51986 m
.62353 .49761 L
s
.6425 .51986 m
.64947 .50864 L
s
.66654 .52734 m
.64947 .50864 L
s
.66654 .52734 m
.66886 .50981 L
s
.68201 .58395 m
.69151 .58514 L
s
.69151 .58514 m
.69456 .5652 L
s
.55345 .57895 m
.58481 .59406 L
s
.57976 .5887 m
.58481 .59406 L
s
.54749 .50449 m
.57244 .51703 L
s
.57244 .51703 m
.56474 .49521 L
s
.60588 .59749 m
.62853 .60097 L
s
.61648 .59069 m
.62853 .60097 L
s
.62853 .60097 m
.64696 .59907 L
s
.52067 .50379 m
.55062 .52268 L
s
.55062 .52268 m
.54749 .50449 L
s
.63275 .58899 m
.64696 .59907 L
s
.64696 .59907 m
.66053 .59183 L
s
.51994 .55832 m
.55519 .57984 L
s
.55345 .57895 m
.55519 .57984 L
s
.57976 .5887 m
.60588 .59749 L
s
.59644 .58759 m
.60588 .59749 L
s
.69961 .54853 m
.6932 .53781 L
s
.70201 .55677 m
.69961 .54853 L
s
.69961 .54853 m
.69564 .52242 L
s
.6932 .53781 m
.68289 .52482 L
s
.6932 .53781 m
.68928 .51251 L
s
.58382 .50197 m
.60036 .50466 L
s
.60036 .50466 m
.58383 .47917 L
s
.60036 .50466 m
.61376 .5032 L
s
.70032 .56238 m
.70201 .55677 L
s
.70201 .55677 m
.69802 .53043 L
s
.61376 .5032 m
.59429 .478 L
s
.61376 .5032 m
.62353 .49761 L
s
.56474 .49521 m
.58382 .50197 L
s
.58382 .50197 m
.5709 .47704 L
s
.64947 .50864 m
.62926 .48808 L
s
.64947 .50864 m
.65136 .49306 L
s
.68289 .52482 m
.66886 .50981 L
s
.68289 .52482 m
.67906 .50091 L
s
.66872 .57942 m
.68201 .58395 L
s
.68201 .58395 m
.68477 .56514 L
s
.64469 .58255 m
.66053 .59183 L
s
.66053 .59183 m
.66872 .57942 L
s
.69456 .5652 m
.70032 .56238 L
s
.70032 .56238 m
.69634 .53638 L
s
.48261 .51381 m
.5198 .54138 L
s
.5198 .54138 m
.51998 .53087 L
s
.51973 .54956 m
.5198 .54138 L
s
.48419 .50418 m
.51998 .53087 L
s
.51998 .53087 m
.52027 .51826 L
s
.52116 .48772 m
.54749 .50449 L
s
.54749 .50449 m
.5438 .48456 L
s
.62353 .49761 m
.60187 .47358 L
s
.62353 .49761 m
.62926 .48808 L
s
.55101 .57483 m
.57976 .5887 L
s
.57333 .57978 m
.57976 .5887 L
s
.48202 .52175 m
.51973 .54956 L
s
.51978 .55525 m
.51973 .54956 L
s
.52022 .55867 m
.55345 .57895 L
s
.55101 .57483 m
.55345 .57895 L
s
.66886 .50981 m
.65136 .49306 L
s
.66886 .50981 m
.6652 .48785 L
s
.5438 .48456 m
.56474 .49521 L
s
.56474 .49521 m
.55596 .47168 L
s
.24 .35 .67 r
.29151 .53736 m
.32967 .53794 L
s
.32967 .53794 m
.33687 .52754 L
s
.32698 .54609 m
.32967 .53794 L
s
.32967 .53794 m
.37595 .53421 L
s
0 0 0 r
.48672 .49304 m
.52027 .51826 L
s
.52027 .51826 m
.52067 .50379 L
s
.24 .35 .67 r
.30012 .52698 m
.33687 .52754 L
s
.33687 .52754 m
.34844 .51511 L
s
.33687 .52754 m
.38145 .52393 L
s
.26285 .53249 m
.29151 .53736 L
s
.29151 .53736 m
.30012 .52698 L
s
.28829 .54551 m
.29151 .53736 L
s
.27255 .52227 m
.30012 .52698 L
s
.30012 .52698 m
.31395 .51458 L
s
.28829 .54551 m
.32698 .54609 L
s
.32887 .55183 m
.32698 .54609 L
s
.32698 .54609 m
.37389 .54233 L
s
.25923 .5406 m
.28829 .54551 L
s
.29056 .55126 m
.28829 .54551 L
s
.31395 .51458 m
.34844 .51511 L
s
.34844 .51511 m
.36416 .50089 L
s
.34844 .51511 m
.39029 .5117 L
s
0 0 0 r
.48244 .52781 m
.51978 .55525 L
s
.51994 .55832 m
.51978 .55525 L
s
.68477 .56514 m
.69456 .5652 L
s
.69456 .5652 m
.69062 .54011 L
s
.24 .35 .67 r
.28812 .51013 m
.31395 .51458 L
s
.31395 .51458 m
.33275 .50041 L
s
.37595 .53421 m
.38145 .52393 L
s
.37389 .54233 m
.37595 .53421 L
s
.37595 .53421 m
.42871 .52629 L
s
.38145 .52393 m
.39029 .5117 L
s
.38145 .52393 m
.43228 .51625 L
s
0 0 0 r
.59644 .58759 m
.61648 .59069 L
s
.60198 .57663 m
.61648 .59069 L
s
.61648 .59069 m
.63275 .58899 L
s
.24 .35 .67 r
.24482 .52348 m
.26285 .53249 L
s
.26285 .53249 m
.27255 .52227 L
s
.25923 .5406 m
.26285 .53249 L
s
.25524 .51353 m
.27255 .52227 L
s
.27255 .52227 m
.28812 .51013 L
s
0 0 0 r
.49015 .48064 m
.52067 .50379 L
s
.52067 .50379 m
.52116 .48772 L
s
.24 .35 .67 r
.37534 .54812 m
.37389 .54233 L
s
.37389 .54233 m
.42738 .53434 L
s
0 0 0 r
.61567 .57519 m
.63275 .58899 L
s
.63275 .58899 m
.64469 .58255 L
s
.24 .35 .67 r
.39029 .5117 m
.4023 .49776 L
s
.39029 .5117 m
.438 .50445 L
s
0 0 0 r
.62926 .48808 m
.60625 .46604 L
s
.62926 .48808 m
.63069 .47489 L
s
.24 .35 .67 r
.29056 .55126 m
.32887 .55183 L
s
.33535 .55502 m
.32887 .55183 L
s
.32887 .55183 m
.37534 .54812 L
s
.26178 .54641 m
.29056 .55126 L
s
.2983 .55446 m
.29056 .55126 L
s
0 0 0 r
.57333 .57978 m
.59644 .58759 L
s
.58509 .57399 m
.59644 .58759 L
s
.24 .35 .67 r
.24093 .5315 m
.25923 .5406 L
s
.26178 .54641 m
.25923 .5406 L
s
0 0 0 r
.6518 .57154 m
.66872 .57942 L
s
.66872 .57942 m
.6711 .56216 L
s
.24 .35 .67 r
.27196 .50188 m
.28812 .51013 L
s
.28812 .51013 m
.30927 .49631 L
s
0 0 0 r
.65136 .49306 m
.63069 .47489 L
s
.65136 .49306 m
.64795 .47361 L
s
.24 .35 .67 r
.33275 .50041 m
.36416 .50089 L
s
.36416 .50089 m
.38375 .48516 L
s
.36416 .50089 m
.4023 .49776 L
s
.30927 .49631 m
.33275 .50041 L
s
.33275 .50041 m
.35618 .48472 L
s
0 0 0 r
.5709 .47704 m
.58383 .47917 L
s
.58383 .47917 m
.59429 .478 L
s
.52175 .47037 m
.5438 .48456 L
s
.5438 .48456 m
.5396 .46327 L
s
.48386 .53184 m
.51994 .55832 L
s
.52022 .55867 m
.51994 .55832 L
s
.24 .35 .67 r
.38029 .55144 m
.37534 .54812 L
s
.37534 .54812 m
.42831 .54023 L
s
0 0 0 r
.59429 .478 m
.60187 .47358 L
s
.24 .35 .67 r
.4023 .49776 m
.41726 .48238 L
s
.4023 .49776 m
.44578 .4911 L
s
.43228 .51625 m
.438 .50445 L
s
.42871 .52629 m
.43228 .51625 L
s
.43228 .51625 m
.48754 .50474 L
s
.42738 .53434 m
.42871 .52629 L
s
.42871 .52629 m
.4861 .5144 L
s
0 0 0 r
.55596 .47168 m
.5709 .47704 L
s
.24 .35 .67 r
.24367 .53743 m
.26178 .54641 L
s
.27049 .54979 m
.26178 .54641 L
s
0 0 0 r
.5206 .55623 m
.55101 .57483 L
s
.54792 .56747 m
.55101 .57483 L
s
.62565 .56973 m
.64469 .58255 L
s
.64469 .58255 m
.6518 .57154 L
s
.24 .35 .67 r
.29466 .48874 m
.30927 .49631 L
s
.30927 .49631 m
.33562 .4811 L
s
0 0 0 r
.6711 .56216 m
.68477 .56514 L
s
.68477 .56514 m
.68093 .54152 L
s
.52116 .48772 m
.52175 .47037 L
s
.24 .35 .67 r
.438 .50445 m
.44578 .4911 L
s
.438 .50445 m
.48986 .49358 L
s
.2983 .55446 m
.33535 .55502 L
s
.34632 .55555 m
.33535 .55502 L
s
.33535 .55502 m
.38029 .55144 L
s
.42831 .54023 m
.42738 .53434 L
s
.42738 .53434 m
.48556 .52234 L
s
.249 .50105 m
.25524 .51353 L
s
.25524 .51353 m
.27196 .50188 L
s
.24482 .52348 m
.25524 .51353 L
s
.23826 .51058 m
.24482 .52348 L
s
.24093 .5315 m
.24482 .52348 L
s
.27049 .54979 m
.2983 .55446 L
s
.31143 .55503 m
.2983 .55446 L
s
0 0 0 r
.68928 .51251 m
.67906 .50091 L
s
.69564 .52242 m
.68928 .51251 L
s
.68928 .51251 m
.67826 .48274 L
s
.60187 .47358 m
.60625 .46604 L
s
.69802 .53043 m
.69564 .52242 L
s
.69564 .52242 m
.6843 .49166 L
s
.54792 .56747 m
.57333 .57978 L
s
.56561 .56737 m
.57333 .57978 L
s
.24 .35 .67 r
.35618 .48472 m
.38375 .48516 L
s
.38375 .48516 m
.40685 .46821 L
s
.38375 .48516 m
.41726 .48238 L
s
.26622 .49009 m
.27196 .50188 L
s
.27196 .50188 m
.29466 .48874 L
s
.33562 .4811 m
.35618 .48472 L
s
.35618 .48472 m
.38381 .46784 L
s
.23424 .51849 m
.24093 .5315 L
s
.24367 .53743 m
.24093 .5315 L
s
0 0 0 r
.67906 .50091 m
.6652 .48785 L
s
.67906 .50091 m
.66857 .47283 L
s
.5396 .46327 m
.55596 .47168 L
s
.24 .35 .67 r
.38867 .55218 m
.38029 .55144 L
s
.38029 .55144 m
.43152 .54382 L
s
0 0 0 r
.69634 .53638 m
.69802 .53043 L
s
.69802 .53043 m
.68657 .49939 L
s
.24 .35 .67 r
.44578 .4911 m
.45546 .47649 L
s
.44578 .4911 m
.49301 .48113 L
s
.43152 .54382 m
.42831 .54023 L
s
.42831 .54023 m
.48594 .52839 L
s
.41726 .48238 m
.4349 .46586 L
s
.41726 .48238 m
.45546 .47649 L
s
.25303 .54113 m
.27049 .54979 L
s
.28527 .55063 m
.27049 .54979 L
s
0 0 0 r
.63069 .47489 m
.60722 .45565 L
s
.63069 .47489 m
.62764 .45847 L
s
.24 .35 .67 r
.3229 .4744 m
.33562 .4811 L
s
.33562 .4811 m
.36667 .46479 L
s
0 0 0 r
.48626 .53375 m
.52022 .55867 L
s
.5206 .55623 m
.52022 .55867 L
s
.24 .35 .67 r
.28958 .47794 m
.29466 .48874 L
s
.29466 .48874 m
.3229 .4744 L
s
0 0 0 r
.6652 .48785 m
.64795 .47361 L
s
.6652 .48785 m
.65546 .46214 L
s
.24 .35 .67 r
.23707 .52459 m
.24367 .53743 L
s
.25303 .54113 m
.24367 .53743 L
s
0 0 0 r
.69062 .54011 m
.69634 .53638 L
s
.69634 .53638 m
.68498 .50574 L
s
.60625 .46604 m
.60722 .45565 L
s
.24 .35 .67 r
.48754 .50474 m
.48986 .49358 L
s
.4861 .5144 m
.48754 .50474 L
s
.31143 .55503 m
.34632 .55555 L
s
.36165 .55338 m
.34632 .55555 L
s
.34632 .55555 m
.38867 .55218 L
s
.48556 .52234 m
.4861 .5144 L
s
0 0 0 r
.48419 .50418 m
.48672 .49304 L
s
.48261 .51381 m
.48419 .50418 L
s
.24 .35 .67 r
.28527 .55063 m
.31143 .55503 L
s
.32975 .5529 m
.31143 .55503 L
s
0 0 0 r
.48202 .52175 m
.48261 .51381 L
s
.63152 .5604 m
.6518 .57154 L
s
.6518 .57154 m
.65375 .55626 L
s
.24 .35 .67 r
.48986 .49358 m
.49301 .48113 L
s
.45546 .47649 m
.46686 .46089 L
s
0 0 0 r
.48672 .49304 m
.49015 .48064 L
s
.24 .35 .67 r
.43696 .54502 m
.43152 .54382 L
s
.43152 .54382 m
.48724 .53241 L
s
0 0 0 r
.65375 .55626 m
.6711 .56216 L
s
.6711 .56216 m
.66741 .54055 L
s
.24 .35 .67 r
.38381 .46784 m
.40685 .46821 L
s
.40685 .46821 m
.43304 .45039 L
s
.40685 .46821 m
.4349 .46586 L
s
0 0 0 r
.58509 .57399 m
.60198 .57663 L
s
.58525 .55894 m
.60198 .57663 L
s
.60198 .57663 m
.61567 .57519 L
s
.24 .35 .67 r
.48594 .52839 m
.48556 .52234 L
s
.48556 .52234 m
.54635 .50671 L
s
.36667 .46479 m
.38381 .46784 L
s
.38381 .46784 m
.41513 .4501 L
s
.31861 .46485 m
.3229 .4744 L
s
.3229 .4744 m
.35615 .45914 L
s
.25431 .48521 m
.249 .50105 L
s
.249 .50105 m
.26622 .49009 L
s
.23826 .51058 m
.249 .50105 L
s
0 0 0 r
.48244 .52781 m
.48202 .52175 L
s
.24 .35 .67 r
.40038 .5503 m
.38867 .55218 L
s
.38867 .55218 m
.43696 .54502 L
s
.24368 .49421 m
.23826 .51058 L
s
.23424 .51849 m
.23826 .51058 L
s
0 0 0 r
.64795 .47361 m
.62764 .45847 L
s
.64795 .47361 m
.63919 .45091 L
s
.59596 .5578 m
.61567 .57519 L
s
.61567 .57519 m
.62565 .56973 L
s
.24 .35 .67 r
.27135 .47515 m
.26622 .49009 L
s
.26622 .49009 m
.28958 .47794 L
s
.24672 .52874 m
.25303 .54113 L
s
.2689 .54248 m
.25303 .54113 L
s
.4349 .46586 m
.45488 .44855 L
s
.4349 .46586 m
.46686 .46089 L
s
.2689 .54248 m
.28527 .55063 L
s
.3059 .54887 m
.28527 .55063 L
s
.416 .747 1 r
.50676 .42284 m .50418 .43963 L .52236 .44106 L p F P
0 0 1 r
s
.416 .747 1 r
.52236 .44106 m .52266 .4241 L .50676 .42284 L p F P
0 0 1 r
s
.395 .699 .995 r
.52211 .45801 m .52236 .44106 L .50418 .43963 L p F P
0 0 1 r
s
.385 .694 1 r
.52266 .4241 m .52236 .44106 L .54063 .44022 L p F P
0 0 1 r
s
0 0 0 r
.53888 .45983 m
.5396 .46327 L
s
.361 .642 .927 r
.52236 .44106 m .52211 .45801 L .54225 .45709 L p F P
0 0 1 r
s
.361 .642 .927 r
.54225 .45709 m .54063 .44022 L .52236 .44106 L p F P
0 0 1 r
s
0 0 0 r
.5211 .55102 m
.54792 .56747 L
s
.54421 .55695 m
.54792 .56747 L
s
.56561 .56737 m
.58509 .57399 L
s
.572 .55686 m
.58509 .57399 L
s
.68093 .54152 m
.69062 .54011 L
s
.69062 .54011 m
.67954 .51058 L
s
.385 .694 1 r
.54063 .44022 m .53863 .42336 L .52266 .4241 L p F P
0 0 1 r
s
.358 .647 .949 r
.53863 .42336 m .54063 .44022 L .55827 .43715 L p F P
0 0 1 r
s
.331 .592 .867 r
.54063 .44022 m .54225 .45709 L .5617 .45374 L p F P
0 0 1 r
s
0 0 0 r
.54974 .4558 m
.55596 .47168 L
s
.331 .592 .867 r
.5617 .45374 m .55827 .43715 L .54063 .44022 L p F P
0 0 1 r
s
0 0 0 r
.55656 .45063 m
.55726 .45192 L
s
.24 .35 .67 r
.35615 .45914 m
.36667 .46479 L
s
.36667 .46479 m
.40185 .4477 L
s
.437 .795 1 r
.50977 .40644 m .50676 .42284 L .52266 .4241 L p F P
0 0 1 r
s
.437 .795 1 r
.52266 .4241 m .523 .4075 L .50977 .40644 L p F P
0 0 1 r
s
.409 .747 1 r
.523 .4075 m .52266 .4241 L .53863 .42336 L p F P
0 0 1 r
s
.395 .699 .995 r
.50418 .43963 m .50208 .45645 L .52211 .45801 L p F P
0 0 1 r
s
.372 .65 .921 r
.52193 .47459 m .52211 .45801 L .50208 .45645 L p F P
0 0 1 r
s
.336 .591 .85 r
.52211 .45801 m .52193 .47459 L .54346 .47362 L p F P
0 0 1 r
s
.336 .591 .85 r
.54346 .47362 m .54225 .45709 L .52211 .45801 L p F P
0 0 1 r
s
0 0 0 r
.52241 .45209 m
.53229 .45851 L
s
.52208 .46134 m
.52241 .45209 L
s
.53496 .44102 m
.53835 .45731 L
s
.451 .809 1 r
.49159 .41963 m .48682 .436 L .50418 .43963 L p F P
0 0 1 r
s
.451 .809 1 r
.50418 .43963 m .50676 .42284 L .49159 .41963 L p F P
0 0 1 r
s
.432 .764 1 r
.50208 .45645 m .50418 .43963 L .48682 .436 L p F P
0 0 1 r
s
.24 .35 .67 r
.2397 .50196 m
.23424 .51849 L
s
.23707 .52459 m
.23424 .51849 L
s
.409 .747 1 r
.53863 .42336 m .53631 .40688 L .523 .4075 L p F P
0 0 1 r
s
.385 .704 1 r
.53631 .40688 m .53863 .42336 L .55405 .42065 L p F P
0 0 1 r
s
.358 .647 .949 r
.55827 .43715 m .55405 .42065 L .53863 .42336 L p F P
0 0 1 r
s
.305 .539 .787 r
.54225 .45709 m .54346 .47362 L .56426 .47006 L p F P
0 0 1 r
s
.305 .539 .787 r
.56426 .47006 m .5617 .45374 L .54225 .45709 L p F P
0 0 1 r
s
0 0 0 r
.5631 .46268 m
.5709 .47704 L
s
.54625 .44688 m
.54914 .45428 L
s
.468 .851 1 r
.49715 .40375 m .49159 .41963 L .50676 .42284 L p F P
0 0 1 r
s
.468 .851 1 r
.50676 .42284 m .50977 .40644 L .49715 .40375 L p F P
0 0 1 r
s
.24 .35 .67 r
.48724 .53241 m
.48594 .52839 L
s
.432 .764 1 r
.48682 .436 m .48294 .45248 L .50208 .45645 L p F P
0 0 1 r
s
.411 .717 1 r
.50051 .47294 m .50208 .45645 L .48294 .45248 L p F P
0 0 1 r
s
0 0 0 r
.49459 .46737 m
.49793 .46993 L
s
.5006 .47198 m
.52116 .48772 L
s
.49441 .46724 m
.49459 .46737 L
s
.49015 .48064 m
.49441 .46724 L
s
.24 .35 .67 r
.49301 .48113 m
.49668 .46848 L
s
.45546 .47649 m
.49613 .46784 L
s
.372 .65 .921 r
.50208 .45645 m .50051 .47294 L .52193 .47459 L p F P
0 0 1 r
s
.24 .35 .67 r
.29443 .46427 m
.28958 .47794 L
s
.28958 .47794 m
.31861 .46485 L
s
0 0 0 r
.48386 .53184 m
.48244 .52781 L
s
.4896 .53345 m
.5206 .55623 L
s
.5211 .55102 m
.5206 .55623 L
s
.457 .844 1 r
.51315 .39078 m .50977 .40644 L .523 .4075 L p F P
0 0 1 r
s
.457 .844 1 r
.523 .4075 m .52339 .39161 L .51315 .39078 L p F P
0 0 1 r
s
.434 .801 1 r
.52339 .39161 m .523 .4075 L .53631 .40688 L p F P
0 0 1 r
s
.333 .606 .902 r
.55405 .42065 m .55827 .43715 L .57456 .43195 L p F P
0 0 1 r
s
.304 .548 .814 r
.55827 .43715 m .5617 .45374 L .57967 .44806 L p F P
0 0 1 r
s
0 0 0 r
.5727 .45131 m
.59429 .478 L
s
.56573 .45247 m
.58383 .47917 L
s
.304 .548 .814 r
.57967 .44806 m .57456 .43195 L .55827 .43715 L p F P
0 0 1 r
s
.348 .6 .847 r
.52182 .49043 m .52193 .47459 L .50051 .47294 L p F P
0 0 1 r
s
.24 .35 .67 r
.49301 .48113 m
.50625 .47765 L
s
.48986 .49358 m
.517 .48648 L
s
.48754 .50474 m
.53731 .49182 L
s
.311 .54 .774 r
.52193 .47459 m .52182 .49043 L .54424 .48943 L p F P
0 0 1 r
s
.311 .54 .774 r
.54424 .48943 m .54346 .47362 L .52193 .47459 L p F P
0 0 1 r
s
0 0 0 r
.55656 .45063 m
.56017 .45123 L
s
.56754 .45189 m
.5727 .45131 L
s
.385 .704 1 r
.55405 .42065 m .54914 .4046 L .53631 .40688 L p F P
0 0 1 r
s
.363 .668 .994 r
.54914 .4046 m .55405 .42065 L .56828 .41607 L p F P
0 0 1 r
s
.333 .606 .902 r
.57456 .43195 m .56828 .41607 L .55405 .42065 L p F P
0 0 1 r
s
.434 .801 1 r
.53631 .40688 m .5337 .39112 L .52339 .39161 L p F P
0 0 1 r
s
.413 .764 1 r
.5337 .39112 m .53631 .40688 L .54914 .4046 L p F P
0 0 1 r
s
0 0 0 r
.60722 .45565 m
.60468 .44275 L
s
.484 .892 1 r
.50338 .38868 m .49715 .40375 L .50977 .40644 L p F P
0 0 1 r
s
.484 .892 1 r
.50977 .40644 m .51315 .39078 L .50338 .38868 L p F P
0 0 1 r
s
0 0 0 r
.60372 .55348 m
.62565 .56973 L
s
.62565 .56973 m
.63152 .5604 L
s
.278 .487 .708 r
.54346 .47362 m .54424 .48943 L .5659 .48577 L p F P
0 0 1 r
s
.278 .487 .708 r
.5659 .48577 m .56426 .47006 L .54346 .47362 L p F P
0 0 1 r
s
.24 .35 .67 r
.53165 .48266 m
.54395 .47944 L
s
.489 .879 1 r
.47777 .41459 m .47099 .43028 L .48682 .436 L p F P
0 0 1 r
s
.489 .879 1 r
.48682 .436 m .49159 .41963 L .47777 .41459 L p F P
0 0 1 r
s
.474 .838 1 r
.48294 .45248 m .48682 .436 L .47099 .43028 L p F P
0 0 1 r
s
.276 .492 .729 r
.5617 .45374 m .56426 .47006 L .58349 .46405 L p F P
0 0 1 r
s
.276 .492 .729 r
.58349 .46405 m .57967 .44806 L .5617 .45374 L p F P
0 0 1 r
s
0 0 0 r
.58032 .4508 m
.60187 .47358 L
s
.54567 .42405 m
.56398 .44998 L
s
.502 .915 1 r
.48567 .39951 m .47777 .41459 L .49159 .41963 L p F P
0 0 1 r
s
.502 .915 1 r
.49159 .41963 m .49715 .40375 L .48567 .39951 L p F P
0 0 1 r
s
0 0 0 r
.54625 .44688 m
.55656 .45063 L
s
.54107 .42327 m
.55656 .45063 L
s
.411 .717 1 r
.48294 .45248 m .48004 .46873 L .50051 .47294 L p F P
0 0 1 r
s
0 0 0 r
.49481 .46612 m
.49942 .45311 L
s
.24 .35 .67 r
.49829 .46731 m
.54004 .45624 L
s
.49724 .46668 m
.50152 .45347 L
s
0 0 0 r
.49942 .45311 m
.51207 .46289 L
s
.388 .666 .927 r
.49951 .48873 m .50051 .47294 L .48004 .46873 L p F P
0 0 1 r
s
0 0 0 r
.48144 .47289 m
.49015 .48064 L
s
.348 .6 .847 r
.50051 .47294 m .49951 .48873 L .52182 .49043 L p F P
0 0 1 r
s
.24 .35 .67 r
.5142 .47556 m
.54221 .46819 L
s
.44454 .54374 m
.43696 .54502 L
s
.43696 .54502 m
.48944 .53428 L
s
.2425 .50829 m
.23707 .52459 L
s
.24672 .52874 m
.23707 .52459 L
s
.32975 .5529 m
.36165 .55338 L
s
.38107 .5485 m
.36165 .55338 L
s
.36165 .55338 m
.40038 .5503 L
s
.474 .838 1 r
.47099 .43028 m .46547 .44624 L .48294 .45248 L p F P
0 0 1 r
s
.455 .792 1 r
.48004 .46873 m .48294 .45248 L .46547 .44624 L p F P
0 0 1 r
s
.24 .35 .67 r
.48132 .4578 m
.50152 .45347 L
s
.46686 .46089 m
.47133 .45527 L
s
.46686 .46089 m
.47398 .45937 L
s
.35272 .4511 m
.35615 .45914 L
s
.35615 .45914 m
.39376 .44327 L
s
.413 .764 1 r
.54914 .4046 m .54363 .38934 L .5337 .39112 L p F P
0 0 1 r
s
.395 .733 1 r
.54363 .38934 m .54914 .4046 L .56096 .40075 L p F P
0 0 1 r
s
.363 .668 .994 r
.56828 .41607 m .56096 .40075 L .54914 .4046 L p F P
0 0 1 r
s
.24 .35 .67 r
.3059 .54887 m
.32975 .5529 L
s
.35298 .54808 m
.32975 .5529 L
s
0 0 0 r
.62764 .45847 m
.60468 .44275 L
s
.62764 .45847 m
.62013 .43939 L
s
.512 .947 1 r
.49451 .38537 m .48567 .39951 L .49715 .40375 L p F P
0 0 1 r
s
.512 .947 1 r
.49715 .40375 m .50338 .38868 L .49451 .38537 L p F P
0 0 1 r
s
0 0 0 r
.54421 .55695 m
.56561 .56737 L
s
.55671 .55162 m
.56561 .56737 L
s
.24 .35 .67 r
.32305 .45279 m
.31861 .46485 L
s
.31861 .46485 m
.35272 .4511 L
s
0 0 0 r
.50509 .43855 m
.52241 .45209 L
s
.52241 .45209 m
.52314 .43325 L
s
.24 .35 .67 r
.26308 .53083 m
.2689 .54248 L
s
.29103 .54142 m
.2689 .54248 L
s
.476 .891 1 r
.51682 .37621 m .51315 .39078 L .52339 .39161 L p F P
0 0 1 r
s
.476 .891 1 r
.52339 .39161 m .52382 .37678 L .51682 .37621 L p F P
0 0 1 r
s
.458 .857 1 r
.52382 .37678 m .52339 .39161 L .5337 .39112 L p F P
0 0 1 r
s
.247 .437 .647 r
.56426 .47006 m .5659 .48577 L .58594 .47956 L p F P
0 0 1 r
s
.247 .437 .647 r
.58594 .47956 m .58349 .46405 L .56426 .47006 L p F P
0 0 1 r
s
.24 .35 .67 r
.48944 .53428 m
.48724 .53241 L
s
.321 .547 .769 r
.52177 .5052 m .52182 .49043 L .49951 .48873 L p F P
0 0 1 r
s
.24 .35 .67 r
.4861 .5144 m
.52175 .50519 L
s
.285 .488 .697 r
.52182 .49043 m .52177 .5052 L .54456 .50419 L p F P
0 0 1 r
s
.285 .488 .697 r
.54456 .50419 m .54424 .48943 L .52182 .49043 L p F P
0 0 1 r
s
.24 .35 .67 r
.54425 .49001 m
.54524 .48975 L
s
.344 .637 .961 r
.56096 .40075 m .56828 .41607 L .58072 .40979 L p F P
0 0 1 r
s
.311 .57 .862 r
.56828 .41607 m .57456 .43195 L .58883 .42483 L p F P
0 0 1 r
s
.311 .57 .862 r
.58883 .42483 m .58072 .40979 L .56828 .41607 L p F P
0 0 1 r
s
0 0 0 r
.54936 .42362 m
.56991 .448 L
s
.458 .857 1 r
.5337 .39112 m .53086 .37644 L .52382 .37678 L p F P
0 0 1 r
s
.441 .828 1 r
.53086 .37644 m .5337 .39112 L .54363 .38934 L p F P
0 0 1 r
s
.279 .508 .767 r
.57456 .43195 m .57967 .44806 L .59543 .44028 L p F P
0 0 1 r
s
0 0 0 r
.58472 .44649 m
.60625 .46604 L
s
.58406 .44589 m
.58472 .44649 L
s
.279 .508 .767 r
.59543 .44028 m .58883 .42483 L .57456 .43195 L p F P
0 0 1 r
s
0 0 0 r
.552 .42201 m
.5759 .44621 L
s
.53496 .44102 m
.54625 .44688 L
s
.54625 .44688 m
.53577 .42132 L
s
.497 .93 1 r
.51016 .37476 m .50338 .38868 L .51315 .39078 L p F P
0 0 1 r
s
.497 .93 1 r
.51315 .39078 m .51682 .37621 L .51016 .37476 L p F P
0 0 1 r
s
0 0 0 r
.48626 .53375 m
.48386 .53184 L
s
.66741 .54055 m
.68093 .54152 L
s
.68093 .54152 m
.67034 .51377 L
s
.24 .35 .67 r
.54518 .48927 m
.54524 .48975 L
s
.41522 .54577 m
.40038 .5503 L
s
.40038 .5503 m
.44454 .54374 L
s
.251 .435 .63 r
.54424 .48943 m .54456 .50419 L .56657 .5005 L p F P
0 0 1 r
s
.24 .35 .67 r
.54524 .48975 m
.54526 .48994 L
s
.251 .435 .63 r
.56657 .5005 m .5659 .48577 L .54424 .48943 L p F P
0 0 1 r
s
.24 .35 .67 r
.54395 .47944 m
.54512 .48874 L
s
.41513 .4501 m
.43304 .45039 L
s
.43304 .45039 m
.45488 .44855 L
s
.455 .792 1 r
.46547 .44624 m .46135 .46211 L .48004 .46873 L p F P
0 0 1 r
s
.24 .35 .67 r
.47354 .45248 m
.47976 .44465 L
s
.433 .741 1 r
.47819 .48439 m .48004 .46873 L .46135 .46211 L p F P
0 0 1 r
s
0 0 0 r
.47973 .47136 m
.48144 .47289 L
s
.388 .666 .927 r
.48004 .46873 m .47819 .48439 L .49951 .48873 L p F P
0 0 1 r
s
.24 .35 .67 r
.40185 .4477 m
.41513 .4501 L
s
.538 .986 1 r
.47581 .39391 m .46588 .40791 L .47777 .41459 L p F P
0 0 1 r
s
.538 .986 1 r
.47777 .41459 m .48567 .39951 L .47581 .39391 L p F P
0 0 1 r
s
.531 .957 1 r
.47099 .43028 m .47777 .41459 L .46588 .40791 L p F P
0 0 1 r
s
.24 .35 .67 r
.54221 .46819 m
.54395 .47944 L
s
.395 .733 1 r
.56096 .40075 m .55277 .38634 L .54363 .38934 L p F P
0 0 1 r
s
.379 .708 1 r
.55277 .38634 m .56096 .40075 L .57129 .39549 L p F P
0 0 1 r
s
.344 .637 .961 r
.58072 .40979 m .57129 .39549 L .56096 .40075 L p F P
0 0 1 r
s
.362 .611 .847 r
.4991 .50349 m .49951 .48873 L .47819 .48439 L p F P
0 0 1 r
s
0 0 0 r
.46698 .47562 m
.48672 .49304 L
s
.321 .547 .769 r
.49951 .48873 m .4991 .50349 L .52177 .5052 L p F P
0 0 1 r
s
.441 .828 1 r
.54363 .38934 m .53764 .37522 L .53086 .37644 L p F P
0 0 1 r
s
.427 .803 1 r
.53764 .37522 m .54363 .38934 L .55277 .38634 L p F P
0 0 1 r
s
.531 .957 1 r
.46588 .40791 m .45735 .4227 L .47099 .43028 L p F P
0 0 1 r
s
.519 .921 1 r
.46547 .44624 m .47099 .43028 L .45735 .4227 L p F P
0 0 1 r
s
.24 .35 .67 r
.54624 .50391 m
.54635 .50671 L
s
.249 .448 .676 r
.57967 .44806 m .58349 .46405 L .60038 .45579 L p F P
0 0 1 r
s
.249 .448 .676 r
.60038 .45579 m .59543 .44028 L .57967 .44806 L p F P
0 0 1 r
s
0 0 0 r
.59808 .4486 m
.60722 .45565 L
s
.58082 .44295 m
.58206 .44408 L
s
.57963 .44508 m
.58082 .44295 L
s
.24 .35 .67 r
.29103 .54142 m
.3059 .54887 L
s
.33203 .54452 m
.3059 .54887 L
s
.518 .972 1 r
.50411 .37249 m .49451 .38537 L .50338 .38868 L p F P
0 0 1 r
s
.518 .972 1 r
.50338 .38868 m .51016 .37476 L .50411 .37249 L p F P
0 0 1 r
s
.541 1 1 r
.48691 .38101 m .47581 .39391 L .48567 .39951 L p F P
0 0 1 r
s
.541 1 1 r
.48567 .39951 m .49451 .38537 L .48691 .38101 L p F P
0 0 1 r
s
0 0 0 r
.63299 .54749 m
.65375 .55626 L
s
.65375 .55626 m
.6503 .53717 L
s
.24 .35 .67 r
.50152 .45347 m
.50671 .43883 L
s
.50152 .45347 m
.5375 .44387 L
s
.39376 .44327 m
.40185 .4477 L
s
.54221 .46819 m
.54004 .45624 L
s
.25206 .51303 m
.24672 .52874 L
s
.26308 .53083 m
.24672 .52874 L
s
0 0 0 r
.47771 .43337 m
.49942 .45311 L
s
.49942 .45311 m
.50509 .43855 L
s
.519 .921 1 r
.45735 .4227 m .4504 .43795 L .46547 .44624 L p F P
0 0 1 r
s
.503 .877 1 r
.46135 .46211 m .46547 .44624 L .4504 .43795 L p F P
0 0 1 r
s
.24 .35 .67 r
.45488 .44855 m
.45511 .44836 L
s
.4649 .44698 m
.47976 .44465 L
s
.45488 .44855 m
.45518 .4485 L
s
0 0 0 r
.58082 .44295 m
.58139 .43572 L
s
.22 .384 .566 r
.5659 .48577 m .56657 .5005 L .58694 .49425 L p F P
0 0 1 r
s
.22 .384 .566 r
.58694 .49425 m .58594 .47956 L .5659 .48577 L p F P
0 0 1 r
s
.427 .803 1 r
.55277 .38634 m .54387 .37315 L .53764 .37522 L p F P
0 0 1 r
s
.415 .783 1 r
.54387 .37315 m .55277 .38634 L .56073 .38224 L p F P
0 0 1 r
s
.379 .708 1 r
.57129 .39549 m .56073 .38224 L .55277 .38634 L p F P
0 0 1 r
s
.24 .35 .67 r
.27128 .46654 m
.25431 .48521 L
s
.25431 .48521 m
.27135 .47515 L
s
.24368 .49421 m
.25431 .48521 L
s
.54 1 1 r
.49894 .36949 m .48691 .38101 L .49451 .38537 L p F P
0 0 1 r
s
.54 1 1 r
.49451 .38537 m .50411 .37249 L .49894 .36949 L p F P
0 0 1 r
s
.219 .391 .588 r
.58349 .46405 m .58594 .47956 L .60354 .47104 L p F P
0 0 1 r
s
.219 .391 .588 r
.60354 .47104 m .60038 .45579 L .58349 .46405 L p F P
0 0 1 r
s
.24 .35 .67 r
.54221 .46819 m
.59147 .45271 L
s
.28741 .45758 m
.27135 .47515 L
s
.27135 .47515 m
.29443 .46427 L
s
.35662 .44096 m
.35272 .4511 L
s
.35272 .4511 m
.39123 .43698 L
s
0 0 0 r
.60821 .54612 m
.63152 .5604 L
s
.63152 .5604 m
.63299 .54749 L
s
.493 .935 1 r
.52071 .36305 m .51682 .37621 L .52382 .37678 L p F P
0 0 1 r
s
.493 .935 1 r
.52382 .37678 m .52427 .36334 L .52071 .36305 L p F P
0 0 1 r
s
.481 .912 1 r
.52427 .36334 m .52382 .37678 L .53086 .37644 L p F P
0 0 1 r
s
.433 .741 1 r
.46135 .46211 m .4587 .47756 L .47819 .48439 L p F P
0 0 1 r
s
0 0 0 r
.46828 .44373 m
.49336 .46629 L
s
.405 .682 .931 r
.47743 .49912 m .47819 .48439 L .4587 .47756 L p F P
0 0 1 r
s
0 0 0 r
.45689 .48026 m
.47429 .49551 L
s
.47747 .49829 m
.48419 .50418 L
s
.362 .611 .847 r
.47819 .48439 m .47743 .49912 L .4991 .50349 L p F P
0 0 1 r
s
.328 .611 .934 r
.57129 .39549 m .58072 .40979 L .59085 .40206 L p F P
0 0 1 r
s
.292 .539 .827 r
.58072 .40979 m .58883 .42483 L .60047 .41605 L p F P
0 0 1 r
s
0 0 0 r
.55347 .41927 m
.58082 .44295 L
s
.292 .539 .827 r
.60047 .41605 m .59085 .40206 L .58072 .40979 L p F P
0 0 1 r
s
0 0 0 r
.52314 .43325 m
.53496 .44102 L
s
.53496 .44102 m
.52997 .41827 L
s
.481 .912 1 r
.53086 .37644 m .52785 .36317 L .52427 .36334 L p F P
0 0 1 r
s
.47 .892 1 r
.52785 .36317 m .53086 .37644 L .53764 .37522 L p F P
0 0 1 r
s
.292 .491 .688 r
.52179 .51856 m .52177 .5052 L .4991 .50349 L p F P
0 0 1 r
s
.24 .35 .67 r
.48724 .53241 m
.53747 .51957 L
s
.256 .434 .618 r
.52177 .5052 m .52179 .51856 L .5444 .51756 L p F P
0 0 1 r
s
.24 .35 .67 r
.48594 .52839 m
.52484 .51842 L
s
.256 .434 .618 r
.5444 .51756 m .54456 .50419 L .52177 .5052 L p F P
0 0 1 r
s
.366 .687 1 r
.56073 .38224 m .57129 .39549 L .57967 .38901 L p F P
0 0 1 r
s
.328 .611 .934 r
.59085 .40206 m .57967 .38901 L .57129 .39549 L p F P
0 0 1 r
s
.506 .961 1 r
.51733 .36231 m .51016 .37476 L .51682 .37621 L p F P
0 0 1 r
s
.506 .961 1 r
.51682 .37621 m .52071 .36305 L .51733 .36231 L p F P
0 0 1 r
s
.24 .35 .67 r
.47976 .44465 m
.49391 .42809 L
s
.47976 .44465 m
.50671 .43883 L
s
.26121 .47491 m
.24368 .49421 L
s
.2397 .50196 m
.24368 .49421 L
s
.257 .471 .723 r
.58883 .42483 m .59543 .44028 L .60831 .43067 L p F P
0 0 1 r
s
0 0 0 r
.58139 .43572 m
.58907 .44165 L
s
.257 .471 .723 r
.60831 .43067 m .60047 .41605 L .58883 .42483 L p F P
0 0 1 r
s
.223 .382 .551 r
.54456 .50419 m .5444 .51756 L .56625 .51393 L p F P
0 0 1 r
s
.223 .382 .551 r
.56625 .51393 m .56657 .5005 L .54456 .50419 L p F P
0 0 1 r
s
.24 .35 .67 r
.54004 .45624 m
.5375 .44387 L
s
.54004 .45624 m
.58313 .44261 L
s
.47 .892 1 r
.53764 .37522 m .53129 .36255 L .52785 .36317 L p F P
0 0 1 r
s
.46 .875 1 r
.53129 .36255 m .53764 .37522 L .54387 .37315 L p F P
0 0 1 r
s
.24 .35 .67 r
.30923 .4482 m
.29443 .46427 L
s
.29443 .46427 m
.32305 .45279 L
s
.503 .877 1 r
.4504 .43795 m .44519 .45332 L .46135 .46211 L p F P
0 0 1 r
s
.24 .35 .67 r
.46084 .44372 m
.47682 .43079 L
s
.43304 .45039 m
.44979 .43973 L
s
.48 .822 1 r
.4587 .47756 m .46135 .46211 L .44519 .45332 L p F P
0 0 1 r
s
0 0 0 r
.46022 .45398 m
.47763 .46949 L
s
.24 .35 .67 r
.45414 .53999 m
.44454 .54374 L
s
.44454 .54374 m
.49251 .53393 L
s
.575 1 1 r
.468 .38716 m .45644 .39985 L .46588 .40791 L p F P
0 0 1 r
s
.575 1 1 r
.46588 .40791 m .47581 .39391 L .468 .38716 L p F P
0 0 1 r
s
.573 1 1 r
.45735 .4227 m .46588 .40791 L .45644 .39985 L p F P
0 0 1 r
s
.519 .987 1 r
.51426 .36115 m .50411 .37249 L .51016 .37476 L p F P
0 0 1 r
s
.519 .987 1 r
.51016 .37476 m .51733 .36231 L .51426 .36115 L p F P
0 0 1 r
s
0 0 0 r
.67826 .48274 m
.66857 .47283 L
s
.6843 .49166 m
.67826 .48274 L
s
.67826 .48274 m
.66021 .44944 L
s
.24 .35 .67 r
.39123 .43698 m
.39376 .44327 L
s
.57 1 1 r
.48091 .37576 m .468 .38716 L .47581 .39391 L p F P
0 0 1 r
s
.57 1 1 r
.47581 .39391 m .48691 .38101 L .48091 .37576 L p F P
0 0 1 r
s
0 0 0 r
.66857 .47283 m
.65546 .46214 L
s
.66857 .47283 m
.65151 .44149 L
s
.24 .35 .67 r
.49251 .53393 m
.48944 .53428 L
s
.331 .551 .761 r
.49929 .51687 m .4991 .50349 L .47743 .49912 L p F P
0 0 1 r
s
.292 .491 .688 r
.4991 .50349 m .49929 .51687 L .52179 .51856 L p F P
0 0 1 r
s
.415 .783 1 r
.56073 .38224 m .54929 .37033 L .54387 .37315 L p F P
0 0 1 r
s
.405 .768 1 r
.54929 .37033 m .56073 .38224 L .56718 .3772 L p F P
0 0 1 r
s
.366 .687 1 r
.57967 .38901 m .56718 .3772 L .56073 .38224 L p F P
0 0 1 r
s
0 0 0 r
.52168 .54306 m
.5211 .55102 L
s
.4896 .53345 m
.48626 .53375 L
s
.573 1 1 r
.45644 .39985 m .44648 .41354 L .45735 .4227 L p F P
0 0 1 r
s
.565 1 1 r
.4504 .43795 m .45735 .4227 L .44648 .41354 L p F P
0 0 1 r
s
.24 .35 .67 r
.45307 .43764 m
.46182 .43207 L
s
.54541 .51754 m
.54544 .51739 L
s
0 0 0 r
.68657 .49939 m
.6843 .49166 L
s
.6843 .49166 m
.66565 .4572 L
s
.46 .875 1 r
.54387 .37315 m .53446 .36149 L .53129 .36255 L p F P
0 0 1 r
s
.452 .862 1 r
.53446 .36149 m .54387 .37315 L .54929 .37033 L p F P
0 0 1 r
s
0 0 0 r
.52168 .54306 m
.54421 .55695 L
s
.53995 .54341 m
.54421 .55695 L
s
.65546 .46214 m
.63919 .45091 L
s
.65546 .46214 m
.63976 .43353 L
s
.24 .35 .67 r
.25743 .48247 m
.2397 .50196 L
s
.2425 .50829 m
.2397 .50196 L
s
.56 1 1 r
.49488 .36589 m .48091 .37576 L .48691 .38101 L p F P
0 0 1 r
s
.56 1 1 r
.48691 .38101 m .49894 .36949 L .49488 .36589 L p F P
0 0 1 r
s
.224 .407 .624 r
.59543 .44028 m .60038 .45579 L .61419 .4456 L p F P
0 0 1 r
s
.224 .407 .624 r
.61419 .4456 m .60831 .43067 L .59543 .44028 L p F P
0 0 1 r
s
0 0 0 r
.57952 .42678 m
.59793 .43847 L
s
.531 1 1 r
.51164 .35962 m .49894 .36949 L .50411 .37249 L p F P
0 0 1 r
s
.531 1 1 r
.50411 .37249 m .51426 .36115 L .51164 .35962 L p F P
0 0 1 r
s
.24 .35 .67 r
.28586 .53078 m
.29103 .54142 L
s
.31905 .53794 m
.29103 .54142 L
s
.33623 .43864 m
.32305 .45279 L
s
.32305 .45279 m
.35662 .44096 L
s
.19 .335 .503 r
.58594 .47956 m .58694 .49425 L .60483 .48566 L p F P
0 0 1 r
s
.24 .35 .67 r
.56313 .49364 m
.58894 .48568 L
s
.19 .335 .503 r
.60483 .48566 m .60354 .47104 L .58594 .47956 L p F P
0 0 1 r
s
.24 .35 .67 r
.54395 .47944 m
.5982 .46251 L
s
0 0 0 r
.6503 .53717 m
.66741 .54055 L
s
.66741 .54055 m
.65755 .51522 L
s
.191 .331 .486 r
.56657 .5005 m .56625 .51393 L .58645 .50777 L p F P
0 0 1 r
s
.191 .331 .486 r
.58645 .50777 m .58694 .49425 L .56657 .5005 L p F P
0 0 1 r
s
.24 .35 .67 r
.35298 .54808 m
.38107 .5485 L
s
.40427 .54094 m
.38107 .5485 L
s
.38107 .5485 m
.41522 .54577 L
s
0 0 0 r
.5537 .41553 m
.58139 .43572 L
s
.58139 .43572 m
.57952 .42678 L
s
.24 .35 .67 r
.33203 .54452 m
.35298 .54808 L
s
.38073 .54059 m
.35298 .54808 L
s
.26824 .51607 m
.26308 .53083 L
s
.28586 .53078 m
.26308 .53083 L
s
.565 1 1 r
.44648 .41354 m .43836 .42792 L .4504 .43795 L p F P
0 0 1 r
s
.548 .963 1 r
.44519 .45332 m .4504 .43795 L .43836 .42792 L p F P
0 0 1 r
s
.24 .35 .67 r
.40185 .4477 m
.43914 .4308 L
s
.41513 .4501 m
.44068 .43656 L
s
.44794 .43272 m
.44953 .43187 L
s
.452 .862 1 r
.54929 .37033 m .5372 .36005 L .53446 .36149 L p F P
0 0 1 r
s
.445 .851 1 r
.5372 .36005 m .54929 .37033 L .55366 .36688 L p F P
0 0 1 r
s
.405 .768 1 r
.56718 .3772 m .55366 .36688 L .54929 .37033 L p F P
0 0 1 r
s
.24 .35 .67 r
.50671 .43883 m
.51239 .42407 L
s
.50671 .43883 m
.53463 .43132 L
s
0 0 0 r
.68498 .50574 m
.68657 .49939 L
s
.68657 .49939 m
.66769 .46459 L
s
.405 .682 .931 r
.4587 .47756 m .45762 .49223 L .47743 .49912 L p F P
0 0 1 r
s
0 0 0 r
.45794 .49234 m
.48261 .51381 L
s
.37 .613 .836 r
.47779 .51256 m .47743 .49912 L .45762 .49223 L p F P
0 0 1 r
s
.331 .551 .761 r
.47743 .49912 m .47779 .51256 L .49929 .51687 L p F P
0 0 1 r
s
0 0 0 r
.48832 .42313 m
.50509 .43855 L
s
.50509 .43855 m
.51128 .42388 L
s
.355 .671 1 r
.56718 .3772 m .57967 .38901 L .58573 .38159 L p F P
0 0 1 r
s
.314 .588 .912 r
.57967 .38901 m .59085 .40206 L .5982 .39318 L p F P
0 0 1 r
s
.314 .588 .912 r
.5982 .39318 m .58573 .38159 L .57967 .38901 L p F P
0 0 1 r
s
0 0 0 r
.63919 .45091 m
.62013 .43939 L
s
.24 .35 .67 r
.5375 .44387 m
.53463 .43132 L
s
.5375 .44387 m
.57336 .43243 L
s
.48 .822 1 r
.44519 .45332 m .44186 .46848 L .4587 .47756 L p F P
0 0 1 r
s
.448 .754 1 r
.45762 .49223 m .4587 .47756 L .44186 .46848 L p F P
0 0 1 r
s
0 0 0 r
.45371 .4639 m
.46184 .47108 L
s
.45226 .48739 m
.45736 .49183 L
s
.4459 .48186 m
.45226 .48739 L
s
.543 1 1 r
.5096 .35779 m .49488 .36589 L .49894 .36949 L p F P
0 0 1 r
s
.543 1 1 r
.49894 .36949 m .51164 .35962 L .5096 .35779 L p F P
0 0 1 r
s
.397 .756 1 r
.55366 .36688 m .56718 .3772 L .57182 .37143 L p F P
0 0 1 r
s
.355 .671 1 r
.58573 .38159 m .57182 .37143 L .56718 .3772 L p F P
0 0 1 r
s
0 0 0 r
.572 .55686 m
.58525 .55894 L
s
.58525 .55894 m
.59596 .5578 L
s
.274 .51 .794 r
.59085 .40206 m .60047 .41605 L .60896 .40594 L p F P
0 0 1 r
s
.274 .51 .794 r
.60896 .40594 m .5982 .39318 L .59085 .40206 L p F P
0 0 1 r
s
0 0 0 r
.51128 .42388 m
.52314 .43325 L
s
.52314 .43325 m
.52392 .41425 L
s
.191 .344 .527 r
.60038 .45579 m .60354 .47104 L .61796 .4605 L p F P
0 0 1 r
s
.191 .344 .527 r
.61796 .4605 m .61419 .4456 L .60038 .45579 L p F P
0 0 1 r
s
.502 .968 1 r
.52427 .36334 m .52474 .35163 L .52071 .36305 L closepath p F P
0 0 1 r
s
.498 .959 1 r
.52785 .36317 m .52474 .35163 L .52427 .36334 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.43293 .53865 m
.41522 .54577 L
s
.41522 .54577 m
.45414 .53999 L
s
.26009 .48906 m
.2425 .50829 L
s
.25206 .51303 m
.2425 .50829 L
s
.39442 .42906 m
.39123 .43698 L
s
.494 .952 1 r
.53129 .36255 m .52474 .35163 L .52785 .36317 L closepath p F P
0 0 1 r
s
.506 .977 1 r
.52071 .36305 m .52474 .35163 L .51733 .36231 L closepath p F P
0 0 1 r
s
.595 1 1 r
.47678 .36984 m .46259 .37954 L .468 .38716 L p F P
0 0 1 r
s
.595 1 1 r
.468 .38716 m .48091 .37576 L .47678 .36984 L p F P
0 0 1 r
s
.606 1 1 r
.45644 .39985 m .468 .38716 L .46259 .37954 L p F P
0 0 1 r
s
.259 .429 .601 r
.52189 .53018 m .52179 .51856 L .49929 .51687 L p F P
0 0 1 r
s
.24 .35 .67 r
.48944 .53428 m
.51693 .52726 L
s
.225 .377 .535 r
.52179 .51856 m .52189 .53018 L .54378 .52923 L p F P
0 0 1 r
s
.225 .377 .535 r
.54378 .52923 m .5444 .51756 L .52179 .51856 L p F P
0 0 1 r
s
.24 .35 .67 r
.54439 .5178 m
.54541 .51754 L
s
0 0 0 r
.59596 .5578 m
.60372 .55348 L
s
.577 1 1 r
.49209 .36184 m .47678 .36984 L .48091 .37576 L p F P
0 0 1 r
s
.577 1 1 r
.48091 .37576 m .49488 .36589 L .49209 .36184 L p F P
0 0 1 r
s
.49 .945 1 r
.53446 .36149 m .52474 .35163 L .53129 .36255 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.44953 .43187 m
.46182 .43207 L
s
.46182 .43207 m
.4926 .41364 L
s
.46182 .43207 m
.47682 .43079 L
s
.511 .986 1 r
.51733 .36231 m .52474 .35163 L .51426 .36115 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.44653 .43132 m
.44953 .43187 L
s
.44953 .43187 m
.48633 .41354 L
s
.445 .851 1 r
.55366 .36688 m .53941 .35829 L .5372 .36005 L p F P
0 0 1 r
s
.44 .844 1 r
.53941 .35829 m .55366 .36688 L .55679 .36293 L p F P
0 0 1 r
s
.397 .756 1 r
.57182 .37143 m .55679 .36293 L .55366 .36688 L p F P
0 0 1 r
s
.24 .35 .67 r
.31905 .53794 m
.33203 .54452 L
s
.36321 .53759 m
.33203 .54452 L
s
.193 .326 .471 r
.5444 .51756 m .54378 .52923 L .56492 .52573 L p F P
0 0 1 r
s
.24 .35 .67 r
.53173 .52348 m
.54419 .5203 L
s
.193 .326 .471 r
.56492 .52573 m .56625 .51393 L .5444 .51756 L p F P
0 0 1 r
s
.24 .35 .67 r
.54419 .5203 m
.54529 .51781 L
s
0 0 0 r
.55671 .55162 m
.572 .55686 L
s
.606 1 1 r
.46259 .37954 m .44986 .39073 L .45644 .39985 L p F P
0 0 1 r
s
.608 1 1 r
.44648 .41354 m .45644 .39985 L .44986 .39073 L p F P
0 0 1 r
s
.235 .435 .678 r
.60047 .41605 m .60831 .43067 L .61773 .4196 L p F P
0 0 1 r
s
0 0 0 r
.59866 .42783 m
.60212 .43641 L
s
.235 .435 .678 r
.61773 .4196 m .60896 .40594 L .60047 .41605 L p F P
0 0 1 r
s
.24 .35 .67 r
.36781 .42911 m
.35662 .44096 L
s
.35662 .44096 m
.39442 .42906 L
s
.487 .939 1 r
.5372 .36005 m .52474 .35163 L .53446 .36149 L closepath p F P
0 0 1 r
s
.515 .994 1 r
.51426 .36115 m .52474 .35163 L .51164 .35962 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.47682 .43079 m
.50027 .41298 L
s
.47682 .43079 m
.49391 .42809 L
s
.293 .482 .665 r
.50011 .52856 m .49929 .51687 L .47779 .51256 L p F P
0 0 1 r
s
0 0 0 r
.44934 .49344 m
.45185 .49561 L
s
.45185 .49561 m
.48202 .52175 L
s
.259 .429 .601 r
.49929 .51687 m .50011 .52856 L .52189 .53018 L p F P
0 0 1 r
s
.552 1 1 r
.5082 .35572 m .49209 .36184 L .49488 .36589 L p F P
0 0 1 r
s
.552 1 1 r
.49488 .36589 m .5096 .35779 L .5082 .35572 L p F P
0 0 1 r
s
.548 .963 1 r
.43836 .42792 m .43228 .44268 L .44519 .45332 L p F P
0 0 1 r
s
.521 .897 1 r
.44186 .46848 m .44519 .45332 L .43228 .44268 L p F P
0 0 1 r
s
.24 .35 .67 r
.39376 .44327 m
.43498 .42714 L
s
0 0 0 r
.67954 .51058 m
.68498 .50574 L
s
.68498 .50574 m
.66626 .47142 L
s
.24 .35 .67 r
.43498 .42714 m
.43799 .42883 L
s
0 0 0 r
.45371 .4639 m
.46022 .45398 L
s
.44985 .47141 m
.45371 .4639 L
s
.484 .935 1 r
.53941 .35829 m .52474 .35163 L .5372 .36005 L closepath p F P
0 0 1 r
s
0 0 0 r
.4459 .48186 m
.44757 .47708 L
s
.518 1 1 r
.51164 .35962 m .52474 .35163 L .5096 .35779 L closepath p F P
0 0 1 r
s
.16 .278 .419 r
.58694 .49425 m .58645 .50777 L .60421 .49931 L p F P
0 0 1 r
s
.24 .35 .67 r
.56329 .50772 m
.58921 .49979 L
s
.16 .278 .419 r
.60421 .49931 m .60483 .48566 L .58694 .49425 L p F P
0 0 1 r
s
.24 .35 .67 r
.56657 .5005 m
.58694 .49425 L
s
.60469 .4888 m
.60746 .48795 L
s
.54744 .48907 m
.60094 .47248 L
s
0 0 0 r
.46022 .45398 m
.46828 .44373 L
s
.24 .35 .67 r
.51403 .52844 m
.54249 .52118 L
s
.51019 .52942 m
.51052 .52933 L
s
.49251 .53393 m
.51019 .52942 L
s
.608 1 1 r
.44986 .39073 m .43888 .40316 L .44648 .41354 L p F P
0 0 1 r
s
.599 1 1 r
.43836 .42792 m .44648 .41354 L .43888 .40316 L p F P
0 0 1 r
s
.24 .35 .67 r
.44378 .42879 m
.48171 .41268 L
s
.59147 .45271 m
.5982 .46251 L
s
.5982 .46251 m
.60269 .47087 L
s
.482 .932 1 r
.54098 .35628 m .52474 .35163 L .53941 .35829 L closepath p F P
0 0 1 r
s
.44 .844 1 r
.55679 .36293 m .54098 .35628 L .53941 .35829 L p F P
0 0 1 r
s
.391 .748 1 r
.55679 .36293 m .57182 .37143 L .57444 .36517 L p F P
0 0 1 r
s
.346 .656 1 r
.57182 .37143 m .58573 .38159 L .58918 .37352 L p F P
0 0 1 r
s
.346 .656 1 r
.58918 .37352 m .57444 .36517 L .57182 .37143 L p F P
0 0 1 r
s
.24 .35 .67 r
.49391 .42809 m
.50901 .41159 L
s
.49391 .42809 m
.51239 .42407 L
s
.59147 .45271 m
.58313 .44261 L
s
.436 .84 1 r
.54098 .35628 m .55679 .36293 L .55853 .35865 L p F P
0 0 1 r
s
.391 .748 1 r
.57444 .36517 m .55853 .35865 L .55679 .36293 L p F P
0 0 1 r
s
0 0 0 r
.60372 .55348 m
.60821 .54612 L
s
.197 .361 .564 r
.60831 .43067 m .61419 .4456 L .62432 .43385 L p F P
0 0 1 r
s
0 0 0 r
.6199 .43898 m
.62013 .43939 L
s
.61973 .43918 m
.62013 .43939 L
s
.197 .361 .564 r
.62432 .43385 m .61773 .4196 L .60831 .43067 L p F P
0 0 1 r
s
0 0 0 r
.59866 .42783 m
.60949 .43366 L
s
.161 .273 .404 r
.56625 .51393 m .56492 .52573 L .58448 .51981 L p F P
0 0 1 r
s
.161 .273 .404 r
.58448 .51981 m .58645 .50777 L .56625 .51393 L p F P
0 0 1 r
s
.52 1 1 r
.5096 .35779 m .52474 .35163 L .5082 .35572 L closepath p F P
0 0 1 r
s
.159 .281 .433 r
.60354 .47104 m .60483 .48566 L .6195 .47504 L p F P
0 0 1 r
s
.159 .281 .433 r
.6195 .47504 m .61796 .4605 L .60354 .47104 L p F P
0 0 1 r
s
.24 .35 .67 r
.5982 .46251 m
.60991 .45822 L
s
0 0 0 r
.60922 .53596 m
.63299 .54749 L
s
.63299 .54749 m
.62991 .53141 L
s
.448 .754 1 r
.44186 .46848 m .4405 .48308 L .45762 .49223 L p F P
0 0 1 r
s
.405 .668 .899 r
.45815 .50579 m .45762 .49223 L .4405 .48308 L p F P
0 0 1 r
s
0 0 0 r
.44477 .48949 m
.44693 .49136 L
s
.44477 .48949 m
.44488 .48872 L
s
.45192 .50147 m
.45195 .5015 L
s
.44556 .49598 m
.45192 .50147 L
s
.37 .613 .836 r
.45762 .49223 m .45815 .50579 L .47779 .51256 L p F P
0 0 1 r
s
.24 .35 .67 r
.53463 .43132 m
.5315 .41889 L
s
.53463 .43132 m
.56239 .42241 L
s
.43979 .42538 m
.47895 .4111 L
s
.43498 .42714 m
.43841 .42589 L
s
.3 .566 .888 r
.58573 .38159 m .5982 .39318 L .60244 .38351 L p F P
0 0 1 r
s
.3 .566 .888 r
.60244 .38351 m .58918 .37352 L .58573 .38159 L p F P
0 0 1 r
s
0 0 0 r
.44386 .41802 m
.46828 .44373 L
s
.46828 .44373 m
.47771 .43337 L
s
.24 .35 .67 r
.26915 .49451 m
.25206 .51303 L
s
.26824 .51607 m
.25206 .51303 L
s
0 0 0 r
.57952 .42678 m
.55268 .41092 L
s
.57952 .42678 m
.57526 .41649 L
s
.558 1 1 r
.50753 .35353 m .49073 .35751 L .49209 .36184 L p F P
0 0 1 r
s
.558 1 1 r
.49209 .36184 m .5082 .35572 L .50753 .35353 L p F P
0 0 1 r
s
.588 1 1 r
.47678 .36984 m .49209 .36184 L .49073 .35751 L p F P
0 0 1 r
s
.588 1 1 r
.49073 .35751 m .47471 .3635 L .47678 .36984 L p F P
0 0 1 r
s
.61 1 1 r
.46259 .37954 m .47678 .36984 L .47471 .3635 L p F P
0 0 1 r
s
0 0 0 r
.54107 .42327 m
.54567 .42405 L
s
.54567 .42405 m
.52474 .39553 L
s
.54567 .42405 m
.54936 .42362 L
s
.325 .53 .723 r
.47929 .52442 m .47779 .51256 L .45815 .50579 L p F P
0 0 1 r
s
.293 .482 .665 r
.47779 .51256 m .47929 .52442 L .50011 .52856 L p F P
0 0 1 r
s
0 0 0 r
.45195 .5015 m
.48244 .52781 L
s
.4587 .51017 m
.48386 .53184 L
s
.48 .931 1 r
.54184 .3541 m .52474 .35163 L .54098 .35628 L closepath p F P
0 0 1 r
s
.436 .84 1 r
.55853 .35865 m .54184 .3541 L .54098 .35628 L p F P
0 0 1 r
s
0 0 0 r
.54936 .42362 m
.52474 .39553 L
s
.54936 .42362 m
.552 .42201 L
s
.24 .35 .67 r
.60688 .48417 m
.60746 .48795 L
s
.58313 .44261 m
.57336 .43243 L
s
0 0 0 r
.53995 .54341 m
.55671 .55162 L
s
.53577 .42132 m
.54107 .42327 L
s
.54107 .42327 m
.52474 .39553 L
s
.522 1 1 r
.5082 .35572 m .52474 .35163 L .50753 .35353 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.29075 .51732 m
.28586 .53078 L
s
.31465 .52857 m
.28586 .53078 L
s
.61 1 1 r
.47471 .3635 m .45985 .37136 L .46259 .37954 L p F P
0 0 1 r
s
.622 1 1 r
.44986 .39073 m .46259 .37954 L .45985 .37136 L p F P
0 0 1 r
s
.599 1 1 r
.43888 .40316 m .42992 .41655 L .43836 .42792 L p F P
0 0 1 r
s
.575 1 1 r
.43228 .44268 m .43836 .42792 L .42992 .41655 L p F P
0 0 1 r
s
.24 .35 .67 r
.39123 .43698 m
.43057 .42373 L
s
.40328 .41982 m
.39442 .42906 L
s
.43376 .41788 m
.43566 .41734 L
s
.521 .897 1 r
.43228 .44268 m .42838 .45749 L .44186 .46848 L p F P
0 0 1 r
s
.478 .808 1 r
.4405 .48308 m .44186 .46848 L .42838 .45749 L p F P
0 0 1 r
s
.254 .477 .754 r
.5982 .39318 m .60896 .40594 L .61388 .39493 L p F P
0 0 1 r
s
.254 .477 .754 r
.61388 .39493 m .60244 .38351 L .5982 .39318 L p F P
0 0 1 r
s
.24 .35 .67 r
.31465 .52857 m
.31905 .53794 L
s
.35244 .53206 m
.31905 .53794 L
s
0 0 0 r
.552 .42201 m
.52474 .39553 L
s
.552 .42201 m
.55347 .41927 L
s
.4436 .4883 m
.44477 .48949 L
s
.44477 .48949 m
.44556 .49598 L
s
.67034 .51377 m
.67954 .51058 L
s
.67954 .51058 m
.66136 .47754 L
s
.24 .35 .67 r
.54249 .52118 m
.54419 .5203 L
s
.48 .931 1 r
.54196 .35187 m .52474 .35163 L .54184 .3541 L closepath p F P
0 0 1 r
s
.434 .839 1 r
.54184 .3541 m .55853 .35865 L .55881 .35424 L p F P
0 0 1 r
s
.434 .839 1 r
.55881 .35424 m .54196 .35187 L .54184 .3541 L p F P
0 0 1 r
s
.24 .35 .67 r
.51239 .42407 m
.51845 .40952 L
s
.51239 .42407 m
.5315 .41889 L
s
0 0 0 r
.49987 .41326 m
.51128 .42388 L
s
.51128 .42388 m
.51788 .40942 L
s
.52997 .41827 m
.53577 .42132 L
s
.53577 .42132 m
.52474 .39553 L
s
.62991 .53141 m
.6503 .53717 L
s
.6503 .53717 m
.64141 .51487 L
s
.59866 .42783 m
.57526 .41649 L
s
.58933 .41145 m
.59866 .42783 L
s
.386 .742 1 r
.55853 .35865 m .57444 .36517 L .5749 .35869 L p F P
0 0 1 r
s
.386 .742 1 r
.5749 .35869 m .55881 .35424 L .55853 .35865 L p F P
0 0 1 r
s
0 0 0 r
.45754 .41188 m
.47771 .43337 L
s
.47771 .43337 m
.48832 .42313 L
s
.522 1 1 r
.50753 .35353 m .52474 .35163 L .50761 .35129 L closepath p F P
0 0 1 r
s
.559 1 1 r
.49073 .35751 m .50753 .35353 L .50761 .35129 L p F P
0 0 1 r
s
.24 .35 .67 r
.31409 .43799 m
.28741 .45758 L
s
.28741 .45758 m
.30923 .4482 L
s
.27128 .46654 m
.28741 .45758 L
s
.482 .94 1 r
.53793 .34572 m .52474 .35163 L .53996 .34758 L closepath p F P
0 0 1 r
s
.484 .945 1 r
.53531 .34417 m .52474 .35163 L .53793 .34572 L closepath p F P
0 0 1 r
s
.519 1 1 r
.50843 .3491 m .52474 .35163 L .50998 .34707 L closepath p F P
0 0 1 r
s
.521 1 1 r
.50761 .35129 m .52474 .35163 L .50843 .3491 L closepath p F P
0 0 1 r
s
.48 .932 1 r
.54133 .34966 m .52474 .35163 L .54196 .35187 L closepath p F P
0 0 1 r
s
.481 .935 1 r
.53996 .34758 m .52474 .35163 L .54133 .34966 L closepath p F P
0 0 1 r
s
.487 .952 1 r
.53223 .34298 m .52474 .35163 L .53531 .34417 L closepath p F P
0 0 1 r
s
.491 .96 1 r
.52881 .34222 m .52474 .35163 L .53223 .34298 L closepath p F P
0 0 1 r
s
.495 .968 1 r
.52521 .34193 m .52474 .35163 L .52881 .34222 L closepath p F P
0 0 1 r
s
.499 .977 1 r
.52159 .3421 m .52474 .35163 L .52521 .34193 L closepath p F P
0 0 1 r
s
.504 .986 1 r
.51811 .34274 m .52474 .35163 L .52159 .3421 L closepath p F P
0 0 1 r
s
.508 .995 1 r
.51492 .34382 m .52474 .35163 L .51811 .34274 L closepath p F P
0 0 1 r
s
.513 1 1 r
.51217 .34529 m .52474 .35163 L .51492 .34382 L closepath p F P
0 0 1 r
s
.516 1 1 r
.50998 .34707 m .52474 .35163 L .51217 .34529 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.33365 .43035 m
.30923 .4482 L
s
.30923 .4482 m
.33623 .43864 L
s
.218 .356 .498 r
.52205 .53978 m .52189 .53018 L .50011 .52856 L p F P
0 0 1 r
s
.188 .31 .44 r
.52189 .53018 m .52205 .53978 L .54268 .53888 L p F P
0 0 1 r
s
.188 .31 .44 r
.54268 .53888 m .54378 .52923 L .52189 .53018 L p F P
0 0 1 r
s
.158 .286 .45 r
.61419 .4456 m .61796 .4605 L .62854 .44836 L p F P
0 0 1 r
s
.24 .35 .67 r
.62464 .45283 m
.62603 .45232 L
s
.158 .286 .45 r
.62854 .44836 m .62432 .43385 L .61419 .4456 L p F P
0 0 1 r
s
.24 .35 .67 r
.59147 .45271 m
.6182 .44285 L
s
.62609 .43995 m
.63196 .43778 L
s
.43489 .41915 m
.43566 .41734 L
s
.57336 .43243 m
.56239 .42241 L
s
.57336 .43243 m
.60761 .41961 L
s
.2996 .44572 m
.27128 .46654 L
s
.26121 .47491 m
.27128 .46654 L
s
.559 1 1 r
.50761 .35129 m .49084 .35309 L .49073 .35751 L p F P
0 0 1 r
s
.589 1 1 r
.47471 .3635 m .49073 .35751 L .49084 .35309 L p F P
0 0 1 r
s
.622 1 1 r
.45985 .37136 m .44648 .38092 L .44986 .39073 L p F P
0 0 1 r
s
.618 1 1 r
.43888 .40316 m .44986 .39073 L .44648 .38092 L p F P
0 0 1 r
s
.335 .641 1 r
.57444 .36517 m .58918 .37352 L .58985 .36514 L p F P
0 0 1 r
s
.335 .641 1 r
.58985 .36514 m .5749 .35869 L .57444 .36517 L p F P
0 0 1 r
s
.433 .84 1 r
.54196 .35187 m .55881 .35424 L .55759 .34987 L p F P
0 0 1 r
s
.433 .84 1 r
.55759 .34987 m .54133 .34966 L .54196 .35187 L p F P
0 0 1 r
s
.24 .35 .67 r
.3578 .42296 m
.33623 .43864 L
s
.33623 .43864 m
.36781 .42911 L
s
.157 .259 .376 r
.54378 .52923 m .54268 .53888 L .56261 .53561 L p F P
0 0 1 r
s
.157 .259 .376 r
.56261 .53561 m .56492 .52573 L .54378 .52923 L p F P
0 0 1 r
s
0 0 0 r
.55347 .41927 m
.52474 .39553 L
s
.55347 .41927 m
.5537 .41553 L
s
.555 1 1 r
.49084 .35309 m .50761 .35129 L .50843 .3491 L p F P
0 0 1 r
s
.208 .389 .616 r
.60896 .40594 m .61773 .4196 L .62323 .40753 L p F P
0 0 1 r
s
0 0 0 r
.6083 .41834 m
.61501 .43027 L
s
.208 .389 .616 r
.62323 .40753 m .61388 .39493 L .60896 .40594 L p F P
0 0 1 r
s
.127 .212 .327 r
.58645 .50777 m .58448 .51981 L .60165 .51168 L p F P
0 0 1 r
s
.127 .212 .327 r
.60165 .51168 m .60421 .49931 L .58645 .50777 L p F P
0 0 1 r
s
.24 .35 .67 r
.54763 .51686 m
.60158 .5004 L
s
.245 .398 .547 r
.50152 .53826 m .50011 .52856 L .47929 .52442 L p F P
0 0 1 r
s
0 0 0 r
.50125 .53638 m
.5211 .55102 L
s
.47995 .52511 m
.4896 .53345 L
s
.46599 .51628 m
.46627 .51653 L
s
.46627 .51653 m
.48626 .53375 L
s
.24 .35 .67 r
.45414 .53999 m
.49188 .53226 L
s
0 0 0 r
.4896 .53345 m
.49174 .53217 L
s
.24 .35 .67 r
.49251 .53393 m
.4935 .53326 L
s
.218 .356 .498 r
.50011 .52856 m .50152 .53826 L .52205 .53978 L p F P
0 0 1 r
s
0 0 0 r
.52168 .54306 m
.52189 .53977 L
s
.52202 .53784 m
.52236 .53249 L
s
.51672 .53938 m
.52168 .54306 L
s
.52392 .41425 m
.52997 .41827 L
s
.52997 .41827 m
.52474 .39553 L
s
.123 .211 .334 r
.60483 .48566 m .60421 .49931 L .61875 .48886 L p F P
0 0 1 r
s
.123 .211 .334 r
.61875 .48886 m .6195 .47504 L .60483 .48566 L p F P
0 0 1 r
s
.24 .35 .67 r
.29054 .45335 m
.26121 .47491 L
s
.25743 .48247 m
.26121 .47491 L
s
.589 1 1 r
.49084 .35309 m .47482 .35701 L .47471 .3635 L p F P
0 0 1 r
s
.606 1 1 r
.45985 .37136 m .47471 .3635 L .47482 .35701 L p F P
0 0 1 r
s
.24 .35 .67 r
.38073 .54059 m
.40427 .54094 L
s
.43081 .53082 m
.40427 .54094 L
s
.40427 .54094 m
.43293 .53865 L
s
.36321 .53759 m
.38073 .54059 L
s
.41246 .53054 m
.38073 .54059 L
s
0 0 0 r
.60821 .54612 m
.60922 .53596 L
s
.432 .842 1 r
.54133 .34966 m .55759 .34987 L .55492 .34575 L p F P
0 0 1 r
s
.432 .842 1 r
.55492 .34575 m .53996 .34758 L .54133 .34966 L p F P
0 0 1 r
s
.575 1 1 r
.42992 .41655 m .4232 .43061 L .43228 .44268 L p F P
0 0 1 r
s
.24 .35 .67 r
.39442 .42906 m
.42858 .41935 L
s
.53 .925 1 r
.42838 .45749 m .43228 .44268 L .4232 .43061 L p F P
0 0 1 r
s
0 0 0 r
.43212 .42472 m
.46022 .45398 L
s
.40949 .45381 m
.41071 .45504 L
s
.24 .35 .67 r
.28447 .49869 m
.26824 .51607 L
s
.29075 .51732 m
.26824 .51607 L
s
.38 .735 1 r
.55881 .35424 m .5749 .35869 L .57316 .35227 L p F P
0 0 1 r
s
.38 .735 1 r
.57316 .35227 m .55759 .34987 L .55881 .35424 L p F P
0 0 1 r
s
.24 .35 .67 r
.38598 .416 m
.36781 .42911 L
s
.36781 .42911 m
.40328 .41982 L
s
.546 1 1 r
.49244 .34877 m .50843 .3491 L .50998 .34707 L p F P
0 0 1 r
s
.555 1 1 r
.50843 .3491 m .49244 .34877 L .49084 .35309 L p F P
0 0 1 r
s
.282 .537 .85 r
.58918 .37352 m .60244 .38351 L .60331 .37346 L p F P
0 0 1 r
s
.282 .537 .85 r
.60331 .37346 m .58985 .36514 L .58918 .37352 L p F P
0 0 1 r
s
.405 .668 .899 r
.4405 .48308 m .44116 .49678 L .45815 .50579 L p F P
0 0 1 r
s
.344 .56 .752 r
.46028 .5179 m .45815 .50579 L .44116 .49678 L p F P
0 0 1 r
s
.325 .53 .723 r
.45815 .50579 m .46028 .5179 L .47929 .52442 L p F P
0 0 1 r
s
0 0 0 r
.47905 .52433 m
.47995 .52511 L
s
.47284 .40645 m
.48832 .42313 L
s
.48832 .42313 m
.49987 .41326 L
s
.24 .35 .67 r
.5315 .41889 m
.52818 .40687 L
s
.5315 .41889 m
.55044 .41276 L
s
.618 1 1 r
.44648 .38092 m .43494 .39198 L .43888 .40316 L p F P
0 0 1 r
s
.593 1 1 r
.42992 .41655 m .43888 .40316 L .43494 .39198 L p F P
0 0 1 r
s
.24 .35 .67 r
.43697 .42167 m
.47818 .40887 L
s
.576 1 1 r
.47482 .35701 m .49084 .35309 L .49244 .34877 L p F P
0 0 1 r
s
.24 .35 .67 r
.56239 .42241 m
.55044 .41276 L
s
.56239 .42241 m
.5888 .41244 L
s
.124 .201 .303 r
.56492 .52573 m .56261 .53561 L .58103 .53006 L p F P
0 0 1 r
s
.124 .201 .303 r
.58103 .53006 m .58448 .51981 L .56492 .52573 L p F P
0 0 1 r
s
0 0 0 r
.5537 .41553 m
.52474 .39553 L
s
.5537 .41553 m
.55268 .41092 L
s
.24 .35 .67 r
.45318 .52902 m
.43293 .53865 L
s
.432 .845 1 r
.53996 .34758 m .55492 .34575 L .55092 .34205 L p F P
0 0 1 r
s
.432 .845 1 r
.55092 .34205 m .53793 .34572 L .53996 .34758 L p F P
0 0 1 r
s
.478 .808 1 r
.42838 .45749 m .42678 .472 L .4405 .48308 L p F P
0 0 1 r
s
.414 .687 .911 r
.44116 .49678 m .4405 .48308 L .42678 .472 L p F P
0 0 1 r
s
.532 1 1 r
.49547 .34474 m .50998 .34707 L .51217 .34529 L p F P
0 0 1 r
s
.546 1 1 r
.50998 .34707 m .49547 .34474 L .49244 .34877 L p F P
0 0 1 r
s
0 0 0 r
.65755 .51522 m
.67034 .51377 L
s
.67034 .51377 m
.65309 .48279 L
s
.24 .35 .67 r
.43566 .41734 m
.44185 .41099 L
s
.43566 .41734 m
.47942 .40607 L
s
.28715 .4607 m
.25743 .48247 L
s
.26009 .48906 m
.25743 .48247 L
s
.606 1 1 r
.47482 .35701 m .45992 .36297 L .45985 .37136 L p F P
0 0 1 r
s
.604 1 1 r
.44648 .38092 m .45985 .37136 L .45992 .36297 L p F P
0 0 1 r
s
0 0 0 r
.52236 .53249 m
.53247 .53876 L
s
.53332 .53929 m
.53995 .54341 L
s
.51788 .40942 m
.52392 .41425 L
s
.52392 .41425 m
.52474 .39553 L
s
.24 .35 .67 r
.35244 .53206 m
.36321 .53759 L
s
.39885 .52819 m
.36321 .53759 L
s
.263 .425 .576 r
.48191 .53438 m .47929 .52442 L .46028 .5179 L p F P
0 0 1 r
s
.24 .35 .67 r
.43293 .53865 m
.46559 .53378 L
s
.45414 .53999 m
.46559 .53378 L
s
.245 .398 .547 r
.47929 .52442 m .48191 .53438 L .50152 .53826 L p F P
0 0 1 r
s
0 0 0 r
.49423 .53054 m
.49887 .52615 L
s
.24 .35 .67 r
.49778 .53098 m
.54034 .52011 L
s
.49671 .531 m
.501 .52651 L
s
.115 .205 .334 r
.61796 .4605 m .6195 .47504 L .63027 .4628 L p F P
0 0 1 r
s
.115 .205 .334 r
.63027 .4628 m .62854 .44836 L .61796 .4605 L p F P
0 0 1 r
s
.24 .35 .67 r
.63017 .46197 m
.65903 .45147 L
s
.159 .296 .474 r
.61773 .4196 m .62432 .43385 L .63025 .42102 L p F P
0 0 1 r
s
0 0 0 r
.62724 .42935 m
.63919 .45091 L
s
.62678 .42852 m
.62724 .42935 L
s
.24 .35 .67 r
.58313 .44261 m
.62307 .42777 L
s
.159 .296 .474 r
.63025 .42102 m .62323 .40753 L .61773 .4196 L p F P
0 0 1 r
s
0 0 0 r
.57526 .41649 m
.55043 .40564 L
s
.57526 .41649 m
.56875 .40526 L
s
.24 .35 .67 r
.48633 .41354 m
.4926 .41364 L
s
.4926 .41364 m
.52474 .39553 L
s
.4926 .41364 m
.50027 .41298 L
s
.433 .85 1 r
.53793 .34572 m .55092 .34205 L .54574 .33896 L p F P
0 0 1 r
s
.433 .85 1 r
.54574 .33896 m .53531 .34417 L .53793 .34572 L p F P
0 0 1 r
s
.24 .35 .67 r
.48171 .41268 m
.48633 .41354 L
s
.48633 .41354 m
.52474 .39553 L
s
.321 .618 .97 r
.5749 .35869 m .58985 .36514 L .58766 .35683 L p F P
0 0 1 r
s
.321 .618 .97 r
.58766 .35683 m .57316 .35227 L .5749 .35869 L p F P
0 0 1 r
s
.24 .35 .67 r
.41752 .40964 m
.40328 .41982 L
s
.514 1 1 r
.4998 .34119 m .51217 .34529 L .51492 .34382 L p F P
0 0 1 r
s
.532 1 1 r
.51217 .34529 m .4998 .34119 L .49547 .34474 L p F P
0 0 1 r
s
.24 .35 .67 r
.50027 .41298 m
.52474 .39553 L
s
.50027 .41298 m
.50901 .41159 L
s
.54034 .52011 m
.54249 .52118 L
s
.226 .429 .684 r
.60244 .38351 m .61388 .39493 L .61495 .38347 L p F P
0 0 1 r
s
.226 .429 .684 r
.61495 .38347 m .60331 .37346 L .60244 .38351 L p F P
0 0 1 r
s
.373 .724 1 r
.55759 .34987 m .57316 .35227 L .56927 .3462 L p F P
0 0 1 r
s
.373 .724 1 r
.56927 .3462 m .55492 .34575 L .55759 .34987 L p F P
0 0 1 r
s
.24 .35 .67 r
.47895 .4111 m
.48171 .41268 L
s
.48171 .41268 m
.52474 .39553 L
s
.31915 .51672 m
.31465 .52857 L
s
.34892 .52419 m
.31465 .52857 L
s
.436 .859 1 r
.53531 .34417 m .54574 .33896 L .53962 .3366 L p F P
0 0 1 r
s
.436 .859 1 r
.53962 .3366 m .53223 .34298 L .53531 .34417 L p F P
0 0 1 r
s
.495 .983 1 r
.50524 .33827 m .51492 .34382 L .51811 .34274 L p F P
0 0 1 r
s
.514 1 1 r
.51492 .34382 m .50524 .33827 L .4998 .34119 L p F P
0 0 1 r
s
.549 1 1 r
.47712 .35065 m .49244 .34877 L .49547 .34474 L p F P
0 0 1 r
s
.576 1 1 r
.49244 .34877 m .47712 .35065 L .47482 .35701 L p F P
0 0 1 r
s
.574 1 1 r
.45992 .36297 m .47482 .35701 L .47712 .35065 L p F P
0 0 1 r
s
.24 .35 .67 r
.50901 .41159 m
.52474 .39553 L
s
.50901 .41159 m
.51845 .40952 L
s
.47818 .40887 m
.47895 .4111 L
s
.47895 .4111 m
.52474 .39553 L
s
.53 .925 1 r
.4232 .43061 m .41889 .445 L .42838 .45749 L p F P
0 0 1 r
s
.457 .784 1 r
.42678 .472 m .42838 .45749 L .41889 .445 L p F P
0 0 1 r
s
.593 1 1 r
.43494 .39198 m .4255 .40429 L .42992 .41655 L p F P
0 0 1 r
s
.24 .35 .67 r
.43017 .41367 m
.44185 .41099 L
s
.539 .981 1 r
.4232 .43061 m .42992 .41655 L .4255 .40429 L p F P
0 0 1 r
s
.24 .35 .67 r
.40328 .41982 m
.42457 .41495 L
s
0 0 0 r
.55268 .41092 m
.52474 .39553 L
s
.55268 .41092 m
.55043 .40564 L
s
.441 .871 1 r
.53223 .34298 m .53962 .3366 L .53283 .33509 L p F P
0 0 1 r
s
.441 .871 1 r
.53283 .33509 m .52881 .34222 L .53223 .34298 L p F P
0 0 1 r
s
0 0 0 r
.48941 .40184 m
.49987 .41326 L
s
.49987 .41326 m
.5121 .40399 L
s
.477 .947 1 r
.51156 .33612 m .51811 .34274 L .52159 .3421 L p F P
0 0 1 r
s
.495 .983 1 r
.51811 .34274 m .51156 .33612 L .50524 .33827 L p F P
0 0 1 r
s
.24 .35 .67 r
.28953 .46759 m
.26009 .48906 L
s
.26915 .49451 m
.26009 .48906 L
s
.604 1 1 r
.45992 .36297 m .4465 .37085 L .44648 .38092 L p F P
0 0 1 r
s
.571 1 1 r
.43494 .39198 m .44648 .38092 L .4465 .37085 L p F P
0 0 1 r
s
.24 .35 .67 r
.55044 .41276 m
.5378 .40373 L
s
.55044 .41276 m
.5684 .40593 L
s
.449 .89 1 r
.52881 .34222 m .53283 .33509 L .52568 .33449 L p F P
0 0 1 r
s
.449 .89 1 r
.52568 .33449 m .52521 .34193 L .52881 .34222 L p F P
0 0 1 r
s
.24 .35 .67 r
.47087 .5327 m
.47783 .53127 L
s
.46559 .53378 m
.47087 .5327 L
s
.461 .915 1 r
.51848 .33484 m .52159 .3421 L .52521 .34193 L p F P
0 0 1 r
s
.477 .947 1 r
.52159 .3421 m .51848 .33484 L .51156 .33612 L p F P
0 0 1 r
s
.461 .915 1 r
.52521 .34193 m .52568 .33449 L .51848 .33484 L p F P
0 0 1 r
s
.078 .124 .214 r
.60421 .49931 m .60165 .51168 L .61571 .50165 L p F P
0 0 1 r
s
.24 .35 .67 r
.59911 .50357 m
.60338 .50009 L
s
.078 .124 .214 r
.61571 .50165 m .61875 .48886 L .60421 .49931 L p F P
0 0 1 r
s
.24 .35 .67 r
.51845 .40952 m
.52474 .39553 L
s
.51845 .40952 m
.52818 .40687 L
s
0 0 0 r
.5121 .40399 m
.51788 .40942 L
s
.51788 .40942 m
.52474 .39553 L
s
.162 .257 .356 r
.52228 .5471 m .52205 .53978 L .50152 .53826 L p F P
0 0 1 r
s
.138 .217 .308 r
.52205 .53978 m .52228 .5471 L .54114 .54628 L p F P
0 0 1 r
s
.138 .217 .308 r
.54114 .54628 m .54268 .53888 L .52205 .53978 L p F P
0 0 1 r
s
0 0 0 r
.53522 .52703 m
.53869 .53903 L
s
.082 .123 .203 r
.58448 .51981 m .58103 .53006 L .59719 .52245 L p F P
0 0 1 r
s
.082 .123 .203 r
.59719 .52245 m .60165 .51168 L .58448 .51981 L p F P
0 0 1 r
s
.24 .35 .67 r
.54419 .5203 m
.59911 .50357 L
s
.54249 .52118 m
.59254 .50593 L
s
.47942 .40607 m
.47818 .40887 L
s
.47818 .40887 m
.52474 .39553 L
s
.30575 .50149 m
.29075 .51732 L
s
.31915 .51672 m
.29075 .51732 L
s
.363 .709 1 r
.55492 .34575 m .56927 .3462 L .5634 .34075 L p F P
0 0 1 r
s
.363 .709 1 r
.5634 .34075 m .55092 .34205 L .55492 .34575 L p F P
0 0 1 r
s
.254 .49 .776 r
.58985 .36514 m .60331 .37346 L .60073 .36347 L p F P
0 0 1 r
s
.254 .49 .776 r
.60073 .36347 m .58766 .35683 L .58985 .36514 L p F P
0 0 1 r
s
.24 .35 .67 r
.4517 .40402 m
.44185 .41099 L
s
.44185 .41099 m
.48265 .40283 L
s
.106 .197 .332 r
.62432 .43385 m .62854 .44836 L .63476 .43509 L p F P
0 0 1 r
s
.24 .35 .67 r
.62889 .45128 m
.65041 .4434 L
s
.63382 .4371 m
.63878 .43527 L
s
.106 .197 .332 r
.63476 .43509 m .63025 .42102 L .62432 .43385 L p F P
0 0 1 r
s
.109 .166 .245 r
.54268 .53888 m .54114 .54628 L .55935 .5433 L p F P
0 0 1 r
s
0 0 0 r
.5529 .54436 m
.55671 .55162 L
s
.109 .166 .245 r
.55935 .5433 m .56261 .53561 L .54268 .53888 L p F P
0 0 1 r
s
0 0 0 r
.56045 .5407 m
.572 .55686 L
s
.5468 .53276 m
.54976 .53839 L
s
.55739 .53642 m
.5581 .53742 L
s
.24 .35 .67 r
.34892 .52419 m
.35244 .53206 L
s
.39056 .52386 m
.35244 .53206 L
s
.60761 .41961 m
.62322 .42674 L
s
.63396 .43259 m
.63878 .43527 L
s
.164 .316 .509 r
.61388 .39493 m .62323 .40753 L .62449 .39494 L p F P
0 0 1 r
s
.164 .316 .509 r
.62449 .39494 m .61495 .38347 L .61388 .39493 L p F P
0 0 1 r
s
.509 1 1 r
.48154 .34471 m .49547 .34474 L .4998 .34119 L p F P
0 0 1 r
s
.549 1 1 r
.49547 .34474 m .48154 .34471 L .47712 .35065 L p F P
0 0 1 r
s
.24 .35 .67 r
.65041 .4434 m
.63878 .43527 L
s
.63878 .43527 m
.68208 .41654 L
s
.179 .283 .383 r
.50352 .54571 m .50152 .53826 L .48191 .53438 L p F P
0 0 1 r
s
.162 .257 .356 r
.50152 .53826 m .50352 .54571 L .52228 .5471 L p F P
0 0 1 r
s
0 0 0 r
.60663 .52335 m
.62991 .53141 L
s
.62991 .53141 m
.62225 .51271 L
s
.24 .35 .67 r
.60761 .41961 m
.5888 .41244 L
s
.344 .56 .752 r
.44116 .49678 m .44385 .50925 L .46028 .5179 L p F P
0 0 1 r
s
0 0 0 r
.44917 .50192 m
.45283 .50494 L
s
.26 .42 .557 r
.464 .52828 m .46028 .5179 L .44385 .50925 L p F P
0 0 1 r
s
0 0 0 r
.45283 .50494 m
.46107 .51204 L
s
.263 .425 .576 r
.46028 .5179 m .464 .52828 L .48191 .53438 L p F P
0 0 1 r
s
0 0 0 r
.45918 .50718 m
.47688 .52246 L
s
.24 .35 .67 r
.46559 .53378 m
.47057 .53052 L
s
.414 .687 .911 r
.42678 .472 m .42756 .48587 L .44116 .49678 L p F P
0 0 1 r
s
.323 .532 .702 r
.44385 .50925 m .44116 .49678 L .42756 .48587 L p F P
0 0 1 r
s
.299 .581 .907 r
.57316 .35227 m .58766 .35683 L .58266 .34895 L p F P
0 0 1 r
s
.299 .581 .907 r
.58266 .34895 m .56927 .3462 L .57316 .35227 L p F P
0 0 1 r
s
.067 .113 .208 r
.6195 .47504 m .61875 .48886 L .62943 .47682 L p F P
0 0 1 r
s
.067 .113 .208 r
.62943 .47682 m .63027 .4628 L .6195 .47504 L p F P
0 0 1 r
s
.24 .35 .67 r
.62973 .47185 m
.66442 .4593 L
s
.52818 .40687 m
.52474 .39553 L
s
.52818 .40687 m
.5378 .40373 L
s
.65903 .45147 m
.65041 .4434 L
s
.65041 .4434 m
.69832 .42283 L
s
0 0 0 r
.64141 .51487 m
.65755 .51522 L
s
.65755 .51522 m
.64163 .48703 L
s
.574 1 1 r
.47712 .35065 m .46285 .35473 L .45992 .36297 L p F P
0 0 1 r
s
.533 1 1 r
.4465 .37085 m .45992 .36297 L .46285 .35473 L p F P
0 0 1 r
s
0 0 0 r
.60922 .53596 m
.60663 .52335 L
s
.6083 .41834 m
.6239 .42517 L
s
.63312 .42997 m
.63976 .43353 L
s
.24 .35 .67 r
.48265 .40283 m
.47942 .40607 L
s
.47942 .40607 m
.52474 .39553 L
s
0 0 0 r
.6083 .41834 m
.58933 .41145 L
s
.6083 .41834 m
.59252 .39614 L
s
.65151 .44149 m
.63976 .43353 L
s
.63358 .42469 m
.63976 .43353 L
s
.24 .35 .67 r
.5888 .41244 m
.5684 .40593 L
s
.5888 .41244 m
.61272 .40183 L
s
0 0 0 r
.55043 .40564 m
.52474 .39553 L
s
.55043 .40564 m
.54705 .39991 L
s
.45283 .50494 m
.45918 .50718 L
s
.51 1 1 r
.46285 .35473 m .47712 .35065 L .48154 .34471 L p F P
0 0 1 r
s
.352 .691 1 r
.55092 .34205 m .5634 .34075 L .55578 .33617 L p F P
0 0 1 r
s
.352 .691 1 r
.55578 .33617 m .54574 .33896 L .55092 .34205 L p F P
0 0 1 r
s
.539 .981 1 r
.4255 .40429 m .41841 .41757 L .4232 .43061 L p F P
0 0 1 r
s
.45 .808 1 r
.41889 .445 m .4232 .43061 L .41841 .41757 L p F P
0 0 1 r
s
.24 .35 .67 r
.29769 .47385 m
.26915 .49451 L
s
.28447 .49869 m
.26915 .49451 L
s
.571 1 1 r
.4465 .37085 m .43489 .38048 L .43494 .39198 L p F P
0 0 1 r
s
.501 .952 1 r
.4255 .40429 m .43494 .39198 L .43489 .38048 L p F P
0 0 1 r
s
0 0 0 r
.58933 .41145 m
.56875 .40526 L
s
.58933 .41145 m
.57698 .39428 L
s
.075 .107 .166 r
.56261 .53561 m .55935 .5433 L .57617 .53826 L p F P
0 0 1 r
s
0 0 0 r
.57543 .53848 m
.59596 .5578 L
s
.56884 .54045 m
.58525 .55894 L
s
.075 .107 .166 r
.57617 .53826 m .58103 .53006 L .56261 .53561 L p F P
0 0 1 r
s
0 0 0 r
.57926 .53406 m
.60372 .55348 L
s
.66021 .44944 m
.65151 .44149 L
s
.64047 .42562 m
.65151 .44149 L
s
.24 .35 .67 r
.66442 .4593 m
.65903 .45147 L
s
.65903 .45147 m
.71037 .42957 L
s
.463 .927 1 r
.4879 .33947 m .4998 .34119 L .50524 .33827 L p F P
0 0 1 r
s
.509 1 1 r
.4998 .34119 m .4879 .33947 L .48154 .34471 L p F P
0 0 1 r
s
.24 .35 .67 r
.59254 .50593 m
.59911 .50357 L
s
0 0 0 r
.55739 .53642 m
.56108 .537 L
s
.54624 .51375 m
.565 .53603 L
s
.50684 .39817 m
.5121 .40399 L
s
.5121 .40399 m
.52474 .39553 L
s
.457 .784 1 r
.41889 .445 m .41712 .45941 L .42678 .472 L p F P
0 0 1 r
s
.354 .602 .786 r
.42756 .48587 m .42678 .472 L .41712 .45941 L p F P
0 0 1 r
s
0 0 0 r
.4225 .45808 m
.43485 .47062 L
s
.42438 .46886 m
.43024 .47479 L
s
.24 .35 .67 r
.5378 .40373 m
.52474 .39553 L
s
.5378 .40373 m
.54688 .40025 L
s
.41049 .40217 m
.38598 .416 L
s
.38598 .416 m
.41752 .40964 L
s
.3578 .42296 m
.38598 .416 L
s
.38707 .40636 m
.3578 .42296 L
s
.33365 .43035 m
.3578 .42296 L
s
.182 .287 .378 r
.4856 .54218 m .48191 .53438 L .464 .52828 L p F P
0 0 1 r
s
.24 .35 .67 r
.48037 .53075 m
.501 .52651 L
s
.179 .283 .383 r
.48191 .53438 m .4856 .54218 L .50352 .54571 L p F P
0 0 1 r
s
0 0 0 r
.49887 .52615 m
.51179 .53573 L
s
.24 .35 .67 r
.5684 .40593 m
.54688 .40025 L
s
.5684 .40593 m
.58459 .39869 L
s
0 0 0 r
.55004 .51334 m
.57109 .53424 L
s
.57836 .53457 m
.57926 .53406 L
s
.24 .35 .67 r
.53778 .5171 m
.54034 .52011 L
s
.54034 .52011 m
.58426 .50672 L
s
.41752 .40964 m
.42484 .40554 L
s
.42686 .40811 m
.4517 .40402 L
s
.41752 .40964 m
.42314 .40872 L
s
.18 .354 .565 r
.60331 .37346 m .61495 .38347 L .61207 .37204 L p F P
0 0 1 r
s
.18 .354 .565 r
.61207 .37204 m .60073 .36347 L .60331 .37346 L p F P
0 0 1 r
s
.24 .35 .67 r
.48772 .39928 m
.48265 .40283 L
s
.48265 .40283 m
.52474 .39553 L
s
0 0 0 r
.56875 .40526 m
.54705 .39991 L
s
.56875 .40526 m
.56023 .39355 L
s
.24 .35 .67 r
.36694 .4114 m
.33365 .43035 L
s
.31409 .43799 m
.33365 .43035 L
s
0 0 0 r
.50461 .51924 m
.52236 .53249 L
s
.5231 .51945 m
.52236 .53249 L
s
.66565 .4572 m
.66021 .44944 L
s
.5468 .53276 m
.55739 .53642 L
s
.54152 .51299 m
.55739 .53642 L
s
.24 .35 .67 r
.50627 .51952 m
.501 .52651 L
s
.501 .52651 m
.53778 .5171 L
s
.342 .675 1 r
.54574 .33896 m .55578 .33617 L .54675 .33267 L p F P
0 0 1 r
s
.342 .675 1 r
.54675 .33267 m .53962 .3366 L .54574 .33896 L p F P
0 0 1 r
s
.099 .195 .336 r
.62323 .40753 m .63025 .42102 L .63165 .40762 L p F P
0 0 1 r
s
.24 .35 .67 r
.60761 .41961 m
.62567 .41167 L
s
.099 .195 .336 r
.63165 .40762 m .62449 .39494 L .62323 .40753 L p F P
0 0 1 r
s
0 0 0 r
.47666 .50681 m
.49887 .52615 L
s
.50461 .51924 m
.49887 .52615 L
s
.24 .35 .67 r
.66644 .46671 m
.66442 .4593 L
s
.66442 .4593 m
.71792 .43662 L
s
.053 .098 .193 r
.62854 .44836 m .63027 .4628 L .6366 .44941 L p F P
0 0 1 r
s
0 0 0 r
.64106 .42186 m
.66021 .44944 L
s
.053 .098 .193 r
.6366 .44941 m .63476 .43509 L .62854 .44836 L p F P
0 0 1 r
s
.419 .838 1 r
.49592 .33515 m .50524 .33827 L .51156 .33612 L p F P
0 0 1 r
s
.463 .927 1 r
.50524 .33827 m .49592 .33515 L .4879 .33947 L p F P
0 0 1 r
s
.24 .35 .67 r
.46482 .39672 m
.4517 .40402 L
s
.4517 .40402 m
.48772 .39928 L
s
.27 .531 .818 r
.56927 .3462 m .58266 .34895 L .57507 .34187 L p F P
0 0 1 r
s
.27 .531 .818 r
.57507 .34187 m .5634 .34075 L .56927 .3462 L p F P
0 0 1 r
s
.24 .35 .67 r
.3506 .41717 m
.31409 .43799 L
s
.2996 .44572 m
.31409 .43799 L
s
.41246 .53054 m
.43081 .53082 L
s
.43081 .53082 m
.45318 .52902 L
s
.035 .056 .096 r
.60165 .51168 m .59719 .52245 L .61041 .51306 L p F P
0 0 1 r
s
.035 .056 .096 r
.61041 .51306 m .61571 .50165 L .60165 .51168 L p F P
0 0 1 r
s
.24 .35 .67 r
.59911 .50357 m
.61097 .49933 L
s
.39885 .52819 m
.41246 .53054 L
s
.213 .421 .66 r
.58766 .35683 m .60073 .36347 L .59477 .35398 L p F P
0 0 1 r
s
.213 .421 .66 r
.59477 .35398 m .58266 .34895 L .58766 .35683 L p F P
0 0 1 r
s
.533 1 1 r
.46285 .35473 m .44997 .36094 L .4465 .37085 L p F P
0 0 1 r
s
.451 .881 1 r
.43489 .38048 m .4465 .37085 L .44997 .36094 L p F P
0 0 1 r
s
.24 .35 .67 r
.54688 .40025 m
.52474 .39553 L
s
.54688 .40025 m
.55503 .39657 L
s
0 0 0 r
.54705 .39991 m
.52474 .39553 L
s
.54705 .39991 m
.54268 .39397 L
s
.57886 .53372 m
.57926 .53406 L
s
.338 .67 .989 r
.53962 .3366 m .54675 .33267 L .53671 .33043 L p F P
0 0 1 r
s
.338 .67 .989 r
.53671 .33043 m .53283 .33509 L .53962 .3366 L p F P
0 0 1 r
s
.24 .35 .67 r
.35288 .51426 m
.34892 .52419 L
s
.38796 .51771 m
.34892 .52419 L
s
0 0 0 r
.45935 .38918 m
.47284 .40645 L
s
.47284 .40645 m
.48941 .40184 L
s
.45754 .41188 m
.47284 .40645 L
s
.429 .86 1 r
.46854 .34702 m .48154 .34471 L .4879 .33947 L p F P
0 0 1 r
s
.51 1 1 r
.48154 .34471 m .46854 .34702 L .46285 .35473 L p F P
0 0 1 r
s
0 0 0 r
.66769 .46459 m
.66565 .4572 L
s
.66565 .4572 m
.64002 .42027 L
s
.43983 .38953 m
.45754 .41188 L
s
.44386 .41802 m
.45754 .41188 L
s
.383 .764 1 r
.50525 .33197 m .51156 .33612 L .51848 .33484 L p F P
0 0 1 r
s
.419 .838 1 r
.51156 .33612 m .50525 .33197 L .49592 .33515 L p F P
0 0 1 r
s
.24 .35 .67 r
.33256 .50282 m
.31915 .51672 L
s
.35288 .51426 m
.31915 .51672 L
s
0 0 0 r
.48035 .39009 m
.48941 .40184 L
s
.48941 .40184 m
.50684 .39817 L
s
.24 .35 .67 r
.49443 .39558 m
.48772 .39928 L
s
.48772 .39928 m
.52474 .39553 L
s
.31145 .47933 m
.28447 .49869 L
s
.30575 .50149 m
.28447 .49869 L
s
.025 .047 .094 r
.61875 .48886 m .61571 .50165 L .62602 .49008 L p F P
0 0 1 r
s
.24 .35 .67 r
.62095 .49576 m
.62728 .4935 L
s
.025 .047 .094 r
.62602 .49008 m .62943 .47682 L .61875 .48886 L p F P
0 0 1 r
s
.24 .35 .67 r
.62852 .48036 m
.66644 .46671 L
s
.035 .049 .073 r
.58103 .53006 m .57617 .53826 L .59091 .53134 L p F P
0 0 1 r
s
0 0 0 r
.588 .53271 m
.60821 .54612 L
s
.035 .049 .073 r
.59091 .53134 m .59719 .52245 L .58103 .53006 L p F P
0 0 1 r
s
0 0 0 r
.58106 .53099 m
.58228 .52892 L
s
.59357 .52758 m
.60922 .53596 L
s
.58287 .52186 m
.59072 .52606 L
s
.58228 .52892 m
.58355 .52976 L
s
.501 .952 1 r
.43489 .38048 m .42538 .39166 L .4255 .40429 L p F P
0 0 1 r
s
.402 .751 .969 r
.41841 .41757 m .4255 .40429 L .42538 .39166 L p F P
0 0 1 r
s
.24 .35 .67 r
.42519 .40534 m
.43661 .39894 L
s
.33848 .42355 m
.2996 .44572 L
s
.29054 .45335 m
.2996 .44572 L
s
0 0 0 r
.43212 .42472 m
.44386 .41802 L
s
.53522 .52703 m
.5468 .53276 L
s
.53607 .51109 m
.5468 .53276 L
s
.343 .681 .992 r
.53283 .33509 m .53671 .33043 L .52613 .32955 L p F P
0 0 1 r
s
.343 .681 .992 r
.52613 .32955 m .52568 .33449 L .53283 .33509 L p F P
0 0 1 r
s
.423 .84 1 r
.44997 .36094 m .46285 .35473 L .46854 .34702 L p F P
0 0 1 r
s
.24 .35 .67 r
.66502 .47351 m
.66644 .46671 L
s
.66644 .46671 m
.72074 .44379 L
s
.45 .808 1 r
.41841 .41757 m .41387 .43152 L .41889 .445 L p F P
0 0 1 r
s
.342 .607 .784 r
.41712 .45941 m .41889 .445 L .41387 .43152 L p F P
0 0 1 r
s
0 0 0 r
.41569 .45115 m
.41622 .45169 L
s
.357 .711 1 r
.51548 .33007 m .51848 .33484 L .52568 .33449 L p F P
0 0 1 r
s
.383 .764 1 r
.51848 .33484 m .51548 .33007 L .50525 .33197 L p F P
0 0 1 r
s
0 0 0 r
.50233 .39223 m
.50684 .39817 L
s
.50684 .39817 m
.52474 .39553 L
s
.24 .35 .67 r
.39056 .52386 m
.39885 .52819 L
s
0 0 0 r
.45918 .50718 m
.46718 .50781 L
s
.323 .532 .702 r
.42756 .48587 m .43071 .49877 L .44385 .50925 L p F P
0 0 1 r
s
.22 .361 .459 r
.44854 .52017 m .44385 .50925 L .43071 .49877 L p F P
0 0 1 r
s
.26 .42 .557 r
.44385 .50925 m .44854 .52017 L .464 .52828 L p F P
0 0 1 r
s
.24 .35 .67 r
.45318 .52902 m
.4627 .5276 L
s
.357 .711 1 r
.52568 .33449 m .52613 .32955 L .51548 .33007 L p F P
0 0 1 r
s
0 0 0 r
.62225 .51271 m
.64141 .51487 L
s
.092 .123 .167 r
.52257 .55191 m .52228 .5471 L .50352 .54571 L p F P
0 0 1 r
s
.076 .098 .136 r
.52228 .5471 m .52257 .55191 L .53918 .5512 L p F P
0 0 1 r
s
.076 .098 .136 r
.53918 .5512 m .54114 .54628 L .52228 .5471 L p F P
0 0 1 r
s
0 0 0 r
.40958 .39696 m
.41013 .39764 L
s
.40716 .39398 m
.40958 .39696 L
s
.42261 .43181 m
.43212 .42472 L
s
.165 .258 .323 r
.46925 .53663 m .464 .52828 L .44854 .52017 L p F P
0 0 1 r
s
.24 .35 .67 r
.45103 .5222 m
.45107 .52218 L
s
.43081 .53082 m
.45103 .5222 L
s
.45318 .52902 m
.45706 .52694 L
s
.46344 .52749 m
.47867 .52521 L
s
.182 .287 .378 r
.464 .52828 m .46925 .53663 L .4856 .54218 L p F P
0 0 1 r
s
0 0 0 r
.46718 .50781 m
.49276 .52998 L
s
.24 .35 .67 r
.47235 .52935 m
.47867 .52521 L
s
.58426 .50672 m
.59254 .50593 L
s
.55503 .39657 m
.52474 .39553 L
s
.58459 .39869 m
.55503 .39657 L
s
.55503 .39657 m
.56189 .39286 L
s
.108 .22 .372 r
.61495 .38347 m .62449 .39494 L .62136 .38238 L p F P
0 0 1 r
s
.108 .22 .372 r
.62136 .38238 m .61207 .37204 L .61495 .38347 L p F P
0 0 1 r
s
0 0 0 r
.52474 .39553 m
.52474 .39553 L
s
.54268 .39397 m
.52474 .39553 L
s
.24 .35 .67 r
.49443 .39558 m
.52474 .39553 L
s
.56189 .39286 m
.52474 .39553 L
s
0 0 0 r
.49877 .38641 m
.52474 .39553 L
s
.50233 .39223 m
.52474 .39553 L
s
.53748 .38809 m
.52474 .39553 L
s
.24 .35 .67 r
.51157 .38835 m
.52474 .39553 L
s
.50249 .39188 m
.52474 .39553 L
s
.56714 .38927 m
.52474 .39553 L
s
.57056 .38597 m
.52474 .39553 L
s
0 0 0 r
.49633 .38099 m
.52474 .39553 L
s
.5317 .38253 m
.52474 .39553 L
s
.24 .35 .67 r
.52474 .39553 m
.57129 .3808 L
s
.56857 .37916 m
.52474 .39553 L
s
.54967 .37884 m
.52474 .39553 L
s
.54074 .38029 m
.52474 .39553 L
s
.53112 .38242 m
.52474 .39553 L
s
.52125 .38515 m
.52474 .39553 L
s
.57196 .3831 m
.52474 .39553 L
s
0 0 0 r
.49525 .37227 m
.52474 .39553 L
s
.49514 .3762 m
.52474 .39553 L
s
.52557 .37753 m
.52474 .39553 L
s
.51937 .37332 m
.52474 .39553 L
s
.24 .35 .67 r
.5639 .37827 m
.52474 .39553 L
s
.55751 .37816 m
.52474 .39553 L
s
0 0 0 r
.52474 .39553 m
.49934 .36766 L
s
.49667 .36938 m
.52474 .39553 L
s
.51339 .37011 m
.52474 .39553 L
s
.5079 .36804 m
.52474 .39553 L
s
.50314 .36721 m
.52474 .39553 L
s
.057 .075 .103 r
.54114 .54628 m .53918 .5512 L .5552 .54858 L p F P
0 0 1 r
s
.057 .075 .103 r
.5552 .54858 m .55935 .5433 L .54114 .54628 L p F P
0 0 1 r
s
.24 .35 .67 r
.61272 .40183 m
.58459 .39869 L
s
.58459 .39869 m
.59829 .39135 L
s
0 0 0 r
.66626 .47142 m
.66769 .46459 L
s
.66769 .46459 m
.64172 .42727 L
s
.242 .483 .729 r
.5634 .34075 m .57507 .34187 L .56518 .3359 L p F P
0 0 1 r
s
.242 .483 .729 r
.56518 .3359 m .55578 .33617 L .5634 .34075 L p F P
0 0 1 r
s
.24 .35 .67 r
.33088 .43037 m
.29054 .45335 L
s
.28715 .4607 m
.29054 .45335 L
s
.354 .602 .786 r
.41712 .45941 m .41797 .47349 L .42756 .48587 L p F P
0 0 1 r
s
0 0 0 r
.41727 .44089 m
.44725 .47157 L
s
.42261 .43181 m
.45371 .4639 L
s
.249 .424 .537 r
.43071 .49877 m .42756 .48587 L .41797 .47349 L p F P
0 0 1 r
s
0 0 0 r
.42206 .47229 m
.43446 .48479 L
s
.105 .146 .194 r
.50606 .5507 m .50352 .54571 L .4856 .54218 L p F P
0 0 1 r
s
.092 .123 .167 r
.50352 .54571 m .50606 .5507 L .52257 .55191 L p F P
0 0 1 r
s
.24 .35 .67 r
.50249 .39188 m
.49443 .39558 L
s
.46482 .39672 m
.49443 .39558 L
s
.058 .109 .215 r
.63025 .42102 m .63476 .43509 L .63625 .42123 L p F P
0 0 1 r
s
.058 .109 .215 r
.63625 .42123 m .63165 .40762 L .63025 .42102 L p F P
0 0 1 r
s
.24 .35 .67 r
.63615 .42216 m
.66206 .41086 L
s
.63207 .40886 m
.63875 .40592 L
s
.61272 .40183 m
.62523 .40379 L
s
.6299 .40453 m
.63875 .40592 L
s
.4931 .51441 m
.47867 .52521 L
s
.47867 .52521 m
.50627 .51952 L
s
0 0 0 r
.41695 .43769 m
.42261 .43181 L
s
.358 .711 .975 r
.47677 .3402 m .4879 .33947 L .49592 .33515 L p F P
0 0 1 r
s
.429 .86 1 r
.4879 .33947 m .47677 .3402 L .46854 .34702 L p F P
0 0 1 r
s
0 0 0 r
.55426 .50909 m
.58228 .52892 L
s
.58228 .52892 m
.58287 .52186 L
s
.03 .056 .111 r
.63027 .4628 m .62943 .47682 L .63571 .46364 L p F P
0 0 1 r
s
.24 .35 .67 r
.62675 .48724 m
.66502 .47351 L
s
.03 .056 .111 r
.63571 .46364 m .6366 .44941 L .63027 .4628 L p F P
0 0 1 r
s
.24 .35 .67 r
.48067 .3894 m
.46482 .39672 L
s
.43661 .39894 m
.46482 .39672 L
s
.66017 .47955 m
.66502 .47351 L
s
.66502 .47351 m
.71875 .45092 L
s
0 0 0 r
.56023 .39355 m
.54268 .39397 L
s
.54268 .39397 m
.53748 .38809 L
s
.451 .881 1 r
.44997 .36094 m .4388 .36915 L .43489 .38048 L p F P
0 0 1 r
s
.359 .686 .899 r
.42538 .39166 m .43489 .38048 L .4388 .36915 L p F P
0 0 1 r
s
.24 .35 .67 r
.66206 .41086 m
.63875 .40592 L
s
.63875 .40592 m
.66536 .39193 L
s
.38796 .51771 m
.39056 .52386 L
s
.13 .27 .437 r
.60073 .36347 m .61207 .37204 L .60527 .36118 L p F P
0 0 1 r
s
.13 .27 .437 r
.60527 .36118 m .59477 .35398 L .60073 .36347 L p F P
0 0 1 r
s
.032 .041 .057 r
.55935 .5433 m .5552 .54858 L .56998 .54416 L p F P
0 0 1 r
s
.032 .041 .057 r
.56998 .54416 m .57617 .53826 L .55935 .5433 L p F P
0 0 1 r
s
.24 .35 .67 r
.59829 .39135 m
.56189 .39286 L
s
.56189 .39286 m
.56714 .38927 L
s
.172 .354 .547 r
.58266 .34895 m .59477 .35398 L .58563 .34542 L p F P
0 0 1 r
s
.172 .354 .547 r
.58563 .34542 m .57507 .34187 L .58266 .34895 L p F P
0 0 1 r
s
0 0 0 r
.5231 .51945 m
.53522 .52703 L
s
.53011 .50811 m
.53522 .52703 L
s
.24 .35 .67 r
.53488 .51218 m
.53778 .5171 L
s
.53778 .5171 m
.57445 .50589 L
s
0 0 0 r
.49877 .38641 m
.50233 .39223 L
s
.48035 .39009 m
.50233 .39223 L
s
.24 .35 .67 r
.32803 .43748 m
.28715 .4607 L
s
.28953 .46759 m
.28715 .4607 L
s
.33054 .48389 m
.30575 .50149 L
s
.33256 .50282 m
.30575 .50149 L
s
0 0 0 r
.66136 .47754 m
.66626 .47142 L
s
.66626 .47142 m
.64053 .43463 L
s
.24 .35 .67 r
.51157 .38835 m
.50249 .39188 L
s
.48067 .3894 m
.50249 .39188 L
s
.402 .751 .969 r
.42538 .39166 m .41823 .40413 L .41841 .41757 L p F P
0 0 1 r
s
.24 .35 .67 r
.41049 .40217 m
.42003 .40099 L
s
.42406 .40049 m
.43661 .39894 L
s
.315 .58 .749 r
.41387 .43152 m .41841 .41757 L .41823 .40413 L p F P
0 0 1 r
s
0 0 0 r
.41508 .42263 m
.41525 .42284 L
s
.11 .152 .203 r
.4903 .5476 m .4856 .54218 L .46925 .53663 L p F P
0 0 1 r
s
.105 .146 .194 r
.4856 .54218 m .4903 .5476 L .50606 .5507 L p F P
0 0 1 r
s
.225 .457 .676 r
.55578 .33617 m .56518 .3359 L .55343 .33135 L p F P
0 0 1 r
s
.225 .457 .676 r
.55343 .33135 m .54675 .33267 L .55578 .33617 L p F P
0 0 1 r
s
.24 .35 .67 r
.68208 .41654 m
.66206 .41086 L
s
.66206 .41086 m
.69438 .39403 L
s
0 0 0 r
.57698 .39428 m
.56023 .39355 L
s
.56023 .39355 m
.55004 .38188 L
s
.336 .658 .889 r
.45679 .35165 m .46854 .34702 L .47677 .3402 L p F P
0 0 1 r
s
.423 .84 1 r
.46854 .34702 m .45679 .35165 L .44997 .36094 L p F P
0 0 1 r
s
.342 .607 .784 r
.41387 .43152 m .412 .44582 L .41712 .45941 L p F P
0 0 1 r
s
0 0 0 r
.41595 .4237 m
.42261 .43181 L
s
.257 .453 .568 r
.41797 .47349 m .41712 .45941 L .412 .44582 L p F P
0 0 1 r
s
0 0 0 r
.41114 .44653 m
.41244 .44785 L
s
.41071 .45504 m
.41491 .45929 L
s
.41114 .44653 m
.41212 .4449 L
s
.41539 .46557 m
.41651 .4667 L
s
.34 .657 .877 r
.4388 .36915 m .44997 .36094 L .45679 .35165 L p F P
0 0 1 r
s
0 0 0 r
.59719 .52245 m .59091 .53134 L .60294 .52281 L p F P
0 0 1 r
s
0 0 0 r
.60294 .52281 m .61041 .51306 L .59719 .52245 L p F P
0 0 1 r
s
0 0 0 r
.60349 .5221 m
.60663 .52335 L
s
.60517 .51989 m
.60663 .52335 L
s
.58096 .51313 m
.59975 .52061 L
s
.307 .61 .847 r
.48719 .33457 m .49592 .33515 L .50525 .33197 L p F P
0 0 1 r
s
.358 .711 .975 r
.49592 .33515 m .48719 .33457 L .47677 .3402 L p F P
0 0 1 r
s
0 0 0 r
.61571 .50165 m .61041 .51306 L .62008 .50224 L p F P
0 0 1 r
s
0 0 0 r
.62008 .50224 m .62602 .49008 L .61571 .50165 L p F P
0 0 1 r
s
.24 .35 .67 r
.59254 .50593 m
.61971 .49622 L
s
.62372 .49478 m
.62395 .4947 L
s
.62502 .49213 m
.66017 .47955 L
s
0 0 0 r
.47666 .50681 m
.46718 .50781 L
s
.24 .35 .67 r
.38707 .40636 m
.41049 .40217 L
s
.064 .12 .237 r
.62449 .39494 m .63165 .40762 L .62835 .39425 L p F P
0 0 1 r
s
.24 .35 .67 r
.61272 .40183 m
.62483 .3954 L
s
0 0 0 r
.60647 .3991 m
.62449 .42468 L
s
.064 .12 .237 r
.62835 .39425 m .62136 .38238 L .62449 .39494 L p F P
0 0 1 r
s
.24 .35 .67 r
.62803 .3937 m
.63306 .39103 L
s
.65198 .48467 m
.66017 .47955 L
s
.66017 .47955 m
.71197 .45782 L
s
.60886 .38422 m
.56714 .38927 L
s
.56714 .38927 m
.57056 .38597 L
s
.3643 .50264 m
.35288 .51426 L
s
.39122 .50996 m
.35288 .51426 L
s
.59829 .39135 m
.62354 .39112 L
s
.62649 .39109 m
.63306 .39103 L
s
.59829 .39135 m
.60886 .38422 L
s
.57445 .50589 m
.58426 .50672 L
s
.51207 .51049 m
.50627 .51952 L
s
.50627 .51952 m
.53488 .51218 L
s
.69832 .42283 m
.68208 .41654 L
s
.68208 .41654 m
.71937 .3973 L
s
0 0 0 r
.37996 .40915 m
.41114 .44653 L
s
.40949 .45381 m
.41114 .44653 L
s
.48742 .50417 m
.50461 .51924 L
s
.51093 .51029 m
.50461 .51924 L
s
.24 .35 .67 r
.52125 .38515 m
.51157 .38835 L
s
.4986 .38239 m
.51157 .38835 L
s
.22 .361 .459 r
.43071 .49877 m .4362 .51037 L .44854 .52017 L p F P
0 0 1 r
s
.24 .35 .67 r
.39056 .52386 m
.43262 .51348 L
s
.149 .229 .288 r
.45516 .52927 m .44854 .52017 L .4362 .51037 L p F P
0 0 1 r
s
.24 .35 .67 r
.39885 .52819 m
.43824 .51648 L
s
.44452 .51918 m
.4449 .51904 L
s
.44593 .51868 m
.44756 .5181 L
s
.41246 .53054 m
.44452 .51918 L
s
.165 .258 .323 r
.44854 .52017 m .45516 .52927 L .46925 .53663 L p F P
0 0 1 r
s
.24 .35 .67 r
.45124 .52211 m
.46017 .51829 L
s
.45925 .52577 m
.47556 .51705 L
s
0 0 0 r
.55004 .38188 m
.53748 .38809 L
s
.53748 .38809 m
.5317 .38253 L
s
.033 .061 .122 r
.63476 .43509 m .6366 .44941 L .63814 .43543 L p F P
0 0 1 r
s
.033 .061 .122 r
.63814 .43543 m .63625 .42123 L .63476 .43509 L p F P
0 0 1 r
s
0 0 0 r
.63662 .42009 m
.64047 .42562 L
s
.222 .456 .665 r
.54675 .33267 m .55343 .33135 L .54035 .32842 L p F P
0 0 1 r
s
.222 .456 .665 r
.54035 .32842 m .53671 .33043 L .54675 .33267 L p F P
0 0 1 r
s
.24 .35 .67 r
.33004 .4447 m
.28953 .46759 L
s
.29769 .47385 m
.28953 .46759 L
s
0 0 0 r
.59252 .39614 m
.57698 .39428 L
s
.57698 .39428 m
.56209 .37705 L
s
.47315 .37852 m
.48035 .39009 L
s
.45935 .38918 m
.48035 .39009 L
s
.57617 .53826 m .56998 .54416 L .58292 .5381 L p F P
0 0 1 r
s
0 0 0 r
.58292 .5381 m .59091 .53134 L .57617 .53826 L p F P
0 0 1 r
s
0 0 0 r
.55275 .51176 m
.57724 .53235 L
s
.61233 .51091 m
.62225 .51271 L
s
.273 .548 .77 r
.49934 .33042 m .50525 .33197 L .51548 .33007 L p F P
0 0 1 r
s
.307 .61 .847 r
.50525 .33197 m .49934 .33042 L .48719 .33457 L p F P
0 0 1 r
s
0 0 0 r
.65309 .48279 m
.66136 .47754 L
s
.64376 .45256 m
.66136 .47754 L
s
.249 .424 .537 r
.41797 .47349 m .42146 .48688 L .43071 .49877 L p F P
0 0 1 r
s
.177 .289 .352 r
.4362 .51037 m .43071 .49877 L .42146 .48688 L p F P
0 0 1 r
s
.24 .35 .67 r
.4986 .38239 m
.48067 .3894 L
s
.45981 .38817 m
.48067 .3894 L
s
.36694 .4114 m
.38707 .40636 L
s
.39122 .50996 m
.38796 .51771 L
s
0 0 0 r
.5545 .50543 m
.58287 .52186 L
s
.58287 .52186 m
.58096 .51313 L
s
.49633 .38099 m
.49877 .38641 L
s
.47315 .37852 m
.49877 .38641 L
s
.62943 .47682 m .62602 .49008 L .63207 .47743 L p F P
0 0 1 r
s
.24 .35 .67 r
.62395 .4947 m
.64063 .48874 L
s
.62728 .4935 m
.65198 .48467 L
s
0 0 0 r
.63207 .47743 m .63571 .46364 L .62943 .47682 L p F P
0 0 1 r
s
.359 .686 .899 r
.4388 .36915 m .42964 .3792 L .42538 .39166 L p F P
0 0 1 r
s
.24 .35 .67 r
.43661 .39894 m
.45981 .38817 L
s
.3 .566 .733 r
.41823 .40413 m .42538 .39166 L .42964 .3792 L p F P
0 0 1 r
s
.24 .35 .67 r
.41049 .40217 m
.42147 .39705 L
s
.57056 .38597 m
.57196 .3831 L
s
.231 .473 .681 r
.53671 .33043 m .54035 .32842 L .52655 .32727 L p F P
0 0 1 r
s
.231 .473 .681 r
.52655 .32727 m .52613 .32955 L .53671 .33043 L p F P
0 0 1 r
s
.149 .318 .49 r
.57507 .34187 m .58563 .34542 L .5737 .33822 L p F P
0 0 1 r
s
.149 .318 .49 r
.5737 .33822 m .56518 .3359 L .57507 .34187 L p F P
0 0 1 r
s
.101 .135 .184 r
.47594 .54273 m .46925 .53663 L .45516 .52927 L p F P
0 0 1 r
s
.11 .152 .203 r
.46925 .53663 m .47594 .54273 L .4903 .5476 L p F P
0 0 1 r
s
.24 .35 .67 r
.71037 .42957 m
.69832 .42283 L
s
.69832 .42283 m
.7397 .40165 L
s
.248 .504 .717 r
.51266 .32795 m .51548 .33007 L .52613 .32955 L p F P
0 0 1 r
s
.273 .548 .77 r
.51548 .33007 m .51266 .32795 L .49934 .33042 L p F P
0 0 1 r
s
.24 .35 .67 r
.53112 .38242 m
.52125 .38515 L
s
.51781 .37601 m
.52125 .38515 L
s
.08 .156 .285 r
.61207 .37204 m .62136 .38238 L .6139 .37042 L p F P
0 0 1 r
s
.08 .156 .285 r
.6139 .37042 m .60527 .36118 L .61207 .37204 L p F P
0 0 1 r
s
.248 .504 .717 r
.52613 .32955 m .52655 .32727 L .51266 .32795 L p F P
0 0 1 r
s
0 0 0 r
.37781 .41603 m
.40949 .45381 L
s
.41065 .46079 m
.40949 .45381 L
s
.24 .35 .67 r
.35452 .48741 m
.33256 .50282 L
s
.3643 .50264 m
.33256 .50282 L
s
.315 .58 .749 r
.41823 .40413 m .41364 .41761 L .41387 .43152 L p F P
0 0 1 r
s
0 0 0 r
.4178 .40708 m
.43212 .42472 L
s
.25 .455 .564 r
.412 .44582 m .41387 .43152 L .41364 .41761 L p F P
0 0 1 r
s
0 0 0 r
.41211 .41902 m
.41346 .42066 L
s
.24 .35 .67 r
.66536 .39193 m
.63306 .39103 L
s
.63306 .39103 m
.64886 .38052 L
s
.053 .069 .095 r
.52293 .55405 m .52257 .55191 L .50606 .5507 L p F P
0 0 1 r
s
.039 .051 .071 r
.52257 .55191 m .52293 .55405 L .53683 .55346 L p F P
0 0 1 r
s
.039 .051 .071 r
.53683 .55346 m .53918 .5512 L .52257 .55191 L p F P
0 0 1 r
s
.283 .562 .768 r
.46669 .34341 m .47677 .3402 L .48719 .33457 L p F P
0 0 1 r
s
.336 .658 .889 r
.47677 .3402 m .46669 .34341 L .45679 .35165 L p F P
0 0 1 r
s
0 0 0 r
.51093 .51029 m
.5231 .51945 L
s
.5239 .50419 m
.5231 .51945 L
s
.24 .35 .67 r
.64063 .48874 m
.65198 .48467 L
s
.65198 .48467 m
.70052 .46433 L
s
.11 .226 .374 r
.59477 .35398 m .60527 .36118 L .59481 .35138 L p F P
0 0 1 r
s
.11 .226 .374 r
.59481 .35138 m .58563 .34542 L .59477 .35398 L p F P
0 0 1 r
s
0 0 0 r
.60647 .3991 m
.59252 .39614 L
s
.59252 .39614 m
.57334 .37375 L
s
.24 .35 .67 r
.40793 .39216 m
.36694 .4114 L
s
.3506 .41717 m
.36694 .4114 L
s
.018 .023 .032 r
.53918 .5512 m .53683 .55346 L .55023 .55127 L p F P
0 0 1 r
s
.018 .023 .032 r
.55023 .55127 m .5552 .54858 L .53918 .5512 L p F P
0 0 1 r
s
.24 .35 .67 r
.33687 .45184 m
.29769 .47385 L
s
.31145 .47933 m
.29769 .47385 L
s
.57196 .3831 m
.57129 .3808 L
s
.059 .077 .107 r
.5091 .55304 m .50606 .5507 L .4903 .5476 L p F P
0 0 1 r
s
.053 .069 .095 r
.50606 .5507 m .5091 .55304 L .52293 .55405 L p F P
0 0 1 r
s
.24 .35 .67 r
.44756 .5181 m
.46017 .51829 L
s
.49172 .5036 m
.46017 .51829 L
s
.46017 .51829 m
.47556 .51705 L
s
.44448 .51756 m
.44756 .5181 L
s
.43824 .51648 m
.44318 .51734 L
s
.257 .453 .568 r
.412 .44582 m .4129 .46011 L .41797 .47349 L p F P
0 0 1 r
s
.185 .315 .375 r
.42146 .48688 m .41797 .47349 L .4129 .46011 L p F P
0 0 1 r
s
0 0 0 r
.41462 .46732 m
.41548 .46818 L
s
.41065 .46079 m
.41429 .46446 L
s
.41635 .46905 m
.4466 .4995 L
s
.53859 .37076 m
.5317 .38253 L
s
.5317 .38253 m
.52557 .37753 L
s
.4485 .37208 m
.45935 .38918 L
s
.43983 .38953 m
.45935 .38918 L
s
.24 .35 .67 r
.54074 .38029 m
.53112 .38242 L
s
.53745 .37055 m
.53112 .38242 L
s
.34 .657 .877 r
.45679 .35165 m .44658 .35851 L .4388 .36915 L p F P
0 0 1 r
s
.281 .544 .712 r
.42964 .3792 m .4388 .36915 L .44658 .35851 L p F P
0 0 1 r
s
.24 .35 .67 r
.71792 .43662 m
.71037 .42957 L
s
.71037 .42957 m
.75481 .40699 L
s
0 0 0 r
.64163 .48703 m
.65309 .48279 L
s
.63803 .46162 m
.64132 .46624 L
s
.64132 .46624 m
.65309 .48279 L
s
.035 .065 .128 r
.63165 .40762 m .63625 .42123 L .63284 .40738 L p F P
0 0 1 r
s
0 0 0 r
.63562 .41865 m
.63662 .42009 L
s
.035 .065 .128 r
.63284 .40738 m .62835 .39425 L .63165 .40762 L p F P
0 0 1 r
s
0 0 0 r
.61848 .4031 m
.63087 .42081 L
s
.24 .35 .67 r
.60886 .38422 m
.62091 .38311 L
s
.4996 .50295 m
.47556 .51705 L
s
.47556 .51705 m
.4931 .51441 L
s
.273 .539 .718 r
.44658 .35851 m .45679 .35165 L .46669 .34341 L p F P
0 0 1 r
s
.24 .35 .67 r
.48615 .37781 m
.45981 .38817 L
s
.44041 .38821 m
.45981 .38817 L
s
0 0 0 r
.45602 .48575 m
.47666 .50681 L
s
.48742 .50417 m
.47666 .50681 L
s
.49514 .3762 m
.49633 .38099 L
s
.46814 .36767 m
.49633 .38099 L
s
.24 .35 .67 r
.44122 .5155 m
.44131 .51547 L
s
.43824 .51648 m
.44122 .5155 L
s
.53168 .50543 m
.53488 .51218 L
s
.53488 .51218 m
.56332 .50345 L
s
.61517 .36797 m
.61655 .36756 L
s
.61655 .36756 m
.61751 .36729 L
s
.57129 .3808 m
.56857 .37916 L
s
0 0 0 r
.37933 .42355 m
.41065 .46079 L
s
.41065 .46079 m
.41462 .46732 L
s
.5552 .54858 m .55023 .55127 L .56259 .54758 L p F P
0 0 1 r
s
0 0 0 r
.56259 .54758 m .56998 .54416 L .5552 .54858 L p F P
0 0 1 r
s
0 0 0 r
.61041 .51306 m .60294 .52281 L .61172 .513 L p F P
0 0 1 r
s
0 0 0 r
.60048 .50876 m
.60402 .51715 L
s
.61172 .513 m .62008 .50224 L .61041 .51306 L p F P
0 0 1 r
s
0 0 0 r
.61783 .50516 m
.62225 .51271 L
s
.61782 .50514 m
.61783 .50516 L
s
.60048 .50876 m
.61148 .51076 L
s
.6366 .44941 m .63571 .46364 L .63723 .44989 L p F P
0 0 1 r
s
0 0 0 r
.63723 .44989 m .63814 .43543 L .6366 .44941 L p F P
0 0 1 r
s
.24 .35 .67 r
.54967 .37884 m
.54074 .38029 L
s
.55663 .36627 m
.54074 .38029 L
s
.56332 .50345 m
.57445 .50589 L
s
.57445 .50589 m
.60948 .49332 L
s
.138 .297 .454 r
.56518 .3359 m .5737 .33822 L .55949 .33271 L p F P
0 0 1 r
s
.138 .297 .454 r
.55949 .33271 m .55343 .33135 L .56518 .3359 L p F P
0 0 1 r
s
0 0 0 r
.59091 .53134 m .58292 .5381 L .59345 .53063 L p F P
0 0 1 r
s
0 0 0 r
.59345 .53063 m .60294 .52281 L .59091 .53134 L p F P
0 0 1 r
s
.24 .35 .67 r
.39569 .39599 m
.3506 .41717 L
s
.33848 .42355 m
.3506 .41717 L
s
.51781 .37601 m
.4986 .38239 L
s
.48615 .37781 m
.4986 .38239 L
s
.057 .074 .103 r
.49591 .55045 m .4903 .5476 L .47594 .54273 L p F P
0 0 1 r
s
.059 .077 .107 r
.4903 .5476 m .49591 .55045 L .5091 .55304 L p F P
0 0 1 r
s
0 0 0 r
.61848 .4031 m
.60647 .3991 L
s
.60647 .3991 m
.58349 .37208 L
s
.24 .35 .67 r
.69438 .39403 m
.66536 .39193 L
s
.66536 .39193 m
.68614 .37827 L
s
0 0 0 r
.56209 .37705 m
.55004 .38188 L
s
.55004 .38188 m
.53859 .37076 L
s
.24 .35 .67 r
.56857 .37916 m
.5639 .37827 L
s
.55751 .37816 m
.54967 .37884 L
s
.57447 .36337 m
.54967 .37884 L
s
.226 .464 .638 r
.47927 .33661 m .48719 .33457 L .49934 .33042 L p F P
0 0 1 r
s
.283 .562 .768 r
.48719 .33457 m .47927 .33661 L .46669 .34341 L p F P
0 0 1 r
s
.24 .35 .67 r
.50858 .50159 m
.4931 .51441 L
s
.4931 .51441 m
.51207 .51049 L
s
.62635 .49165 m
.62705 .49151 L
s
.64063 .48874 m
.68466 .47028 L
s
.72074 .44379 m
.71792 .43662 L
s
.71792 .43662 m
.76428 .4132 L
s
.40028 .50093 m
.39122 .50996 L
s
.34839 .45874 m
.31145 .47933 L
s
.33054 .48389 m
.31145 .47933 L
s
.5639 .37827 m
.55751 .37816 L
s
.3 .566 .733 r
.42964 .3792 m .42275 .39086 L .41823 .40413 L p F P
0 0 1 r
s
.24 .35 .67 r
.42295 .39636 m
.44041 .38821 L
s
0 0 0 r
.42317 .39225 m
.44386 .41802 L
s
.41364 .41761 m .41823 .40413 L .42275 .39086 L p F P
0 0 1 r
s
0 0 0 r
.42228 .39114 m
.42254 .39146 L
s
.42254 .39146 m
.42254 .39146 L
s
.24 .35 .67 r
.41944 .3912 m
.42031 .3908 L
s
.38707 .40636 m
.41944 .3912 L
s
0 0 0 r
.41385 .40222 m
.41739 .40658 L
s
.41739 .40658 m
.41739 .40658 L
s
.24 .35 .67 r
.59013 .36199 m
.55751 .37816 L
s
.149 .229 .288 r
.4362 .51037 m .44393 .52037 L .45516 .52927 L p F P
0 0 1 r
s
.24 .35 .67 r
.43262 .51348 m
.43824 .51648 L
s
.078 .101 .14 r
.46357 .53629 m .45516 .52927 L .44393 .52037 L p F P
0 0 1 r
s
.101 .135 .184 r
.45516 .52927 m .46357 .53629 L .47594 .54273 L p F P
0 0 1 r
s
.233 .444 .556 r
.62602 .49008 m .62008 .50224 L .62573 .49043 L p F P
0 0 1 r
s
.24 .35 .67 r
.625 .49214 m
.62601 .49178 L
s
.58426 .50672 m
.6249 .49217 L
s
.62601 .49178 m
.62635 .49165 L
s
.233 .444 .556 r
.62573 .49043 m .63207 .47743 L .62602 .49008 L p F P
0 0 1 r
s
.24 .35 .67 r
.62705 .49151 m
.64063 .48874 L
s
0 0 0 r
.62722 .49015 m
.64141 .51487 L
s
.177 .289 .352 r
.42146 .48688 m .42753 .49925 L .4362 .51037 L p F P
0 0 1 r
s
.105 .153 .198 r
.44393 .52037 m .4362 .51037 L .42753 .49925 L p F P
0 0 1 r
s
.24 .35 .67 r
.38796 .51771 m
.43094 .50923 L
s
.39122 .50996 m
.4279 .50468 L
s
.43094 .50923 m
.43262 .51348 L
s
.43262 .51348 m
.43709 .51225 L
s
.43709 .51225 m
.43753 .51213 L
s
0 0 0 r
.5264 .36071 m
.52557 .37753 L
s
.52557 .37753 m
.51937 .37332 L
s
.55345 .50093 m
.58096 .51313 L
s
.58096 .51313 m
.57659 .50308 L
s
.57659 .50308 m
.60048 .50876 L
s
.60048 .50876 m
.59093 .49273 L
s
.42228 .39114 m
.42266 .3911 L
s
.42266 .3911 m
.42267 .3911 L
s
.13 .204 .254 r
.62136 .38238 m .62835 .39425 L .6204 .3815 L p F P
0 0 1 r
s
.24 .35 .67 r
.62179 .38303 m
.64886 .38052 L
s
.62174 .38303 m
.62179 .38303 L
s
.13 .204 .254 r
.6204 .3815 m .6139 .37042 L .62136 .38238 L p F P
0 0 1 r
s
.24 .35 .67 r
.60886 .38422 m
.61579 .37764 L
s
.6177 .37215 m
.61873 .37191 L
s
.61539 .37271 m
.6177 .37215 L
s
.61533 .37272 m
.61539 .37271 L
s
.57196 .3831 m
.6149 .37282 L
s
.57056 .38597 m
.61579 .37764 L
s
.38285 .48979 m
.3643 .50264 L
s
.40028 .50093 m
.3643 .50264 L
s
0 0 0 r
.62722 .49015 m
.64163 .48703 L
s
.25 .455 .564 r
.41364 .41761 m .41175 .43178 L .412 .44582 L p F P
0 0 1 r
s
.01 .018 .036 r
.4129 .46011 m .412 .44582 L .41175 .43178 L p F P
0 0 1 r
s
0 0 0 r
.3857 .40309 m
.41116 .43383 L
s
.41116 .43383 m
.4118 .43461 L
s
.38449 .43153 m
.41018 .46204 L
s
.41462 .46732 m
.41544 .46803 L
s
.49525 .37227 m
.49514 .3762 L
s
.24 .35 .67 r
.38659 .40095 m
.33848 .42355 L
s
.33088 .43037 m
.33848 .42355 L
s
0 0 0 r
.46814 .36767 m
.47315 .37852 L
s
.4485 .37208 m
.47315 .37852 L
s
.213 .439 .592 r
.56998 .54416 m .56259 .54758 L .57339 .54252 L p F P
0 0 1 r
s
.213 .439 .592 r
.57339 .54252 m .58292 .5381 L .56998 .54416 L p F P
0 0 1 r
s
.025 .033 .046 r
.55343 .33135 m .55949 .33271 L .54366 .32917 L p F P
0 0 1 r
s
.025 .033 .046 r
.54366 .32917 m .54035 .32842 L .55343 .33135 L p F P
0 0 1 r
s
.068 .088 .122 r
.58563 .34542 m .59481 .35138 L .58111 .3431 L p F P
0 0 1 r
s
.068 .088 .122 r
.58111 .3431 m .5737 .33822 L .58563 .34542 L p F P
0 0 1 r
s
0 0 0 r
.54152 .51299 m
.54624 .51375 L
s
.52474 .48702 m
.54624 .51375 L
s
.54624 .51375 m
.55004 .51334 L
s
.24 .35 .67 r
.61579 .37764 m
.61777 .37733 L
s
.61817 .37727 m
.61822 .37726 L
s
.61579 .37764 m
.61676 .37575 L
s
.61699 .37529 m
.61873 .37191 L
s
.61697 .37534 m
.61699 .37529 L
s
0 0 0 r
.61848 .4031 m
.62823 .40804 L
s
.52474 .48702 m
.55004 .51334 L
s
.55004 .51334 m
.55275 .51176 L
s
.226 .464 .638 r
.49934 .33042 m .49397 .33159 L .47927 .33661 L p F P
0 0 1 r
s
0 0 0 r
.49397 .33159 m .49934 .33042 L .51266 .32795 L p F P
0 0 1 r
s
.24 .35 .67 r
.71875 .45092 m
.72074 .44379 L
s
.72074 .44379 m
.76783 .42012 L
s
.51827 .49958 m
.51207 .51049 L
s
.51207 .51049 m
.53168 .50543 L
s
0 0 0 r
.53607 .51109 m
.54152 .51299 L
s
.52474 .48702 m
.54152 .51299 L
s
.103 .145 .192 r
.60527 .36118 m .6139 .37042 L .60236 .35962 L p F P
0 0 1 r
s
.24 .35 .67 r
.61237 .36879 m
.61517 .36797 L
s
.57129 .3808 m
.6122 .36884 L
s
.103 .145 .192 r
.60236 .35962 m .59481 .35138 L .60527 .36118 L p F P
0 0 1 r
s
.24 .35 .67 r
.71937 .3973 m
.69438 .39403 L
s
.69438 .39403 m
.71974 .37754 L
s
0 0 0 r
.49921 .49993 m
.51093 .51029 L
s
.51769 .49948 m
.51093 .51029 L
s
.185 .315 .375 r
.4129 .46011 m .41658 .47404 L .42146 .48688 L p F P
0 0 1 r
s
0 0 0 r
.41595 .46848 m
.42132 .47321 L
s
.41018 .46204 m
.41462 .46732 L
s
.045 .083 .165 r
.42753 .49925 m .42146 .48688 L .41658 .47404 L p F P
0 0 1 r
s
0 0 0 r
.42132 .47321 m
.45283 .50494 L
s
.057 .074 .103 r
.47594 .54273 m .48391 .54639 L .49591 .55045 L p F P
0 0 1 r
s
.113 .236 .376 r
.48391 .54639 m .47594 .54273 L .46357 .53629 L p F P
0 0 1 r
s
.2 .348 .411 r
.63625 .42123 m .63814 .43543 L .63468 .42146 L p F P
0 0 1 r
s
0 0 0 r
.63691 .41587 m
.64106 .42186 L
s
.2 .348 .411 r
.63468 .42146 m .63284 .40738 L .63625 .42123 L p F P
0 0 1 r
s
0 0 0 r
.63548 .41381 m
.63691 .41587 L
s
.62823 .40804 m
.63397 .41629 L
s
.24 .35 .67 r
.68614 .37827 m
.64886 .38052 L
s
.64886 .38052 m
.65931 .37077 L
s
.281 .544 .712 r
.44658 .35851 m .4382 .36748 L .42964 .3792 L p F P
0 0 1 r
s
.24 .35 .67 r
.44041 .38821 m
.47454 .37474 L
s
0 0 0 r
.42275 .39086 m .42964 .3792 L .4382 .36748 L p F P
0 0 1 r
s
.24 .35 .67 r
.42297 .38955 m
.42321 .38953 L
s
.42321 .38953 m
.42355 .38951 L
s
.4242 .38946 m
.44041 .38821 L
s
0 0 0 r
.42368 .39101 m
.43983 .38953 L
s
.24 .35 .67 r
.42031 .3908 m
.42297 .38955 L
s
.53745 .37055 m
.51781 .37601 L
s
.51449 .36835 m
.51781 .37601 L
s
.273 .539 .718 r
.46669 .34341 m .45793 .34906 L .44658 .35851 L p F P
0 0 1 r
s
0 0 0 r
.45793 .34906 m .46669 .34341 L .47927 .33661 L p F P
0 0 1 r
s
0 0 0 r
.46561 .35803 m
.49514 .3762 L
s
.51401 .35222 m
.51937 .37332 L
s
.51937 .37332 m
.51339 .37011 L
s
.24 .35 .67 r
.36435 .46521 m
.33054 .48389 L
s
.35452 .48741 m
.33054 .48389 L
s
.43233 .5061 m
.43252 .50568 L
s
.43094 .50923 m
.43233 .5061 L
s
.43418 .50851 m
.43463 .50841 L
s
.43094 .50923 m
.43418 .50851 L
s
0 0 0 r
.52474 .48702 m
.55275 .51176 L
s
.55275 .51176 m
.55426 .50909 L
s
.02 .026 .036 r
.54035 .32842 m .54366 .32917 L .52693 .32777 L p F P
0 0 1 r
s
.02 .026 .036 r
.52693 .32777 m .52655 .32727 L .54035 .32842 L p F P
0 0 1 r
s
.24 .35 .67 r
.62517 .49177 m
.62612 .49168 L
s
.62612 .49168 m
.62635 .49165 L
s
.62635 .49165 m
.63069 .48983 L
s
0 0 0 r
.53011 .50811 m
.53607 .51109 L
s
.52474 .48702 m
.53607 .51109 L
s
.265 .488 .613 r
.63571 .46364 m .63207 .47743 L .63351 .46424 L p F P
0 0 1 r
s
0 0 0 r
.6345 .47713 m
.64163 .48703 L
s
.265 .488 .613 r
.63351 .46424 m .63723 .44989 L .63571 .46364 L p F P
0 0 1 r
s
0 0 0 r
.49667 .36938 m
.49525 .37227 L
s
.005 .007 .01 r
.5101 .32859 m .51266 .32795 L .52655 .32727 L p F P
0 0 1 r
s
0 0 0 r
.51266 .32795 m .5101 .32859 L .49397 .33159 L p F P
0 0 1 r
s
0 0 0 r
.47155 .48784 m
.48742 .50417 L
s
.49921 .49993 m
.48742 .50417 L
s
.24 .35 .67 r
.38088 .40693 m
.33088 .43037 L
s
.32803 .43748 m
.33088 .43037 L
s
0 0 0 r
.40911 .45869 m
.41129 .46129 L
s
.39319 .43976 m
.40911 .45869 L
s
.42132 .47321 m
.43061 .47834 L
s
.4382 .36748 m .44658 .35851 L .45793 .34906 L p F P
0 0 1 r
s
.005 .007 .01 r
.52655 .32727 m .52693 .32777 L .5101 .32859 L p F P
0 0 1 r
s
.24 .35 .67 r
.55112 .49944 m
.56332 .50345 L
s
.56332 .50345 m
.59039 .4937 L
s
.51449 .36835 m
.48615 .37781 L
s
.47454 .37474 m
.48615 .37781 L
s
0 0 0 r
.62587 .49031 m
.62722 .49015 L
s
.62645 .4891 m
.62699 .48985 L
s
.62699 .48985 m
.62722 .49015 L
s
.167 .362 .525 r
.52333 .55342 m .52293 .55405 L .5091 .55304 L p F P
0 0 1 r
s
.185 .395 .562 r
.52293 .55405 m .52333 .55342 L .53414 .55295 L p F P
0 0 1 r
s
.185 .395 .562 r
.53414 .55295 m .53683 .55346 L .52293 .55405 L p F P
0 0 1 r
s
.289 .563 .746 r
.60294 .52281 m .59345 .53063 L .60112 .52206 L p F P
0 0 1 r
s
.289 .563 .746 r
.60112 .52206 m .61172 .513 L .60294 .52281 L p F P
0 0 1 r
s
0 0 0 r
.62823 .40804 m
.63347 .41222 L
s
.63429 .41287 m
.63548 .41381 L
s
.63417 .41277 m
.63429 .41287 L
s
.24 .35 .67 r
.71197 .45782 m
.71875 .45092 L
s
.71875 .45092 m
.76534 .42758 L
s
0 0 0 r
.57334 .37375 m
.56209 .37705 L
s
.56209 .37705 m
.54525 .36054 L
s
.216 .449 .63 r
.53683 .55346 m .53414 .55295 L .54457 .55125 L p F P
0 0 1 r
s
.216 .449 .63 r
.54457 .55125 m .55023 .55127 L .53683 .55346 L p F P
0 0 1 r
s
0 0 0 r
.52474 .48702 m
.55426 .50909 L
s
.55426 .50909 m
.5545 .50543 L
s
.42275 .39086 m .41832 .40387 L .41364 .41761 L p F P
0 0 1 r
s
0 0 0 r
.40716 .39398 m
.42228 .39114 L
s
.41013 .39764 m
.41385 .40222 L
s
.01 .018 .035 r
.41175 .43178 m .41364 .41761 L .41832 .40387 L p F P
0 0 1 r
s
0 0 0 r
.41192 .41879 m
.41211 .41902 L
s
.502 .34571 m
.51339 .37011 L
s
.51339 .37011 m
.5079 .36804 L
s
.24 .35 .67 r
.42297 .38955 m
.4233 .38942 L
s
.4233 .38942 m
.42369 .38926 L
s
.162 .352 .52 r
.51257 .55263 m .5091 .55304 L .49591 .55045 L p F P
0 0 1 r
s
.167 .362 .525 r
.5091 .55304 m .51257 .55263 L .52333 .55342 L p F P
0 0 1 r
s
0 0 0 r
.49934 .36766 m
.49667 .36938 L
s
.24 .35 .67 r
.7397 .40165 m
.71937 .3973 L
s
.71937 .3973 m
.74878 .37839 L
s
0 0 0 r
.5239 .50419 m
.53011 .50811 L
s
.52474 .48702 m
.53011 .50811 L
s
.284 .563 .76 r
.58292 .5381 m .57339 .54252 L .58216 .5363 L p F P
0 0 1 r
s
.284 .563 .76 r
.58216 .5363 m .59345 .53063 L .58292 .5381 L p F P
0 0 1 r
s
.24 .35 .67 r
.52828 .49698 m
.53168 .50543 L
s
.53168 .50543 m
.55112 .49944 L
s
.307 .584 .764 r
.62008 .50224 m .61172 .513 L .61682 .5023 L p F P
0 0 1 r
s
0 0 0 r
.61018 .49208 m
.61652 .50292 L
s
.307 .584 .764 r
.61682 .5023 m .62573 .49043 L .62008 .50224 L p F P
0 0 1 r
s
0 0 0 r
.61018 .49208 m
.62579 .49032 L
s
.24 .35 .67 r
.60948 .49332 m
.62469 .49182 L
s
.41485 .49096 m
.40028 .50093 L
s
.01 .018 .036 r
.41175 .43178 m .41266 .4463 L .4129 .46011 L p F P
0 0 1 r
s
.042 .079 .156 r
.41658 .47404 m .4129 .46011 L .41266 .4463 L p F P
0 0 1 r
s
0 0 0 r
.41369 .46414 m
.41458 .46519 L
s
.41548 .46627 m
.42132 .47321 L
s
.08 .105 .145 r
.5737 .33822 m .58111 .3431 L .56477 .33677 L p F P
0 0 1 r
s
.08 .105 .145 r
.56477 .33677 m .55949 .33271 L .5737 .33822 L p F P
0 0 1 r
s
.197 .331 .397 r
.62835 .39425 m .63284 .40738 L .62457 .39417 L p F P
0 0 1 r
s
.197 .331 .397 r
.62457 .39417 m .6204 .3815 L .62835 .39425 L p F P
0 0 1 r
s
0 0 0 r
.54525 .36054 m
.53859 .37076 L
s
.53859 .37076 m
.5264 .36071 L
s
.24 .35 .67 r
.38434 .47109 m
.35452 .48741 L
s
.38285 .48979 m
.35452 .48741 L
s
.105 .153 .198 r
.42753 .49925 m .43606 .51029 L .44393 .52037 L p F P
0 0 1 r
s
.24 .35 .67 r
.43252 .50567 m
.4333 .5039 L
s
0 0 0 r
.44226 .48255 m
.46718 .50781 L
s
.24 .35 .67 r
.43093 .50425 m
.43134 .50419 L
s
.43136 .50418 m
.4333 .5039 L
s
.4279 .50468 m
.43093 .50425 L
s
0 0 0 r
.43061 .47834 m
.45918 .50718 L
s
.078 .101 .14 r
.44393 .52037 m .45374 .5285 L .46357 .53629 L p F P
0 0 1 r
s
.102 .206 .351 r
.45374 .5285 m .44393 .52037 L .43606 .51029 L p F P
0 0 1 r
s
.24 .35 .67 r
.43778 .51206 m
.47769 .50112 L
s
.44165 .51536 m
.48053 .50266 L
s
.44756 .5181 m
.48527 .5035 L
s
0 0 0 r
.5079 .36804 m
.50314 .36721 L
s
.24 .35 .67 r
.55663 .36627 m
.53745 .37055 L
s
.54357 .36023 m
.53745 .37055 L
s
.37874 .41378 m
.32803 .43748 L
s
.33004 .4447 m
.32803 .43748 L
s
.255 .517 .718 r
.55023 .55127 m .54457 .55125 L .55417 .54838 L p F P
0 0 1 r
s
.255 .517 .718 r
.55417 .54838 m .56259 .54758 L .55023 .55127 L p F P
0 0 1 r
s
0 0 0 r
.50314 .36721 m
.49934 .36766 L
s
.44226 .48255 m
.43061 .47834 L
s
.133 .279 .443 r
.4736 .54101 m .46357 .53629 L .45374 .5285 L p F P
0 0 1 r
s
.113 .236 .376 r
.46357 .53629 m .4736 .54101 L .48391 .54639 L p F P
0 0 1 r
s
.169 .362 .541 r
.50232 .55061 m .49591 .55045 L .48391 .54639 L p F P
0 0 1 r
s
.162 .352 .52 r
.49591 .55045 m .50232 .55061 L .51257 .55263 L p F P
0 0 1 r
s
.24 .35 .67 r
.59039 .4937 m
.60948 .49332 L
s
.002 .002 .003 r
.47238 .34126 m .47927 .33661 L .49397 .33159 L p F P
0 0 1 r
s
0 0 0 r
.47927 .33661 m .47238 .34126 L .45793 .34906 L p F P
0 0 1 r
s
0 0 0 r
.55114 .49578 m
.57659 .50308 L
s
.57659 .50308 m
.56992 .4921 L
s
.24 .35 .67 r
.70052 .46433 m
.71197 .45782 L
s
.71197 .45782 m
.75681 .4354 L
s
0 0 0 r
.52474 .48702 m
.5545 .50543 L
s
.5545 .50543 m
.55345 .50093 L
s
.63548 .41381 m
.64002 .42027 L
s
.63396 .41201 m
.63401 .41207 L
s
.63401 .41207 m
.63548 .41381 L
s
.277 .496 .627 r
.63814 .43543 m .63723 .44989 L .63379 .43614 L p F P
0 0 1 r
s
0 0 0 r
.63785 .44417 m
.64376 .45256 L
s
.277 .496 .627 r
.63379 .43614 m .63468 .42146 L .63814 .43543 L p F P
0 0 1 r
s
0 0 0 r
.38662 .36308 m
.40716 .39398 L
s
.39485 .39799 m
.40716 .39398 L
s
.24 .35 .67 r
.71974 .37754 m
.68614 .37827 L
s
.68614 .37827 m
.70002 .36556 L
s
.045 .083 .165 r
.41658 .47404 m .42298 .48726 L .42753 .49925 L p F P
0 0 1 r
s
.081 .157 .289 r
.43606 .51029 m .42753 .49925 L .42298 .48726 L p F P
0 0 1 r
s
.24 .35 .67 r
.42684 .49875 m
.42744 .4987 L
s
.42744 .4987 m
.42771 .49868 L
s
.42939 .49854 m
.43965 .4977 L
s
.40028 .50093 m
.42684 .49875 L
s
.4333 .5039 m
.43965 .4977 L
s
.43495 .50833 m
.47689 .49893 L
s
0 0 0 r
.59093 .49273 m
.61018 .49208 L
s
.46561 .35803 m
.46814 .36767 L
s
.51769 .49948 m
.5239 .50419 L
s
.52474 .48702 m
.5239 .50419 L
s
.173 .279 .343 r
.6139 .37042 m .6204 .3815 L .60805 .36997 L p F P
0 0 1 r
s
.24 .35 .67 r
.61751 .36729 m
.61873 .37191 L
s
.61873 .37191 m
.66387 .36225 L
s
.62132 .37677 m
.65931 .37077 L
s
.61822 .37726 m
.62132 .37677 L
s
.173 .279 .343 r
.60805 .36997 m .60236 .35962 L .6139 .37042 L p F P
0 0 1 r
s
.24 .35 .67 r
.56857 .37916 m
.60595 .36615 L
s
.60903 .36508 m
.6099 .36478 L
s
.60858 .36524 m
.60903 .36508 L
s
.6099 .36478 m
.61215 .364 L
s
.5639 .37827 m
.60289 .3622 L
s
0 0 0 r
.4382 .36748 m .43188 .37837 L .42275 .39086 L p F P
0 0 1 r
s
0 0 0 r
.42547 .36727 m
.42947 .37347 L
s
.42947 .37347 m
.43022 .37463 L
s
.43022 .37463 m
.43119 .37614 L
s
.43223 .37776 m
.43983 .38953 L
s
.43119 .37614 m
.43177 .37704 L
s
.006 .012 .024 r
.41832 .40387 m .42275 .39086 L .43188 .37837 L p F P
0 0 1 r
s
.24 .35 .67 r
.40793 .39216 m
.42224 .38968 L
s
.42224 .38968 m
.42297 .38955 L
s
0 0 0 r
.42171 .39027 m
.42228 .39114 L
s
.24 .35 .67 r
.66223 .35537 m
.61751 .36729 L
s
.61215 .364 m
.61751 .36729 L
s
.132 .196 .252 r
.59481 .35138 m .60236 .35962 L .58721 .35049 L p F P
0 0 1 r
s
.132 .196 .252 r
.58721 .35049 m .58111 .3431 L .59481 .35138 L p F P
0 0 1 r
s
.24 .35 .67 r
.48527 .5035 m
.49172 .5036 L
s
.52474 .48702 m
.49172 .5036 L
s
.49172 .5036 m
.4996 .50295 L
s
.326 .607 .788 r
.63207 .47743 m .62573 .49043 L .62704 .47811 L p F P
0 0 1 r
s
.24 .35 .67 r
.63059 .48443 m
.64134 .4799 L
s
.62795 .48554 m
.62815 .48545 L
s
.60948 .49332 m
.62617 .48629 L
s
.62815 .48545 m
.63059 .48443 L
s
.326 .607 .788 r
.62704 .47811 m .63351 .46424 L .63207 .47743 L p F P
0 0 1 r
s
.24 .35 .67 r
.63069 .48983 m
.66478 .47551 L
s
0 0 0 r
.63286 .47485 m
.63295 .47498 L
s
.6326 .47449 m
.63286 .47485 L
s
.63295 .47498 m
.6345 .47713 L
s
.24 .35 .67 r
.48053 .50266 m
.48527 .5035 L
s
.52474 .48702 m
.48527 .5035 L
s
.75481 .40699 m
.7397 .40165 L
s
.7397 .40165 m
.77245 .38079 L
s
.70002 .36556 m
.65931 .37077 L
s
.65931 .37077 m
.66387 .36225 L
s
.38025 .42134 m
.33004 .4447 L
s
.33687 .45184 m
.33004 .4447 L
s
.40793 .39216 m
.42206 .38655 L
s
.39569 .39599 m
.40793 .39216 L
s
.57447 .36337 m
.55663 .36627 L
s
.57202 .35384 m
.55663 .36627 L
s
.295 .586 .808 r
.56259 .54758 m .55417 .54838 L .56254 .54445 L p F P
0 0 1 r
s
.295 .586 .808 r
.56254 .54445 m .57339 .54252 L .56259 .54758 L p F P
0 0 1 r
s
.24 .35 .67 r
.52474 .48702 m
.4996 .50295 L
s
.4996 .50295 m
.50858 .50159 L
s
.47769 .50112 m
.48053 .50266 L
s
.52474 .48702 m
.48053 .50266 L
s
0 0 0 r
.48846 .48876 m
.49921 .49993 L
s
.51175 .49417 m
.49921 .49993 L
s
.24 .35 .67 r
.40789 .47623 m
.38285 .48979 L
s
.41485 .49096 m
.38285 .48979 L
s
0 0 0 r
.45602 .48575 m
.44226 .48255 L
s
.08 .105 .145 r
.55949 .33271 m .56477 .33677 L .54654 .3327 L p F P
0 0 1 r
s
.08 .105 .145 r
.54654 .3327 m .54366 .32917 L .55949 .33271 L p F P
0 0 1 r
s
.24 .35 .67 r
.53816 .49392 m
.55112 .49944 L
s
.55112 .49944 m
.56956 .49276 L
s
.68466 .47028 m
.70052 .46433 L
s
.70052 .46433 m
.74245 .44338 L
s
.002 .003 .004 r
.45072 .35707 m .45793 .34906 L .47238 .34126 L p F P
0 0 1 r
s
0 0 0 r
.45793 .34906 m .45072 .35707 L .4382 .36748 L p F P
0 0 1 r
s
.184 .384 .577 r
.493 .54746 m .48391 .54639 L .4736 .54101 L p F P
0 0 1 r
s
.169 .362 .541 r
.48391 .54639 m .493 .54746 L .50232 .55061 L p F P
0 0 1 r
s
.24 .35 .67 r
.51139 .36239 m
.47454 .37474 L
s
.46406 .37328 m
.47454 .37474 L
s
.52474 .48702 m
.50858 .50159 L
s
.50858 .50159 m
.51827 .49958 L
s
.01 .018 .035 r
.41832 .40387 m .4165 .41791 L .41175 .43178 L p F P
0 0 1 r
s
.039 .073 .145 r
.41266 .4463 m .41175 .43178 L .4165 .41791 L p F P
0 0 1 r
s
0 0 0 r
.39485 .39799 m
.409 .41523 L
s
.409 .41523 m
.41192 .41879 L
s
.43188 .37837 m .4382 .36748 L .45072 .35707 L p F P
0 0 1 r
s
0 0 0 r
.44309 .36062 m
.44408 .36272 L
s
.44408 .36272 m
.44415 .36286 L
s
.44465 .36393 m
.4485 .37208 L
s
.44826 .35912 m
.44827 .35912 L
s
.44873 .35932 m
.46814 .36767 L
s
.43629 .36953 m
.43693 .36966 L
s
.43917 .37013 m
.4485 .37208 L
s
.42547 .36727 m
.43629 .36953 L
s
.034 .044 .061 r
.48929 .33549 m .49397 .33159 L .5101 .32859 L p F P
0 0 1 r
s
.002 .002 .003 r
.49397 .33159 m .48929 .33549 L .47238 .34126 L p F P
0 0 1 r
s
0 0 0 r
.64172 .42727 m
.64002 .42027 L
s
.63528 .41464 m
.64002 .42027 L
s
.24 .35 .67 r
.47689 .49893 m
.47769 .50112 L
s
.52474 .48702 m
.47769 .50112 L
s
.54357 .36023 m
.51449 .36835 L
s
.51139 .36239 m
.51449 .36835 L
s
.61215 .364 m
.6544 .35046 L
s
.6067 .36294 m
.61215 .364 L
s
.60596 .3628 m
.6067 .36294 L
s
.60289 .3622 m
.60389 .3624 L
s
0 0 0 r
.52474 .48702 m
.55345 .50093 L
s
.55345 .50093 m
.55114 .49578 L
s
.58349 .37208 m
.57334 .37375 L
s
.24 .35 .67 r
.56956 .49276 m
.59039 .4937 L
s
.59039 .4937 m
.61492 .48332 L
s
.344 .671 .9 r
.59345 .53063 m .58216 .5363 L .58851 .52916 L p F P
0 0 1 r
s
.344 .671 .9 r
.58851 .52916 m .60112 .52206 L .59345 .53063 L p F P
0 0 1 r
s
.24 .35 .67 r
.59013 .36199 m
.57447 .36337 L
s
.44975 .49089 m
.43965 .4977 L
s
.48148 .49304 m
.43965 .4977 L
s
.042 .079 .156 r
.41266 .4463 m .41638 .46079 L .41658 .47404 L p F P
0 0 1 r
s
0 0 0 r
.41129 .46129 m
.41369 .46414 L
s
.069 .13 .251 r
.42298 .48726 m .41658 .47404 L .41638 .46079 L p F P
0 0 1 r
s
0 0 0 r
.37189 .36387 m
.39485 .39799 L
s
.3857 .40309 m
.39485 .39799 L
s
.24 .35 .67 r
.38539 .4294 m
.33687 .45184 L
s
.34839 .45874 m
.33687 .45184 L
s
.362 .7 .922 r
.61172 .513 m .60112 .52206 L .60553 .51272 L p F P
0 0 1 r
s
.362 .7 .922 r
.60553 .51272 m .61682 .5023 L .61172 .513 L p F P
0 0 1 r
s
.24 .35 .67 r
.52474 .48702 m
.51827 .49958 L
s
.51827 .49958 m
.52828 .49698 L
s
0 0 0 r
.56992 .4921 m
.59093 .49273 L
s
.59093 .49273 m
.57829 .47593 L
s
.51175 .49417 m
.51769 .49948 L
s
.52474 .48702 m
.51769 .49948 L
s
.279 .482 .617 r
.63284 .40738 m .63468 .42146 L .62629 .40813 L p F P
0 0 1 r
s
0 0 0 r
.63321 .41219 m
.63528 .41464 L
s
.279 .482 .617 r
.62629 .40813 m .62457 .39417 L .63284 .40738 L p F P
0 0 1 r
s
.24 .35 .67 r
.60461 .36155 m
.60499 .3614 L
s
.60289 .3622 m
.60363 .36192 L
s
.59013 .36199 m
.60289 .3622 L
s
.60237 .35637 m
.62179 .34746 L
s
.072 .094 .13 r
.54366 .32917 m .54654 .3327 L .52727 .3311 L p F P
0 0 1 r
s
.072 .094 .13 r
.52727 .3311 m .52693 .32777 L .54366 .32917 L p F P
0 0 1 r
s
.24 .35 .67 r
.47817 .4962 m
.47689 .49893 L
s
.52474 .48702 m
.47689 .49893 L
s
.76428 .4132 m
.75481 .40699 L
s
.75481 .40699 m
.79007 .38472 L
s
.057 .074 .102 r
.50787 .33204 m .5101 .32859 L .52693 .32777 L p F P
0 0 1 r
s
.034 .044 .061 r
.5101 .32859 m .50787 .33204 L .48929 .33549 L p F P
0 0 1 r
s
.24 .35 .67 r
.66478 .47551 m
.68466 .47028 L
s
.68466 .47028 m
.7226 .4513 L
s
0 0 0 r
.43789 .46382 m
.45602 .48575 L
s
.47155 .48784 m
.45602 .48575 L
s
.102 .206 .351 r
.43606 .51029 m .44689 .51969 L .45374 .5285 L p F P
0 0 1 r
s
.156 .324 .508 r
.46542 .53452 m .45374 .5285 L .44689 .51969 L p F P
0 0 1 r
s
.133 .279 .443 r
.45374 .5285 m .46542 .53452 L .4736 .54101 L p F P
0 0 1 r
s
.24 .35 .67 r
.38659 .40095 m
.39569 .39599 L
s
0 0 0 r
.5272 .34554 m
.5264 .36071 L
s
.5264 .36071 m
.51401 .35222 L
s
.346 .684 .93 r
.57339 .54252 m .56254 .54445 L .56931 .53963 L p F P
0 0 1 r
s
.346 .684 .93 r
.56931 .53963 m .58216 .5363 L .57339 .54252 L p F P
0 0 1 r
s
.057 .074 .102 r
.52693 .32777 m .52727 .3311 L .50787 .33204 L p F P
0 0 1 r
s
.24 .35 .67 r
.41485 .49096 m
.42261 .48681 L
s
.42261 .48681 m
.42271 .48676 L
s
.361 .653 .844 r
.63723 .44989 m .63351 .46424 L .63016 .45106 L p F P
0 0 1 r
s
0 0 0 r
.63612 .45893 m
.63648 .45944 L
s
.63536 .45786 m
.63612 .45893 L
s
.63648 .45944 m
.63803 .46162 L
s
.361 .653 .844 r
.63016 .45106 m .63379 .43614 L .63723 .44989 L p F P
0 0 1 r
s
0 0 0 r
.62955 .4497 m
.63025 .45068 L
s
.63644 .44217 m
.63785 .44417 L
s
.24 .35 .67 r
.74878 .37839 m
.71974 .37754 L
s
.71974 .37754 m
.73682 .36216 L
s
0 0 0 r
.64053 .43463 m
.64172 .42727 L
s
.271 .543 .782 r
.52377 .54995 m .52333 .55342 L .51257 .55263 L p F P
0 0 1 r
s
.284 .567 .809 r
.52333 .55342 m .52377 .54995 L .53119 .54963 L p F P
0 0 1 r
s
.284 .567 .809 r
.53119 .54963 m .53414 .55295 L .52333 .55342 L p F P
0 0 1 r
s
.081 .157 .289 r
.42298 .48726 m .43197 .49943 L .43606 .51029 L p F P
0 0 1 r
s
.24 .35 .67 r
.4257 .49094 m
.44975 .49089 L
s
.42437 .49094 m
.42437 .49094 L
s
.41485 .49096 m
.42437 .49094 L
s
.127 .262 .429 r
.44689 .51969 m .43606 .51029 L .43197 .49943 L p F P
0 0 1 r
s
.24 .35 .67 r
.43505 .5036 m
.47817 .4962 L
s
.52474 .48702 m
.52828 .49698 L
s
.52828 .49698 m
.53816 .49392 L
s
.306 .609 .861 r
.53414 .55295 m .53119 .54963 L .53833 .54846 L p F P
0 0 1 r
s
.306 .609 .861 r
.53833 .54846 m .54457 .55125 L .53414 .55295 L p F P
0 0 1 r
s
.24 .35 .67 r
.39404 .43778 m
.34839 .45874 L
s
.36435 .46521 m
.34839 .45874 L
s
.137 .207 .263 r
.58111 .3431 m .58721 .35049 L .56912 .3435 L p F P
0 0 1 r
s
.137 .207 .263 r
.56912 .3435 m .56477 .33677 L .58111 .3431 L p F P
0 0 1 r
s
.209 .423 .643 r
.48502 .54328 m .4736 .54101 L .46542 .53452 L p F P
0 0 1 r
s
.184 .384 .577 r
.4736 .54101 m .48502 .54328 L .493 .54746 L p F P
0 0 1 r
s
.267 .535 .78 r
.5164 .54941 m .51257 .55263 L .50232 .55061 L p F P
0 0 1 r
s
.271 .543 .782 r
.51257 .55263 m .5164 .54941 L .52377 .54995 L p F P
0 0 1 r
s
.24 .35 .67 r
.48148 .49304 m
.47817 .4962 L
s
.52474 .48702 m
.47817 .4962 L
s
.406 .773 .999 r
.62573 .49043 m .61682 .5023 L .61795 .49115 L p F P
0 0 1 r
s
.406 .773 .999 r
.61795 .49115 m .62704 .47811 L .62573 .49043 L p F P
0 0 1 r
s
0 0 0 r
.6081 .46395 m
.62283 .48415 L
s
.006 .012 .024 r
.43188 .37837 m .42782 .39093 L .41832 .40387 L p F P
0 0 1 r
s
.24 .35 .67 r
.42904 .38715 m
.46406 .37328 L
s
.4277 .38432 m
.42817 .38413 L
s
.42206 .38655 m
.4277 .38432 L
s
0 0 0 r
.40465 .36423 m
.42171 .39027 L
s
.034 .064 .127 r
.4165 .41791 m .41832 .40387 L .42782 .39093 L p F P
0 0 1 r
s
0 0 0 r
.52474 .48702 m
.55114 .49578 L
s
.55114 .49578 m
.54767 .49019 L
s
.24 .35 .67 r
.7062 .35441 m
.66387 .36225 L
s
.66387 .36225 m
.66223 .35537 L
s
.64134 .4799 m
.66478 .47551 L
s
.66478 .47551 m
.69776 .45897 L
s
.54749 .49052 m
.56956 .49276 L
s
.56956 .49276 m
.58619 .48568 L
s
.26 .433 .558 r
.6204 .3815 m .62457 .39417 L .61172 .38222 L p F P
0 0 1 r
s
.26 .433 .558 r
.61172 .38222 m .60805 .36997 L .6204 .3815 L p F P
0 0 1 r
s
0 0 0 r
.36091 .36662 m
.3857 .40309 L
s
.37996 .40915 m
.3857 .40309 L
s
.339 .674 .945 r
.54457 .55125 m .53833 .54846 L .5449 .54649 L p F P
0 0 1 r
s
.339 .674 .945 r
.5449 .54649 m .55417 .54838 L .54457 .55125 L p F P
0 0 1 r
s
0 0 0 r
.41524 .34613 m
.42547 .36727 L
s
.40465 .36423 m
.42547 .36727 L
s
.04 .053 .073 r
.4667 .34845 m .47238 .34126 L .48929 .33549 L p F P
0 0 1 r
s
.002 .003 .004 r
.47238 .34126 m .4667 .34845 L .45072 .35707 L p F P
0 0 1 r
s
0 0 0 r
.54767 .49019 m
.56992 .4921 L
s
.56992 .4921 m
.56118 .48066 L
s
.4577 .47094 m
.47155 .48784 L
s
.48846 .48876 m
.47155 .48784 L
s
.24 .35 .67 r
.76783 .42012 m
.76428 .4132 L
s
.76428 .4132 m
.80114 .39007 L
s
.274 .545 .806 r
.50938 .54803 m .50232 .55061 L .493 .54746 L p F P
0 0 1 r
s
.267 .535 .78 r
.50232 .55061 m .50938 .54803 L .5164 .54941 L p F P
0 0 1 r
s
.039 .073 .145 r
.4165 .41791 m .41738 .43265 L .41266 .4463 L p F P
0 0 1 r
s
.062 .117 .226 r
.41638 .46079 m .41266 .4463 L .41738 .43265 L p F P
0 0 1 r
s
0 0 0 r
.4052 .44803 m
.41345 .45786 L
s
.41345 .45786 m
.41562 .46046 L
s
.41562 .46046 m
.41603 .46095 L
s
.50634 .48849 m
.51175 .49417 L
s
.52474 .48702 m
.51175 .49417 L
s
.207 .334 .43 r
.60236 .35962 m .60805 .36997 L .59182 .36023 L p F P
0 0 1 r
s
.24 .35 .67 r
.59013 .36199 m
.59275 .36079 L
s
.60499 .3614 m
.60611 .36098 L
s
.207 .334 .43 r
.59182 .36023 m .58721 .35049 L .60236 .35962 L p F P
0 0 1 r
s
.24 .35 .67 r
.57447 .36337 m
.58927 .35484 L
s
.5919 .35333 m
.5919 .35332 L
s
.59986 .35752 m
.60011 .35741 L
s
.59963 .35763 m
.59986 .35752 L
s
.60011 .35741 m
.60237 .35637 L
s
.5919 .35332 m
.59464 .35175 L
s
.59464 .35175 m
.59852 .34951 L
s
.52474 .48702 m
.53816 .49392 L
s
.53816 .49392 m
.54749 .49052 L
s
0 0 0 r
.5515 .35217 m
.54525 .36054 L
s
.54525 .36054 m
.5272 .34554 L
s
.63782 .43963 m
.64053 .43463 L
s
.63644 .44217 m
.63782 .43963 L
s
.63571 .42896 m
.64053 .43463 L
s
.24 .35 .67 r
.40599 .44623 m
.36435 .46521 L
s
.38434 .47109 m
.36435 .46521 L
s
.57202 .35384 m
.54357 .36023 L
s
.5493 .35176 m
.54357 .36023 L
s
.455 .37349 m
.46406 .37328 L
s
.46322 .48376 m
.44975 .49089 L
s
.48669 .48957 m
.44975 .49089 L
s
.73682 .36216 m
.70002 .36556 L
s
.70002 .36556 m
.7062 .35441 L
s
.48669 .48957 m
.48148 .49304 L
s
.52474 .48702 m
.48148 .49304 L
s
.38088 .40693 m
.38659 .40095 L
s
.069 .13 .251 r
.41638 .46079 m .42283 .4749 L .42298 .48726 L p F P
0 0 1 r
s
.119 .236 .393 r
.43197 .49943 m .42298 .48726 L .42283 .4749 L p F P
0 0 1 r
s
0 0 0 r
.41695 .46204 m
.43061 .47834 L
s
.24 .35 .67 r
.42649 .48472 m
.43441 .48049 L
s
.62763 .48167 m
.64134 .4799 L
s
.61492 .48332 m
.62425 .48211 L
s
.64134 .4799 m
.66857 .46618 L
s
0 0 0 r
.45072 .35707 m .44529 .36725 L .43188 .37837 L p F P
0 0 1 r
s
0 0 0 r
.44087 .35594 m
.44521 .3578 L
s
.44521 .3578 m
.44826 .35912 L
s
.44087 .35594 m
.44309 .36062 L
s
.046 .076 .135 r
.42782 .39093 m .43188 .37837 L .44529 .36725 L p F P
0 0 1 r
s
.24 .35 .67 r
.43476 .38152 m
.455 .37349 L
s
.42496 .38437 m
.4324 .38142 L
s
.384 .768 1 r
.55417 .54838 m .5449 .54649 L .55061 .5438 L p F P
0 0 1 r
s
.384 .768 1 r
.55061 .5438 m .56254 .54445 L .55417 .54838 L p F P
0 0 1 r
s
.051 .075 .122 r
.44529 .36725 m .45072 .35707 L .4667 .34845 L p F P
0 0 1 r
s
0 0 0 r
.46571 .35008 m
.49525 .37227 L
s
.46561 .35803 m
.46571 .35008 L
s
.45471 .35177 m
.45698 .35307 L
s
.45698 .35307 m
.45719 .35319 L
s
.45968 .35462 m
.46561 .35803 L
s
.447 .884 1 r
.60112 .52206 m .58851 .52916 L .59213 .5214 L p F P
0 0 1 r
s
.447 .884 1 r
.59213 .5214 m .60553 .51272 L .60112 .52206 L p F P
0 0 1 r
s
.391 .675 .878 r
.63468 .42146 m .63379 .43614 L .62546 .42303 L p F P
0 0 1 r
s
0 0 0 r
.63369 .42658 m
.63571 .42896 L
s
.391 .675 .878 r
.62546 .42303 m .62629 .40813 L .63468 .42146 L p F P
0 0 1 r
s
0 0 0 r
.6338 .41789 m
.64172 .42727 L
s
.6284 .41149 m
.6338 .41789 L
s
.62988 .40823 m
.63321 .41219 L
s
.427 .852 1 r
.58216 .5363 m .56931 .53963 L .57419 .53411 L p F P
0 0 1 r
s
.427 .852 1 r
.57419 .53411 m .58851 .52916 L .58216 .5363 L p F P
0 0 1 r
s
0 0 0 r
.47916 .47728 m
.48846 .48876 L
s
.50634 .48849 m
.48846 .48876 L
s
.24 .35 .67 r
.40789 .47623 m
.38434 .47109 L
s
.29 .574 .863 r
.503 .54586 m .493 .54746 L .48502 .54328 L p F P
0 0 1 r
s
.274 .545 .806 r
.493 .54746 m .503 .54586 L .50938 .54803 L p F P
0 0 1 r
s
.137 .207 .272 r
.56477 .33677 m .56912 .3435 L .54891 .339 L p F P
0 0 1 r
s
.137 .207 .272 r
.54891 .339 m .54654 .3327 L .56477 .33677 L p F P
0 0 1 r
s
.467 .857 1 r
.63351 .46424 m .62704 .47811 L .62384 .46582 L p F P
0 0 1 r
s
.467 .857 1 r
.62384 .46582 m .63016 .45106 L .63351 .46424 L p F P
0 0 1 r
s
0 0 0 r
.62003 .45702 m
.62478 .46363 L
s
.24 .35 .67 r
.52474 .48702 m
.54749 .49052 L
s
.54749 .49052 m
.55587 .48693 L
s
0 0 0 r
.35401 .37127 m
.37996 .40915 L
s
.37781 .41603 m
.37996 .40915 L
s
.63532 .4434 m
.63644 .44217 L
s
.63508 .44366 m
.63532 .4434 L
s
.62955 .4497 m
.63083 .4483 L
s
.63496 .44044 m
.63644 .44217 L
s
.63491 .44038 m
.63496 .44044 L
s
.24 .35 .67 r
.77245 .38079 m
.74878 .37839 L
s
.74878 .37839 m
.7687 .3607 L
s
.76534 .42758 m
.76783 .42012 L
s
.76783 .42012 m
.80529 .39674 L
s
.58619 .48568 m
.61492 .48332 L
s
.62745 .47697 m
.63579 .47275 L
s
.62734 .47702 m
.62745 .47697 L
s
.61492 .48332 m
.62682 .47729 L
s
0 0 0 r
.52474 .48702 m
.54767 .49019 L
s
.54767 .49019 m
.54318 .48439 L
s
.24 .35 .67 r
.5493 .35176 m
.51139 .36239 L
s
.50858 .35832 m
.51139 .36239 L
s
0 0 0 r
.51401 .35222 m
.502 .34571 L
s
.156 .324 .508 r
.44689 .51969 m .45976 .5272 L .46542 .53452 L p F P
0 0 1 r
s
.248 .487 .755 r
.47871 .53825 m .46542 .53452 L .45976 .5272 L p F P
0 0 1 r
s
.209 .423 .643 r
.46542 .53452 m .47871 .53825 L .48502 .54328 L p F P
0 0 1 r
s
0 0 0 r
.4369 .34153 m
.44087 .35594 L
s
.41524 .34613 m
.44087 .35594 L
s
.24 .35 .67 r
.49359 .48596 m
.48669 .48957 L
s
.52474 .48702 m
.48669 .48957 L
s
.074 .101 .148 r
.48543 .34208 m .48929 .33549 L .50787 .33204 L p F P
0 0 1 r
s
.04 .053 .073 r
.48929 .33549 m .48543 .34208 L .4667 .34845 L p F P
0 0 1 r
s
0 0 0 r
.47027 .34583 m
.47067 .34619 L
s
.47141 .34685 m
.49667 .36938 L
s
.47376 .34074 m
.47418 .34117 L
s
.48173 .34026 m
.48309 .34197 L
s
.48138 .33981 m
.48173 .34026 L
s
.127 .262 .429 r
.43197 .49943 m .44336 .51022 L .44689 .51969 L p F P
0 0 1 r
s
.208 .409 .645 r
.45976 .5272 m .44689 .51969 L .44336 .51022 L p F P
0 0 1 r
s
.24 .35 .67 r
.70427 .34538 m
.66223 .35537 L
s
.66223 .35537 m
.6544 .35046 L
s
.40789 .47623 m
.42165 .47844 L
s
.42431 .47886 m
.43441 .48049 L
s
.499 .965 1 r
.61682 .5023 m .60553 .51272 L .60646 .50301 L p F P
0 0 1 r
s
.499 .965 1 r
.60646 .50301 m .61795 .49115 L .61682 .5023 L p F P
0 0 1 r
s
0 0 0 r
.59407 .47031 m
.61018 .49208 L
s
.5017 .48268 m
.50634 .48849 L
s
.52474 .48702 m
.50634 .48849 L
s
.24 .35 .67 r
.37874 .41378 m
.38088 .40693 L
s
.55587 .48693 m
.58619 .48568 L
s
.58619 .48568 m
.60026 .4785 L
s
.034 .064 .127 r
.42782 .39093 m .42615 .40485 L .4165 .41791 L p F P
0 0 1 r
s
.24 .35 .67 r
.39569 .39599 m
.42496 .38437 L
s
.079 .137 .245 r
.41738 .43265 m .4165 .41791 L .42615 .40485 L p F P
0 0 1 r
s
0 0 0 r
.46682 .34772 m
.46691 .34753 L
s
.46571 .35008 m
.46631 .3488 L
s
.46404 .3489 m
.46433 .34911 L
s
.46523 .34975 m
.46571 .35008 L
s
.441 .884 1 r
.56254 .54445 m .55061 .5438 L .55522 .5405 L p F P
0 0 1 r
s
.441 .884 1 r
.55522 .5405 m .56931 .53963 L .56254 .54445 L p F P
0 0 1 r
s
0 0 0 r
.62003 .45702 m
.62955 .4497 L
s
.24 .35 .67 r
.45817 .46994 m
.43441 .48049 L
s
.46322 .48376 m
.43441 .48049 L
s
.062 .117 .226 r
.41738 .43265 m .42096 .44771 L .41638 .46079 L p F P
0 0 1 r
s
.122 .231 .382 r
.42283 .4749 m .41638 .46079 L .42096 .44771 L p F P
0 0 1 r
s
0 0 0 r
.42023 .45612 m
.4205 .45644 L
s
.24 .35 .67 r
.38434 .47109 m
.41734 .45618 L
s
.41734 .45618 m
.42093 .45456 L
s
.41874 .47137 m
.42043 .47061 L
s
.42043 .47061 m
.42063 .47052 L
s
.40789 .47623 m
.41874 .47137 L
s
.52474 .48702 m
.55587 .48693 L
s
.55587 .48693 m
.56292 .4833 L
s
.125 .187 .256 r
.54654 .3327 m .54891 .339 L .52754 .33722 L p F P
0 0 1 r
s
.125 .187 .256 r
.52754 .33722 m .52727 .3311 L .54654 .3327 L p F P
0 0 1 r
s
.369 .614 .81 r
.62457 .39417 m .62629 .40813 L .61322 .39606 L p F P
0 0 1 r
s
.369 .614 .81 r
.61322 .39606 m .61172 .38222 L .62457 .39417 L p F P
0 0 1 r
s
.24 .35 .67 r
.75681 .4354 m
.76534 .42758 L
s
.76534 .42758 m
.80237 .40454 L
s
.314 .616 .939 r
.49756 .543 m .48502 .54328 L .47871 .53825 L p F P
0 0 1 r
s
.29 .574 .863 r
.48502 .54328 m .49756 .543 L .503 .54586 L p F P
0 0 1 r
s
0 0 0 r
.35141 .37772 m
.37781 .41603 L
s
.37933 .42355 m
.37781 .41603 L
s
.24 .35 .67 r
.47949 .4766 m
.46322 .48376 L
s
.49359 .48596 m
.46322 .48376 L
s
.102 .148 .21 r
.50604 .33827 m .50787 .33204 L .52727 .3311 L p F P
0 0 1 r
s
.074 .101 .148 r
.50787 .33204 m .50604 .33827 L .48543 .34208 L p F P
0 0 1 r
s
0 0 0 r
.49094 .3415 m
.5079 .36804 L
s
.52474 .48702 m
.52474 .48702 L
s
.49862 .45868 m
.52474 .48702 L
s
.52474 .48702 m
.49588 .46036 L
s
.52474 .48702 m
.49442 .46318 L
s
.52474 .48702 m
.49431 .46702 L
s
.52474 .48702 m
.49554 .4717 L
s
.52474 .48702 m
.49805 .477 L
s
.52474 .48702 m
.5017 .48268 L
s
.52474 .48702 m
.54318 .48439 L
s
.52474 .48702 m
.53784 .47865 L
s
.52474 .48702 m
.53189 .47321 L
s
.52474 .48702 m
.52559 .46832 L
s
.52474 .48702 m
.51922 .46421 L
s
.52474 .48702 m
.51307 .46107 L
s
.52474 .48702 m
.50742 .45905 L
s
.52474 .48702 m
.50253 .45824 L
s
.24 .35 .67 r
.5726 .47152 m
.52474 .48702 L
s
.52474 .48702 m
.56979 .46992 L
s
.52474 .48702 m
.565 .46905 L
s
.52474 .48702 m
.55843 .46894 L
s
.52474 .48702 m
.55037 .46961 L
s
.52474 .48702 m
.54119 .47102 L
s
.52474 .48702 m
.5313 .47311 L
s
.52474 .48702 m
.52116 .47577 L
s
.52474 .48702 m
.5112 .4789 L
s
.52474 .48702 m
.50187 .48235 L
s
.52474 .48702 m
.49359 .48596 L
s
.52474 .48702 m
.56292 .4833 L
s
.52474 .48702 m
.56833 .4798 L
s
.52474 .48702 m
.57184 .47657 L
s
.52474 .48702 m
.57328 .47377 L
s
.119 .236 .393 r
.42283 .4749 m .4319 .48825 L .43197 .49943 L p F P
0 0 1 r
s
.188 .363 .582 r
.44336 .51022 m .43197 .49943 L .4319 .48825 L p F P
0 0 1 r
s
.24 .35 .67 r
.50187 .48235 m
.49359 .48596 L
s
.225 .362 .483 r
.58721 .35049 m .59182 .36023 L .57241 .35276 L p F P
0 0 1 r
s
.24 .35 .67 r
.57202 .35384 m
.57314 .35304 L
s
.57202 .35384 m
.57427 .35348 L
s
.58796 .35124 m
.58804 .35123 L
s
.58782 .35126 m
.58796 .35124 L
s
.58804 .35123 m
.59852 .34951 L
s
.225 .362 .483 r
.57241 .35276 m .56912 .3435 L .58721 .35049 L p F P
0 0 1 r
s
0 0 0 r
.5515 .35217 m
.57334 .37375 L
s
.24 .35 .67 r
.57895 .34884 m
.57934 .34856 L
s
.57934 .34856 m
.58076 .34753 L
s
.58076 .34753 m
.5865 .34339 L
s
0 0 0 r
.6081 .46395 m
.62003 .45702 L
s
.102 .148 .21 r
.52727 .3311 m .52754 .33722 L .50604 .33827 L p F P
0 0 1 r
s
0 0 0 r
.50877 .33281 m
.50945 .33533 L
s
.39196 .33856 m
.40465 .36423 L
s
.38662 .36308 m
.40465 .36423 L
s
.4 .794 1 r
.52424 .54369 m .52377 .54995 L .5164 .54941 L p F P
0 0 1 r
s
.41 .816 1 r
.52377 .54995 m .52424 .54369 L .52802 .54352 L p F P
0 0 1 r
s
.41 .816 1 r
.52802 .54352 m .53119 .54963 L .52377 .54995 L p F P
0 0 1 r
s
.307 .499 .665 r
.60805 .36997 m .61172 .38222 L .59479 .37211 L p F P
0 0 1 r
s
0 0 0 r
.60118 .37593 m
.61249 .38936 L
s
.307 .499 .665 r
.59479 .37211 m .59182 .36023 L .60805 .36997 L p F P
0 0 1 r
s
0 0 0 r
.59227 .3721 m
.61848 .4031 L
s
.58349 .37208 m
.59227 .3721 L
s
.24 .35 .67 r
.60885 .35993 m
.64072 .34778 L
s
.60611 .36098 m
.60885 .35993 L
s
0 0 0 r
.59227 .3721 m
.5965 .37314 L
s
.24 .35 .67 r
.69419 .33893 m
.6544 .35046 L
s
.6544 .35046 m
.64072 .34778 L
s
0 0 0 r
.54318 .48439 m
.56118 .48066 L
s
.54318 .48439 m
.53784 .47865 L
s
.427 .851 1 r
.53119 .54963 m .52802 .54352 L .53166 .54292 L p F P
0 0 1 r
s
.427 .851 1 r
.53166 .54292 m .53833 .54846 L .53119 .54963 L p F P
0 0 1 r
s
.492 .86 1 r
.63379 .43614 m .63016 .45106 L .62208 .43849 L p F P
0 0 1 r
s
.492 .86 1 r
.62208 .43849 m .62546 .42303 L .63379 .43614 L p F P
0 0 1 r
s
0 0 0 r
.63034 .42263 m
.63369 .42658 L
s
.24 .35 .67 r
.38025 .42134 m
.37874 .41378 L
s
.52 1 1 r
.58851 .52916 m .57419 .53411 L .57695 .52811 L p F P
0 0 1 r
s
.52 1 1 r
.57695 .52811 m .59213 .5214 L .58851 .52916 L p F P
0 0 1 r
s
.395 .782 1 r
.52049 .54341 m .5164 .54941 L .50938 .54803 L p F P
0 0 1 r
s
.4 .794 1 r
.5164 .54941 m .52049 .54341 L .52424 .54369 L p F P
0 0 1 r
s
0 0 0 r
.49094 .3415 m
.502 .34571 L
s
.59407 .47031 m
.6081 .46395 L
s
.24 .35 .67 r
.74245 .44338 m
.75681 .4354 L
s
.75681 .4354 m
.79241 .41328 L
s
.551 1 1 r
.62704 .47811 m .61795 .49115 L .61499 .48004 L p F P
0 0 1 r
s
.551 1 1 r
.61499 .48004 m .62384 .46582 L .62704 .47811 L p F P
0 0 1 r
s
.093 .139 .219 r
.46242 .35806 m .4667 .34845 L .48543 .34208 L p F P
0 0 1 r
s
0 0 0 r
.46346 .34849 m
.46404 .3489 L
s
.4671 .34712 m
.46846 .34422 L
s
.46691 .34753 m
.4671 .34712 L
s
.47418 .34117 m
.47536 .34241 L
s
.47536 .34241 m
.47663 .34376 L
s
.47663 .34376 m
.4769 .34404 L
s
.47917 .34643 m
.49934 .36766 L
s
.46846 .34422 m
.46849 .34424 L
s
.46849 .34424 m
.47027 .34583 L
s
.48398 .34309 m
.50314 .36721 L
s
.051 .075 .122 r
.4667 .34845 m .46242 .35806 L .44529 .36725 L p F P
0 0 1 r
s
0 0 0 r
.4369 .34153 m
.45471 .35177 L
s
.24 .35 .67 r
.46406 .37328 m
.50858 .35832 L
s
.046 .076 .135 r
.44529 .36725 m .44179 .3794 L .42782 .39093 L p F P
0 0 1 r
s
.092 .153 .257 r
.42615 .40485 m .42782 .39093 L .44179 .3794 L p F P
0 0 1 r
s
.24 .35 .67 r
.4324 .38142 m
.43261 .38134 L
s
.43261 .38134 m
.43577 .38008 L
s
.38659 .40095 m
.42962 .38389 L
s
.79007 .38472 m
.77245 .38079 L
s
.77245 .38079 m
.79474 .36124 L
s
.62179 .34746 m
.59852 .34951 L
s
.62117 .33769 m
.59852 .34951 L
s
.56292 .4833 m
.60026 .4785 L
s
.56292 .4833 m
.56833 .4798 L
s
0 0 0 r
.56118 .48066 m
.57829 .47593 L
s
.56118 .48066 m
.55072 .46925 L
s
.24 .35 .67 r
.7687 .3607 m
.73682 .36216 L
s
.73682 .36216 m
.74458 .34863 L
s
.449 .897 1 r
.53833 .54846 m .53166 .54292 L .535 .54192 L p F P
0 0 1 r
s
.449 .897 1 r
.535 .54192 m .5449 .54649 L .53833 .54846 L p F P
0 0 1 r
s
0 0 0 r
.57829 .47593 m
.59407 .47031 L
s
.59407 .47031 m
.57446 .44833 L
s
.35324 .38581 m
.37933 .42355 L
s
.38449 .43153 m
.37933 .42355 L
s
.5 1 1 r
.56931 .53963 m .55522 .5405 L .55852 .53673 L p F P
0 0 1 r
s
.5 1 1 r
.55852 .53673 m .57419 .53411 L .56931 .53963 L p F P
0 0 1 r
s
0 0 0 r
.57829 .47593 m
.56304 .45905 L
s
.24 .35 .67 r
.74458 .34863 m
.7062 .35441 L
s
.7062 .35441 m
.70427 .34538 L
s
.395 .781 1 r
.51691 .5427 m .50938 .54803 L .503 .54586 L p F P
0 0 1 r
s
.395 .782 1 r
.50938 .54803 m .51691 .5427 L .52049 .54341 L p F P
0 0 1 r
s
0 0 0 r
.46846 .34422 m
.47376 .34074 L
s
.49805 .477 m
.5017 .48268 L
s
.5017 .48268 m
.47916 .47728 L
s
.24 .35 .67 r
.5112 .4789 m
.50187 .48235 L
s
.50187 .48235 m
.47949 .4766 L
s
.561 1 1 r
.60553 .51272 m .59213 .5214 L .59284 .51335 L p F P
0 0 1 r
s
.561 1 1 r
.59284 .51335 m .60646 .50301 L .60553 .51272 L p F P
0 0 1 r
s
.208 .409 .645 r
.44336 .51022 m .45687 .51933 L .45976 .5272 L p F P
0 0 1 r
s
.286 .554 .87 r
.47436 .53259 m .45976 .5272 L .45687 .51933 L p F P
0 0 1 r
s
.248 .487 .755 r
.45976 .5272 m .47436 .53259 L .47871 .53825 L p F P
0 0 1 r
s
.24 .35 .67 r
.67637 .33541 m
.64072 .34778 L
s
.64072 .34778 m
.62179 .34746 L
s
.098 .156 .252 r
.44179 .3794 m .44529 .36725 L .46242 .35806 L p F P
0 0 1 r
s
.24 .35 .67 r
.44446 .37663 m
.44761 .37538 L
s
.44761 .37538 m
.455 .37349 L
s
.65163 .33498 m
.62179 .34746 L
s
.7226 .4513 m
.74245 .44338 L
s
.74245 .44338 m
.77565 .42274 L
s
.338 .658 1 r
.49327 .53956 m .47871 .53825 L .47436 .53259 L p F P
0 0 1 r
s
.314 .616 .939 r
.47871 .53825 m .49327 .53956 L .49756 .543 L p F P
0 0 1 r
s
.24 .35 .67 r
.62755 .47408 m
.63579 .47275 L
s
.62608 .47432 m
.62755 .47408 L
s
.62607 .47432 m
.62608 .47432 L
s
.60026 .4785 m
.61771 .47568 L
s
.60026 .4785 m
.61112 .47154 L
s
.475 .948 1 r
.5449 .54649 m .535 .54192 L .5379 .54055 L p F P
0 0 1 r
s
.475 .948 1 r
.5379 .54055 m .55061 .5438 L .5449 .54649 L p F P
0 0 1 r
s
.079 .137 .245 r
.42615 .40485 m .42695 .4198 L .41738 .43265 L p F P
0 0 1 r
s
.24 .35 .67 r
.38088 .40693 m
.42468 .3896 L
s
.129 .234 .378 r
.42096 .44771 m .41738 .43265 L .42695 .4198 L p F P
0 0 1 r
s
.24 .35 .67 r
.38539 .4294 m
.38025 .42134 L
s
.122 .231 .382 r
.42096 .44771 m .42719 .4627 L .42283 .4749 L p F P
0 0 1 r
s
0 0 0 r
.42675 .46394 m
.44226 .48255 L
s
.4205 .45644 m
.42114 .45721 L
s
.179 .337 .539 r
.4319 .48825 m .42283 .4749 L .42719 .4627 L p F P
0 0 1 r
s
.24 .35 .67 r
.42802 .46721 m
.43848 .46253 L
s
.399 .786 1 r
.51367 .5416 m .503 .54586 L .49756 .543 L p F P
0 0 1 r
s
.395 .781 1 r
.503 .54586 m .51367 .5416 L .51691 .5427 L p F P
0 0 1 r
s
0 0 0 r
.48981 .33981 m
.49015 .34032 L
s
.49068 .34111 m
.49094 .3415 L
s
.48138 .33981 m
.48678 .34077 L
s
.48678 .34077 m
.48709 .34082 L
s
.48972 .34129 m
.49094 .3415 L
s
.35945 .39532 m
.38449 .43153 L
s
.39319 .43976 m
.38449 .43153 L
s
.24 .35 .67 r
.69776 .45897 m
.7226 .4513 L
s
.7226 .4513 m
.75253 .43264 L
s
0 0 0 r
.47175 .46597 m
.47916 .47728 L
s
.47916 .47728 m
.4577 .47094 L
s
.24 .35 .67 r
.56833 .4798 m
.61112 .47154 L
s
.56833 .4798 m
.57184 .47657 L
s
.188 .363 .582 r
.4319 .48825 m .44336 .50048 L .44336 .51022 L p F P
0 0 1 r
s
.253 .485 .77 r
.45687 .51933 m .44336 .51022 L .44336 .50048 L p F P
0 0 1 r
s
.24 .35 .67 r
.63579 .47275 m
.66857 .46618 L
s
.63579 .47275 m
.652 .46245 L
s
.50615 .35628 m
.50858 .35832 L
s
0 0 0 r
.44866 .31549 m
.47376 .34074 L
s
.47376 .34074 m
.48138 .33981 L
s
.24 .35 .67 r
.49789 .46975 m
.47949 .4766 L
s
.47949 .4766 m
.45817 .46994 L
s
.216 .348 .474 r
.56912 .3435 m .57241 .35276 L .55071 .34795 L p F P
0 0 1 r
s
.24 .35 .67 r
.5493 .35176 m
.55216 .34827 L
s
.5493 .35176 m
.55853 .34968 L
s
.57113 .34685 m
.57226 .34659 L
s
.57089 .3469 m
.57113 .34685 L
s
.57226 .34659 m
.5865 .34339 L
s
0 0 0 r
.5515 .35217 m
.55455 .3488 L
s
.216 .348 .474 r
.55071 .34795 m .54891 .339 L .56912 .3435 L p F P
0 0 1 r
s
0 0 0 r
.55717 .34591 m
.55826 .34699 L
s
.55672 .34641 m
.55717 .34591 L
s
.24 .35 .67 r
.55414 .34586 m
.55451 .34541 L
s
.55303 .34583 m
.55451 .34541 L
s
.66857 .46618 m
.69776 .45897 L
s
.69776 .45897 m
.72367 .44275 L
s
.66857 .46618 m
.68985 .45277 L
s
.52116 .47577 m
.5112 .4789 L
s
.5112 .4789 m
.49789 .46975 L
s
.458 .771 1 r
.62629 .40813 m .62546 .42303 L .61249 .41116 L p F P
0 0 1 r
s
.458 .771 1 r
.61249 .41116 m .61322 .39606 L .62629 .40813 L p F P
0 0 1 r
s
0 0 0 r
.53784 .47865 m
.55072 .46925 L
s
.53784 .47865 m
.53189 .47321 L
s
.46001 .31409 m
.48138 .33981 L
s
.501 .999 1 r
.55061 .5438 m .5379 .54055 L .54023 .53887 L p F P
0 0 1 r
s
.501 .999 1 r
.54023 .53887 m .55522 .5405 L .55061 .5438 L p F P
0 0 1 r
s
.24 .35 .67 r
.39404 .43778 m
.38539 .4294 L
s
0 0 0 r
.3699 .40599 m
.39319 .43976 L
s
.4052 .44803 m
.39319 .43976 L
s
.131 .209 .307 r
.48252 .35124 m .48543 .34208 L .50604 .33827 L p F P
0 0 1 r
s
0 0 0 r
.49998 .34161 m
.502 .34571 L
s
.49865 .3389 m
.49873 .33906 L
s
.093 .139 .219 r
.48543 .34208 m .48252 .35124 L .46242 .35806 L p F P
0 0 1 r
s
0 0 0 r
.44083 .32075 m
.46846 .34422 L
s
.43686 .32959 m
.46346 .34849 L
s
.4577 .47094 m
.43789 .46382 L
s
.599 1 1 r
.61795 .49115 m .60646 .50301 L .6038 .49334 L p F P
0 0 1 r
s
.599 1 1 r
.6038 .49334 m .61499 .48004 L .61795 .49115 L p F P
0 0 1 r
s
.24 .35 .67 r
.80114 .39007 m
.79007 .38472 L
s
.79007 .38472 m
.81418 .3638 L
s
.56 .999 1 r
.63016 .45106 m .62384 .46582 L .61621 .45411 L p F P
0 0 1 r
s
.56 .999 1 r
.61621 .45411 m .62208 .43849 L .63016 .45106 L p F P
0 0 1 r
s
.405 .796 1 r
.51091 .54014 m .49756 .543 L .49327 .53956 L p F P
0 0 1 r
s
.399 .786 1 r
.49756 .543 m .51091 .54014 L .51367 .5416 L p F P
0 0 1 r
s
.55 1 1 r
.57419 .53411 m .55852 .53673 L .56036 .53265 L p F P
0 0 1 r
s
.55 1 1 r
.56036 .53265 m .57695 .52811 L .57419 .53411 L p F P
0 0 1 r
s
0 0 0 r
.49554 .4717 m
.49805 .477 L
s
.49805 .477 m
.47175 .46597 L
s
.24 .35 .67 r
.48517 .4598 m
.45817 .46994 L
s
.45817 .46994 m
.43848 .46253 L
s
0 0 0 r
.38428 .41754 m
.4052 .44803 L
s
.4052 .44803 m
.42023 .45612 L
s
.42023 .45612 m
.42062 .45629 L
s
.42062 .45629 m
.42163 .45673 L
s
.42539 .45837 m
.43789 .46382 L
s
.24 .35 .67 r
.57184 .47657 m
.57328 .47377 L
s
0 0 0 r
.40221 .42964 m
.41772 .45243 L
s
.41772 .45243 m
.42023 .45612 L
s
.43686 .32959 m
.4369 .34153 L
s
.40978 .32718 m
.4369 .34153 L
s
.586 1 1 r
.59213 .5214 m .57695 .52811 L .57744 .52191 L p F P
0 0 1 r
s
.586 1 1 r
.57744 .52191 m .59284 .51335 L .59213 .5214 L p F P
0 0 1 r
s
0 0 0 r
.3717 .33348 m
.38662 .36308 L
s
.37189 .36387 m
.38662 .36308 L
s
.24 .35 .67 r
.40599 .44623 m
.39404 .43778 L
s
.5313 .47311 m
.52116 .47577 L
s
.52116 .47577 m
.51762 .46351 L
s
.092 .153 .257 r
.44179 .3794 m .44035 .39322 L .42615 .40485 L p F P
0 0 1 r
s
.24 .35 .67 r
.43175 .39287 m
.43735 .39066 L
s
.42468 .3896 m
.43865 .38407 L
s
.136 .238 .374 r
.42695 .4198 m .42615 .40485 L .44035 .39322 L p F P
0 0 1 r
s
.286 .554 .87 r
.45687 .51933 m .47218 .52651 L .47436 .53259 L p F P
0 0 1 r
s
.357 .692 1 r
.49033 .5357 m .47436 .53259 L .47218 .52651 L p F P
0 0 1 r
s
.338 .658 1 r
.47436 .53259 m .49033 .5357 L .49327 .53956 L p F P
0 0 1 r
s
.388 .637 .853 r
.61172 .38222 m .61322 .39606 L .596 .38586 L p F P
0 0 1 r
s
0 0 0 r
.61755 .39863 m
.62303 .40512 L
s
.61229 .38733 m
.61515 .39072 L
s
.61515 .39072 m
.61854 .39476 L
s
.388 .637 .853 r
.596 .38586 m .59479 .37211 L .61172 .38222 L p F P
0 0 1 r
s
0 0 0 r
.60629 .37911 m
.60634 .37917 L
s
.60389 .37673 m
.60476 .3773 L
s
.6037 .37661 m
.60389 .37673 L
s
.60476 .3773 m
.60629 .37911 L
s
.304 .493 .669 r
.59182 .36023 m .59479 .37211 L .57452 .36436 L p F P
0 0 1 r
s
0 0 0 r
.59039 .36479 m
.59144 .36584 L
s
.57649 .36511 m
.58349 .37208 L
s
.59072 .37056 m
.59227 .3721 L
s
.304 .493 .669 r
.57452 .36436 m .57241 .35276 L .59182 .36023 L p F P
0 0 1 r
s
0 0 0 r
.57459 .35444 m
.57495 .3548 L
s
.56167 .35038 m
.57426 .36289 L
s
.58631 .36071 m
.58683 .36123 L
s
.24 .35 .67 r
.42093 .45456 m
.42116 .45466 L
s
.42116 .45466 m
.42217 .45512 L
s
.42448 .45617 m
.43848 .46253 L
s
0 0 0 r
.40978 .32718 m
.41524 .34613 L
s
.39196 .33856 m
.41524 .34613 L
s
.192 .311 .433 r
.54891 .339 m .55071 .34795 L .52775 .34605 L p F P
0 0 1 r
s
.24 .35 .67 r
.50858 .35832 m
.54666 .34762 L
s
0 0 0 r
.546 .34756 m
.5515 .35217 L
s
.192 .311 .433 r
.52775 .34605 m .52754 .33722 L .54891 .339 L p F P
0 0 1 r
s
0 0 0 r
.53451 .33795 m
.53734 .34032 L
s
.53734 .34032 m
.53829 .34111 L
s
.52796 .33247 m
.53451 .33795 L
s
.24 .35 .67 r
.40599 .44623 m
.4202 .45415 L
s
.4202 .45415 m
.42093 .45456 L
s
.525 1 1 r
.55522 .5405 m .54023 .53887 L .54189 .53695 L p F P
0 0 1 r
s
.525 1 1 r
.54189 .53695 m .55852 .53673 L .55522 .5405 L p F P
0 0 1 r
s
.179 .337 .539 r
.42719 .4627 m .43592 .47723 L .4319 .48825 L p F P
0 0 1 r
s
.232 .437 .695 r
.44336 .50048 m .4319 .48825 L .43592 .47723 L p F P
0 0 1 r
s
.24 .35 .67 r
.42093 .45456 m
.4212 .45446 L
s
.74246 .33765 m
.70427 .34538 L
s
.70427 .34538 m
.69419 .33893 L
s
.163 .264 .375 r
.50465 .34717 m .50604 .33827 L .52754 .33722 L p F P
0 0 1 r
s
0 0 0 r
.51994 .34053 m
.5272 .34554 L
s
.51019 .33809 m
.5102 .33809 L
s
.51181 .34406 m
.51401 .35222 L
s
.131 .209 .307 r
.50604 .33827 m .50465 .34717 L .48252 .35124 L p F P
0 0 1 r
s
0 0 0 r
.49084 .323 m
.49865 .3389 L
s
.47431 .31664 m
.48981 .33981 L
s
.129 .234 .378 r
.42695 .4198 m .43024 .4354 L .42096 .44771 L p F P
0 0 1 r
s
.174 .321 .505 r
.42719 .4627 m .42096 .44771 L .43024 .4354 L p F P
0 0 1 r
s
.24 .35 .67 r
.39404 .43778 m
.42268 .42667 L
s
.40599 .44623 m
.42288 .43973 L
s
.42288 .43973 m
.42608 .4385 L
s
.42608 .4385 m
.42656 .43831 L
s
.4212 .45446 m
.42127 .45443 L
s
.42127 .45443 m
.42226 .45405 L
s
.62435 .4686 m
.652 .46245 L
s
.62374 .46873 m
.62435 .4686 L
s
.62345 .4688 m
.62374 .46873 L
s
.61112 .47154 m
.62176 .46918 L
s
.253 .485 .77 r
.44336 .50048 m .45694 .51126 L .45687 .51933 L p F P
0 0 1 r
s
.315 .603 .949 r
.47218 .52651 m .45687 .51933 L .45694 .51126 L p F P
0 0 1 r
s
.412 .806 1 r
.50875 .53839 m .49327 .53956 L .49033 .5357 L p F P
0 0 1 r
s
.405 .796 1 r
.49327 .53956 m .50875 .53839 L .51091 .54014 L p F P
0 0 1 r
s
.24 .35 .67 r
.79474 .36124 m
.7687 .3607 L
s
.7687 .3607 m
.77791 .3451 L
s
.57328 .47377 m
.5726 .47152 L
s
.14 .232 .348 r
.45966 .36986 m .46242 .35806 L .48252 .35124 L p F P
0 0 1 r
s
.098 .156 .252 r
.46242 .35806 m .45966 .36986 L .44179 .3794 L p F P
0 0 1 r
s
.163 .264 .375 r
.52754 .33722 m .52775 .34605 L .50465 .34717 L p F P
0 0 1 r
s
0 0 0 r
.50945 .33533 m
.51019 .33809 L
s
.50877 .33281 m
.51651 .33815 L
s
.51651 .33815 m
.51667 .33827 L
s
.52761 .33862 m
.52796 .33247 L
s
.52758 .33899 m
.52761 .33862 L
s
.53189 .47321 m
.53897 .45837 L
s
.53189 .47321 m
.52559 .46832 L
s
.24 .35 .67 r
.54119 .47102 m
.5313 .47311 L
s
.5313 .47311 m
.5378 .45817 L
s
.14 .239 .366 r
.44035 .39322 m .44179 .3794 L .45966 .36986 L p F P
0 0 1 r
s
.24 .35 .67 r
.44211 .37893 m
.44243 .37873 L
s
.44243 .37873 m
.44257 .37864 L
s
.44257 .37864 m
.44265 .37858 L
s
.42962 .38389 m
.44211 .37893 L
s
.4573 .37272 m
.50615 .35628 L
s
.48 .947 1 r
.52474 .53473 m .52424 .54369 L .52049 .54341 L closepath p F P
0 0 1 r
s
.485 .957 1 r
.52474 .53473 m .52802 .54352 L .52424 .54369 L closepath p F P
0 0 1 r
s
.49 .967 1 r
.52474 .53473 m .53166 .54292 L .52802 .54352 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.62117 .33769 m
.5865 .34339 L
s
.59965 .33521 m
.5865 .34339 L
s
.477 .939 1 r
.52474 .53473 m .52049 .54341 L .51691 .5427 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.51762 .46351 m
.49789 .46975 L
s
.49789 .46975 m
.48517 .4598 L
s
.617 1 1 r
.60646 .50301 m .59284 .51335 L .59056 .50535 L p F P
0 0 1 r
s
.617 1 1 r
.59056 .50535 m .6038 .49334 L .60646 .50301 L p F P
0 0 1 r
s
.24 .35 .67 r
.80529 .39674 m
.80114 .39007 L
s
.80114 .39007 m
.82639 .36834 L
s
.44211 .37893 m
.44426 .37821 L
s
.44426 .37821 m
.4444 .37816 L
s
.43865 .38407 m
.44211 .37893 L
s
.496 .978 1 r
.52474 .53473 m .535 .54192 L .53166 .54292 L closepath p F P
0 0 1 r
s
0 0 0 r
.55072 .46925 m
.56304 .45905 L
s
.55072 .46925 m
.53897 .45837 L
s
.474 .933 1 r
.52474 .53473 m .51691 .5427 L .51367 .5416 L closepath p F P
0 0 1 r
s
0 0 0 r
.49431 .46702 m
.49554 .4717 L
s
.49554 .4717 m
.46661 .45535 L
s
.599 1 1 r
.62384 .46582 m .61499 .48004 L .60798 .46947 L p F P
0 0 1 r
s
.599 1 1 r
.60798 .46947 m .61621 .45411 L .62384 .46582 L p F P
0 0 1 r
s
.24 .35 .67 r
.57184 .47657 m
.60911 .46736 L
s
.61735 .46066 m
.61785 .46051 L
s
.61785 .46051 m
.62022 .45981 L
s
.62022 .45981 m
.62128 .45949 L
s
.517 .889 1 r
.62546 .42303 m .62208 .43849 L .60953 .42712 L p F P
0 0 1 r
s
0 0 0 r
.61212 .42947 m
.62141 .44026 L
s
.517 .889 1 r
.60953 .42712 m .61249 .41116 L .62546 .42303 L p F P
0 0 1 r
s
.24 .35 .67 r
.61905 .45531 m
.62003 .45497 L
s
.5726 .47152 m
.56979 .46992 L
s
.55037 .46961 m
.54119 .47102 L
s
.54119 .47102 m
.5575 .45398 L
s
.58 1 1 r
.57695 .52811 m .56036 .53265 L .56066 .52843 L p F P
0 0 1 r
s
.58 1 1 r
.56066 .52843 m .57744 .52191 L .57695 .52811 L p F P
0 0 1 r
s
.544 1 1 r
.55852 .53673 m .54189 .53695 L .54281 .53488 L p F P
0 0 1 r
s
.544 1 1 r
.54281 .53488 m .56036 .53265 L .55852 .53673 L p F P
0 0 1 r
s
.502 .989 1 r
.52474 .53473 m .5379 .54055 L .535 .54192 L closepath p F P
0 0 1 r
s
0 0 0 r
.60476 .3773 m
.60811 .38237 L
s
.59911 .37163 m
.60476 .3773 L
s
.473 .929 1 r
.52474 .53473 m .51367 .5416 L .51091 .54014 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.77791 .3451 m
.74458 .34863 L
s
.74458 .34863 m
.74246 .33765 L
s
.56979 .46992 m
.565 .46905 L
s
.357 .692 1 r
.47218 .52651 m .48889 .53156 L .49033 .5357 L p F P
0 0 1 r
s
.419 .816 1 r
.50727 .53642 m .49033 .5357 L .48889 .53156 L p F P
0 0 1 r
s
.412 .806 1 r
.49033 .5357 m .50727 .53642 L .50875 .53839 L p F P
0 0 1 r
s
.232 .437 .695 r
.43592 .47723 m .44695 .49089 L .44336 .50048 L p F P
0 0 1 r
s
.283 .536 .846 r
.45694 .51126 m .44336 .50048 L .44695 .49089 L p F P
0 0 1 r
s
.24 .35 .67 r
.55843 .46894 m
.55037 .46961 L
s
.55037 .46961 m
.57583 .45114 L
s
.507 1 1 r
.52474 .53473 m .54023 .53887 L .5379 .54055 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.652 .46245 m
.68985 .45277 L
s
.652 .46245 m
.66273 .45291 L
s
.315 .603 .949 r
.45694 .51126 m .47228 .52029 L .47218 .52651 L p F P
0 0 1 r
s
.372 .717 1 r
.48889 .53156 m .47218 .52651 L .47228 .52029 L p F P
0 0 1 r
s
.24 .35 .67 r
.565 .46905 m
.55843 .46894 L
s
.472 .926 1 r
.52474 .53473 m .51091 .54014 L .50875 .53839 L closepath p F P
0 0 1 r
s
0 0 0 r
.46661 .45535 m
.47175 .46597 L
s
.47175 .46597 m
.44657 .45419 L
s
.174 .321 .505 r
.43024 .4354 m .43595 .45123 L .42719 .4627 L p F P
0 0 1 r
s
0 0 0 r
.43247 .45579 m
.43789 .46382 L
s
.42317 .44197 m
.42863 .45008 L
s
.217 .403 .632 r
.43592 .47723 m .42719 .4627 L .43595 .45123 L p F P
0 0 1 r
s
0 0 0 r
.42863 .45008 m
.42904 .45069 L
s
.42904 .45069 m
.42963 .45157 L
s
.136 .238 .374 r
.44035 .39322 m .44105 .40836 L .42695 .4198 L p F P
0 0 1 r
s
.24 .35 .67 r
.4339 .40027 m
.43826 .39856 L
s
.43384 .40029 m
.4339 .40027 L
s
.173 .31 .479 r
.43024 .4354 m .42695 .4198 L .44105 .40836 L p F P
0 0 1 r
s
.24 .35 .67 r
.37874 .41378 m
.43175 .39287 L
s
.38539 .4294 m
.4293 .41226 L
s
.277 .452 .622 r
.57241 .35276 m .57452 .36436 L .55186 .35937 L p F P
0 0 1 r
s
0 0 0 r
.5742 .35405 m
.57446 .35431 L
s
.57446 .35431 m
.57459 .35444 L
s
.277 .452 .622 r
.55186 .35937 m .55071 .34795 L .57241 .35276 L p F P
0 0 1 r
s
0 0 0 r
.57018 .35004 m
.5742 .35405 L
s
.5621 .34196 m
.57018 .35004 L
s
.24 .35 .67 r
.73039 .32979 m
.69419 .33893 L
s
.69419 .33893 m
.67637 .33541 L
s
0 0 0 r
.52559 .46832 m
.52644 .44854 L
s
.52559 .46832 m
.51922 .46421 L
s
.50381 .31566 m
.50877 .33281 L
s
.50877 .33281 m
.49084 .323 L
s
.55717 .34591 m
.5621 .34196 L
s
.52865 .3219 m
.55699 .34575 L
s
.55699 .34575 m
.55717 .34591 L
s
.612 1 1 r
.59284 .51335 m .57744 .52191 L .57562 .51575 L p F P
0 0 1 r
s
.612 1 1 r
.57562 .51575 m .59056 .50535 L .59284 .51335 L p F P
0 0 1 r
s
.24 .35 .67 r
.80237 .40454 m
.80529 .39674 L
s
.80529 .39674 m
.83098 .37476 L
s
.62028 .46455 m
.62074 .46442 L
s
.61949 .4628 m
.62128 .45949 L
s
.61925 .46325 m
.61949 .4628 L
s
0 0 0 r
.3551 .33107 m
.37189 .36387 L
s
.36091 .36662 m
.37189 .36387 L
s
.512 1 1 r
.52474 .53473 m .54189 .53695 L .54023 .53887 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.55451 .34541 m
.59965 .33521 L
s
.55451 .34541 m
.55903 .34139 L
s
.444 .742 .994 r
.61322 .39606 m .61249 .41116 L .59541 .40113 L p F P
0 0 1 r
s
0 0 0 r
.61283 .40199 m
.61555 .40519 L
s
.61555 .40519 m
.61896 .40921 L
s
.444 .742 .994 r
.59541 .40113 m .596 .38586 L .61322 .39606 L p F P
0 0 1 r
s
0 0 0 r
.61049 .39027 m
.61755 .39863 L
s
.60811 .38237 m
.61229 .38733 L
s
.60937 .38894 m
.61049 .39027 L
s
.472 .925 1 r
.52474 .53473 m .50875 .53839 L .50727 .53642 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.65163 .33498 m
.62117 .33769 L
s
.64179 .32827 m
.62117 .33769 L
s
0 0 0 r
.49442 .46318 m
.49431 .46702 L
s
.174 .291 .423 r
.48064 .36279 m .48252 .35124 L .50465 .34717 L p F P
0 0 1 r
s
.14 .232 .348 r
.48252 .35124 m .48064 .36279 L .45966 .36986 L p F P
0 0 1 r
s
.24 .35 .67 r
.51423 .45053 m
.48517 .4598 L
s
.48517 .4598 m
.47338 .44931 L
s
.556 1 1 r
.56036 .53265 m .54281 .53488 L .54293 .53274 L p F P
0 0 1 r
s
.556 1 1 r
.54293 .53274 m .56066 .52843 L .56036 .53265 L p F P
0 0 1 r
s
.24 .35 .67 r
.43735 .39066 m
.43865 .38407 L
s
.616 1 1 r
.61499 .48004 m .6038 .49334 L .59761 .48416 L p F P
0 0 1 r
s
.616 1 1 r
.59761 .48416 m .60798 .46947 L .61499 .48004 L p F P
0 0 1 r
s
.24 .35 .67 r
.57328 .47377 m
.61182 .46231 L
s
.5378 .45817 m
.51762 .46351 L
s
.51762 .46351 m
.51423 .45053 L
s
0 0 0 r
.56304 .45905 m
.57446 .44833 L
s
.56304 .45905 m
.54578 .44288 L
s
.361 .593 .806 r
.59479 .37211 m .596 .38586 L .57539 .37803 L p F P
0 0 1 r
s
.361 .593 .806 r
.57539 .37803 m .57452 .36436 L .59479 .37211 L p F P
0 0 1 r
s
0 0 0 r
.59431 .36681 m
.59911 .37163 L
s
.58683 .36123 m
.58988 .36428 L
s
.58988 .36428 m
.59039 .36479 L
s
.283 .536 .846 r
.44695 .49089 m .45999 .50333 L .45694 .51126 L p F P
0 0 1 r
s
.333 .635 .993 r
.47228 .52029 m .45694 .51126 L .45999 .50333 L p F P
0 0 1 r
s
.516 1 1 r
.52474 .53473 m .54281 .53488 L .54189 .53695 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.68985 .45277 m
.72367 .44275 L
s
.68985 .45277 m
.70408 .44029 L
s
.372 .717 1 r
.47228 .52029 m .489 .52734 L .48889 .53156 L p F P
0 0 1 r
s
.425 .826 1 r
.50656 .53433 m .48889 .53156 L .489 .52734 L p F P
0 0 1 r
s
.419 .816 1 r
.48889 .53156 m .50656 .53433 L .50727 .53642 L p F P
0 0 1 r
s
.24 .35 .67 r
.81418 .3638 m
.79474 .36124 L
s
.79474 .36124 m
.80519 .34397 L
s
.555 .973 1 r
.62208 .43849 m .61621 .45411 L .60438 .44353 L p F P
0 0 1 r
s
.24 .35 .67 r
.62391 .46355 m
.66273 .45291 L
s
.62074 .46442 m
.62391 .46355 L
s
.555 .973 1 r
.60438 .44353 m .60953 .42712 L .62208 .43849 L p F P
0 0 1 r
s
.473 .925 1 r
.52474 .53473 m .50727 .53642 L .50656 .53433 L closepath p F P
0 0 1 r
s
0 0 0 r
.44083 .32075 m
.43686 .32959 L
s
.4095 .3114 m
.43686 .32959 L
s
.24 .35 .67 r
.70884 .32548 m
.67637 .33541 L
s
.67637 .33541 m
.65163 .33498 L
s
0 0 0 r
.60811 .38237 m
.60937 .38894 L
s
.59797 .3722 m
.60811 .38237 L
s
.24 .35 .67 r
.67881 .32497 m
.65163 .33498 L
s
.592 1 1 r
.57744 .52191 m .56066 .52843 L .55938 .52426 L p F P
0 0 1 r
s
.592 1 1 r
.55938 .52426 m .57562 .51575 L .57744 .52191 L p F P
0 0 1 r
s
.24 .35 .67 r
.79241 .41328 m
.80237 .40454 L
s
.80237 .40454 m
.82775 .38288 L
s
.14 .239 .366 r
.45966 .36986 m .45853 .38358 L .44035 .39322 L p F P
0 0 1 r
s
.24 .35 .67 r
.45042 .38012 m
.45653 .37807 L
s
.44731 .38116 m
.45042 .38012 L
s
.173 .304 .459 r
.44105 .40836 m .44035 .39322 L .45853 .38358 L p F P
0 0 1 r
s
.24 .35 .67 r
.43865 .38407 m
.44731 .38116 L
s
0 0 0 r
.51922 .46421 m
.51371 .44023 L
s
.51922 .46421 m
.51307 .46107 L
s
.243 .4 .559 r
.55071 .34795 m .55186 .35937 L .52789 .3574 L p F P
0 0 1 r
s
.243 .4 .559 r
.52789 .3574 m .52775 .34605 L .55071 .34795 L p F P
0 0 1 r
s
.24 .35 .67 r
.50615 .35628 m
.5278 .35018 L
s
.53605 .34786 m
.53658 .34771 L
s
.53658 .34771 m
.54054 .3466 L
s
.54054 .3466 m
.55903 .34139 L
s
.174 .3 .443 r
.45853 .38358 m .45966 .36986 L .48064 .36279 L p F P
0 0 1 r
s
.217 .403 .632 r
.43595 .45123 m .44395 .46688 L .43592 .47723 L p F P
0 0 1 r
s
.24 .35 .67 r
.4412 .4615 m
.47338 .44931 L
s
.26 .484 .76 r
.44695 .49089 m .43592 .47723 L .44395 .46688 L p F P
0 0 1 r
s
0 0 0 r
.44657 .45419 m
.4577 .47094 L
s
.519 1 1 r
.52474 .53473 m .54293 .53274 L .54281 .53488 L closepath p F P
0 0 1 r
s
0 0 0 r
.49588 .46036 m
.49442 .46318 L
s
.208 .346 .492 r
.50375 .35856 m .50465 .34717 L .52775 .34605 L p F P
0 0 1 r
s
.174 .291 .423 r
.50465 .34717 m .50375 .35856 L .48064 .36279 L p F P
0 0 1 r
s
.24 .35 .67 r
.4782 .36509 m
.49024 .36103 L
s
.72367 .44275 m
.75253 .43264 L
s
.72367 .44275 m
.74113 .42761 L
s
.425 .826 1 r
.489 .52734 m .50664 .53219 L .50656 .53433 L p F P
0 0 1 r
s
.474 .927 1 r
.52474 .53473 m .50656 .53433 L .50664 .53219 L closepath p F P
0 0 1 r
s
.333 .635 .993 r
.45999 .50333 m .4747 .5142 L .47228 .52029 L p F P
0 0 1 r
s
.383 .735 1 r
.489 .52734 m .47228 .52029 L .4747 .5142 L p F P
0 0 1 r
s
.618 1 1 r
.6038 .49334 m .59056 .50535 L .58535 .49777 L p F P
0 0 1 r
s
.618 1 1 r
.58535 .49777 m .59761 .48416 L .6038 .49334 L p F P
0 0 1 r
s
.56 1 1 r
.56066 .52843 m .54293 .53274 L .54226 .53064 L p F P
0 0 1 r
s
.56 1 1 r
.54226 .53064 m .55938 .52426 L .56066 .52843 L p F P
0 0 1 r
s
.24 .35 .67 r
.77565 .42274 m
.79241 .41328 L
s
.79241 .41328 m
.81676 .39251 L
s
0 0 0 r
.52865 .3219 m
.52796 .33247 L
s
.52796 .33247 m
.50381 .31566 L
s
.24 .35 .67 r
.51108 .43719 m
.47338 .44931 L
s
.47338 .44931 m
.46283 .43855 L
s
.62128 .45949 m
.66742 .44456 L
s
.62003 .45497 m
.62128 .45949 L
s
.173 .31 .479 r
.44105 .40836 m .44388 .42444 L .43024 .4354 L p F P
0 0 1 r
s
.24 .35 .67 r
.4312 .42336 m
.43142 .42328 L
s
.38025 .42134 m
.43384 .40029 L
s
.43142 .42328 m
.43462 .42203 L
s
.208 .379 .584 r
.43595 .45123 m .43024 .4354 L .44388 .42444 L p F P
0 0 1 r
s
.24 .35 .67 r
.42268 .42667 m
.4306 .42359 L
s
.4306 .42359 m
.4312 .42336 L
s
.43675 .44851 m
.46283 .43855 L
s
.208 .346 .492 r
.52775 .34605 m .52789 .3574 L .50375 .35856 L p F P
0 0 1 r
s
.24 .35 .67 r
.43735 .39066 m
.43826 .39856 L
s
.75253 .43264 m
.77565 .42274 L
s
.75253 .43264 m
.77283 .41519 L
s
.519 1 1 r
.52474 .53473 m .53867 .52688 L .54082 .52866 L closepath p F P
0 0 1 r
s
.516 1 1 r
.52474 .53473 m .53591 .5254 L .53867 .52688 L closepath p F P
0 0 1 r
s
.513 .998 1 r
.52474 .53473 m .53265 .52427 L .53591 .5254 L closepath p F P
0 0 1 r
s
.509 .989 1 r
.52474 .53473 m .52904 .52355 L .53265 .52427 L closepath p F P
0 0 1 r
s
.504 .98 1 r
.52474 .53473 m .52524 .52326 L .52904 .52355 L closepath p F P
0 0 1 r
s
.5 .97 1 r
.52474 .53473 m .52141 .52343 L .52524 .52326 L closepath p F P
0 0 1 r
s
.495 .961 1 r
.52474 .53473 m .51773 .52404 L .52141 .52343 L closepath p F P
0 0 1 r
s
.491 .953 1 r
.52474 .53473 m .51437 .52507 L .51773 .52404 L closepath p F P
0 0 1 r
s
.486 .946 1 r
.52474 .53473 m .51146 .52647 L .51437 .52507 L closepath p F P
0 0 1 r
s
.483 .939 1 r
.52474 .53473 m .50915 .52817 L .51146 .52647 L closepath p F P
0 0 1 r
s
.479 .934 1 r
.52474 .53473 m .50751 .53011 L .50915 .52817 L closepath p F P
0 0 1 r
s
.477 .93 1 r
.52474 .53473 m .50664 .53219 L .50751 .53011 L closepath p F P
0 0 1 r
s
.52 1 1 r
.52474 .53473 m .54226 .53064 L .54293 .53274 L closepath p F P
0 0 1 r
s
.52 1 1 r
.52474 .53473 m .54082 .52866 L .54226 .53064 L closepath p F P
0 0 1 r
s
.24 .35 .67 r
.77565 .42274 m
.79828 .40338 L
s
0 0 0 r
.57446 .44833 m
.58468 .43736 L
s
.383 .735 1 r
.4747 .5142 m .49068 .52321 L .489 .52734 L p F P
0 0 1 r
s
.431 .835 1 r
.50664 .53219 m .489 .52734 L .49068 .52321 L p F P
0 0 1 r
s
0 0 0 r
.42317 .44197 m
.4348 .44804 L
s
.43661 .44899 m
.44657 .45419 L
s
.38503 .31543 m
.39196 .33856 L
s
.3717 .33348 m
.39196 .33856 L
s
.51307 .46107 m
.50137 .43386 L
s
.51307 .46107 m
.50742 .45905 L
s
.53897 .45837 m
.54578 .44288 L
s
.53897 .45837 m
.52644 .44854 L
s
.24 .35 .67 r
.5575 .45398 m
.5378 .45817 L
s
.5378 .45817 m
.54405 .44258 L
s
.431 .835 1 r
.49068 .52321 m .50751 .53011 L .50664 .53219 L p F P
0 0 1 r
s
.24 .35 .67 r
.52942 .34923 m
.56273 .33985 L
s
.52108 .35158 m
.52942 .34923 L
s
.51731 .35264 m
.52108 .35158 L
s
0 0 0 r
.34267 .33147 m
.36091 .36662 L
s
.35401 .37127 m
.36091 .36662 L
s
.60849 .39686 m
.60937 .38894 L
s
.60245 .38203 m
.60916 .38873 L
s
.60916 .38873 m
.60937 .38894 L
s
.49862 .45868 m
.49588 .46036 L
s
.24 .35 .67 r
.77569 .33242 m
.74246 .33765 L
s
.74246 .33765 m
.73039 .32979 L
s
.26 .484 .76 r
.44395 .46688 m .45403 .48191 L .44695 .49089 L p F P
0 0 1 r
s
.303 .569 .889 r
.45999 .50333 m .44695 .49089 L .45403 .48191 L p F P
0 0 1 r
s
.484 .825 1 r
.61249 .41116 m .60953 .42712 L .59301 .41751 L p F P
0 0 1 r
s
0 0 0 r
.5934 .42644 m
.60541 .44024 L
s
.484 .825 1 r
.59301 .41751 m .59541 .40113 L .61249 .41116 L p F P
0 0 1 r
s
0 0 0 r
.60849 .39686 m
.61283 .40199 L
s
.60547 .40592 m
.60701 .40772 L
s
.60701 .40772 m
.60706 .40778 L
s
.24 .35 .67 r
.66273 .45291 m
.70408 .44029 L
s
.66273 .45291 m
.66742 .44456 L
s
.577 1 1 r
.61621 .45411 m .60798 .46947 L .59718 .45993 L p F P
0 0 1 r
s
.24 .35 .67 r
.5726 .47152 m
.59963 .46209 L
s
.577 1 1 r
.59718 .45993 m .60438 .44353 L .61621 .45411 L p F P
0 0 1 r
s
.24 .35 .67 r
.61526 .45664 m
.61905 .45531 L
s
.61476 .45681 m
.61526 .45664 L
s
.56979 .46992 m
.59779 .45856 L
s
.61087 .45324 m
.61133 .45306 L
s
0 0 0 r
.58468 .43736 m
.59963 .45435 L
s
.24 .35 .67 r
.61222 .4527 m
.61453 .45176 L
s
.61133 .45306 m
.61222 .4527 L
s
.607 1 1 r
.59056 .50535 m .57562 .51575 L .57155 .50993 L p F P
0 0 1 r
s
.607 1 1 r
.57155 .50993 m .58535 .49777 L .59056 .50535 L p F P
0 0 1 r
s
.24 .35 .67 r
.80519 .34397 m
.77791 .3451 L
s
.77791 .3451 m
.77569 .33242 L
s
.558 1 1 r
.55938 .52426 m .54226 .53064 L .54082 .52866 L p F P
0 0 1 r
s
0 0 0 r
.50742 .45905 m
.50253 .45824 L
s
.48024 .30267 m
.49084 .323 L
s
.49084 .323 m
.47431 .31664 L
s
.24 .35 .67 r
.46283 .43855 m
.45383 .42781 L
s
0 0 0 r
.50253 .45824 m
.49862 .45868 L
s
.438 .844 1 r
.49387 .51936 m .50915 .52817 L .50751 .53011 L p F P
0 0 1 r
s
.438 .844 1 r
.50751 .53011 m .49068 .52321 L .49387 .51936 L p F P
0 0 1 r
s
.322 .532 .733 r
.57452 .36436 m .57539 .37803 L .55234 .37299 L p F P
0 0 1 r
s
.322 .532 .733 r
.55234 .37299 m .55186 .35937 L .57452 .36436 L p F P
0 0 1 r
s
0 0 0 r
.56915 .34157 m
.59431 .36681 L
s
.57104 .34521 m
.59797 .3722 L
s
.56613 .34049 m
.58631 .36071 L
s
.587 1 1 r
.57562 .51575 m .55938 .52426 L .55657 .52032 L p F P
0 0 1 r
s
.587 1 1 r
.55657 .52032 m .57155 .50993 L .57562 .51575 L p F P
0 0 1 r
s
.558 1 1 r
.54082 .52866 m .55657 .52032 L .55938 .52426 L p F P
0 0 1 r
s
0 0 0 r
.464 .44592 m
.46661 .45535 L
s
.24 .35 .67 r
.64179 .32827 m
.59965 .33521 L
s
.6111 .32961 m
.59965 .33521 L
s
.82639 .36834 m
.81418 .3638 L
s
.81418 .3638 m
.82558 .3453 L
s
0 0 0 r
.58468 .43736 m
.5934 .42644 L
s
.303 .569 .889 r
.45403 .48191 m .46593 .49591 L .45999 .50333 L p F P
0 0 1 r
s
.347 .659 1 r
.4747 .5142 m .45999 .50333 L .46593 .49591 L p F P
0 0 1 r
s
.24 .35 .67 r
.61453 .45176 m
.62003 .45497 L
s
.62003 .45497 m
.66575 .43781 L
s
.54405 .44258 m
.51423 .45053 L
s
.51423 .45053 m
.51108 .43719 L
s
.403 .674 .917 r
.596 .38586 m .59541 .40113 L .57497 .39343 L p F P
0 0 1 r
s
.403 .674 .917 r
.57497 .39343 m .57539 .37803 L .596 .38586 L p F P
0 0 1 r
s
0 0 0 r
.4095 .3114 m
.40978 .32718 L
s
.38503 .31543 m
.40978 .32718 L
s
.173 .304 .459 r
.45853 .38358 m .45908 .39888 L .44105 .40836 L p F P
0 0 1 r
s
.24 .35 .67 r
.45024 .39457 m
.45623 .39258 L
s
.44696 .39566 m
.45024 .39457 L
s
.43826 .39856 m
.44696 .39566 L
s
.204 .365 .55 r
.44388 .42444 m .44105 .40836 L .45908 .39888 L p F P
0 0 1 r
s
.24 .35 .67 r
.4293 .41226 m
.44138 .40754 L
s
.43826 .39856 m
.44138 .40754 L
s
0 0 0 r
.60547 .40592 m
.60849 .39686 L
s
.59856 .38699 m
.60849 .39686 L
s
.551 1 1 r
.55657 .52032 m .54082 .52866 L .53867 .52688 L p F P
0 0 1 r
s
.208 .355 .513 r
.47987 .37644 m .48064 .36279 L .50375 .35856 L p F P
0 0 1 r
s
.24 .35 .67 r
.5028 .35838 m
.50282 .35835 L
s
.50032 .35936 m
.50047 .3593 L
s
.47537 .36775 m
.48046 .36603 L
s
.174 .3 .443 r
.48064 .36279 m .47987 .37644 L .45853 .38358 L p F P
0 0 1 r
s
.208 .379 .584 r
.44388 .42444 m .44879 .44103 L .43595 .45123 L p F P
0 0 1 r
s
.24 .35 .67 r
.44579 .43091 m
.45383 .42781 L
s
.244 .448 .692 r
.44395 .46688 m .43595 .45123 L .44879 .44103 L p F P
0 0 1 r
s
0 0 0 r
.43872 .43837 m
.441 .44296 L
s
.441 .44296 m
.44202 .44502 L
s
.44202 .44502 m
.44209 .44516 L
s
.44639 .45383 m
.44657 .45419 L
s
.43872 .43837 m
.44315 .44107 L
s
.44866 .31549 m
.44083 .32075 L
s
.41454 .29968 m
.44083 .32075 L
s
.393 .751 1 r
.47934 .50851 m .49387 .51936 L .49068 .52321 L p F P
0 0 1 r
s
.393 .751 1 r
.49068 .52321 m .4747 .5142 L .47934 .50851 L p F P
0 0 1 r
s
.24 .35 .67 r
.4474 .41852 m
.45383 .42781 L
s
.44138 .40754 m
.44354 .40683 L
s
.44354 .40683 m
.44369 .40678 L
s
.44138 .40754 m
.44168 .40812 L
s
.44168 .40812 m
.44182 .40837 L
s
.44182 .40837 m
.44189 .40851 L
s
.57583 .45114 m
.5575 .45398 L
s
.5575 .45398 m
.57324 .43632 L
s
.347 .659 1 r
.46593 .49591 m .47934 .50851 L .4747 .5142 L p F P
0 0 1 r
s
.445 .856 1 r
.49844 .51596 m .51146 .52647 L .50915 .52817 L p F P
0 0 1 r
s
.445 .856 1 r
.50915 .52817 m .49387 .51936 L .49844 .51596 L p F P
0 0 1 r
s
0 0 0 r
.56613 .34049 m
.5621 .34196 L
s
.5621 .34196 m
.52926 .31419 L
s
.588 1 1 r
.60798 .46947 m .59761 .48416 L .58811 .47588 L p F P
0 0 1 r
s
.588 1 1 r
.58811 .47588 m .59718 .45993 L .60798 .46947 L p F P
0 0 1 r
s
.24 .35 .67 r
.565 .46905 m
.60062 .45209 L
s
.55843 .46894 m
.59191 .44979 L
s
.6111 .32961 m
.55903 .34139 L
s
.56273 .33985 m
.55903 .34139 L
s
0 0 0 r
.5934 .42644 m
.59756 .42016 L
s
.205 .358 .528 r
.45908 .39888 m .45853 .38358 L .47987 .37644 L p F P
0 0 1 r
s
.24 .35 .67 r
.43735 .39066 m
.45853 .38358 L
s
.551 1 1 r
.53867 .52688 m .55235 .51679 L .55657 .52032 L p F P
0 0 1 r
s
.541 1 1 r
.55235 .51679 m .53867 .52688 L .53591 .5254 L p F P
0 0 1 r
s
0 0 0 r
.60464 .40754 m
.60547 .40592 L
s
.60446 .40789 m
.60464 .40754 L
s
.60017 .40068 m
.60547 .40592 L
s
.41267 .42122 m
.42317 .44197 L
s
.42317 .44197 m
.40221 .42964 L
s
.454 .87 1 r
.50418 .51317 m .51437 .52507 L .51146 .52647 L p F P
0 0 1 r
s
.454 .87 1 r
.51146 .52647 m .49844 .51596 L .50418 .51317 L p F P
0 0 1 r
s
.24 .35 .67 r
.61453 .45176 m
.65774 .433 L
s
.60893 .45072 m
.61453 .45176 L
s
.60817 .45058 m
.60893 .45072 L
s
0 0 0 r
.33485 .3347 m
.35401 .37127 L
s
.35141 .37772 m
.35401 .37127 L
s
.512 .89 1 r
.60953 .42712 m .60438 .44353 L .58885 .43459 L p F P
0 0 1 r
s
.512 .89 1 r
.58885 .43459 m .59301 .41751 L .60953 .42712 L p F P
0 0 1 r
s
.573 1 1 r
.57155 .50993 m .55657 .52032 L .55235 .51679 L p F P
0 0 1 r
s
.281 .469 .657 r
.55186 .35937 m .55234 .37299 L .52794 .371 L p F P
0 0 1 r
s
.281 .469 .657 r
.52794 .371 m .52789 .3574 L .55186 .35937 L p F P
0 0 1 r
s
.24 .35 .67 r
.59191 .44979 m
.57583 .45114 L
s
.541 1 1 r
.53591 .5254 m .54689 .51383 L .55235 .51679 L p F P
0 0 1 r
s
.528 1 1 r
.54689 .51383 m .53591 .5254 L .53265 .52427 L p F P
0 0 1 r
s
.463 .887 1 r
.51084 .51112 m .51773 .52404 L .51437 .52507 L p F P
0 0 1 r
s
.463 .887 1 r
.51437 .52507 m .50418 .51317 L .51084 .51112 L p F P
0 0 1 r
s
.24 .35 .67 r
.70408 .44029 m
.74113 .42761 L
s
.70408 .44029 m
.71043 .42935 L
s
.244 .448 .692 r
.44879 .44103 m .45567 .45768 L .44395 .46688 L p F P
0 0 1 r
s
0 0 0 r
.4507 .44566 m
.46661 .45535 L
s
.44627 .44297 m
.44628 .44297 L
s
.44315 .44107 m
.44627 .44297 L
s
.281 .521 .804 r
.45403 .48191 m .44395 .46688 L .45567 .45768 L p F P
0 0 1 r
s
.591 1 1 r
.59761 .48416 m .58535 .49777 L .57741 .49094 L p F P
0 0 1 r
s
.591 1 1 r
.57741 .49094 m .58811 .47588 L .59761 .48416 L p F P
0 0 1 r
s
0 0 0 r
.45847 .29422 m
.47431 .31664 L
s
.47431 .31664 m
.46001 .31409 L
s
.243 .41 .584 r
.50339 .37217 m .50375 .35856 L .52789 .3574 L p F P
0 0 1 r
s
.208 .355 .513 r
.50375 .35856 m .50339 .37217 L .47987 .37644 L p F P
0 0 1 r
s
.24 .35 .67 r
.48356 .369 m
.50174 .3629 L
s
.50047 .3593 m
.50267 .35857 L
s
.50267 .35857 m
.5028 .35838 L
s
.76193 .32333 m
.73039 .32979 L
s
.73039 .32979 m
.70884 .32548 L
s
.403 .768 1 r
.48601 .50347 m .49844 .51596 L .49387 .51936 L p F P
0 0 1 r
s
.403 .768 1 r
.49387 .51936 m .47934 .50851 L .48601 .50347 L p F P
0 0 1 r
s
.24 .35 .67 r
.51117 .35617 m
.5655 .34089 L
s
.50174 .3629 m
.50267 .35857 L
s
.60832 .44833 m
.6437 .43037 L
s
.60718 .44891 m
.60832 .44833 L
s
.60678 .44911 m
.60718 .44891 L
s
.59191 .44979 m
.60157 .44995 L
s
.528 1 1 r
.53265 .52427 m .54044 .51157 L .54689 .51383 L p F P
0 0 1 r
s
.514 .983 1 r
.54044 .51157 m .53265 .52427 L .52904 .52355 L p F P
0 0 1 r
s
.475 .907 1 r
.51814 .50989 m .52141 .52343 L .51773 .52404 L p F P
0 0 1 r
s
.475 .907 1 r
.51773 .52404 m .51084 .51112 L .51814 .50989 L p F P
0 0 1 r
s
.585 1 1 r
.58535 .49777 m .57155 .50993 L .56538 .5047 L p F P
0 0 1 r
s
.573 1 1 r
.55235 .51679 m .56538 .5047 L .57155 .50993 L p F P
0 0 1 r
s
0 0 0 r
.44866 .31549 m
.42475 .29269 L
s
.46001 .31409 m
.44866 .31549 L
s
.243 .41 .584 r
.52789 .3574 m .52794 .371 L .50339 .37217 L p F P
0 0 1 r
s
.24 .35 .67 r
.50267 .35857 m
.51117 .35617 L
s
.585 1 1 r
.56538 .5047 m .57741 .49094 L .58535 .49777 L p F P
0 0 1 r
s
.514 .983 1 r
.52904 .52355 m .53327 .51013 L .54044 .51157 L p F P
0 0 1 r
s
.5 .956 1 r
.53327 .51013 m .52904 .52355 L .52524 .52326 L p F P
0 0 1 r
s
.487 .93 1 r
.52573 .50956 m .52524 .52326 L .52141 .52343 L p F P
0 0 1 r
s
.487 .93 1 r
.52141 .52343 m .51814 .50989 L .52573 .50956 L p F P
0 0 1 r
s
.24 .35 .67 r
.66742 .44456 m
.71043 .42935 L
s
.66742 .44456 m
.66575 .43781 L
s
.83098 .37476 m
.82639 .36834 L
s
.82639 .36834 m
.8384 .3491 L
s
.67881 .32497 m
.64179 .32827 L
s
.65976 .32158 m
.64179 .32827 L
s
.5 .956 1 r
.52524 .52326 m .52573 .50956 L .53327 .51013 L p F P
0 0 1 r
s
.204 .365 .55 r
.45908 .39888 m .46131 .41537 L .44388 .42444 L p F P
0 0 1 r
s
.236 .426 .644 r
.44879 .44103 m .44388 .42444 L .46131 .41537 L p F P
0 0 1 r
s
0 0 0 r
.52644 .44854 m
.52727 .42818 L
s
.52644 .44854 m
.51371 .44023 L
s
.281 .521 .804 r
.45567 .45768 m .46433 .47393 L .45403 .48191 L p F P
0 0 1 r
s
0 0 0 r
.464 .44592 m
.49431 .46702 L
s
.321 .599 .922 r
.46593 .49591 m .45403 .48191 L .46433 .47393 L p F P
0 0 1 r
s
0 0 0 r
.43964 .29083 m
.46001 .31409 L
s
.361 .681 1 r
.47454 .48934 m .48601 .50347 L .47934 .50851 L p F P
0 0 1 r
s
.361 .681 1 r
.47934 .50851 m .46593 .49591 L .47454 .48934 L p F P
0 0 1 r
s
.552 1 1 r
.56538 .5047 m .55235 .51679 L .54689 .51383 L p F P
0 0 1 r
s
.435 .742 1 r
.59541 .40113 m .59301 .41751 L .57326 .41015 L p F P
0 0 1 r
s
.435 .742 1 r
.57326 .41015 m .57497 .39343 L .59541 .40113 L p F P
0 0 1 r
s
0 0 0 r
.58837 .40408 m
.59124 .4069 L
s
.59124 .4069 m
.59231 .40794 L
s
.59521 .39578 m
.60017 .40068 L
s
.24 .35 .67 r
.54988 .42675 m
.51108 .43719 L
s
.51108 .43719 m
.50825 .42383 L
s
0 0 0 r
.38922 .40437 m
.40221 .42964 L
s
.40221 .42964 m
.38428 .41754 L
s
.321 .599 .922 r
.46433 .47393 m .47454 .48934 L .46593 .49591 L p F P
0 0 1 r
s
0 0 0 r
.54578 .44288 m
.55213 .42715 L
s
.54578 .44288 m
.52727 .42818 L
s
.357 .6 .83 r
.57539 .37803 m .57497 .39343 L .55211 .38847 L p F P
0 0 1 r
s
0 0 0 r
.58741 .40314 m
.58837 .40408 L
s
.357 .6 .83 r
.55211 .38847 m .55234 .37299 L .57539 .37803 L p F P
0 0 1 r
s
0 0 0 r
.57176 .35135 m
.60245 .38203 L
s
.57126 .35984 m
.59856 .38699 L
s
.33191 .34072 m
.35141 .37772 L
s
.35324 .38581 m
.35141 .37772 L
s
.24 .35 .67 r
.57324 .43632 m
.54405 .44258 L
s
.54405 .44258 m
.54988 .42675 L
s
.415 .787 1 r
.49444 .49933 m .50418 .51317 L .49844 .51596 L p F P
0 0 1 r
s
.415 .787 1 r
.49844 .51596 m .48601 .50347 L .49444 .49933 L p F P
0 0 1 r
s
.531 .942 1 r
.60438 .44353 m .59718 .45993 L .58303 .45188 L p F P
0 0 1 r
s
.531 .942 1 r
.58303 .45188 m .58885 .43459 L .60438 .44353 L p F P
0 0 1 r
s
.24 .35 .67 r
.57583 .45114 m
.58591 .44332 L
s
.60213 .44356 m
.60235 .44343 L
s
.60164 .44386 m
.60213 .44356 L
s
.60235 .44343 m
.62429 .43005 L
s
.59366 .43731 m
.59601 .43549 L
s
.59366 .43731 m
.59366 .43731 L
s
.59601 .43549 m
.60042 .43207 L
s
.82558 .3453 m
.80519 .34397 L
s
.80519 .34397 m
.80294 .3299 L
s
.73714 .31835 m
.70884 .32548 L
s
.70884 .32548 m
.67881 .32497 L
s
.70251 .31775 m
.67881 .32497 L
s
.238 .412 .597 r
.48025 .39186 m .47987 .37644 L .50339 .37217 L p F P
0 0 1 r
s
.205 .358 .528 r
.47987 .37644 m .48025 .39186 L .45908 .39888 L p F P
0 0 1 r
s
.24 .35 .67 r
.45853 .38358 m
.47987 .37644 L
s
0 0 0 r
.36342 .3067 m
.3717 .33348 L
s
.3551 .33107 m
.3717 .33348 L
s
.235 .415 .615 r
.46131 .41537 m .45908 .39888 L .48025 .39186 L p F P
0 0 1 r
s
.24 .35 .67 r
.74113 .42761 m
.77283 .41519 L
s
.74113 .42761 m
.74908 .41429 L
s
.80294 .3299 m
.77569 .33242 L
s
.77569 .33242 m
.76193 .32333 L
s
.552 1 1 r
.54689 .51383 m .55737 .50031 L .56538 .5047 L p F P
0 0 1 r
s
.53 .999 1 r
.55737 .50031 m .54689 .51383 L .54044 .51157 L p F P
0 0 1 r
s
.236 .426 .644 r
.46131 .41537 m .46518 .43259 L .44879 .44103 L p F P
0 0 1 r
s
.269 .49 .743 r
.45567 .45768 m .44879 .44103 L .46518 .43259 L p F P
0 0 1 r
s
.24 .35 .67 r
.46293 .43852 m
.50825 .42383 L
s
0 0 0 r
.43463 .42425 m
.45291 .43774 L
s
.45291 .43774 m
.45415 .43865 L
s
.45415 .43865 m
.45516 .4394 L
s
.45516 .4394 m
.45537 .43955 L
s
.46097 .44369 m
.464 .44592 L
s
.556 1 1 r
.57741 .49094 m .56538 .5047 L .55737 .50031 L p F P
0 0 1 r
s
.24 .35 .67 r
.82775 .38288 m
.83098 .37476 L
s
.83098 .37476 m
.84322 .35529 L
s
0 0 0 r
.36907 .38831 m
.38428 .41754 L
s
.38428 .41754 m
.3699 .40599 L
s
.49927 .30133 m
.50381 .31566 L
s
.50381 .31566 m
.48024 .30267 L
s
.429 .811 1 r
.50425 .49628 m .51084 .51112 L .50418 .51317 L p F P
0 0 1 r
s
.429 .811 1 r
.50418 .51317 m .49444 .49933 L .50425 .49628 L p F P
0 0 1 r
s
0 0 0 r
.33398 .34936 m
.35324 .38581 L
s
.35945 .39532 m
.35324 .38581 L
s
.24 .35 .67 r
.51731 .35853 m
.56724 .34451 L
s
.50174 .3629 m
.51731 .35853 L
s
.50139 .36925 m
.50174 .3629 L
s
.545 .984 1 r
.59718 .45993 m .58811 .47588 L .5757 .4689 L p F P
0 0 1 r
s
.545 .984 1 r
.5757 .4689 m .58303 .45188 L .59718 .45993 L p F P
0 0 1 r
s
0 0 0 r
.56915 .34157 m
.56613 .34049 L
s
.56613 .34049 m
.52975 .30965 L
s
.52926 .31419 m
.52865 .3219 L
s
.52865 .3219 m
.49927 .30133 L
s
.377 .706 1 r
.48543 .48392 m .49444 .49933 L .48601 .50347 L p F P
0 0 1 r
s
.377 .706 1 r
.48601 .50347 m .47454 .48934 L .48543 .48392 L p F P
0 0 1 r
s
0 0 0 r
.43463 .42425 m
.43872 .43837 L
s
.43872 .43837 m
.41267 .42122 L
s
.314 .532 .747 r
.55234 .37299 m .55211 .38847 L .52791 .38651 L p F P
0 0 1 r
s
.314 .532 .747 r
.52791 .38651 m .52794 .371 L .55234 .37299 L p F P
0 0 1 r
s
.24 .35 .67 r
.62049 .32678 m
.56273 .33985 L
s
.5655 .34089 m
.56273 .33985 L
s
0 0 0 r
.35284 .37351 m
.3699 .40599 L
s
.3699 .40599 m
.35945 .39532 L
s
.553 1 1 r
.58811 .47588 m .57741 .49094 L .56707 .4852 L p F P
0 0 1 r
s
.556 1 1 r
.55737 .50031 m .56707 .4852 L .57741 .49094 L p F P
0 0 1 r
s
.24 .35 .67 r
.66575 .43781 m
.65774 .433 L
s
.70848 .42048 m
.66575 .43781 L
s
0 0 0 r
.34102 .3604 m
.35945 .39532 L
s
.53 .999 1 r
.54044 .51157 m .54788 .49696 L .55737 .50031 L p F P
0 0 1 r
s
.507 .953 1 r
.54788 .49696 m .54044 .51157 L .53327 .51013 L p F P
0 0 1 r
s
.553 1 1 r
.56707 .4852 m .5757 .4689 L .58811 .47588 L p F P
0 0 1 r
s
.24 .35 .67 r
.65976 .32158 m
.6111 .32961 L
s
.62049 .32678 m
.6111 .32961 L
s
.461 .801 1 r
.59301 .41751 m .58885 .43459 L .57029 .42774 L p F P
0 0 1 r
s
0 0 0 r
.57736 .43035 m
.58468 .43736 L
s
.461 .801 1 r
.57029 .42774 m .57326 .41015 L .59301 .41751 L p F P
0 0 1 r
s
.24 .35 .67 r
.77283 .41519 m
.79828 .40338 L
s
.77283 .41519 m
.78223 .3998 L
s
.446 .839 1 r
.515 .49446 m .51814 .50989 L .51084 .51112 L p F P
0 0 1 r
s
.446 .839 1 r
.51084 .51112 m .50425 .49628 L .515 .49446 L p F P
0 0 1 r
s
.24 .35 .67 r
.50825 .42383 m
.50583 .41083 L
s
.275 .469 .67 r
.50356 .38767 m .50339 .37217 L .52794 .371 L p F P
0 0 1 r
s
.238 .412 .597 r
.50339 .37217 m .50356 .38767 L .48025 .39186 L p F P
0 0 1 r
s
.24 .35 .67 r
.47987 .37644 m
.50139 .36925 L
s
.48337 .38354 m
.50163 .37746 L
s
.269 .49 .743 r
.46518 .43259 m .4706 .45008 L .45567 .45768 L p F P
0 0 1 r
s
.304 .557 .846 r
.46433 .47393 m .45567 .45768 L .4706 .45008 L p F P
0 0 1 r
s
0 0 0 r
.46787 .44126 m
.49442 .46318 L
s
.24 .35 .67 r
.81676 .39251 m
.82775 .38288 L
s
.82775 .38288 m
.83983 .36371 L
s
.58958 .43376 m
.60042 .43207 L
s
.58944 .43379 m
.58958 .43376 L
s
.57324 .43632 m
.5875 .43409 L
s
.58212 .42557 m
.58795 .41852 L
s
.507 .953 1 r
.53327 .51013 m .53733 .49481 L .54788 .49696 L p F P
0 0 1 r
s
.485 .911 1 r
.53733 .49481 m .53327 .51013 L .52573 .50956 L p F P
0 0 1 r
s
.339 .629 .955 r
.47741 .46735 m .48543 .48392 L .47454 .48934 L p F P
0 0 1 r
s
.339 .629 .955 r
.47454 .48934 m .46433 .47393 L .47741 .46735 L p F P
0 0 1 r
s
.275 .469 .67 r
.52794 .371 m .52791 .38651 L .50356 .38767 L p F P
0 0 1 r
s
.464 .872 1 r
.5262 .49396 m .52573 .50956 L .51814 .50989 L p F P
0 0 1 r
s
.464 .872 1 r
.51814 .50989 m .515 .49446 L .5262 .49396 L p F P
0 0 1 r
s
0 0 0 r
.51371 .44023 m
.50137 .43386 L
s
.304 .557 .846 r
.4706 .45008 m .47741 .46735 L .46433 .47393 L p F P
0 0 1 r
s
.387 .662 .918 r
.57497 .39343 m .57326 .41015 L .55117 .4054 L p F P
0 0 1 r
s
0 0 0 r
.57531 .40889 m
.5758 .40937 L
s
.387 .662 .918 r
.55117 .4054 m .55211 .38847 L .57497 .39343 L p F P
0 0 1 r
s
0 0 0 r
.56274 .39669 m
.56639 .40023 L
s
.56668 .38283 m
.58741 .40314 L
s
.56955 .37043 m
.59521 .39578 L
s
.485 .911 1 r
.52573 .50956 m .5262 .49396 L .53733 .49481 L p F P
0 0 1 r
s
0 0 0 r
.41454 .29968 m
.4095 .3114 L
s
.38444 .29611 m
.4095 .3114 L
s
.24 .35 .67 r
.71043 .42935 m
.74908 .41429 L
s
.71043 .42935 m
.70848 .42048 L
s
.79828 .40338 m
.81676 .39251 L
s
.79828 .40338 m
.80889 .38628 L
s
.235 .415 .615 r
.48025 .39186 m .48176 .40865 L .46131 .41537 L p F P
0 0 1 r
s
.265 .474 .704 r
.46518 .43259 m .46131 .41537 L .48176 .40865 L p F P
0 0 1 r
s
.24 .35 .67 r
.47278 .42162 m
.50583 .41083 L
s
.524 .973 1 r
.56707 .4852 m .55737 .50031 L .54788 .49696 L p F P
0 0 1 r
s
.24 .35 .67 r
.81676 .39251 m
.82828 .37414 L
s
.5679 .35064 m
.50139 .36925 L
s
.50139 .36925 m
.50163 .37746 L
s
.394 .736 1 r
.49815 .47992 m .50425 .49628 L .49444 .49933 L p F P
0 0 1 r
s
.394 .736 1 r
.49444 .49933 m .48543 .48392 L .49815 .47992 L p F P
0 0 1 r
s
.268 .468 .682 r
.48176 .40865 m .48025 .39186 L .50356 .38767 L p F P
0 0 1 r
s
.24 .35 .67 r
.48623 .40435 m
.50389 .39854 L
s
.5001 .3881 m
.50026 .38805 L
s
0 0 0 r
.43457 .41254 m
.45966 .4343 L
s
.45966 .4343 m
.46238 .43666 L
s
.46238 .43666 m
.46268 .43692 L
s
.482 .852 1 r
.58885 .43459 m .58303 .45188 L .56614 .44571 L p F P
0 0 1 r
s
.482 .852 1 r
.56614 .44571 m .57029 .42774 L .58885 .43459 L p F P
0 0 1 r
s
0 0 0 r
.55213 .42715 m
.56714 .44138 L
s
.24 .35 .67 r
.58068 .42731 m
.58212 .42557 L
s
.58028 .42779 m
.58068 .42731 L
s
.8384 .3491 m
.82558 .3453 L
s
.82558 .3453 m
.82332 .33021 L
s
.50583 .41083 m
.50389 .39854 L
s
.65774 .433 m
.69817 .41415 L
s
.65774 .433 m
.6437 .43037 L
s
0 0 0 r
.38444 .29611 m
.38503 .31543 L
s
.36342 .3067 m
.38503 .31543 L
s
.24 .35 .67 r
.62429 .43005 m
.60042 .43207 L
s
.60042 .43207 m
.62344 .41293 L
s
.514 .938 1 r
.5757 .4689 m .56707 .4852 L .55477 .48081 L p F P
0 0 1 r
s
.524 .973 1 r
.54788 .49696 m .55477 .48081 L .56707 .4852 L p F P
0 0 1 r
s
.493 .913 1 r
.55477 .48081 m .54788 .49696 L .53733 .49481 L p F P
0 0 1 r
s
.24 .35 .67 r
.78782 .31981 m
.76193 .32333 L
s
.76193 .32333 m
.73714 .31835 L
s
.265 .474 .704 r
.48176 .40865 m .4844 .42634 L .46518 .43259 L p F P
0 0 1 r
s
.296 .534 .796 r
.4706 .45008 m .46518 .43259 L .4844 .42634 L p F P
0 0 1 r
s
0 0 0 r
.47869 .43615 m
.49862 .45868 L
s
.46691 .4324 m
.46876 .43419 L
s
.46552 .43524 m
.46691 .4324 L
s
.46532 .43564 m
.46549 .4353 L
s
.46522 .43583 m
.46532 .43564 L
s
.46549 .4353 m
.46552 .43524 L
s
.46876 .43419 m
.46918 .43459 L
s
.47586 .44103 m
.49588 .46036 L
s
.24 .35 .67 r
.51727 .3731 m
.56744 .35913 L
s
.50163 .37746 m
.51727 .3731 L
s
.50163 .37746 m
.50247 .38731 L
s
.5 .898 1 r
.58303 .45188 m .5757 .4689 L .56092 .46357 L p F P
0 0 1 r
s
.5 .898 1 r
.56092 .46357 m .56614 .44571 L .58303 .45188 L p F P
0 0 1 r
s
.415 .771 1 r
.5121 .47754 m .515 .49446 L .50425 .49628 L p F P
0 0 1 r
s
.415 .771 1 r
.50425 .49628 m .49815 .47992 L .5121 .47754 L p F P
0 0 1 r
s
.343 .59 .832 r
.55211 .38847 m .55117 .4054 L .52781 .40353 L p F P
0 0 1 r
s
.343 .59 .832 r
.52781 .40353 m .52791 .38651 L .55211 .38847 L p F P
0 0 1 r
s
.24 .35 .67 r
.5404 .40138 m
.55962 .39613 L
s
.53625 .40251 m
.5404 .40138 L
s
.36 .664 .993 r
.4927 .46249 m .49815 .47992 L .48543 .48392 L p F P
0 0 1 r
s
.36 .664 .993 r
.48543 .48392 m .47741 .46735 L .4927 .46249 L p F P
0 0 1 r
s
.514 .938 1 r
.55477 .48081 m .56092 .46357 L .5757 .4689 L p F P
0 0 1 r
s
.24 .35 .67 r
.6437 .43037 m
.67994 .41068 L
s
.6437 .43037 m
.62429 .43005 L
s
.413 .718 1 r
.57326 .41015 m .57029 .42774 L .54955 .42333 L p F P
0 0 1 r
s
.24 .35 .67 r
.54988 .42675 m
.55093 .42362 L
s
.54988 .42675 m
.5577 .42506 L
s
0 0 0 r
.55213 .42715 m
.55325 .42411 L
s
.413 .718 1 r
.54955 .42333 m .55117 .4054 L .57326 .41015 L p F P
0 0 1 r
s
0 0 0 r
.55784 .41161 m
.55895 .41267 L
s
.24 .35 .67 r
.55361 .41153 m
.55512 .41112 L
s
0 0 0 r
.55738 .41285 m
.55784 .41161 L
s
.24 .35 .67 r
.57198 .42197 m
.57222 .42192 L
s
.57222 .42192 m
.58795 .41852 L
s
.55475 .41222 m
.55512 .41112 L
s
0 0 0 r
.56639 .40023 m
.57268 .40634 L
s
.57268 .40634 m
.57504 .40863 L
s
.57504 .40863 m
.57531 .40889 L
s
.24 .35 .67 r
.62429 .43005 m
.65462 .41027 L
s
.304 .526 .754 r
.50429 .40463 m .50356 .38767 L .52791 .38651 L p F P
0 0 1 r
s
.24 .35 .67 r
.50389 .39854 m
.50403 .3985 L
s
.268 .468 .682 r
.50356 .38767 m .50429 .40463 L .48176 .40865 L p F P
0 0 1 r
s
.24 .35 .67 r
.50259 .38826 m
.50261 .38842 L
s
.50255 .3879 m
.50259 .38826 L
s
.50247 .38731 m
.50255 .3879 L
s
.50026 .38805 m
.50247 .38731 L
s
.70251 .31775 m
.65976 .32158 L
s
.67451 .31786 m
.65976 .32158 L
s
.51099 .38495 m
.56587 .36975 L
s
0 0 0 r
.34564 .30131 m
.3551 .33107 L
s
.34267 .33147 m
.3551 .33107 L
s
.57104 .34521 m
.56915 .34157 L
s
.56915 .34157 m
.53013 .30846 L
s
.493 .913 1 r
.53733 .49481 m .54108 .47799 L .55477 .48081 L p F P
0 0 1 r
s
.464 .859 1 r
.54108 .47799 m .53733 .49481 L .5262 .49396 L p F P
0 0 1 r
s
0 0 0 r
.50137 .43386 m
.49001 .42974 L
s
.296 .534 .796 r
.4844 .42634 m .48808 .44446 L .4706 .45008 L p F P
0 0 1 r
s
0 0 0 r
.48648 .43658 m
.50253 .45824 L
s
.4817 .43014 m
.48194 .43045 L
s
.48018 .42809 m
.4817 .43014 L
s
.47236 .42899 m
.47278 .42947 L
s
.4753 .43232 m
.47558 .43263 L
s
.47278 .42947 m
.4753 .43232 L
s
.328 .598 .892 r
.47741 .46735 m .4706 .45008 L .48808 .44446 L p F P
0 0 1 r
s
.438 .812 1 r
.52663 .47688 m .5262 .49396 L .515 .49446 L p F P
0 0 1 r
s
.438 .812 1 r
.515 .49446 m .5121 .47754 L .52663 .47688 L p F P
0 0 1 r
s
.328 .598 .892 r
.48808 .44446 m .4927 .46249 L .47741 .46735 L p F P
0 0 1 r
s
0 0 0 r
.49001 .42974 m
.50742 .45905 L
s
.304 .526 .754 r
.52791 .38651 m .52781 .40353 L .50429 .40463 L p F P
0 0 1 r
s
.24 .35 .67 r
.50247 .38731 m
.51099 .38495 L
s
.50583 .41083 m
.53146 .40382 L
s
.52334 .39318 m
.56324 .38221 L
s
.51721 .39487 m
.52334 .39318 L
s
.62752 .32686 m
.5655 .34089 L
s
.56724 .34451 m
.5655 .34089 L
s
.297 .525 .768 r
.4844 .42634 m .48176 .40865 L .50429 .40463 L p F P
0 0 1 r
s
.464 .859 1 r
.5262 .49396 m .52663 .47688 L .54108 .47799 L p F P
0 0 1 r
s
.24 .35 .67 r
.82332 .33021 m
.80294 .3299 L
s
.80294 .3299 m
.78782 .31981 L
s
0 0 0 r
.46691 .4324 m
.47236 .42899 L
s
.43863 .40387 m
.46691 .4324 L
s
.24 .35 .67 r
.74908 .41429 m
.78223 .3998 L
s
.74908 .41429 m
.74694 .40347 L
s
0 0 0 r
.47051 .28537 m
.48024 .30267 L
s
.48024 .30267 m
.45847 .29422 L
s
.476 .868 1 r
.56092 .46357 m .55477 .48081 L .54108 .47799 L p F P
0 0 1 r
s
0 0 0 r
.40706 .4026 m
.41267 .42122 L
s
.41267 .42122 m
.38922 .40437 L
s
.24 .35 .67 r
.7604 .31427 m
.73714 .31835 L
s
.73714 .31835 m
.70251 .31775 L
s
.385 .705 1 r
.5095 .45958 m .5121 .47754 L .49815 .47992 L p F P
0 0 1 r
s
.385 .705 1 r
.49815 .47992 m .4927 .46249 L .5095 .45958 L p F P
0 0 1 r
s
.24 .35 .67 r
.70848 .42048 m
.69817 .41415 L
s
.74694 .40347 m
.70848 .42048 L
s
.437 .771 1 r
.57029 .42774 m .56614 .44571 L .54728 .44174 L p F P
0 0 1 r
s
.437 .771 1 r
.54728 .44174 m .54955 .42333 L .57029 .42774 L p F P
0 0 1 r
s
.24 .35 .67 r
.50825 .42383 m
.55054 .41236 L
s
.72197 .3136 m
.70251 .31775 L
s
.84322 .35529 m
.8384 .3491 L
s
.8384 .3491 m
.83616 .33339 L
s
.67451 .31786 m
.62049 .32678 L
s
.62752 .32686 m
.62049 .32678 L
s
.37 .646 .914 r
.55117 .4054 m .54955 .42333 L .52762 .42159 L p F P
0 0 1 r
s
0 0 0 r
.54713 .42313 m
.54935 .42492 L
s
.37 .646 .914 r
.52762 .42159 m .52781 .40353 L .55117 .4054 L p F P
0 0 1 r
s
0 0 0 r
.52804 .40779 m
.53387 .41248 L
s
.53387 .41248 m
.536 .41419 L
s
.536 .41419 m
.53861 .41629 L
s
.55784 .41161 m
.56274 .39669 L
s
.52874 .38796 m
.55689 .41084 L
s
.55689 .41084 m
.55784 .41161 L
s
.457 .821 1 r
.56614 .44571 m .56092 .46357 L .54443 .46014 L p F P
0 0 1 r
s
.476 .868 1 r
.54108 .47799 m .54443 .46014 L .56092 .46357 L p F P
0 0 1 r
s
.297 .525 .768 r
.50429 .40463 m .50554 .42261 L .4844 .42634 L p F P
0 0 1 r
s
.326 .583 .855 r
.48808 .44446 m .4844 .42634 L .50554 .42261 L p F P
0 0 1 r
s
0 0 0 r
.49974 .42988 m
.50137 .43386 L
s
.48573 .42902 m
.48605 .42907 L
s
.48503 .4289 m
.48573 .42902 L
s
.48018 .42809 m
.48503 .4289 L
s
.457 .821 1 r
.54443 .46014 m .54728 .44174 L .56614 .44571 L p F P
0 0 1 r
s
.332 .582 .837 r
.50554 .42261 m .50429 .40463 L .52781 .40353 L p F P
0 0 1 r
s
0 0 0 r
.42475 .29269 m
.41454 .29968 L
s
.3904 .2817 m
.41454 .29968 L
s
.24 .35 .67 r
.55512 .41112 m
.6012 .40108 L
s
.55512 .41112 m
.55962 .39613 L
s
0 0 0 r
.44667 .3987 m
.47236 .42899 L
s
.47236 .42899 m
.48018 .42809 L
s
.24 .35 .67 r
.62344 .41293 m
.58795 .41852 L
s
.58795 .41852 m
.6012 .40108 L
s
.442 .806 1 r
.54443 .46014 m .54108 .47799 L .52663 .47688 L p F P
0 0 1 r
s
0 0 0 r
.43457 .41254 m
.43463 .42425 L
s
.43463 .42425 m
.40706 .4026 L
s
.412 .752 1 r
.52702 .45879 m .52663 .47688 L .5121 .47754 L p F P
0 0 1 r
s
.412 .752 1 r
.5121 .47754 m .5095 .45958 L .52702 .45879 L p F P
0 0 1 r
s
.355 .643 .945 r
.5073 .4411 m .5095 .45958 L .4927 .46249 L p F P
0 0 1 r
s
.355 .643 .945 r
.4927 .46249 m .48808 .44446 L .5073 .4411 L p F P
0 0 1 r
s
0 0 0 r
.45831 .39733 m
.48018 .42809 L
s
.332 .582 .837 r
.52781 .40353 m .52762 .42159 L .50554 .42261 L p F P
0 0 1 r
s
0 0 0 r
.51796 .42203 m
.52727 .42818 L
s
.50836 .41569 m
.51646 .42105 L
s
.52727 .42818 m
.52752 .42159 L
s
.52765 .41795 m
.52804 .40779 L
s
.326 .583 .855 r
.50554 .42261 m .5073 .4411 L .48808 .44446 L p F P
0 0 1 r
s
0 0 0 r
.48869 .42741 m
.4892 .42831 L
s
.47299 .39984 m
.48869 .42741 L
s
.48996 .40607 m
.49707 .42339 L
s
.49795 .42552 m
.49803 .42571 L
s
.49707 .42339 m
.49795 .42552 L
s
.442 .806 1 r
.52663 .47688 m .52702 .45879 L .54443 .46014 L p F P
0 0 1 r
s
0 0 0 r
.52975 .30965 m
.52926 .31419 L
s
.52926 .31419 m
.4953 .29032 L
s
.57176 .35135 m
.57104 .34521 L
s
.57104 .34521 m
.53036 .31073 L
s
.24 .35 .67 r
.78223 .3998 m
.80889 .38628 L
s
.78223 .3998 m
.78 .38727 L
s
.395 .7 .995 r
.54955 .42333 m .54728 .44174 L .52735 .44018 L p F P
0 0 1 r
s
.395 .7 .995 r
.52735 .44018 m .52762 .42159 L .54955 .42333 L p F P
0 0 1 r
s
.24 .35 .67 r
.63195 .32991 m
.56724 .34451 L
s
.5679 .35064 m
.56724 .34451 L
s
.419 .753 1 r
.54728 .44174 m .54443 .46014 L .52702 .45879 L p F P
0 0 1 r
s
.359 .638 .921 r
.5073 .4411 m .50554 .42261 L .52762 .42159 L p F P
0 0 1 r
s
0 0 0 r
.50981 .42236 m
.50981 .42236 L
s
.51276 .43586 m
.51371 .44023 L
s
.385 .694 1 r
.52735 .44018 m .52702 .45879 L .5095 .45958 L p F P
0 0 1 r
s
.385 .694 1 r
.5095 .45958 m .5073 .4411 L .52735 .44018 L p F P
0 0 1 r
s
.24 .35 .67 r
.83983 .36371 m
.84322 .35529 L
s
.84322 .35529 m
.84099 .33939 L
s
.419 .753 1 r
.52702 .45879 m .52735 .44018 L .54728 .44174 L p F P
0 0 1 r
s
.359 .638 .921 r
.52762 .42159 m .52735 .44018 L .5073 .4411 L p F P
0 0 1 r
s
0 0 0 r
.50836 .41569 m
.50981 .42236 L
s
.24 .35 .67 r
.69817 .41415 m
.73464 .39574 L
s
.69817 .41415 m
.67994 .41068 L
s
0 0 0 r
.3323 .29949 m
.34267 .33147 L
s
.33485 .3347 m
.34267 .33147 L
s
.4439 .27498 m
.45847 .29422 L
s
.45847 .29422 m
.43964 .29083 L
s
.4953 .29032 m
.49927 .30133 L
s
.49927 .30133 m
.47051 .28537 L
s
.56274 .39669 m
.56668 .38283 L
s
.56274 .39669 m
.52934 .36927 L
s
.24 .35 .67 r
.80721 .31938 m
.78782 .31981 L
s
.78782 .31981 m
.7604 .31427 L
s
.65462 .41027 m
.62344 .41293 L
s
.62344 .41293 m
.64421 .39424 L
s
.83616 .33339 m
.82332 .33021 L
s
.82332 .33021 m
.80721 .31938 L
s
.80889 .38628 m
.82828 .37414 L
s
.80889 .38628 m
.80664 .37235 L
s
.61259 .38449 m
.55962 .39613 L
s
.55962 .39613 m
.56324 .38221 L
s
0 0 0 r
.42475 .29269 m
.40274 .27309 L
s
.43964 .29083 m
.42475 .29269 L
s
.38212 .38159 m
.38922 .40437 L
s
.38922 .40437 m
.36907 .38831 L
s
.24 .35 .67 r
.82828 .37414 m
.83983 .36371 L
s
.83983 .36371 m
.83759 .34805 L
s
.72197 .3136 m
.67451 .31786 L
s
.68556 .31728 m
.67451 .31786 L
s
0 0 0 r
.57126 .35984 m
.57176 .35135 L
s
.57176 .35135 m
.53045 .31645 L
s
.24 .35 .67 r
.82828 .37414 m
.82603 .35915 L
s
.74694 .40347 m
.78 .38727 L
s
.74694 .40347 m
.73464 .39574 L
s
.67994 .41068 m
.71265 .39149 L
s
.67994 .41068 m
.65462 .41027 L
s
.63362 .33586 m
.5679 .35064 L
s
.56744 .35913 m
.5679 .35064 L
s
0 0 0 r
.42089 .2708 m
.43964 .29083 L
s
.24 .35 .67 r
.65462 .41027 m
.682 .39099 L
s
0 0 0 r
.36248 .28425 m
.36342 .3067 L
s
.34564 .30131 m
.36342 .3067 L
s
.50836 .41569 m
.50331 .39128 L
s
.50836 .41569 m
.48996 .40607 L
s
.24 .35 .67 r
.68556 .31728 m
.62752 .32686 L
s
.63195 .32991 m
.62752 .32686 L
s
0 0 0 r
.56668 .38283 m
.56955 .37043 L
s
.56668 .38283 m
.52982 .35228 L
s
.24 .35 .67 r
.64421 .39424 m
.6012 .40108 L
s
.6012 .40108 m
.61259 .38449 L
s
.62177 .36926 m
.56324 .38221 L
s
.56324 .38221 m
.56587 .36975 L
s
0 0 0 r
.3904 .2817 m
.38444 .29611 L
s
.36248 .28425 m
.38444 .29611 L
s
.56955 .37043 m
.57126 .35984 L
s
.57126 .35984 m
.53039 .32547 L
s
.52804 .40779 m
.52874 .38796 L
s
.52804 .40779 m
.50331 .39128 L
s
.24 .35 .67 r
.77782 .31343 m
.7604 .31427 L
s
.7604 .31427 m
.72197 .3136 L
s
0 0 0 r
.56955 .37043 m
.53018 .33753 L
s
.24 .35 .67 r
.63245 .34458 m
.56744 .35913 L
s
.56587 .36975 m
.56744 .35913 L
s
.73656 .31271 m
.72197 .3136 L
s
.62846 .35582 m
.56587 .36975 L
s
0 0 0 r
.43863 .40387 m
.43457 .41254 L
s
.43457 .41254 m
.40675 .38709 L
s
.32388 .30139 m
.33485 .3347 L
s
.33191 .34072 m
.33485 .3347 L
s
.24 .35 .67 r
.84099 .33939 m
.83616 .33339 L
s
.83616 .33339 m
.81943 .32211 L
s
0 0 0 r
.36061 .36187 m
.36907 .38831 L
s
.36907 .38831 m
.35284 .37351 L
s
.24 .35 .67 r
.78 .38727 m
.76602 .3783 L
s
.80664 .37235 m
.78 .38727 L
s
0 0 0 r
.53013 .30846 m
.52975 .30965 L
s
.52975 .30965 m
.49203 .28305 L
s
.24 .35 .67 r
.73464 .39574 m
.76602 .3783 L
s
.73464 .39574 m
.71265 .39149 L
s
0 0 0 r
.40675 .38709 m
.40706 .4026 L
s
.40706 .4026 m
.38212 .38159 L
s
.24 .35 .67 r
.81943 .32211 m
.80721 .31938 L
s
.80721 .31938 m
.77782 .31343 L
s
.682 .39099 m
.64421 .39424 L
s
.64421 .39424 m
.66209 .37656 L
s
.69253 .31993 m
.63195 .32991 L
s
.63362 .33586 m
.63195 .32991 L
s
.66209 .37656 m
.61259 .38449 L
s
.61259 .38449 m
.62177 .36926 L
s
0 0 0 r
.32072 .30698 m
.33191 .34072 L
s
.33398 .34936 m
.33191 .34072 L
s
.24 .35 .67 r
.73656 .31271 m
.68556 .31728 L
s
.69253 .31993 m
.68556 .31728 L
s
0 0 0 r
.48996 .40607 m
.47918 .3785 L
s
.48996 .40607 m
.47299 .39984 L
s
.34322 .34402 m
.35284 .37351 L
s
.35284 .37351 m
.34102 .3604 L
s
.24 .35 .67 r
.84099 .33939 m
.82402 .32797 L
s
.84099 .33939 m
.83759 .34805 L
s
.71265 .39149 m
.74082 .37337 L
s
.71265 .39149 m
.682 .39099 L
s
.80664 .37235 m
.79134 .36235 L
s
.82603 .35915 m
.80664 .37235 L
s
.682 .39099 m
.70559 .37278 L
s
0 0 0 r
.46197 .27174 m
.47051 .28537 L
s
.47051 .28537 m
.4439 .27498 L
s
.32295 .31615 m
.33398 .34936 L
s
.34102 .3604 m
.33398 .34936 L
s
.44667 .3987 m
.43863 .40387 L
s
.43863 .40387 m
.41189 .37557 L
s
.33052 .32862 m
.34102 .3604 L
s
.24 .35 .67 r
.7888 .31591 m
.77782 .31343 L
s
.77782 .31343 m
.73656 .31271 L
s
.82603 .35915 m
.83759 .34805 L
s
.83759 .34805 m
.82079 .3368 L
s
.82603 .35915 m
.80979 .34838 L
s
.69515 .32576 m
.63362 .33586 L
s
.63245 .34458 m
.63362 .33586 L
s
.74576 .31517 m
.73656 .31271 L
s
.67652 .36042 m
.62177 .36926 L
s
.62177 .36926 m
.62846 .35582 L
s
0 0 0 r
.52874 .38796 m
.52934 .36927 L
s
.52874 .38796 m
.49874 .3677 L
s
.34436 .27628 m
.34564 .30131 L
s
.3323 .29949 m
.34564 .30131 L
s
.24 .35 .67 r
.76602 .3783 m
.79134 .36235 L
s
.76602 .3783 m
.74082 .37337 L
s
0 0 0 r
.40274 .27309 m
.3904 .2817 L
s
.36919 .26746 m
.3904 .2817 L
s
.49203 .28305 m
.4953 .29032 L
s
.4953 .29032 m
.46197 .27174 L
s
.24 .35 .67 r
.82402 .32797 m
.81943 .32211 L
s
.81943 .32211 m
.7888 .31591 L
s
0 0 0 r
.47299 .39984 m
.45688 .3702 L
s
.47299 .39984 m
.45831 .39733 L
s
.24 .35 .67 r
.69331 .33463 m
.63245 .34458 L
s
.62846 .35582 m
.63245 .34458 L
s
.68703 .3463 m
.62846 .35582 L
s
.70559 .37278 m
.66209 .37656 L
s
.66209 .37656 m
.67652 .36042 L
s
0 0 0 r
.42234 .36869 m
.44667 .3987 L
s
.45831 .39733 m
.44667 .3987 L
s
.24 .35 .67 r
.74576 .31517 m
.69253 .31993 L
s
.69515 .32576 m
.69253 .31993 L
s
0 0 0 r
.53036 .31073 m
.53013 .30846 L
s
.53013 .30846 m
.48956 .27985 L
s
.50331 .39128 m
.49874 .3677 L
s
.50331 .39128 m
.47918 .3785 L
s
.45831 .39733 m
.43759 .36686 L
s
.24 .35 .67 r
.74082 .37337 m
.76356 .35686 L
s
.74082 .37337 m
.70559 .37278 L
s
.70559 .37278 m
.72462 .35621 L
s
0 0 0 r
.38149 .36255 m
.38212 .38159 L
s
.38212 .38159 m
.36061 .36187 L
s
.24 .35 .67 r
.79134 .36235 m
.80979 .34838 L
s
.79134 .36235 m
.76356 .35686 L
s
0 0 0 r
.36919 .26746 m
.36248 .28425 L
s
.34436 .27628 m
.36248 .28425 L
s
.24 .35 .67 r
.82079 .3368 m
.82402 .32797 L
s
.82402 .32797 m
.79293 .32169 L
s
0 0 0 r
.43109 .25962 m
.4439 .27498 L
s
.4439 .27498 m
.42089 .2708 L
s
.24 .35 .67 r
.79293 .32169 m
.7888 .31591 L
s
.7888 .31591 m
.74576 .31517 L
s
.74922 .32094 m
.74576 .31517 L
s
0 0 0 r
.41189 .37557 m
.40675 .38709 L
s
.40675 .38709 m
.38149 .36255 L
s
.24 .35 .67 r
.72462 .35621 m
.67652 .36042 L
s
.67652 .36042 m
.68703 .3463 L
s
0 0 0 r
.40274 .27309 m
.38338 .25741 L
s
.42089 .2708 m
.40274 .27309 L
s
.24 .35 .67 r
.74922 .32094 m
.69515 .32576 L
s
.69331 .33463 m
.69515 .32576 L
s
0 0 0 r
.52934 .36927 m
.52982 .35228 L
s
.52934 .36927 m
.49478 .34568 L
s
.24 .35 .67 r
.80979 .34838 m
.82079 .3368 L
s
.80979 .34838 m
.78014 .34247 L
s
.82079 .3368 m
.79003 .33062 L
s
0 0 0 r
.40439 .25473 m
.42089 .2708 L
s
.24 .35 .67 r
.7385 .34176 m
.68703 .3463 L
s
.68703 .3463 m
.69331 .33463 L
s
.74678 .32988 m
.69331 .33463 L
s
.76356 .35686 m
.78014 .34247 L
s
.76356 .35686 m
.72462 .35621 L
s
0 0 0 r
.33074 .27255 m
.3323 .29949 L
s
.32388 .30139 m
.3323 .29949 L
s
.53045 .31645 m
.53036 .31073 L
s
.53036 .31073 m
.48801 .28089 L
s
.24 .35 .67 r
.72462 .35621 m
.7385 .34176 L
s
.79003 .33062 m
.79293 .32169 L
s
.79293 .32169 m
.74922 .32094 L
s
.74678 .32988 m
.74922 .32094 L
s
.78014 .34247 m
.79003 .33062 L
s
.78014 .34247 m
.7385 .34176 L
s
.79003 .33062 m
.74678 .32988 L
s
.7385 .34176 m
.74678 .32988 L
s
0 0 0 r
.52982 .35228 m
.53018 .33753 L
s
.52982 .35228 m
.49158 .32593 L
s
.47918 .3785 m
.46937 .35197 L
s
.47918 .3785 m
.45688 .3702 L
s
.35962 .33968 m
.36061 .36187 L
s
.36061 .36187 m
.34322 .34402 L
s
.48956 .27985 m
.49203 .28305 L
s
.49203 .28305 m
.45491 .26231 L
s
.53039 .32547 m
.53045 .31645 L
s
.53045 .31645 m
.48742 .28622 L
s
.45491 .26231 m
.46197 .27174 L
s
.46197 .27174 m
.43109 .25962 L
s
.42234 .36869 m
.41189 .37557 L
s
.41189 .37557 m
.38755 .34835 L
s
.49874 .3677 m
.49478 .34568 L
s
.49874 .3677 m
.46937 .35197 L
s
.53018 .33753 m
.53039 .32547 L
s
.53018 .33753 m
.48924 .30909 L
s
.53039 .32547 m
.48784 .29571 L
s
.32213 .27327 m
.32388 .30139 L
s
.32072 .30698 m
.32388 .30139 L
s
.38338 .25741 m
.36919 .26746 L
s
.35165 .25752 m
.36919 .26746 L
s
.35165 .25752 m
.34436 .27628 L
s
.33074 .27255 m
.34436 .27628 L
s
.34189 .31921 m
.34322 .34402 L
s
.34322 .34402 m
.33052 .32862 L
s
.38755 .34835 m
.38149 .36255 L
s
.38149 .36255 m
.35962 .33968 L
s
.45688 .3702 m
.44218 .34172 L
s
.45688 .3702 m
.43759 .36686 L
s
.40014 .33985 m
.42234 .36869 L
s
.43759 .36686 m
.42234 .36869 L
s
.31888 .2785 m
.32072 .30698 L
s
.32295 .31615 m
.32072 .30698 L
s
.43759 .36686 m
.41868 .3376 L
s
.32892 .30184 m
.33052 .32862 L
s
.33052 .32862 m
.32295 .31615 L
s
.32117 .28812 m
.32295 .31615 L
s
.42048 .24875 m
.43109 .25962 L
s
.43109 .25962 m
.40439 .25473 L
s
.48801 .28089 m
.48956 .27985 L
s
.48956 .27985 m
.4496 .25749 L
s
.38338 .25741 m
.36735 .24627 L
s
.40439 .25473 m
.38338 .25741 L
s
.49478 .34568 m
.49158 .32593 L
s
.49478 .34568 m
.46086 .32732 L
s
.39072 .24327 m
.40439 .25473 L
s
.46937 .35197 m
.46086 .32732 L
s
.46937 .35197 m
.44218 .34172 L
s
.4496 .25749 m
.45491 .26231 L
s
.45491 .26231 m
.42048 .24875 L
s
.33844 .25232 m
.33074 .27255 L
s
.32213 .27327 m
.33074 .27255 L
s
.36642 .32309 m
.35962 .33968 L
s
.35962 .33968 m
.34189 .31921 L
s
.40014 .33985 m
.38755 .34835 L
s
.38755 .34835 m
.36642 .32309 L
s
.48742 .28622 m
.48801 .28089 L
s
.48801 .28089 m
.44624 .25754 L
s
.36735 .24627 m
.35165 .25752 L
s
.33844 .25232 m
.35165 .25752 L
s
.49158 .32593 m
.48924 .30909 L
s
.49158 .32593 m
.45395 .30537 L
s
.44218 .34172 m
.42942 .31533 L
s
.44218 .34172 m
.41868 .3376 L
s
.48784 .29571 m
.48742 .28622 L
s
.48742 .28622 m
.44497 .26256 L
s
.38085 .31314 m
.40014 .33985 L
s
.41868 .3376 m
.40014 .33985 L
s
.48924 .30909 m
.48784 .29571 L
s
.48924 .30909 m
.44889 .28686 L
s
.33008 .25215 m
.32213 .27327 L
s
.31888 .2785 m
.32213 .27327 L
s
.34926 .30062 m
.34189 .31921 L
s
.34189 .31921 m
.32892 .30184 L
s
.48784 .29571 m
.44586 .27244 L
s
.41249 .24285 m
.42048 .24875 L
s
.42048 .24875 m
.39072 .24327 L
s
.41868 .3376 m
.40224 .3105 L
s
.46086 .32732 m
.45395 .30537 L
s
.46086 .32732 m
.42942 .31533 L
s
.44624 .25754 m
.4496 .25749 L
s
.4496 .25749 m
.41249 .24285 L
s
.36735 .24627 m
.35527 .24017 L
s
.39072 .24327 m
.36735 .24627 L
s
.32693 .25709 m
.31888 .2785 L
s
.32117 .28812 m
.31888 .2785 L
s
.33668 .28173 m
.32892 .30184 L
s
.32892 .30184 m
.32117 .28812 L
s
.38042 .23694 m
.39072 .24327 L
s
.38085 .31314 m
.36642 .32309 L
s
.36642 .32309 m
.34926 .30062 L
s
.32915 .26706 m
.32117 .28812 L
s
.35527 .24017 m
.33844 .25232 L
s
.33008 .25215 m
.33844 .25232 L
s
.45395 .30537 m
.44889 .28686 L
s
.45395 .30537 m
.41903 .29192 L
s
.42942 .31533 m
.41903 .29192 L
s
.42942 .31533 m
.40224 .3105 L
s
.44497 .26256 m
.44624 .25754 L
s
.44624 .25754 m
.40743 .24225 L
s
.36516 .28946 m
.38085 .31314 L
s
.40224 .3105 m
.38085 .31314 L
s
.40743 .24225 m
.41249 .24285 L
s
.41249 .24285 m
.38042 .23694 L
s
.36516 .28946 m
.34926 .30062 L
s
.34926 .30062 m
.33668 .28173 L
s
.40224 .3105 m
.38886 .2865 L
s
.34761 .23945 m
.33008 .25215 L
s
.32693 .25709 m
.33008 .25215 L
s
.35527 .24017 m
.34761 .23945 L
s
.38042 .23694 m
.35527 .24017 L
s
.44889 .28686 m
.44586 .27244 L
s
.44889 .28686 m
.41142 .27231 L
s
.44586 .27244 m
.44497 .26256 L
s
.44497 .26256 m
.40552 .24705 L
s
.37389 .23607 m
.38042 .23694 L
s
.44586 .27244 m
.40686 .25718 L
s
.35365 .26965 m
.33668 .28173 L
s
.33668 .28173 m
.32915 .26706 L
s
.34473 .24422 m
.32693 .25709 L
s
.32915 .26706 m
.32693 .25709 L
s
.41903 .29192 m
.41142 .27231 L
s
.41903 .29192 m
.38886 .2865 L
s
.34676 .25439 m
.32915 .26706 L
s
.40552 .24705 m
.40743 .24225 L
s
.40743 .24225 m
.37389 .23607 L
s
.35365 .26965 m
.36516 .28946 L
s
.38886 .2865 m
.36516 .28946 L
s
.34761 .23945 m
.34473 .24422 L
s
.37389 .23607 m
.34761 .23945 L
s
.38886 .2865 m
.37904 .26643 L
s
.37143 .24079 m
.37389 .23607 L
s
.41142 .27231 m
.40686 .25718 L
s
.41142 .27231 m
.37904 .26643 L
s
.40686 .25718 m
.40552 .24705 L
s
.40552 .24705 m
.37143 .24079 L
s
.34676 .25439 m
.35365 .26965 L
s
.37904 .26643 m
.35365 .26965 L
s
.40686 .25718 m
.37316 .25102 L
s
.34473 .24422 m
.34676 .25439 L
s
.37143 .24079 m
.34473 .24422 L
s
.37904 .26643 m
.37316 .25102 L
s
.37316 .25102 m
.34676 .25439 L
s
.37316 .25102 m
.37143 .24079 L
s
.25 Mabswid
.69069 0 m
.97431 .43047 L
s
.97431 .43047 m
1 .61842 L
s
1 .61842 m
.70263 .20566 L
s
.70263 .20566 m
.69069 0 L
s
.03114 .256 m
0 .45252 L
s
0 .45252 m
.70263 .20566 L
s
.70263 .20566 m
.69069 0 L
s
.69069 0 m
.03114 .256 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[330]:=",
  ImageSize->{400, 311.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001=b000`400?l00000o`00003oo`3ooolC
0?ooo`800000O03oool00?l0g9A`4@3LU702000000030=bDL0000000000007X0g9A`0@3oool00?l0
g9A`3P3LU703000000<0g9A`0P00001j0=bDL040oooo003o0=bDL0/0g9A`0`0000060=bDL0030000
003LU700000007T0g9A`0@3oool00?l0g9A`2@3LU702000000T0g9A`00@000000=bDL03LU7000000
N03LU7010?ooo`00o`3LU7060=bDL0<000002`3LU70010000000g9A`0=bDL000001h0=bDL040oooo
003o0=bDL0@0g9A`0P00000>0=bDL0050000003LU700g9A`0=bDL0000000M`3LU7010?ooo`00o`3L
U7010=bDL0<00000403LU7000`000000g9A`0=bDL0020=bDL0030000003LU700g9A`07@0g9A`0@3o
ool00?h0g9A`0P00000C0=bDL0030000003LU700g9A`0080g9A`00<000000=bDL03LU700M03LU701
0?ooo`00n`3LU703000001H0g9A`00<000000=bDL03LU7000P3LU7000`000000g9A`0=bDL01c0=bD
L040oooo003h0=bDL0<000006@3LU7000`000000g9A`0=bDL0030=bDL0030000003LU700g9A`0780
g9A`0@3oool00?H0g9A`0P00000L0=bDL0030000003LU700g9A`00<0g9A`00<000000=bDL03LU700
LP3LU7010?ooo`00l`3LU703000001h0g9A`00<000000=bDL03LU700103LU7000`000000g9A`0=bD
L01a0=bDL040oooo003a0=bDL08000008@3LU7000`000000g9A`0=bDL0050=bDL0030000003LU700
g9A`0700g9A`0@3oool00>h0g9A`0`00000S0=bDL0030000003LU700g9A`00D0g9A`00<000000=bD
L03LU700L03LU7010?ooo`00k03LU702000002H0g9A`00<000000=bDL03LU7001P3LU7000`000000
g9A`0=bDL01_0=bDL040oooo003Y0=bDL0<00000:03LU7000`000000g9A`0=bDL0070=bDL0030000
003LU700g9A`06h0g9A`0@3oool00>H0g9A`0`00000[0=bDL0030000003LU700g9A`00L0g9A`00<0
00000=bDL03LU700KP3LU7010?ooo`00i03LU702000002h0g9A`00<000000=bDL03LU700203LU700
0`000000g9A`0=bDL01]0=bDL040oooo003Q0=bDL0<00000<03LU7000`000000g9A`0=bDL0080=bD
L0030000003LU700g9A`06d0g9A`0@3oool00=l0g9A`0P00000c0=bDL0030000003LU700g9A`00T0
g9A`00<000000=bDL03LU700K03LU7010?ooo`00g03LU703000003D0g9A`00<000000=bDL03LU700
2P3LU7000`000000g9A`0=bDL01[0=bDL040oooo003I0=bDL0<00000>03LU7000`000000g9A`0=bD
L00:0=bDL0030000003LU700g9A`06/0g9A`0@3oool00=L0g9A`0P00000k0=bDL0030000003LU700
g9A`00/0g9A`00<000000=bDL03LU700JP3LU7010?ooo`00e03LU703000003d0g9A`00<000000=bD
L03LU700303LU7000`000000g9A`0=bDL01Y0=bDL040oooo003B0=bDL0800000@@3LU7000`000000
g9A`0=bDL00;0=bDL0030000003LU700g9A`06T0g9A`0@3oool00<l0g9A`0`0000130=bDL0030000
003LU700g9A`00`0g9A`00<000000=bDL03LU700J03LU7010?ooo`00c@3LU702000004H0g9A`00<0
00000=bDL03LU7003@3LU7000`000000g9A`0=bDL01W0=bDL040oooo003:0=bDL0<00000B03LU700
0`000000g9A`0=bDL00=0=bDL0030000003LU700g9A`06L0g9A`0@3oool00<L0g9A`0`00001;0=bD
L0030000003LU700g9A`00h0g9A`00<000000=bDL03LU700IP3LU7010?ooo`00a@3LU702000004h0
g9A`00<000000=bDL03LU7003`3LU7000`000000g9A`0=bDL01U0=bDL040oooo00320=bDL0<00000
D03LU7000`000000g9A`0=bDL00?0=bDL0030000003LU700g9A`06D0g9A`0@3oool00<00g9A`0P00
001C0=bDL0030000003LU700g9A`0100g9A`00<000000=bDL03LU700I03LU7010?ooo`00_@3LU703
000005D0g9A`00<000000=bDL03LU7004@3LU7000`000000g9A`0=bDL01S0=bDL040oooo002k0=bD
L0800000F03LU7000`000000g9A`0=bDL00A0=bDL0030000003LU700g9A`06<0g9A`0@3oool00;P0
g9A`0`00001J0=bDL0030000003LU700g9A`0180g9A`00<000000=bDL03LU700HP3LU7010?ooo`00
]@3LU703000005d0g9A`00<000000=bDL03LU7004`3LU7000`000000g9A`0=bDL01Q0=bDL040oooo
002c0=bDL0800000H03LU7000`000000g9A`0=bDL00C0=bDL0030000003LU700g9A`0640g9A`0@3o
ool00;00g9A`0`00001R0=bDL0030000003LU700g9A`01@0g9A`00<000000=bDL03LU700H03LU701
0?ooo`00[P3LU702000006D0g9A`00<000000=bDL03LU7005@3LU7000`000000g9A`0=bDL01O0=bD
L040oooo002[0=bDL0<00000I`3LU7000`000000g9A`0=bDL00E0=bDL0030000003LU700g9A`05l0
g9A`0@3oool00:P0g9A`0`00001Z0=bDL0030000003LU700g9A`01H0g9A`00<000000=bDL03LU700
GP3LU7010?ooo`00YP3LU702000006h0g9A`00<000000=bDL03LU7005P3LU7000`000000g9A`0=bD
L01M0=bDL040oooo002S0=bDL0<00000L03LU7000`000000g9A`0=bDL00F0=bDL0030000003LU700
g9A`05d0g9A`0@3oool00:40g9A`0P00001c0=bDL0030000003LU700g9A`01L0g9A`00<000000=bD
L03LU700G03LU7010?ooo`00WP3LU703000007D0g9A`00<000000=bDL03LU700603LU7000`000000
g9A`0=bDL01K0=bDL040oooo002L0=bDL0800000N03LU7000`000000g9A`0=bDL00H0=bDL0030000
003LU700g9A`05/0g9A`0@3oool009T0g9A`0`00001j0=bDL0030000003LU700g9A`01T0g9A`00<0
00000=bDL03LU700FP3LU7010?ooo`00UP3LU703000007d0g9A`00<000000=bDL03LU7006P3LU700
0`000000g9A`0=bDL01I0=bDL040oooo002D0=bDL0800000P03LU7000`000000g9A`0=bDL00J0=bD
L0030000003LU700g9A`05T0g9A`0@3oool00940g9A`0`0000220=bDL0030000003LU700g9A`01/0
g9A`00<000000=bDL03LU700F03LU7010?ooo`00S`3LU702000008D0g9A`00<000000=bDL03LU700
703LU7000`000000g9A`0=bDL01G0=bDL040oooo002<0=bDL0<00000Q`3LU7000`000000g9A`0=bD
L00L0=bDL0030000003LU700g9A`05L0g9A`0@3oool008X0g9A`0P00002:0=bDL0030000003LU700
g9A`01d0g9A`00<000000=bDL03LU700EP3LU7010?ooo`00Q`3LU703000008`0g9A`00<000000=bD
L03LU7007@3LU7000`000000g9A`0=bDL01F0=bDL040oooo00240=bDL0<00000S`3LU7000`000000
g9A`0=bDL00N0=bDL0030000003LU700g9A`05D0g9A`0@3oool00880g9A`0P00002B0=bDL0030000
003LU700g9A`01l0g9A`00<000000=bDL03LU700E03LU7010?ooo`00O`3LU703000009@0g9A`00<0
00000=bDL03LU7007`3LU7000`000000g9A`0=bDL01D0=bDL040oooo001m0=bDL0800000V03LU700
0`000000g9A`0=bDL00O0=bDL0030000003LU700g9A`05<0g9A`0@3oool007X0g9A`0`00002J0=bD
L0030000003LU700g9A`0200g9A`00<000000=bDL03LU700DP3LU7010?ooo`00N03LU702000009d0
g9A`00<000000=bDL03LU700803LU7000`000000g9A`0=bDL01B0=bDL040oooo001e0=bDL0<00000
W`3LU7000`000000g9A`0=bDL00Q0=bDL0030000003LU700g9A`0540g9A`0@3oool00780g9A`0`00
002R0=bDL0030000003LU700g9A`0280g9A`00<000000=bDL03LU700D03LU7010?ooo`00L03LU702
00000:D0g9A`00<000000=bDL03LU7008P3LU7000`000000g9A`0=bDL01@0=bDL040oooo001]0=bD
L0<00000Y`3LU7000`000000g9A`0=bDL00S0=bDL0030000003LU700g9A`04l0g9A`0@3oool006/0
g9A`0P00002Z0=bDL0030000003LU700g9A`02@0g9A`00<000000=bDL03LU700CP3LU7010?ooo`00
J03LU70300000:`0g9A`00<000000=bDL03LU700903LU7000`000000g9A`0=bDL01>0=bDL040oooo
001U0=bDL0<00000[`3LU7000`000000g9A`0=bDL00U0=bDL0030000003LU700g9A`04d0g9A`0@3o
ool006<0g9A`0P00002b0=bDL0030000003LU700g9A`02H0g9A`00<000000=bDL03LU700C03LU701
0?ooo`00H03LU70300000;@0g9A`00<000000=bDL03LU7009P3LU7000`000000g9A`0=bDL01<0=bD
L040oooo001N0=bDL0800000]`3LU7000`000000g9A`0=bDL00W0=bDL0030000003LU700g9A`04/0
g9A`0@3oool005/0g9A`0`00002i0=bDL0030000003LU700g9A`02P0g9A`00<000000=bDL03LU700
BP3LU7010?ooo`00F@3LU70200000;`0g9A`00<000000=bDL03LU700:03LU7000`000000g9A`0=bD
L01:0=bDL040oooo001F0=bDL0<00000_P3LU7000`000000g9A`0=bDL00Y0=bDL0030000003LU700
g9A`04T0g9A`0@3oool005<0g9A`0`0000320=bDL0030000003LU700g9A`02T0g9A`00<000000=bD
L03LU700B03LU7010?ooo`00D@3LU70200000<D0g9A`00<000000=bDL03LU700:@3LU7000`000000
g9A`0=bDL0180=bDL040oooo001>0=bDL0<00000a`3LU7000`000000g9A`0=bDL00Z0=bDL0030000
003LU700g9A`04L0g9A`0@3oool004`0g9A`0P00003:0=bDL0030000003LU700g9A`02/0g9A`00<0
00000=bDL03LU700AP3LU7010?ooo`00B@3LU70300000<`0g9A`00<000000=bDL03LU700:`3LU700
0`000000g9A`0=bDL0160=bDL040oooo00170=bDL0800000c`3LU7000`000000g9A`0=bDL00/0=bD
L0030000003LU700g9A`04D0g9A`0@3oool004@0g9A`0`00003A0=bDL0030000003LU700g9A`02d0
g9A`00<000000=bDL03LU700A03LU7010?ooo`00@@3LU70300000=@0g9A`00<000000=bDL03LU700
;@3LU7000`000000g9A`0=bDL0140=bDL040oooo000o0=bDL0800000eP3LU70200000300g9A`00<0
00000=bDL03LU700@`3LU7010?ooo`00?03LU70300000=D0g9A`0`0000020=bDL0030000003LU700
g9A`02h0g9A`00<000000=bDL03LU700@P3LU7010?ooo`00>P3LU70200000=D0g9A`0`0000050=bD
L0030000003LU700g9A`02h0g9A`00<000000=bDL03LU700@P3LU7010?ooo`00=`3LU70300000=D0
g9A`0P0000090=bDL0030000003LU700g9A`02h0g9A`00<000000=bDL03LU700@@3LU7010?ooo`00
=03LU70300000=D0g9A`0`00000<0=bDL0030000003LU700g9A`02d0g9A`00<000000=bDL03LU700
@@3LU7010?ooo`00<P3LU70200000=D0g9A`0`00000@0=bDL0030000003LU700g9A`02d0g9A`00<0
00000=bDL03LU700@03LU7010?ooo`00;`3LU70300000=@0g9A`0`00000C0=bDL0030000003LU700
g9A`02h0g9A`00<000000=bDL03LU700?`3LU7010?ooo`00;@3LU70200000=@0g9A`0`00000G0=bD
L0030000003LU700g9A`02d0g9A`00<000000=bDL03LU700?`3LU7010?ooo`00:P3LU70300000=<0
g9A`0`00000K0=bDL0030000003LU700g9A`02d0g9A`00<000000=bDL03LU700?P3LU7010?ooo`00
:03LU70200000=@0g9A`0P00000N0=bDL0030000003LU700g9A`02h0g9A`00<000000=bDL03LU700
?@3LU7010?ooo`009@3LU70300000=<0g9A`0`00000Q0=bDL0030000003LU700g9A`02d0g9A`00<0
00000=bDL03LU700?@3LU7010?ooo`008P3LU70300000=<0g9A`0`00000U0=bDL0030000003LU700
g9A`02d0g9A`00<000000=bDL03LU700?03LU7010?ooo`00803LU70200000740g9A`1@00001M0=bD
L0<00000:@3LU7000`000000g9A`0=bDL00]0=bDL0030000003LU700g9A`03/0g9A`0@3oool001d0
g9A`0`00001]0=bDL0l00000EP3LU703000002`0g9A`00<000000=bDL03LU700;@3LU7000`000000
g9A`0=bDL00k0=bDL040oooo000K0=bDL0800000K@3LU70=000000040=bDL000000000000=bDL0H0
0000CP3LU70300000300g9A`00<000000=bDL03LU700;@3LU7000`000000g9A`0=bDL00j0=bDL040
oooo000H0=bDL0<00000K@3LU70200000080g9A`1P0000020=bDL0030000003LU700g9A`00L00000
0P3LU706000004L0g9A`0P00000d0=bDL0030000003LU700g9A`02d0g9A`00<000000=bDL03LU700
>@3LU7010?ooo`005P3LU702000006l0g9A`00<000000=bDL00000000P0000050=bDL0H00000103L
U70=00000480g9A`0`00000f0=bDL0030000003LU700g9A`02d0g9A`00<000000=bDL03LU700>@3L
U7010?ooo`004`3LU70300000700g9A`1@0000060=bDL0040000003LU7000000000000P0g9A`00<0
00000=bDL00000000`0000000`3LU700000000000005000003`0g9A`0`00000j0=bDL0030000003L
U700g9A`02d0g9A`00<000000=bDL03LU700>03LU7010?ooo`00403LU70300000740g9A`0`000000
0`3LU7000000000000060=bDL0030000003LU700000000@000001`3LU702000000030=bDL0000000
g9A`008000000`3LU705000003L0g9A`0`00000n0=bDL0030000003LU700g9A`02d0g9A`00<00000
0=bDL03LU700=`3LU7010?ooo`003P3LU702000007<0g9A`1P000000103LU70000000=bDL03LU705
00000080g9A`00<000000=bDL0000000100000050=bDL08000000`3LU703000000030=bDL0000000
g9A`00D00000<@3LU70300000480g9A`00<000000=bDL03LU700;03LU7000`000000g9A`0=bDL00g
0=bDL040oooo000<0=bDL0800000M03LU70300000080g9A`00<000000=bDL0000000100000070=bD
L0040000003LU700000000000080g9A`2@0000040=bDL0<000000P3LU705000002d0g9A`0P000015
0=bDL0030000003LU700g9A`02d0g9A`00<000000=bDL03LU700=P3LU7010?ooo`00303LU7020000
07@0g9A`00H000000=bDL03LU700g9A`0000003LU705000000P0g9A`00@000000=bDL03LU700g9A`
1@0000020=bDL0X0000000<0g9A`0000000000000`3LU704000002P0g9A`0`0000180=bDL0030000
003LU700g9A`02d0g9A`00<000000=bDL03LU700=@3LU7010?ooo`00303LU7000`000000g9A`0000
001c0=bDL0040000003LU700g9A`0=bDL08000000`3LU704000000L0g9A`0`0000000`3LU7000000
0=bDL0060=bDL0@00000103LU706000000030=bDL0000000000000<000008`3LU703000004`0g9A`
00<000000=bDL03LU700;03LU7000`000000g9A`0=bDL00e0=bDL040oooo000<0=bDL0040000003L
U700g9A`00000740g9A`0P0000020=bDL0800000103LU70010000000g9A`0=bDL03LU702000000D0
g9A`00<000000=bDL03LU7000P3LU7000`000000g9A`0=bDL0050=bDL080000000@0g9A`00000000
00000000103LU70500000080g9A`1000000N0=bDL0<00000C`3LU7000`000000g9A`0=bDL00]0=bD
L0030000003LU700g9A`03@0g9A`0@3oool000/0g9A`00<000000=bDL03LU7000P3LU7000`000000
g9A`0=bDL01^0=bDL0030000003LU7000000008000001@3LU702000000@0g9A`0P0000000`3LU700
00000000000400000080g9A`0P0000050=bDL0030000003LU700000000<0g9A`0P0000030=bDL003
0000003LU700000000<000000P3LU704000001T0g9A`0`00001C0=bDL0030000003LU700g9A`02d0
g9A`00<000000=bDL03LU700<`3LU7010?ooo`002`3LU7000`000000g9A`0=bDL0030=bDL0030000
003LU700g9A`06`0g9A`0P000000103LU70000000=bDL00000040=bDL0030000003LU700000000<0
g9A`1@0000020=bDL0030000003LU700g9A`00D00000103LU70010000000g9A`0=bDL00000040=bD
L0@000000P3LU706000000040=bDL00000000000000001D0g9A`0`00001G0=bDL0030000003LU700
g9A`02`0g9A`00<000000=bDL03LU700<`3LU7010?ooo`002`3LU7000`000000g9A`0=bDL0040=bD
L0800000K03LU7000`000000g9A`0=bDL002000000D0g9A`00<000000=bDL03LU7000`0000030=bD
L08000000`3LU7000`000000g9A`0=bDL0030=bDL0@000000P3LU706000000@0g9A`0P0000000`3L
U70000000=bDL0020=bDL0<000000P3LU70300000140g9A`0P00001K0=bDL0030000003LU700g9A`
02`0g9A`00<000000=bDL03LU700<P3LU7010?ooo`002`3LU7000`000000g9A`0=bDL0060=bDL003
0000003LU700g9A`06T0g9A`1`0000020=bDL0030000003LU700000000800000103LU7000`000000
g9A`0=bDL002000000030=bDL0000000g9A`00H0g9A`1P0000020=bDL0030000003LU700000000@0
000000<0g9A`0000000000001@3LU70300000080g9A`0`00000<0=bDL0<00000G@3LU7000`000000
g9A`0=bDL00]0=bDL0030000003LU700g9A`0340g9A`0@3oool000/0g9A`00<000000=bDL03LU700
1`3LU7000`000000g9A`0=bDL01W0=bDL080000000@0g9A`0000003LU70000000P3LU704000000<0
g9A`00D000000=bDL03LU700g9A`000000040=bDL0030000003LU700000000D0g9A`00<000000=bD
L00000000P3LU7001P000000g9A`000000000000g9A`000000D0g9A`1@0000050=bDL0<000000P3L
U703000000L0g9A`0`00001Q0=bDL0030000003LU700g9A`02`0g9A`00<000000=bDL03LU700<@3L
U7010?ooo`002`3LU7000`000000g9A`0=bDL0080=bDL0030000003LU700g9A`06H0g9A`0`000002
0=bDL08000000`3LU70300000080g9A`00@000000=bDL03LU70000001P3LU702000000<0g9A`0P00
00030=bDL0040000003LU700g9A`00000080g9A`0`0000070=bDL0@000000`3LU7000`000000g9A`
0000000200000080g9A`0`0000020=bDL0<00000I@3LU7000`000000g9A`0=bDL00/0=bDL0030000
003LU700g9A`0300g9A`0@3oool000X0g9A`00<000000=bDL03LU7002P3LU7000`000000g9A`0=bD
L01U0=bDL0<000000P3LU702000000040=bDL0000000000000000080g9A`0P000000103LU7000000
0=bDL00000070=bDL080000000<0g9A`0000003LU7001@3LU7000`000000g9A`000000050=bDL080
00001@3LU7000`000000g9A`0=bDL00300000080g9A`00<000000=bDL03LU7000`0000020=bDL0<0
0000J03LU7000`000000g9A`0=bDL00]0=bDL0030000003LU700g9A`02l0g9A`0@3oool000X0g9A`
00<000000=bDL03LU7002`3LU7000`000000g9A`0=bDL01T0=bDL0<000000P3LU7000`000000g9A`
000000020=bDL0030000003LU700g9A`0080g9A`0`0000090=bDL0800000203LU702000000H0g9A`
100000020=bDL0800000103LU703000000@0g9A`1`00001X0=bDL0030000003LU700g9A`02`0g9A`
00<000000=bDL03LU700;`3LU7010?ooo`002P3LU7000`000000g9A`0=bDL00<0=bDL0030000003L
U700g9A`06<0g9A`0P0000030=bDL0060000003LU70000000000003LU70000001P3LU702000000L0
g9A`1@0000080=bDL0030000003LU700g9A`00@0g9A`00<000000=bDL03LU7000P0000000`3LU700
00000=bDL0050=bDL080000000<0g9A`0000000000000P3LU702000000040=bDL000000000000000
06P0g9A`00<000000=bDL03LU700;03LU7000`000000g9A`0=bDL00^0=bDL040oooo000:0=bDL003
0000003LU700g9A`00d0g9A`00<000000=bDL03LU700HP3LU70300000080g9A`0P000000103LU700
00000=bDL00000060=bDL0030000003LU700000000H0000000@0g9A`000000000000g9A`10000005
0=bDL08000001P3LU70010000000g9A`0=bDL03LU703000000D0g9A`100000040=bDL0L00000I`3L
U7000`000000g9A`0=bDL00/0=bDL0030000003LU700g9A`02d0g9A`0@3oool000X0g9A`00<00000
0=bDL03LU7003P3LU7000`000000g9A`0=bDL01Q0=bDL0<000000P3LU70200000080g9A`0P000006
0=bDL0H00000103LU7000`000000g9A`000000020=bDL0030000003LU700000000<000000P3LU702
000000@0g9A`100000020=bDL0<0000000@0g9A`00000000000000000P3LU70010000000g9A`0000
000000020=bDL0050000003LU700g9A`0000003LU7000`00001V0=bDL0030000003LU700g9A`02`0
g9A`00<000000=bDL03LU700;@3LU7010?ooo`002P3LU7000`000000g9A`0=bDL00?0=bDL0030000
003LU700g9A`0600g9A`0`0000020=bDL0030000003LU700g9A`0080g9A`00<000000=bDL03LU700
0`3LU702000000030=bDL0000000g9A`0080g9A`0P0000001@3LU70000000=bDL03LU700000000<0
g9A`0P0000030=bDL0P000000`3LU708000000D0g9A`00<000000=bDL03LU7000`0000020=bDL0<0
000000<0g9A`000000000000IP3LU7000`000000g9A`0=bDL00/0=bDL0030000003LU700g9A`02`0
g9A`0@3oool000X0g9A`00<000000=bDL03LU700403LU7000`000000g9A`0=bDL01P0=bDL0800000
0P3LU7000`000000g9A`0=bDL0020=bDL08000000`3LU7000`000000g9A`000000020=bDL0030000
003LU700g9A`0080g9A`0P0000030=bDL0030000003LU700g9A`0080g9A`00<000000=bDL03LU700
0P3LU705000000D0g9A`2@0000030=bDL0030000003LU700g9A`0080g9A`0P0000020=bDL0<00000
00@0g9A`0000000000000000I@3LU7000`000000g9A`0=bDL00/0=bDL0030000003LU700g9A`02/0
g9A`0@3oool000T0g9A`00<000000=bDL03LU7004P3LU7000`000000g9A`0=bDL01O0=bDL0<00000
00<0g9A`0000003LU7000`3LU702000000030=bDL0000000000000<0g9A`00<000000=bDL0000000
1@3LU703000000030=bDL0000000g9A`00@0g9A`0P000000103LU70000000000000000020=bDL0H0
000000@0g9A`0000003LU70000000P3LU70500000080g9A`00@000000=bDL03LU700g9A`1@000002
0=bDL0030000003LU700g9A`00800000I03LU7000`000000g9A`0=bDL00/0=bDL0030000003LU700
g9A`02/0g9A`0@3oool000T0g9A`00<000000=bDL03LU7004`3LU7000`000000g9A`0=bDL01N0=bD
L0`000001@3LU70010000000g9A`0=bDL00000040=bDL0030000003LU700g9A`00<000001P3LU700
10000000g9A`0=bDL00000030=bDL0D000000P3LU702000000<0g9A`00<000000=bDL03LU7001000
00030=bDL0030000003LU700g9A`00<000000P3LU702000000040=bDL00000000000000006<0g9A`
00<000000=bDL03LU700;03LU7000`000000g9A`0=bDL00Z0=bDL040oooo00090=bDL0030000003L
U700g9A`01@0g9A`0P00001N0=bDL080000000<0g9A`000000000000103LU70010000000g9A`0000
000000040=bDL0050000003LU700g9A`0=bDL00000000`3LU7000`000000g9A`0=bDL0020=bDL003
0000003LU700g9A`00<0g9A`00<000000=bDL00000000P3LU703000000030=bDL0000000g9A`0080
g9A`0`0000000`3LU70000000=bDL0020=bDL0030000003LU700g9A`0080g9A`0P0000030=bDL003
0000003LU700g9A`00<000000`3LU7000`000000g9A`0=bDL002000006<0g9A`00<000000=bDL03L
U700:`3LU7000`000000g9A`0=bDL00Z0=bDL040oooo00090=bDL0030000003LU700g9A`01H0g9A`
00<000000=bDL03LU700F`3LU7000`000000g9A`00000003000000@0g9A`00<000000=bDL03LU700
0`0000000`3LU70000000=bDL0030=bDL0040000003LU700g9A`000000D0g9A`0P0000030=bDL003
0000003LU700000000<00000103LU702000000@0g9A`0P0000030=bDL0030000003LU700g9A`00<0
g9A`0`0000000`3LU70000000=bDL0020=bDL0@000000P3LU702000000040=bDL000000000000000
0680g9A`00<000000=bDL03LU700:`3LU7000`000000g9A`0=bDL00Y0=bDL040oooo00090=bDL003
0000003LU700g9A`01L0g9A`00<000000=bDL03LU700FP3LU7000`000000g9A`00000003000000@0
g9A`00@000000=bDL03LU70000000P3LU703000000<0g9A`00@000000=bDL03LU70000001@3LU700
0`000000g9A`00000004000000<0g9A`0P0000050=bDL0030000003LU700g9A`0080g9A`0`000002
0=bDL0030000003LU700g9A`00<0g9A`00@000000=bDL00000000000103LU702000000030=bDL000
0000g9A`0080g9A`00<000000=bDL00000000P00001Q0=bDL0030000003LU700g9A`02`0g9A`00<0
00000=bDL03LU700:03LU7010?ooo`002@3LU7000`000000g9A`0=bDL00H0=bDL0030000003LU700
g9A`05T0g9A`00H000000=bDL000000000000=bDL00000030=bDL08000000`3LU7001@000000g9A`
0=bDL0000000g9A`008000000P3LU7000`000000g9A`000000030=bDL0L000001P3LU7000`000000
g9A`0=bDL0040=bDL0040000003LU700g9A`0=bDL080000000D0g9A`000000000000g9A`00000004
0=bDL0030000003LU700g9A`00<000000P3LU7000`000000g9A`00000002000000<0g9A`00<00000
0=bDL03LU7000P00001Q0=bDL0030000003LU700g9A`02/0g9A`00<000000=bDL03LU700:03LU701
0?ooo`002@3LU7000`000000g9A`0=bDL00I0=bDL0030000003LU700g9A`05P0g9A`100000020=bD
L0060000003LU700g9A`0000003LU70000000`3LU70010000000g9A`0=bDL00000020=bDL0/00000
00<0g9A`0000003LU7001P0000020=bDL0030000003LU700g9A`00@0g9A`00@000000=bDL03LU700
g9A`1`0000040=bDL0040000003LU70000000=bDL0<0000000@0g9A`0000003LU700g9A`0P000003
0=bDL0H00000A03LU70L03eIZ`030000003LU700g9A`02/0g9A`00<000000=bDL03LU7009`3LU701
0?ooo`00203LU7000`000000g9A`0=bDL00K0=bDL0030000003LU700g9A`05L0g9A`0P000000103L
U70000000=bDL03LU702000000040=bDL0000000g9A`000000@0g9A`00<000000=bDL00000000`3L
U704000000030=bDL0000000000000@0g9A`00<000000=bDL00000000P3LU7000`000000g9A`0=bD
L005000000D0g9A`100000000`3LU70000000=bDL004000000<0g9A`00<000000=bDL00000000`3L
U703000000<0g9A`0P0000040=bDL0050000003LU70000000=bDL0000000>P3LU70?03eIZ`<0g9A`
4`0mFJ/00`000000?EV[03eIZ`0203eIZbX0g9A`00<000000=bDL03LU7009P3LU7010?ooo`00203L
U7000`000000g9A`0=bDL00L0=bDL0030000003LU700g9A`05H0g9A`0P000000103LU70000000=bD
L03LU70300000080g9A`00<000000=bDL03LU7000P3LU7000`000000g9A`000000020=bDL0030000
003LU700g9A`00@000001P3LU702000000<0g9A`00H000000=bDL03LU700g9A`0000003LU7020000
0080g9A`0P000000103LU70000000=bDL00000020=bDL0030000003LU700g9A`0080g9A`0P000002
0=bDL0030000003LU700000000<0g9A`0`0000040=bDL08000000P3LU702000000040=bDL0000000
000000000380g9A`800mFJ/70=bDL0H0?EV[00<000000=bDL03LU7001@0mFJ/V0=bDL0030000003L
U700g9A`02H0g9A`0@3oool000P0g9A`00<000000=bDL03LU7007@3LU7000`000000g9A`0=bDL01F
0=bDL0<000000`3LU702000000<0g9A`00<000000=bDL03LU7000P3LU70700000080g9A`00@00000
0=bDL000000000001@3LU7000`000000g9A`0=bDL0020=bDL08000000P3LU7000`000000g9A`0=bD
L002000000@0g9A`0P0000020=bDL0030000003LU700g9A`0080g9A`00<000000=bDL00000000P00
00000`3LU70000000=bDL0030=bDL0@000000`3LU704000000030=bDL0000000000000<00000:`3L
U70;03eIZ`80g9A`200mFJ/70=bDL1P0?EV[00<0000003eIZ`0mFJ/0200mFJ/S0=bDL0030000003L
U700g9A`02D0g9A`0@3oool000P0g9A`00<000000=bDL03LU7007P3LU7000`000000g9A`0=bDL01E
0=bDL0@000000P3LU70300000080g9A`00<000000=bDL03LU7000`3LU703000000D0g9A`0P000002
0=bDL08000000`3LU7000`000000g9A`0=bDL0040=bDL0030000003LU70000000080g9A`1@000002
0=bDL08000000P3LU7000`000000g9A`0=bDL0020=bDL0030000003LU700g9A`00<00000103LU700
1@000000g9A`0000003LU700000000<0g9A`0`0000020=bDL080000000<0g9A`0000000000009@3L
U70903eIZ`<0g9A`2@0mFJ/60=bDL0X0?EV[1@3LU7000`0mFJ/0g9A`0=bDL00803eIZ`D0g9A`00@0
000003eIZ`0mFJ/0g9A`2@0mFJ/Q0=bDL0030000003LU700g9A`02@0g9A`0@3oool000P0g9A`00<0
00000=bDL03LU7007`3LU7000`000000g9A`0=bDL01D0=bDL0@000000P3LU702000000040=bDL000
0000g9A`00000080g9A`1@0000060=bDL0800000103LU702000000030=bDL0000000000000H0g9A`
00@000000=bDL000000000000P3LU702000000050=bDL000000000000=bDL00000000`3LU7001@00
0000g9A`0=bDL03LU700000000<0g9A`0`0000040=bDL0050000003LU70000000=bDL00000000`3L
U702000000@0g9A`00<000000=bDL00000000P00000M0=bDL0X0?EV[0P3LU70G03eIZ``0g9A`1@0m
FJ/20=bDL080?EV[203LU70010000000?EV[0=bDL00mFJ/40=bDL0@0?EV[00<0g9A`03eIZ`0mFJ/0
7`3LU7000`000000g9A`0=bDL00T0=bDL040oooo00080=bDL0030000003LU700g9A`0200g9A`00<0
00000=bDL03LU700E03LU703000000<0g9A`00D000000=bDL03LU70000000=bDL00200000080g9A`
00@000000=bDL000000000001P3LU702000000D0g9A`0`0000070=bDL0<00000103LU7000`000000
g9A`0=bDL003000000<0g9A`00D000000=bDL03LU700g9A`000000030=bDL0@0000000<0g9A`0000
o`0000000P000?l4000000030000o`0000000000008000000`000?l01@000000g9A`0000003LU700
000001L0g9A`200mFJ/00`3LU700?EV[03eIZ`0803eIZ`80g9A`200mFJ/30=bDL0@0?EV[103LU704
03eIZ`D0g9A`100mFJ/80=bDL00303eIZ`3LU700g9A`00H0g9A`00<000000=bDL03LU7000P0mFJ/6
0=bDL0D0?EV[7P3LU7000`000000g9A`0=bDL00S0=bDL040oooo00070=bDL0030000003LU700g9A`
0280g9A`00<000000=bDL03LU700D`3LU703000000<0g9A`2P0000020=bDL0030000003LU700g9A`
00@0g9A`0P0000060=bDL0040000003LU7000000000000L0g9A`00<000000=bDL03LU7000`3LU700
0`000000g9A`0=bDL003000000<0g9A`00D000000=bDL03LU700g9A`000000020=bDL00300000000
0?l0003o00@00000100>4QX00`000000003o00000002000000030000o`000000000000804QPQ00H0
003o000000000?l000000000o`00000B0=bDL0l0?EV[1P3LU70603eIZ`H0g9A`100mFJ/;0=bDL1/0
?EV[00<0000003eIZ`0mFJ/03P0mFJ/M0=bDL0030000003LU700g9A`0280g9A`0@3oool000L0g9A`
00<000000=bDL03LU7008`3LU702000005<0g9A`200000020=bDL0040000003LU70000000=bDL0H0
00001@3LU7000`000000g9A`000000060=bDL0030000003LU7000000008000001@3LU703000000@0
g9A`00D000000=bDL03LU70000000=bDL00200000080g9A`00D000000=bDL03LU70000000000o`03
0000000500P;3`000?l000000000o`00000010000?l00`0J9CD0000001XU=@02000000807bm10P00
00030000o`D0000000<0003o0=bDL03LU7002@3LU70>03eIZ`030=bDL00mFJ/0?EV[00<0g9A`200m
FJ/70=bDL0<0?EV[0P3LU7000`0mFJ/0g9A`0=bDL0030=bDL0`0?EV[0P3LU7000`0mFJ/0g9A`0=bD
L0070=bDL0T0?EV[00<0g9A`0000000mFJ/00`0mFJ/60=bDL080?EV[0P3LU70303eIZa`0g9A`00<0
00000=bDL03LU7008P3LU7010?ooo`001`3LU7000`000000g9A`0=bDL00U0=bDL0030000003LU700
g9A`0540g9A`100000000`3LU7000000000000030=bDL080000000<0g9A`0000003LU7000P3LU700
0`000000g9A`0000000300000080g9A`00<000000=bDL00000001@3LU7000`000000g9A`00000002
0=bDL08000000`3LU702000000030=bDL0000000g9A`00<0g9A`00<000000=bDL00000000P3LU704
00000080003o0P00000010000?l00000000000000?l2018I9@@00000100J9CD4000000807bm10`00
00000`000?l08cA500000005000000030000o`3LU700g9A`0080g9A`3`0mFJ/30=bDL1P0?EV[00<0
g9A`03eIZ`0mFJ/0200mFJ/:0=bDL080?EV[103LU70603eIZ`<0g9A`00D0?EV[0=bDL03LU700g9A`
03eIZ`030=bDL0030000003LU700g9A`00D0?EV[0P3LU70203eIZ`<0g9A`0`0mFJ/L0=bDL0030000
003LU700g9A`0240g9A`0@3oool000L0g9A`00<000000=bDL03LU7009P3LU7000`000000g9A`0=bD
L01>0=bDL0H0000000@0g9A`0000003LU70000000`3LU702000000D0g9A`00<000000=bDL0000000
0P3LU705000000D0g9A`2@0000000`3LU7000000000000020=bDL0030000003LU700g9A`0080g9A`
0`0000020=bDL004000000000?l0000000000080003o00<00000018I9@0B6BD00P0000001P0B6BD0
003o0000o`000?l000000000o`8000000`000?l2000000030000o`000000003o0080003o0P000002
0000o`0602<dA@0000000000000000000?l000003`0mFJ/20=bDL0X0?EV[0P3LU70203eIZ`L0g9A`
3P0mFJ/?0=bDL0H0?EV[2@3LU7001@0mFJ/0g9A`0=bDL03LU700?EV[00@0g9A`00@000000=bDL03L
U700?EV[0`3LU70403eIZ`@0g9A`0P0mFJ/M0=bDL0030000003LU700g9A`0200g9A`0@3oool000L0
g9A`00<000000=bDL03LU7009`3LU7000`000000g9A`0=bDL01:0=bDL0<000000`3LU70500000003
0=bDL0000000g9A`00<0g9A`00<000000=bDL03LU7000`3LU70010000000g9A`0=bDL00000030=bD
L0030000003LU700000000H000000`3LU70010000000g9A`0=bDL03LU706000000030=bDL0000000
000000@0g9A`00<000000=bDL0000?l0200000001P000?l000000000o`0000008CE>0000o`80:D=O
00@0000002U3G`0Y@el000000P0Y@el01@000?l000000000000aCfh0000000<0<Dm^0P0000001P0g
FGT0003o03eIZ`000000?EV[000001D0?EV[1@3LU700100mFJ/0g9A`03eIZ`0mFJ/60=bDL0H0?EV[
103LU70403eIZ`030=bDL00mFJ/0g9A`00X0g9A`3P0mFJ/70=bDL00303eIZ`3LU700?EV[00H0g9A`
00<000000=bDL00mFJ/0103LU700100mFJ/0g9A`03eIZ`0mFJ/30=bDL00303eIZ`3LU700?EV[01`0
g9A`00<000000=bDL03LU700803LU7010?ooo`001`3LU7000`000000g9A`0=bDL00X0=bDL0030000
003LU700g9A`04L0g9A`0P0000060=bDL080000000<0g9A`0000000000000P3LU70010000000g9A`
0=bDL03LU702000000D0g9A`00<000000=bDL0000000103LU702000000030=bDL000000000000080
000000D0g9A`0000003LU700g9A`000000050=bDL0<0000000D0g9A`000000000000g9A`00000003
0=bDL0<0000000@02PdB0000000000002PdB0P000?l200000003024eCP0000008CE>00808CE>00<0
003o02U3G`0Y@el00`00000302U3G`030000o`000000<Dm^008000000`0aCfh00`0mFJ/0000003eI
Z`0303eIZ`030000000mFJ/00000008000003@0mFJ/00`3LU700?EV[03eIZ`070=bDL080?EV[0P3L
U70703eIZ`H0g9A`0`0mFJ/20=bDL00403eIZ`3LU700g9A`0=bDL0`0?EV[0`3LU700100mFJ/0g9A`
0=bDL00mFJ/60=bDL0/0?EV[0P3LU70303eIZ`030000000mFJ/0?EV[00@0?EV[0`3LU70303eIZ`80
g9A`0P0mFJ/M0=bDL0030000003LU700g9A`01l0g9A`0@3oool000L0g9A`00<000000=bDL03LU700
:@3LU7000`000000g9A`0=bDL0130=bDL0<00000203LU706000000030=bDL0000000g9A`0080g9A`
0`0000040=bDL0050000003LU700g9A`0000003LU7000`0000030=bDL0030000003LU700g9A`00<0
00000P3LU7000`000000g9A`0=bDL0020=bDL0030000003LU700g9A`0080000000<0g9A`00000000
00000P0000020000o`8000000`000?l00`0000005b<h0000o`02024eCP8000000`0Q=Dh00`000?l0
:D=O02U3G`0202U3G`030000o`000000003o0080003o00D000000000o`000?l0?EV[0000000403eI
Z`050000000mFJ/0?EV[03eIZ`0gFGT00P00000203eIZ`030000000mFJ/08cA300D0?EV[103LU702
03eIZ`L0g9A`1P0mFJ/0103LU700?EV[03eIZ`0mFJ/60=bDL0<0?EV[0`3LU70;03eIZ`T0g9A`00<0
?EV[0=bDL03LU7000P3LU7000`0mFJ/0g9A`0=bDL0040=bDL100?EV[00@000000=bDL03LU700g9A`
300mFJ/N0=bDL0030000003LU700g9A`01h0g9A`0@3oool000H0g9A`00<000000=bDL03LU700:`3L
U7000`000000g9A`0=bDL00o0=bDL0<00000303LU702000000060=bDL000000000000000003LU700
00000P3LU70010000000g9A`0000000000040=bDL0040000003LU700g9A`000000<0g9A`00@00000
0=bDL03LU70000000`3LU7000`000000g9A`00000002000000@0g9A`00D000000=bDL03LU7000000
0=bDL002000000030=bDL0000000000000<0000000<0003o01LS>00G8cP00P0G8cP00`000?l08CE>
024eCP02024eCP<000001P000?l203EHO@040000000eF7d0?EV[000000@0?EV[00<000000000o`00
0?l00P000?l01P000000?EV[03eIZ`0mFJ/0=eUi03eIZ`800000100mFJ/30000o`<0g9A`0P0mFJ/3
0=bDL0h0?EV[1@3LU70903eIZ`030=bDL00mFJ/0g9A`00@0?EV[00<0g9A`03eIZ`3LU7002@3LU700
100mFJ/0g9A`0=bDL03LU70903eIZ`D0g9A`00<0?EV[0=bDL03LU700203LU700100mFJ/0000003eI
Z`0mFJ/40=bDL00403eIZ`3LU700g9A`0=bDL0@0?EV[7P3LU7000`000000g9A`0=bDL00N0=bDL040
oooo00060=bDL0030000003LU700g9A`02`0g9A`00<000000=bDL03LU700>`3LU703000000l0g9A`
0P0000003@3LU70000000000003LU70000000=bDL0000000g9A`0000003LU70000000=bDL0000000
0`3LU7000`000000g9A`0=bDL00200000080g9A`00D000000=bDL03LU700g9A`000000030=bDL003
0000003LU700g9A`00<000000`3LU70010000000g9A`0=bDL00000020=bDL0030000000000400001
0080000000<05b<h0000000G8cP00P0G8cP60000o`050000000/BV`0;4Y/000000000?l01@0eF7d2
03eIZ`<0000000<0?EV[03iVS`0nIXl00P0nIXl01P000000?EV[03eIZ`0mFJ/0AW>O00000080003o
100mFJ/010000000>Eak0000000iG7/20000o``0?EV[103LU70303eIZ`@0g9A`200mFJ/50=bDL0@0
?EV[1@3LU7000`0mFJ/0g9A`0=bDL0070=bDL0D0?EV[00<0g9A`03eIZ`3LU7002@3LU70303eIZ`T0
g9A`00D0?EV[0=bDL0000000?EV[0=bDL00203eIZ`80g9A`00<0?EV[0=bDL03LU7000P3LU70403eI
Zah0g9A`00<000000=bDL03LU7007@3LU7010?ooo`001P3LU7000`000000g9A`0=bDL00]0=bDL003
0000003LU700g9A`03L0g9A`0`00000B0=bDL0<0000000P0g9A`0000003LU70000000=bDL0000000
g9A`00000080g9A`00<000000=bDL00000000`3LU70200000080g9A`00@000000=bDL03LU7000000
0`3LU70010000000g9A`0=bDL00000030=bDL0060000003LU70000000000003LU70000000P3LU700
20000000g9A`0000o`00004000000000o`0=4al0003o0P0000001@0G8cP0003o0000o`0S>eT0003o
00@0;4Y/00@0000002a:K00/BV`0003o0P00000203EHO@@0?EV[00@0=EQm0000o`000000?VJ?100m
FJ/0100nIXl000000000o`16Lil203eIZ`80000000<0AW>O03eIZ`000?l00`0000000`0iG7/00000
03ULN`0603eIZ`80g9A`0`0mFJ/40=bDL0<0?EV[0P3LU70603eIZ`80g9A`0P0mFJ/30=bDL0D0?EV[
2@3LU7000`0mFJ/0g9A`0=bDL00703eIZ`D0g9A`00<0?EV[0=bDL03LU7001`3LU7000`0mFJ/0g9A`
03eIZ`0:0=bDL0<0?EV[00@000000=bDL03LU700g9A`0P0mFJ/30=bDL0H0?EV[7`3LU7000`000000
g9A`0=bDL00L0=bDL040oooo00060=bDL0030000003LU700g9A`02h0g9A`00<000000=bDL03LU700
<`3LU703000001H0g9A`0P0000020=bDL0040000003LU70000000=bDL08000000P3LU70010000000
g9A`0=bDL00000020=bDL08000000`3LU7000`000000g9A`000000040=bDL0040000003LU700g9A`
000000<0g9A`00<000000=bDL03LU7000P0000030=bDL003000000000?l0003o00803A<O00<0003o
01LS>0000?l00`00000202<kF@030000o`0/BV`0;4Y/0080;4Y/00P0000002a:K00/BV`0003o03EH
O@0mFJ/0000003eIZ`@0=EQm0P0mFJ/2000000@0?VJ?0P0mFJ/2000000@0AW>O00@0000003eIZ`00
0000003o1@0mFJ/00`0iG7/0003o03AEKP030000o`80?EV[103LU70:03eIZ`L0g9A`100mFJ/40=bD
L00303eIZ`3LU700g9A`00D0g9A`1@0mFJ/00`3LU700?EV[03eIZ`0:03eIZ`P0g9A`00<0?EV[0=bD
L00mFJ/02P3LU70203eIZ`<0g9A`00<000000=bDL03LU7000`0mFJ/0203LU700?EV[0=bDL00mFJ/0
g9A`03eIZ`3LU700?EV[7`3LU7000`000000g9A`0=bDL00L0=bDL040oooo00060=bDL0030000003L
U700g9A`02l0g9A`00<000000=bDL03LU700<03LU702000001T0g9A`0`000000103LU70000000=bD
L03LU703000000<0g9A`00@000000=bDL03LU70000000P3LU7000`000000g9A`0=bDL0020=bDL003
0000003LU700000000@0g9A`00<000000=bDL0000000103LU7000`000000g9A`0=bDL005000000@0
3A<O0P000?l202<kF@040000000S>eT00000000000H0;4Y/00@0000003eIZ`0mFJ/0?EV[0P000?l2
000000<0?EV[0P000?l010000000003o00000000000203eIZ`<0?VJ?00<0003o00000016Lil00P16
Lil403eIZ`80CGj[0P0000000`000?l000000000o`0203AEKP030000o`0mFJ/0003o00<0g9A`100m
FJ/20=bDL0<0?EV[1P3LU70403eIZ`030=bDL00mFJ/0g9A`00@0g9A`00<0?EV[0=bDL03LU700300m
FJ/30=bDL00303eIZ`3LU700g9A`00<0g9A`00<0?EV[0=bDL03LU7002`0mFJ/:0=bDL00303eIZ`3L
U700g9A`00<0g9A`00<0000003eIZ`3LU7000P3LU7000`0mFJ/0g9A`03eIZ`020=bDL080?EV[8@3L
U7000`000000g9A`0=bDL00K0=bDL040oooo00060=bDL0030000003LU700g9A`0300g9A`00<00000
0=bDL03LU700;03LU703000001`0g9A`0P0000000`3LU7000000000000020=bDL08000000`3LU700
10000000g9A`0=bDL03LU703000000D0g9A`0P0000050=bDL0030000003LU700000000<0g9A`00@0
00000=bDL03LU700g9A`0P00000010000?l03A<O0000000=4al30000o`<08c]I00@0000002<kF@0S
>eT0003o0P0000040000o`040000000eFX<0?EV[03iXU@<0?EV[00<0?VRE0000000000000P0nJ9D0
1P0mFJ/0000003eIZ`0mFJ/0AgRX000000H0003o00P0000003eIZ`0mFJ/0AW>O03eIZ`000000AW>O
0000o`80CGj[1000000010000?l0=5E^03AEKP0dEFh403eIZ`80g9A`100mFJ/60=bDL0<0?EV[1@3L
U7000`0mFJ/0g9A`03eIZ`0803eIZ`D0g9A`00<0?EV[0=bDL03LU700103LU7000`0mFJ/0g9A`0=bD
L0040=bDL00303eIZ`3LU700g9A`00<0g9A`5@0mFJ/30=bDL0040000000mFJ/0g9A`0=bDL080?EV[
00@0g9A`03eIZ`3LU700g9A`0P0mFJ/R0=bDL0030000003LU700g9A`01X0g9A`0@3oool000D0g9A`
00<000000=bDL03LU700<P3LU7000`000000g9A`0=bDL00X0=bDL0<000007`3LU703000000030=bD
L0000000g9A`0080g9A`00@000000=bDL03LU700g9A`400000030=bDL0030000003LU700000000@0
g9A`00T000000=bDL03LU700003o000000000?l03A<O000000000?l00P0I9d000`000?l08c]I02<k
F@0202<kF@03000000000?l0003o0080003o0P00000203EJP`040000000mFJ/0?EV[03eIZ`@0?VRE
0P0mFJ/010000000?EV[0000o`00000404MhZ00300000017N:P0?EV[00<0?EV[00D0DXRk00000000
0?l0003o03eIZ`02000000040000o`1=OZ/0CGj[04enZ`<00000100mFJ/00`000?l0?EV[03eIZ`03
03eIZ`<0g9A`00<0?EV[0=bDL03LU700100mFJ/30=bDL0P0?EV[00<0g9A`03eIZ`3LU7002@3LU700
0`0mFJ/0g9A`0=bDL0040=bDL0h0?EV[00<0g9A`03eIZ`3LU7000P3LU7000`0mFJ/0g9A`0=bDL005
0=bDL0@0?EV[103LU70403eIZ`040000000mFJ/0?EV[0=bDL080?EV[0`3LU7000`0mFJ/0g9A`0=bD
L00Q0=bDL0030000003LU700g9A`01X0g9A`0@3oool000D0g9A`00<000000=bDL03LU700<`3LU702
000002D0g9A`0`00000S0=bDL0D000000P3LU70400000080g9A`00<000000=bDL03LU7000P000000
0`3LU70000000=bDL0030=bDL0030000003LU700000000D0000000<0g9A`0000003LU7000P3LU700
10000000g9A`0000o`0000030000o`0401TW@00000006BM00000o`@08c]I00@0003o0000000/C740
003o0`0eFX<01`0mFJ/00000000000000000=EZ303eIZ`0nJ9D0100mFJ/303iXU@<000000`17N:P2
03eIZ`0400000017N:P0AgRX0000o`<0DXRk00P0000003eIZ`1BR;/000000000o`000000003o04en
Z`@0?EV[00H0003o0000001>OjX0003o03AEKP000?l203eIZ`040=bDL00mFJ/0g9A`0=bDL0h0?EV[
0P3LU700100mFJ/0g9A`0=bDL00mFJ/80=bDL0/0?EV[1@3LU7000`0mFJ/0g9A`0=bDL0040=bDL080
?EV[0`3LU7000`0mFJ/0g9A`0=bDL0060=bDL0D0?EV[1@3LU7001P0mFJ/0g9A`03eIZ`000000?EV[
0=bDL080?EV[0P3LU7000`0mFJ/0g9A`0=bDL00S0=bDL0030000003LU700g9A`01T0g9A`0@3oool0
00D0g9A`00<000000=bDL03LU700=@3LU7000`000000g9A`0=bDL00O0=bDL0<000009P3LU7050000
00030=bDL0000000000000<000000P3LU7001@000000g9A`0=bDL0000000g9A`008000001@3LU702
000000@0g9A`2`00000301TW@0040000000I9d00003o02<kF@<0003o00@0;4aa0000000/C740003o
0`0mFJ/303EJP`040000000mFJ/0?EV[03eIZ`P0?VRE00<0003o0000000mFJ/00P0mFJ/304MhZ080
000000<0003o05:8^`1BR;/00P1BR;/00`0mFJ/000000000000403eIZ`080000o`1=OZ/0000004en
Z`000000003o0000001>OjX20000o`0302a7E`000?l0?EV[00L0?EV[00<0g9A`03eIZ`0mFJ/00`0m
FJ/50=bDL00503eIZ`3LU700g9A`03eIZ`3LU700200mFJ/20=bDL00303eIZ`3LU700g9A`0080g9A`
00<0?EV[0=bDL03LU7001@3LU7000`0mFJ/0g9A`0=bDL0040=bDL00303eIZ`3LU700g9A`0080g9A`
00<0?EV[0=bDL03LU7001@3LU70203eIZ`030=bDL00mFJ/0g9A`0080g9A`00X0?EV[0=bDL03LU700
g9A`03eIZ`3LU700?EV[0=bDL0000000g9A`0`0mFJ/00`3LU700?EV[03eIZ`0V0=bDL0030000003L
U700g9A`01P0g9A`0@3oool000D0g9A`00<000000=bDL03LU700=P3LU7000`000000g9A`0=bDL00K
0=bDL0<00000:P3LU70500000080g9A`0P0000001`3LU70000000=bDL03LU70000000=bDL0000000
0P3LU702000000D0g9A`0P0000030=bDL0050000003LU70000000000003LU700100000020000o`H0
000000<0003o02a<L@0/C7400`0/C7400`000000003o03EJP`0303EJP`80?EV[0`00000503iXU@80
003o0`0mFJ/200000080003o1@17N:P010000000DXRk05:8^`1BR;/403eIZ`0505:8^`000?l0G9O>
0000001LUlh00P000?l01@000000CGj[0000001>OjX000000080CWnZ00<0003o03eIZ`0mFJ/00`0m
FJ/00`3LU700?EV[03eIZ`0203eIZ`L0g9A`200mFJ/90=bDL00303eIZ`3LU700g9A`0080g9A`00<0
?EV[0=bDL03LU7001@3LU7000`0mFJ/0g9A`0=bDL0030=bDL080?EV[0`3LU70203eIZ`L0g9A`00@0
?EV[0=bDL00mFJ/0?EV[1@3LU70503eIZ`<0g9A`00<0000003eIZ`3LU7000`0mFJ/W0=bDL0030000
003LU700g9A`01P0g9A`0@3oool000D0g9A`00<000000=bDL03LU700=`3LU7000`000000g9A`0=bD
L00H0=bDL0800000;@3LU70600000080g9A`0P000000103LU70000000=bDL03LU702000000<0g9A`
0P0000050=bDL0@000000`3LU702000000<0003o00<0000000/C8P000?l00`0I9d000`000?l00000
0000o`03000000<0;4aa00<000000000o`0eFX<00`0mFJ/20000o`04000000000?l0?EV[000000<0
003o0`0mFJ/204IhZ`050000o`000000D8Ro0000001@R;l01@000?l01`0mFJ/0000003eIZ`0mFJ/0
DXRk03eIZ`1BR;/00P00000010000?l0G9O>05bGcP00000305bGcP03000000000?l0000000@0?EV[
00<0003o02a7E`000?l00`0mFJ/30=bDL0P0?EV[0P3LU700100mFJ/0g9A`0=bDL00mFJ/70=bDL1T0
?EV[0P3LU7000`0mFJ/0g9A`0=bDL0050=bDL080?EV[00<0g9A`03eIZ`3LU7001`3LU70203eIZ`D0
g9A`00H0?EV[0000003LU700?EV[0=bDL00mFJ/X0=bDL0030000003LU700g9A`01L0g9A`0@3oool0
00D0g9A`00<000000=bDL03LU700>03LU7000`000000g9A`0=bDL00D0=bDL0<00000<03LU7050000
0080g9A`0P0000020=bDL0@00000103LU7000`000000g9A`0=bDL0040=bDL0030000003LU700g9A`
00<0g9A`0P0000020000o`802a<R00<0000003eIZ`0I9d000P000?l202<mG@040000000/C740;4aa
02a<L@<0000000<0?EV[0000000mFJ/00`000?l303aYV0030000000mFJ/0AWR[0080000000<0?EV[
04IhZ`16N:/00`16N:/010000?l000000528_`1@R;l2000000@0?EV[00<0003o05^Ie00000000P00
0?l01@0mFJ/0003o0000001BR;/0000000<0G9O>00<0000005bGcP0mFJ/00`0mFJ/200000080CWnZ
0`000?l603eIZ`P0g9A`3@0mFJ/00`3LU700?EV[0=bDL0040=bDL00303eIZ`3LU700g9A`00D0g9A`
00<0?EV[0=bDL03LU7000P3LU70203eIZ`<0g9A`1@0mFJ/30=bDL080?EV[0P3LU7000`0mFJ/0g9A`
0=bDL0060=bDL0<0?EV[103LU7001P0mFJ/0g9A`03eIZ`000000g9A`03eIZbX0g9A`00<000000=bD
L03LU7005P3LU7010?ooo`001@3LU7000`000000g9A`0=bDL00i0=bDL0030000003LU700g9A`0100
g9A`0`00000c0=bDL0H0000000@0g9A`0000003LU70000000`3LU702000000D0g9A`00<000000=bD
L03LU7000`3LU702000000D0g9A`00@000000000o`0;4b802a<R0P0mFJ/01`000000003o02<mG@0S
?Ed0?EV[0000o`0000000`0/C74303eIZ`8000001`0lJIP00`000000?EV[03eIZ`0204IhZ`030000
0016N:/0AWR[00<0AWR[00<000000528_`1@R;l00`0mFJ/01@000000D8Ro0528_`1@R;l0003o0080
FiWD00@0000003eIZ`1KVM@000000`000?l00`000000?EV[03eIZ`0203eIZ`80G9O>00<0003o0000
001SXmX00`00000010000?l0@Vj>049^SP0mFJ/:0=bDL0D0?EV[00@0g9A`03eIZ`3LU700g9A`:00m
FJ/30=bDL00303eIZ`3LU700g9A`00D0g9A`0P0mFJ/20=bDL00903eIZ`3LU700g9A`0=bDL00mFJ/0
g9A`03eIZ`3LU70000000080?EV[:P3LU7000`000000g9A`0=bDL00F0=bDL040oooo00040=bDL003
0000003LU700g9A`03/0g9A`00<000000=bDL03LU700303LU703000003L0g9A`1P000000103LU700
00000=bDL00000030=bDL0030000003LU700g9A`00@0g9A`00H000000=bDL03LU700g9A`0000003L
U702000000<0g9A`00<0003o03eIZ`0000000`0mFJ/00`000?l0000003eIZ`0203eIZ`0402<mG@00
0?l0;4aa00000080?EV[100dFhL30000000303aYV00mFJ/0?EV[0080?EV[00<0000003eIZ`16N:/0
0`16N:/200000080AWR[00@0?EV[0000000mFJ/0?EV[101@R;l010000000D8Ro0528_`000?l305^I
e00303eIZ`000000000000@0?EV[00/000000000o`1LUlh0G9O>0000001LUlh0003o06>SfP000000
Hj?J000000030000o`0303eIZ`12KXh0003o00@0g9A`3P0mFJ/60=bDL00303eIZ`3LU700g9A`0080
g9A`00<0?EV[0=bDL03LU7001@3LU70203eIZ`<0g9A`0P0mFJ/40=bDL080?EV[1@3LU70703eIZ`H0
g9A`0P0mFJ/40=bDL0D0?EV[00@0g9A`03eIZ`0mFJ/00000;03LU7000`000000g9A`0=bDL00E0=bD
L040oooo00040=bDL0030000003LU700g9A`03`0g9A`00<000000=bDL03LU700203LU703000003X0
g9A`100000001P3LU7000000000000000000g9A`000000<0g9A`0P0000050=bDL08000000P3LU700
0`000000g9A`0=bDL002000000D0?EV[00H000000000o`0mFJ/0?EV[02<mG@00000202<mG@<0?EV[
00<0000003AKQ`0dFhL0100dFhL00`000?l0000003eIZ`02000000<0?6VH00<0000003eIZ`16N:/0
0`16N:/203eIZ`040000000mFJ/0AWR[000000L0D8Ro00<000000528_`000?l00P1KVM@403eIZ`80
FiWD00@0003o06N/jP1W[>X000000`000?l02`000000003o06>SfP1SXmX0000006>SfP000000Hj?J
0000o`0mFJ/0@Vj>00L0?EV[0P3LU70203eIZ`<0g9A`00<0?EV[0=bDL03LU7001P3LU70203eIZ`@0
g9A`00<0?EV[0=bDL03LU700103LU70203eIZ`<0g9A`0P0mFJ/50=bDL00303eIZ`3LU700g9A`00<0
g9A`0P0mFJ/30=bDL0<0?EV[00<0g9A`03eIZ`0mFJ/01@0mFJ/50=bDL0<0?EV[0P3LU7001@0mFJ/0
g9A`0=bDL00mFJ/0000002`0g9A`00<000000=bDL03LU700503LU7010?ooo`00103LU7000`000000
g9A`0=bDL00m0=bDL0030000003LU700g9A`00@0g9A`0`00000n0=bDL0@0000000H0g9A`00000000
000000000=bDL00000030=bDL08000001@3LU703000000<0g9A`0P0mFJ/02@000000?EV[0000o`00
0?l02a<R03eIZ`000000?EV[0000o`0202<mG@040000000mFJ/0003o0000o`80=5^700<0000003AK
Q`0dFhL00`0dFhL00`000?l0000003aYV00203aYV08000000P0lJIP00`000000AWR[03eIZ`0203eI
Z`0304IhZ`000?l0003o00<0000010000?l40528_`070000000mFJ/0?EV[03eIZ`1KVM@0?EV[05^I
e0020000000305^Ie0000?l0IjcZ0080IjcZ00D0000006N/jP1W[>X0003o0000000306>SfP030000
000mFJ/0?EV[00<0?EV[00<0@Vj>0000o`3LU7001@3LU700100mFJ/0g9A`0=bDL03LU70203eIZ`P0
g9A`00<0?EV[0=bDL03LU7000P3LU70203eIZ`D0g9A`0P0mFJ/40=bDL00303eIZ`3LU700g9A`00<0
g9A`0P0mFJ/50=bDL00403eIZ`3LU700g9A`0=bDL080?EV[0`3LU70203eIZ`030=bDL00mFJ/0?EV[
0080?EV[1@3LU70203eIZ`<0g9A`0P0mFJ/0103LU700?EV[0=bDL000000/0=bDL0030000003LU700
g9A`01@0g9A`0@3oool000@0g9A`00<000000=bDL03LU700?P3LU70010000000g9A`0=bDL03LU702
00000480g9A`00<000000=bDL00000000P3LU702000000030=bDL0000000g9A`0080g9A`0`000005
0=bDL080000000<0g9A`03eIZ`0mFJ/00P0mFJ/00`3LU70000000000o`0203eIZ`0301LW@@0mFJ/0
000000<0?EV[00@0000002a=M@0/CGD0003o0P0dFhL00`000000=5^703AKQ`0303AKQ`030000o`00
0000?6VH0080?6VH0P000?l30000000303eIZ`000?l0003o0080003o101=Q/400`000000EiOD05NG
e00205NGe0@0?EV[00L0003o000000000000003o05^Ie00mFJ/000000080FiWD00<000000000o`1W
[>X00`1W[>X00`000000IjcZ06N/jP0503eIZ`0406>SfP0mFJ/0000005jMc`@0003o0`3LU70203eI
Z`<0g9A`00<0?EV[0=bDL03LU7001`3LU7000`0mFJ/0g9A`0=bDL0020=bDL00303eIZ`3LU700g9A`
00<0g9A`0P0mFJ/40=bDL080?EV[1@3LU7000`0mFJ/0g9A`0=bDL0030=bDL080?EV[0`3LU7000`0m
FJ/0g9A`0=bDL0040=bDL080?EV[00@0g9A`03eIZ`0mFJ/0g9A`0P0mFJ/20=bDL080?EV[0`3LU704
03eIZ`<0g9A`00<000000=bDL03LU700:P3LU7000`000000g9A`0=bDL00C0=bDL040oooo00040=bD
L0030000003LU700g9A`03l0g9A`0`0000140=bDL0@0000000H0g9A`00000000000000000=bDL000
00020=bDL0040000003LU7000000000000@0g9A`00<0?EV[0000000000001P0mFJ/01P0000005bM1
01LW@@0G9d40?EV[00000080003o0P0/CGD00`000000;4ee0000o`0303AKQ`040000000dFhL0=5^7
03AKQ`<0003o00<000000000o`000?l01014Mjh00`000000CHK104f6`@0704f6`@8000000`0mFJ/5
05NGe0070000o`1SZN/0000003eIZ`000?l000000000o`0205^Ie0030000001W[>X0?EV[00D0?EV[
00<0003o076moP0000000P000?l0100mFJ/000000000o`00000205jMc`80003o2@0mFJ/60=bDL1H0
?EV[0`3LU70203eIZ`@0g9A`0P0mFJ/30=bDL080?EV[1@3LU70203eIZ`030=bDL00mFJ/0?EV[00D0
g9A`0P0mFJ/00`3LU700?EV[0=bDL00203eIZ`030=bDL00mFJ/0?EV[00D0g9A`00<000000=bDL03L
U700:@3LU7000`000000g9A`0=bDL00C0=bDL040oooo00040=bDL0030000003LU700g9A`03`0g9A`
0`0000000`3LU70000000=bDL0150=bDL0030000003LU70000000080g9A`1@0000020=bDL0030000
003LU7000000008000000`0mFJ/00`000000?EV[0000000303eIZ`<0003o00H0000003eIZ`0mFJ/0
?EV[0000o`00000402a=M@030000000mFJ/0003o0080=5^700P0000003AKQ`000?l0003o03aZW@00
0?l0A7N^000000H0A7N^0`00000504f6`@80?EV[00@0000005NGe000000000001P1GUm@01P000?l0
HjW[06>Yj`0mFJ/0000006>Yj`D0?EV[1@1W[>X020000000003o076moP1a_Oh0000003eIZ`000000
003o0P00000305jMc`80003o00<0?EV[0=bDL03LU7006@0mFJ/30=bDL080?EV[0`3LU70403eIZ`<0
g9A`0P0mFJ/40=bDL00303eIZ`3LU700g9A`00<0g9A`0P0mFJ/20=bDL080?EV[1@3LU70203eIZ`04
0=bDL00mFJ/0g9A`03eIZ`80g9A`0P0mFJ/70=bDL0030000003LU700g9A`02T0g9A`00<000000=bD
L03LU7004P3LU7010?ooo`000`3LU7000`000000g9A`0=bDL00j0=bDL0<000001@3LU702000004D0
g9A`00<000000=bDL00000000P3LU70010000000g9A`0=bDL00000020=bDL0030000003LU7000000
0080?EV[00@0000003eIZ`3LU70000000P0mFJ/010000000g9A`0000o`000?l203eIZ`0701LW@@00
00005bM103eIZ`000?l0;4ee0000000303eIZ`040000000/CGD0003o03AKQ`80003o00D0000003aZ
W@0lJYd0?6ZM0000o`0204Ag[P0300000014Mjh0A7N^00<0A7N^00@0000004f6`@1=Q/4000000P1=
Q/4203eIZ`80CHK100D0000005NGe01GUm@0EiOD0000000505NGe0030000o`1SZN/0?EV[00<0?EV[
0`1SZN/010000?l0Kkgo000000000?l406N/jP080000001a_Oh0LKgn076moP0mFJ/00000076moP00
0?l20000000305jMc`0mFJ/0?EV[00@0?EV[00<0g9A`03eIZ`3LU7001@3LU70203eIZ`D0g9A`00<0
?EV[0=bDL03LU7000P3LU70203eIZ`<0g9A`1@0mFJ/30=bDL080?EV[0P3LU70303eIZ`@0g9A`0P0m
FJ/30=bDL0<0?EV[0`3LU700100mFJ/0g9A`0=bDL00mFJ/20=bDL080?EV[0`3LU70203eIZ`040=bD
L00mFJ/0?EV[03eIZ`P0g9A`00<000000=bDL03LU700:P3LU7000`000000g9A`0=bDL00A0=bDL040
oooo00030=bDL0030000003LU700g9A`03L0g9A`0`00000:0=bDL0030000003LU700g9A`04<0g9A`
0P0000020=bDL08000000P3LU7000`000000g9A`0000000303eIZ`040000003LU700000003eIZ`80
00000P3LU7001@000000?EV[03eIZ`084200003o00805bM100D0000003eIZ`0mFJ/0?EV[02a=M@07
00000080?6ZM00D0000003aZW@0lJYd0?6ZM0000o`0204Ag[P0300000014Mjh0A7N^00@0A7N^00@0
000004f6`@1=Q/4000001@1=Q/400`000000EiOD05NGe00205NGe0030000001GUm@0EiOD00@0?EV[
00<0HjW[03eIZ`000000101SZN/010000?l0Kkgo06nmo`0000030000o`0606N/jP000?l00000076m
oP0mFJ/0LKgn1P0mFJ/0101NWLl0003o0000o`000?l20=bDL00303eIZ`3LU700g9A`00<0g9A`0P0m
FJ/60=bDL00403eIZ`3LU700g9A`0=bDL080?EV[1@3LU7000`0mFJ/0g9A`0=bDL0020=bDL0P0?EV[
0P3LU700100mFJ/0g9A`03eIZ`0mFJ/30=bDL080?EV[103LU70203eIZ`<0g9A`0`0mFJ/40=bDL0D0
?EV[2`3LU7000`000000g9A`0=bDL00Y0=bDL0030000003LU700g9A`0140g9A`0@3oool000<0g9A`
00<000000=bDL03LU700=03LU703000000h0g9A`00<000000=bDL03LU700@P3LU70300000080g9A`
00<000000=bDL03LU7001@00000303eIZ`030=bDL0000000000000<0?EV[00H0003o000000000000
210P0000o`0G9d4203eIZ`07000000000?l000000000000/CGD0000002a=M@020000o`030000000l
JYd0000000@000000P0lJYd00`000?l0A7N^0000000604Ag[P040000001=Q/40CHK104f6`@800000
0`1=Q/400`000000EiOD05NGe00205NGe00503eIZ`000000000005NGe0000?l00P1SZN/0100mFJ/0
000006>Yj`00000306>Yj`050000o`1__Ol0Kkgo06nmo`0000000P1__Ol00`000?l0?EV[03eIZ`03
03eIZ`07076moP000000003o07G5o`000?l0000005jMc`030000o`030=bDL00mFJ/0g9A`00<0g9A`
0P0mFJ/60=bDL080?EV[0`3LU7000`0mFJ/0g9A`0=bDL0030=bDL080?EV[1@3LU70203eIZ`80g9A`
0P0mFJ/00`3LU700?EV[03eIZ`0403eIZ`80g9A`0P0mFJ/40=bDL080?EV[103LU70303eIZ`@0g9A`
0`0mFJ/00`3LU700?EV[0=bDL00<0=bDL0030000003LU700g9A`02T0g9A`00<000000=bDL03LU700
403LU7010?ooo`000`3LU7000`000000g9A`0=bDL00b0=bDL08000004P3LU7000`000000g9A`0=bD
L0120=bDL0<000000P3LU7000`000000?EV[03eIZ`0203eIZ`050000000mFJ/0?EV[0=bDL0000000
0P0mFJ/01@000000?EV[03eIZ`000000003o0080210P00<0000003eIZ`0mFJ/00`0R?5l01P000000
003o02a=M@0/CGD0003o00000080=5f<00<0000003aZW@0lJYd00`0lJYd50000000304Ag[P000000
A7N^00@0A7N^00<0000004f6`@1=Q/400P1=Q/401@000?l000000000o`000?l0000000@0003o0`1G
Um@01P000000003o06>Yj`1SZN/0?EV[00000080HjW[0P0000000`000?l0Kkgo06nmo`0206nmo`@0
?EV[00<0003o03eIZ`000?l00P000002076moP090000001eaOl0MLGo0000001NWLl0003o04MkW@00
0?l0?EV[00<0g9A`0P0mFJ/70=bDL00403eIZ`3LU700g9A`0=bDL080?EV[1@3LU7000`0mFJ/0g9A`
0=bDL0030=bDL080?EV[0P3LU70203eIZ`D0g9A`0P0mFJ/0103LU700?EV[03eIZ`0mFJ/50=bDL004
03eIZ`3LU700g9A`0=bDL0@0?EV[103LU70303eIZ`030=bDL00mFJ/0?EV[00h0g9A`00<000000=bD
L03LU700:P3LU7000`000000g9A`0=bDL00?0=bDL040oooo00030=bDL0030000003LU700g9A`02l0
g9A`0`00000E0=bDL0030000003LU700g9A`0480g9A`0P0000000`3LU700?EV[0000000303eIZ`<0
00001@0mFJ/3000000060=bDL0000?l0?EV[03eIZ`08420000000`0R?5l01`000000?EV[0000000m
FJ/0003o03AMS00000000P0dGH`00`000?l0000003aZW@0303aZW@050000000lJYd0?6ZM0000o`14
Mjh00P0000000`14Mjh0003o0000o`020000o`03000000000?l0003o0080003o0P1DU=H3000000@0
GZGY10000?l01@000000003o0000o`0mFJ/0000000@0HjW[1@0mFJ/206nmo`070000001__Ol0003o
03eIZ`1kdol0003o00000002076moP090000o`000000MLGo07G5o`000000003o04MkW@0mFJ/0003o
00@0?EV[1`3LU7000`0mFJ/0g9A`0=bDL00203eIZ`D0g9A`0P0mFJ/40=bDL080?EV[0P3LU70203eI
Z`D0g9A`0P0mFJ/0103LU700?EV[03eIZ`3LU70303eIZ`80g9A`0P0mFJ/20=bDL080?EV[00@0g9A`
03eIZ`3LU700?EV[0`3LU70303eIZ`030=bDL00mFJ/0?EV[0100g9A`00<000000=bDL03LU700:@3L
U7000`000000g9A`0=bDL00?0=bDL040oooo00030=bDL0030000003LU700g9A`02`0g9A`0`00000I
0=bDL0030000003LU700g9A`0480g9A`0P00000203eIZ`050000000mFJ/0?EV[0=bDL00mFJ/00`00
0000200mFJ/000000=bDL03LU700000003eIZ`000000?EV[0P0842020000o`040000000R?5l08SaO
00000080?EV[00D0000003AMS00dGH`0=5f<0000000203AMS0030000o`000000?6ZM00<0?6ZM00<0
00000000o`000?l00P000?l3000000<0C8K400<0000005BDeP1DU=H01P1DU=H00`000000GZGY05jU
j@0605jUj@050000o`000000?EV[000000000?l0100mFJ/00`000?l0000006nmo`0506nmo`030000
000mFJ/0Nm?o0080Nm?o0P0000020000o`0907G5o`000000MLGo07G5o`000?l0?EV[000000000?l0
?EV[00<0g9A`1`0mFJ/00`3LU700?EV[03eIZ`050=bDL080?EV[103LU70203eIZ`80g9A`0P0mFJ/5
0=bDL080?EV[00<0g9A`03eIZ`0mFJ/00`3LU7000`0mFJ/0g9A`0=bDL00203eIZ`050=bDL00mFJ/0
?EV[03eIZ`3LU7000P0mFJ/0103LU700?EV[0=bDL03LU70403eIZ`030=bDL00mFJ/0?EV[0180g9A`
00<000000=bDL03LU700:@3LU7000`000000g9A`0=bDL00>0=bDL040oooo00030=bDL0030000003L
U700g9A`02T0g9A`0`00000M0=bDL0030000003LU700g9A`03l0g9A`0P0mFJ/30000000303eIZ`00
000000000080?EV[00H0g9A`0000000mFJ/0?EV[0000003LU70203eIZ`090000000mFJ/0003o0000
00084200003o01@S?P000?l08SaO0080000000D0?EV[0000o`000?l0=5f<0000000303AMS0050000
000dGH`0003o03aZW@0000000P0lJYd010000?l0000004=i]0000?l304b6a0070000001<Q/@00000
0000001<Q/@0003o0000000705BDeP<000001P1NYNT00`000?l0?EV[03eIZ`0203eIZ`80JKOo1000
0?l606nmo`0303eIZ`1kdol0Nm?o00D0Nm?o00<0003o07G5o`1eaOl00P1eaOl01P0mFJ/000000000
00000?l000000=bDL1@0?EV[00<0g9A`03eIZ`0mFJ/00P3LU70203eIZ`D0g9A`0P0mFJ/00`3LU700
?EV[03eIZ`060=bDL0H0?EV[00<0g9A`03eIZ`0mFJ/00P3LU7000`0mFJ/0g9A`0=bDL00203eIZ`03
0=bDL00mFJ/0?EV[0080?EV[503LU7000`000000g9A`0=bDL00Y0=bDL0030000003LU700g9A`00d0
g9A`0@3oool00080g9A`00<000000=bDL03LU7009`3LU70300000240g9A`00<000000=bDL03LU700
?03LU70503eIZ`H0000000@0g9A`03eIZ`0mFJ/000000P0mFJ/01@000000?EV[000000000000?EV[
0080003o0P000000200D8ch0?EV[03eIZ`0mFJ/000000000o`0/CgX0003o0P0dGH`020000000=5f<
03AMS00dGH`000000000o`0lJYd000000P000?l204=i]003000000000?l0C8K40080C8K400@00000
04b6a01<Q/@0C8K40`00000705BDeP040000001NYNT0GZGY000000D0GZGY00<0003o06Vgo`0mFJ/0
0P00000406Vgo`040000o`1fcOl0003o0000o`<0Kkgo00<0?EV[0000o`1kdol01P1kdol00`000?l0
?EV[03eIZ`0803eIZ`@0g9A`100mFJ/30=bDL0D0?EV[0`3LU70603eIZ`D0g9A`0P0mFJ/00`3LU700
?EV[03eIZ`070=bDL0<0?EV[103LU7000`0mFJ/0g9A`0=bDL0020=bDL0<0?EV[00<0g9A`03eIZ`0m
FJ/00P0mFJ/F0=bDL0030000003LU700g9A`02T0g9A`00<000000=bDL03LU7003@3LU7010?ooo`00
0P3LU7000`000000g9A`0=bDL00U0=bDL08000009@3LU7000`000000g9A`0=bDL00i0=bDL0D0?EV[
00<0g9A`03eIZ`0mFJ/00P000000100mFJ/0000003eIZ`00000203eIZ`8000000P3LU70300000003
0=bDL0000?l0003o0080?EV[00@000000000o`0R?5l0003o0P0000000`0/CgX0003o03AMS00203AM
S0080000000dGH`0=5f<0000o`000000003o04=i]000000304=i]003000000000?l0C8K400<0C8K4
00H0000004b6a01<Q/@0C8K40000o`00000705BDeP050000001NYNT0GZGY05jUj@000000101NYNT0
0`000?l0JKOo06Vgo`0606Vgo`040000o`1fcOl0M/go07K=o`<0003o00<0?EV[0000o`1kdol01`0m
FJ/02024hol0003o03eIZ`1eaOl0003o06B/h0000000Ag^M0P0000030=bDL0<0?EV[1P3LU70203eI
Z`030=bDL00mFJ/0?EV[0080?EV[0P3LU70203eIZ`030=bDL00mFJ/0g9A`0080g9A`0P0mFJ/00`3L
U700?EV[03eIZ`070=bDL0<0?EV[103LU70203eIZ`030=bDL00mFJ/0g9A`00<0?EV[0P3LU70403eI
ZaP0g9A`00<000000=bDL03LU700:@3LU7000`000000g9A`0=bDL00<0=bDL040oooo00020=bDL003
0000003LU700g9A`0280g9A`0`00000X0=bDL0030000003LU700g9A`03H0g9A`1@0mFJ/01@3LU700
?EV[03eIZ`0mFJ/0g9A`008000000P0mFJ/00`000000?EV[03eIZ`020=bDL0030000003LU700g9A`
0080?EV[0P00000203eIZ`<052<n00D000000000o`0/CgX0000002a?NP02000000040000o`0mFJ/0
=5f<00000080003o00<0?6fT0000o`0000000P13NK@01P000000@gVd04=i]013NK@000000000o`<0
C8K400D0000004b6a01<Q/@0C8K40000o`03000000D0E9CF00<0000005jUj@1NYNT01P1NYNT00`00
0?l0JKOo06Vgo`0606Vgo`040000o`1fcOl0M/go07K=o`H0?EV[1P1kdol01P000?l0Q>?o03eIZ`00
0?l0MLGo0000o`80I:cP00@000000000o`000000g9A`0`0mFJ/60=bDL080?EV[0P3LU70203eIZ`80
g9A`0`0mFJ/40=bDL0<0?EV[00<0g9A`03eIZ`0mFJ/01P3LU70303eIZ`80g9A`00<0?EV[0=bDL03L
U7000P0mFJ/30=bDL0@0?EV[0P3LU70303eIZa/0g9A`00<000000=bDL03LU700:@3LU7000`000000
g9A`0=bDL00;0=bDL040oooo00020=bDL0030000003LU700g9A`01l0g9A`0`00000/0=bDL0030000
003LU700g9A`03<0g9A`1@0mFJ/00`3LU700?EV[03eIZ`0403eIZ`050=bDL0000000?EV[03eIZ`3L
U7000P0000020=bDL0800000100mFJ/00`0000000P@80000o`0301@S?P040000o`00000000000000
00<0;4mj00D0000003AMS0000?l0003o0000000203a]Y0060000o`000000@gVd04=i]00mFJ/00000
0P13NK@00`000000003o04b6a00304b6a0080000001<Q/@0C8K40000o`1DU=H0000005BDeP000009
0000o`@0GZGY00<0003o06Vgo`1Y]ol01@1Y]ol00`000?l0?EV[03eIZ`0203eIZ`0407K=o`0mFJ/0
M/go07K=o`<0003o101kdol00`000?l0Q>?o03eIZ`0208CSo`80003o0`1T[>0010000000g9A`03eI
Z`0mFJ/60=bDL080?EV[0P3LU70203eIZ`<0g9A`0P0mFJ/00`3LU700?EV[03eIZ`020=bDL0D0?EV[
1P3LU70303eIZ`<0g9A`00@0?EV[0=bDL00mFJ/0?EV[0P3LU70503eIZ`<0g9A`0P0mFJ/N0=bDL003
0000003LU700g9A`02P0g9A`00<000000=bDL03LU7002`3LU7010?ooo`000P3LU7000`000000g9A`
0=bDL00L0=bDL0<00000<03LU7000`000000g9A`0=bDL00`0=bDL080?EV[00@0g9A`03eIZ`0mFJ/0
g9A`100mFJ/40=bDL080?EV[00H0000003eIZ`000000000003eIZ`00000203eIZ`050000000mFJ/0
g9A`0=bDL00mFJ/00`00000201@S?P050000o`0mFJ/0?EV[03eIZ`0000000`0/CgX00`000?l00000
03a]Y00203a]Y0050000000lKJ@0003o04=i]00000000P13NK@01@000000@gVd04=i]013NK@00000
00@0C8K400<000000000o`000?l00P000?l00`000000003o0000o`0405^Sj`030000o`1U/oh0IK?n
0080IK?n1P000?l606Vgo`030000o`1fcOl0M/go00<0M/go00<0?EV[07K=o`000?l00`23hol20000
o`80Nm?o0P0mFJ/408CSo`040000o`1T[>00000006B/h080?EV[0P0000040=bDL080?EV[0P3LU702
03eIZ`<0g9A`0P0mFJ/50=bDL0@0?EV[00<0g9A`03eIZ`3LU7000`3LU70403eIZ`D0g9A`0P0mFJ/0
1@3LU700?EV[03eIZ`0mFJ/0g9A`00@0?EV[00@0g9A`03eIZ`0mFJ/0?EV[7`3LU7000`000000g9A`
0=bDL00Y0=bDL0030000003LU700g9A`00X0g9A`0@3oool00080g9A`00<000000=bDL03LU7006@3L
U703000003@0g9A`00<000000=bDL03LU700;@3LU70203eIZ`030=bDL00mFJ/0?EV[00@0?EV[1@3L
U70503eIZ`80000000h0g9A`03eIZ`0mFJ/0000003eIZ`000000?EV[0000000mFJ/0g9A`0000o`00
0000003o00000080?EV[00<0003o02a?NP0/CgX00P0000001@0/CgX0003o0000o`0lKJ@0000000<0
?6fT00D0000003a]Y0000?l0@gVd0000000204=i]00400000013NK@0003o000000@0003o00@00000
05>EfP1CUMX0003o201KXn/00`000?l0IK?n06FcoP0606FcoP030000o`1_aOl0003o00<0003o0P1Y
]ol00`000?l0M/go07K=o`0207K=o`0403eIZ`1fcOl0M/go0000o`D0Pn?o00<0003o03eIZ`000?l0
1@24hol20000o`0406B/h00mFJ/0003o0=bDL08000000P3LU70203eIZ`040=bDL00mFJ/0?EV[03eI
Z`<0g9A`0P0mFJ/50=bDL0H0?EV[0P3LU7000`0mFJ/0g9A`03eIZ`0303eIZ`D0g9A`0P0mFJ/00`3L
U700?EV[03eIZ`020=bDL0P0?EV[8P3LU7000`000000g9A`0=bDL00Y0=bDL0030000003LU700g9A`
00T0g9A`0@3oool00080g9A`00<000000=bDL03LU7005P3LU703000003P0g9A`0P00000[0=bDL0X0
?EV[103LU70403eIZ`<0g9A`00H0000003eIZ`0mFJ/0g9A`0000000mFJ/3000000070=bDL0000000
g9A`0000o`000000?EV[01@S?P02000000040000o`0/CgX0;4mj02a?NP8000000P0eHID010000?l0
?6fT00000000000203a]Y004000000000?l0@gVd04=i]0P000001@1CUMX00`000?l0Fj?[05^Sj`06
05^Sj`030000o`1U/oh0IK?n00H0IK?n00<0003o06o5o`1_aOl00`1_aOl40000o`80M/go00D0?EV[
07K=o`1fcOl0M/go0000o`0508?So`0403eIZ`23hol0003o000000@0Q>?o00D0003o03eIZ`0mFJ/0
003o000000020=bDL0040000000mFJ/0?EV[0=bDL080?EV[103LU70203eIZ`D0g9A`0`0mFJ/50=bD
L0H0?EV[1@3LU70503eIZ`80g9A`0P0mFJ/00`3LU700?EV[0=bDL00303eIZbD0g9A`00<000000=bD
L03LU700:03LU7000`000000g9A`0=bDL0090=bDL040oooo00000`3LU70000000=bDL00F0=bDL080
0000?@3LU7000`000000g9A`0=bDL00V0=bDL0H0?EV[00@0g9A`03eIZ`0mFJ/0?EV[0`3LU70403eI
Z`@0g9A`0P0mFJ/00`3LU700000003eIZ`020000000403eIZ`3LU7000000000000@0?EV[00<02A8U
000000000?l00P0Q>f020000000402a?NP000?l0000003EQU@80000000D0003o03a]Y00lKJ@0?6fT
0000000203a]Y00500000013NK@00000000000000?l00P1;R</00`000000003o05>EfP0605>EfP03
0000o`1KXn/0Fj?[00H0Fj?[00<0003o06FcoP1U/oh01P1U/oh00`000?l0KlGo06o5o`0506o5o`04
0000o`1kf_l0003o0000o`@0M/go00<0003o08?So`23hol00P23hol00`0mFJ/0Pn?o08?So`020000
o`l0?EV[103LU70203eIZ`@0g9A`100mFJ/50=bDL0H0?EV[1@3LU70503eIZ`80g9A`0P0mFJ/20=bD
L0D0?EV[9P3LU7000`000000g9A`0=bDL00X0=bDL08000002P3LU7010?ooo`0000<0g9A`0000003L
U7004`3LU70300000400g9A`00<000000=bDL03LU700903LU70503eIZ`060=bDL00mFJ/0?EV[0=bD
L00mFJ/0g9A`100mFJ/00`3LU700?EV[0=bDL0020=bDL0D0?EV[00<0g9A`0000000mFJ/00P000002
03eIZ`<0000000@0g9A`0000o`094RD00000100Q>f0010000?l0000003EQU@00000303EQU@030000
000lKJ@0?6fT0080?6fT00<0000003a]Y0000?l00P0000000`1;R</0000004^8b`0204^8b`030000
o`1CUMX0DiGJ00H0DiGJ00<0003o05^Sj`1KXn/01@1KXn/00`000?l0IK?n06FcoP0506FcoP030000
o`1_aOl0KlGo00D0KlGo00<0003o07_Jo`1kf_l00P1kf_l20000o``0?EV[0P000?l203eIZ`80OMco
0P000?l01016OZ00?EV[03eIZ`0mFJ/2000000D0?EV[103LU70403eIZ`@0g9A`0`0mFJ/01@3LU700
?EV[03eIZ`0mFJ/0g9A`0080?EV[0P3LU70303eIZ`80g9A`00@0?EV[0=bDL00mFJ/0?EV[0P3LU705
03eIZbT0g9A`00<000000=bDL03LU7008`3LU704000000030=bDL0000000g9A`00T0g9A`0@3oool0
00030=bDL0000000g9A`0100g9A`0`0000140=bDL0030000003LU700g9A`0240g9A`200mFJ/00`3L
U700?EV[03eIZ`0403eIZ`<0g9A`00<0?EV[0=bDL00mFJ/00`0mFJ/40=bDL080000000<0?EV[0000
000000000P0mFJ/01`000000g9A`0000000000002A8U0000o`0000000`0Q>f000`000?l0=F6E0000
000200000080=F6E00<0003o0000000lKJ@00P0lKJ@01@000?l000000000001;R</0000000H0BhS;
00<0003o05>EfP1CUMX01@1CUMX00`000?l0Fj?[05^Sj`0505^Sj`030000o`1U/oh0IK?n00D0IK?n
00<0003o06o5o`1_aOl01@1_aOl00`000?l0Nm[o07_Jo`0407_Jo`<0003o00<0Pn?o03eIZ`0mFJ/0
0`23hol00`000?l0S_Wo08kio`0203eIZ`80003o0`1mg?l203eIZ`050000o`00000000000=bDL000
00000P0mFJ/20=bDL0H0?EV[1@3LU70203eIZ`060=bDL00mFJ/0?EV[03eIZ`3LU700?EV[0`3LU703
03eIZ`<0g9A`100mFJ/00`3LU700?EV[03eIZ`0203eIZ`030=bDL00mFJ/0g9A`02/0g9A`00<00000
0=bDL03LU7007`3LU703000000D0g9A`00<000000=bDL03LU700203LU7010?ooo`0000<0g9A`0000
003LU7003@3LU703000004P0g9A`00<000000=bDL03LU7007P3LU70403eIZ`050=bDL00mFJ/0?EV[
03eIZ`3LU7000`0mFJ/00`3LU700?EV[03eIZ`040=bDL0@0?EV[1P3LU70203eIZ`040000000mFJ/0
?EV[03eIZ`80g9A`0P0000000`0mFJ/0003o00000002000000808C]P00<0?EV[0000o`0eHID00P0e
HID01@000000=F6E03EQU@0eHID0003o0080000000D0003o04Am_P0mFJ/0A7fn0000o`0704^8b`03
0000o`1CUMX0DiGJ00D0DiGJ00<0003o05^Sj`1KXn/01@1KXn/00`000?l0IK?n06FcoP0506FcoP03
0000o`1_aOl0KlGo00D0KlGo00<0003o07_Jo`1kf_l01@1kf_l010000?l0Qo7o03eIZ`000?l408?S
o`030000o`0mFJ/0?EV[00<0S_Wo00L0003o07gLo`0mFJ/0?EV[0000o`16OZ00000000@0?EV[0P00
00020=bDL0@0?EV[103LU70603eIZ`@0g9A`100mFJ/00`3LU700?EV[0=bDL0020=bDL0P0?EV[00<0
g9A`03eIZ`0mFJ/0;P3LU7000`000000g9A`0=bDL00K0=bDL0<00000203LU7000`000000g9A`0=bD
L0080=bDL040oooo00000`3LU70000000=bDL00:0=bDL0<00000C03LU7000`000000g9A`0=bDL00K
0=bDL0@0?EV[00<0g9A`03eIZ`0mFJ/01@0mFJ/00`3LU700?EV[03eIZ`040=bDL0<0?EV[1P3LU703
03eIZ`030=bDL00mFJ/0?EV[00800000100mFJ/2000000<0003o0P000000100mFJ/0;5:102aBP@00
0?l203EQU@8000000P0eHID20000o`D0A7fn00@0003o04^8b`1;R</00000101;R</00`000?l0DiGJ
05>EfP0205>EfQD0003o1P1_aOl00`000?l0Nm[o07_Jo`0407_Jo`030000o`27lOl0Qo7o0080Qo7o
0P000?l00`23hol0?EV[03eIZ`0408kio`030000o`0mFJ/0?EV[0080OMco00D0003o0000000mFJ/0
?EV[0000000203eIZ`<000000P0mFJ/0103LU700?EV[0=bDL03LU70303eIZ`030=bDL00mFJ/0?EV[
00D0g9A`100mFJ/40=bDL00303eIZ`3LU700?EV[00<0?EV[00@0g9A`03eIZ`0mFJ/0g9A`0P0mFJ/`
0=bDL0030000003LU700g9A`01L0g9A`1000000<0=bDL0030000003LU700g9A`00L0g9A`0@3oool0
00030=bDL0000000g9A`00L0g9A`0`00001@0=bDL0030000003LU700g9A`01P0g9A`100mFJ/20=bD
L0@0?EV[00<0g9A`03eIZ`0mFJ/00P0mFJ/30=bDL0@0?EV[1@3LU70303eIZ`80g9A`0P0mFJ/20=bD
L00403eIZ`00000000000=bDL080?EV[00<0g9A`0000000mFJ/00P0mFJ/01P000?l08C]P00000000
0000;5:10000o`80=F6E00D0000003EQU@00000000000000o`0304Am_P0400000014OKh0A7fn0000
o`H0BhS;1P000?l305ZTl@030000o`1R/Ol0H[7o00D0H[7o00<0003o06_0o`1[`?l01@1[`?l00`00
0?l0M=;o0000o`030000o`0306o5o`000?l0Nm[o00H0Nm[o00<0003o08Oao`27lOl01027lOl00`0m
FJ/0003o08kio`0308kio`80?EV[00@0Sooo0000o`1mg?l0003o0P0mFJ/010000000g9A`0=bDL000
000403eIZ`030000003LU700g9A`00<0?EV[00@0g9A`03eIZ`0mFJ/0?EV[103LU70503eIZ`D0g9A`
100mFJ/20=bDL0D0?EV[<`3LU7000`000000g9A`0=bDL00C0=bDL0<00000403LU7000`000000g9A`
0=bDL0070=bDL040oooo00000`000000g9A`0=bDL0050=bDL0800000E03LU7000`000000g9A`0=bD
L00F0=bDL0<0?EV[0P3LU70403eIZ`<0g9A`0P0mFJ/30=bDL0@0?EV[00<0g9A`03eIZ`3LU7000P3L
U70203eIZ`<0g9A`0P0mFJ/20=bDL080?EV[0P3LU703000000<0?EV[00<0000000lM>@0?7CT00P00
0?l010000000;5:100000000000303EQU@050000000nL[40?W:a000000000?l01@14OKh00`000?l0
BhS;04^8b`0204^8b`80003o00<0DiWT0000o`1JY?401P1JY?400`000?l0H[7o06:ao`0506:ao`03
0000o`1[`?l0Jl3o00D0Jl3o00<0003o07CBo`1dd_l00`1dd_l30000o`H0Nm[o00<0003o08Oao`27
lOl01@27lOl20000o`0408kio`0mFJ/0?EV[0000o`80Sooo0`0mFJ/00`1LYmP0003o0000000403eI
Z`030=bDL00mFJ/0000000L0?EV[103LU70603eIZ`D0g9A`100mFJ/20=bDL0D0?EV[=P3LU7000`00
0000g9A`0=bDL00?0=bDL0<000004`3LU7000`000000g9A`0=bDL0070=bDL040oooo00000`000000
g9A`0=bDL0020=bDL0<00000E`3LU7000`000000g9A`0=bDL00C0=bDL0@0?EV[00@0g9A`03eIZ`0m
FJ/0?EV[103LU70203eIZ`030=bDL00mFJ/0?EV[00@0?EV[0P3LU7000`0mFJ/0g9A`03eIZ`0203eI
Z`80g9A`0`0mFJ/0103LU700?EV[03eIZ`0mFJ/50=bDL080?EV[00L0000003eIZ`0mFJ/0?EV[0000
000?7CT0003o0080;5:100@0000002aBP@0/DX4000000P000?l403ib/@030000o`14OKh0A7fn00@0
A7fn00@0003o04^8b`000?l0003o0`1CVN@00`000?l0FZCa05ZTl@0505ZTl@030000o`1R/Ol0H[7o
00D0H[7o00<0003o06_0o`1[`?l01@1[`?l00`000?l0M=;o07CBo`0407CBo`030000o`1oiOl0003o
00<0003o00<0Nm[o0000o`27lOl01P27lOl010000?l0Tooo03eIZ`0mFJ/208kio`040000o`0mFJ/0
?EV[08ooo`80003o0P1LYmP303eIZ`030=bDL0000000?EV[0080?EV[0P00000203eIZ`<0g9A`100m
FJ/01@3LU700?EV[03eIZ`3LU700?EV[0080g9A`1`0mFJ/00`3LU700?EV[03eIZ`0303eIZcP0g9A`
00<000000=bDL03LU7002`3LU704000001H0g9A`00<000000=bDL03LU7001`3LU7010?ooo`0000<0
00000=bDL00000000P00001K0=bDL0030000003LU700g9A`0140g9A`0`0mFJ/0103LU700?EV[03eI
Z`0mFJ/40=bDL0H0?EV[00<0g9A`03eIZ`0mFJ/00`3LU70303eIZ`<0g9A`0P0mFJ/20=bDL080?EV[
1P3LU70303eIZ`050000003LU7000000000000000?l00P0mFJ/01`000?l0;5:102aBP@0/DX400000
02aBP@000?l01P0nL[400`000?l0A7fn04Am_P0404Am_P80003o1P1CVN@00`000?l0FZCa05ZTl@05
05ZTl@030000o`1R/Ol0H[7o00@0H[7o00<0003o06_0o`1[`?l0101[`?l00`000?l0M=;o07CBo`04
07CBo`030000o`1oiOl0OnGo00@0OnGo0P000?l708Oao`030000o`2Cool0?EV[00@0?EV[102?ool3
03eIZ`030000o`0mFJ/0?EV[0080?EV[00<000000=bDL00mFJ/00P0000000`0mFJ/0g9A`03eIZ`02
03eIZ`80g9A`0`0mFJ/20=bDL0D0?EV[0P3LU7000`0mFJ/0g9A`03eIZ`0503eIZc/0g9A`00<00000
0=bDL03LU7001`3LU703000001X0g9A`00<000000=bDL03LU7001`3LU7010?ooo`000P00001O0=bD
L0030000003LU700g9A`00l0g9A`00<0?EV[0=bDL00mFJ/0100mFJ/30=bDL0D0?EV[0P3LU70203eI
Z`030=bDL00mFJ/0?EV[0080?EV[0P3LU7001@0mFJ/0g9A`03eIZ`0mFJ/0g9A`00<0?EV[1P3LU703
03eIZ`80g9A`1`00000203eIZ`<0;5:100<0003o03MWX@000?l01@0nL[400`000?l0A7fn04Am_P02
04Am_P<0003o1`1CVN@00`000?l0FZCa05ZTl@0505ZTl@030000o`1R/Ol0H[7o00@0H[7o00<0003o
06_0o`1[`?l0101[`?l00`000?l0M=;o07CBo`0407CBo`030000o`1oiOl0OnGo00D0OnGo0`000?l4
08Oao`040000o`2Cool0Tooo09?oo`80?EV[00@0003o03eIZ`2?ool0Sooo0P0mFJ/010000?l0?EV[
03eIZ`0mFJ/2000000060=bDL00mFJ/0?EV[0000003LU70000000`0mFJ/30=bDL080?EV[0`3LU705
03eIZ`80g9A`200mFJ/n0=bDL0030000003LU700g9A`00<0g9A`0`00000M0=bDL0030000003LU700
g9A`00L0g9A`0@3oool000030=bDL0000000g9A`05l0g9A`00<000000=bDL03LU700303LU70603eI
Z`030=bDL00mFJ/0g9A`0080g9A`0`0mFJ/00`3LU700?EV[0=bDL00203eIZ`<0g9A`100mFJ/20=bD
L080?EV[00<0g9A`03eIZ`0mFJ/01`3LU70303eIZ`D0g9A`0`0000001@000?l0?EV[000000000000
003o00<0;5:100<0003o03MWX@000?l01P0nL[4010000?l0A7fn0000o`000?l304f>f0030000o`1C
VN@0DiWT00@0DiWT00<0003o05ZTl@1JY?401@1JY?400`000?l0H[7o06:ao`0406:ao`030000o`1[
`?l0Jl3o00@0Jl3o00<0003o07CBo`1dd_l0101dd_l00`000?l0OnGo07oUo`0407oUo`050000o`2;
nol0Ro_o08_ko`000?l00`27lOl00`000?l0Tooo09?oo`0209?oo`030000o`0mFJ/0?EV[00D0?EV[
00D0G:OH0000o`000?l0000003eIZ`02000000D0?EV[00<000000=bDL03LU7000P0mFJ/00`3LU700
?EV[03eIZ`0503eIZ`80g9A`200mFJ]10=bDL0D00000803LU7000`000000g9A`0=bDL0070=bDL040
oooo00020=bDL0800000G`3LU7000`000000g9A`0=bDL00:0=bDL0D0?EV[0P3LU7000`0mFJ/0g9A`
0=bDL00203eIZ`@0g9A`0P0mFJ/30=bDL080?EV[103LU70503eIZ`L0g9A`0`0mFJ/60=bDL00303eI
Z`3LU70000000080?EV[00L02Q@W0000o`0O>f4000000000o`0/DX40003o00<0=fNQ00<0003o03ib
/@0nL[400`0nL[420000o`D0CHkH00<0003o05>Ii01CVN@0101CVN@00`000?l0FZCa05ZTl@0405ZT
l@`0003o0`1[`?l00`000?l0M=;o07CBo`0407CBo`030000o`1oiOl0OnGo00@0OnGo00<0003o08_k
o`2;nol00P2;nol30000o`D0Tooo00<0003o09Woo`000?l00P0mFJ/01@000?l0Mm_o07OKo`000?l0
000000D0?EV[0`000000100mFJ/0000003eIZ`00000403eIZ`040=bDL00mFJ/0?EV[03eIZ`<0g9A`
100mFJ/0103LU700?EV[03eIZ`0mFJ]10=bDL0<00000903LU7000`000000g9A`0=bDL0070=bDL040
oooo00040=bDL0030000003LU700g9A`05d0g9A`0P0000090=bDL0@0?EV[0`3LU70403eIZ`D0g9A`
00@0?EV[0=bDL03LU700g9A`0P0mFJ/40=bDL0D0?EV[00<0g9A`03eIZ`3LU700103LU70303eIZ`H0
g9A`0P0mFJ/00`3LU700?EV[03eIZ`03000000060000o`0O>f407c]Q0000o`0/DX40003o100gIj40
1`000?l0?W:a03ib/@0nL[40003o04N5c@000?l01P1=S]P00`000?l0DiWT05>Ii00405>Ii0030000
o`1JY?40003o00<0003o00<0H[Co0000o`1Y`?l01@1Y`?l010000?l0LLko077>o`1ac_l60000o`<0
M=;o00<0003o07oUo`1oiOl0101oiOl00`000?l0Ro_o08_ko`0508_ko`030000o`0mFJ/0Tooo0080
Tooo00<0003o09Woo`2Iool00P0mFJ/00`2?ool0003o07OKo`0403eIZ`040=bDL0000000g9A`0000
0080g9A`1@0mFJ/00`000000g9A`0=bDL00303eIZ`030=bDL00mFJ/0?EV[00<0?EV[0P3LU70303eI
Zd00g9A`0`0000030=bDL0030000003LU700g9A`0280g9A`00<000000=bDL03LU7001P3LU7010?oo
o`001@3LU7000`000000g9A`0=bDL01N0=bDL0030000003LU700g9A`00@0g9A`1P0mFJ/20=bDL0<0
?EV[1@3LU70303eIZ`030=bDL00mFJ/0?EV[00@0g9A`100mFJ/30=bDL0@0?EV[00@0g9A`03eIZ`0m
FJ/0?EV[1P3LU70203eIZ`030=bDL00mFJ/0?EV[00<0g9A`00<0003o000000000?l00`0O>f400`00
0?l0=fNQ03MWX@0303MWX@040000o`0nL[40003o0000o`80AhG=00<0003o04f>f01=S]P0101=S]P0
0`000?l0DiWT05>Ii00305>Ii0<0003o1@1R]?l00`000?l0JL3o06W0o`0406W0o`030000o`1ac_l0
LLko00@0LLko00<0003o07WNo`1ig_l01@000?l507oUo`030000o`2;nol0Ro_o00@0Ro_o00<0003o
09Koo`000?l00`2Cool010000?l0?EV[09Woo`2Iool403eIZ`0707OKo`000?l0003o0000003LU700
00000=bDL00403eIZ`<0000000<0?EV[0000000mFJ/01@0mFJ/00`3LU700?EV[03eIZ`020=bDL0<0
?EV[?P3LU704000000L0g9A`00<000000=bDL03LU7008@3LU7000`000000g9A`0=bDL0060=bDL040
oooo00060=bDL0030000003LU700g9A`05h0g9A`00<000000=bDL03LU7000P3LU70203eIZ`030=bD
L00mFJ/0?EV[0080g9A`0`0mFJ/50=bDL080?EV[00@0g9A`03eIZ`0mFJ/0?EV[103LU70403eIZ`L0
g9A`1P0mFJ/40=bDL080?EV[00<0g9A`03eIZ`0mFJ/0103LU7000`0mFJ/00000000000020000o`80
7c]Q00<0003o03MWX@0gIj40100gIj400`000?l0AhG=04N5c@0304N5c@030000o`1=S]P0CHkH00@0
CHkH00<0003o05>Ii0000?l00P000?l00`1LZOh0003o06:do`0506:do`030000o`1Y`?l0JL3o00@0
JL3o00<0003o077>o`1ac_l00`1ac_l00`000?l0NMko07WNo`0407WNo`030000o`23l?l0003o0080
003o00<0OnGo0000o`2;nol01P2;nol00`000?l0U_oo09Koo`030000o`D0VOoo00@0003o07OKo`1g
fol0Mm_o200mFJ/20=bDL08000001@0mFJ/20=bDL0<0?EV[00<0g9A`03eIZ`0mFJ/00P0mFJ/m0=bD
L0<000002`3LU7000`000000g9A`0=bDL00Q0=bDL0030000003LU700g9A`00H0g9A`0@3oool000L0
g9A`00<000000=bDL03LU700GP3LU7000`000000g9A`0=bDL00203eIZ`040=bDL00mFJ/0?EV[0=bD
L0@0?EV[103LU70203eIZ`050=bDL00mFJ/0?EV[0=bDL00mFJ/00`3LU70303eIZ`T0g9A`0P0mFJ/2
0=bDL180?EV[0`000?l0100O>f40003o03eIZ`000?l403MWX@030000o`12Nl80003o00D0AhG=00<0
003o04f>f01=S]P00P1=S]P30000o`D0G:Wn00<0003o06:do`1R]?l00`1R]?l00`000?l0JL3o06W0
o`0406W0o`030000o`1ac_l0LLko00<0LLko00<0003o07WNo`1ig_l00`1ig_l00`000?l0Po3o08?`
o`0308?`o`80003o1P2;nol00`000?l0U_oo09Koo`0309Koo`030000o`0mFJ/0VOoo0080VOoo00<0
003o03eIZ`0mFJ/00P0mFJ/20000o`@0?EV[0P3LU70603eIZ`030=bDL0000000g9A`00<0?EV[00<0
g9A`03eIZ`0mFJ/00P0mFJ/l0=bDL0<000003`3LU7000`000000g9A`0=bDL00P0=bDL0030000003L
U700g9A`00H0g9A`0@3oool000P0g9A`0P00001O0=bDL0040000000mFJ/0?EV[0=bDL0H0?EV[00@0
g9A`03eIZ`0mFJ/0g9A`0P0mFJ/00`3LU700?EV[03eIZ`040=bDL0@0?EV[2@3LU70203eIZ`P0g9A`
1@0mFJ/50=bDL00303eIZ`3LU700g9A`0080g9A`0P0mFJ/0100O>f40003o02eFR@000?l303MWX@04
0000o`12Nl80@W_20000o`D0AhG=00<0003o04f>f01=S]P00P000?l00`1FXO@0003o05bYoP0505bY
oP030000o`1R]?l0H[Co00@0H[Co00<0003o06W0o`1Y`?l00`1Y`?l00`000?l0LLko077>o`03077>
o`030000o`1ig_l0NMko00<0NMko00<0003o08?`o`23l?l01023l?l30000o`<0Ro_o00<0003o09Ko
o`2Fool00`2Fool00`000?l0WOoo0000o`0309Woo`040000o`2=ool0003o07OKo`80003o00<0g9A`
03eIZ`0mFJ/01@0mFJ/01P000000?EV[03eIZ`3LU70000000=bDL0P0?EV[>P3LU704000001<0g9A`
00<000000=bDL03LU7007`3LU7000`000000g9A`0=bDL0060=bDL040oooo000:0=bDL0030000003L
U700g9A`05`0g9A`00<0?EV[0000000mFJ/00`0mFJ/00`3LU700?EV[0=bDL0020=bDL00303eIZ`3L
U700?EV[00<0?EV[1@3LU70303eIZ`T0g9A`0P0mFJ/80=bDL0@0?EV[0`3LU70503eIZ`<0g9A`0P0m
FJ/00`000?l04B500000o`0302eFR@040000o`0gIj40=fNQ0000o`<0@W_200<0003o04N5c@17QLd0
0`17QLd20000o`@0EZ7d00<0003o05bYoP1LZOh00`1LZOh00`000?l0H[Co06:do`0406:do`030000
o`1Y`?l0JL3o00<0JL3o00<0003o077>o`1ac_l00`1ac_l00`000?l0NMko07WNo`0307WNo`030000
o`23l?l0Po3o00<0Po3o00@0003o08goo`2=ool0SOoo0P000?l00`2;nol0003o09Koo`0409Koo`03
0000o`2Mool0003o0080VOoo00<0003o08goo`2=ool01`0mFJ/0103LU700000003eIZ`3LU70203eI
Z`<000001`0mFJ/j0=bDL0<00000603LU7000`000000g9A`0=bDL00N0=bDL0030000003LU700g9A`
00H0g9A`0@3oool000/0g9A`00<000000=bDL03LU700FP3LU7001P0mFJ/0g9A`03eIZ`000000?EV[
0=bDL080?EV[0`3LU70403eIZ`040=bDL00mFJ/0?EV[03eIZ`80g9A`0`0mFJ/00`3LU700?EV[03eI
Z`060=bDL080?EV[203LU70403eIZ`L0g9A`00<0?EV[0=bDL00mFJ/0100mFJ/0103LU700003o014Q
@0000?l302eFR@030000o`0gIj40003o00D0@W_200L0003o04N5c@17QLd0AhG=0000o`1BVN`0003o
00@0EZ7d00<0003o05bYoP1LZOh00`1LZOh00`000?l0H[Co06:do`0406:do`040000o`1Y`?l0JL3o
06W0o`D0003o0P1ac_l00`000?l0NMko07WNo`0407WNo`030000o`23l?l0Po3o00<0Po3o00<0003o
08goo`2=ool00`2=ool00`000?l0U_oo09Koo`0309Koo`070000o`2Mool0WOoo09goo`000?l0VOoo
0000o`0308goo`040000o`0mFJ/00000000000<0?EV[00H0g9A`03eIZ`0mFJ/0g9A`03eIZ`000007
03eIZcT0g9A`0`00000K0=bDL0030000003LU700g9A`01h0g9A`00<000000=bDL03LU7001P3LU701
0?ooo`00303LU7000`000000g9A`0=bDL01H0=bDL0L0?EV[1@3LU70203eIZ`H0g9A`0`0mFJ/50=bD
L080?EV[0P3LU70203eIZ`P0g9A`0P0mFJ/00`3LU700?EV[0=bDL0070=bDL00303eIZ`3LU700g9A`
0080?EV[0`3LU70403eIZ`050000o`0]EXT0;EJ902eFR@000?l01P12Nl8010000?l0AhG=0000o`00
0?l205:Ik0030000o`1FXO@0EZ7d00<0EZ7d00<0003o05bYoP1LZOh00`1LZOh010000?l0H[Co06:d
o`1R]?l60000o`80L<oo00<0003o07KKo`1ffol01@000?l307WNo`030000o`23l?l0Po3o00<0Po3o
00<0003o08goo`2=ool00`2=ool00`000?l0Uooo0000o`0309Koo`030000o`2Mool0WOoo0080WOoo
0P000?l408goo`040000o`1CVlT0003o00000080g9A`2`0mFJ/3000003D0g9A`1000000O0=bDL003
0000003LU700g9A`01h0g9A`00<000000=bDL03LU7001@3LU7010?ooo`003@3LU702000005L0g9A`
100mFJ/0103LU700?EV[03eIZ`0000030=bDL0<0?EV[1P3LU70203eIZ`80g9A`100mFJ/30=bDL0D0
?EV[1@3LU70203eIZ`030=bDL00mFJ/0?EV[00L0g9A`0P0mFJ/00`3LU700?EV[03eIZ`070=bDL080
003o00@07SaT0000o`0]EXT0;EJ90P000?l6049k`P030000o`1BVN`0DYW/00<0DYW/00<0003o05JQ
m01FXO@00P1FXO@010000?l0G:Wn05bYoP1LZOh60000o`80J/Go00<0003o073?o`1`col00`1`col0
0`000?l0M]_o07KKo`0207KKo`030000o`1njOl0O^Wo00D0003o1023l?l00`000?l0SOoo08goo`03
08goo`030000o`2Gool0Uooo0080003o00<0U_oo0000o`2Mool0102Mool01@000?l0SOoo08goo`2=
ool0003o00P0?EV[0P00000503eIZ`80g9A`00@000000=bDL00000000000<@3LU703000002@0g9A`
00<000000=bDL03LU7007@3LU7000`000000g9A`0=bDL0050=bDL040oooo000?0=bDL0030000003L
U700g9A`05<0g9A`0`0mFJ/20=bDL080?EV[0P3LU70010000000?EV[03eIZ`0mFJ/20=bDL00403eI
Z`3LU700g9A`0=bDL080?EV[203LU70403eIZ`@0g9A`2P0mFJ/60=bDL00403eIZ`3LU700g9A`03eI
Z`80g9A`1`0mFJ/20000o`0401hlI0000?l0;EJ90000o`80>fna00<0003o049k`P12Nl800P12Nl80
0`000?l0CI7S0000o`0505:Ik0030000o`1FXO@0EZ7d0080EZ7d0`000?l206Blo`030000o`1ZaOl0
J/Go00<0J/Go00<0003o073?o`1`col00`1`col00`000?l0M]_o07KKo`0207KKo`030000o`1njOl0
O^Wo0080O^Wo00<0003o08Kio`26nOl00P000?l00`23l?l0003o08goo`0408goo`030000o`2Gool0
Uooo00<0Uooo00<0003o09goo`2Mool00`2Mool20000o`80SOoo00<0003o06O5o`000?l00`0mFJ/0
0`000000g9A`0=bDL00503eIZ`030=bDL000000000000080g9A`0P0000000`3LU70000000=bDL00]
0=bDL0<000009`3LU7000`000000g9A`0=bDL00M0=bDL0030000003LU700g9A`00D0g9A`0@3oool0
0100g9A`00<000000=bDL03LU700D@3LU70303eIZ`060=bDL00mFJ/0?EV[0=bDL00mFJ/0g9A`0`0m
FJ/40=bDL00303eIZ`3LU700?EV[0080?EV[203LU70203eIZ`<0g9A`1@0mFJ/00`3LU700?EV[03eI
Z`0203eIZ`@0g9A`300mFJ/50=bDL00403eIZ`3LU700g9A`0000o`807SaT0P000?l303]_/@040000
o`12Nl80@W_20000o`80CI7S00<0003o05:Ik01BVN`00`1BVN`00`000?l0EZ7d05JQm0020000o`03
062do`000?l0I;co00<0I;co00<0003o06[5o`1ZaOl00P1ZaOl00`000?l0L<oo073?o`02073?o`03
0000o`1ffol0M]_o00<0M]_o00<0003o07kYo`1njOl00P1njOl00`000?l0Q_Wo08Kio`0208Kio`80
003o102=ool00`000?l0Uooo09Ooo`0309Ooo`80003o102Mool00`000?l0VOoo0000o`0208goo`80
003o0P0mFJ/20=bDL0030000000mFJ/0?EV[0080?EV[00<000000=bDL00000000P3LU70200000080
g9A`00@000000=bDL00000000000:@3LU704000002/0g9A`00<000000=bDL03LU700703LU7000`00
0000g9A`0=bDL0050=bDL040oooo000A0=bDL0030000003LU700g9A`04l0g9A`0`0mFJ/0103LU700
?EV[0=bDL03LU70303eIZ`040=bDL00mFJ/0g9A`000000@0g9A`0`0mFJ/80=bDL080?EV[2@3LU708
03eIZ`D0g9A`0`0mFJ/90=bDL00503eIZ`3LU700?EV[03eIZ`000?l00`0N?6@00`000?l0>fna03]_
/@0203]_/@030000o`12Nl80003o00<0CI7S00<0003o05:Ik01BVN`00`1BVN`20000o`<0H;Co00<0
003o06Blo`1T_?l00P1T_?l00`000?l0J/Go06[5o`0306[5o`050000o`1`col0L<oo073?o`000?l0
101ffol00`000?l0O^Wo07kYo`0207kYo`030000o`26nOl0Q_Wo00<0Q_Wo00@0003o08koo`000?l0
003o0P2=ool00`000?l0Uooo09Ooo`0209Ooo`040000o`2Nool0W_oo0000o`80WOoo00@0003o09Wo
o`2Iool0VOoo0P000?l01@1WaOl0003o0000o`0mFJ/0000000@0?EV[00D000000=bDL0000000g9A`
000000030=bDL0030000003LU700g9A`0080000000<0g9A`0000003LU7009@3LU70300000300g9A`
00<000000=bDL03LU7006`3LU7000`000000g9A`0=bDL0050=bDL040oooo000B0=bDL0030000003L
U700g9A`04d0g9A`0`0mFJ/00`3LU700?EV[0=bDL00303eIZ`030=bDL00mFJ/0?EV[00<0g9A`0P00
000503eIZ`H0g9A`0P0mFJ/:0=bDL0<0?EV[1P3LU70F03eIZ`030000o`0N?6@07SaT0080003o100k
Kk400`000?l0CI7S04fAh`0304fAh`070000o`1BVN`0DYW/05:Ik0000?l0G:ko0000o`04062do`03
0000o`1T_?l0I;co0080I;co00<0003o06[5o`1ZaOl00P1ZaOl01@000?l0L<oo073?o`1`col0003o
00@0M]_o00<0003o07kYo`1njOl00P1njOl00`000?l0Q_Wo08Kio`0308Kio`040000o`2>ool0S_oo
08koo`80003o102Gool01`000?l0W_oo09koo`2Nool0003o09goo`000?l0102Iool01@000?l0IlGo
06O5o`000?l0000000<0?EV[0P3LU70010000000g9A`0000000000020=bDL0030000003LU700g9A`
008000000P3LU70400000280g9A`0`00000d0=bDL0030000003LU700g9A`01X0g9A`00<000000=bD
L03LU7001@3LU7010?ooo`004`3LU702000004`0g9A`0P0mFJ/00`3LU700?EV[03eIZ`020=bDL0D0
?EV[103LU70203eIZ`030000000mFJ/0g9A`0080g9A`0P0mFJ/20=bDL0<0?EV[2@3LU70303eIZ`X0
g9A`0`0mFJ/:0=bDL0<0?EV[103LU7020000o`0401hlI0000?l0<5bD0000o`80>fna00<0003o04R9
f0000?l0101=TN<010000?l0DYW/0000o`000?l205b^o`030000o`1P]?l0H;Co00<0H;Co00D0003o
06Blo`1T_?l0I;co0000o`0306[5o`P0003o0P1ffol01@000?l0O^Wo07kYo`1njOl0003o00D0Q_Wo
00<0003o08koo`2>ool00P2>ool00`000?l0UOoo0000o`0309Ooo`030000o`2Nool0W_oo0080W_oo
00<0003o09Woo`2Iool00P2Iool20000o`0706O5o`000?l0?EV[0000000mFJ/0g9A`000000030=bD
L0030000003LU70000000080g9A`00L000000=bDL03LU70000000=bDL0000000g9A`00@000007P3L
U704000003L0g9A`00<000000=bDL03LU7006P3LU7000`000000g9A`0=bDL0050=bDL040oooo000E
0=bDL0030000003LU700g9A`04P0g9A`0P0mFJ/20=bDL00403eIZ`3LU700?EV[03eIZ`80g9A`0P0m
FJ/00`3LU700?EV[03eIZ`0203eIZ`040=bDL00mFJ/0?EV[000000D0g9A`100mFJ/90=bDL0<0?EV[
2P3LU70203eIZ`/0g9A`200mFJ/01P000?l052Q90000o`000?l0<5bD0000o`80>fna00@0003o04R9
f018RMP0003o101=TN<00`000?l0G:ko05b^o`0305b^o`030000o`1P]?l0H;Co0080H;Co00@0003o
06Blo`1T_?l0I;co10000?l00`1be_l0003o07KOo`0207KOo`030000o`1ljOl0O>Wo00L0003o1026
nOl00`000?l0S_oo08koo`0208koo`070000o`2Eool0UOoo09Goo`000?l0Uooo0000o`0409koo`80
003o0`2Iool020000?l0OoOo0000o`1WaOl0003o0000003LU70000000P3LU7001@000000g9A`0=bD
L0000000g9A`008000000P3LU70010000000g9A`0000003LU703000000040=bDL000000000000000
01X0g9A`0`00000l0=bDL0030000003LU700g9A`01T0g9A`00<000000=bDL03LU7001@3LU7010?oo
o`005P3LU7000`000000g9A`0=bDL0170=bDL00303eIZ`3LU700g9A`00<0?EV[0`3LU700100mFJ/0
g9A`03eIZ`3LU70203eIZ`030=bDL00mFJ/0?EV[00@0?EV[103LU70203eIZ`80g9A`100mFJ/30=bD
L0<0?EV[2P3LU70303eIZ`@0g9A`2P0mFJ/20=bDL0H0?EV[00@052Q90000o`0`G9@0<5bD0P000?l4
04R9f0060000o`1=TN<0CI7S0000o`1HZ?l0003o1@1L[_l00`000?l0H;Co062do`02062do`<0003o
00<0KLoo0000o`1be_l00P1be_l01@000?l0M]oo07KOo`1fgol0003o00@0O>Wo00D0003o087co`21
lol0003o08Ooo`020000o`80Q_Wo00D0003o08koo`2>ool0S_oo0000o`0509Goo`030000o`2Nool0
W_oo0080W_oo00<0003o09goo`000?l00P2Iool00`000?l0OoOo07ogo`020000o`040000003LU700
g9A`000000<0g9A`00<000000=bDL03LU7000P0000001P3LU70000000=bDL0000000g9A`00000080
g9A`1P00000G0=bDL0<00000@03LU7000`000000g9A`0=bDL00I0=bDL0030000003LU700g9A`00@0
g9A`0@3oool001L0g9A`00<000000=bDL03LU700A@3LU70203eIZ`80g9A`00<0?EV[0=bDL03LU700
0P3LU7001@0mFJ/0g9A`0=bDL03LU700?EV[00<0g9A`00<0?EV[0=bDL03LU7000`3LU70903eIZ`<0
g9A`8`0mFJ/60=bDL0<0003o0P0`G9@00`000?l0B8WH04R9f00304R9f0030000o`1=TN<0003o0080
F:So00<0003o05b^o`1L[_l00P1L[_l00`000?l0H;Co062do`020000o`0306[9o`000?l0KLoo0080
KLoo00@0003o07;Fo`1be_l0003o0`1fgol01@000?l0O>Wo07cYo`1ljOl0003o00<0PO?o00@0003o
08Ooo`27ool0Qooo0`000?l208koo`030000o`2Eool0UOoo00<0UOoo00<0003o09_oo`000?l00P2N
ool010000?l0WOoo09goo`2Mool20000o`<0OoOo0P000?l01@3LU70000000=bDL03LU700000000<0
g9A`00@000000=bDL000000000000P3LU703000000040=bDL0000000g9A`0=bDL080000000@0g9A`
00000000000000004P3LU704000004<0g9A`00<000000=bDL03LU7006@3LU7000`000000g9A`0=bD
L0040=bDL040oooo000H0=bDL0800000A@3LU70203eIZ`030=bDL00mFJ/0?EV[00<0g9A`00<0?EV[
0=bDL03LU7000P0mFJ/0103LU700?EV[03eIZ`0mFJ/70=bDL00303eIZ`3LU700?EV[00D0g9A`6P0m
FJ/50=bDL00303eIZ`3LU700g9A`00L0g9A`100mFJ/0100D:4T0?EV[0000o`0`G9@30000o`@0B8WH
00<0003o05RXo`1HZ?l00P1HZ?l20000o`<0G:ko0P000?l306[9o`050000o`1]col0KLoo06g?o`00
0?l00`1be_l010000?l0M]oo07KOo`000?l307cYo`040000o`21lol0PO?o0000o`@0Qooo00<0003o
08goo`2=ool00P000?l509Goo`060000o`2Kool0Vooo0000o`2Nool0003o102Mool00`000?l0OoOo
07ogo`0207ogo`070000o`3LU700g9A`0=bDL0000000g9A`000000040=bDL0030000003LU7000000
00@0g9A`0`0000020=bDL0H000003`3LU703000004P0g9A`00<000000=bDL03LU700603LU7000`00
0000g9A`0=bDL0040=bDL040oooo000J0=bDL0030000003LU700g9A`0440g9A`00@0?EV[0=bDL00m
FJ/0?EV[0P3LU7001P0mFJ/0g9A`0=bDL00mFJ/0g9A`03eIZ`@0g9A`0`0mFJ/50=bDL00303eIZ`3L
U700?EV[00P0g9A`00<0?EV[0=bDL00mFJ/02`3LU70203eIZ``0g9A`00<0?EV[0=bDL03LU700103L
U70703eIZ`060=bDL0000?l0003o0000o`0`G9@0003o0P10O<D010000?l0B8WH04R9f018RMP30000
o`@0F:So00D0003o05b^o`000?l0IlCo0000o`0406[9o`040000o`1]col0KLoo0000o`<0L]Ko00@0
003o07KOo`1fgol0003o0`1ljOl010000?l0PO?o087co`000?l308Ooo`070000o`2=ool0SOoo08go
o`000?l0T_oo0000o`0309Goo`030000o`2Kool0Vooo0080Vooo00<0003o09goo`2Mool00P2Mool2
0000o`<0OoOo0P000?l40=bDL0030000003LU700000000@0g9A`0`0000040=bDL08000000`3LU700
0`000000g9A`00000002000000`0g9A`0`00001<0=bDL0030000003LU700g9A`01L0g9A`00<00000
0=bDL03LU700103LU7010?ooo`006`3LU7000`000000g9A`0=bDL0100=bDL0<0?EV[0`3LU7001@0m
FJ/0g9A`03eIZ`3LU700?EV[00D0g9A`00<0?EV[0=bDL03LU7000P0mFJ/01`3LU700?EV[03eIZ`3L
U700?EV[0=bDL00000001P3LU7000`0mFJ/0g9A`03eIZ`0;0=bDL080?EV[303LU70203eIZ`030=bD
L00mFJ/0?EV[00@0?EV[103LU70503eIZ`<0003o0`10O<D30000o`<0EJ;n00<0003o05RXo`1HZ?l0
0P1HZ?l01@000?l0IlCo06O4o`1Wa?l0003o00@0J/Wo00@0003o06g?o`1]col0003o0P1be_l00`00
0?l0M]oo0000o`020000o`0507cYo`000?l0PO?o087co`000?l01027ool010000?l0SOoo08goo`00
0?l309;oo`030000o`2Eool0003o00<0Vooo0`000?l209goo`80003o00<0Sooo0000o`1omol00`00
0?l2000000@0g9A`0P0000050=bDL08000001@3LU70010000000g9A`0=bDL03LU704000000030=bD
L0000000g9A`00H0g9A`1000001@0=bDL0030000003LU700g9A`01H0g9A`00<000000=bDL03LU700
103LU7010?ooo`00703LU7000`000000g9A`0=bDL00o0=bDL0D0?EV[0P3LU70303eIZ`D0g9A`00<0
?EV[0=bDL03LU7000`3LU70503eIZ`80g9A`00@000000=bDL03LU700g9A`0P0mFJ/00`3LU700?EV[
0=bDL00:0=bDL00303eIZ`3LU700g9A`00D0g9A`2P0mFJ/60=bDL0@0?EV[0P3LU7001P0mFJ/0g9A`
03eIZ`000?l084=]0000o`D0@7c500<0003o05FRoP1EX_h00P1EX_h20000o`0305RXo`000?l0I<3o
0080003o0P1Wa?l01@000?l0J/Wo06[9o`1ZbOl0003o0080KLoo1@000?l00`1lk_l0003o07odo`06
0000o`80Qooo00@0003o08goo`2=ool0003o1@2Bool01@000?l0Vooo09_oo`2Kool0003o00<0W?oo
0P000?l308ooo`80003o00<0G;?/0000o`000?l00P0000040=bDL0030000003LU700000000<0g9A`
00@000000=bDL00000000000103LU70200000080g9A`0P000000103LU70000000000000000040=bD
L0<00000E03LU7000`000000g9A`0=bDL00F0=bDL0030000003LU700g9A`00@0g9A`0@3oool001d0
g9A`0P00000o0=bDL080?EV[0`3LU70503eIZ`@0g9A`00<0?EV[0=bDL03LU7000P3LU70203eIZ`80
g9A`00<0?EV[0=bDL03LU700300mFJ/20=bDL180?EV[0P3LU70203eIZ`D0g9A`100mFJ/50=bDL0@0
?EV[00<0g9A`0000o`0P@fd00P000?l3041la@<0003o101EX_h00`000?l0I<3o06C0o`0206C0o`04
0000o`1Wa?l0IlCo0000o`80J/Wo0`000?l0101fhol0003o07WXo`000?l207c^o`040000o`1om?l0
OoCo0000o`80Po_o0P27ool20000o`80SOoo00<0003o09;oo`2Bool00P2Bool30000o`0309_oo`00
0?l0003o00@0W?oo00<0003o08ooo`2?ool00P2?ool01@000?l0G;?/05bck0000?l0g9A`00H00000
00<0g9A`0000000000000`3LU70010000000g9A`0=bDL00000030=bDL0D0000000@0g9A`0000003L
U700g9A`0P000000103LU700000000000000001H0=bDL0030000003LU700g9A`01D0g9A`00<00000
0=bDL03LU700103LU7010?ooo`007`3LU7000`000000g9A`0=bDL00k0=bDL0@0?EV[0`3LU7000`0m
FJ/0g9A`0=bDL00Y03eIZ`X0g9A`0P0mFJ/00`3LU700?EV[03eIZ`0203eIZ`D0g9A`2@0mFJ/30000
o`0503EXY@000?l0003o041la@000?l00P1@V_8010000?l0EJ;n05FRoP1EX_h30000o`<0I<3o0P00
0?l00`1Wa?l0003o0000o`0207CNo`030000o`1fhol0003o0080NNSo00<0003o07c^o`000?l00P1o
m?l00`000?l0Po_o0000o`0208Ooo`040000o`2:ool0003o0000o`@0T_oo00D0003o09Koo`2Fool0
U_oo0000o`0409coo`<0003o0P2?ool20000o`0305bck0000?l0003o00@0g9A`00@000000=bDL03L
U700g9A`3@0000001P3LU70000000000003LU70000000=bDL0H00000G03LU7000`000000g9A`0=bD
L00E0=bDL0030000003LU700g9A`00<0g9A`0@3oool00200g9A`00<000000=bDL03LU700>P3LU700
100mFJ/0g9A`03eIZ`0mFJ/20=bDL00303eIZ`3LU700g9A`00<0g9A`0`0mFJ/00`3LU700?EV[03eI
Z`050=bDL00303eIZ`3LU700g9A`00@0g9A`00D0?EV[0=bDL0000000g9A`03eIZ`0:0=bDL080?EV[
2`3LU70603eIZ`D0g9A`1`0mFJ/0103LU700?EV[03eIZ`0mFJ/30=bDL0030000o`0J=5T0003o0080
=FRU0P000?l3052JlP<0003o0`1R_?l00`000?l0I<3o06C0o`0206C0o`040000o`1afol0003o0000
o`80M=ko00/0003o07KSo`000?l0NNSo0000o`1lk_l0003o07odo`000?l0Po_o0000o`0208Ooo`07
0000o`2:ool0R_oo0000o`2=ool0003o09;oo`020000o`80U_oo0`000?l209coo`80003o0P2Fool3
0000o`0507;Ro`000?l0003o0000o`0000001@3LU7000`000000g9A`0=bDL0030=bDL0030000003L
U700000000@0g9A`00@000000=bDL03LU70000000P3LU7000`000000g9A`00000002000000040=bD
L00000000000000005`0g9A`00<000000=bDL03LU7005@3LU7000`000000g9A`0=bDL0030=bDL040
oooo000Q0=bDL0030000003LU700g9A`03T0g9A`0P0mFJ/20=bDL0<0?EV[1P3LU70503eIZ`@0g9A`
00<0?EV[0=bDL03LU7000`3LU70203eIZ`<0g9A`00<0?EV[0=bDL03LU700203LU7000`0mFJ/0g9A`
03eIZ`030=bDL0P0?EV[0P3LU70203eIZ`030=bDL00mFJ/0?EV[00D0?EV[103LU70303eIZ`040=bD
L00mFJ/0g9A`0=bDL080?EV[00<0g9A`0000o`0J=5T00P000?l0100eJ:D0003o0000o`000?l3052J
lP80003o0`1R_?l20000o`0306C0o`000?l0L=So0080003o00H0LM_o0000o`1dg_l0003o07KSo`00
0?l207WXo`80003o00P0OoCo0000o`23nol0003o08Ooo`000?l0R_oo0000o`@0SOoo00<0003o09Ko
o`2Fool00P000?l309Ooo`80003o102Fool020000?l0L^;o07;Ro`000?l0BI2n0000o`3LU7000000
1@3LU7000`000000g9A`0=bDL0030=bDL08000001P3LU70010000000g9A`0000003LU70300000003
0=bDL000000000000080g9A`0`00001L0=bDL0030000003LU700g9A`01@0g9A`00<000000=bDL03L
U7000`3LU7010?ooo`008P3LU7000`000000g9A`0=bDL00i0=bDL00603eIZ`3LU700g9A`03eIZ`3L
U700?EV[1P3LU70203eIZ`<0g9A`1P0mFJ/30=bDL00303eIZ`3LU700g9A`00<0g9A`00<0?EV[0000
000000001`3LU70703eIZ`D0g9A`2P0mFJ/60=bDL0<0?EV[103LU70703eIZ`80003o00D09e:20000
o`0eJ:D0003o04V=gP020000o`03052JlP000?l0GkOo00@0003o00<0H[co0000o`000?l00`1`f?l0
0`000?l0LM_o0000o`020000o`0307KSo`000?l0003o00D0003o00@0Qooo0000o`000?l0003o0P2=
ool20000o`80S_oo0P000?l209Ooo`80003o00<0U?oo0000o`2Fool00P2Fool20000o`0507;Ro`00
0?l0003o04V@_P000?l0100000050=bDL0030000003LU700g9A`0080000000<0g9A`000000000000
1@3LU704000000030=bDL0000000g9A`0080g9A`0P000000103LU70000000=bDL000001M0=bDL003
0000003LU700g9A`01<0g9A`00<000000=bDL03LU7000`3LU7010?ooo`008`3LU702000003T0g9A`
1P0mFJ/60=bDL00303eIZ`3LU700g9A`00H0g9A`00<0?EV[0=bDL00mFJ/02@0mFJ/20=bDL0L0?EV[
0`3LU70>03eIZ`<0g9A`0P0mFJ/30=bDL0<0?EV[103LU70603eIZ`030=bDL00mFJ/0?EV[0080g9A`
0P000?l202MBPP040000o`19SMh0BHgN04V=gP<0003o101O]ol50000o`80L=So0P000?l0101afol0
003o0000o`1mlol50000o`0308?oo`000?l0003o0080SOoo0P000?l01P2>ool0003o0000o`2?ool0
003o09Ooo`80003o0`2Dool01@000?l0U_oo0000o`000?l0QOoo00<0003o00H0BI2n0000o`000000
g9A`0000003LU70300000080g9A`100000040=bDL0030000003LU700g9A`00<0000000<0g9A`0000
000000000`3LU7000`000000g9A`0=bDL002000000040=bDL00000000000000005h0g9A`00<00000
0=bDL03LU7004P3LU7000`000000g9A`0=bDL0030=bDL040oooo000U0=bDL0030000003LU700g9A`
03L0g9A`1`0mFJ/30=bDL080?EV[1`3LU7001P0mFJ/0g9A`0=bDL03LU700?EV[0=bDL1<0?EV[00@0
g9A`03eIZ`3LU700g9A`1@0mFJ/30=bDL00303eIZ`3LU700g9A`00@0g9A`2P0mFJ/30=bDL00503eI
Z`3LU700?EV[03eIZ`3LU7001@0mFJ/00`000?l09e:202MBPP020000o`80BHgN00<0003o05^ao`00
0?l00`000?l00`1O]ol0003o06cCo`040000o`80L=So20000?l00`23ool0003o0000o`030000o`03
08koo`000?l0003o00<0Sooo0P000?l509Coo`80003o0P25ool00`000?l0F:_V05R[iP020000o`80
g9A`2@0000000`3LU7000000000000040=bDL0<00000103LU7000`000000g9A`000000020=bDL003
0000003LU700g9A`0080000000<0g9A`0000000000000P00001M0=bDL0030000003LU700g9A`0180
g9A`00<000000=bDL03LU7000`3LU7010?ooo`009P3LU7000`000000g9A`0=bDL00f0=bDL080?EV[
0P3LU7000`0mFJ/0g9A`0=bDL00B03eIZ`D0g9A`00<0?EV[0=bDL03LU7000`3LU7000`000000g9A`
03eIZ`040=bDL0D0?EV[1`3LU700100mFJ/0g9A`0=bDL03LU70703eIZ`030=bDL00mFJ/0?EV[00d0
?EV[00<0g9A`03eIZ`0mFJ/00P3LU7030000o`0503ml`@000?l0003o04V=gP000?l0101K/Ol50000
o`80K=?o5@000?l00`2>ool0003o09Coo`050000o`0408Goo`000?l0003o0000o`80F:_V00@0003o
0=bDL000000000000`3LU70010000000g9A`0=bDL00000030=bDL0L0000000<0g9A`000000000000
103LU70010000000g9A`0=bDL00000020=bDL0040000003LU70000000=bDL0<0000000<0g9A`0000
003LU700G@3LU7000`000000g9A`0=bDL00A0=bDL0030000003LU700g9A`00<0g9A`0@3oool002L0
g9A`00<000000=bDL03LU700=P3LU70403eIZ`@0g9A`1P0mFJ/40=bDL00403eIZ`3LU700g9A`03eI
Z`P0g9A`00<0?EV[0=bDL03LU7000`3LU7000`0mFJ/0g9A`03eIZ`0303eIZ`<0g9A`00<0?EV[0=bD
L03LU7000P3LU70803eIZ`H0g9A`0`0mFJ/40=bDL0H0?EV[0`3LU70203eIZ`@0g9A`00<0?EV[0000
o`000?l00P000?l00`0oO<40003o0000o`020000o`<0Fk7o00@0003o06_@o`1[d?l0Jm3o4`000?l5
08koo`80003o102<ool20000o`80KM[o0`000?l20=bDL0060000003LU70000000000003LU7000000
0P3LU70010000000g9A`0=bDL03LU707000000040=bDL0000000g9A`00000080g9A`00<000000=bD
L00000000P3LU70010000000g9A`0000000000020=bDL0D00000G`3LU7000`000000g9A`0=bDL00@
0=bDL0030000003LU700g9A`00<0g9A`0@3oool002P0g9A`0P00000f0=bDL080?EV[00<0g9A`03eI
Z`0mFJ/00`3LU7000`0mFJ/0g9A`03eIZ`030=bDL0h0?EV[0P3LU700100mFJ/0g9A`0=bDL03LU704
03eIZ`80g9A`3`0mFJ/50=bDL0`0?EV[0P3LU700100mFJ/0g9A`0=bDL03LU70803eIZ`80g9A`00<0
003o0297L@000?l010000?l00`1FZ?l0003o0000o`0P0000o`80Oooo00<0003o06gJo`000?l01000
0?l200000080g9A`00<000000=bDL03LU7000P0000030=bDL0<0000000D0g9A`0000003LU700g9A`
000000020=bDL0@000000P3LU7000`000000g9A`000000020=bDL0040000003LU700000000000080
g9A`1@00001O0=bDL0030000003LU700g9A`0140g9A`00<000000=bDL03LU7000P3LU7010?ooo`00
:P3LU7000`000000g9A`0=bDL00d0=bDL080?EV[00<0g9A`03eIZ`0mFJ/00P0mFJ/20=bDL00303eI
Z`3LU700g9A`00H0g9A`0P0mFJ/50=bDL0h0?EV[1P3LU70603eIZ`030=bDL00mFJ/0g9A`0080g9A`
1`0mFJ/30=bDL080?EV[0P3LU70:03eIZ`@0g9A`100mFJ/30000o`80=FbT3P000?l00`1hkOl0003o
0000o`0;0000o`<0Q_oo00@0003o07ooo`1oool0Oooo1@000?l00`1H[nh0003o0000o`0200000080
g9A`00<000000=bDL00000000`3LU705000000<0g9A`00D000000=bDL03LU700g9A`000000030=bD
L0030000003LU700000000<0000000L0g9A`0000003LU700g9A`0000003LU700000000<0g9A`1@00
001O0=bDL0030000003LU700g9A`0100g9A`00<000000=bDL03LU7000P3LU7010?ooo`00:`3LU700
0`000000g9A`0=bDL00e0=bDL0L0?EV[00<0g9A`03eIZ`3LU7000`3LU70:03eIZ`L0g9A`0`0mFJ/3
0=bDL0030000000mFJ/0?EV[00@0?EV[0`3LU70L03eIZ`80g9A`2P0mFJ/20=bDL0@0003o00<0=FbT
0000o`1@WO000`1@WO0010000?l0Il_o06O;o`1Wbol40000o`80NNko00<0003o07[bo`000?l00P00
0?l00`1nn_l0003o0000o`020000o`03083oo`000?l0003o00L0003o0P1H[nh30000o`80g9A`0`00
00000`3LU700000000000003000000<0g9A`0`0000030=bDL0040000003LU700g9A`000000<0g9A`
00@000000=bDL000000000000P3LU70?00000600g9A`00<000000=bDL03LU7003`3LU7000`000000
g9A`0=bDL0020=bDL040oooo000/0=bDL0030000003LU700g9A`03H0g9A`2`0mFJ/30=bDL00403eI
Z`3LU700?EV[03eIZ`/0g9A`3`0mFJ/00`3LU700?EV[03eIZ`0203eIZ`L0g9A`600mFJ/80=bDL0`0
003o00@0I/Wo0000o`000?l0ILOo20000?l0101biOl0003o0000o`1il_l=0000o`030=bDL0000000
g9A`0080g9A`200000050=bDL08000000P3LU7001@000000g9A`0=bDL03LU70000000080g9A`0P00
00020=bDL0040000003LU700g9A`000000@0g9A`00@000000=bDL03LU700g9A`1@00001Q0=bDL003
0000003LU700g9A`00h0g9A`00<000000=bDL03LU7000P3LU7010?ooo`00;@3LU7000`000000g9A`
0=bDL00g0=bDL0@0?EV[00<0g9A`03eIZ`0mFJ/00P3LU70J03eIZ`@0g9A`100mFJ/30=bDL00403eI
Z`3LU700g9A`0=bDL1P0?EV[3P3LU7050000o`<0BY;L0`000?l206G7o`<0003o00@0I/_o0000o`1X
d?l0003o0P1]fOl00`000?l0L^Go07;Uo`030000o`<0H/Co0P000?l204^FcP80003o00@000000=bD
L03LU700g9A`1P0000020=bDL0H000000`3LU704000000030=bDL0000000000000@000000`3LU700
10000000g9A`0=bDL00000030=bDL0<000000P3LU702000000030=bDL000000000000640g9A`00<0
00000=bDL03LU7003P3LU7000`000000g9A`0=bDL0020=bDL040oooo000^0=bDL0800000>P3LU707
03eIZ`80g9A`00<0?EV[0=bDL03LU7001`0mFJ/50=bDL00303eIZ`3LU700g9A`00D0g9A`800mFJ/H
0=bDL0D0003o0`16Rlh>0000o`<0EZca1`000?l20=bDL0H00000103LU7001@000000g9A`0=bDL000
0000g9A`0080000000<0g9A`0000000000001P0000030=bDL0040000003LU700g9A`000000<0g9A`
00<000000=bDL00000000`3LU7000`000000g9A`000000020=bDL080000000<0g9A`000000000000
HP3LU7000`000000g9A`0=bDL00=0=bDL0030000003LU700g9A`0080g9A`0@3oool00300g9A`00<0
00000=bDL03LU700?03LU70N03eIZ`H0g9A`400mFJ/Q0=bDL0H0003o0`14R<L010000?l0AH_804F;
b0000?l304RAc`040000o`1>Vm`0CY_L04jKg0H0003o0P0000020=bDL0H0000000<0g9A`00000000
0000103LU70010000000g9A`0000000000020=bDL0030000003LU700g9A`0080g9A`00@000000=bD
L0000000g9A`0P0000020=bDL0030000003LU700000000@0g9A`0P0000020=bDL0030000003LU700
g9A`0080000000@0g9A`000000000000g9A`0`00001R0=bDL0030000003LU700g9A`00`0g9A`00<0
00000=bDL03LU7000P3LU7010?ooo`00<@3LU7000`000000g9A`0=bDL0100=bDL0X0?EV[0P3LU70H
03eIZc00g9A`4@000?l010000000g9A`0=bDL03LU707000000<0g9A`1@0000040=bDL0030000003L
U700000000<0g9A`0P0000030=bDL08000000`3LU703000000030=bDL0000000g9A`00@0g9A`0`00
00030=bDL0030000003LU70000000080000000@0g9A`0000003LU7000000HP3LU7000`000000g9A`
0=bDL00=0=bDL0040000003LU700g9A`0=bDL040oooo000b0=bDL0030000003LU700g9A`04D0g9A`
5@0mFJ/o0=bDL08000000P3LU703000000<0g9A`0P0000020=bDL0D000000P3LU704000000040=bD
L000000000000=bDL0D0000000@0g9A`0000000000000000103LU70010000000g9A`0=bDL0000007
0=bDL0<00000103LU703000000<0g9A`00<000000=bDL00000000P000000103LU700000000000000
001S0=bDL0030000003LU700g9A`00`0g9A`00@000000=bDL03LU700g9A`0@3oool003<0g9A`0P00
001J0=bDL0030000003LU700g9A`03d0g9A`0`0000020=bDL0<000000P3LU703000000050=bDL000
0000g9A`0000003LU7000P0000020=bDL0030000003LU700000000P000000`3LU7000`000000g9A`
0=bDL0030=bDL0<000001`3LU702000000030=bDL000000000000080000000<0g9A`0000003LU700
0`3LU7000`000000g9A`0=bDL002000000040=bDL00000000000000006@0g9A`00<000000=bDL03L
U7002`3LU70010000000g9A`0=bDL03LU7010?ooo`00=@3LU7000`000000g9A`0=bDL01H0=bDL003
0000003LU700g9A`03d0g9A`100000000`3LU700000000000003000000040=bDL000000000000000
0080g9A`00<000000=bDL03LU7000`0000030=bDL08000000`3LU7000`000000g9A`000000020000
00030=bDL0000000000000D0g9A`0P0000070=bDL0030000003LU700g9A`0080g9A`100000040=bD
L0<0000000<0g9A`0000000000000P00001U0=bDL0030000003LU700g9A`00X0g9A`00@000000=bD
L03LU700g9A`0@3oool003H0g9A`00<000000=bDL03LU700F03LU7000`000000g9A`0=bDL00n0=bD
L0@000000P3LU70300000080g9A`100000040=bDL08000000`3LU702000000<0g9A`00@000000=bD
L03LU700g9A`100000030=bDL0030000003LU7000000008000001@3LU7000`000000g9A`0=bDL002
00000080g9A`00<000000=bDL00000000P000000103LU70000000=bDL03LU704000006H0g9A`00<0
00000=bDL03LU7002P3LU70010000000g9A`0=bDL03LU7010?ooo`00=`3LU7000`000000g9A`0=bD
L01H0=bDL0030000003LU700g9A`03X0g9A`0`0000020=bDL0<000000`3LU702000000030=bDL000
0000000000@00000103LU702000000040=bDL0000000g9A`000000<0g9A`00D000000=bDL03LU700
g9A`000000020=bDL0@000000P3LU7001@000000g9A`000000000000g9A`00D00000103LU7000`00
0000g9A`000000020=bDL0H0000000<0g9A`0000003LU700IP3LU7000`000000g9A`0=bDL0090=bD
L0040000003LU700g9A`0=bDL040oooo000h0=bDL0030000003LU700g9A`05P0g9A`00<000000=bD
L03LU700=@3LU704000000H0g9A`100000000`3LU700000000000003000000030=bDL00000000000
00<000000`3LU704000000030=bDL0000000g9A`0080g9A`0P0000020=bDL0060000003LU700g9A`
0=bDL0000000g9A`20000000103LU70000000=bDL00000040=bDL0050000003LU700g9A`0000003L
U7000P0000030=bDL0030000003LU700000006P0g9A`00<000000=bDL03LU700203LU70010000000
g9A`0=bDL03LU7010?ooo`00>@3LU702000005T0g9A`00<000000=bDL03LU700<@3LU703000000`0
g9A`1@0000000`3LU7000000000000030=bDL080000000<0g9A`0000000000000P0000000`3LU700
00000=bDL003000000@0g9A`00<000000=bDL00000000P3LU7001P000000g9A`000000000000g9A`
000000D0g9A`0P0000000`3LU70000000=bDL0020=bDL0030000003LU700g9A`0080g9A`00<00000
0=bDL00000000P3LU702000000030=bDL0000000g9A`06L0g9A`00<000000=bDL03LU700203LU700
10000000g9A`0=bDL03LU7010?ooo`00>`3LU7000`000000g9A`0=bDL01G0=bDL0030000003LU700
g9A`02d0g9A`0`00000@0=bDL0H0000000<0g9A`0000000000000P3LU70300000080g9A`1@000002
0=bDL0<000000P3LU704000000@0g9A`00<000000=bDL0000000103LU7000`000000g9A`00000002
00000080g9A`00<000000=bDL03LU7000`000000103LU70000000=bDL03LU703000006X0g9A`00<0
00000=bDL03LU700203LU7000`000000g9A`0=bDL0010?ooo`00?03LU7000`000000g9A`0=bDL01G
0=bDL0030000003LU700g9A`02P0g9A`1000000E0=bDL0@000000`3LU70300000080g9A`0P000002
0=bDL080000000<0g9A`000000000000200000060=bDL08000000`3LU7000`000000g9A`0=bDL002
0=bDL080000000@0g9A`0000003LU70000000`3LU7000`000000g9A`0=bDL002000000030=bDL000
0000g9A`06X0g9A`00<000000=bDL03LU7001`3LU7000`000000g9A`0=bDL0010?ooo`00?@3LU700
0`000000g9A`0=bDL01G0=bDL0030000003LU700g9A`02@0g9A`0`00000K0=bDL0@000000`3LU703
00000080g9A`100000050=bDL0040000003LU700g9A`0=bDL0@000001P3LU702000000030=bDL000
0000g9A`00@0g9A`100000040=bDL0070000003LU70000000=bDL0000000g9A`0000001/0=bDL003
0000003LU700g9A`00H0g9A`00<000000=bDL03LU7000@3oool003h0g9A`0P00001H0=bDL0030000
003LU700g9A`0200g9A`0`00000P0=bDL0@000000`3LU70300000080g9A`0`0000050=bDL0060000
003LU700g9A`0=bDL0000000g9A`1P000000103LU70000000=bDL00000030=bDL0D000000P3LU703
000000030=bDL000000000000080000000<0g9A`000000000000K03LU7000`000000g9A`0=bDL006
0=bDL0030000003LU700g9A`0040oooo00100=bDL0030000003LU700g9A`05H0g9A`00<000000=bD
L03LU7006`3LU704000002D0g9A`100000000`3LU70000000=bDL003000000030=bDL00000000000
00<000000P3LU7001@000000g9A`0=bDL03LU70000000080g9A`00<000000=bDL03LU7000P3LU707
000000@0g9A`00<000000=bDL03LU7000`3LU703000000030=bDL0000000g9A`00800000K@3LU700
0`000000g9A`0=bDL0050=bDL0030000003LU700g9A`0040oooo00110=bDL0030000003LU700g9A`
05H0g9A`0P00000H0=bDL0<00000:`3LU70500000080g9A`100000030=bDL0@000000`3LU7000`00
0000g9A`0=bDL002000000050=bDL000000000000=bDL00000000`3LU7001`000000g9A`0=bDL03L
U70000000=bDL0000000103LU707000006l0g9A`00<000000=bDL03LU700103LU7000`000000g9A`
0=bDL0010?ooo`00@P3LU7000`000000g9A`0=bDL01G0=bDL0030000003LU700g9A`0180g9A`0`00
000`0=bDL0D000000P3LU70600000080g9A`0`0000000`3LU70000000=bDL004000000@0g9A`00@0
00000=bDL03LU700g9A`0P000000103LU70000000=bDL00000030=bDL0030000003LU700g9A`00<0
000000<0g9A`0000003LU700KP3LU7000`000000g9A`0=bDL0040=bDL0030000003LU700g9A`0040
oooo00130=bDL0030000003LU700g9A`05L0g9A`00<000000=bDL03LU7003@3LU704000003D0g9A`
1P0000001@3LU7000000000000000000g9A`00h000000P3LU7000`000000g9A`0=bDL0030=bDL080
00000P3LU70400000080g9A`1000001a0=bDL0030000003LU700g9A`00@0g9A`0@0000010=bDL040
oooo00140=bDL0800000F03LU7000`000000g9A`0=bDL0090=bDL0<00000>`3LU70<00000080g9A`
0P0000050=bDL0l0000000<0g9A`0000003LU7000P3LU703000007<0g9A`00<000000=bDL03LU700
0`3LU70100000040g9A`0@3oool004H0g9A`00<000000=bDL03LU700EP3LU7000`000000g9A`0=bD
L0050=bDL0<00000@03LU70?000000L0g9A`1@0000060=bDL0<000000P3LU704000007@0g9A`00<0
00000=bDL03LU7000P3LU70100000040g9A`0@3oool004L0g9A`00<000000=bDL03LU700EP3LU700
0`000000g9A`0=bDL004000004D0g9A`3`0000040=bDL0@000001`3LU703000000030=bDL0000000
000000<00000M@3LU7000`000000g9A`0=bDL0020=bDL04000000@3LU7010?ooo`00B03LU7000`00
0000g9A`0=bDL01F0=bDL0800000C03LU708000000030=bDL0000000000000L000000P3LU7000`00
0000g9A`0=bDL0020=bDL0T00000N03LU7001P000000g9A`0=bDL03LU70000000=bDL040oooo0019
0=bDL0800000EP3LU7000`000000g9A`0=bDL01>0=bDL0/00000103LU70800000080g9A`1000001k
0=bDL0050000003LU700g9A`0000003LU7000@3oool004/0g9A`00<000000=bDL03LU700D`3LU700
0`000000g9A`0=bDL01A0=bDL1P00000O@3LU7001@000000g9A`0=bDL0000000g9A`0040oooo001<
0=bDL0030000003LU700g9A`0580g9A`00<000000=bDL03LU700F03LU70?00000800g9A`00@00000
0=bDL0000000g9A`0@3oool004d0g9A`00<000000=bDL03LU700D@3LU7000`000000g9A`0=bDL03X
0=bDL0030000003LU70000000040oooo001>0=bDL0030000003LU700g9A`0500g9A`00<000000=bD
L03LU700j@3LU70200000040oooo001?0=bDL0800000D03LU7000`000000g9A`0=bDL03Y0=bDL080
00000@3oool00540g9A`00<000000=bDL03LU700C@3LU7000`000000g9A`0=bDL03Y0=bDL0800000
0@3oool00580g9A`00<000000=bDL03LU700C03LU7000`000000g9A`0=bDL03U0=bDL0@000000P3L
U7010?ooo`00D`3LU7000`000000g9A`0=bDL01;0=bDL0030000003LU700g9A`0>40g9A`10000006
0=bDL040oooo001D0=bDL0800000B`3LU7000`000000g9A`0=bDL03M0=bDL0@000002P3LU7010?oo
o`00EP3LU7000`000000g9A`0=bDL0180=bDL0030000003LU700g9A`0=T0g9A`1000000>0=bDL040
oooo001G0=bDL0030000003LU700g9A`04H0g9A`00<000000=bDL03LU700e`3LU70300000180g9A`
0@3oool005P0g9A`00<000000=bDL03LU700A@3LU7000`000000g9A`0=bDL03C0=bDL0@000005@3L
U7010?ooo`00F@3LU702000004D0g9A`00<000000=bDL03LU700c`3LU704000001T0g9A`0@3oool0
05/0g9A`00<000000=bDL03LU700@P3LU7000`000000g9A`0=bDL03;0=bDL0@000007@3LU7010?oo
o`00G03LU7000`000000g9A`0=bDL0110=bDL0030000003LU700g9A`0<L0g9A`1000000Q0=bDL040
oooo001M0=bDL0030000003LU700g9A`0400g9A`00<000000=bDL03LU700a03LU703000002D0g9A`
0@3oool005h0g9A`00<000000=bDL03LU700?`3LU7000`000000g9A`0=bDL0300=bDL0@00000:03L
U7010?ooo`00G`3LU702000003l0g9A`00<000000=bDL03LU700_03LU704000002`0g9A`0@3oool0
0640g9A`00<000000=bDL03LU700?03LU7000`000000g9A`0=bDL02h0=bDL0@00000<03LU7010?oo
o`00HP3LU7000`000000g9A`0=bDL00k0=bDL0030000003LU700g9A`0;@0g9A`1000000d0=bDL040
oooo001S0=bDL0030000003LU700g9A`03X0g9A`00<000000=bDL03LU700/03LU704000003P0g9A`
0@3oool006@0g9A`0P00000j0=bDL0030000003LU700g9A`0:d0g9A`0`00000l0=bDL040oooo001V
0=bDL0030000003LU700g9A`03L0g9A`00<000000=bDL03LU700Z@3LU704000003l0g9A`0@3oool0
06L0g9A`00<000000=bDL03LU700=P3LU7000`000000g9A`0=bDL02U0=bDL0@00000@`3LU7010?oo
o`00J03LU7000`000000g9A`0=bDL00e0=bDL0030000003LU700g9A`0:40g9A`100000170=bDL040
oooo001Y0=bDL0030000003LU700g9A`03@0g9A`00<000000=bDL03LU700W@3LU704000004/0g9A`
0@3oool006X0g9A`0P00000d0=bDL0030000003LU700g9A`09X0g9A`0`00001?0=bDL040oooo001/
0=bDL0030000003LU700g9A`0340g9A`00<000000=bDL03LU700UP3LU70400000580g9A`0@3oool0
06d0g9A`00<000000=bDL03LU700<03LU7000`000000g9A`0=bDL02B0=bDL0@00000EP3LU7010?oo
o`00KP3LU7000`000000g9A`0=bDL00_0=bDL0030000003LU700g9A`08h0g9A`1000001J0=bDL040
oooo001_0=bDL0800000;`3LU7000`000000g9A`0=bDL02:0=bDL0@00000GP3LU7010?ooo`00L@3L
U7000`000000g9A`0=bDL00/0=bDL0030000003LU700g9A`08L0g9A`0`00001R0=bDL040oooo001b
0=bDL0030000003LU700g9A`02/0g9A`00<000000=bDL03LU700P`3LU704000006D0g9A`0@3oool0
07<0g9A`00<000000=bDL03LU700:@3LU7000`000000g9A`0=bDL0200=bDL0@00000J@3LU7010?oo
o`00M03LU7000`000000g9A`0=bDL00X0=bDL0030000003LU700g9A`07`0g9A`1000001]0=bDL040
oooo001e0=bDL0800000:03LU7000`000000g9A`0=bDL01h0=bDL0@00000L@3LU7010?ooo`00M`3L
U7000`000000g9A`0=bDL00U0=bDL0030000003LU700g9A`07D0g9A`0`00001e0=bDL040oooo001h
0=bDL0030000003LU700g9A`02@0g9A`00<000000=bDL03LU700L@3LU704000007P0g9A`0@3oool0
07T0g9A`00<000000=bDL03LU7008`3LU7000`000000g9A`0=bDL01]0=bDL0@00000O03LU7010?oo
o`00NP3LU702000002<0g9A`00<000000=bDL03LU700J@3LU70400000800g9A`0@3oool007`0g9A`
00<000000=bDL03LU700803LU7000`000000g9A`0=bDL01U0=bDL0@00000Q03LU7010?ooo`00O@3L
U7000`000000g9A`0=bDL00O0=bDL0030000003LU700g9A`0640g9A`100000280=bDL040oooo001n
0=bDL0030000003LU700g9A`01h0g9A`00<000000=bDL03LU700GP3LU703000008`0g9A`0@3oool0
07l0g9A`00<000000=bDL03LU7007@3LU7000`000000g9A`0=bDL01J0=bDL0@00000S`3LU7010?oo
o`00P03LU702000001d0g9A`00<000000=bDL03LU700EP3LU704000009<0g9A`0@3oool00880g9A`
00<000000=bDL03LU7006P3LU7000`000000g9A`0=bDL01B0=bDL0@00000U`3LU7010?ooo`00P`3L
U7000`000000g9A`0=bDL00I0=bDL0030000003LU700g9A`04h0g9A`1000002K0=bDL040oooo0024
0=bDL0030000003LU700g9A`01P0g9A`00<000000=bDL03LU700B`3LU703000009l0g9A`0@3oool0
08D0g9A`0P00000H0=bDL0030000003LU700g9A`04L0g9A`1000002R0=bDL040oooo00270=bDL003
0000003LU700g9A`01D0g9A`00<000000=bDL03LU700@`3LU70400000:H0g9A`0@3oool008P0g9A`
00<000000=bDL03LU700503LU7000`000000g9A`0=bDL00o0=bDL0@00000ZP3LU7010?ooo`00R@3L
U7000`000000g9A`0=bDL00C0=bDL0030000003LU700g9A`03/0g9A`1000002^0=bDL040oooo002:
0=bDL08000004`3LU7000`000000g9A`0=bDL00h0=bDL0<00000/P3LU7010?ooo`00S03LU7000`00
0000g9A`0=bDL00@0=bDL0030000003LU700g9A`03@0g9A`1000002e0=bDL040oooo002=0=bDL003
0000003LU700g9A`00l0g9A`00<000000=bDL03LU700<03LU70400000;T0g9A`0@3oool008h0g9A`
00<000000=bDL03LU7003P3LU7000`000000g9A`0=bDL00/0=bDL0@00000_@3LU7010?ooo`00S`3L
U7000`000000g9A`0=bDL00=0=bDL0030000003LU700g9A`02P0g9A`100000310=bDL040oooo002@
0=bDL0800000303LU7000`000000g9A`0=bDL00V0=bDL0<00000a@3LU7010?ooo`00TP3LU7000`00
0000g9A`0=bDL0090=bDL0030000003LU700g9A`0280g9A`100000380=bDL040oooo002C0=bDL003
0000003LU700g9A`00P0g9A`00<000000=bDL03LU7007P3LU70400000<`0g9A`0@3oool009@0g9A`
00<000000=bDL03LU7001`3LU7000`000000g9A`0=bDL00J0=bDL0@00000d03LU7010?ooo`00U@3L
U702000000L0g9A`00<000000=bDL03LU7005P3LU70400000=@0g9A`0@3oool009L0g9A`00<00000
0=bDL03LU700103LU7000`000000g9A`0=bDL00B0=bDL0@00000f03LU7010?ooo`00V03LU7000`00
0000g9A`0=bDL0030=bDL0030000003LU700g9A`00l0g9A`0`00003L0=bDL040oooo002I0=bDL003
0000003LU700g9A`0080g9A`00<000000=bDL03LU7002`3LU70400000=l0g9A`0@3oool009X0g9A`
00D000000=bDL03LU700g9A`000000090=bDL0@00000h`3LU7010?ooo`00V`3LU702000000030=bD
L0000000g9A`00@0g9A`1000003W0=bDL040oooo002M0=bDL080000000<0g9A`0000000000000P00
003[0=bDL040oooo002N0=bDL0800000k`3LU7010?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {310.25, 0}} -> {-0.000391438, 0.0801287, \
0.00239006, 0.00239006}}]
}, Open  ]],

Cell[BoxData[
    \(Clear[gsphere, gsphere2]\)], "Input",
  CellLabel->"In[4]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->{},
WindowSize->{494, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 61, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1840, 56, 571, 22, 50, "Usage",
      CellTags->"Function?"],
    Cell[2581, 85, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 296354, 15330}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 61, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1840, 56, 571, 22, 50, "Usage",
  CellTags->"Function?"],
Cell[2414, 80, 164, 3, 58, "MathCaption"],
Cell[2581, 85, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2678, 90, 115, 3, 58, "MathCaption"],
Cell[2796, 95, 596, 22, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3417, 121, 33, 0, 39, "ExampleSection"],
Cell[3453, 123, 99, 2, 29, "Input"],
Cell[3555, 127, 247, 4, 59, "Text"],
Cell[3805, 133, 186, 4, 49, "Input"],

Cell[CellGroupData[{
Cell[4016, 141, 654, 12, 229, "Input"],
Cell[4673, 155, 290906, 15149, 318, 194906, 13960, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[295594, 15307, 81, 2, 29, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

