(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4819,        157]*)
(*NotebookOutlinePosition[      5790,        191]*)
(*  CellTagsIndexPosition[      5716,        185]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["UseTranslateShape", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["UseTranslateShape",
            "MR"], 
          StyleBox["[",
            "MR"], 
          StyleBox[\({x, y, z}\),
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["g",
          "MR"], 
        StyleBox["]",
          "MR"]}]]],
  " will translate the primitive graphics object g by the specified vector."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
UseTranslateShape implements the TranslateShape function directly on \
primitive graphics.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["UseAffineShape",
    ButtonData:>{"UseAffineShape"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["UseRotateShape",
    ButtonData:>{"UseRotateShape"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["UseWireFrame",
    ButtonData:>{"UseWireFrame"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DrawingTransform3D",
    ButtonData:>{"DrawingTransform3D"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["TranslateShape",
    ButtonData:>{"Graphics`Shapes`", "1.12"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Here, a sphere centered at the origin is stretched in the x and y directions \
and squeezed in the z direction (Cobalt), then rotated about the z axis by 90\
\[Degree](DarkGreen), then translated in the z direction by 2 units (Black). \
The transformations are rendered as wireframes.\
\>", "Text"],

Cell[BoxData[
    \(\(gsphere = 
        SphericalDraw3D[1, {\[Theta], 0, \[Pi]}, {\[Phi], 0, 2  \[Pi]}, 
          PlotPoints \[Rule] {21, 31}];\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(Draw3DItems[\[IndentingNewLine]{{EdgeForm[Blue], 
            SurfaceColor[SteelBlue, SteelBlue, 3], 
            gsphere}, \[IndentingNewLine]Cobalt, \[IndentingNewLine]gsphere2 \
= \(gsphere // UseAffineShape[{3, 1, 1/2}]\) // 
              UseWireFrame, \[IndentingNewLine]DarkGreen, \
\[IndentingNewLine]gsphere3 = 
            gsphere2 // 
              UseRotateShape[0, 0, 90  \[Degree]], \[IndentingNewLine]Black, 
          gsphere3 // 
            UseTranslateShape[{0, 0, 2}]}, \[IndentingNewLine]NeutralLighting[
          0.3, 0.6, 0], \[IndentingNewLine]Background \[Rule] 
          YellowBrown, \[IndentingNewLine]BoxStyle \[Rule] 
          Black, \[IndentingNewLine]ViewPoint -> {1.886, \ \(-2.634\), \ 
            0.975}, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(Clear[gsphere, gsphere2, gsphere3]\)], "Input",
  CellLabel->"In[4]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{494, 740},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 64, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1843, 56, 532, 21, 50, "Usage",
      CellTags->"Function?"],
    Cell[2378, 79, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5470, 174}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 64, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1843, 56, 532, 21, 50, "Usage",
  CellTags->"Function?"],
Cell[2378, 79, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2475, 84, 121, 3, 58, "MathCaption"],
Cell[2599, 89, 593, 22, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3217, 115, 33, 0, 39, "ExampleSection"],
Cell[3253, 117, 97, 2, 29, "Input"],
Cell[3353, 121, 308, 5, 59, "Text"],
Cell[3664, 128, 184, 4, 49, "Input"],
Cell[3851, 134, 846, 15, 289, "Input"],
Cell[4700, 151, 91, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

