(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    100693,       3373]*)
(*NotebookOutlinePosition[    101667,       3407]*)
(*  CellTagsIndexPosition[    101590,       3401]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["XTickLine", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["XTickLine",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\({xmin, xmax, yloc}, {rangemin, rangemax}, {labelstart, 
            labelend, increment}, subdivisions, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " \nwill draw a horizontal labeled line with tick marks"
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
xmin, xmax and yloc control the actual placement of the line in the graphics.\
\
\>", "MathCaption"],

Cell["\<\
rangemin and rangemax specify what number range this line is meant to \
signify.\
\>", "MathCaption"],

Cell["\<\
labelstart, labelend and increment specify the values and spacing for the \
major tick marks.\
\>", "MathCaption"],

Cell["\<\
subdivisions gives the number of subdivisions between the major tick marks. \
The number of unlabeled tick marks will be one less than the number of \
subdivisions.\
\>", "MathCaption"],

Cell["\<\
The options are XLabTickSpecs, XUnLabTickSpecs and XTextSpecs.\
\>", "MathCaption"],

Cell[TextData[{
  "XLabTickSpecs specifies the details for the labeled tick lines. It can \
take the form ",
  Cell[BoxData[
      \({plen, mlen, {style\ directives}}\)]],
  " where the last item is optional. plen and mlen are as in the regular ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  ButtonBox["Ticks",
    ButtonStyle->"RefGuideLink"],
  " specification. The default value is ",
  Cell[BoxData[
      \(\((0.00625, 0)\)\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "XUnLabTickSpecs specifies the details for the minor unlabeled tick lines. \
It can take the form ",
  Cell[BoxData[
      \({plen, mlen, {style\ directives}}\)]],
  " where the last item is optional. plen and mlen are as in the regular ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  ButtonBox["Ticks",
    ButtonStyle->"RefGuideLink"],
  " specification. The default value is ",
  Cell[BoxData[
      \(\((0.00375, 0)\)\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "XTextSpecs specifies the placement and style for the label values. It \
takes the form ",
  Cell[BoxData[
      \({offset, direction, displacement, options ... }\)]],
  ". offset and direction are as in the regular ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  " statement. displacement is the ",
  ButtonBox["Scaled",
    ButtonStyle->"RefGuideLink"],
  " displacement of the label from the line. Options can be used to pass ",
  ButtonBox["StyleForm",
    ButtonStyle->"RefGuideLink"],
  "  type options for the label. The default value is ",
  Cell[BoxData[
      \({{0, 1}, {1, 0}, 0.002}\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["YTickLine",
    ButtonData:>{"YTickLine"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CustomTicks",
    ButtonData:>{"CustomTicks"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["Ticks",
    ButtonStyle->"RefGuideLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input",
  CellLabel->"In[331]:="],

Cell["\<\
The following puts horizontal and vertical scales next to an ellipse.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{LightSteelBlue, 
          Disk[{0, 0}, {2, 1}], \[IndentingNewLine]Black, 
          Circle[{0, 0}, {2, 1}], \[IndentingNewLine]XTickLine[{\(-2\), 
              2, \(-1.3\)}, {0, 10}, {0, 10, 1}, 
            5], \[IndentingNewLine]YTickLine[{\(-1\), 1, 2.5}, {0, 5}, {0, 5, 
              1}, 5], \[IndentingNewLine]Text["\<mm.\>", {\(-0.00542015\), \
\(-1.54438\)}], \[IndentingNewLine]Text["\<mm.\>", {2.85, 
              0.0157696}]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]PlotRange \[Rule] {{\(-2.5\), 
              3.2}, {\(-2\), 1.5}}, \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)], "Input",
  CellLabel->"In[332]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61404 
%%ImageSize: 400 245.614 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.438596 0.175439 0.350877 0.175439 [
[ 0 0 0 0 ]
[ 1 .61404 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61404 L
0 .61404 L
closepath
clip
newpath
.69 .769 .871 r
.4386 .35088 m
matrix currentmatrix
0.350877 0.175439 scale
1.25001 2.00002 1 0 365.73 arc
setmatrix F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.350877 0.175439 scale
1.25001 2.00002 1 0 365.73 arc
setmatrix s
.08772 .12281 m
.78947 .12281 L
s
.08772 .12281 m
.08772 .12511 L
s
.08772 .12281 m
.08772 .12281 L
s
.10175 .12281 m
.10175 .12511 L
s
.10175 .12281 m
.10175 .12281 L
s
.11579 .12281 m
.11579 .12511 L
s
.11579 .12281 m
.11579 .12281 L
s
.12982 .12281 m
.12982 .12511 L
s
.12982 .12281 m
.12982 .12281 L
s
.14386 .12281 m
.14386 .12511 L
s
.14386 .12281 m
.14386 .12281 L
s
.15789 .12281 m
.15789 .12511 L
s
.15789 .12281 m
.15789 .12281 L
s
.17193 .12281 m
.17193 .12511 L
s
.17193 .12281 m
.17193 .12281 L
s
.18596 .12281 m
.18596 .12511 L
s
.18596 .12281 m
.18596 .12281 L
s
.2 .12281 m
.2 .12511 L
s
.2 .12281 m
.2 .12281 L
s
.21404 .12281 m
.21404 .12511 L
s
.21404 .12281 m
.21404 .12281 L
s
.22807 .12281 m
.22807 .12511 L
s
.22807 .12281 m
.22807 .12281 L
s
.24211 .12281 m
.24211 .12511 L
s
.24211 .12281 m
.24211 .12281 L
s
.25614 .12281 m
.25614 .12511 L
s
.25614 .12281 m
.25614 .12281 L
s
.27018 .12281 m
.27018 .12511 L
s
.27018 .12281 m
.27018 .12281 L
s
.28421 .12281 m
.28421 .12511 L
s
.28421 .12281 m
.28421 .12281 L
s
.29825 .12281 m
.29825 .12511 L
s
.29825 .12281 m
.29825 .12281 L
s
.31228 .12281 m
.31228 .12511 L
s
.31228 .12281 m
.31228 .12281 L
s
.32632 .12281 m
.32632 .12511 L
s
.32632 .12281 m
.32632 .12281 L
s
.34035 .12281 m
.34035 .12511 L
s
.34035 .12281 m
.34035 .12281 L
s
.35439 .12281 m
.35439 .12511 L
s
.35439 .12281 m
.35439 .12281 L
s
.36842 .12281 m
.36842 .12511 L
s
.36842 .12281 m
.36842 .12281 L
s
.38246 .12281 m
.38246 .12511 L
s
.38246 .12281 m
.38246 .12281 L
s
.39649 .12281 m
.39649 .12511 L
s
.39649 .12281 m
.39649 .12281 L
s
.41053 .12281 m
.41053 .12511 L
s
.41053 .12281 m
.41053 .12281 L
s
.42456 .12281 m
.42456 .12511 L
s
.42456 .12281 m
.42456 .12281 L
s
.4386 .12281 m
.4386 .12511 L
s
.4386 .12281 m
.4386 .12281 L
s
.45263 .12281 m
.45263 .12511 L
s
.45263 .12281 m
.45263 .12281 L
s
.46667 .12281 m
.46667 .12511 L
s
.46667 .12281 m
.46667 .12281 L
s
.4807 .12281 m
.4807 .12511 L
s
.4807 .12281 m
.4807 .12281 L
s
.49474 .12281 m
.49474 .12511 L
s
.49474 .12281 m
.49474 .12281 L
s
.50877 .12281 m
.50877 .12511 L
s
.50877 .12281 m
.50877 .12281 L
s
.52281 .12281 m
.52281 .12511 L
s
.52281 .12281 m
.52281 .12281 L
s
.53684 .12281 m
.53684 .12511 L
s
.53684 .12281 m
.53684 .12281 L
s
.55088 .12281 m
.55088 .12511 L
s
.55088 .12281 m
.55088 .12281 L
s
.56491 .12281 m
.56491 .12511 L
s
.56491 .12281 m
.56491 .12281 L
s
.57895 .12281 m
.57895 .12511 L
s
.57895 .12281 m
.57895 .12281 L
s
.59298 .12281 m
.59298 .12511 L
s
.59298 .12281 m
.59298 .12281 L
s
.60702 .12281 m
.60702 .12511 L
s
.60702 .12281 m
.60702 .12281 L
s
.62105 .12281 m
.62105 .12511 L
s
.62105 .12281 m
.62105 .12281 L
s
.63509 .12281 m
.63509 .12511 L
s
.63509 .12281 m
.63509 .12281 L
s
.64912 .12281 m
.64912 .12511 L
s
.64912 .12281 m
.64912 .12281 L
s
.66316 .12281 m
.66316 .12511 L
s
.66316 .12281 m
.66316 .12281 L
s
.67719 .12281 m
.67719 .12511 L
s
.67719 .12281 m
.67719 .12281 L
s
.69123 .12281 m
.69123 .12511 L
s
.69123 .12281 m
.69123 .12281 L
s
.70526 .12281 m
.70526 .12511 L
s
.70526 .12281 m
.70526 .12281 L
s
.7193 .12281 m
.7193 .12511 L
s
.7193 .12281 m
.7193 .12281 L
s
.73333 .12281 m
.73333 .12511 L
s
.73333 .12281 m
.73333 .12281 L
s
.74737 .12281 m
.74737 .12511 L
s
.74737 .12281 m
.74737 .12281 L
s
.7614 .12281 m
.7614 .12511 L
s
.7614 .12281 m
.7614 .12281 L
s
.77544 .12281 m
.77544 .12511 L
s
.77544 .12281 m
.77544 .12281 L
s
.78947 .12281 m
.78947 .12511 L
s
.78947 .12281 m
.78947 .12281 L
s
.08772 .12281 m
.08772 .12664 L
s
.08772 .12281 m
.08772 .12281 L
s
gsave
.08772 .12158 -66 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.15789 .12281 m
.15789 .12664 L
s
.15789 .12281 m
.15789 .12281 L
s
gsave
.15789 .12158 -66 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22807 .12281 m
.22807 .12664 L
s
.22807 .12281 m
.22807 .12281 L
s
gsave
.22807 .12158 -66 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.29825 .12281 m
.29825 .12664 L
s
.29825 .12281 m
.29825 .12281 L
s
gsave
.29825 .12158 -66 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.36842 .12281 m
.36842 .12664 L
s
.36842 .12281 m
.36842 .12281 L
s
gsave
.36842 .12158 -66 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.4386 .12281 m
.4386 .12664 L
s
.4386 .12281 m
.4386 .12281 L
s
gsave
.4386 .12158 -66 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.50877 .12281 m
.50877 .12664 L
s
.50877 .12281 m
.50877 .12281 L
s
gsave
.50877 .12158 -66 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.57895 .12281 m
.57895 .12664 L
s
.57895 .12281 m
.57895 .12281 L
s
gsave
.57895 .12158 -66 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.64912 .12281 m
.64912 .12664 L
s
.64912 .12281 m
.64912 .12281 L
s
gsave
.64912 .12158 -66 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.7193 .12281 m
.7193 .12664 L
s
.7193 .12281 m
.7193 .12281 L
s
gsave
.7193 .12158 -66 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.78947 .12281 m
.78947 .12664 L
s
.78947 .12281 m
.78947 .12281 L
s
gsave
.78947 .12158 -69 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.87719 .17544 m
.87719 .52632 L
s
.87719 .17544 m
.88094 .17544 L
s
.87719 .17544 m
.87719 .17544 L
s
.87719 .18947 m
.88094 .18947 L
s
.87719 .18947 m
.87719 .18947 L
s
.87719 .20351 m
.88094 .20351 L
s
.87719 .20351 m
.87719 .20351 L
s
.87719 .21754 m
.88094 .21754 L
s
.87719 .21754 m
.87719 .21754 L
s
.87719 .23158 m
.88094 .23158 L
s
.87719 .23158 m
.87719 .23158 L
s
.87719 .24561 m
.88094 .24561 L
s
.87719 .24561 m
.87719 .24561 L
s
.87719 .25965 m
.88094 .25965 L
s
.87719 .25965 m
.87719 .25965 L
s
.87719 .27368 m
.88094 .27368 L
s
.87719 .27368 m
.87719 .27368 L
s
.87719 .28772 m
.88094 .28772 L
s
.87719 .28772 m
.87719 .28772 L
s
.87719 .30175 m
.88094 .30175 L
s
.87719 .30175 m
.87719 .30175 L
s
.87719 .31579 m
.88094 .31579 L
s
.87719 .31579 m
.87719 .31579 L
s
.87719 .32982 m
.88094 .32982 L
s
.87719 .32982 m
.87719 .32982 L
s
.87719 .34386 m
.88094 .34386 L
s
.87719 .34386 m
.87719 .34386 L
s
.87719 .35789 m
.88094 .35789 L
s
.87719 .35789 m
.87719 .35789 L
s
.87719 .37193 m
.88094 .37193 L
s
.87719 .37193 m
.87719 .37193 L
s
.87719 .38596 m
.88094 .38596 L
s
.87719 .38596 m
.87719 .38596 L
s
.87719 .4 m
.88094 .4 L
s
.87719 .4 m
.87719 .4 L
s
.87719 .41404 m
.88094 .41404 L
s
.87719 .41404 m
.87719 .41404 L
s
.87719 .42807 m
.88094 .42807 L
s
.87719 .42807 m
.87719 .42807 L
s
.87719 .44211 m
.88094 .44211 L
s
.87719 .44211 m
.87719 .44211 L
s
.87719 .45614 m
.88094 .45614 L
s
.87719 .45614 m
.87719 .45614 L
s
.87719 .47018 m
.88094 .47018 L
s
.87719 .47018 m
.87719 .47018 L
s
.87719 .48421 m
.88094 .48421 L
s
.87719 .48421 m
.87719 .48421 L
s
.87719 .49825 m
.88094 .49825 L
s
.87719 .49825 m
.87719 .49825 L
s
.87719 .51228 m
.88094 .51228 L
s
.87719 .51228 m
.87719 .51228 L
s
.87719 .52632 m
.88094 .52632 L
s
.87719 .52632 m
.87719 .52632 L
s
.87719 .17544 m
.88344 .17544 L
s
.87719 .17544 m
.87719 .17544 L
s
gsave
.87519 .17544 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.87719 .24561 m
.88344 .24561 L
s
.87719 .24561 m
.87719 .24561 L
s
gsave
.87519 .24561 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.87719 .31579 m
.88344 .31579 L
s
.87719 .31579 m
.87719 .31579 L
s
gsave
.87519 .31579 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.87719 .38596 m
.88344 .38596 L
s
.87719 .38596 m
.87719 .38596 L
s
gsave
.87519 .38596 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.87719 .45614 m
.88344 .45614 L
s
.87719 .45614 m
.87719 .45614 L
s
gsave
.87519 .45614 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.87719 .52632 m
.88344 .52632 L
s
.87719 .52632 m
.87719 .52632 L
s
gsave
.87519 .52632 -71 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
gsave
.43765 .07993 -72 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
81.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.9386 .35364 -72 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
81.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[332]:=",
  ImageSize->{400, 245.563},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mB000`400?l00000o`00003oo`3jl>J@
0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo
003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00
n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool0
0?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03j
l>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00
o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`
iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o
0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V
0@3oool00?l0n_3VT03jl>H10?ooo`00Y@3jl>H2000000030?[`iP000000n_3V00<0000000@0n_3V
0000003jl>H000000P3jl>H200000=X0n_3V0@3oool00:H0n_3V00/000000?[`iP000000n_3V0000
003jl>H000000?[`iP000000n_3V0000003N0?[`iP40oooo002V0?[`iP0;0000003jl>H000000?[`
iP000000n_3V0000003jl>H000000?[`iP000000gP3jl>H10?ooo`00Y@3jl>H3000000030?[`iP00
0000n_3V00<0000000<0n_3V0000003jl>H0gP3jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`
iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3o
ool00?l0n_3VT03jl>H10?ooo`008P3jl>H2000001T0n_3V1@00000G0?[`iP@000006@3jl>H20000
01/0n_3V0`00000H0?[`iP800000603jl>H3000001/0n_3V00<000000?[`iP3jl>H0603jl>H20000
01T0n_3V0`00000F0?[`iPD000000P3jl>H200000540n_3V0@3oool00240n_3V00@000000?[`iP3j
l>H000006P3jl>H00`000000n_3V0?[`iP0G0?[`iP030000003jl>H0n_3V01T0n_3V00@000000?[`
iP3jl>H000006`3jl>H00`000000n_3V0?[`iP0F0?[`iP040000003jl>H0n_3V000001L0n_3V00@0
00000?[`iP3jl>H000006P3jl>H00`000000n_3V0?[`iP0G0?[`iP040000003jl>H0n_3V000001X0
n_3V00<000000?[`iP3jl>H05P3jl>H01@000000n_3V0?[`iP3jl>H000000080n_3V00<000000?[`
iP3jl>H0CP3jl>H10?ooo`008@3jl>H010000000n_3V0?[`iP00000J0?[`iP030000003jl>H0n_3V
01P0n_3V00<000000?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP0G0?[`iPD000006P3jl>H00`00
0000n_3V0?[`iP0E0?[`iP040000003jl>H0n_3V000001X0n_3V00<000000?[`iP3jl>H05`3jl>H0
10000000n_3V0?[`iP00000I0?[`iP<000005`3jl>H01@000000n_3V0?[`iP3jl>H000000080n_3V
00<000000?[`iP3jl>H0CP3jl>H10?ooo`008@3jl>H010000000n_3V0?[`iP00000J0?[`iP030000
003jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06P3jl>H00`000000n_3V0?[`iP0F0?[`iP040000
003jl>H0n_3V000001T0n_3V0P00000H0?[`iP<00000703jl>H00`000000n_3V0?[`iP0G0?[`iP80
00006@3jl>H010000000n_3V0?[`iP00000G0?[`iP050000003jl>H0n_3V0?[`iP0000000P3jl>H0
0`000000n_3V0?[`iP1>0?[`iP40oooo000Q0?[`iP040000003jl>H0n_3V000001X0n_3V00<00000
0?[`iP3jl>H05`3jl>H010000000n_3V0?[`iP00000H0?[`iP040000003jl>H0n_3V000001T0n_3V
00<000000?[`iP0000006@3jl>H00`000000n_3V0?[`iP0H0?[`iP030000003jl>H0n_3V01P0n_3V
00@000000?[`iP3jl>H00000603jl>H010000000n_3V0?[`iP00000H0?[`iP040000003jl>H0n_3V
000001L0n_3V00D000000?[`iP3jl>H0n_3V000000020?[`iP030000003jl>H0n_3V04h0n_3V0@3o
ool00280n_3V0P00000J0?[`iP8000006P3jl>H2000001X0n_3V0P00000K0?[`iP8000006@3jl>H3
000001P0n_3V0`00000H0?[`iP@000006@3jl>H2000001X0n_3V0`00000F0?[`iP800000103jl>H2
00000540n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V
0@3oool002<0n_3Vo`00000J000005<0n_3V0@3oool002<0n_3V00<000000?[`iP3jl>H00P3jl>H0
0`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H0
0`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H0
0`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H0
0`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H0
0`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H0
0`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H0
0`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H0
0`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00`3jl>H0
0`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H0
0`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H0
0`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H0
0`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00`3jl>H0
0`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H0
0`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V00<0n_3V00<000000?[`iP3jl>H00P3jl>H0
0`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H0
0`000000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H00`3jl>H0
0`000000n_3V0?[`iP020?[`iP030000003jl>H0n_3V0580n_3V0@3oool00?l0n_3VT03jl>H10?oo
o`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@
0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo
003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00
n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool0
0?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iUL0n_3V0P00000g0?[`iP40oooo
003o0?[`iUH0n_3V00@000000?[`iP3jl>H00000=P3jl>H10?ooo`00V`3jl>HX00000980n_3V00@0
00000?[`iP3jl>H00000103jl>H4000002h0n_3V0@3oool00940n_3V2P00000X0;34gPX00000R03j
l>H010000000n_3V0?[`iP0000040?[`iP030000003jl>H0n_3V02l0n_3V0@3oool008T0n_3V2000
000l0;34gPP00000P03jl>H010000000n_3V0?[`iP0000040?[`iP030000003jl>H0n_3V02l0n_3V
0@3oool00880n_3V1`00001<0;34gPL00000NP3jl>H2000000D0n_3V00<000000?[`iP3jl>H0;`3j
l>H10?ooo`00O@3jl>H5000005X0/<CN1@00001l0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool0
07P0n_3V1@00001T0;34gPD00000M`3jl>H3000002l0n_3V0@3oool007@0n_3V1000001^0;34gPD0
0000LP3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo001`0?[`iP@00000M`2`a=h3000006l0n_3V
00<000000?[`iP3jl>H0;`3jl>H10?ooo`00J`3jl>H5000007h0/<CN1000001[0?[`iP030000003j
l>H0n_3V02l0n_3V0@3oool006P0n_3V0`0000270;34gP@00000I`3jl>H00`000000n_3V0?[`iP0_
0?[`iP40oooo001U0?[`iP<00000SP2`a=h3000006@0n_3V00<000000?[`iP3jl>H0;`3jl>H10?oo
o`00HP3jl>H3000009@0/<CN0`00001Q0?[`iP<00000;`3jl>H10?ooo`00G`3jl>H3000009X0/<CN
0`00001N0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool005`0n_3V0`00002P0;34gP<00000F`3j
l>H00`000000n_3V0?[`iP0_0?[`iP40oooo001I0?[`iP<00000YP2`a=h3000005P0n_3V00<00000
0?[`iP3jl>H0;`3jl>H10?ooo`00E`3jl>H200000:`0/<CN0P00001F0?[`iP030000003jl>H0n_3V
02l0n_3V0@3oool005@0n_3V0`00002`0;34gP<00000D`3jl>H00`000000n_3V0?[`iP0_0?[`iP40
oooo001B0?[`iP800000]P2`a=h300000500n_3V0`00000_0?[`iP40oooo001@0?[`iP800000^`2`
a=h2000004h0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00CP3jl>H200000;l0/<CN00<00000
0?[`iP3jl>H0B`3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo001=0?[`iP030000002`a=h0/<CN
0<00/<CN0P00001;0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool004X0n_3V0`0000350;34gP80
0000B@3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo00180?[`iP800000bP2`a=h2000004L0n_3V
0`00000_0?[`iP40oooo00160?[`iP800000cP2`a=h2000004D0n_3V00<000000?[`iP3jl>H0;`3j
l>H10?ooo`00A@3jl>H00`000000/<CN0;34gP3@0;34gP800000@`3jl>H00`000000n_3V0?[`iP0_
0?[`iP40oooo00130?[`iP800000e@2`a=h00`000000n_3V0?[`iP100?[`iP030000003jl>H0n_3V
02l0n_3V0@3oool00440n_3V0P00003H0;34gP800000>03jl>H5000000<0n_3V00<000000?[`iP3j
l>H0;`3jl>H10?ooo`00?`3jl>H200000=`0/<CN00<000000?[`iP3jl>H0=`3jl>H00`000000n_3V
0?[`iP030?[`iP030000003jl>H0n_3V02l0n_3V0@3oool003h0n_3V00<000000;34gP2`a=h0g@2`
a=h00`000000n_3V0?[`iP0f0?[`iP030000003jl>H0n_3V00<0n_3V1000000^0?[`iP40oooo000m
0?[`iP030000002`a=h0/<CN0=l0/<CN0P00000f0?[`iP030000003jl>H0n_3V00<0n_3V00<00000
0?[`iP3jl>H0;`3jl>H10?ooo`00>`3jl>H200000>@0/<CN0P00000d0?[`iP030000003jl>H0n_3V
00<0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00>P3jl>H00`000000/<CN0;34gP3V0;34gP03
0000003jl>H0n_3V0300n_3V0P0000050?[`iP030000003jl>H0n_3V02l0n_3V0@3oool003T0n_3V
00<000000;34gP2`a=h0j02`a=h00`000000n_3V0?[`iP0f0?[`iP030000003jl>H0n_3V02l0n_3V
0@3oool003L0n_3V0P00003/0;34gP800000=P3jl>H3000002l0n_3V0@3oool003H0n_3V00<00000
0;34gP2`a=h0kP2`a=h00`000000n_3V0?[`iP0c0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool0
03H0n_3V00<000000;34gP2`a=h0k`2`a=h00`000000n_3V0?[`iP0b0?[`iP030000003jl>H0n_3V
02l0n_3V0@3oool003@0n_3V0P00003c0;34gP030000003jl>H0n_3V0340n_3V00<000000?[`iP3j
l>H0;`3jl>H10?ooo`00<`3jl>H00`000000/<CN0;34gP3d0;34gP030000003jl>H0n_3V0300n_3V
00<000000?[`iP3jl>H0;`3jl>H10?ooo`00<P3jl>H00`000000/<CN0;34gP3f0;34gP030000003j
l>H0n_3V02l0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00<@3jl>H00`000000/<CN0;34gP3h
0;34gP030000003jl>H0n_3V02h0n_3V0`00000_0?[`iP40oooo000`0?[`iP030000002`a=h0/<CN
0?X0/<CN00<000000?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000_0?[`iP03
0000002`a=h0/<CN0?`0/<CN00<000000?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0_0?[`iP40
oooo000^0?[`iP030000002`a=h0/<CN0?d0/<CN00<000000?[`iP3jl>H0;03jl>H00`000000n_3V
0?[`iP0_0?[`iP40oooo000^0?[`iP030000002`a=h0/<CN0?h0/<CN00<000000?[`iP3jl>H0:`3j
l>H00`000000n_3V0?[`iP0_0?[`iP40oooo000/0?[`iP800000o`2`a=h30;34gP800000:`3jl>H0
0`000000n_3V0?[`iP0_0?[`iP40oooo000[0?[`iP030000002`a=h0/<CN0?l0/<CN102`a=h00`00
0000n_3V0?[`iP0Y0?[`iP<00000;`3jl>H10?ooo`00:`3jl>H00`000000/<CN0;34gP3o0;34gPD0
/<CN00<000000?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000Z0?[`iP030000
002`a=h0/<CN0?l0/<CN1`2`a=h00`000000n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V02l0n_3V
0@3oool002T0n_3V00<000000;34gP2`a=h0o`2`a=h80;34gP030000003jl>H0n_3V02L0n_3V00<0
00000?[`iP3jl>H0;`3jl>H10?ooo`00:@3jl>H00`000000/<CN0;34gP3o0;34gPT0/<CN00<00000
0?[`iP3jl>H09P3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000X0?[`iP030000002`a=h0/<CN
0?l0/<CN2P2`a=h00`000000n_3V0?[`iP0V0?[`iP<00000;`3jl>H10?ooo`00:03jl>H00`000000
/<CN0;34gP3o0;34gP/0/<CN00<000000?[`iP3jl>H09@3jl>H00`000000n_3V0?[`iP0_0?[`iP40
oooo000W0?[`iP030000002`a=h0/<CN0?l0/<CN3@2`a=h00`000000n_3V0?[`iP0T0?[`iP030000
003jl>H0n_3V02l0n_3V0@3oool002H0n_3V00<000000;34gP2`a=h0o`2`a=h>0;34gP030000003j
l>H0n_3V02@0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`009P3jl>H00`000000/<CN0;34gP3o
0;34gPl0/<CN00<000000?[`iP3jl>H06`3jl>H4000000@0n_3V00<000000?[`iP3jl>H0;`3jl>H1
0?ooo`009P3jl>H00`000000/<CN0;34gP3o0;34gPl0/<CN00<000000?[`iP3jl>H06`3jl>H00`00
0000n_3V0?[`iP050?[`iP030000003jl>H0n_3V02l0n_3V0@3oool002H0n_3V00<000000;34gP2`
a=h0o`2`a=h@0;34gP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H0103jl>H4000002h0
n_3V0@3oool002D0n_3V00<000000;34gP2`a=h0o`2`a=hA0;34gP030000003jl>H0n_3V01`0n_3V
00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000U0?[`iP030000002`
a=h0/<CN0?l0/<CN4@2`a=h00`000000n_3V0?[`iP0J0?[`iP040000003jl>H0n_3V000000@0n_3V
00<000000?[`iP3jl>H0;`3jl>H10?ooo`00903jl>H00`000000/<CN0;34gP3o0;34gQ<0/<CN00<0
00000?[`iP3jl>H06P3jl>H2000000D0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00903jl>H0
0`000000/<CN0;34gP3o0;34gQ<0/<CN00<000000?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0_
0?[`iP40oooo000T0?[`iP030000002`a=h0/<CN0?l0/<CN4`2`a=h00`000000n_3V0?[`iP0Q0?[`
iP<00000;`3jl>H10?ooo`008`3jl>H00`000000/<CN0;34gP3o0;34gQ@0/<CN00<000000?[`iP3j
l>H08@3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000S0?[`iP030000002`a=h0/<CN0?l0/<CN
5@2`a=h00`000000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool002<0n_3V00<0
00000;34gP2`a=h0o`2`a=hE0;34gP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0;`3j
l>H10?ooo`008`3jl>H00`000000/<CN0;34gP3o0;34gQD0/<CN00<000000?[`iP3jl>H0803jl>H0
0`000000n_3V0?[`iP0_0?[`iP40oooo000S0?[`iP030000002`a=h0/<CN0?l0/<CN5@2`a=h00`00
0000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool002<0n_3V00<000000;34gP2`
a=h0o`2`a=hE0;34gP030000003jl>H0n_3V0200n_3V0`00000_0?[`iP40oooo000S0?[`iP030000
002`a=h0/<CN0?l0/<CN5@2`a=h00`000000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V02l0n_3V
0@3oool002<0n_3V00<000000;34gP2`a=h0o`2`a=hE0;34gP030000003jl>H0n_3V0200n_3V00<0
00000?[`iP3jl>H03@3jl>H2000000030?[`iP000000n_3V00<0000000@0n_3V0000003jl>H00000
0P3jl>H200000180n_3V0@3oool002<0n_3V00<000000;34gP2`a=h0o`2`a=hE0;34gP030000003j
l>H0n_3V0200n_3V00<000000?[`iP3jl>H03P3jl>H02`000000n_3V0000003jl>H000000?[`iP00
0000n_3V0000003jl>H0000001H0n_3V0@3oool002<0n_3V00<000000;34gP2`a=h0o`2`a=hE0;34
gP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H03P3jl>H02`000000n_3V0000003jl>H0
00000?[`iP000000n_3V0000003jl>H0000001H0n_3V0@3oool002<0n_3V00<000000;34gP2`a=h0
o`2`a=hE0;34gP030000003jl>H0n_3V0200n_3V0`00000=0?[`iP<0000000<0n_3V0000003jl>H0
0`0000000`3jl>H000000?[`iP0F0?[`iP40oooo000S0?[`iP030000002`a=h0/<CN0?l0/<CN5@2`
a=h00`000000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool002<0n_3V00<00000
0;34gP2`a=h0o`2`a=hE0;34gP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0;`3jl>H1
0?ooo`008`3jl>H00`000000/<CN0;34gP3o0;34gQD0/<CN00<000000?[`iP3jl>H0803jl>H00`00
0000n_3V0?[`iP0_0?[`iP40oooo000S0?[`iP030000002`a=h0/<CN0?l0/<CN5@2`a=h00`000000
n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool002<0n_3V00<000000;34gP2`a=h0
o`2`a=hE0;34gP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00903j
l>H00`000000/<CN0;34gP3o0;34gQ<0/<CN00<000000?[`iP3jl>H08@3jl>H3000002l0n_3V0@3o
ool002@0n_3V00<000000;34gP2`a=h0o`2`a=hC0;34gP030000003jl>H0n_3V0240n_3V00<00000
0?[`iP3jl>H0;`3jl>H10?ooo`00903jl>H00`000000/<CN0;34gP3o0;34gQ<0/<CN00<000000?[`
iP3jl>H08@3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000T0?[`iP030000002`a=h0/<CN0?l0
/<CN4P2`a=h00`000000n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool002D0n_3V
00<000000;34gP2`a=h0o`2`a=hA0;34gP030000003jl>H0n_3V01/0n_3V0P0000050?[`iP030000
003jl>H0n_3V02l0n_3V0@3oool002D0n_3V00<000000;34gP2`a=h0o`2`a=hA0;34gP030000003j
l>H0n_3V01X0n_3V00@000000?[`iP3jl>H00000103jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo
000V0?[`iP030000002`a=h0/<CN0?l0/<CN402`a=h00`000000n_3V0?[`iP0L0?[`iP030000003j
l>H0n_3V00<0n_3V1000000^0?[`iP40oooo000V0?[`iP030000002`a=h0/<CN0?l0/<CN3`2`a=h0
0`000000n_3V0?[`iP0N0?[`iP030000003jl>H0n_3V0080n_3V00<000000?[`iP3jl>H0;`3jl>H1
0?ooo`009P3jl>H00`000000/<CN0;34gP3o0;34gPh0/<CN00<000000?[`iP3jl>H0703jl>H01000
0000n_3V0?[`iP0000040?[`iP030000003jl>H0n_3V02l0n_3V0@3oool002L0n_3V00<000000;34
gP2`a=h0o`2`a=h=0;34gP030000003jl>H0n_3V01d0n_3V0P0000050?[`iP030000003jl>H0n_3V
02l0n_3V0@3oool002L0n_3V00<000000;34gP2`a=h0o`2`a=h<0;34gP030000003jl>H0n_3V02D0
n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00:03jl>H00`000000/<CN0;34gP3o0;34gP/0/<CN
00<000000?[`iP3jl>H09@3jl>H3000002l0n_3V0@3oool002T0n_3V00<000000;34gP2`a=h0o`2`
a=h90;34gP030000003jl>H0n_3V02H0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00:@3jl>H0
0`000000/<CN0;34gP3o0;34gPP0/<CN00<000000?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP0_
0?[`iP40oooo000Z0?[`iP030000002`a=h0/<CN0?l0/<CN1`2`a=h00`000000n_3V0?[`iP0W0?[`
iP030000003jl>H0n_3V02l0n_3V0@3oool002X0n_3V00<000000;34gP2`a=h0o`2`a=h60;34gP03
0000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00:`3jl>H00`000000/<CN
0;34gP3o0;34gPD0/<CN00<000000?[`iP3jl>H0:03jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo
000/0?[`iP030000002`a=h0/<CN0?l0/<CN0`2`a=h00`000000n_3V0?[`iP0Y0?[`iP<00000;`3j
l>H10?ooo`00;@3jl>H00`000000/<CN0;34gP3o0;34gP40/<CN00<000000?[`iP3jl>H0:P3jl>H0
0`000000n_3V0?[`iP0_0?[`iP40oooo000^0?[`iP030000002`a=h0/<CN0?h0/<CN00<000000?[`
iP3jl>H0:`3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000_0?[`iP030000002`a=h0/<CN0?`0
/<CN00<000000?[`iP3jl>H0;03jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000`0?[`iP030000
002`a=h0/<CN0?X0/<CN00<000000?[`iP3jl>H0;@3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo
000a0?[`iP030000002`a=h0/<CN0?P0/<CN00<000000?[`iP3jl>H0;P3jl>H3000002l0n_3V0@3o
ool00340n_3V00<000000;34gP2`a=h0m`2`a=h00`000000n_3V0?[`iP0_0?[`iP030000003jl>H0
n_3V02l0n_3V0@3oool00380n_3V00<000000;34gP2`a=h0mP2`a=h00`000000n_3V0?[`iP0_0?[`
iP030000003jl>H0n_3V02l0n_3V0@3oool003<0n_3V0P00003d0;34gP800000<P3jl>H00`000000
n_3V0?[`iP0_0?[`iP40oooo000e0?[`iP030000002`a=h0/<CN0?00/<CN00<000000?[`iP3jl>H0
<P3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000f0?[`iP030000002`a=h0/<CN0>l0/<CN00<0
00000?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000g0?[`iP030000002`a=h0
/<CN0>`0/<CN0P00000e0?[`iP<00000;`3jl>H10?ooo`00>03jl>H00`000000/<CN0;34gP3Z0;34
gP030000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00>@3jl>H00`000000
/<CN0;34gP3X0;34gP030000003jl>H0n_3V03H0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00
>P3jl>H200000>H0/<CN0P00000i0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool003`0n_3V0P00
003R0;34gP800000=@3jl>H3000000<0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00?P3jl>H0
0`000000/<CN0;34gP3N0;34gP030000003jl>H0n_3V03H0n_3V00<000000?[`iP3jl>H00P3jl>H0
0`000000n_3V0?[`iP0_0?[`iP40oooo000o0?[`iP030000002`a=h0/<CN0=`0/<CN00<000000?[`
iP3jl>H0=03jl>H5000000<0n_3V1000000^0?[`iP40oooo00100?[`iP800000fP2`a=h2000003L0
n_3V00@000000?[`iP3jl>H00000103jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo00120?[`iP03
0000002`a=h0/<CN0=H0/<CN00<000000?[`iP3jl>H0>03jl>H00`000000n_3V000000040?[`iP03
0000003jl>H0n_3V02l0n_3V0@3oool004<0n_3V0P00003D0;34gP800000?03jl>H2000000@0n_3V
00<000000?[`iP3jl>H0;`3jl>H10?ooo`00A@3jl>H200000=00/<CN0P0000140?[`iP030000003j
l>H0n_3V02l0n_3V0@3oool004L0n_3V0P00003<0;34gP800000AP3jl>H3000002l0n_3V0@3oool0
04T0n_3V0P0000380;34gP800000B03jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo001;0?[`iP80
0000a02`a=h2000004X0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00C@3jl>H00`000000/<CN
0;34gP300;34gP030000003jl>H0n_3V04X0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00CP3j
l>H300000;`0/<CN0`00001=0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool00540n_3V0`00002f
0;34gP<00000D03jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo001D0?[`iP800000/P2`a=h20000
05<0n_3V0`00000_0?[`iP40oooo001F0?[`iP<00000[02`a=h3000005D0n_3V00<000000?[`iP3j
l>H0;`3jl>H10?ooo`00F@3jl>H300000:H0/<CN0`00001H0?[`iP030000003jl>H0n_3V02l0n_3V
0@3oool005`0n_3V0`00002P0;34gP<00000F`3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo001O
0?[`iP<00000VP2`a=h3000005h0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00HP3jl>H30000
09@0/<CN0`00001Q0?[`iP<00000;`3jl>H10?ooo`00I@3jl>H3000008h0/<CN0`00001T0?[`iP03
0000003jl>H0n_3V02l0n_3V0@3oool006P0n_3V0P0000290;34gP<00000I`3jl>H00`000000n_3V
0?[`iP0_0?[`iP40oooo001Z0?[`iP@00000PP2`a=h3000006X0n_3V00<000000?[`iP3jl>H0;`3j
l>H10?ooo`00KP3jl>H3000007`0/<CN0`00001]0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool0
0740n_3V1@00001b0;34gPD00000L03jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo001f0?[`iPD0
0000J02`a=h5000007D0n_3V0`00000_0?[`iP40oooo001k0?[`iPD00000GP2`a=h5000007X0n_3V
00<000000?[`iP3jl>H0;`3jl>H10?ooo`00P03jl>H600000580/<CN1P00001o0?[`iP030000003j
l>H0n_3V02l0n_3V0@3oool008H0n_3V1`0000140;34gPL00000Q@3jl>H00`000000n_3V0?[`iP0_
0?[`iP40oooo002=0?[`iPX00000<02`a=h:000008D0n_3V0P0000050?[`iP030000003jl>H0n_3V
02l0n_3V0@3oool009L0n_3V4P00000=0;34gQ400000SP3jl>H010000000n_3V0?[`iP0000040?[`
iP030000003jl>H0n_3V02l0n_3V0@3oool00:T0n_3V3@00002R0?[`iP030000003jl>H0n_3V0080
n_3V1000000^0?[`iP40oooo003o0?[`iUL0n_3V0P00000g0?[`iP40oooo003o0?[`iUL0n_3V00<0
00000?[`iP3jl>H0=P3jl>H10?ooo`00o`3jl>IG0?[`iP<00000=P3jl>H10?ooo`00o`3jl>J@0?[`
iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o
0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V
0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0
n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H1
0?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3j
l>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40
oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`
iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3o
ool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {244.563, 0}} -> {-2.50514, -2.00001, \
0.0143115, 0.0143115}}]
}, Open  ]],

Cell["\<\
This reverses the tick and labels on the vertical scale and makes the tick \
marks larger and changes the font for the labels.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Draw2D[\[IndentingNewLine]{LightSteelBlue, 
          Disk[{0, 0}, {2, 1}], \[IndentingNewLine]Black, 
          Circle[{0, 0}, {2, 1}], \[IndentingNewLine]XTickLine[{\(-2\), 
              2, \(-1.3\)}, {0, 10}, {0, 10, 1}, 
            5, \[IndentingNewLine]XLabTickSpecs \[Rule] {0.016, 
                0}, \[IndentingNewLine]XUnLabTickSpecs \[Rule] {0.010, 
                0, {Red}}, \[IndentingNewLine]XTextSpecs \[Rule] {{0, 1}, {1, 
                  0}, 0.002, {FontFamily \[Rule] "\<Helvetica\>", 
                  FontSize \[Rule] 
                    10}}], \[IndentingNewLine]YTickLine[{\(-1\), 1, 2.5}, {0, 
              5}, {0, 5, 1}, 
            5, \[IndentingNewLine]YLabTickSpecs \[Rule] {0, 
                0.016}, \[IndentingNewLine]YUnLabTickSpecs \[Rule] {0, 
                0.010, {Red}}, \[IndentingNewLine]YTextSpecs \[Rule] \
{{\(-1\), 0}, {1, 0}, \(-0.002\), {FontFamily \[Rule] "\<Helvetica\>", 
                  FontSize \[Rule] 
                    10}}], \[IndentingNewLine]Text["\<mm.\>", \
{\(-0.00542015\), \(-1.54438\)}], \[IndentingNewLine]Text["\<mm.\>", {2.85, 
              0.0157696}]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]PlotRange \[Rule] {{\(-2.5\), 
              3.2}, {\(-2\), 1.5}}, \[IndentingNewLine]Background \[Rule] 
          Linen, \[IndentingNewLine]ImageSize \[Rule] 400];\)\)], "Input",
  CellLabel->"In[333]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61404 
%%ImageSize: 400 245.614 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
0.438596 0.175439 0.350877 0.175439 [
[ 0 0 0 0 ]
[ 1 .61404 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61404 L
0 .61404 L
closepath
clip
newpath
.69 .769 .871 r
.4386 .35088 m
matrix currentmatrix
0.350877 0.175439 scale
1.25001 2.00002 1 0 365.73 arc
setmatrix F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.350877 0.175439 scale
1.25001 2.00002 1 0 365.73 arc
setmatrix s
.08772 .12281 m
.78947 .12281 L
s
1 0 0 r
.08772 .12281 m
.08772 .12895 L
s
.08772 .12281 m
.08772 .12281 L
s
.10175 .12281 m
.10175 .12895 L
s
.10175 .12281 m
.10175 .12281 L
s
.11579 .12281 m
.11579 .12895 L
s
.11579 .12281 m
.11579 .12281 L
s
.12982 .12281 m
.12982 .12895 L
s
.12982 .12281 m
.12982 .12281 L
s
.14386 .12281 m
.14386 .12895 L
s
.14386 .12281 m
.14386 .12281 L
s
.15789 .12281 m
.15789 .12895 L
s
.15789 .12281 m
.15789 .12281 L
s
.17193 .12281 m
.17193 .12895 L
s
.17193 .12281 m
.17193 .12281 L
s
.18596 .12281 m
.18596 .12895 L
s
.18596 .12281 m
.18596 .12281 L
s
.2 .12281 m
.2 .12895 L
s
.2 .12281 m
.2 .12281 L
s
.21404 .12281 m
.21404 .12895 L
s
.21404 .12281 m
.21404 .12281 L
s
.22807 .12281 m
.22807 .12895 L
s
.22807 .12281 m
.22807 .12281 L
s
.24211 .12281 m
.24211 .12895 L
s
.24211 .12281 m
.24211 .12281 L
s
.25614 .12281 m
.25614 .12895 L
s
.25614 .12281 m
.25614 .12281 L
s
.27018 .12281 m
.27018 .12895 L
s
.27018 .12281 m
.27018 .12281 L
s
.28421 .12281 m
.28421 .12895 L
s
.28421 .12281 m
.28421 .12281 L
s
.29825 .12281 m
.29825 .12895 L
s
.29825 .12281 m
.29825 .12281 L
s
.31228 .12281 m
.31228 .12895 L
s
.31228 .12281 m
.31228 .12281 L
s
.32632 .12281 m
.32632 .12895 L
s
.32632 .12281 m
.32632 .12281 L
s
.34035 .12281 m
.34035 .12895 L
s
.34035 .12281 m
.34035 .12281 L
s
.35439 .12281 m
.35439 .12895 L
s
.35439 .12281 m
.35439 .12281 L
s
.36842 .12281 m
.36842 .12895 L
s
.36842 .12281 m
.36842 .12281 L
s
.38246 .12281 m
.38246 .12895 L
s
.38246 .12281 m
.38246 .12281 L
s
.39649 .12281 m
.39649 .12895 L
s
.39649 .12281 m
.39649 .12281 L
s
.41053 .12281 m
.41053 .12895 L
s
.41053 .12281 m
.41053 .12281 L
s
.42456 .12281 m
.42456 .12895 L
s
.42456 .12281 m
.42456 .12281 L
s
.4386 .12281 m
.4386 .12895 L
s
.4386 .12281 m
.4386 .12281 L
s
.45263 .12281 m
.45263 .12895 L
s
.45263 .12281 m
.45263 .12281 L
s
.46667 .12281 m
.46667 .12895 L
s
.46667 .12281 m
.46667 .12281 L
s
.4807 .12281 m
.4807 .12895 L
s
.4807 .12281 m
.4807 .12281 L
s
.49474 .12281 m
.49474 .12895 L
s
.49474 .12281 m
.49474 .12281 L
s
.50877 .12281 m
.50877 .12895 L
s
.50877 .12281 m
.50877 .12281 L
s
.52281 .12281 m
.52281 .12895 L
s
.52281 .12281 m
.52281 .12281 L
s
.53684 .12281 m
.53684 .12895 L
s
.53684 .12281 m
.53684 .12281 L
s
.55088 .12281 m
.55088 .12895 L
s
.55088 .12281 m
.55088 .12281 L
s
.56491 .12281 m
.56491 .12895 L
s
.56491 .12281 m
.56491 .12281 L
s
.57895 .12281 m
.57895 .12895 L
s
.57895 .12281 m
.57895 .12281 L
s
.59298 .12281 m
.59298 .12895 L
s
.59298 .12281 m
.59298 .12281 L
s
.60702 .12281 m
.60702 .12895 L
s
.60702 .12281 m
.60702 .12281 L
s
.62105 .12281 m
.62105 .12895 L
s
.62105 .12281 m
.62105 .12281 L
s
.63509 .12281 m
.63509 .12895 L
s
.63509 .12281 m
.63509 .12281 L
s
.64912 .12281 m
.64912 .12895 L
s
.64912 .12281 m
.64912 .12281 L
s
.66316 .12281 m
.66316 .12895 L
s
.66316 .12281 m
.66316 .12281 L
s
.67719 .12281 m
.67719 .12895 L
s
.67719 .12281 m
.67719 .12281 L
s
.69123 .12281 m
.69123 .12895 L
s
.69123 .12281 m
.69123 .12281 L
s
.70526 .12281 m
.70526 .12895 L
s
.70526 .12281 m
.70526 .12281 L
s
.7193 .12281 m
.7193 .12895 L
s
.7193 .12281 m
.7193 .12281 L
s
.73333 .12281 m
.73333 .12895 L
s
.73333 .12281 m
.73333 .12281 L
s
.74737 .12281 m
.74737 .12895 L
s
.74737 .12281 m
.74737 .12281 L
s
.7614 .12281 m
.7614 .12895 L
s
.7614 .12281 m
.7614 .12281 L
s
.77544 .12281 m
.77544 .12895 L
s
.77544 .12281 m
.77544 .12281 L
s
.78947 .12281 m
.78947 .12895 L
s
.78947 .12281 m
.78947 .12281 L
s
0 0 0 r
.08772 .12281 m
.08772 .13263 L
s
.08772 .12281 m
.08772 .12281 L
s
gsave
.08772 .12158 -65.7813 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.15789 .12281 m
.15789 .13263 L
s
.15789 .12281 m
.15789 .12281 L
s
gsave
.15789 .12158 -65.7813 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22807 .12281 m
.22807 .13263 L
s
.22807 .12281 m
.22807 .12281 L
s
gsave
.22807 .12158 -65.7813 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.29825 .12281 m
.29825 .13263 L
s
.29825 .12281 m
.29825 .12281 L
s
gsave
.29825 .12158 -65.7813 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.36842 .12281 m
.36842 .13263 L
s
.36842 .12281 m
.36842 .12281 L
s
gsave
.36842 .12158 -65.7813 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.4386 .12281 m
.4386 .13263 L
s
.4386 .12281 m
.4386 .12281 L
s
gsave
.4386 .12158 -65.7813 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.50877 .12281 m
.50877 .13263 L
s
.50877 .12281 m
.50877 .12281 L
s
gsave
.50877 .12158 -65.7813 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.57895 .12281 m
.57895 .13263 L
s
.57895 .12281 m
.57895 .12281 L
s
gsave
.57895 .12158 -65.7813 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.64912 .12281 m
.64912 .13263 L
s
.64912 .12281 m
.64912 .12281 L
s
gsave
.64912 .12158 -65.7813 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.7193 .12281 m
.7193 .13263 L
s
.7193 .12281 m
.7193 .12281 L
s
gsave
.7193 .12158 -65.7813 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.78947 .12281 m
.78947 .13263 L
s
.78947 .12281 m
.78947 .12281 L
s
gsave
.78947 .12158 -68.5625 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.87719 .17544 m
.87719 .52632 L
s
1 0 0 r
.87719 .17544 m
.87719 .17544 L
s
.87719 .17544 m
.86719 .17544 L
s
.87719 .18947 m
.87719 .18947 L
s
.87719 .18947 m
.86719 .18947 L
s
.87719 .20351 m
.87719 .20351 L
s
.87719 .20351 m
.86719 .20351 L
s
.87719 .21754 m
.87719 .21754 L
s
.87719 .21754 m
.86719 .21754 L
s
.87719 .23158 m
.87719 .23158 L
s
.87719 .23158 m
.86719 .23158 L
s
.87719 .24561 m
.87719 .24561 L
s
.87719 .24561 m
.86719 .24561 L
s
.87719 .25965 m
.87719 .25965 L
s
.87719 .25965 m
.86719 .25965 L
s
.87719 .27368 m
.87719 .27368 L
s
.87719 .27368 m
.86719 .27368 L
s
.87719 .28772 m
.87719 .28772 L
s
.87719 .28772 m
.86719 .28772 L
s
.87719 .30175 m
.87719 .30175 L
s
.87719 .30175 m
.86719 .30175 L
s
.87719 .31579 m
.87719 .31579 L
s
.87719 .31579 m
.86719 .31579 L
s
.87719 .32982 m
.87719 .32982 L
s
.87719 .32982 m
.86719 .32982 L
s
.87719 .34386 m
.87719 .34386 L
s
.87719 .34386 m
.86719 .34386 L
s
.87719 .35789 m
.87719 .35789 L
s
.87719 .35789 m
.86719 .35789 L
s
.87719 .37193 m
.87719 .37193 L
s
.87719 .37193 m
.86719 .37193 L
s
.87719 .38596 m
.87719 .38596 L
s
.87719 .38596 m
.86719 .38596 L
s
.87719 .4 m
.87719 .4 L
s
.87719 .4 m
.86719 .4 L
s
.87719 .41404 m
.87719 .41404 L
s
.87719 .41404 m
.86719 .41404 L
s
.87719 .42807 m
.87719 .42807 L
s
.87719 .42807 m
.86719 .42807 L
s
.87719 .44211 m
.87719 .44211 L
s
.87719 .44211 m
.86719 .44211 L
s
.87719 .45614 m
.87719 .45614 L
s
.87719 .45614 m
.86719 .45614 L
s
.87719 .47018 m
.87719 .47018 L
s
.87719 .47018 m
.86719 .47018 L
s
.87719 .48421 m
.87719 .48421 L
s
.87719 .48421 m
.86719 .48421 L
s
.87719 .49825 m
.87719 .49825 L
s
.87719 .49825 m
.86719 .49825 L
s
.87719 .51228 m
.87719 .51228 L
s
.87719 .51228 m
.86719 .51228 L
s
.87719 .52632 m
.87719 .52632 L
s
.87719 .52632 m
.86719 .52632 L
s
0 0 0 r
.87719 .17544 m
.87719 .17544 L
s
.87719 .17544 m
.86119 .17544 L
s
gsave
.87919 .17544 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.87719 .24561 m
.87719 .24561 L
s
.87719 .24561 m
.86119 .24561 L
s
gsave
.87919 .24561 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.87719 .31579 m
.87719 .31579 L
s
.87719 .31579 m
.86119 .31579 L
s
gsave
.87919 .31579 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.87719 .38596 m
.87719 .38596 L
s
.87719 .38596 m
.86119 .38596 L
s
gsave
.87919 .38596 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.87719 .45614 m
.87719 .45614 L
s
.87719 .45614 m
.86119 .45614 L
s
gsave
.87919 .45614 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.87719 .52632 m
.87719 .52632 L
s
.87719 .52632 m
.86119 .52632 L
s
gsave
.87919 .52632 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
gsave
.43765 .07993 -72 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
81.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.9386 .35364 -72 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
81.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[333]:=",
  ImageSize->{400, 245.563},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mB000`400?l00000o`00003oo`3jl>J@
0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo
003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00
n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool0
0?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03j
l>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00
o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`
iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o
0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V
0@3oool00?l0n_3VT03jl>H10?ooo`00Y@3jl>H2000000030?[`iP000000n_3V00<0000000@0n_3V
0000003jl>H000000P3jl>H200000=X0n_3V0@3oool00:H0n_3V00/000000?[`iP000000n_3V0000
003jl>H000000?[`iP000000n_3V0000003N0?[`iP40oooo002V0?[`iP0;0000003jl>H000000?[`
iP000000n_3V0000003jl>H000000?[`iP000000gP3jl>H10?ooo`00Y@3jl>H3000000030?[`iP00
0000n_3V00<0000000<0n_3V0000003jl>H0gP3jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`
iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3o
ool00?l0n_3VT03jl>H10?ooo`008@3jl>H3000001/0n_3V00<000000?[`iP3jl>H05P3jl>H50000
01P0n_3V0`00000L0?[`iP030000003jl>H0n_3V01H0n_3V0`00000I0?[`iP<000006@3jl>H00`00
0000n_3V0?[`iP0I0?[`iP<000006@3jl>H3000001P0n_3V00@000000?[`iP3jl>H0n_3V0`00001@
0?[`iP40oooo000P0?[`iP050000003jl>H0n_3V0?[`iP0000006P3jl>H00`000000n_3V0?[`iP0G
0?[`iP030000003jl>H0n_3V01P0n_3V00D000000?[`iP3jl>H0n_3V0000000K0?[`iP030000003j
l>H0n_3V01D0n_3V00D000000?[`iP3jl>H0n_3V0000000G0?[`iP050000003jl>H0n_3V0?[`iP00
0000603jl>H00`000000n_3V0?[`iP0H0?[`iP050000003jl>H0n_3V0?[`iP0000005`3jl>H01@00
0000n_3V0?[`iP3jl>H0000001L0n_3V00@000000?[`iP3jl>H000000`3jl>H00`000000n_3V0?[`
iP1=0?[`iP40oooo000P0?[`iP050000003jl>H0n_3V0?[`iP0000006P3jl>H00`000000n_3V0?[`
iP0H0?[`iP030000003jl>H0n_3V01/0n_3V00<000000?[`iP3jl>H05@3jl>H6000001X0n_3V00<0
00000?[`iP3jl>H05@3jl>H01@000000n_3V0?[`iP3jl>H0000001T0n_3V00<000000?[`iP3jl>H0
5`3jl>H01@000000n_3V0?[`iP3jl>H0000001P0n_3V1000000G0?[`iP040000003jl>H0n_3V0000
00<0n_3V00<000000?[`iP3jl>H0C@3jl>H10?ooo`00803jl>H01@000000n_3V0?[`iP3jl>H00000
01X0n_3V00<000000?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0H0?[`iP800000603jl>H01@00
0000n_3V0?[`iP3jl>H0000001L0n_3V00D000000?[`iP3jl>H0n_3V0000000G0?[`iP050000003j
l>H0n_3V0?[`iP0000006@3jl>H00`000000n_3V0?[`iP0H0?[`iP<00000603jl>H01@000000n_3V
0?[`iP3jl>H0000001L0n_3V00@000000?[`iP3jl>H000000`3jl>H00`000000n_3V0?[`iP1=0?[`
iP40oooo000P0?[`iP050000003jl>H0n_3V0?[`iP000000603jl>H00`000000n_3V0000000L0?[`
iP030000003jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H05P3jl>H010000000n_3V0?[`iP00000G
0?[`iP@00000603jl>H4000001/0n_3V00<000000?[`iP3jl>H05P3jl>H01@000000n_3V0?[`iP3j
l>H0000001L0n_3V00D000000?[`iP3jl>H0n_3V0000000E0?[`iP030000003jl>H000000080n_3V
00D000000?[`iP3jl>H0n_3V0000001?0?[`iP40oooo000P0?[`iP050000003jl>H0n_3V0?[`iP00
00006@3jl>H2000001P0n_3V00D000000?[`iP3jl>H0n_3V0000000G0?[`iP050000003jl>H0n_3V
0?[`iP0000006@3jl>H00`000000n_3V0000000H0?[`iP030000003jl>H0n_3V01P0n_3V00D00000
0?[`iP3jl>H0n_3V0000000J0?[`iP030000003jl>H0n_3V01H0n_3V00D000000?[`iP3jl>H0n_3V
0000000G0?[`iP050000003jl>H0n_3V0?[`iP0000005P3jl>H200000080n_3V00D000000?[`iP3j
l>H0n_3V0000001?0?[`iP40oooo000Q0?[`iP<000006`3jl>H00`000000n_3V0?[`iP0G0?[`iP<0
00006@3jl>H3000001/0n_3V0P00000H0?[`iP@00000603jl>H3000001P0n_3V1@00000H0?[`iP<0
00006@3jl>H3000001P0n_3V00@000000?[`iP3jl>H0n_3V0`00001@0?[`iP40oooo003o0?[`iY00
n_3V0@3oool00?l0n_3VT03jl>H10?ooo`008`3jl>H500000080o`00100000000`3o000000000000
0003000000030?l00000000000000080000000<0o`00000000000000200000020?l000@0000000<0
o`000000000000000`0000000`3o0000000000000002000000030?l000000000000000P000000P3o
0004000000030?l0000000000000008000000P3o0004000000030?l000000000000000P0000000<0
o`000000000000000`0000000`3o000000000000000200000080o`00100000000`3o000000000000
0008000000030?l000000000000000<0000000<0o`000000000000000P0000020?l000@0000000<0
o`00000000000000200000000`3o0000000000000003000000030?l0000000000000008000000P3o
0004000000030?l000000000000000P0000000<0o`000000000000000`0000000`3o000000000000
000200000080o`00100000000`3o0000000000000008000000030?l000000000000000<0000000<0
o`000000000000000P0000000`3o0000000000000003000000030?l000000000000000P0000000<0
o`000000000000000`0000000`3o0000000000000002000000030?l000000000000000<0000000<0
o`00000000000000200000000`3o0000000000000003000000030?l00000000000000080000000<0
o`000000000000000`0000000`3o0000000000000004000005<0n_3V0@3oool002<0n_3V00<00000
0?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V00<0n_3V00<0o`00
0?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0080n_3V00<0o`00
0?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V0080n_3V00<0o`00
0?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP020?[`iP030?l0003jl>H0n_3V00<0n_3V00<0o`00
0?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V00<0n_3V00<00000
0?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V0080n_3V00<0o`00
0?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP030?[`iP030000003jl>H0n_3V0080n_3V00<0o`00
0?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP020?[`iP030?l0003jl>H0n_3V00<0n_3V00<0o`00
0?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP020?[`iP030?l0003jl>H0n_3V00<0n_3V00<0o`00
0?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V0080n_3V00<00000
0?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V0080n_3V00<0o`00
0?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP020?[`iP030000003jl>H0n_3V00<0n_3V00<0o`00
0?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP020?[`iP030?l0003jl>H0n_3V00<0n_3V00<0o`00
0?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V00<0n_3V00<0o`00
0?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V0080n_3V00<00000
0?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V0080n_3V00<0o`00
0?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP020?[`iP030000003jl>H0n_3V0580n_3V0@3oool0
02<0n_3V00<000000?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V
00<0n_3V00<0o`000?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP030?[`iP030000003jl>H0n_3V
0080n_3V00<0o`000?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V
0080n_3V00<0o`000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP020?[`iP030?l0003jl>H0n_3V
00<0n_3V00<0o`000?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V
00<0n_3V00<000000?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V
0080n_3V00<0o`000?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP030?[`iP030000003jl>H0n_3V
0080n_3V00<0o`000?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP020?[`iP030?l0003jl>H0n_3V
00<0n_3V00<0o`000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP020?[`iP030?l0003jl>H0n_3V
00<0n_3V00<0o`000?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V
0080n_3V00<000000?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V
0080n_3V00<0o`000?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP020?[`iP030000003jl>H0n_3V
00<0n_3V00<0o`000?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP020?[`iP030?l0003jl>H0n_3V
00<0n_3V00<0o`000?[`iP3jl>H00P3jl>H00`000000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V
00<0n_3V00<0o`000?[`iP3jl>H00P3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V
0080n_3V00<000000?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP030?[`iP030?l0003jl>H0n_3V
0080n_3V00<0o`000?[`iP3jl>H00`3jl>H00`3o0000n_3V0?[`iP020?[`iP030000003jl>H0n_3V
0580n_3V0@3oool002<0n_3V00<000000?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0I0?[`iP03
0000003jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0I0?[`iP03
0000003jl>H0n_3V01P0n_3V00<000000?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP0I0?[`iP03
0000003jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06@3jl>H00`000000n_3V0?[`iP1B0?[`iP40
oooo000S0?[`iP030000003jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06@3jl>H00`000000n_3V
0?[`iP0I0?[`iP030000003jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06@3jl>H00`000000n_3V
0?[`iP0H0?[`iP030000003jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H06@3jl>H00`000000n_3V
0?[`iP0I0?[`iP030000003jl>H0n_3V01T0n_3V00<000000?[`iP3jl>H0DP3jl>H10?ooo`00o`3j
l>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40
oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`
iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3o
ool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3V
HP3jl>H3000002/0n_3V0@3oool00?l0n_3VH@3jl>H01@000000n_3V0?[`iP3jl>H0000002X0n_3V
0@3oool009/0n_3V:000002D0?[`iPL000000P3jl>H01@000000n_3V0?[`iP3jl>H0000002X0n_3V
0@3oool00940n_3V2P00000X0;34gPX00000T03jl>H010000000n_3V0?[`iP0000030?[`iP030000
003jl>H0n_3V02P0n_3V0@3oool008T0n_3V2000000l0;34gPP00000R03jl>H010000000n_3V0?[`
iP0000030?[`iP030000003jl>H0n_3V02P0n_3V0@3oool00880n_3V1`00001<0;34gPL00000P@3j
l>H010000000n_3V0?[`iP0000030?[`iP030000003jl>H0n_3V02P0n_3V0@3oool007d0n_3V1@00
001J0;34gPD00000O03jl>H010000000n_3V0?[`iP3jl>H3000002/0n_3V0@3oool007P0n_3V1@00
001T0;34gPD00000L`3jl>H50?l00340n_3V0@3oool007@0n_3V1000001^0;34gPD00000LP3jl>H0
0`000000n_3V0?[`iP0_0?[`iP40oooo001`0?[`iP@00000M`2`a=h3000006l0n_3V00<000000?[`
iP3jl>H0;`3jl>H10?ooo`00J`3jl>H5000007h0/<CN1000001[0?[`iP030000003jl>H0n_3V02l0
n_3V0@3oool006P0n_3V0`0000270;34gP@00000I`3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo
001U0?[`iP<00000SP2`a=h3000006@0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00HP3jl>H3
000009@0/<CN0`00001M0?[`iPD0o`00<@3jl>H10?ooo`00G`3jl>H3000009X0/<CN0`00001N0?[`
iP030000003jl>H0n_3V02l0n_3V0@3oool005`0n_3V0`00002P0;34gP<00000F`3jl>H00`000000
n_3V0?[`iP0_0?[`iP40oooo001I0?[`iP<00000YP2`a=h3000005P0n_3V00<000000?[`iP3jl>H0
;`3jl>H10?ooo`00E`3jl>H200000:`0/<CN0P00001F0?[`iP030000003jl>H0n_3V02l0n_3V0@3o
ool005@0n_3V0`00002`0;34gP<00000D`3jl>H00`3o0000n_3V0?[`iP0_0?[`iP40oooo001B0?[`
iP800000]P2`a=h3000004`0n_3V1@3o000a0?[`iP40oooo001@0?[`iP800000^`2`a=h2000004h0
n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00CP3jl>H200000;l0/<CN00<000000?[`iP3jl>H0
B`3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo001=0?[`iP030000002`a=h0/<CN0<00/<CN0P00
001;0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool004X0n_3V0`0000350;34gP800000B@3jl>H0
0`000000n_3V0?[`iP0_0?[`iP40oooo00180?[`iP800000bP2`a=h2000004<0n_3V1@3o000a0?[`
iP40oooo00160?[`iP800000cP2`a=h2000004D0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00
A@3jl>H00`000000/<CN0;34gP3@0;34gP800000@`3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo
00130?[`iP800000e@2`a=h00`000000n_3V0?[`iP100?[`iP030000003jl>H0n_3V02l0n_3V0@3o
ool00440n_3V0P00003H0;34gP800000@03jl>H00`000000n_3V0?[`iP030?[`iP030000003jl>H0
n_3V02T0n_3V0@3oool003l0n_3V0P00003L0;34gP030000003jl>H0n_3V03d0n_3V00<000000?[`
iP3jl>H00`3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo000n0?[`iP030000002`a=h0/<CN0=d0
/<CN00<000000?[`iP3jl>H0=P3jl>H7000000D0n_3V00<000000?[`iP3jl>H0:@3jl>H10?ooo`00
?@3jl>H00`000000/<CN0;34gP3O0;34gP800000?03jl>H00`000000n_3V0?[`iP030?[`iP030000
003jl>H0n_3V02T0n_3V0@3oool003/0n_3V0P00003T0;34gP800000>P3jl>H01`000000n_3V0?[`
iP3jl>H000000?[`iP000000:`3jl>H10?ooo`00>P3jl>H00`000000/<CN0;34gP3V0;34gP030000
003jl>H0n_3V03L0n_3V00<000000?[`iP3jl>H00P3jl>H2000002/0n_3V0@3oool003T0n_3V00<0
00000;34gP2`a=h0j02`a=h00`000000n_3V0?[`iP0f0?[`iP030000003jl>H0n_3V00<0n_3V00<0
00000?[`iP3jl>H0:@3jl>H10?ooo`00=`3jl>H200000>`0/<CN0P00000b0?[`iPD0o`00<@3jl>H1
0?ooo`00=P3jl>H00`000000/<CN0;34gP3^0;34gP030000003jl>H0n_3V03<0n_3V00<000000?[`
iP3jl>H0;`3jl>H10?ooo`00=P3jl>H00`000000/<CN0;34gP3_0;34gP030000003jl>H0n_3V0380
n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00=03jl>H200000?<0/<CN00<000000?[`iP3jl>H0
<@3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000c0?[`iP030000002`a=h0/<CN0?@0/<CN00<0
00000?[`iP3jl>H0<03jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000b0?[`iP030000002`a=h0
/<CN0?H0/<CN00<000000?[`iP3jl>H0;`3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000a0?[`
iP030000002`a=h0/<CN0?P0/<CN00<000000?[`iP3jl>H0:P3jl>H50?l00340n_3V0@3oool00300
n_3V00<000000;34gP2`a=h0nP2`a=h00`000000n_3V0?[`iP0]0?[`iP030000003jl>H0n_3V02l0
n_3V0@3oool002l0n_3V00<000000;34gP2`a=h0o02`a=h00`000000n_3V0?[`iP0/0?[`iP030000
003jl>H0n_3V02l0n_3V0@3oool002h0n_3V00<000000;34gP2`a=h0o@2`a=h00`000000n_3V0?[`
iP0/0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool002h0n_3V00<000000;34gP2`a=h0oP2`a=h0
0`000000n_3V0?[`iP0[0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool002`0n_3V0P00003o0;34
gP<0/<CN0P00000[0?[`iP030?l0003jl>H0n_3V02l0n_3V0@3oool002/0n_3V00<000000;34gP2`
a=h0o`2`a=h40;34gP030000003jl>H0n_3V02D0n_3V1@3o000a0?[`iP40oooo000[0?[`iP030000
002`a=h0/<CN0?l0/<CN1@2`a=h00`000000n_3V0?[`iP0X0?[`iP030000003jl>H0n_3V02l0n_3V
0@3oool002X0n_3V00<000000;34gP2`a=h0o`2`a=h70;34gP030000003jl>H0n_3V02L0n_3V00<0
00000?[`iP3jl>H0;`3jl>H10?ooo`00:@3jl>H00`000000/<CN0;34gP3o0;34gPP0/<CN00<00000
0?[`iP3jl>H09`3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000Y0?[`iP030000002`a=h0/<CN
0?l0/<CN2@2`a=h00`000000n_3V0?[`iP0V0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool002P0
n_3V00<000000;34gP2`a=h0o`2`a=h:0;34gP030000003jl>H0n_3V0280n_3V1@3o000a0?[`iP40
oooo000X0?[`iP030000002`a=h0/<CN0?l0/<CN2`2`a=h00`000000n_3V0?[`iP0U0?[`iP030000
003jl>H0n_3V02l0n_3V0@3oool002L0n_3V00<000000;34gP2`a=h0o`2`a=h=0;34gP030000003j
l>H0n_3V02@0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`009P3jl>H00`000000/<CN0;34gP3o
0;34gPh0/<CN00<000000?[`iP3jl>H0903jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000V0?[`
iP030000002`a=h0/<CN0?l0/<CN3`2`a=h00`000000n_3V0?[`iP0S0?[`iP030000003jl>H0n_3V
00D00000:P3jl>H10?ooo`009P3jl>H00`000000/<CN0;34gP3o0;34gPl0/<CN00<000000?[`iP3j
l>H08`3jl>H01@000000n_3V0?[`iP3jl>H0000002d0n_3V0@3oool002H0n_3V00<000000;34gP2`
a=h0o`2`a=h@0;34gP030000003jl>H0n_3V01`0n_3V1`0000040?[`iP030000003jl>H0n_3V02X0
n_3V0@3oool002D0n_3V00<000000;34gP2`a=h0o`2`a=hA0;34gP030000003jl>H0n_3V0280n_3V
00<000000?[`iP3jl>H00`3jl>H00`000000n_3V0?[`iP0Y0?[`iP40oooo000U0?[`iP030000002`
a=h0/<CN0?l0/<CN4@2`a=h00`000000n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V00@0n_3V00<0
00000?[`iP3jl>H0:03jl>H10?ooo`00903jl>H00`000000/<CN0;34gP3o0;34gQ<0/<CN00<00000
0?[`iP3jl>H08@3jl>H010000000n_3V0?[`iP0000030?[`iP030000003jl>H0n_3V02P0n_3V0@3o
ool002@0n_3V00<000000;34gP2`a=h0o`2`a=hC0;34gP030000003jl>H0n_3V0240n_3V00@00000
0?[`iP3jl>H0n_3V0`00000[0?[`iP40oooo000T0?[`iP030000002`a=h0/<CN0?l0/<CN4`2`a=h0
0`000000n_3V0?[`iP0M0?[`iPD0o`00<@3jl>H10?ooo`008`3jl>H00`000000/<CN0;34gP3o0;34
gQ@0/<CN00<000000?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000S0?[`iP03
0000002`a=h0/<CN0?l0/<CN5@2`a=h00`000000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V02l0
n_3V0@3oool002<0n_3V00<000000;34gP2`a=h0o`2`a=hE0;34gP030000003jl>H0n_3V0200n_3V
00<000000?[`iP3jl>H0;`3jl>H10?ooo`008`3jl>H00`000000/<CN0;34gP3o0;34gQD0/<CN00<0
00000?[`iP3jl>H0803jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000S0?[`iP030000002`a=h0
/<CN0?l0/<CN5@2`a=h00`000000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool0
02<0n_3V00<000000;34gP2`a=h0o`2`a=hE0;34gP030000003jl>H0n_3V01`0n_3V1@3o000a0?[`
iP40oooo000S0?[`iP030000002`a=h0/<CN0?l0/<CN5@2`a=h00`000000n_3V0?[`iP0P0?[`iP03
0000003jl>H0n_3V02l0n_3V0@3oool002<0n_3V00<000000;34gP2`a=h0o`2`a=hE0;34gP030000
003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H03@3jl>H2000000030?[`iP000000n_3V00<00000
00@0n_3V0000003jl>H000000P3jl>H200000180n_3V0@3oool002<0n_3V00<000000;34gP2`a=h0
o`2`a=hE0;34gP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H03P3jl>H02`000000n_3V
0000003jl>H000000?[`iP000000n_3V0000003jl>H0000001H0n_3V0@3oool002<0n_3V00<00000
0;34gP2`a=h0o`2`a=hE0;34gP030000003jl>H0n_3V0200n_3V00<000000?[`iP3jl>H03P3jl>H0
2`000000n_3V0000003jl>H000000?[`iP000000n_3V0000003jl>H0000001H0n_3V0@3oool002<0
n_3V00<000000;34gP2`a=h0o`2`a=hE0;34gP030000003jl>H0n_3V01`0n_3V1@3o000?0?[`iP<0
000000<0n_3V0000003jl>H00`0000000`3jl>H000000?[`iP0F0?[`iP40oooo000S0?[`iP030000
002`a=h0/<CN0?l0/<CN5@2`a=h00`000000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V02l0n_3V
0@3oool002<0n_3V00<000000;34gP2`a=h0o`2`a=hE0;34gP030000003jl>H0n_3V0200n_3V00<0
00000?[`iP3jl>H0;`3jl>H10?ooo`008`3jl>H00`000000/<CN0;34gP3o0;34gQD0/<CN00<00000
0?[`iP3jl>H0803jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000S0?[`iP030000002`a=h0/<CN
0?l0/<CN5@2`a=h00`000000n_3V0?[`iP0P0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool002<0
n_3V00<000000;34gP2`a=h0o`2`a=hE0;34gP030000003jl>H0n_3V0200n_3V00<000000?[`iP3j
l>H0;`3jl>H10?ooo`00903jl>H00`000000/<CN0;34gP3o0;34gQ<0/<CN00<000000?[`iP3jl>H0
7@3jl>H50?l00340n_3V0@3oool002@0n_3V00<000000;34gP2`a=h0o`2`a=hC0;34gP030000003j
l>H0n_3V0240n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00903jl>H00`000000/<CN0;34gP3o
0;34gQ<0/<CN00<000000?[`iP3jl>H08@3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000T0?[`
iP030000002`a=h0/<CN0?l0/<CN4P2`a=h00`000000n_3V0?[`iP0R0?[`iP030000003jl>H0n_3V
02l0n_3V0@3oool002D0n_3V00<000000;34gP2`a=h0o`2`a=hA0;34gP030000003jl>H0n_3V0280
n_3V00@000000?[`iP3jl>H0n_3V0`00000[0?[`iP40oooo000U0?[`iP030000002`a=h0/<CN0?l0
/<CN4@2`a=h00`000000n_3V0?[`iP0R0?[`iP040000003jl>H0n_3V000000<0n_3V00<000000?[`
iP3jl>H0:03jl>H10?ooo`009P3jl>H00`000000/<CN0;34gP3o0;34gQ00/<CN00<000000?[`iP3j
l>H0703jl>H7000000H0n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`009P3jl>H00`000000/<CN
0;34gP3o0;34gPl0/<CN00<000000?[`iP3jl>H08`3jl>H00`000000n_3V0?[`iP020?[`iP800000
:`3jl>H10?ooo`009P3jl>H00`000000/<CN0;34gP3o0;34gPh0/<CN00<000000?[`iP3jl>H0903j
l>H00`000000n_3V0?[`iP040?[`iP030000003jl>H0n_3V02P0n_3V0@3oool002L0n_3V00<00000
0;34gP2`a=h0o`2`a=h=0;34gP030000003jl>H0n_3V02@0n_3V00@000000?[`iP3jl>H000000`3j
l>H00`000000n_3V0?[`iP0X0?[`iP40oooo000W0?[`iP030000002`a=h0/<CN0?l0/<CN302`a=h0
0`000000n_3V0?[`iP0U0?[`iP040000003jl>H0n_3V0?[`iP<00000:`3jl>H10?ooo`00:03jl>H0
0`000000/<CN0;34gP3o0;34gP/0/<CN00<000000?[`iP3jl>H08@3jl>H50?l00340n_3V0@3oool0
02T0n_3V00<000000;34gP2`a=h0o`2`a=h90;34gP030000003jl>H0n_3V02H0n_3V00<000000?[`
iP3jl>H0;`3jl>H10?ooo`00:@3jl>H00`000000/<CN0;34gP3o0;34gPP0/<CN00<000000?[`iP3j
l>H09`3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000Z0?[`iP030000002`a=h0/<CN0?l0/<CN
1`2`a=h00`000000n_3V0?[`iP0W0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool002X0n_3V00<0
00000;34gP2`a=h0o`2`a=h60;34gP030000003jl>H0n_3V02P0n_3V00<000000?[`iP3jl>H0;`3j
l>H10?ooo`00:`3jl>H00`000000/<CN0;34gP3o0;34gPD0/<CN00<000000?[`iP3jl>H0:03jl>H0
0`000000n_3V0?[`iP0_0?[`iP40oooo000/0?[`iP030000002`a=h0/<CN0?l0/<CN0`2`a=h00`00
0000n_3V0?[`iP0U0?[`iPD0o`00<@3jl>H10?ooo`00;@3jl>H00`000000/<CN0;34gP3o0;34gP40
/<CN00<000000?[`iP3jl>H0:P3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000^0?[`iP030000
002`a=h0/<CN0?h0/<CN00<000000?[`iP3jl>H0:`3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo
000_0?[`iP030000002`a=h0/<CN0?`0/<CN00<000000?[`iP3jl>H0;03jl>H00`000000n_3V0?[`
iP0_0?[`iP40oooo000`0?[`iP030000002`a=h0/<CN0?X0/<CN00<000000?[`iP3jl>H0;@3jl>H0
0`000000n_3V0?[`iP0_0?[`iP40oooo000a0?[`iP030000002`a=h0/<CN0?P0/<CN00<000000?[`
iP3jl>H0:P3jl>H50?l00340n_3V0@3oool00340n_3V00<000000;34gP2`a=h0m`2`a=h00`000000
n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool00380n_3V00<000000;34gP2`a=h0
mP2`a=h00`000000n_3V0?[`iP0_0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool003<0n_3V0P00
003d0;34gP800000<P3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000e0?[`iP030000002`a=h0
/<CN0?00/<CN00<000000?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo000f0?[`
iP030000002`a=h0/<CN0>l0/<CN00<000000?[`iP3jl>H0<P3jl>H00`000000n_3V0?[`iP0_0?[`
iP40oooo000g0?[`iP030000002`a=h0/<CN0>`0/<CN0P00000a0?[`iPD0o`00<@3jl>H10?ooo`00
>03jl>H00`000000/<CN0;34gP3Z0;34gP030000003jl>H0n_3V03D0n_3V00<000000?[`iP3jl>H0
;`3jl>H10?ooo`00>@3jl>H00`000000/<CN0;34gP3X0;34gP030000003jl>H0n_3V03H0n_3V00<0
00000?[`iP3jl>H0;`3jl>H10?ooo`00>P3jl>H200000>H0/<CN0P00000i0?[`iP030000003jl>H0
n_3V02l0n_3V0@3oool003`0n_3V0P00003R0;34gP800000>`3jl>H00`000000n_3V0?[`iP040?[`
iP030000003jl>H0n_3V02P0n_3V0@3oool003h0n_3V00<000000;34gP2`a=h0gP2`a=h00`000000
n_3V0?[`iP0k0?[`iP030000003jl>H0n_3V00@0n_3V00<000000?[`iP3jl>H0:03jl>H10?ooo`00
?`3jl>H00`000000/<CN0;34gP3L0;34gP030000003jl>H0n_3V03H0n_3V1`0000020?[`iPH00000
:@3jl>H10?ooo`00@03jl>H200000=X0/<CN0P00000o0?[`iP040000003jl>H0n_3V000000<0n_3V
00<000000?[`iP3jl>H0:03jl>H10?ooo`00@P3jl>H00`000000/<CN0;34gP3F0;34gP030000003j
l>H0n_3V03l0n_3V00D000000?[`iP3jl>H0n_3V000000020?[`iP030000003jl>H0n_3V02P0n_3V
0@3oool004<0n_3V0P00003D0;34gP800000@P3jl>H00`000000n_3V0?[`iP020?[`iP030000003j
l>H0000002X0n_3V0@3oool004D0n_3V0P00003@0;34gP800000A03jl>H00`000000n_3V0?[`iP03
0?[`iP800000:P3jl>H10?ooo`00A`3jl>H200000<`0/<CN0P0000120?[`iPD0o`00<@3jl>H10?oo
o`00B@3jl>H200000<P0/<CN0P0000180?[`iP030000003jl>H0n_3V02l0n_3V0@3oool004/0n_3V
0P0000340;34gP800000BP3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo001=0?[`iP030000002`
a=h0/<CN0<00/<CN00<000000?[`iP3jl>H0BP3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo001>
0?[`iP<00000_02`a=h3000004d0n_3V00<000000?[`iP3jl>H0;`3jl>H10?ooo`00D@3jl>H30000
0;H0/<CN0`00001@0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool005@0n_3V0P00002b0;34gP80
0000C`3jl>H50?l00340n_3V0@3oool005H0n_3V0`00002/0;34gP<00000E@3jl>H00`000000n_3V
0?[`iP0_0?[`iP40oooo001I0?[`iP<00000YP2`a=h3000005P0n_3V00<000000?[`iP3jl>H0;`3j
l>H10?ooo`00G03jl>H300000:00/<CN0`00001K0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool0
05l0n_3V0`00002J0;34gP<00000GP3jl>H00`000000n_3V0?[`iP0_0?[`iP40oooo001R0?[`iP<0
0000U02`a=h3000005d0n_3V1@3o000a0?[`iP40oooo001U0?[`iP<00000SP2`a=h3000006@0n_3V
00<000000?[`iP3jl>H0;`3jl>H10?ooo`00J03jl>H2000008T0/<CN0`00001W0?[`iP030000003j
l>H0n_3V02l0n_3V0@3oool006X0n_3V100000220;34gP<00000JP3jl>H00`000000n_3V0?[`iP0_
0?[`iP40oooo001^0?[`iP<00000O02`a=h3000006d0n_3V00<000000?[`iP3jl>H0;`3jl>H10?oo
o`00L@3jl>H500000780/<CN1@00001`0?[`iP030000003jl>H0n_3V02l0n_3V0@3oool007H0n_3V
1@00001X0;34gPD00000L@3jl>H50?l00340n_3V0@3oool007/0n_3V1@00001N0;34gPD00000NP3j
l>H00`000000n_3V0?[`iP0_0?[`iP40oooo00200?[`iPH00000DP2`a=h6000007l0n_3V00<00000
0?[`iP3jl>H0;`3jl>H10?ooo`00QP3jl>H7000004@0/<CN1`0000250?[`iP030000003jl>H0n_3V
02l0n_3V0@3oool008d0n_3V2P00000`0;34gPX00000S03jl>H010000000n_3V0?[`iP3jl>H30000
02/0n_3V0@3oool009L0n_3V4P00000=0;34gQ400000UP3jl>H010000000n_3V0?[`iP0000030?[`
iP030000003jl>H0n_3V02P0n_3V0@3oool00:T0n_3V3@00002Q0?[`iPL000001P3jl>H00`000000
n_3V0?[`iP0X0?[`iP40oooo003o0?[`iV40n_3V00D000000?[`iP3jl>H0n_3V0000000Z0?[`iP40
oooo003o0?[`iV40n_3V1000000[0?[`iP40oooo003o0?[`iV80n_3V00<000000?[`iP3jl>H0:`3j
l>H10?ooo`00o`3jl>IR0?[`iP@00000:P3jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00
n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool0
0?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03j
l>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00
o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`
iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o
0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V
0@3oool00?l0n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0
n_3VT03jl>H10?ooo`00o`3jl>J@0?[`iP40oooo003o0?[`iY00n_3V0@3oool00?l0n_3VT03jl>H1
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {244.563, 0}} -> {-2.50514, -2.00001, \
0.0143115, 0.0143115}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->{},
WindowSize->{494, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 56, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1835, 56, 455, 15, 74, "Usage",
      CellTags->"Function?"],
    Cell[2293, 73, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 101344, 3390}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 56, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1835, 56, 455, 15, 74, "Usage",
  CellTags->"Function?"],
Cell[2293, 73, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2390, 78, 110, 3, 41, "MathCaption"],
Cell[2503, 83, 111, 3, 41, "MathCaption"],
Cell[2617, 88, 124, 3, 58, "MathCaption"],
Cell[2744, 93, 195, 4, 58, "MathCaption"],
Cell[2942, 99, 93, 2, 41, "MathCaption"],
Cell[3038, 103, 475, 15, 92, "MathCaption"],
Cell[3516, 120, 485, 15, 92, "MathCaption"],
Cell[4004, 137, 654, 18, 109, "MathCaption"],
Cell[4661, 157, 308, 13, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[4994, 174, 34, 0, 39, "ExampleSection"],
Cell[5031, 176, 99, 2, 29, "Input"],
Cell[5133, 180, 93, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[5251, 186, 777, 12, 229, "Input"],
Cell[6031, 200, 44598, 1542, 252, 25468, 1302, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[50644, 1745, 150, 3, 42, "Text"],

Cell[CellGroupData[{
Cell[50819, 1752, 1443, 23, 389, "Input"],
Cell[52265, 1777, 48388, 1591, 252, 25657, 1306, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

