(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6050,        233]*)
(*NotebookOutlinePosition[      7058,        268]*)
(*  CellTagsIndexPosition[      6984,        262]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["YSymbolicScale", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["YSymbolicScale",
            "MR"], 
          StyleBox["[",
            "MR"], 
          
          StyleBox[\({ymin, ymax, yloc}, {rangemin, rangemax}, 
            marks : {{y, yval} .. }, xplus : 0.02, xminus : 0, 
            labloc : \(-0.04\)\),
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox[" ",
          "MR"], 
        StyleBox["will",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["draw",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["a",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["scale",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["in",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["the",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["x",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["direction",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["with",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["tick",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["marks",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["and",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["values",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["as",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["indicated",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["in",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["the",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox["marks",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox[\(\(list\)\(.\)\),
          "MR"]}]]],
  " "
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
xmin, xmax and xloc control the actual placement of the scale in the \
graphics.\
\>", "MathCaption"],

Cell[TextData[{
  "The scale will linearly represent values from ",
  Cell[BoxData[
      \(rangemin\  < \ y\  < \ rangemax\)]],
  "."
}], "MathCaption"],

Cell["\<\
The mark values give the placement and value of the ticks on the scale. The \
values may be symbolic. The y placements do not have to be uniformly spaced. \
It is similar to databased CustomTicks or CustomGridLines.\
\>", "MathCaption"],

Cell[TextData[{
  "The mark values may optionally be given as ",
  Cell[BoxData[
      \({y, val, textoffset}\)]],
  " where textoffset is inserted in the Text statement displaying the value. \
The default value for textoffset is ",
  Cell[BoxData[
      \({0, 0}\)]],
  "."
}], "MathCaption"],

Cell["\<\
xplus and xminus give the right and left positions of the tick marks as in \
the Ticks specification statements. labloc gives the placement of the value \
label from the line. These can also be individually modified with textoffset \
as in the preceding note.\
\>", "MathCaption"],

Cell["\<\
XSymbolicScale, YSymbolicScale, XTickLine and YTickLine are especially useful \
in attaching scales to Rectangle plots laid on a larger piece of paper. The \
scales can actually be placed outside the Rectangles but right next to \
them.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["XSymbolicScale",
    ButtonData:>{"XSymbolicScale"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["XTickLine",
    ButtonData:>{"XTickLine"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CustomTicks",
    ButtonData:>{"CustomTicks"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["Ticks",
    ButtonStyle->"RefGuideLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[TextData[{
  "See the example in ",
  ButtonBox["XSymbolicScale",
    ButtonData:>{"XSymbolicScale"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{786, 543},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 61, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1840, 56, 2065, 94, 51, "Usage",
      CellTags->"Function?"],
    Cell[3908, 152, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6736, 251}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 61, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1840, 56, 2065, 94, 51, "Usage",
  CellTags->"Function?"],
Cell[3908, 152, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[4005, 157, 111, 3, 41, "MathCaption"],
Cell[4119, 162, 153, 5, 41, "MathCaption"],
Cell[4275, 169, 246, 4, 58, "MathCaption"],
Cell[4524, 175, 293, 9, 58, "MathCaption"],
Cell[4820, 186, 290, 5, 58, "MathCaption"],
Cell[5113, 193, 267, 5, 58, "MathCaption"],
Cell[5383, 200, 414, 17, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[5822, 221, 34, 0, 39, "ExampleSection"],
Cell[5859, 223, 163, 6, 41, "MathCaption"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

