(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5201,        186]*)
(*NotebookOutlinePosition[      6172,        220]*)
(*  CellTagsIndexPosition[      6098,        214]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["YTickLine", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["YTickLine",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\({ymin, ymax, xloc}, {rangemin, rangemax}, {labelstart, 
            labelend, increment}, subdivisions, opts ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " \nwill draw a vertical labeled line with tick marks"
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Display of the Graphics is suppressed.\
\>", "MathCaption",
  CellTags->"Function?"],

Cell["\<\
ymin,ymax and xloc control the actual placement of the line in the \
graphics.\
\>", "MathCaption"],

Cell["\<\
rangemin and rangemax specify what number range this line is meant to \
signify.\
\>", "MathCaption"],

Cell["\<\
labelstart, labelend and increment specify the values and spacing for the \
major tick marks.\
\>", "MathCaption"],

Cell["\<\
subdivisions gives the number of subdivisions between the major tick marks. \
The number of unlabeled tick marks will be one less than the number of \
subdivisions.\
\>", "MathCaption"],

Cell["\<\
The options are YLabTickSpecs, YUnLabTickSpecs and YTextSpecs.\
\>", "MathCaption"],

Cell[TextData[{
  "YLabTickSpecs specifies the details for the labeled tick lines. It can \
take the form ",
  Cell[BoxData[
      \({plen, mlen, {style\ directives}}\)]],
  " where the last item is optional. plen and mlen are as in the regular ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  ButtonBox["Ticks",
    ButtonStyle->"RefGuideLink"],
  " specification. The default value is ",
  Cell[BoxData[
      \(\((0.00625, 0)\)\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "YUnLabTickSpecs specifies the details for the minor unlabeled tick lines. \
It can take the form ",
  Cell[BoxData[
      \({plen, mlen, {style\ directives}}\)]],
  " where the last item is optional. plen and mlen are as in the regular ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  ButtonBox["Ticks",
    ButtonStyle->"RefGuideLink"],
  " specification. The default value is ",
  Cell[BoxData[
      \(\((0.00375, 0)\)\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "YTextSpecs specifies the placement and style for the label values. It \
takes the form ",
  Cell[BoxData[
      \({offset, direction, displacement, options ... }\)]],
  ". offset and direction are as in the regular ",
  ButtonBox["Text",
    ButtonStyle->"RefGuideLink"],
  " statement. displacement is the ",
  ButtonBox["Scaled",
    ButtonStyle->"RefGuideLink"],
  " displacement of the label from the line. Options can be used to pass ",
  ButtonBox["StyleForm",
    ButtonStyle->"RefGuideLink"],
  "  type options for the label. The default value is ",
  Cell[BoxData[
      \({{1, 0}, {1, 0}, 0.002}\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["XTickLine",
    ButtonData:>{"XTickLine"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CustomTicks",
    ButtonData:>{"CustomTicks"},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["Ticks",
    ButtonStyle->"RefGuideLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection"],

Cell[TextData[{
  "See the example in ",
  ButtonBox["XTickLine",
    ButtonData:>{"XTickLine"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{494, 740},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 56, 1, 41, "ObjectName",
      CellTags->"Function?"],
    Cell[1835, 56, 453, 15, 74, "Usage",
      CellTags->"Function?"],
    Cell[2291, 73, 94, 3, 41, "MathCaption",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5852, 203}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 56, 1, 41, "ObjectName",
  CellTags->"Function?"],
Cell[1835, 56, 453, 15, 74, "Usage",
  CellTags->"Function?"],
Cell[2291, 73, 94, 3, 41, "MathCaption",
  CellTags->"Function?"],
Cell[2388, 78, 109, 3, 41, "MathCaption"],
Cell[2500, 83, 111, 3, 41, "MathCaption"],
Cell[2614, 88, 124, 3, 58, "MathCaption"],
Cell[2741, 93, 195, 4, 58, "MathCaption"],
Cell[2939, 99, 93, 2, 41, "MathCaption"],
Cell[3035, 103, 475, 15, 92, "MathCaption"],
Cell[3513, 120, 485, 15, 92, "MathCaption"],
Cell[4001, 137, 654, 18, 109, "MathCaption"],
Cell[4658, 157, 308, 13, 41, "MathCaption"],

Cell[CellGroupData[{
Cell[4991, 174, 33, 0, 39, "ExampleSection"],
Cell[5027, 176, 146, 6, 25, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

